/*
Package opstateoc is a generated package which contains definitions
of structs which represent a YANG schema. The generated schema can be
compressed by a series of transformations (compression was true
in this case).

NOTE WELL: This is an example code file that is distributed with ygot.
It should not be used within your application, as it WILL change,
without warning. Rather, you should generate structs directly from
OpenConfig models using the ygot package.

This package was generated by github.com/openconfig/ygot
using the following YANG input files:
	- public/release/models/network-instance/openconfig-network-instance.yang
	- public/release/models/optical-transport/openconfig-optical-amplifier.yang
	- public/release/models/optical-transport/openconfig-terminal-device.yang
	- public/release/models/optical-transport/openconfig-transport-line-protection.yang
	- public/release/models/platform/openconfig-platform.yang
	- public/release/models/policy/openconfig-routing-policy.yang
	- public/release/models/lacp/openconfig-lacp.yang
	- public/release/models/system/openconfig-system.yang
	- public/release/models/lldp/openconfig-lldp.yang
	- public/release/models/stp/openconfig-spanning-tree.yang
	- public/release/models/interfaces/openconfig-interfaces.yang
	- public/release/models/interfaces/openconfig-if-ip.yang
	- public/release/models/interfaces/openconfig-if-aggregate.yang
	- public/release/models/interfaces/openconfig-if-ethernet.yang
	- public/release/models/interfaces/openconfig-if-ip-ext.yang
	- public/release/models/relay-agent/openconfig-relay-agent.yang
	- public/release/models/lldp/openconfig-lldp.yang
Imported modules were sourced from:
	- public/...
	- deps/...
*/
package opstateoc

import (
	"encoding/json"
	"fmt"
	"reflect"

	"github.com/openconfig/goyang/pkg/yang"
	"github.com/openconfig/ygot/ygot"
	"github.com/openconfig/ygot/ytypes"
)

// Binary is a type that is used for fields that have a YANG type of
// binary. It is used such that binary fields can be distinguished from
// leaf-lists of uint8s (which are mapped to []uint8, equivalent to
// []byte in reflection).
type Binary []byte

// YANGEmpty is a type that is used for fields that have a YANG type of
// empty. It is used such that empty fields can be distinguished from boolean fields
// in the generated code.
type YANGEmpty bool

// UnionInt8 is an int8 type assignable to unions of which it is a subtype.
type UnionInt8 int8

// UnionInt16 is an int16 type assignable to unions of which it is a subtype.
type UnionInt16 int16

// UnionInt32 is an int32 type assignable to unions of which it is a subtype.
type UnionInt32 int32

// UnionInt64 is an int64 type assignable to unions of which it is a subtype.
type UnionInt64 int64

// UnionUint8 is a uint8 type assignable to unions of which it is a subtype.
type UnionUint8 uint8

// UnionUint16 is a uint16 type assignable to unions of which it is a subtype.
type UnionUint16 uint16

// UnionUint32 is a uint32 type assignable to unions of which it is a subtype.
type UnionUint32 uint32

// UnionUint64 is a uint64 type assignable to unions of which it is a subtype.
type UnionUint64 uint64

// UnionFloat64 is a float64 type assignable to unions of which it is a subtype.
type UnionFloat64 float64

// UnionString is a string type assignable to unions of which it is a subtype.
type UnionString string

// UnionBool is a bool type assignable to unions of which it is a subtype.
type UnionBool bool

// UnionUnsupported is an interface{} wrapper type for unsupported types. It is
// assignable to unions of which it is a subtype.
type UnionUnsupported struct {
	Value interface{}
}

var (
	SchemaTree map[string]*yang.Entry
)

func init() {
	var err error
	if SchemaTree, err = UnzipSchema(); err != nil {
		panic("schema error: " + err.Error())
	}
}

// Schema returns the details of the generated schema.
func Schema() (*ytypes.Schema, error) {
	uzp, err := UnzipSchema()
	if err != nil {
		return nil, fmt.Errorf("cannot unzip schema, %v", err)
	}

	return &ytypes.Schema{
		Root:       &Device{},
		SchemaTree: uzp,
		Unmarshal:  Unmarshal,
	}, nil
}

// UnzipSchema unzips the zipped schema and returns a map of yang.Entry nodes,
// keyed by the name of the struct that the yang.Entry describes the schema for.
func UnzipSchema() (map[string]*yang.Entry, error) {
	var schemaTree map[string]*yang.Entry
	var err error
	if schemaTree, err = ygot.GzipToSchema(ySchema); err != nil {
		return nil, fmt.Errorf("could not unzip the schema; %v", err)
	}
	return schemaTree, nil
}

// Unmarshal unmarshals data, which must be RFC7951 JSON format, into
// destStruct, which must be non-nil and the correct GoStruct type. It returns
// an error if the destStruct is not found in the schema or the data cannot be
// unmarshaled. The supplied options (opts) are used to control the behaviour
// of the unmarshal function - for example, determining whether errors are
// thrown for unknown fields in the input JSON.
func Unmarshal(data []byte, destStruct ygot.GoStruct, opts ...ytypes.UnmarshalOpt) error {
	tn := reflect.TypeOf(destStruct).Elem().Name()
	schema, ok := SchemaTree[tn]
	if !ok {
		return fmt.Errorf("could not find schema for type %s", tn)
	}
	var jsonTree interface{}
	if err := json.Unmarshal([]byte(data), &jsonTree); err != nil {
		return err
	}
	return ytypes.Unmarshal(schema, destStruct, jsonTree, opts...)
}

// Acl represents the /openconfig-acl/acl YANG schema element.
type Acl struct {
	ΛMetadata          []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	AclSet             map[Acl_AclSet_Key]*Acl_AclSet         `path:"acl-sets/acl-set" module:"openconfig-acl"`
	ΛAclSet            []ygot.Annotation                      `path:"acl-sets/@acl-set" ygotAnnotation:"true"`
	CounterCapability  E_OpenconfigAcl_ACL_COUNTER_CAPABILITY `path:"state/counter-capability" module:"openconfig-acl"`
	ΛCounterCapability []ygot.Annotation                      `path:"state/@counter-capability" ygotAnnotation:"true"`
	Interface          map[string]*Acl_Interface              `path:"interfaces/interface" module:"openconfig-acl"`
	ΛInterface         []ygot.Annotation                      `path:"interfaces/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl) IsYANGGoStruct() {}

// Acl_AclSet_Key represents the key for list AclSet of element /openconfig-acl/acl.
type Acl_AclSet_Key struct {
	Name string                   `path:"name"`
	Type E_OpenconfigAcl_ACL_TYPE `path:"type"`
}

// NewAclSet creates a new entry in the AclSet list of the
// Acl struct. The keys of the list are populated from the input
// arguments.
func (t *Acl) NewAclSet(Name string, Type E_OpenconfigAcl_ACL_TYPE) (*Acl_AclSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclSet == nil {
		t.AclSet = make(map[Acl_AclSet_Key]*Acl_AclSet)
	}

	key := Acl_AclSet_Key{
		Name: Name,
		Type: Type,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclSet", key)
	}

	t.AclSet[key] = &Acl_AclSet{
		Name: &Name,
		Type: Type,
	}

	return t.AclSet[key], nil
}

// RenameAclSet renames an entry in the list AclSet within
// the Acl struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl) RenameAclSet(oldK, newK Acl_AclSet_Key) error {
	if _, ok := t.AclSet[newK]; ok {
		return fmt.Errorf("key %v already exists in AclSet", newK)
	}

	e, ok := t.AclSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AclSet", oldK)
	}
	e.Name = &newK.Name
	e.Type = newK.Type

	t.AclSet[newK] = e
	delete(t.AclSet, oldK)
	return nil
}

// GetOrCreateAclSet retrieves the value with the specified keys from
// the receiver Acl. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl) GetOrCreateAclSet(Name string, Type E_OpenconfigAcl_ACL_TYPE) *Acl_AclSet {

	key := Acl_AclSet_Key{
		Name: Name,
		Type: Type,
	}

	if v, ok := t.AclSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAclSet(Name, Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAclSet got unexpected error: %v", err))
	}
	return v
}

// GetAclSet retrieves the value with the specified key from
// the AclSet map field of Acl. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl) GetAclSet(Name string, Type E_OpenconfigAcl_ACL_TYPE) *Acl_AclSet {

	if t == nil {
		return nil
	}

	key := Acl_AclSet_Key{
		Name: Name,
		Type: Type,
	}

	if lm, ok := t.AclSet[key]; ok {
		return lm
	}
	return nil
}

// AppendAclSet appends the supplied Acl_AclSet struct to the
// list AclSet of Acl. If the key value(s) specified in
// the supplied Acl_AclSet already exist in the list, an error is
// returned.
func (t *Acl) AppendAclSet(v *Acl_AclSet) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key for Name")
	}

	key := Acl_AclSet_Key{
		Name: *v.Name,
		Type: v.Type,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclSet == nil {
		t.AclSet = make(map[Acl_AclSet_Key]*Acl_AclSet)
	}

	if _, ok := t.AclSet[key]; ok {
		return fmt.Errorf("duplicate key for list AclSet %v", key)
	}

	t.AclSet[key] = v
	return nil
}

// NewInterface creates a new entry in the Interface list of the
// Acl struct. The keys of the list are populated from the input
// arguments.
func (t *Acl) NewInterface(Id string) (*Acl_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Acl_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Acl_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Acl struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Id = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Acl. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl) GetOrCreateInterface(Id string) *Acl_Interface {

	key := Id

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Acl. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl) GetInterface(Id string) *Acl_Interface {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Acl_Interface struct to the
// list Interface of Acl. If the key value(s) specified in
// the supplied Acl_Interface already exist in the list, an error is
// returned.
func (t *Acl) AppendInterface(v *Acl_Interface) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Acl_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetCounterCapability retrieves the value of the leaf CounterCapability from the Acl
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CounterCapability is set, it can safely use t.GetCounterCapability()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CounterCapability == nil'
// before retrieving the leaf's value.
func (t *Acl) GetCounterCapability() E_OpenconfigAcl_ACL_COUNTER_CAPABILITY {
	if t == nil || t.CounterCapability == 0 {
		return 0
	}
	return t.CounterCapability
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet represents the /openconfig-acl/acl/acl-sets/acl-set YANG schema element.
type Acl_AclSet struct {
	ΛMetadata    []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	AclEntry     map[uint32]*Acl_AclSet_AclEntry `path:"acl-entries/acl-entry" module:"openconfig-acl"`
	ΛAclEntry    []ygot.Annotation               `path:"acl-entries/@acl-entry" ygotAnnotation:"true"`
	Description  *string                         `path:"state/description" shadow-path:"config/description" module:"openconfig-acl"`
	ΛDescription []ygot.Annotation               `path:"state/@description" ygotAnnotation:"true"`
	Name         *string                         `path:"state/name|name" shadow-path:"config/name" module:"openconfig-acl"`
	ΛName        []ygot.Annotation               `path:"state/@name|@name" ygotAnnotation:"true"`
	Type         E_OpenconfigAcl_ACL_TYPE        `path:"state/type|type" shadow-path:"config/type" module:"openconfig-acl"`
	ΛType        []ygot.Annotation               `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet) IsYANGGoStruct() {}

// NewAclEntry creates a new entry in the AclEntry list of the
// Acl_AclSet struct. The keys of the list are populated from the input
// arguments.
func (t *Acl_AclSet) NewAclEntry(SequenceId uint32) (*Acl_AclSet_AclEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*Acl_AclSet_AclEntry)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclEntry", key)
	}

	t.AclEntry[key] = &Acl_AclSet_AclEntry{
		SequenceId: &SequenceId,
	}

	return t.AclEntry[key], nil
}

// RenameAclEntry renames an entry in the list AclEntry within
// the Acl_AclSet struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl_AclSet) RenameAclEntry(oldK, newK uint32) error {
	if _, ok := t.AclEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in AclEntry", newK)
	}

	e, ok := t.AclEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AclEntry", oldK)
	}
	e.SequenceId = &newK

	t.AclEntry[newK] = e
	delete(t.AclEntry, oldK)
	return nil
}

// GetOrCreateAclEntry retrieves the value with the specified keys from
// the receiver Acl_AclSet. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl_AclSet) GetOrCreateAclEntry(SequenceId uint32) *Acl_AclSet_AclEntry {

	key := SequenceId

	if v, ok := t.AclEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAclEntry(SequenceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAclEntry got unexpected error: %v", err))
	}
	return v
}

// GetAclEntry retrieves the value with the specified key from
// the AclEntry map field of Acl_AclSet. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl_AclSet) GetAclEntry(SequenceId uint32) *Acl_AclSet_AclEntry {

	if t == nil {
		return nil
	}

	key := SequenceId

	if lm, ok := t.AclEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendAclEntry appends the supplied Acl_AclSet_AclEntry struct to the
// list AclEntry of Acl_AclSet. If the key value(s) specified in
// the supplied Acl_AclSet_AclEntry already exist in the list, an error is
// returned.
func (t *Acl_AclSet) AppendAclEntry(v *Acl_AclSet_AclEntry) error {
	if v.SequenceId == nil {
		return fmt.Errorf("invalid nil key received for SequenceId")
	}

	key := *v.SequenceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*Acl_AclSet_AclEntry)
	}

	if _, ok := t.AclEntry[key]; ok {
		return fmt.Errorf("duplicate key for list AclEntry %v", key)
	}

	t.AclEntry[key] = v
	return nil
}

// GetDescription retrieves the value of the leaf Description from the Acl_AclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetName retrieves the value of the leaf Name from the Acl_AclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetType retrieves the value of the leaf Type from the Acl_AclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet) GetType() E_OpenconfigAcl_ACL_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Acl_AclSet struct, which is a YANG list entry.
func (t *Acl_AclSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry YANG schema element.
type Acl_AclSet_AclEntry struct {
	ΛMetadata       []ygot.Annotation                   `path:"@" ygotAnnotation:"true"`
	Actions         *Acl_AclSet_AclEntry_Actions        `path:"actions" module:"openconfig-acl"`
	ΛActions        []ygot.Annotation                   `path:"@actions" ygotAnnotation:"true"`
	Description     *string                             `path:"state/description" shadow-path:"config/description" module:"openconfig-acl"`
	ΛDescription    []ygot.Annotation                   `path:"state/@description" ygotAnnotation:"true"`
	InputInterface  *Acl_AclSet_AclEntry_InputInterface `path:"input-interface" module:"openconfig-acl"`
	ΛInputInterface []ygot.Annotation                   `path:"@input-interface" ygotAnnotation:"true"`
	Ipv4            *Acl_AclSet_AclEntry_Ipv4           `path:"ipv4" module:"openconfig-acl"`
	ΛIpv4           []ygot.Annotation                   `path:"@ipv4" ygotAnnotation:"true"`
	Ipv6            *Acl_AclSet_AclEntry_Ipv6           `path:"ipv6" module:"openconfig-acl"`
	ΛIpv6           []ygot.Annotation                   `path:"@ipv6" ygotAnnotation:"true"`
	L2              *Acl_AclSet_AclEntry_L2             `path:"l2" module:"openconfig-acl"`
	ΛL2             []ygot.Annotation                   `path:"@l2" ygotAnnotation:"true"`
	MatchedOctets   *uint64                             `path:"state/matched-octets" module:"openconfig-acl"`
	ΛMatchedOctets  []ygot.Annotation                   `path:"state/@matched-octets" ygotAnnotation:"true"`
	MatchedPackets  *uint64                             `path:"state/matched-packets" module:"openconfig-acl"`
	ΛMatchedPackets []ygot.Annotation                   `path:"state/@matched-packets" ygotAnnotation:"true"`
	SequenceId      *uint32                             `path:"state/sequence-id|sequence-id" shadow-path:"config/sequence-id" module:"openconfig-acl"`
	ΛSequenceId     []ygot.Annotation                   `path:"state/@sequence-id|@sequence-id" ygotAnnotation:"true"`
	Transport       *Acl_AclSet_AclEntry_Transport      `path:"transport" module:"openconfig-acl"`
	ΛTransport      []ygot.Annotation                   `path:"@transport" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry) IsYANGGoStruct() {}

// GetOrCreateActions retrieves the value of the Actions field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry) GetOrCreateActions() *Acl_AclSet_AclEntry_Actions {
	if t.Actions != nil {
		return t.Actions
	}
	t.Actions = &Acl_AclSet_AclEntry_Actions{}
	return t.Actions
}

// GetOrCreateInputInterface retrieves the value of the InputInterface field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry) GetOrCreateInputInterface() *Acl_AclSet_AclEntry_InputInterface {
	if t.InputInterface != nil {
		return t.InputInterface
	}
	t.InputInterface = &Acl_AclSet_AclEntry_InputInterface{}
	return t.InputInterface
}

// GetOrCreateIpv4 retrieves the value of the Ipv4 field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry) GetOrCreateIpv4() *Acl_AclSet_AclEntry_Ipv4 {
	if t.Ipv4 != nil {
		return t.Ipv4
	}
	t.Ipv4 = &Acl_AclSet_AclEntry_Ipv4{}
	return t.Ipv4
}

// GetOrCreateIpv6 retrieves the value of the Ipv6 field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry) GetOrCreateIpv6() *Acl_AclSet_AclEntry_Ipv6 {
	if t.Ipv6 != nil {
		return t.Ipv6
	}
	t.Ipv6 = &Acl_AclSet_AclEntry_Ipv6{}
	return t.Ipv6
}

// GetOrCreateL2 retrieves the value of the L2 field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry) GetOrCreateL2() *Acl_AclSet_AclEntry_L2 {
	if t.L2 != nil {
		return t.L2
	}
	t.L2 = &Acl_AclSet_AclEntry_L2{}
	return t.L2
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry) GetOrCreateTransport() *Acl_AclSet_AclEntry_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &Acl_AclSet_AclEntry_Transport{}
	return t.Transport
}

// GetActions returns the value of the Actions struct pointer
// from Acl_AclSet_AclEntry. If the receiver or the field Actions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry) GetActions() *Acl_AclSet_AclEntry_Actions {
	if t != nil && t.Actions != nil {
		return t.Actions
	}
	return nil
}

// GetInputInterface returns the value of the InputInterface struct pointer
// from Acl_AclSet_AclEntry. If the receiver or the field InputInterface is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry) GetInputInterface() *Acl_AclSet_AclEntry_InputInterface {
	if t != nil && t.InputInterface != nil {
		return t.InputInterface
	}
	return nil
}

// GetIpv4 returns the value of the Ipv4 struct pointer
// from Acl_AclSet_AclEntry. If the receiver or the field Ipv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry) GetIpv4() *Acl_AclSet_AclEntry_Ipv4 {
	if t != nil && t.Ipv4 != nil {
		return t.Ipv4
	}
	return nil
}

// GetIpv6 returns the value of the Ipv6 struct pointer
// from Acl_AclSet_AclEntry. If the receiver or the field Ipv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry) GetIpv6() *Acl_AclSet_AclEntry_Ipv6 {
	if t != nil && t.Ipv6 != nil {
		return t.Ipv6
	}
	return nil
}

// GetL2 returns the value of the L2 struct pointer
// from Acl_AclSet_AclEntry. If the receiver or the field L2 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry) GetL2() *Acl_AclSet_AclEntry_L2 {
	if t != nil && t.L2 != nil {
		return t.L2
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from Acl_AclSet_AclEntry. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry) GetTransport() *Acl_AclSet_AclEntry_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetDescription retrieves the value of the leaf Description from the Acl_AclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetMatchedOctets retrieves the value of the leaf MatchedOctets from the Acl_AclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedOctets is set, it can safely use t.GetMatchedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedOctets == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry) GetMatchedOctets() uint64 {
	if t == nil || t.MatchedOctets == nil {
		return 0
	}
	return *t.MatchedOctets
}

// GetMatchedPackets retrieves the value of the leaf MatchedPackets from the Acl_AclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedPackets is set, it can safely use t.GetMatchedPackets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedPackets == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry) GetMatchedPackets() uint64 {
	if t == nil || t.MatchedPackets == nil {
		return 0
	}
	return *t.MatchedPackets
}

// GetSequenceId retrieves the value of the leaf SequenceId from the Acl_AclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SequenceId is set, it can safely use t.GetSequenceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SequenceId == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry) GetSequenceId() uint32 {
	if t == nil || t.SequenceId == nil {
		return 0
	}
	return *t.SequenceId
}

// ΛListKeyMap returns the keys of the Acl_AclSet_AclEntry struct, which is a YANG list entry.
func (t *Acl_AclSet_AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry_Actions represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/actions YANG schema element.
type Acl_AclSet_AclEntry_Actions struct {
	ΛMetadata         []ygot.Annotation                 `path:"@" ygotAnnotation:"true"`
	ForwardingAction  E_OpenconfigAcl_FORWARDING_ACTION `path:"state/forwarding-action" shadow-path:"config/forwarding-action" module:"openconfig-acl"`
	ΛForwardingAction []ygot.Annotation                 `path:"state/@forwarding-action" ygotAnnotation:"true"`
	LogAction         E_OpenconfigAcl_LOG_ACTION        `path:"state/log-action" shadow-path:"config/log-action" module:"openconfig-acl"`
	ΛLogAction        []ygot.Annotation                 `path:"state/@log-action" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_Actions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_Actions) IsYANGGoStruct() {}

// GetForwardingAction retrieves the value of the leaf ForwardingAction from the Acl_AclSet_AclEntry_Actions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingAction is set, it can safely use t.GetForwardingAction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingAction == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Actions) GetForwardingAction() E_OpenconfigAcl_FORWARDING_ACTION {
	if t == nil || t.ForwardingAction == 0 {
		return 0
	}
	return t.ForwardingAction
}

// GetLogAction retrieves the value of the leaf LogAction from the Acl_AclSet_AclEntry_Actions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogAction is set, it can safely use t.GetLogAction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogAction == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Actions) GetLogAction() E_OpenconfigAcl_LOG_ACTION {
	if t == nil || t.LogAction == 0 {
		return OpenconfigAcl_LOG_ACTION_LOG_NONE
	}
	return t.LogAction
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_Actions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_Actions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_Actions) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry_InputInterface represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface YANG schema element.
type Acl_AclSet_AclEntry_InputInterface struct {
	ΛMetadata     []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	InterfaceRef  *Acl_AclSet_AclEntry_InputInterface_InterfaceRef `path:"interface-ref" module:"openconfig-acl"`
	ΛInterfaceRef []ygot.Annotation                                `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_InputInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_InputInterface) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *Acl_AclSet_AclEntry_InputInterface) GetOrCreateInterfaceRef() *Acl_AclSet_AclEntry_InputInterface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &Acl_AclSet_AclEntry_InputInterface_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from Acl_AclSet_AclEntry_InputInterface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_AclSet_AclEntry_InputInterface) GetInterfaceRef() *Acl_AclSet_AclEntry_InputInterface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_InputInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_InputInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_InputInterface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Acl_AclSet_AclEntry_InputInterface_InterfaceRef represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface/interface-ref YANG schema element.
type Acl_AclSet_AclEntry_InputInterface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-acl"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-acl"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_InputInterface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_InputInterface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the Acl_AclSet_AclEntry_InputInterface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_InputInterface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the Acl_AclSet_AclEntry_InputInterface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_InputInterface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_InputInterface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_InputInterface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_InputInterface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Acl_AclSet_AclEntry_Ipv4 represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4 YANG schema element.
type Acl_AclSet_AclEntry_Ipv4 struct {
	ΛMetadata           []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	DestinationAddress  *string                                 `path:"state/destination-address" shadow-path:"config/destination-address" module:"openconfig-acl"`
	ΛDestinationAddress []ygot.Annotation                       `path:"state/@destination-address" ygotAnnotation:"true"`
	Dscp                *uint8                                  `path:"state/dscp" shadow-path:"config/dscp" module:"openconfig-acl"`
	ΛDscp               []ygot.Annotation                       `path:"state/@dscp" ygotAnnotation:"true"`
	HopLimit            *uint8                                  `path:"state/hop-limit" shadow-path:"config/hop-limit" module:"openconfig-acl"`
	ΛHopLimit           []ygot.Annotation                       `path:"state/@hop-limit" ygotAnnotation:"true"`
	Protocol            Acl_AclSet_AclEntry_Ipv4_Protocol_Union `path:"state/protocol" shadow-path:"config/protocol" module:"openconfig-acl"`
	ΛProtocol           []ygot.Annotation                       `path:"state/@protocol" ygotAnnotation:"true"`
	SourceAddress       *string                                 `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-acl"`
	ΛSourceAddress      []ygot.Annotation                       `path:"state/@source-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_Ipv4) IsYANGGoStruct() {}

// GetDestinationAddress retrieves the value of the leaf DestinationAddress from the Acl_AclSet_AclEntry_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationAddress is set, it can safely use t.GetDestinationAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationAddress == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv4) GetDestinationAddress() string {
	if t == nil || t.DestinationAddress == nil {
		return ""
	}
	return *t.DestinationAddress
}

// GetDscp retrieves the value of the leaf Dscp from the Acl_AclSet_AclEntry_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dscp is set, it can safely use t.GetDscp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dscp == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv4) GetDscp() uint8 {
	if t == nil || t.Dscp == nil {
		return 0
	}
	return *t.Dscp
}

// GetHopLimit retrieves the value of the leaf HopLimit from the Acl_AclSet_AclEntry_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HopLimit is set, it can safely use t.GetHopLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HopLimit == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv4) GetHopLimit() uint8 {
	if t == nil || t.HopLimit == nil {
		return 0
	}
	return *t.HopLimit
}

// GetProtocol retrieves the value of the leaf Protocol from the Acl_AclSet_AclEntry_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Protocol is set, it can safely use t.GetProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Protocol == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv4) GetProtocol() Acl_AclSet_AclEntry_Ipv4_Protocol_Union {
	if t == nil || t.Protocol == nil {
		return nil
	}
	return t.Protocol
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the Acl_AclSet_AclEntry_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv4) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry_Ipv4_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state/protocol within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8].
type Acl_AclSet_AclEntry_Ipv4_Protocol_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8]
	Documentation_for_Acl_AclSet_AclEntry_Ipv4_Protocol_Union()
}

// Documentation_for_Acl_AclSet_AclEntry_Ipv4_Protocol_Union ensures that E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the Acl_AclSet_AclEntry_Ipv4_Protocol_Union interface.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Documentation_for_Acl_AclSet_AclEntry_Ipv4_Protocol_Union() {
}

// Documentation_for_Acl_AclSet_AclEntry_Ipv4_Protocol_Union ensures that UnionUint8
// implements the Acl_AclSet_AclEntry_Ipv4_Protocol_Union interface.
func (UnionUint8) Documentation_for_Acl_AclSet_AclEntry_Ipv4_Protocol_Union() {}

// To_Acl_AclSet_AclEntry_Ipv4_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Acl_AclSet_AclEntry_Ipv4_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Acl_AclSet_AclEntry_Ipv4) To_Acl_AclSet_AclEntry_Ipv4_Protocol_Union(i interface{}) (Acl_AclSet_AclEntry_Ipv4_Protocol_Union, error) {
	if v, ok := i.(Acl_AclSet_AclEntry_Ipv4_Protocol_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint8:
		return UnionUint8(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Acl_AclSet_AclEntry_Ipv4_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
}

// Acl_AclSet_AclEntry_Ipv6 represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6 YANG schema element.
type Acl_AclSet_AclEntry_Ipv6 struct {
	ΛMetadata             []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	DestinationAddress    *string                                 `path:"state/destination-address" shadow-path:"config/destination-address" module:"openconfig-acl"`
	ΛDestinationAddress   []ygot.Annotation                       `path:"state/@destination-address" ygotAnnotation:"true"`
	DestinationFlowLabel  *uint32                                 `path:"state/destination-flow-label" shadow-path:"config/destination-flow-label" module:"openconfig-acl"`
	ΛDestinationFlowLabel []ygot.Annotation                       `path:"state/@destination-flow-label" ygotAnnotation:"true"`
	Dscp                  *uint8                                  `path:"state/dscp" shadow-path:"config/dscp" module:"openconfig-acl"`
	ΛDscp                 []ygot.Annotation                       `path:"state/@dscp" ygotAnnotation:"true"`
	HopLimit              *uint8                                  `path:"state/hop-limit" shadow-path:"config/hop-limit" module:"openconfig-acl"`
	ΛHopLimit             []ygot.Annotation                       `path:"state/@hop-limit" ygotAnnotation:"true"`
	Protocol              Acl_AclSet_AclEntry_Ipv6_Protocol_Union `path:"state/protocol" shadow-path:"config/protocol" module:"openconfig-acl"`
	ΛProtocol             []ygot.Annotation                       `path:"state/@protocol" ygotAnnotation:"true"`
	SourceAddress         *string                                 `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-acl"`
	ΛSourceAddress        []ygot.Annotation                       `path:"state/@source-address" ygotAnnotation:"true"`
	SourceFlowLabel       *uint32                                 `path:"state/source-flow-label" shadow-path:"config/source-flow-label" module:"openconfig-acl"`
	ΛSourceFlowLabel      []ygot.Annotation                       `path:"state/@source-flow-label" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_Ipv6) IsYANGGoStruct() {}

// GetDestinationAddress retrieves the value of the leaf DestinationAddress from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationAddress is set, it can safely use t.GetDestinationAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationAddress == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetDestinationAddress() string {
	if t == nil || t.DestinationAddress == nil {
		return ""
	}
	return *t.DestinationAddress
}

// GetDestinationFlowLabel retrieves the value of the leaf DestinationFlowLabel from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationFlowLabel is set, it can safely use t.GetDestinationFlowLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationFlowLabel == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetDestinationFlowLabel() uint32 {
	if t == nil || t.DestinationFlowLabel == nil {
		return 0
	}
	return *t.DestinationFlowLabel
}

// GetDscp retrieves the value of the leaf Dscp from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dscp is set, it can safely use t.GetDscp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dscp == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetDscp() uint8 {
	if t == nil || t.Dscp == nil {
		return 0
	}
	return *t.Dscp
}

// GetHopLimit retrieves the value of the leaf HopLimit from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HopLimit is set, it can safely use t.GetHopLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HopLimit == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetHopLimit() uint8 {
	if t == nil || t.HopLimit == nil {
		return 0
	}
	return *t.HopLimit
}

// GetProtocol retrieves the value of the leaf Protocol from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Protocol is set, it can safely use t.GetProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Protocol == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetProtocol() Acl_AclSet_AclEntry_Ipv6_Protocol_Union {
	if t == nil || t.Protocol == nil {
		return nil
	}
	return t.Protocol
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// GetSourceFlowLabel retrieves the value of the leaf SourceFlowLabel from the Acl_AclSet_AclEntry_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceFlowLabel is set, it can safely use t.GetSourceFlowLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceFlowLabel == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Ipv6) GetSourceFlowLabel() uint32 {
	if t == nil || t.SourceFlowLabel == nil {
		return 0
	}
	return *t.SourceFlowLabel
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry_Ipv6_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state/protocol within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8].
type Acl_AclSet_AclEntry_Ipv6_Protocol_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8]
	Documentation_for_Acl_AclSet_AclEntry_Ipv6_Protocol_Union()
}

// Documentation_for_Acl_AclSet_AclEntry_Ipv6_Protocol_Union ensures that E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the Acl_AclSet_AclEntry_Ipv6_Protocol_Union interface.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Documentation_for_Acl_AclSet_AclEntry_Ipv6_Protocol_Union() {
}

// Documentation_for_Acl_AclSet_AclEntry_Ipv6_Protocol_Union ensures that UnionUint8
// implements the Acl_AclSet_AclEntry_Ipv6_Protocol_Union interface.
func (UnionUint8) Documentation_for_Acl_AclSet_AclEntry_Ipv6_Protocol_Union() {}

// To_Acl_AclSet_AclEntry_Ipv6_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Acl_AclSet_AclEntry_Ipv6_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Acl_AclSet_AclEntry_Ipv6) To_Acl_AclSet_AclEntry_Ipv6_Protocol_Union(i interface{}) (Acl_AclSet_AclEntry_Ipv6_Protocol_Union, error) {
	if v, ok := i.(Acl_AclSet_AclEntry_Ipv6_Protocol_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint8:
		return UnionUint8(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Acl_AclSet_AclEntry_Ipv6_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
}

// Acl_AclSet_AclEntry_L2 represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2 YANG schema element.
type Acl_AclSet_AclEntry_L2 struct {
	ΛMetadata           []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	DestinationMac      *string                                `path:"state/destination-mac" shadow-path:"config/destination-mac" module:"openconfig-acl"`
	ΛDestinationMac     []ygot.Annotation                      `path:"state/@destination-mac" ygotAnnotation:"true"`
	DestinationMacMask  *string                                `path:"state/destination-mac-mask" shadow-path:"config/destination-mac-mask" module:"openconfig-acl"`
	ΛDestinationMacMask []ygot.Annotation                      `path:"state/@destination-mac-mask" ygotAnnotation:"true"`
	Ethertype           Acl_AclSet_AclEntry_L2_Ethertype_Union `path:"state/ethertype" shadow-path:"config/ethertype" module:"openconfig-acl"`
	ΛEthertype          []ygot.Annotation                      `path:"state/@ethertype" ygotAnnotation:"true"`
	SourceMac           *string                                `path:"state/source-mac" shadow-path:"config/source-mac" module:"openconfig-acl"`
	ΛSourceMac          []ygot.Annotation                      `path:"state/@source-mac" ygotAnnotation:"true"`
	SourceMacMask       *string                                `path:"state/source-mac-mask" shadow-path:"config/source-mac-mask" module:"openconfig-acl"`
	ΛSourceMacMask      []ygot.Annotation                      `path:"state/@source-mac-mask" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_L2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_L2) IsYANGGoStruct() {}

// GetDestinationMac retrieves the value of the leaf DestinationMac from the Acl_AclSet_AclEntry_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationMac is set, it can safely use t.GetDestinationMac()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationMac == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_L2) GetDestinationMac() string {
	if t == nil || t.DestinationMac == nil {
		return ""
	}
	return *t.DestinationMac
}

// GetDestinationMacMask retrieves the value of the leaf DestinationMacMask from the Acl_AclSet_AclEntry_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationMacMask is set, it can safely use t.GetDestinationMacMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationMacMask == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_L2) GetDestinationMacMask() string {
	if t == nil || t.DestinationMacMask == nil {
		return ""
	}
	return *t.DestinationMacMask
}

// GetEthertype retrieves the value of the leaf Ethertype from the Acl_AclSet_AclEntry_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ethertype is set, it can safely use t.GetEthertype()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ethertype == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_L2) GetEthertype() Acl_AclSet_AclEntry_L2_Ethertype_Union {
	if t == nil || t.Ethertype == nil {
		return nil
	}
	return t.Ethertype
}

// GetSourceMac retrieves the value of the leaf SourceMac from the Acl_AclSet_AclEntry_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceMac is set, it can safely use t.GetSourceMac()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceMac == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_L2) GetSourceMac() string {
	if t == nil || t.SourceMac == nil {
		return ""
	}
	return *t.SourceMac
}

// GetSourceMacMask retrieves the value of the leaf SourceMacMask from the Acl_AclSet_AclEntry_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceMacMask is set, it can safely use t.GetSourceMacMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceMacMask == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_L2) GetSourceMacMask() string {
	if t == nil || t.SourceMacMask == nil {
		return ""
	}
	return *t.SourceMacMask
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_L2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_L2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_L2) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry_L2_Ethertype_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state/ethertype within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_ETHERTYPE, UnionUint16].
type Acl_AclSet_AclEntry_L2_Ethertype_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_ETHERTYPE, UnionUint16]
	Documentation_for_Acl_AclSet_AclEntry_L2_Ethertype_Union()
}

// Documentation_for_Acl_AclSet_AclEntry_L2_Ethertype_Union ensures that E_OpenconfigPacketMatchTypes_ETHERTYPE
// implements the Acl_AclSet_AclEntry_L2_Ethertype_Union interface.
func (E_OpenconfigPacketMatchTypes_ETHERTYPE) Documentation_for_Acl_AclSet_AclEntry_L2_Ethertype_Union() {
}

// Documentation_for_Acl_AclSet_AclEntry_L2_Ethertype_Union ensures that UnionUint16
// implements the Acl_AclSet_AclEntry_L2_Ethertype_Union interface.
func (UnionUint16) Documentation_for_Acl_AclSet_AclEntry_L2_Ethertype_Union() {}

// To_Acl_AclSet_AclEntry_L2_Ethertype_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Acl_AclSet_AclEntry_L2_Ethertype_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Acl_AclSet_AclEntry_L2) To_Acl_AclSet_AclEntry_L2_Ethertype_Union(i interface{}) (Acl_AclSet_AclEntry_L2_Ethertype_Union, error) {
	if v, ok := i.(Acl_AclSet_AclEntry_L2_Ethertype_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Acl_AclSet_AclEntry_L2_Ethertype_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_ETHERTYPE, uint16]", i, i)
}

// Acl_AclSet_AclEntry_Transport represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport YANG schema element.
type Acl_AclSet_AclEntry_Transport struct {
	ΛMetadata        []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	DestinationPort  Acl_AclSet_AclEntry_Transport_DestinationPort_Union `path:"state/destination-port" shadow-path:"config/destination-port" module:"openconfig-acl"`
	ΛDestinationPort []ygot.Annotation                                   `path:"state/@destination-port" ygotAnnotation:"true"`
	SourcePort       Acl_AclSet_AclEntry_Transport_SourcePort_Union      `path:"state/source-port" shadow-path:"config/source-port" module:"openconfig-acl"`
	ΛSourcePort      []ygot.Annotation                                   `path:"state/@source-port" ygotAnnotation:"true"`
	TcpFlags         []E_OpenconfigPacketMatchTypes_TCP_FLAGS            `path:"state/tcp-flags" shadow-path:"config/tcp-flags" module:"openconfig-acl"`
	ΛTcpFlags        []ygot.Annotation                                   `path:"state/@tcp-flags" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_AclSet_AclEntry_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_AclSet_AclEntry_Transport) IsYANGGoStruct() {}

// GetDestinationPort retrieves the value of the leaf DestinationPort from the Acl_AclSet_AclEntry_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationPort is set, it can safely use t.GetDestinationPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationPort == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Transport) GetDestinationPort() Acl_AclSet_AclEntry_Transport_DestinationPort_Union {
	if t == nil || t.DestinationPort == nil {
		return nil
	}
	return t.DestinationPort
}

// GetSourcePort retrieves the value of the leaf SourcePort from the Acl_AclSet_AclEntry_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourcePort is set, it can safely use t.GetSourcePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourcePort == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Transport) GetSourcePort() Acl_AclSet_AclEntry_Transport_SourcePort_Union {
	if t == nil || t.SourcePort == nil {
		return nil
	}
	return t.SourcePort
}

// GetTcpFlags retrieves the value of the leaf TcpFlags from the Acl_AclSet_AclEntry_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TcpFlags is set, it can safely use t.GetTcpFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TcpFlags == nil'
// before retrieving the leaf's value.
func (t *Acl_AclSet_AclEntry_Transport) GetTcpFlags() []E_OpenconfigPacketMatchTypes_TCP_FLAGS {
	if t == nil || t.TcpFlags == nil {
		return nil
	}
	return t.TcpFlags
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_AclSet_AclEntry_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_AclSet_AclEntry_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_AclSet_AclEntry_Transport) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_AclSet_AclEntry_Transport_DestinationPort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16].
type Acl_AclSet_AclEntry_Transport_DestinationPort_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16]
	Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union()
}

// Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union ensures that E_OpenconfigPacketMatchTypes_PortNumRange_Enum
// implements the Acl_AclSet_AclEntry_Transport_DestinationPort_Union interface.
func (E_OpenconfigPacketMatchTypes_PortNumRange_Enum) Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union() {
}

// Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union ensures that UnionString
// implements the Acl_AclSet_AclEntry_Transport_DestinationPort_Union interface.
func (UnionString) Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union() {}

// Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union ensures that UnionUint16
// implements the Acl_AclSet_AclEntry_Transport_DestinationPort_Union interface.
func (UnionUint16) Documentation_for_Acl_AclSet_AclEntry_Transport_DestinationPort_Union() {}

// To_Acl_AclSet_AclEntry_Transport_DestinationPort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Acl_AclSet_AclEntry_Transport_DestinationPort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Acl_AclSet_AclEntry_Transport) To_Acl_AclSet_AclEntry_Transport_DestinationPort_Union(i interface{}) (Acl_AclSet_AclEntry_Transport_DestinationPort_Union, error) {
	if v, ok := i.(Acl_AclSet_AclEntry_Transport_DestinationPort_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Acl_AclSet_AclEntry_Transport_DestinationPort_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, string, uint16]", i, i)
}

// Acl_AclSet_AclEntry_Transport_SourcePort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16].
type Acl_AclSet_AclEntry_Transport_SourcePort_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16]
	Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union()
}

// Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union ensures that E_OpenconfigPacketMatchTypes_PortNumRange_Enum
// implements the Acl_AclSet_AclEntry_Transport_SourcePort_Union interface.
func (E_OpenconfigPacketMatchTypes_PortNumRange_Enum) Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union() {
}

// Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union ensures that UnionString
// implements the Acl_AclSet_AclEntry_Transport_SourcePort_Union interface.
func (UnionString) Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union() {}

// Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union ensures that UnionUint16
// implements the Acl_AclSet_AclEntry_Transport_SourcePort_Union interface.
func (UnionUint16) Documentation_for_Acl_AclSet_AclEntry_Transport_SourcePort_Union() {}

// To_Acl_AclSet_AclEntry_Transport_SourcePort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Acl_AclSet_AclEntry_Transport_SourcePort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Acl_AclSet_AclEntry_Transport) To_Acl_AclSet_AclEntry_Transport_SourcePort_Union(i interface{}) (Acl_AclSet_AclEntry_Transport_SourcePort_Union, error) {
	if v, ok := i.(Acl_AclSet_AclEntry_Transport_SourcePort_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Acl_AclSet_AclEntry_Transport_SourcePort_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, string, uint16]", i, i)
}

// Acl_Interface represents the /openconfig-acl/acl/interfaces/interface YANG schema element.
type Acl_Interface struct {
	ΛMetadata      []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	EgressAclSet   map[Acl_Interface_EgressAclSet_Key]*Acl_Interface_EgressAclSet   `path:"egress-acl-sets/egress-acl-set" module:"openconfig-acl"`
	ΛEgressAclSet  []ygot.Annotation                                                `path:"egress-acl-sets/@egress-acl-set" ygotAnnotation:"true"`
	Id             *string                                                          `path:"state/id|id" shadow-path:"config/id" module:"openconfig-acl"`
	ΛId            []ygot.Annotation                                                `path:"state/@id|@id" ygotAnnotation:"true"`
	IngressAclSet  map[Acl_Interface_IngressAclSet_Key]*Acl_Interface_IngressAclSet `path:"ingress-acl-sets/ingress-acl-set" module:"openconfig-acl"`
	ΛIngressAclSet []ygot.Annotation                                                `path:"ingress-acl-sets/@ingress-acl-set" ygotAnnotation:"true"`
	InterfaceRef   *Acl_Interface_InterfaceRef                                      `path:"interface-ref" module:"openconfig-acl"`
	ΛInterfaceRef  []ygot.Annotation                                                `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_Interface) IsYANGGoStruct() {}

// Acl_Interface_EgressAclSet_Key represents the key for list EgressAclSet of element /openconfig-acl/acl/interfaces/interface.
type Acl_Interface_EgressAclSet_Key struct {
	SetName string                   `path:"set-name"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type"`
}

// Acl_Interface_IngressAclSet_Key represents the key for list IngressAclSet of element /openconfig-acl/acl/interfaces/interface.
type Acl_Interface_IngressAclSet_Key struct {
	SetName string                   `path:"set-name"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type"`
}

// NewEgressAclSet creates a new entry in the EgressAclSet list of the
// Acl_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *Acl_Interface) NewEgressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) (*Acl_Interface_EgressAclSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.EgressAclSet == nil {
		t.EgressAclSet = make(map[Acl_Interface_EgressAclSet_Key]*Acl_Interface_EgressAclSet)
	}

	key := Acl_Interface_EgressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.EgressAclSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list EgressAclSet", key)
	}

	t.EgressAclSet[key] = &Acl_Interface_EgressAclSet{
		SetName: &SetName,
		Type:    Type,
	}

	return t.EgressAclSet[key], nil
}

// RenameEgressAclSet renames an entry in the list EgressAclSet within
// the Acl_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl_Interface) RenameEgressAclSet(oldK, newK Acl_Interface_EgressAclSet_Key) error {
	if _, ok := t.EgressAclSet[newK]; ok {
		return fmt.Errorf("key %v already exists in EgressAclSet", newK)
	}

	e, ok := t.EgressAclSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in EgressAclSet", oldK)
	}
	e.SetName = &newK.SetName
	e.Type = newK.Type

	t.EgressAclSet[newK] = e
	delete(t.EgressAclSet, oldK)
	return nil
}

// GetOrCreateEgressAclSet retrieves the value with the specified keys from
// the receiver Acl_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl_Interface) GetOrCreateEgressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) *Acl_Interface_EgressAclSet {

	key := Acl_Interface_EgressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	if v, ok := t.EgressAclSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewEgressAclSet(SetName, Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateEgressAclSet got unexpected error: %v", err))
	}
	return v
}

// GetEgressAclSet retrieves the value with the specified key from
// the EgressAclSet map field of Acl_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl_Interface) GetEgressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) *Acl_Interface_EgressAclSet {

	if t == nil {
		return nil
	}

	key := Acl_Interface_EgressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	if lm, ok := t.EgressAclSet[key]; ok {
		return lm
	}
	return nil
}

// AppendEgressAclSet appends the supplied Acl_Interface_EgressAclSet struct to the
// list EgressAclSet of Acl_Interface. If the key value(s) specified in
// the supplied Acl_Interface_EgressAclSet already exist in the list, an error is
// returned.
func (t *Acl_Interface) AppendEgressAclSet(v *Acl_Interface_EgressAclSet) error {
	if v.SetName == nil {
		return fmt.Errorf("invalid nil key for SetName")
	}

	key := Acl_Interface_EgressAclSet_Key{
		SetName: *v.SetName,
		Type:    v.Type,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.EgressAclSet == nil {
		t.EgressAclSet = make(map[Acl_Interface_EgressAclSet_Key]*Acl_Interface_EgressAclSet)
	}

	if _, ok := t.EgressAclSet[key]; ok {
		return fmt.Errorf("duplicate key for list EgressAclSet %v", key)
	}

	t.EgressAclSet[key] = v
	return nil
}

// NewIngressAclSet creates a new entry in the IngressAclSet list of the
// Acl_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *Acl_Interface) NewIngressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) (*Acl_Interface_IngressAclSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.IngressAclSet == nil {
		t.IngressAclSet = make(map[Acl_Interface_IngressAclSet_Key]*Acl_Interface_IngressAclSet)
	}

	key := Acl_Interface_IngressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.IngressAclSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list IngressAclSet", key)
	}

	t.IngressAclSet[key] = &Acl_Interface_IngressAclSet{
		SetName: &SetName,
		Type:    Type,
	}

	return t.IngressAclSet[key], nil
}

// RenameIngressAclSet renames an entry in the list IngressAclSet within
// the Acl_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl_Interface) RenameIngressAclSet(oldK, newK Acl_Interface_IngressAclSet_Key) error {
	if _, ok := t.IngressAclSet[newK]; ok {
		return fmt.Errorf("key %v already exists in IngressAclSet", newK)
	}

	e, ok := t.IngressAclSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in IngressAclSet", oldK)
	}
	e.SetName = &newK.SetName
	e.Type = newK.Type

	t.IngressAclSet[newK] = e
	delete(t.IngressAclSet, oldK)
	return nil
}

// GetOrCreateIngressAclSet retrieves the value with the specified keys from
// the receiver Acl_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl_Interface) GetOrCreateIngressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) *Acl_Interface_IngressAclSet {

	key := Acl_Interface_IngressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	if v, ok := t.IngressAclSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewIngressAclSet(SetName, Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateIngressAclSet got unexpected error: %v", err))
	}
	return v
}

// GetIngressAclSet retrieves the value with the specified key from
// the IngressAclSet map field of Acl_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl_Interface) GetIngressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) *Acl_Interface_IngressAclSet {

	if t == nil {
		return nil
	}

	key := Acl_Interface_IngressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	if lm, ok := t.IngressAclSet[key]; ok {
		return lm
	}
	return nil
}

// AppendIngressAclSet appends the supplied Acl_Interface_IngressAclSet struct to the
// list IngressAclSet of Acl_Interface. If the key value(s) specified in
// the supplied Acl_Interface_IngressAclSet already exist in the list, an error is
// returned.
func (t *Acl_Interface) AppendIngressAclSet(v *Acl_Interface_IngressAclSet) error {
	if v.SetName == nil {
		return fmt.Errorf("invalid nil key for SetName")
	}

	key := Acl_Interface_IngressAclSet_Key{
		SetName: *v.SetName,
		Type:    v.Type,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.IngressAclSet == nil {
		t.IngressAclSet = make(map[Acl_Interface_IngressAclSet_Key]*Acl_Interface_IngressAclSet)
	}

	if _, ok := t.IngressAclSet[key]; ok {
		return fmt.Errorf("duplicate key for list IngressAclSet %v", key)
	}

	t.IngressAclSet[key] = v
	return nil
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *Acl_Interface) GetOrCreateInterfaceRef() *Acl_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &Acl_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from Acl_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Acl_Interface) GetInterfaceRef() *Acl_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetId retrieves the value of the leaf Id from the Acl_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// ΛListKeyMap returns the keys of the Acl_Interface struct, which is a YANG list entry.
func (t *Acl_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_Interface_EgressAclSet represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set YANG schema element.
type Acl_Interface_EgressAclSet struct {
	ΛMetadata []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	AclEntry  map[uint32]*Acl_Interface_EgressAclSet_AclEntry `path:"acl-entries/acl-entry" module:"openconfig-acl"`
	ΛAclEntry []ygot.Annotation                               `path:"acl-entries/@acl-entry" ygotAnnotation:"true"`
	SetName   *string                                         `path:"state/set-name|set-name" shadow-path:"config/set-name" module:"openconfig-acl"`
	ΛSetName  []ygot.Annotation                               `path:"state/@set-name|@set-name" ygotAnnotation:"true"`
	Type      E_OpenconfigAcl_ACL_TYPE                        `path:"state/type|type" shadow-path:"config/type" module:"openconfig-acl"`
	ΛType     []ygot.Annotation                               `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_Interface_EgressAclSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_Interface_EgressAclSet) IsYANGGoStruct() {}

// NewAclEntry creates a new entry in the AclEntry list of the
// Acl_Interface_EgressAclSet struct. The keys of the list are populated from the input
// arguments.
func (t *Acl_Interface_EgressAclSet) NewAclEntry(SequenceId uint32) (*Acl_Interface_EgressAclSet_AclEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*Acl_Interface_EgressAclSet_AclEntry)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclEntry", key)
	}

	t.AclEntry[key] = &Acl_Interface_EgressAclSet_AclEntry{
		SequenceId: &SequenceId,
	}

	return t.AclEntry[key], nil
}

// RenameAclEntry renames an entry in the list AclEntry within
// the Acl_Interface_EgressAclSet struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl_Interface_EgressAclSet) RenameAclEntry(oldK, newK uint32) error {
	if _, ok := t.AclEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in AclEntry", newK)
	}

	e, ok := t.AclEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AclEntry", oldK)
	}
	e.SequenceId = &newK

	t.AclEntry[newK] = e
	delete(t.AclEntry, oldK)
	return nil
}

// GetOrCreateAclEntry retrieves the value with the specified keys from
// the receiver Acl_Interface_EgressAclSet. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl_Interface_EgressAclSet) GetOrCreateAclEntry(SequenceId uint32) *Acl_Interface_EgressAclSet_AclEntry {

	key := SequenceId

	if v, ok := t.AclEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAclEntry(SequenceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAclEntry got unexpected error: %v", err))
	}
	return v
}

// GetAclEntry retrieves the value with the specified key from
// the AclEntry map field of Acl_Interface_EgressAclSet. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl_Interface_EgressAclSet) GetAclEntry(SequenceId uint32) *Acl_Interface_EgressAclSet_AclEntry {

	if t == nil {
		return nil
	}

	key := SequenceId

	if lm, ok := t.AclEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendAclEntry appends the supplied Acl_Interface_EgressAclSet_AclEntry struct to the
// list AclEntry of Acl_Interface_EgressAclSet. If the key value(s) specified in
// the supplied Acl_Interface_EgressAclSet_AclEntry already exist in the list, an error is
// returned.
func (t *Acl_Interface_EgressAclSet) AppendAclEntry(v *Acl_Interface_EgressAclSet_AclEntry) error {
	if v.SequenceId == nil {
		return fmt.Errorf("invalid nil key received for SequenceId")
	}

	key := *v.SequenceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*Acl_Interface_EgressAclSet_AclEntry)
	}

	if _, ok := t.AclEntry[key]; ok {
		return fmt.Errorf("duplicate key for list AclEntry %v", key)
	}

	t.AclEntry[key] = v
	return nil
}

// GetSetName retrieves the value of the leaf SetName from the Acl_Interface_EgressAclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetName is set, it can safely use t.GetSetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetName == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_EgressAclSet) GetSetName() string {
	if t == nil || t.SetName == nil {
		return ""
	}
	return *t.SetName
}

// GetType retrieves the value of the leaf Type from the Acl_Interface_EgressAclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_EgressAclSet) GetType() E_OpenconfigAcl_ACL_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Acl_Interface_EgressAclSet struct, which is a YANG list entry.
func (t *Acl_Interface_EgressAclSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SetName == nil {
		return nil, fmt.Errorf("nil value for key SetName")
	}

	return map[string]interface{}{
		"set-name": *t.SetName,
		"type":     t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_Interface_EgressAclSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_Interface_EgressAclSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_Interface_EgressAclSet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_Interface_EgressAclSet_AclEntry represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set/acl-entries/acl-entry YANG schema element.
type Acl_Interface_EgressAclSet_AclEntry struct {
	ΛMetadata       []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MatchedOctets   *uint64           `path:"state/matched-octets" module:"openconfig-acl"`
	ΛMatchedOctets  []ygot.Annotation `path:"state/@matched-octets" ygotAnnotation:"true"`
	MatchedPackets  *uint64           `path:"state/matched-packets" module:"openconfig-acl"`
	ΛMatchedPackets []ygot.Annotation `path:"state/@matched-packets" ygotAnnotation:"true"`
	SequenceId      *uint32           `path:"state/sequence-id|sequence-id" module:"openconfig-acl"`
	ΛSequenceId     []ygot.Annotation `path:"state/@sequence-id|@sequence-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_Interface_EgressAclSet_AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_Interface_EgressAclSet_AclEntry) IsYANGGoStruct() {}

// GetMatchedOctets retrieves the value of the leaf MatchedOctets from the Acl_Interface_EgressAclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedOctets is set, it can safely use t.GetMatchedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedOctets == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_EgressAclSet_AclEntry) GetMatchedOctets() uint64 {
	if t == nil || t.MatchedOctets == nil {
		return 0
	}
	return *t.MatchedOctets
}

// GetMatchedPackets retrieves the value of the leaf MatchedPackets from the Acl_Interface_EgressAclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedPackets is set, it can safely use t.GetMatchedPackets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedPackets == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_EgressAclSet_AclEntry) GetMatchedPackets() uint64 {
	if t == nil || t.MatchedPackets == nil {
		return 0
	}
	return *t.MatchedPackets
}

// GetSequenceId retrieves the value of the leaf SequenceId from the Acl_Interface_EgressAclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SequenceId is set, it can safely use t.GetSequenceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SequenceId == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_EgressAclSet_AclEntry) GetSequenceId() uint32 {
	if t == nil || t.SequenceId == nil {
		return 0
	}
	return *t.SequenceId
}

// ΛListKeyMap returns the keys of the Acl_Interface_EgressAclSet_AclEntry struct, which is a YANG list entry.
func (t *Acl_Interface_EgressAclSet_AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_Interface_EgressAclSet_AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_Interface_EgressAclSet_AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_Interface_EgressAclSet_AclEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Acl_Interface_IngressAclSet represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set YANG schema element.
type Acl_Interface_IngressAclSet struct {
	ΛMetadata []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	AclEntry  map[uint32]*Acl_Interface_IngressAclSet_AclEntry `path:"acl-entries/acl-entry" module:"openconfig-acl"`
	ΛAclEntry []ygot.Annotation                                `path:"acl-entries/@acl-entry" ygotAnnotation:"true"`
	SetName   *string                                          `path:"state/set-name|set-name" shadow-path:"config/set-name" module:"openconfig-acl"`
	ΛSetName  []ygot.Annotation                                `path:"state/@set-name|@set-name" ygotAnnotation:"true"`
	Type      E_OpenconfigAcl_ACL_TYPE                         `path:"state/type|type" shadow-path:"config/type" module:"openconfig-acl"`
	ΛType     []ygot.Annotation                                `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_Interface_IngressAclSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_Interface_IngressAclSet) IsYANGGoStruct() {}

// NewAclEntry creates a new entry in the AclEntry list of the
// Acl_Interface_IngressAclSet struct. The keys of the list are populated from the input
// arguments.
func (t *Acl_Interface_IngressAclSet) NewAclEntry(SequenceId uint32) (*Acl_Interface_IngressAclSet_AclEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*Acl_Interface_IngressAclSet_AclEntry)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclEntry", key)
	}

	t.AclEntry[key] = &Acl_Interface_IngressAclSet_AclEntry{
		SequenceId: &SequenceId,
	}

	return t.AclEntry[key], nil
}

// RenameAclEntry renames an entry in the list AclEntry within
// the Acl_Interface_IngressAclSet struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Acl_Interface_IngressAclSet) RenameAclEntry(oldK, newK uint32) error {
	if _, ok := t.AclEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in AclEntry", newK)
	}

	e, ok := t.AclEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AclEntry", oldK)
	}
	e.SequenceId = &newK

	t.AclEntry[newK] = e
	delete(t.AclEntry, oldK)
	return nil
}

// GetOrCreateAclEntry retrieves the value with the specified keys from
// the receiver Acl_Interface_IngressAclSet. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Acl_Interface_IngressAclSet) GetOrCreateAclEntry(SequenceId uint32) *Acl_Interface_IngressAclSet_AclEntry {

	key := SequenceId

	if v, ok := t.AclEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAclEntry(SequenceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAclEntry got unexpected error: %v", err))
	}
	return v
}

// GetAclEntry retrieves the value with the specified key from
// the AclEntry map field of Acl_Interface_IngressAclSet. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Acl_Interface_IngressAclSet) GetAclEntry(SequenceId uint32) *Acl_Interface_IngressAclSet_AclEntry {

	if t == nil {
		return nil
	}

	key := SequenceId

	if lm, ok := t.AclEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendAclEntry appends the supplied Acl_Interface_IngressAclSet_AclEntry struct to the
// list AclEntry of Acl_Interface_IngressAclSet. If the key value(s) specified in
// the supplied Acl_Interface_IngressAclSet_AclEntry already exist in the list, an error is
// returned.
func (t *Acl_Interface_IngressAclSet) AppendAclEntry(v *Acl_Interface_IngressAclSet_AclEntry) error {
	if v.SequenceId == nil {
		return fmt.Errorf("invalid nil key received for SequenceId")
	}

	key := *v.SequenceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*Acl_Interface_IngressAclSet_AclEntry)
	}

	if _, ok := t.AclEntry[key]; ok {
		return fmt.Errorf("duplicate key for list AclEntry %v", key)
	}

	t.AclEntry[key] = v
	return nil
}

// GetSetName retrieves the value of the leaf SetName from the Acl_Interface_IngressAclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetName is set, it can safely use t.GetSetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetName == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_IngressAclSet) GetSetName() string {
	if t == nil || t.SetName == nil {
		return ""
	}
	return *t.SetName
}

// GetType retrieves the value of the leaf Type from the Acl_Interface_IngressAclSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_IngressAclSet) GetType() E_OpenconfigAcl_ACL_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Acl_Interface_IngressAclSet struct, which is a YANG list entry.
func (t *Acl_Interface_IngressAclSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SetName == nil {
		return nil, fmt.Errorf("nil value for key SetName")
	}

	return map[string]interface{}{
		"set-name": *t.SetName,
		"type":     t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_Interface_IngressAclSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_Interface_IngressAclSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_Interface_IngressAclSet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Acl_Interface_IngressAclSet_AclEntry represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/acl-entries/acl-entry YANG schema element.
type Acl_Interface_IngressAclSet_AclEntry struct {
	ΛMetadata       []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MatchedOctets   *uint64           `path:"state/matched-octets" module:"openconfig-acl"`
	ΛMatchedOctets  []ygot.Annotation `path:"state/@matched-octets" ygotAnnotation:"true"`
	MatchedPackets  *uint64           `path:"state/matched-packets" module:"openconfig-acl"`
	ΛMatchedPackets []ygot.Annotation `path:"state/@matched-packets" ygotAnnotation:"true"`
	SequenceId      *uint32           `path:"state/sequence-id|sequence-id" module:"openconfig-acl"`
	ΛSequenceId     []ygot.Annotation `path:"state/@sequence-id|@sequence-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_Interface_IngressAclSet_AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_Interface_IngressAclSet_AclEntry) IsYANGGoStruct() {}

// GetMatchedOctets retrieves the value of the leaf MatchedOctets from the Acl_Interface_IngressAclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedOctets is set, it can safely use t.GetMatchedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedOctets == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_IngressAclSet_AclEntry) GetMatchedOctets() uint64 {
	if t == nil || t.MatchedOctets == nil {
		return 0
	}
	return *t.MatchedOctets
}

// GetMatchedPackets retrieves the value of the leaf MatchedPackets from the Acl_Interface_IngressAclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedPackets is set, it can safely use t.GetMatchedPackets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedPackets == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_IngressAclSet_AclEntry) GetMatchedPackets() uint64 {
	if t == nil || t.MatchedPackets == nil {
		return 0
	}
	return *t.MatchedPackets
}

// GetSequenceId retrieves the value of the leaf SequenceId from the Acl_Interface_IngressAclSet_AclEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SequenceId is set, it can safely use t.GetSequenceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SequenceId == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_IngressAclSet_AclEntry) GetSequenceId() uint32 {
	if t == nil || t.SequenceId == nil {
		return 0
	}
	return *t.SequenceId
}

// ΛListKeyMap returns the keys of the Acl_Interface_IngressAclSet_AclEntry struct, which is a YANG list entry.
func (t *Acl_Interface_IngressAclSet_AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_Interface_IngressAclSet_AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_Interface_IngressAclSet_AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_Interface_IngressAclSet_AclEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Acl_Interface_InterfaceRef represents the /openconfig-acl/acl/interfaces/interface/interface-ref YANG schema element.
type Acl_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-acl"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-acl"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Acl_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Acl_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the Acl_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the Acl_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *Acl_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Acl_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Acl_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Acl_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Aps represents the /openconfig-transport-line-protection/aps YANG schema element.
type Aps struct {
	ΛMetadata  []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	ApsModule  map[string]*Aps_ApsModule `path:"aps-modules/aps-module" module:"openconfig-transport-line-protection"`
	ΛApsModule []ygot.Annotation         `path:"aps-modules/@aps-module" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps) IsYANGGoStruct() {}

// NewApsModule creates a new entry in the ApsModule list of the
// Aps struct. The keys of the list are populated from the input
// arguments.
func (t *Aps) NewApsModule(Name string) (*Aps_ApsModule, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ApsModule == nil {
		t.ApsModule = make(map[string]*Aps_ApsModule)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ApsModule[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ApsModule", key)
	}

	t.ApsModule[key] = &Aps_ApsModule{
		Name: &Name,
	}

	return t.ApsModule[key], nil
}

// RenameApsModule renames an entry in the list ApsModule within
// the Aps struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Aps) RenameApsModule(oldK, newK string) error {
	if _, ok := t.ApsModule[newK]; ok {
		return fmt.Errorf("key %v already exists in ApsModule", newK)
	}

	e, ok := t.ApsModule[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ApsModule", oldK)
	}
	e.Name = &newK

	t.ApsModule[newK] = e
	delete(t.ApsModule, oldK)
	return nil
}

// GetOrCreateApsModule retrieves the value with the specified keys from
// the receiver Aps. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Aps) GetOrCreateApsModule(Name string) *Aps_ApsModule {

	key := Name

	if v, ok := t.ApsModule[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewApsModule(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateApsModule got unexpected error: %v", err))
	}
	return v
}

// GetApsModule retrieves the value with the specified key from
// the ApsModule map field of Aps. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Aps) GetApsModule(Name string) *Aps_ApsModule {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.ApsModule[key]; ok {
		return lm
	}
	return nil
}

// AppendApsModule appends the supplied Aps_ApsModule struct to the
// list ApsModule of Aps. If the key value(s) specified in
// the supplied Aps_ApsModule already exist in the list, an error is
// returned.
func (t *Aps) AppendApsModule(v *Aps_ApsModule) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ApsModule == nil {
		t.ApsModule = make(map[string]*Aps_ApsModule)
	}

	if _, ok := t.ApsModule[key]; ok {
		return fmt.Errorf("duplicate key for list ApsModule %v", key)
	}

	t.ApsModule[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Aps_ApsModule represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module YANG schema element.
type Aps_ApsModule struct {
	ΛMetadata                      []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	ActivePath                     E_OpenconfigTransportLineProtection_APS_PATHS `path:"state/active-path" module:"openconfig-transport-line-protection"`
	ΛActivePath                    []ygot.Annotation                             `path:"state/@active-path" ygotAnnotation:"true"`
	ForceToPort                    E_ApsModule_ForceToPort                       `path:"state/force-to-port" shadow-path:"config/force-to-port" module:"openconfig-transport-line-protection"`
	ΛForceToPort                   []ygot.Annotation                             `path:"state/@force-to-port" ygotAnnotation:"true"`
	HoldOffTime                    *uint32                                       `path:"state/hold-off-time" shadow-path:"config/hold-off-time" module:"openconfig-transport-line-protection"`
	ΛHoldOffTime                   []ygot.Annotation                             `path:"state/@hold-off-time" ygotAnnotation:"true"`
	Name                           *string                                       `path:"state/name|name" shadow-path:"config/name" module:"openconfig-transport-line-protection"`
	ΛName                          []ygot.Annotation                             `path:"state/@name|@name" ygotAnnotation:"true"`
	Ports                          *Aps_ApsModule_Ports                          `path:"ports" module:"openconfig-transport-line-protection"`
	ΛPorts                         []ygot.Annotation                             `path:"@ports" ygotAnnotation:"true"`
	PrimarySwitchHysteresis        *float64                                      `path:"state/primary-switch-hysteresis" shadow-path:"config/primary-switch-hysteresis" module:"openconfig-transport-line-protection"`
	ΛPrimarySwitchHysteresis       []ygot.Annotation                             `path:"state/@primary-switch-hysteresis" ygotAnnotation:"true"`
	PrimarySwitchThreshold         *float64                                      `path:"state/primary-switch-threshold" shadow-path:"config/primary-switch-threshold" module:"openconfig-transport-line-protection"`
	ΛPrimarySwitchThreshold        []ygot.Annotation                             `path:"state/@primary-switch-threshold" ygotAnnotation:"true"`
	RelativeSwitchThreshold        *float64                                      `path:"state/relative-switch-threshold" shadow-path:"config/relative-switch-threshold" module:"openconfig-transport-line-protection"`
	ΛRelativeSwitchThreshold       []ygot.Annotation                             `path:"state/@relative-switch-threshold" ygotAnnotation:"true"`
	RelativeSwitchThresholdOffset  *float64                                      `path:"state/relative-switch-threshold-offset" shadow-path:"config/relative-switch-threshold-offset" module:"openconfig-transport-line-protection"`
	ΛRelativeSwitchThresholdOffset []ygot.Annotation                             `path:"state/@relative-switch-threshold-offset" ygotAnnotation:"true"`
	Revertive                      *bool                                         `path:"state/revertive" shadow-path:"config/revertive" module:"openconfig-transport-line-protection"`
	ΛRevertive                     []ygot.Annotation                             `path:"state/@revertive" ygotAnnotation:"true"`
	SecondarySwitchThreshold       *float64                                      `path:"state/secondary-switch-threshold" shadow-path:"config/secondary-switch-threshold" module:"openconfig-transport-line-protection"`
	ΛSecondarySwitchThreshold      []ygot.Annotation                             `path:"state/@secondary-switch-threshold" ygotAnnotation:"true"`
	WaitToRestoreTime              *uint32                                       `path:"state/wait-to-restore-time" shadow-path:"config/wait-to-restore-time" module:"openconfig-transport-line-protection"`
	ΛWaitToRestoreTime             []ygot.Annotation                             `path:"state/@wait-to-restore-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule) IsYANGGoStruct() {}

// GetOrCreatePorts retrieves the value of the Ports field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule) GetOrCreatePorts() *Aps_ApsModule_Ports {
	if t.Ports != nil {
		return t.Ports
	}
	t.Ports = &Aps_ApsModule_Ports{}
	return t.Ports
}

// GetPorts returns the value of the Ports struct pointer
// from Aps_ApsModule. If the receiver or the field Ports is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule) GetPorts() *Aps_ApsModule_Ports {
	if t != nil && t.Ports != nil {
		return t.Ports
	}
	return nil
}

// GetActivePath retrieves the value of the leaf ActivePath from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ActivePath is set, it can safely use t.GetActivePath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ActivePath == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetActivePath() E_OpenconfigTransportLineProtection_APS_PATHS {
	if t == nil || t.ActivePath == 0 {
		return 0
	}
	return t.ActivePath
}

// GetForceToPort retrieves the value of the leaf ForceToPort from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForceToPort is set, it can safely use t.GetForceToPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForceToPort == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetForceToPort() E_ApsModule_ForceToPort {
	if t == nil || t.ForceToPort == 0 {
		return ApsModule_ForceToPort_NONE
	}
	return t.ForceToPort
}

// GetHoldOffTime retrieves the value of the leaf HoldOffTime from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldOffTime is set, it can safely use t.GetHoldOffTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldOffTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetHoldOffTime() uint32 {
	if t == nil || t.HoldOffTime == nil {
		return 0
	}
	return *t.HoldOffTime
}

// GetName retrieves the value of the leaf Name from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPrimarySwitchHysteresis retrieves the value of the leaf PrimarySwitchHysteresis from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrimarySwitchHysteresis is set, it can safely use t.GetPrimarySwitchHysteresis()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrimarySwitchHysteresis == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetPrimarySwitchHysteresis() float64 {
	if t == nil || t.PrimarySwitchHysteresis == nil {
		return 0
	}
	return *t.PrimarySwitchHysteresis
}

// GetPrimarySwitchThreshold retrieves the value of the leaf PrimarySwitchThreshold from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrimarySwitchThreshold is set, it can safely use t.GetPrimarySwitchThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrimarySwitchThreshold == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetPrimarySwitchThreshold() float64 {
	if t == nil || t.PrimarySwitchThreshold == nil {
		return 0.0
	}
	return *t.PrimarySwitchThreshold
}

// GetRelativeSwitchThreshold retrieves the value of the leaf RelativeSwitchThreshold from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RelativeSwitchThreshold is set, it can safely use t.GetRelativeSwitchThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RelativeSwitchThreshold == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetRelativeSwitchThreshold() float64 {
	if t == nil || t.RelativeSwitchThreshold == nil {
		return 0
	}
	return *t.RelativeSwitchThreshold
}

// GetRelativeSwitchThresholdOffset retrieves the value of the leaf RelativeSwitchThresholdOffset from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RelativeSwitchThresholdOffset is set, it can safely use t.GetRelativeSwitchThresholdOffset()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RelativeSwitchThresholdOffset == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetRelativeSwitchThresholdOffset() float64 {
	if t == nil || t.RelativeSwitchThresholdOffset == nil {
		return 0
	}
	return *t.RelativeSwitchThresholdOffset
}

// GetRevertive retrieves the value of the leaf Revertive from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Revertive is set, it can safely use t.GetRevertive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Revertive == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetRevertive() bool {
	if t == nil || t.Revertive == nil {
		return false
	}
	return *t.Revertive
}

// GetSecondarySwitchThreshold retrieves the value of the leaf SecondarySwitchThreshold from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SecondarySwitchThreshold is set, it can safely use t.GetSecondarySwitchThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SecondarySwitchThreshold == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetSecondarySwitchThreshold() float64 {
	if t == nil || t.SecondarySwitchThreshold == nil {
		return 0.0
	}
	return *t.SecondarySwitchThreshold
}

// GetWaitToRestoreTime retrieves the value of the leaf WaitToRestoreTime from the Aps_ApsModule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WaitToRestoreTime is set, it can safely use t.GetWaitToRestoreTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WaitToRestoreTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule) GetWaitToRestoreTime() uint32 {
	if t == nil || t.WaitToRestoreTime == nil {
		return 0
	}
	return *t.WaitToRestoreTime
}

// ΛListKeyMap returns the keys of the Aps_ApsModule struct, which is a YANG list entry.
func (t *Aps_ApsModule) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Aps_ApsModule_Ports represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports YANG schema element.
type Aps_ApsModule_Ports struct {
	ΛMetadata         []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	CommonIn          *Aps_ApsModule_Ports_CommonIn         `path:"common-in" module:"openconfig-transport-line-protection"`
	ΛCommonIn         []ygot.Annotation                     `path:"@common-in" ygotAnnotation:"true"`
	CommonOutput      *Aps_ApsModule_Ports_CommonOutput     `path:"common-output" module:"openconfig-transport-line-protection"`
	ΛCommonOutput     []ygot.Annotation                     `path:"@common-output" ygotAnnotation:"true"`
	LinePrimaryIn     *Aps_ApsModule_Ports_LinePrimaryIn    `path:"line-primary-in" module:"openconfig-transport-line-protection"`
	ΛLinePrimaryIn    []ygot.Annotation                     `path:"@line-primary-in" ygotAnnotation:"true"`
	LinePrimaryOut    *Aps_ApsModule_Ports_LinePrimaryOut   `path:"line-primary-out" module:"openconfig-transport-line-protection"`
	ΛLinePrimaryOut   []ygot.Annotation                     `path:"@line-primary-out" ygotAnnotation:"true"`
	LineSecondaryIn   *Aps_ApsModule_Ports_LineSecondaryIn  `path:"line-secondary-in" module:"openconfig-transport-line-protection"`
	ΛLineSecondaryIn  []ygot.Annotation                     `path:"@line-secondary-in" ygotAnnotation:"true"`
	LineSecondaryOut  *Aps_ApsModule_Ports_LineSecondaryOut `path:"line-secondary-out" module:"openconfig-transport-line-protection"`
	ΛLineSecondaryOut []ygot.Annotation                     `path:"@line-secondary-out" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports) IsYANGGoStruct() {}

// GetOrCreateCommonIn retrieves the value of the CommonIn field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports) GetOrCreateCommonIn() *Aps_ApsModule_Ports_CommonIn {
	if t.CommonIn != nil {
		return t.CommonIn
	}
	t.CommonIn = &Aps_ApsModule_Ports_CommonIn{}
	return t.CommonIn
}

// GetOrCreateCommonOutput retrieves the value of the CommonOutput field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports) GetOrCreateCommonOutput() *Aps_ApsModule_Ports_CommonOutput {
	if t.CommonOutput != nil {
		return t.CommonOutput
	}
	t.CommonOutput = &Aps_ApsModule_Ports_CommonOutput{}
	return t.CommonOutput
}

// GetOrCreateLinePrimaryIn retrieves the value of the LinePrimaryIn field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports) GetOrCreateLinePrimaryIn() *Aps_ApsModule_Ports_LinePrimaryIn {
	if t.LinePrimaryIn != nil {
		return t.LinePrimaryIn
	}
	t.LinePrimaryIn = &Aps_ApsModule_Ports_LinePrimaryIn{}
	return t.LinePrimaryIn
}

// GetOrCreateLinePrimaryOut retrieves the value of the LinePrimaryOut field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports) GetOrCreateLinePrimaryOut() *Aps_ApsModule_Ports_LinePrimaryOut {
	if t.LinePrimaryOut != nil {
		return t.LinePrimaryOut
	}
	t.LinePrimaryOut = &Aps_ApsModule_Ports_LinePrimaryOut{}
	return t.LinePrimaryOut
}

// GetOrCreateLineSecondaryIn retrieves the value of the LineSecondaryIn field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports) GetOrCreateLineSecondaryIn() *Aps_ApsModule_Ports_LineSecondaryIn {
	if t.LineSecondaryIn != nil {
		return t.LineSecondaryIn
	}
	t.LineSecondaryIn = &Aps_ApsModule_Ports_LineSecondaryIn{}
	return t.LineSecondaryIn
}

// GetOrCreateLineSecondaryOut retrieves the value of the LineSecondaryOut field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports) GetOrCreateLineSecondaryOut() *Aps_ApsModule_Ports_LineSecondaryOut {
	if t.LineSecondaryOut != nil {
		return t.LineSecondaryOut
	}
	t.LineSecondaryOut = &Aps_ApsModule_Ports_LineSecondaryOut{}
	return t.LineSecondaryOut
}

// GetCommonIn returns the value of the CommonIn struct pointer
// from Aps_ApsModule_Ports. If the receiver or the field CommonIn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports) GetCommonIn() *Aps_ApsModule_Ports_CommonIn {
	if t != nil && t.CommonIn != nil {
		return t.CommonIn
	}
	return nil
}

// GetCommonOutput returns the value of the CommonOutput struct pointer
// from Aps_ApsModule_Ports. If the receiver or the field CommonOutput is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports) GetCommonOutput() *Aps_ApsModule_Ports_CommonOutput {
	if t != nil && t.CommonOutput != nil {
		return t.CommonOutput
	}
	return nil
}

// GetLinePrimaryIn returns the value of the LinePrimaryIn struct pointer
// from Aps_ApsModule_Ports. If the receiver or the field LinePrimaryIn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports) GetLinePrimaryIn() *Aps_ApsModule_Ports_LinePrimaryIn {
	if t != nil && t.LinePrimaryIn != nil {
		return t.LinePrimaryIn
	}
	return nil
}

// GetLinePrimaryOut returns the value of the LinePrimaryOut struct pointer
// from Aps_ApsModule_Ports. If the receiver or the field LinePrimaryOut is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports) GetLinePrimaryOut() *Aps_ApsModule_Ports_LinePrimaryOut {
	if t != nil && t.LinePrimaryOut != nil {
		return t.LinePrimaryOut
	}
	return nil
}

// GetLineSecondaryIn returns the value of the LineSecondaryIn struct pointer
// from Aps_ApsModule_Ports. If the receiver or the field LineSecondaryIn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports) GetLineSecondaryIn() *Aps_ApsModule_Ports_LineSecondaryIn {
	if t != nil && t.LineSecondaryIn != nil {
		return t.LineSecondaryIn
	}
	return nil
}

// GetLineSecondaryOut returns the value of the LineSecondaryOut struct pointer
// from Aps_ApsModule_Ports. If the receiver or the field LineSecondaryOut is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports) GetLineSecondaryOut() *Aps_ApsModule_Ports_LineSecondaryOut {
	if t != nil && t.LineSecondaryOut != nil {
		return t.LineSecondaryOut
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Aps_ApsModule_Ports_CommonIn represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/common-in YANG schema element.
type Aps_ApsModule_Ports_CommonIn struct {
	ΛMetadata          []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Attenuation        *float64                                   `path:"state/attenuation" module:"openconfig-transport-line-protection"`
	ΛAttenuation       []ygot.Annotation                          `path:"state/@attenuation" ygotAnnotation:"true"`
	Enabled            *bool                                      `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-transport-line-protection"`
	ΛEnabled           []ygot.Annotation                          `path:"state/@enabled" ygotAnnotation:"true"`
	OpticalPower       *Aps_ApsModule_Ports_CommonIn_OpticalPower `path:"state/optical-power" module:"openconfig-transport-line-protection"`
	ΛOpticalPower      []ygot.Annotation                          `path:"state/@optical-power" ygotAnnotation:"true"`
	TargetAttenuation  *float64                                   `path:"state/target-attenuation" shadow-path:"config/target-attenuation" module:"openconfig-transport-line-protection"`
	ΛTargetAttenuation []ygot.Annotation                          `path:"state/@target-attenuation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_CommonIn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_CommonIn) IsYANGGoStruct() {}

// GetOrCreateOpticalPower retrieves the value of the OpticalPower field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports_CommonIn) GetOrCreateOpticalPower() *Aps_ApsModule_Ports_CommonIn_OpticalPower {
	if t.OpticalPower != nil {
		return t.OpticalPower
	}
	t.OpticalPower = &Aps_ApsModule_Ports_CommonIn_OpticalPower{}
	return t.OpticalPower
}

// GetOpticalPower returns the value of the OpticalPower struct pointer
// from Aps_ApsModule_Ports_CommonIn. If the receiver or the field OpticalPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports_CommonIn) GetOpticalPower() *Aps_ApsModule_Ports_CommonIn_OpticalPower {
	if t != nil && t.OpticalPower != nil {
		return t.OpticalPower
	}
	return nil
}

// GetAttenuation retrieves the value of the leaf Attenuation from the Aps_ApsModule_Ports_CommonIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attenuation is set, it can safely use t.GetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn) GetAttenuation() float64 {
	if t == nil || t.Attenuation == nil {
		return 0.0
	}
	return *t.Attenuation
}

// GetEnabled retrieves the value of the leaf Enabled from the Aps_ApsModule_Ports_CommonIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetTargetAttenuation retrieves the value of the leaf TargetAttenuation from the Aps_ApsModule_Ports_CommonIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetAttenuation is set, it can safely use t.GetTargetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetAttenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn) GetTargetAttenuation() float64 {
	if t == nil || t.TargetAttenuation == nil {
		return 0.0
	}
	return *t.TargetAttenuation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_CommonIn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_CommonIn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_CommonIn) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Aps_ApsModule_Ports_CommonIn_OpticalPower represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/common-in/state/optical-power YANG schema element.
type Aps_ApsModule_Ports_CommonIn_OpticalPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-protection"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-protection"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-protection"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-protection"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-protection"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-protection"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-protection"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_CommonIn_OpticalPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_CommonIn_OpticalPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Aps_ApsModule_Ports_CommonIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_CommonIn_OpticalPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_CommonIn_OpticalPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_CommonOutput represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/common-output YANG schema element.
type Aps_ApsModule_Ports_CommonOutput struct {
	ΛMetadata          []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	Attenuation        *float64                                       `path:"state/attenuation" module:"openconfig-transport-line-protection"`
	ΛAttenuation       []ygot.Annotation                              `path:"state/@attenuation" ygotAnnotation:"true"`
	OpticalPower       *Aps_ApsModule_Ports_CommonOutput_OpticalPower `path:"state/optical-power" module:"openconfig-transport-line-protection"`
	ΛOpticalPower      []ygot.Annotation                              `path:"state/@optical-power" ygotAnnotation:"true"`
	TargetAttenuation  *float64                                       `path:"state/target-attenuation" shadow-path:"config/target-attenuation" module:"openconfig-transport-line-protection"`
	ΛTargetAttenuation []ygot.Annotation                              `path:"state/@target-attenuation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_CommonOutput implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_CommonOutput) IsYANGGoStruct() {}

// GetOrCreateOpticalPower retrieves the value of the OpticalPower field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports_CommonOutput) GetOrCreateOpticalPower() *Aps_ApsModule_Ports_CommonOutput_OpticalPower {
	if t.OpticalPower != nil {
		return t.OpticalPower
	}
	t.OpticalPower = &Aps_ApsModule_Ports_CommonOutput_OpticalPower{}
	return t.OpticalPower
}

// GetOpticalPower returns the value of the OpticalPower struct pointer
// from Aps_ApsModule_Ports_CommonOutput. If the receiver or the field OpticalPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports_CommonOutput) GetOpticalPower() *Aps_ApsModule_Ports_CommonOutput_OpticalPower {
	if t != nil && t.OpticalPower != nil {
		return t.OpticalPower
	}
	return nil
}

// GetAttenuation retrieves the value of the leaf Attenuation from the Aps_ApsModule_Ports_CommonOutput
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attenuation is set, it can safely use t.GetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput) GetAttenuation() float64 {
	if t == nil || t.Attenuation == nil {
		return 0.0
	}
	return *t.Attenuation
}

// GetTargetAttenuation retrieves the value of the leaf TargetAttenuation from the Aps_ApsModule_Ports_CommonOutput
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetAttenuation is set, it can safely use t.GetTargetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetAttenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput) GetTargetAttenuation() float64 {
	if t == nil || t.TargetAttenuation == nil {
		return 0.0
	}
	return *t.TargetAttenuation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_CommonOutput) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_CommonOutput"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_CommonOutput) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_CommonOutput_OpticalPower represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/common-output/state/optical-power YANG schema element.
type Aps_ApsModule_Ports_CommonOutput_OpticalPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-protection"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-protection"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-protection"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-protection"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-protection"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-protection"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-protection"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_CommonOutput_OpticalPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_CommonOutput_OpticalPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Aps_ApsModule_Ports_CommonOutput_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_CommonOutput_OpticalPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_CommonOutput_OpticalPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LinePrimaryIn represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-primary-in YANG schema element.
type Aps_ApsModule_Ports_LinePrimaryIn struct {
	ΛMetadata          []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	Attenuation        *float64                                        `path:"state/attenuation" module:"openconfig-transport-line-protection"`
	ΛAttenuation       []ygot.Annotation                               `path:"state/@attenuation" ygotAnnotation:"true"`
	Enabled            *bool                                           `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-transport-line-protection"`
	ΛEnabled           []ygot.Annotation                               `path:"state/@enabled" ygotAnnotation:"true"`
	OpticalPower       *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower `path:"state/optical-power" module:"openconfig-transport-line-protection"`
	ΛOpticalPower      []ygot.Annotation                               `path:"state/@optical-power" ygotAnnotation:"true"`
	TargetAttenuation  *float64                                        `path:"state/target-attenuation" shadow-path:"config/target-attenuation" module:"openconfig-transport-line-protection"`
	ΛTargetAttenuation []ygot.Annotation                               `path:"state/@target-attenuation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LinePrimaryIn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LinePrimaryIn) IsYANGGoStruct() {}

// GetOrCreateOpticalPower retrieves the value of the OpticalPower field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) GetOrCreateOpticalPower() *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower {
	if t.OpticalPower != nil {
		return t.OpticalPower
	}
	t.OpticalPower = &Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower{}
	return t.OpticalPower
}

// GetOpticalPower returns the value of the OpticalPower struct pointer
// from Aps_ApsModule_Ports_LinePrimaryIn. If the receiver or the field OpticalPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) GetOpticalPower() *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower {
	if t != nil && t.OpticalPower != nil {
		return t.OpticalPower
	}
	return nil
}

// GetAttenuation retrieves the value of the leaf Attenuation from the Aps_ApsModule_Ports_LinePrimaryIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attenuation is set, it can safely use t.GetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) GetAttenuation() float64 {
	if t == nil || t.Attenuation == nil {
		return 0.0
	}
	return *t.Attenuation
}

// GetEnabled retrieves the value of the leaf Enabled from the Aps_ApsModule_Ports_LinePrimaryIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetTargetAttenuation retrieves the value of the leaf TargetAttenuation from the Aps_ApsModule_Ports_LinePrimaryIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetAttenuation is set, it can safely use t.GetTargetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetAttenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) GetTargetAttenuation() float64 {
	if t == nil || t.TargetAttenuation == nil {
		return 0.0
	}
	return *t.TargetAttenuation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LinePrimaryIn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LinePrimaryIn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-primary-in/state/optical-power YANG schema element.
type Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-protection"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-protection"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-protection"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-protection"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-protection"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-protection"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-protection"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LinePrimaryIn_OpticalPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LinePrimaryOut represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-primary-out YANG schema element.
type Aps_ApsModule_Ports_LinePrimaryOut struct {
	ΛMetadata          []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	Attenuation        *float64                                         `path:"state/attenuation" module:"openconfig-transport-line-protection"`
	ΛAttenuation       []ygot.Annotation                                `path:"state/@attenuation" ygotAnnotation:"true"`
	OpticalPower       *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower `path:"state/optical-power" module:"openconfig-transport-line-protection"`
	ΛOpticalPower      []ygot.Annotation                                `path:"state/@optical-power" ygotAnnotation:"true"`
	TargetAttenuation  *float64                                         `path:"state/target-attenuation" shadow-path:"config/target-attenuation" module:"openconfig-transport-line-protection"`
	ΛTargetAttenuation []ygot.Annotation                                `path:"state/@target-attenuation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LinePrimaryOut implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LinePrimaryOut) IsYANGGoStruct() {}

// GetOrCreateOpticalPower retrieves the value of the OpticalPower field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports_LinePrimaryOut) GetOrCreateOpticalPower() *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower {
	if t.OpticalPower != nil {
		return t.OpticalPower
	}
	t.OpticalPower = &Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower{}
	return t.OpticalPower
}

// GetOpticalPower returns the value of the OpticalPower struct pointer
// from Aps_ApsModule_Ports_LinePrimaryOut. If the receiver or the field OpticalPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports_LinePrimaryOut) GetOpticalPower() *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower {
	if t != nil && t.OpticalPower != nil {
		return t.OpticalPower
	}
	return nil
}

// GetAttenuation retrieves the value of the leaf Attenuation from the Aps_ApsModule_Ports_LinePrimaryOut
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attenuation is set, it can safely use t.GetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut) GetAttenuation() float64 {
	if t == nil || t.Attenuation == nil {
		return 0.0
	}
	return *t.Attenuation
}

// GetTargetAttenuation retrieves the value of the leaf TargetAttenuation from the Aps_ApsModule_Ports_LinePrimaryOut
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetAttenuation is set, it can safely use t.GetTargetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetAttenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut) GetTargetAttenuation() float64 {
	if t == nil || t.TargetAttenuation == nil {
		return 0.0
	}
	return *t.TargetAttenuation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LinePrimaryOut) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LinePrimaryOut"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LinePrimaryOut) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-primary-out/state/optical-power YANG schema element.
type Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-protection"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-protection"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-protection"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-protection"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-protection"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-protection"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-protection"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LinePrimaryOut_OpticalPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LineSecondaryIn represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-secondary-in YANG schema element.
type Aps_ApsModule_Ports_LineSecondaryIn struct {
	ΛMetadata          []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	Attenuation        *float64                                          `path:"state/attenuation" module:"openconfig-transport-line-protection"`
	ΛAttenuation       []ygot.Annotation                                 `path:"state/@attenuation" ygotAnnotation:"true"`
	Enabled            *bool                                             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-transport-line-protection"`
	ΛEnabled           []ygot.Annotation                                 `path:"state/@enabled" ygotAnnotation:"true"`
	OpticalPower       *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower `path:"state/optical-power" module:"openconfig-transport-line-protection"`
	ΛOpticalPower      []ygot.Annotation                                 `path:"state/@optical-power" ygotAnnotation:"true"`
	TargetAttenuation  *float64                                          `path:"state/target-attenuation" shadow-path:"config/target-attenuation" module:"openconfig-transport-line-protection"`
	ΛTargetAttenuation []ygot.Annotation                                 `path:"state/@target-attenuation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LineSecondaryIn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LineSecondaryIn) IsYANGGoStruct() {}

// GetOrCreateOpticalPower retrieves the value of the OpticalPower field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) GetOrCreateOpticalPower() *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower {
	if t.OpticalPower != nil {
		return t.OpticalPower
	}
	t.OpticalPower = &Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower{}
	return t.OpticalPower
}

// GetOpticalPower returns the value of the OpticalPower struct pointer
// from Aps_ApsModule_Ports_LineSecondaryIn. If the receiver or the field OpticalPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) GetOpticalPower() *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower {
	if t != nil && t.OpticalPower != nil {
		return t.OpticalPower
	}
	return nil
}

// GetAttenuation retrieves the value of the leaf Attenuation from the Aps_ApsModule_Ports_LineSecondaryIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attenuation is set, it can safely use t.GetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) GetAttenuation() float64 {
	if t == nil || t.Attenuation == nil {
		return 0.0
	}
	return *t.Attenuation
}

// GetEnabled retrieves the value of the leaf Enabled from the Aps_ApsModule_Ports_LineSecondaryIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetTargetAttenuation retrieves the value of the leaf TargetAttenuation from the Aps_ApsModule_Ports_LineSecondaryIn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetAttenuation is set, it can safely use t.GetTargetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetAttenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) GetTargetAttenuation() float64 {
	if t == nil || t.TargetAttenuation == nil {
		return 0.0
	}
	return *t.TargetAttenuation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LineSecondaryIn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LineSecondaryIn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-secondary-in/state/optical-power YANG schema element.
type Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-protection"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-protection"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-protection"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-protection"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-protection"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-protection"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-protection"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LineSecondaryIn_OpticalPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LineSecondaryOut represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-secondary-out YANG schema element.
type Aps_ApsModule_Ports_LineSecondaryOut struct {
	ΛMetadata          []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	Attenuation        *float64                                           `path:"state/attenuation" module:"openconfig-transport-line-protection"`
	ΛAttenuation       []ygot.Annotation                                  `path:"state/@attenuation" ygotAnnotation:"true"`
	OpticalPower       *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower `path:"state/optical-power" module:"openconfig-transport-line-protection"`
	ΛOpticalPower      []ygot.Annotation                                  `path:"state/@optical-power" ygotAnnotation:"true"`
	TargetAttenuation  *float64                                           `path:"state/target-attenuation" shadow-path:"config/target-attenuation" module:"openconfig-transport-line-protection"`
	ΛTargetAttenuation []ygot.Annotation                                  `path:"state/@target-attenuation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LineSecondaryOut implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LineSecondaryOut) IsYANGGoStruct() {}

// GetOrCreateOpticalPower retrieves the value of the OpticalPower field
// or returns the existing field if it already exists.
func (t *Aps_ApsModule_Ports_LineSecondaryOut) GetOrCreateOpticalPower() *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower {
	if t.OpticalPower != nil {
		return t.OpticalPower
	}
	t.OpticalPower = &Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower{}
	return t.OpticalPower
}

// GetOpticalPower returns the value of the OpticalPower struct pointer
// from Aps_ApsModule_Ports_LineSecondaryOut. If the receiver or the field OpticalPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Aps_ApsModule_Ports_LineSecondaryOut) GetOpticalPower() *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower {
	if t != nil && t.OpticalPower != nil {
		return t.OpticalPower
	}
	return nil
}

// GetAttenuation retrieves the value of the leaf Attenuation from the Aps_ApsModule_Ports_LineSecondaryOut
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attenuation is set, it can safely use t.GetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut) GetAttenuation() float64 {
	if t == nil || t.Attenuation == nil {
		return 0.0
	}
	return *t.Attenuation
}

// GetTargetAttenuation retrieves the value of the leaf TargetAttenuation from the Aps_ApsModule_Ports_LineSecondaryOut
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetAttenuation is set, it can safely use t.GetTargetAttenuation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetAttenuation == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut) GetTargetAttenuation() float64 {
	if t == nil || t.TargetAttenuation == nil {
		return 0.0
	}
	return *t.TargetAttenuation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LineSecondaryOut) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LineSecondaryOut"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LineSecondaryOut) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower represents the /openconfig-transport-line-protection/aps/aps-modules/aps-module/ports/line-secondary-out/state/optical-power YANG schema element.
type Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-protection"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-protection"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-protection"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-protection"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-protection"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-protection"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-protection"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Aps_ApsModule_Ports_LineSecondaryOut_OpticalPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp represents the /openconfig-bgp/bgp YANG schema element.
type Bgp struct {
	ΛMetadata  []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Global     *Bgp_Global               `path:"global" module:"openconfig-bgp"`
	ΛGlobal    []ygot.Annotation         `path:"@global" ygotAnnotation:"true"`
	Neighbor   map[string]*Bgp_Neighbor  `path:"neighbors/neighbor" module:"openconfig-bgp"`
	ΛNeighbor  []ygot.Annotation         `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	PeerGroup  map[string]*Bgp_PeerGroup `path:"peer-groups/peer-group" module:"openconfig-bgp"`
	ΛPeerGroup []ygot.Annotation         `path:"peer-groups/@peer-group" ygotAnnotation:"true"`
	Rib        *Bgp_Rib                  `path:"rib" module:"openconfig-bgp"`
	ΛRib       []ygot.Annotation         `path:"@rib" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// Bgp struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp) NewNeighbor(NeighborAddress string) (*Bgp_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Bgp_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Bgp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Bgp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp) GetOrCreateNeighbor(NeighborAddress string) *Bgp_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Bgp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp) GetNeighbor(NeighborAddress string) *Bgp_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Bgp_Neighbor struct to the
// list Neighbor of Bgp. If the key value(s) specified in
// the supplied Bgp_Neighbor already exist in the list, an error is
// returned.
func (t *Bgp) AppendNeighbor(v *Bgp_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// NewPeerGroup creates a new entry in the PeerGroup list of the
// Bgp struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp) NewPeerGroup(PeerGroupName string) (*Bgp_PeerGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PeerGroup == nil {
		t.PeerGroup = make(map[string]*Bgp_PeerGroup)
	}

	key := PeerGroupName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PeerGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PeerGroup", key)
	}

	t.PeerGroup[key] = &Bgp_PeerGroup{
		PeerGroupName: &PeerGroupName,
	}

	return t.PeerGroup[key], nil
}

// RenamePeerGroup renames an entry in the list PeerGroup within
// the Bgp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp) RenamePeerGroup(oldK, newK string) error {
	if _, ok := t.PeerGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in PeerGroup", newK)
	}

	e, ok := t.PeerGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PeerGroup", oldK)
	}
	e.PeerGroupName = &newK

	t.PeerGroup[newK] = e
	delete(t.PeerGroup, oldK)
	return nil
}

// GetOrCreatePeerGroup retrieves the value with the specified keys from
// the receiver Bgp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp) GetOrCreatePeerGroup(PeerGroupName string) *Bgp_PeerGroup {

	key := PeerGroupName

	if v, ok := t.PeerGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPeerGroup(PeerGroupName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePeerGroup got unexpected error: %v", err))
	}
	return v
}

// GetPeerGroup retrieves the value with the specified key from
// the PeerGroup map field of Bgp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp) GetPeerGroup(PeerGroupName string) *Bgp_PeerGroup {

	if t == nil {
		return nil
	}

	key := PeerGroupName

	if lm, ok := t.PeerGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendPeerGroup appends the supplied Bgp_PeerGroup struct to the
// list PeerGroup of Bgp. If the key value(s) specified in
// the supplied Bgp_PeerGroup already exist in the list, an error is
// returned.
func (t *Bgp) AppendPeerGroup(v *Bgp_PeerGroup) error {
	if v.PeerGroupName == nil {
		return fmt.Errorf("invalid nil key received for PeerGroupName")
	}

	key := *v.PeerGroupName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PeerGroup == nil {
		t.PeerGroup = make(map[string]*Bgp_PeerGroup)
	}

	if _, ok := t.PeerGroup[key]; ok {
		return fmt.Errorf("duplicate key for list PeerGroup %v", key)
	}

	t.PeerGroup[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *Bgp) GetOrCreateGlobal() *Bgp_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &Bgp_Global{}
	return t.Global
}

// GetOrCreateRib retrieves the value of the Rib field
// or returns the existing field if it already exists.
func (t *Bgp) GetOrCreateRib() *Bgp_Rib {
	if t.Rib != nil {
		return t.Rib
	}
	t.Rib = &Bgp_Rib{}
	return t.Rib
}

// GetGlobal returns the value of the Global struct pointer
// from Bgp. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp) GetGlobal() *Bgp_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// GetRib returns the value of the Rib struct pointer
// from Bgp. If the receiver or the field Rib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp) GetRib() *Bgp_Rib {
	if t != nil && t.Rib != nil {
		return t.Rib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global represents the /openconfig-bgp/bgp/global YANG schema element.
type Bgp_Global struct {
	ΛMetadata              []ygot.Annotation                                          `path:"@" ygotAnnotation:"true"`
	AfiSafi                map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Global_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-bgp"`
	ΛAfiSafi               []ygot.Annotation                                          `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	As                     *uint32                                                    `path:"state/as" shadow-path:"config/as" module:"openconfig-bgp"`
	ΛAs                    []ygot.Annotation                                          `path:"state/@as" ygotAnnotation:"true"`
	Confederation          *Bgp_Global_Confederation                                  `path:"confederation" module:"openconfig-bgp"`
	ΛConfederation         []ygot.Annotation                                          `path:"@confederation" ygotAnnotation:"true"`
	DefaultRouteDistance   *Bgp_Global_DefaultRouteDistance                           `path:"default-route-distance" module:"openconfig-bgp"`
	ΛDefaultRouteDistance  []ygot.Annotation                                          `path:"@default-route-distance" ygotAnnotation:"true"`
	DynamicNeighborPrefix  map[string]*Bgp_Global_DynamicNeighborPrefix               `path:"dynamic-neighbor-prefixes/dynamic-neighbor-prefix" module:"openconfig-bgp"`
	ΛDynamicNeighborPrefix []ygot.Annotation                                          `path:"dynamic-neighbor-prefixes/@dynamic-neighbor-prefix" ygotAnnotation:"true"`
	GracefulRestart        *Bgp_Global_GracefulRestart                                `path:"graceful-restart" module:"openconfig-bgp"`
	ΛGracefulRestart       []ygot.Annotation                                          `path:"@graceful-restart" ygotAnnotation:"true"`
	RouteSelectionOptions  *Bgp_Global_RouteSelectionOptions                          `path:"route-selection-options" module:"openconfig-bgp"`
	ΛRouteSelectionOptions []ygot.Annotation                                          `path:"@route-selection-options" ygotAnnotation:"true"`
	RouterId               *string                                                    `path:"state/router-id" shadow-path:"config/router-id" module:"openconfig-bgp"`
	ΛRouterId              []ygot.Annotation                                          `path:"state/@router-id" ygotAnnotation:"true"`
	TotalPaths             *uint32                                                    `path:"state/total-paths" module:"openconfig-bgp"`
	ΛTotalPaths            []ygot.Annotation                                          `path:"state/@total-paths" ygotAnnotation:"true"`
	TotalPrefixes          *uint32                                                    `path:"state/total-prefixes" module:"openconfig-bgp"`
	ΛTotalPrefixes         []ygot.Annotation                                          `path:"state/@total-prefixes" ygotAnnotation:"true"`
	UseMultiplePaths       *Bgp_Global_UseMultiplePaths                               `path:"use-multiple-paths" module:"openconfig-bgp"`
	ΛUseMultiplePaths      []ygot.Annotation                                          `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// Bgp_Global struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Global) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*Bgp_Global_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Global_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &Bgp_Global_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the Bgp_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Global) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver Bgp_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Global) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_Global_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of Bgp_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Global) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_Global_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied Bgp_Global_AfiSafi struct to the
// list AfiSafi of Bgp_Global. If the key value(s) specified in
// the supplied Bgp_Global_AfiSafi already exist in the list, an error is
// returned.
func (t *Bgp_Global) AppendAfiSafi(v *Bgp_Global_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Global_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// NewDynamicNeighborPrefix creates a new entry in the DynamicNeighborPrefix list of the
// Bgp_Global struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Global) NewDynamicNeighborPrefix(Prefix string) (*Bgp_Global_DynamicNeighborPrefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DynamicNeighborPrefix == nil {
		t.DynamicNeighborPrefix = make(map[string]*Bgp_Global_DynamicNeighborPrefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DynamicNeighborPrefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DynamicNeighborPrefix", key)
	}

	t.DynamicNeighborPrefix[key] = &Bgp_Global_DynamicNeighborPrefix{
		Prefix: &Prefix,
	}

	return t.DynamicNeighborPrefix[key], nil
}

// RenameDynamicNeighborPrefix renames an entry in the list DynamicNeighborPrefix within
// the Bgp_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Global) RenameDynamicNeighborPrefix(oldK, newK string) error {
	if _, ok := t.DynamicNeighborPrefix[newK]; ok {
		return fmt.Errorf("key %v already exists in DynamicNeighborPrefix", newK)
	}

	e, ok := t.DynamicNeighborPrefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in DynamicNeighborPrefix", oldK)
	}
	e.Prefix = &newK

	t.DynamicNeighborPrefix[newK] = e
	delete(t.DynamicNeighborPrefix, oldK)
	return nil
}

// GetOrCreateDynamicNeighborPrefix retrieves the value with the specified keys from
// the receiver Bgp_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Global) GetOrCreateDynamicNeighborPrefix(Prefix string) *Bgp_Global_DynamicNeighborPrefix {

	key := Prefix

	if v, ok := t.DynamicNeighborPrefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewDynamicNeighborPrefix(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateDynamicNeighborPrefix got unexpected error: %v", err))
	}
	return v
}

// GetDynamicNeighborPrefix retrieves the value with the specified key from
// the DynamicNeighborPrefix map field of Bgp_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Global) GetDynamicNeighborPrefix(Prefix string) *Bgp_Global_DynamicNeighborPrefix {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.DynamicNeighborPrefix[key]; ok {
		return lm
	}
	return nil
}

// AppendDynamicNeighborPrefix appends the supplied Bgp_Global_DynamicNeighborPrefix struct to the
// list DynamicNeighborPrefix of Bgp_Global. If the key value(s) specified in
// the supplied Bgp_Global_DynamicNeighborPrefix already exist in the list, an error is
// returned.
func (t *Bgp_Global) AppendDynamicNeighborPrefix(v *Bgp_Global_DynamicNeighborPrefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DynamicNeighborPrefix == nil {
		t.DynamicNeighborPrefix = make(map[string]*Bgp_Global_DynamicNeighborPrefix)
	}

	if _, ok := t.DynamicNeighborPrefix[key]; ok {
		return fmt.Errorf("duplicate key for list DynamicNeighborPrefix %v", key)
	}

	t.DynamicNeighborPrefix[key] = v
	return nil
}

// GetOrCreateConfederation retrieves the value of the Confederation field
// or returns the existing field if it already exists.
func (t *Bgp_Global) GetOrCreateConfederation() *Bgp_Global_Confederation {
	if t.Confederation != nil {
		return t.Confederation
	}
	t.Confederation = &Bgp_Global_Confederation{}
	return t.Confederation
}

// GetOrCreateDefaultRouteDistance retrieves the value of the DefaultRouteDistance field
// or returns the existing field if it already exists.
func (t *Bgp_Global) GetOrCreateDefaultRouteDistance() *Bgp_Global_DefaultRouteDistance {
	if t.DefaultRouteDistance != nil {
		return t.DefaultRouteDistance
	}
	t.DefaultRouteDistance = &Bgp_Global_DefaultRouteDistance{}
	return t.DefaultRouteDistance
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *Bgp_Global) GetOrCreateGracefulRestart() *Bgp_Global_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &Bgp_Global_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateRouteSelectionOptions retrieves the value of the RouteSelectionOptions field
// or returns the existing field if it already exists.
func (t *Bgp_Global) GetOrCreateRouteSelectionOptions() *Bgp_Global_RouteSelectionOptions {
	if t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	t.RouteSelectionOptions = &Bgp_Global_RouteSelectionOptions{}
	return t.RouteSelectionOptions
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *Bgp_Global) GetOrCreateUseMultiplePaths() *Bgp_Global_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &Bgp_Global_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetConfederation returns the value of the Confederation struct pointer
// from Bgp_Global. If the receiver or the field Confederation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global) GetConfederation() *Bgp_Global_Confederation {
	if t != nil && t.Confederation != nil {
		return t.Confederation
	}
	return nil
}

// GetDefaultRouteDistance returns the value of the DefaultRouteDistance struct pointer
// from Bgp_Global. If the receiver or the field DefaultRouteDistance is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global) GetDefaultRouteDistance() *Bgp_Global_DefaultRouteDistance {
	if t != nil && t.DefaultRouteDistance != nil {
		return t.DefaultRouteDistance
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from Bgp_Global. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global) GetGracefulRestart() *Bgp_Global_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetRouteSelectionOptions returns the value of the RouteSelectionOptions struct pointer
// from Bgp_Global. If the receiver or the field RouteSelectionOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global) GetRouteSelectionOptions() *Bgp_Global_RouteSelectionOptions {
	if t != nil && t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from Bgp_Global. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global) GetUseMultiplePaths() *Bgp_Global_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAs retrieves the value of the leaf As from the Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As is set, it can safely use t.GetAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global) GetAs() uint32 {
	if t == nil || t.As == nil {
		return 0
	}
	return *t.As
}

// GetRouterId retrieves the value of the leaf RouterId from the Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetTotalPaths retrieves the value of the leaf TotalPaths from the Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPaths is set, it can safely use t.GetTotalPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global) GetTotalPaths() uint32 {
	if t == nil || t.TotalPaths == nil {
		return 0
	}
	return *t.TotalPaths
}

// GetTotalPrefixes retrieves the value of the leaf TotalPrefixes from the Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPrefixes is set, it can safely use t.GetTotalPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global) GetTotalPrefixes() uint32 {
	if t == nil || t.TotalPrefixes == nil {
		return 0
	}
	return *t.TotalPrefixes
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_AfiSafi represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi YANG schema element.
type Bgp_Global_AfiSafi struct {
	ΛMetadata              []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	AddPaths               *Bgp_Global_AfiSafi_AddPaths              `path:"add-paths" module:"openconfig-bgp"`
	ΛAddPaths              []ygot.Annotation                         `path:"@add-paths" ygotAnnotation:"true"`
	AfiSafiName            E_OpenconfigBgpTypes_AFI_SAFI_TYPE        `path:"state/afi-safi-name|afi-safi-name" shadow-path:"config/afi-safi-name" module:"openconfig-bgp"`
	ΛAfiSafiName           []ygot.Annotation                         `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	Enabled                *bool                                     `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled               []ygot.Annotation                         `path:"state/@enabled" ygotAnnotation:"true"`
	GracefulRestart        *Bgp_Global_AfiSafi_GracefulRestart       `path:"graceful-restart" module:"openconfig-bgp"`
	ΛGracefulRestart       []ygot.Annotation                         `path:"@graceful-restart" ygotAnnotation:"true"`
	Ipv4LabeledUnicast     *Bgp_Global_AfiSafi_Ipv4LabeledUnicast    `path:"ipv4-labeled-unicast" module:"openconfig-bgp"`
	ΛIpv4LabeledUnicast    []ygot.Annotation                         `path:"@ipv4-labeled-unicast" ygotAnnotation:"true"`
	Ipv4Unicast            *Bgp_Global_AfiSafi_Ipv4Unicast           `path:"ipv4-unicast" module:"openconfig-bgp"`
	ΛIpv4Unicast           []ygot.Annotation                         `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6LabeledUnicast     *Bgp_Global_AfiSafi_Ipv6LabeledUnicast    `path:"ipv6-labeled-unicast" module:"openconfig-bgp"`
	ΛIpv6LabeledUnicast    []ygot.Annotation                         `path:"@ipv6-labeled-unicast" ygotAnnotation:"true"`
	Ipv6Unicast            *Bgp_Global_AfiSafi_Ipv6Unicast           `path:"ipv6-unicast" module:"openconfig-bgp"`
	ΛIpv6Unicast           []ygot.Annotation                         `path:"@ipv6-unicast" ygotAnnotation:"true"`
	L2VpnEvpn              *Bgp_Global_AfiSafi_L2VpnEvpn             `path:"l2vpn-evpn" module:"openconfig-bgp"`
	ΛL2VpnEvpn             []ygot.Annotation                         `path:"@l2vpn-evpn" ygotAnnotation:"true"`
	L2VpnVpls              *Bgp_Global_AfiSafi_L2VpnVpls             `path:"l2vpn-vpls" module:"openconfig-bgp"`
	ΛL2VpnVpls             []ygot.Annotation                         `path:"@l2vpn-vpls" ygotAnnotation:"true"`
	L3VpnIpv4Multicast     *Bgp_Global_AfiSafi_L3VpnIpv4Multicast    `path:"l3vpn-ipv4-multicast" module:"openconfig-bgp"`
	ΛL3VpnIpv4Multicast    []ygot.Annotation                         `path:"@l3vpn-ipv4-multicast" ygotAnnotation:"true"`
	L3VpnIpv4Unicast       *Bgp_Global_AfiSafi_L3VpnIpv4Unicast      `path:"l3vpn-ipv4-unicast" module:"openconfig-bgp"`
	ΛL3VpnIpv4Unicast      []ygot.Annotation                         `path:"@l3vpn-ipv4-unicast" ygotAnnotation:"true"`
	L3VpnIpv6Multicast     *Bgp_Global_AfiSafi_L3VpnIpv6Multicast    `path:"l3vpn-ipv6-multicast" module:"openconfig-bgp"`
	ΛL3VpnIpv6Multicast    []ygot.Annotation                         `path:"@l3vpn-ipv6-multicast" ygotAnnotation:"true"`
	L3VpnIpv6Unicast       *Bgp_Global_AfiSafi_L3VpnIpv6Unicast      `path:"l3vpn-ipv6-unicast" module:"openconfig-bgp"`
	ΛL3VpnIpv6Unicast      []ygot.Annotation                         `path:"@l3vpn-ipv6-unicast" ygotAnnotation:"true"`
	RouteSelectionOptions  *Bgp_Global_AfiSafi_RouteSelectionOptions `path:"route-selection-options" module:"openconfig-bgp"`
	ΛRouteSelectionOptions []ygot.Annotation                         `path:"@route-selection-options" ygotAnnotation:"true"`
	SrtePolicyIpv4         *Bgp_Global_AfiSafi_SrtePolicyIpv4        `path:"srte-policy-ipv4" module:"openconfig-bgp"`
	ΛSrtePolicyIpv4        []ygot.Annotation                         `path:"@srte-policy-ipv4" ygotAnnotation:"true"`
	SrtePolicyIpv6         *Bgp_Global_AfiSafi_SrtePolicyIpv6        `path:"srte-policy-ipv6" module:"openconfig-bgp"`
	ΛSrtePolicyIpv6        []ygot.Annotation                         `path:"@srte-policy-ipv6" ygotAnnotation:"true"`
	TotalPaths             *uint32                                   `path:"state/total-paths" module:"openconfig-bgp"`
	ΛTotalPaths            []ygot.Annotation                         `path:"state/@total-paths" ygotAnnotation:"true"`
	TotalPrefixes          *uint32                                   `path:"state/total-prefixes" module:"openconfig-bgp"`
	ΛTotalPrefixes         []ygot.Annotation                         `path:"state/@total-prefixes" ygotAnnotation:"true"`
	UseMultiplePaths       *Bgp_Global_AfiSafi_UseMultiplePaths      `path:"use-multiple-paths" module:"openconfig-bgp"`
	ΛUseMultiplePaths      []ygot.Annotation                         `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateAddPaths retrieves the value of the AddPaths field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateAddPaths() *Bgp_Global_AfiSafi_AddPaths {
	if t.AddPaths != nil {
		return t.AddPaths
	}
	t.AddPaths = &Bgp_Global_AfiSafi_AddPaths{}
	return t.AddPaths
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateGracefulRestart() *Bgp_Global_AfiSafi_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &Bgp_Global_AfiSafi_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateIpv4LabeledUnicast retrieves the value of the Ipv4LabeledUnicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateIpv4LabeledUnicast() *Bgp_Global_AfiSafi_Ipv4LabeledUnicast {
	if t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	t.Ipv4LabeledUnicast = &Bgp_Global_AfiSafi_Ipv4LabeledUnicast{}
	return t.Ipv4LabeledUnicast
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateIpv4Unicast() *Bgp_Global_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &Bgp_Global_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6LabeledUnicast retrieves the value of the Ipv6LabeledUnicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateIpv6LabeledUnicast() *Bgp_Global_AfiSafi_Ipv6LabeledUnicast {
	if t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	t.Ipv6LabeledUnicast = &Bgp_Global_AfiSafi_Ipv6LabeledUnicast{}
	return t.Ipv6LabeledUnicast
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateIpv6Unicast() *Bgp_Global_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &Bgp_Global_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetOrCreateL2VpnEvpn retrieves the value of the L2VpnEvpn field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateL2VpnEvpn() *Bgp_Global_AfiSafi_L2VpnEvpn {
	if t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	t.L2VpnEvpn = &Bgp_Global_AfiSafi_L2VpnEvpn{}
	return t.L2VpnEvpn
}

// GetOrCreateL2VpnVpls retrieves the value of the L2VpnVpls field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateL2VpnVpls() *Bgp_Global_AfiSafi_L2VpnVpls {
	if t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	t.L2VpnVpls = &Bgp_Global_AfiSafi_L2VpnVpls{}
	return t.L2VpnVpls
}

// GetOrCreateL3VpnIpv4Multicast retrieves the value of the L3VpnIpv4Multicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv4Multicast() *Bgp_Global_AfiSafi_L3VpnIpv4Multicast {
	if t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	t.L3VpnIpv4Multicast = &Bgp_Global_AfiSafi_L3VpnIpv4Multicast{}
	return t.L3VpnIpv4Multicast
}

// GetOrCreateL3VpnIpv4Unicast retrieves the value of the L3VpnIpv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv4Unicast() *Bgp_Global_AfiSafi_L3VpnIpv4Unicast {
	if t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	t.L3VpnIpv4Unicast = &Bgp_Global_AfiSafi_L3VpnIpv4Unicast{}
	return t.L3VpnIpv4Unicast
}

// GetOrCreateL3VpnIpv6Multicast retrieves the value of the L3VpnIpv6Multicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv6Multicast() *Bgp_Global_AfiSafi_L3VpnIpv6Multicast {
	if t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	t.L3VpnIpv6Multicast = &Bgp_Global_AfiSafi_L3VpnIpv6Multicast{}
	return t.L3VpnIpv6Multicast
}

// GetOrCreateL3VpnIpv6Unicast retrieves the value of the L3VpnIpv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv6Unicast() *Bgp_Global_AfiSafi_L3VpnIpv6Unicast {
	if t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	t.L3VpnIpv6Unicast = &Bgp_Global_AfiSafi_L3VpnIpv6Unicast{}
	return t.L3VpnIpv6Unicast
}

// GetOrCreateRouteSelectionOptions retrieves the value of the RouteSelectionOptions field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateRouteSelectionOptions() *Bgp_Global_AfiSafi_RouteSelectionOptions {
	if t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	t.RouteSelectionOptions = &Bgp_Global_AfiSafi_RouteSelectionOptions{}
	return t.RouteSelectionOptions
}

// GetOrCreateSrtePolicyIpv4 retrieves the value of the SrtePolicyIpv4 field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateSrtePolicyIpv4() *Bgp_Global_AfiSafi_SrtePolicyIpv4 {
	if t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	t.SrtePolicyIpv4 = &Bgp_Global_AfiSafi_SrtePolicyIpv4{}
	return t.SrtePolicyIpv4
}

// GetOrCreateSrtePolicyIpv6 retrieves the value of the SrtePolicyIpv6 field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateSrtePolicyIpv6() *Bgp_Global_AfiSafi_SrtePolicyIpv6 {
	if t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	t.SrtePolicyIpv6 = &Bgp_Global_AfiSafi_SrtePolicyIpv6{}
	return t.SrtePolicyIpv6
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi) GetOrCreateUseMultiplePaths() *Bgp_Global_AfiSafi_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &Bgp_Global_AfiSafi_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetAddPaths returns the value of the AddPaths struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field AddPaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetAddPaths() *Bgp_Global_AfiSafi_AddPaths {
	if t != nil && t.AddPaths != nil {
		return t.AddPaths
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetGracefulRestart() *Bgp_Global_AfiSafi_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetIpv4LabeledUnicast returns the value of the Ipv4LabeledUnicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field Ipv4LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetIpv4LabeledUnicast() *Bgp_Global_AfiSafi_Ipv4LabeledUnicast {
	if t != nil && t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetIpv4Unicast() *Bgp_Global_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6LabeledUnicast returns the value of the Ipv6LabeledUnicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field Ipv6LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetIpv6LabeledUnicast() *Bgp_Global_AfiSafi_Ipv6LabeledUnicast {
	if t != nil && t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetIpv6Unicast() *Bgp_Global_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetL2VpnEvpn returns the value of the L2VpnEvpn struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field L2VpnEvpn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetL2VpnEvpn() *Bgp_Global_AfiSafi_L2VpnEvpn {
	if t != nil && t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	return nil
}

// GetL2VpnVpls returns the value of the L2VpnVpls struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field L2VpnVpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetL2VpnVpls() *Bgp_Global_AfiSafi_L2VpnVpls {
	if t != nil && t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	return nil
}

// GetL3VpnIpv4Multicast returns the value of the L3VpnIpv4Multicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv4Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetL3VpnIpv4Multicast() *Bgp_Global_AfiSafi_L3VpnIpv4Multicast {
	if t != nil && t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	return nil
}

// GetL3VpnIpv4Unicast returns the value of the L3VpnIpv4Unicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetL3VpnIpv4Unicast() *Bgp_Global_AfiSafi_L3VpnIpv4Unicast {
	if t != nil && t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	return nil
}

// GetL3VpnIpv6Multicast returns the value of the L3VpnIpv6Multicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv6Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetL3VpnIpv6Multicast() *Bgp_Global_AfiSafi_L3VpnIpv6Multicast {
	if t != nil && t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	return nil
}

// GetL3VpnIpv6Unicast returns the value of the L3VpnIpv6Unicast struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetL3VpnIpv6Unicast() *Bgp_Global_AfiSafi_L3VpnIpv6Unicast {
	if t != nil && t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	return nil
}

// GetRouteSelectionOptions returns the value of the RouteSelectionOptions struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field RouteSelectionOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetRouteSelectionOptions() *Bgp_Global_AfiSafi_RouteSelectionOptions {
	if t != nil && t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	return nil
}

// GetSrtePolicyIpv4 returns the value of the SrtePolicyIpv4 struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field SrtePolicyIpv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetSrtePolicyIpv4() *Bgp_Global_AfiSafi_SrtePolicyIpv4 {
	if t != nil && t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	return nil
}

// GetSrtePolicyIpv6 returns the value of the SrtePolicyIpv6 struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field SrtePolicyIpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetSrtePolicyIpv6() *Bgp_Global_AfiSafi_SrtePolicyIpv6 {
	if t != nil && t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from Bgp_Global_AfiSafi. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi) GetUseMultiplePaths() *Bgp_Global_AfiSafi_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetTotalPaths retrieves the value of the leaf TotalPaths from the Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPaths is set, it can safely use t.GetTotalPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi) GetTotalPaths() uint32 {
	if t == nil || t.TotalPaths == nil {
		return 0
	}
	return *t.TotalPaths
}

// GetTotalPrefixes retrieves the value of the leaf TotalPrefixes from the Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPrefixes is set, it can safely use t.GetTotalPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi) GetTotalPrefixes() uint32 {
	if t == nil || t.TotalPrefixes == nil {
		return 0
	}
	return *t.TotalPrefixes
}

// ΛListKeyMap returns the keys of the Bgp_Global_AfiSafi struct, which is a YANG list entry.
func (t *Bgp_Global_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_AfiSafi_AddPaths represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/add-paths YANG schema element.
type Bgp_Global_AfiSafi_AddPaths struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EligiblePrefixPolicy  *string           `path:"state/eligible-prefix-policy" shadow-path:"config/eligible-prefix-policy" module:"openconfig-bgp"`
	ΛEligiblePrefixPolicy []ygot.Annotation `path:"state/@eligible-prefix-policy" ygotAnnotation:"true"`
	Receive               *bool             `path:"state/receive" shadow-path:"config/receive" module:"openconfig-bgp"`
	ΛReceive              []ygot.Annotation `path:"state/@receive" ygotAnnotation:"true"`
	Send                  *bool             `path:"state/send" shadow-path:"config/send" module:"openconfig-bgp"`
	ΛSend                 []ygot.Annotation `path:"state/@send" ygotAnnotation:"true"`
	SendMax               *uint8            `path:"state/send-max" shadow-path:"config/send-max" module:"openconfig-bgp"`
	ΛSendMax              []ygot.Annotation `path:"state/@send-max" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_AddPaths) IsYANGGoStruct() {}

// GetEligiblePrefixPolicy retrieves the value of the leaf EligiblePrefixPolicy from the Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EligiblePrefixPolicy is set, it can safely use t.GetEligiblePrefixPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EligiblePrefixPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_AddPaths) GetEligiblePrefixPolicy() string {
	if t == nil || t.EligiblePrefixPolicy == nil {
		return ""
	}
	return *t.EligiblePrefixPolicy
}

// GetReceive retrieves the value of the leaf Receive from the Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Receive is set, it can safely use t.GetReceive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Receive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_AddPaths) GetReceive() bool {
	if t == nil || t.Receive == nil {
		return false
	}
	return *t.Receive
}

// GetSend retrieves the value of the leaf Send from the Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Send is set, it can safely use t.GetSend()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Send == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_AddPaths) GetSend() bool {
	if t == nil || t.Send == nil {
		return false
	}
	return *t.Send
}

// GetSendMax retrieves the value of the leaf SendMax from the Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendMax is set, it can safely use t.GetSendMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendMax == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_AddPaths) GetSendMax() uint8 {
	if t == nil || t.SendMax == nil {
		return 0
	}
	return *t.SendMax
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_AfiSafi_GracefulRestart represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/graceful-restart YANG schema element.
type Bgp_Global_AfiSafi_GracefulRestart struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled   *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Global_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type Bgp_Global_AfiSafi_Ipv4LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_Ipv4LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast) GetPrefixLimit() *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type Bgp_Global_AfiSafi_Ipv4Unicast struct {
	ΛMetadata         []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit      []ygot.Annotation                           `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                       `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-bgp"`
	ΛSendDefaultRoute []ygot.Annotation                           `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_Ipv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast) GetPrefixLimit() *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the Bgp_Global_AfiSafi_Ipv4Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type Bgp_Global_AfiSafi_Ipv6LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_Ipv6LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast) GetPrefixLimit() *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type Bgp_Global_AfiSafi_Ipv6Unicast struct {
	ΛMetadata         []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit      []ygot.Annotation                           `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                       `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-bgp"`
	ΛSendDefaultRoute []ygot.Annotation                           `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_Ipv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast) GetPrefixLimit() *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the Bgp_Global_AfiSafi_Ipv6Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L2VpnEvpn represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type Bgp_Global_AfiSafi_L2VpnEvpn struct {
	ΛMetadata    []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                         `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_L2VpnEvpn. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn) GetPrefixLimit() *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L2VpnVpls represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type Bgp_Global_AfiSafi_L2VpnVpls struct {
	ΛMetadata    []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                         `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_L2VpnVpls) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_L2VpnVpls. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_L2VpnVpls) GetPrefixLimit() *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv4Multicast struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_L3VpnIpv4Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast) GetPrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv4Unicast struct {
	ΛMetadata    []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_L3VpnIpv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast) GetPrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv6Multicast struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_L3VpnIpv6Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast) GetPrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv6Unicast struct {
	ΛMetadata    []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_L3VpnIpv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast) GetPrefixLimit() *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_RouteSelectionOptions represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/route-selection-options YANG schema element.
type Bgp_Global_AfiSafi_RouteSelectionOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdvertiseInactiveRoutes  *bool             `path:"state/advertise-inactive-routes" shadow-path:"config/advertise-inactive-routes" module:"openconfig-bgp"`
	ΛAdvertiseInactiveRoutes []ygot.Annotation `path:"state/@advertise-inactive-routes" ygotAnnotation:"true"`
	AlwaysCompareMed         *bool             `path:"state/always-compare-med" shadow-path:"config/always-compare-med" module:"openconfig-bgp"`
	ΛAlwaysCompareMed        []ygot.Annotation `path:"state/@always-compare-med" ygotAnnotation:"true"`
	EnableAigp               *bool             `path:"state/enable-aigp" shadow-path:"config/enable-aigp" module:"openconfig-bgp"`
	ΛEnableAigp              []ygot.Annotation `path:"state/@enable-aigp" ygotAnnotation:"true"`
	ExternalCompareRouterId  *bool             `path:"state/external-compare-router-id" shadow-path:"config/external-compare-router-id" module:"openconfig-bgp"`
	ΛExternalCompareRouterId []ygot.Annotation `path:"state/@external-compare-router-id" ygotAnnotation:"true"`
	IgnoreAsPathLength       *bool             `path:"state/ignore-as-path-length" shadow-path:"config/ignore-as-path-length" module:"openconfig-bgp"`
	ΛIgnoreAsPathLength      []ygot.Annotation `path:"state/@ignore-as-path-length" ygotAnnotation:"true"`
	IgnoreNextHopIgpMetric   *bool             `path:"state/ignore-next-hop-igp-metric" shadow-path:"config/ignore-next-hop-igp-metric" module:"openconfig-bgp"`
	ΛIgnoreNextHopIgpMetric  []ygot.Annotation `path:"state/@ignore-next-hop-igp-metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_RouteSelectionOptions) IsYANGGoStruct() {}

// GetAdvertiseInactiveRoutes retrieves the value of the leaf AdvertiseInactiveRoutes from the Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertiseInactiveRoutes is set, it can safely use t.GetAdvertiseInactiveRoutes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertiseInactiveRoutes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) GetAdvertiseInactiveRoutes() bool {
	if t == nil || t.AdvertiseInactiveRoutes == nil {
		return false
	}
	return *t.AdvertiseInactiveRoutes
}

// GetAlwaysCompareMed retrieves the value of the leaf AlwaysCompareMed from the Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlwaysCompareMed is set, it can safely use t.GetAlwaysCompareMed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlwaysCompareMed == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) GetAlwaysCompareMed() bool {
	if t == nil || t.AlwaysCompareMed == nil {
		return false
	}
	return *t.AlwaysCompareMed
}

// GetEnableAigp retrieves the value of the leaf EnableAigp from the Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableAigp is set, it can safely use t.GetEnableAigp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableAigp == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) GetEnableAigp() bool {
	if t == nil || t.EnableAigp == nil {
		return false
	}
	return *t.EnableAigp
}

// GetExternalCompareRouterId retrieves the value of the leaf ExternalCompareRouterId from the Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalCompareRouterId is set, it can safely use t.GetExternalCompareRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalCompareRouterId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) GetExternalCompareRouterId() bool {
	if t == nil || t.ExternalCompareRouterId == nil {
		return true
	}
	return *t.ExternalCompareRouterId
}

// GetIgnoreAsPathLength retrieves the value of the leaf IgnoreAsPathLength from the Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreAsPathLength is set, it can safely use t.GetIgnoreAsPathLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreAsPathLength == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) GetIgnoreAsPathLength() bool {
	if t == nil || t.IgnoreAsPathLength == nil {
		return false
	}
	return *t.IgnoreAsPathLength
}

// GetIgnoreNextHopIgpMetric retrieves the value of the leaf IgnoreNextHopIgpMetric from the Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreNextHopIgpMetric is set, it can safely use t.GetIgnoreNextHopIgpMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreNextHopIgpMetric == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) GetIgnoreNextHopIgpMetric() bool {
	if t == nil || t.IgnoreNextHopIgpMetric == nil {
		return false
	}
	return *t.IgnoreNextHopIgpMetric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_SrtePolicyIpv4 represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type Bgp_Global_AfiSafi_SrtePolicyIpv4 struct {
	ΛMetadata    []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                              `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_SrtePolicyIpv4. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4) GetPrefixLimit() *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_SrtePolicyIpv6 represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type Bgp_Global_AfiSafi_SrtePolicyIpv6 struct {
	ΛMetadata    []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                              `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6) GetOrCreatePrefixLimit() *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Global_AfiSafi_SrtePolicyIpv6. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6) GetPrefixLimit() *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_UseMultiplePaths represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type Bgp_Global_AfiSafi_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Ebgp      *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-bgp"`
	ΛEbgp     []ygot.Annotation                         `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                     `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation                         `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-bgp"`
	ΛIbgp     []ygot.Annotation                         `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) GetOrCreateEbgp() *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) GetOrCreateIbgp() *Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from Bgp_Global_AfiSafi_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) GetEbgp() *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from Bgp_Global_AfiSafi_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) GetIbgp() *Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Global_AfiSafi_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-bgp"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_Confederation represents the /openconfig-bgp/bgp/global/confederation YANG schema element.
type Bgp_Global_Confederation struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Identifier  *uint32           `path:"state/identifier" shadow-path:"config/identifier" module:"openconfig-bgp"`
	ΛIdentifier []ygot.Annotation `path:"state/@identifier" ygotAnnotation:"true"`
	MemberAs    []uint32          `path:"state/member-as" shadow-path:"config/member-as" module:"openconfig-bgp"`
	ΛMemberAs   []ygot.Annotation `path:"state/@member-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_Confederation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_Confederation) IsYANGGoStruct() {}

// GetIdentifier retrieves the value of the leaf Identifier from the Bgp_Global_Confederation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Identifier is set, it can safely use t.GetIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Identifier == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_Confederation) GetIdentifier() uint32 {
	if t == nil || t.Identifier == nil {
		return 0
	}
	return *t.Identifier
}

// GetMemberAs retrieves the value of the leaf MemberAs from the Bgp_Global_Confederation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MemberAs is set, it can safely use t.GetMemberAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MemberAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_Confederation) GetMemberAs() []uint32 {
	if t == nil || t.MemberAs == nil {
		return nil
	}
	return t.MemberAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_Confederation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_Confederation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_Confederation) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_DefaultRouteDistance represents the /openconfig-bgp/bgp/global/default-route-distance YANG schema element.
type Bgp_Global_DefaultRouteDistance struct {
	ΛMetadata              []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExternalRouteDistance  *uint8            `path:"state/external-route-distance" shadow-path:"config/external-route-distance" module:"openconfig-bgp"`
	ΛExternalRouteDistance []ygot.Annotation `path:"state/@external-route-distance" ygotAnnotation:"true"`
	InternalRouteDistance  *uint8            `path:"state/internal-route-distance" shadow-path:"config/internal-route-distance" module:"openconfig-bgp"`
	ΛInternalRouteDistance []ygot.Annotation `path:"state/@internal-route-distance" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_DefaultRouteDistance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_DefaultRouteDistance) IsYANGGoStruct() {}

// GetExternalRouteDistance retrieves the value of the leaf ExternalRouteDistance from the Bgp_Global_DefaultRouteDistance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRouteDistance is set, it can safely use t.GetExternalRouteDistance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRouteDistance == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_DefaultRouteDistance) GetExternalRouteDistance() uint8 {
	if t == nil || t.ExternalRouteDistance == nil {
		return 0
	}
	return *t.ExternalRouteDistance
}

// GetInternalRouteDistance retrieves the value of the leaf InternalRouteDistance from the Bgp_Global_DefaultRouteDistance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InternalRouteDistance is set, it can safely use t.GetInternalRouteDistance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InternalRouteDistance == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_DefaultRouteDistance) GetInternalRouteDistance() uint8 {
	if t == nil || t.InternalRouteDistance == nil {
		return 0
	}
	return *t.InternalRouteDistance
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_DefaultRouteDistance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_DefaultRouteDistance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_DefaultRouteDistance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_DynamicNeighborPrefix represents the /openconfig-bgp/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix YANG schema element.
type Bgp_Global_DynamicNeighborPrefix struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PeerGroup  *string           `path:"state/peer-group" shadow-path:"config/peer-group" module:"openconfig-bgp"`
	ΛPeerGroup []ygot.Annotation `path:"state/@peer-group" ygotAnnotation:"true"`
	Prefix     *string           `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-bgp"`
	ΛPrefix    []ygot.Annotation `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_DynamicNeighborPrefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_DynamicNeighborPrefix) IsYANGGoStruct() {}

// GetPeerGroup retrieves the value of the leaf PeerGroup from the Bgp_Global_DynamicNeighborPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerGroup is set, it can safely use t.GetPeerGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerGroup == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_DynamicNeighborPrefix) GetPeerGroup() string {
	if t == nil || t.PeerGroup == nil {
		return ""
	}
	return *t.PeerGroup
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Global_DynamicNeighborPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_DynamicNeighborPrefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// ΛListKeyMap returns the keys of the Bgp_Global_DynamicNeighborPrefix struct, which is a YANG list entry.
func (t *Bgp_Global_DynamicNeighborPrefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_DynamicNeighborPrefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_DynamicNeighborPrefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_DynamicNeighborPrefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_GracefulRestart represents the /openconfig-bgp/bgp/global/graceful-restart YANG schema element.
type Bgp_Global_GracefulRestart struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled          *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled         []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly       *bool             `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-bgp"`
	ΛHelperOnly      []ygot.Annotation `path:"state/@helper-only" ygotAnnotation:"true"`
	RestartTime      *uint16           `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-bgp"`
	ΛRestartTime     []ygot.Annotation `path:"state/@restart-time" ygotAnnotation:"true"`
	StaleRoutesTime  *float64          `path:"state/stale-routes-time" shadow-path:"config/stale-routes-time" module:"openconfig-bgp"`
	ΛStaleRoutesTime []ygot.Annotation `path:"state/@stale-routes-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// GetRestartTime retrieves the value of the leaf RestartTime from the Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_GracefulRestart) GetRestartTime() uint16 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// GetStaleRoutesTime retrieves the value of the leaf StaleRoutesTime from the Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StaleRoutesTime is set, it can safely use t.GetStaleRoutesTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StaleRoutesTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_GracefulRestart) GetStaleRoutesTime() float64 {
	if t == nil || t.StaleRoutesTime == nil {
		return 0.0
	}
	return *t.StaleRoutesTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_RouteSelectionOptions represents the /openconfig-bgp/bgp/global/route-selection-options YANG schema element.
type Bgp_Global_RouteSelectionOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdvertiseInactiveRoutes  *bool             `path:"state/advertise-inactive-routes" shadow-path:"config/advertise-inactive-routes" module:"openconfig-bgp"`
	ΛAdvertiseInactiveRoutes []ygot.Annotation `path:"state/@advertise-inactive-routes" ygotAnnotation:"true"`
	AlwaysCompareMed         *bool             `path:"state/always-compare-med" shadow-path:"config/always-compare-med" module:"openconfig-bgp"`
	ΛAlwaysCompareMed        []ygot.Annotation `path:"state/@always-compare-med" ygotAnnotation:"true"`
	EnableAigp               *bool             `path:"state/enable-aigp" shadow-path:"config/enable-aigp" module:"openconfig-bgp"`
	ΛEnableAigp              []ygot.Annotation `path:"state/@enable-aigp" ygotAnnotation:"true"`
	ExternalCompareRouterId  *bool             `path:"state/external-compare-router-id" shadow-path:"config/external-compare-router-id" module:"openconfig-bgp"`
	ΛExternalCompareRouterId []ygot.Annotation `path:"state/@external-compare-router-id" ygotAnnotation:"true"`
	IgnoreAsPathLength       *bool             `path:"state/ignore-as-path-length" shadow-path:"config/ignore-as-path-length" module:"openconfig-bgp"`
	ΛIgnoreAsPathLength      []ygot.Annotation `path:"state/@ignore-as-path-length" ygotAnnotation:"true"`
	IgnoreNextHopIgpMetric   *bool             `path:"state/ignore-next-hop-igp-metric" shadow-path:"config/ignore-next-hop-igp-metric" module:"openconfig-bgp"`
	ΛIgnoreNextHopIgpMetric  []ygot.Annotation `path:"state/@ignore-next-hop-igp-metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_RouteSelectionOptions) IsYANGGoStruct() {}

// GetAdvertiseInactiveRoutes retrieves the value of the leaf AdvertiseInactiveRoutes from the Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertiseInactiveRoutes is set, it can safely use t.GetAdvertiseInactiveRoutes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertiseInactiveRoutes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_RouteSelectionOptions) GetAdvertiseInactiveRoutes() bool {
	if t == nil || t.AdvertiseInactiveRoutes == nil {
		return false
	}
	return *t.AdvertiseInactiveRoutes
}

// GetAlwaysCompareMed retrieves the value of the leaf AlwaysCompareMed from the Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlwaysCompareMed is set, it can safely use t.GetAlwaysCompareMed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlwaysCompareMed == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_RouteSelectionOptions) GetAlwaysCompareMed() bool {
	if t == nil || t.AlwaysCompareMed == nil {
		return false
	}
	return *t.AlwaysCompareMed
}

// GetEnableAigp retrieves the value of the leaf EnableAigp from the Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableAigp is set, it can safely use t.GetEnableAigp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableAigp == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_RouteSelectionOptions) GetEnableAigp() bool {
	if t == nil || t.EnableAigp == nil {
		return false
	}
	return *t.EnableAigp
}

// GetExternalCompareRouterId retrieves the value of the leaf ExternalCompareRouterId from the Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalCompareRouterId is set, it can safely use t.GetExternalCompareRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalCompareRouterId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_RouteSelectionOptions) GetExternalCompareRouterId() bool {
	if t == nil || t.ExternalCompareRouterId == nil {
		return true
	}
	return *t.ExternalCompareRouterId
}

// GetIgnoreAsPathLength retrieves the value of the leaf IgnoreAsPathLength from the Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreAsPathLength is set, it can safely use t.GetIgnoreAsPathLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreAsPathLength == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_RouteSelectionOptions) GetIgnoreAsPathLength() bool {
	if t == nil || t.IgnoreAsPathLength == nil {
		return false
	}
	return *t.IgnoreAsPathLength
}

// GetIgnoreNextHopIgpMetric retrieves the value of the leaf IgnoreNextHopIgpMetric from the Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreNextHopIgpMetric is set, it can safely use t.GetIgnoreNextHopIgpMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreNextHopIgpMetric == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_RouteSelectionOptions) GetIgnoreNextHopIgpMetric() bool {
	if t == nil || t.IgnoreNextHopIgpMetric == nil {
		return false
	}
	return *t.IgnoreNextHopIgpMetric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_UseMultiplePaths represents the /openconfig-bgp/bgp/global/use-multiple-paths YANG schema element.
type Bgp_Global_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                 `path:"@" ygotAnnotation:"true"`
	Ebgp      *Bgp_Global_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-bgp"`
	ΛEbgp     []ygot.Annotation                 `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation                 `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *Bgp_Global_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-bgp"`
	ΛIbgp     []ygot.Annotation                 `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *Bgp_Global_UseMultiplePaths) GetOrCreateEbgp() *Bgp_Global_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &Bgp_Global_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *Bgp_Global_UseMultiplePaths) GetOrCreateIbgp() *Bgp_Global_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &Bgp_Global_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from Bgp_Global_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_UseMultiplePaths) GetEbgp() *Bgp_Global_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from Bgp_Global_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Global_UseMultiplePaths) GetIbgp() *Bgp_Global_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Global_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Global_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/global/use-multiple-paths/ebgp YANG schema element.
type Bgp_Global_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-bgp"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the Bgp_Global_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_Global_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Global_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/global/use-multiple-paths/ibgp YANG schema element.
type Bgp_Global_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Global_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Global_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_Global_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_Global_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Global_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Global_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Global_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor represents the /openconfig-bgp/bgp/neighbors/neighbor YANG schema element.
type Bgp_Neighbor struct {
	ΛMetadata               []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	AfiSafi                 map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Neighbor_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-bgp"`
	ΛAfiSafi                []ygot.Annotation                                            `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	ApplyPolicy             *Bgp_Neighbor_ApplyPolicy                                    `path:"apply-policy" module:"openconfig-bgp"`
	ΛApplyPolicy            []ygot.Annotation                                            `path:"@apply-policy" ygotAnnotation:"true"`
	AsPathOptions           *Bgp_Neighbor_AsPathOptions                                  `path:"as-path-options" module:"openconfig-bgp"`
	ΛAsPathOptions          []ygot.Annotation                                            `path:"@as-path-options" ygotAnnotation:"true"`
	AuthPassword            *string                                                      `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-bgp"`
	ΛAuthPassword           []ygot.Annotation                                            `path:"state/@auth-password" ygotAnnotation:"true"`
	Description             *string                                                      `path:"state/description" shadow-path:"config/description" module:"openconfig-bgp"`
	ΛDescription            []ygot.Annotation                                            `path:"state/@description" ygotAnnotation:"true"`
	DynamicallyConfigured   *bool                                                        `path:"state/dynamically-configured" module:"openconfig-bgp"`
	ΛDynamicallyConfigured  []ygot.Annotation                                            `path:"state/@dynamically-configured" ygotAnnotation:"true"`
	EbgpMultihop            *Bgp_Neighbor_EbgpMultihop                                   `path:"ebgp-multihop" module:"openconfig-bgp"`
	ΛEbgpMultihop           []ygot.Annotation                                            `path:"@ebgp-multihop" ygotAnnotation:"true"`
	Enabled                 *bool                                                        `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled                []ygot.Annotation                                            `path:"state/@enabled" ygotAnnotation:"true"`
	ErrorHandling           *Bgp_Neighbor_ErrorHandling                                  `path:"error-handling" module:"openconfig-bgp"`
	ΛErrorHandling          []ygot.Annotation                                            `path:"@error-handling" ygotAnnotation:"true"`
	EstablishedTransitions  *uint64                                                      `path:"state/established-transitions" module:"openconfig-bgp"`
	ΛEstablishedTransitions []ygot.Annotation                                            `path:"state/@established-transitions" ygotAnnotation:"true"`
	GracefulRestart         *Bgp_Neighbor_GracefulRestart                                `path:"graceful-restart" module:"openconfig-bgp"`
	ΛGracefulRestart        []ygot.Annotation                                            `path:"@graceful-restart" ygotAnnotation:"true"`
	LastEstablished         *uint64                                                      `path:"state/last-established" module:"openconfig-bgp"`
	ΛLastEstablished        []ygot.Annotation                                            `path:"state/@last-established" ygotAnnotation:"true"`
	LocalAs                 *uint32                                                      `path:"state/local-as" shadow-path:"config/local-as" module:"openconfig-bgp"`
	ΛLocalAs                []ygot.Annotation                                            `path:"state/@local-as" ygotAnnotation:"true"`
	LoggingOptions          *Bgp_Neighbor_LoggingOptions                                 `path:"logging-options" module:"openconfig-bgp"`
	ΛLoggingOptions         []ygot.Annotation                                            `path:"@logging-options" ygotAnnotation:"true"`
	Messages                *Bgp_Neighbor_Messages                                       `path:"state/messages" module:"openconfig-bgp"`
	ΛMessages               []ygot.Annotation                                            `path:"state/@messages" ygotAnnotation:"true"`
	NeighborAddress         *string                                                      `path:"state/neighbor-address|neighbor-address" shadow-path:"config/neighbor-address" module:"openconfig-bgp"`
	ΛNeighborAddress        []ygot.Annotation                                            `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
	PeerAs                  *uint32                                                      `path:"state/peer-as" shadow-path:"config/peer-as" module:"openconfig-bgp"`
	ΛPeerAs                 []ygot.Annotation                                            `path:"state/@peer-as" ygotAnnotation:"true"`
	PeerGroup               *string                                                      `path:"state/peer-group" shadow-path:"config/peer-group" module:"openconfig-bgp"`
	ΛPeerGroup              []ygot.Annotation                                            `path:"state/@peer-group" ygotAnnotation:"true"`
	PeerType                E_OpenconfigBgpTypes_PeerType                                `path:"state/peer-type" shadow-path:"config/peer-type" module:"openconfig-bgp"`
	ΛPeerType               []ygot.Annotation                                            `path:"state/@peer-type" ygotAnnotation:"true"`
	Queues                  *Bgp_Neighbor_Queues                                         `path:"state/queues" module:"openconfig-bgp"`
	ΛQueues                 []ygot.Annotation                                            `path:"state/@queues" ygotAnnotation:"true"`
	RemovePrivateAs         E_OpenconfigBgpTypes_RemovePrivateAsOption                   `path:"state/remove-private-as" shadow-path:"config/remove-private-as" module:"openconfig-bgp"`
	ΛRemovePrivateAs        []ygot.Annotation                                            `path:"state/@remove-private-as" ygotAnnotation:"true"`
	RouteFlapDamping        *bool                                                        `path:"state/route-flap-damping" shadow-path:"config/route-flap-damping" module:"openconfig-bgp"`
	ΛRouteFlapDamping       []ygot.Annotation                                            `path:"state/@route-flap-damping" ygotAnnotation:"true"`
	RouteReflector          *Bgp_Neighbor_RouteReflector                                 `path:"route-reflector" module:"openconfig-bgp"`
	ΛRouteReflector         []ygot.Annotation                                            `path:"@route-reflector" ygotAnnotation:"true"`
	SendCommunity           E_OpenconfigBgpTypes_CommunityType                           `path:"state/send-community" shadow-path:"config/send-community" module:"openconfig-bgp"`
	ΛSendCommunity          []ygot.Annotation                                            `path:"state/@send-community" ygotAnnotation:"true"`
	SessionState            E_Neighbor_SessionState                                      `path:"state/session-state" module:"openconfig-bgp"`
	ΛSessionState           []ygot.Annotation                                            `path:"state/@session-state" ygotAnnotation:"true"`
	SupportedCapabilities   []E_OpenconfigBgpTypes_BGP_CAPABILITY                        `path:"state/supported-capabilities" module:"openconfig-bgp"`
	ΛSupportedCapabilities  []ygot.Annotation                                            `path:"state/@supported-capabilities" ygotAnnotation:"true"`
	Timers                  *Bgp_Neighbor_Timers                                         `path:"timers" module:"openconfig-bgp"`
	ΛTimers                 []ygot.Annotation                                            `path:"@timers" ygotAnnotation:"true"`
	Transport               *Bgp_Neighbor_Transport                                      `path:"transport" module:"openconfig-bgp"`
	ΛTransport              []ygot.Annotation                                            `path:"@transport" ygotAnnotation:"true"`
	UseMultiplePaths        *Bgp_Neighbor_UseMultiplePaths                               `path:"use-multiple-paths" module:"openconfig-bgp"`
	ΛUseMultiplePaths       []ygot.Annotation                                            `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// Bgp_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Neighbor) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*Bgp_Neighbor_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Neighbor_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &Bgp_Neighbor_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the Bgp_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Neighbor) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver Bgp_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Neighbor) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_Neighbor_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of Bgp_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Neighbor) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_Neighbor_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied Bgp_Neighbor_AfiSafi struct to the
// list AfiSafi of Bgp_Neighbor. If the key value(s) specified in
// the supplied Bgp_Neighbor_AfiSafi already exist in the list, an error is
// returned.
func (t *Bgp_Neighbor) AppendAfiSafi(v *Bgp_Neighbor_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Neighbor_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateApplyPolicy() *Bgp_Neighbor_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &Bgp_Neighbor_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateAsPathOptions retrieves the value of the AsPathOptions field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateAsPathOptions() *Bgp_Neighbor_AsPathOptions {
	if t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	t.AsPathOptions = &Bgp_Neighbor_AsPathOptions{}
	return t.AsPathOptions
}

// GetOrCreateEbgpMultihop retrieves the value of the EbgpMultihop field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateEbgpMultihop() *Bgp_Neighbor_EbgpMultihop {
	if t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	t.EbgpMultihop = &Bgp_Neighbor_EbgpMultihop{}
	return t.EbgpMultihop
}

// GetOrCreateErrorHandling retrieves the value of the ErrorHandling field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateErrorHandling() *Bgp_Neighbor_ErrorHandling {
	if t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	t.ErrorHandling = &Bgp_Neighbor_ErrorHandling{}
	return t.ErrorHandling
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateGracefulRestart() *Bgp_Neighbor_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &Bgp_Neighbor_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateLoggingOptions retrieves the value of the LoggingOptions field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateLoggingOptions() *Bgp_Neighbor_LoggingOptions {
	if t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	t.LoggingOptions = &Bgp_Neighbor_LoggingOptions{}
	return t.LoggingOptions
}

// GetOrCreateMessages retrieves the value of the Messages field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateMessages() *Bgp_Neighbor_Messages {
	if t.Messages != nil {
		return t.Messages
	}
	t.Messages = &Bgp_Neighbor_Messages{}
	return t.Messages
}

// GetOrCreateQueues retrieves the value of the Queues field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateQueues() *Bgp_Neighbor_Queues {
	if t.Queues != nil {
		return t.Queues
	}
	t.Queues = &Bgp_Neighbor_Queues{}
	return t.Queues
}

// GetOrCreateRouteReflector retrieves the value of the RouteReflector field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateRouteReflector() *Bgp_Neighbor_RouteReflector {
	if t.RouteReflector != nil {
		return t.RouteReflector
	}
	t.RouteReflector = &Bgp_Neighbor_RouteReflector{}
	return t.RouteReflector
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateTimers() *Bgp_Neighbor_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &Bgp_Neighbor_Timers{}
	return t.Timers
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateTransport() *Bgp_Neighbor_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &Bgp_Neighbor_Transport{}
	return t.Transport
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor) GetOrCreateUseMultiplePaths() *Bgp_Neighbor_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &Bgp_Neighbor_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from Bgp_Neighbor. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetApplyPolicy() *Bgp_Neighbor_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetAsPathOptions returns the value of the AsPathOptions struct pointer
// from Bgp_Neighbor. If the receiver or the field AsPathOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetAsPathOptions() *Bgp_Neighbor_AsPathOptions {
	if t != nil && t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	return nil
}

// GetEbgpMultihop returns the value of the EbgpMultihop struct pointer
// from Bgp_Neighbor. If the receiver or the field EbgpMultihop is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetEbgpMultihop() *Bgp_Neighbor_EbgpMultihop {
	if t != nil && t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	return nil
}

// GetErrorHandling returns the value of the ErrorHandling struct pointer
// from Bgp_Neighbor. If the receiver or the field ErrorHandling is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetErrorHandling() *Bgp_Neighbor_ErrorHandling {
	if t != nil && t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from Bgp_Neighbor. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetGracefulRestart() *Bgp_Neighbor_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetLoggingOptions returns the value of the LoggingOptions struct pointer
// from Bgp_Neighbor. If the receiver or the field LoggingOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetLoggingOptions() *Bgp_Neighbor_LoggingOptions {
	if t != nil && t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	return nil
}

// GetMessages returns the value of the Messages struct pointer
// from Bgp_Neighbor. If the receiver or the field Messages is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetMessages() *Bgp_Neighbor_Messages {
	if t != nil && t.Messages != nil {
		return t.Messages
	}
	return nil
}

// GetQueues returns the value of the Queues struct pointer
// from Bgp_Neighbor. If the receiver or the field Queues is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetQueues() *Bgp_Neighbor_Queues {
	if t != nil && t.Queues != nil {
		return t.Queues
	}
	return nil
}

// GetRouteReflector returns the value of the RouteReflector struct pointer
// from Bgp_Neighbor. If the receiver or the field RouteReflector is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetRouteReflector() *Bgp_Neighbor_RouteReflector {
	if t != nil && t.RouteReflector != nil {
		return t.RouteReflector
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from Bgp_Neighbor. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetTimers() *Bgp_Neighbor_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from Bgp_Neighbor. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetTransport() *Bgp_Neighbor_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from Bgp_Neighbor. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor) GetUseMultiplePaths() *Bgp_Neighbor_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// GetDescription retrieves the value of the leaf Description from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetDynamicallyConfigured retrieves the value of the leaf DynamicallyConfigured from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DynamicallyConfigured is set, it can safely use t.GetDynamicallyConfigured()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DynamicallyConfigured == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetDynamicallyConfigured() bool {
	if t == nil || t.DynamicallyConfigured == nil {
		return false
	}
	return *t.DynamicallyConfigured
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetEstablishedTransitions retrieves the value of the leaf EstablishedTransitions from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EstablishedTransitions is set, it can safely use t.GetEstablishedTransitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EstablishedTransitions == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetEstablishedTransitions() uint64 {
	if t == nil || t.EstablishedTransitions == nil {
		return 0
	}
	return *t.EstablishedTransitions
}

// GetLastEstablished retrieves the value of the leaf LastEstablished from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastEstablished is set, it can safely use t.GetLastEstablished()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastEstablished == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetLastEstablished() uint64 {
	if t == nil || t.LastEstablished == nil {
		return 0
	}
	return *t.LastEstablished
}

// GetLocalAs retrieves the value of the leaf LocalAs from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAs is set, it can safely use t.GetLocalAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetLocalAs() uint32 {
	if t == nil || t.LocalAs == nil {
		return 0
	}
	return *t.LocalAs
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// GetPeerAs retrieves the value of the leaf PeerAs from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerAs is set, it can safely use t.GetPeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetPeerAs() uint32 {
	if t == nil || t.PeerAs == nil {
		return 0
	}
	return *t.PeerAs
}

// GetPeerGroup retrieves the value of the leaf PeerGroup from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerGroup is set, it can safely use t.GetPeerGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerGroup == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetPeerGroup() string {
	if t == nil || t.PeerGroup == nil {
		return ""
	}
	return *t.PeerGroup
}

// GetPeerType retrieves the value of the leaf PeerType from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerType is set, it can safely use t.GetPeerType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetPeerType() E_OpenconfigBgpTypes_PeerType {
	if t == nil || t.PeerType == 0 {
		return 0
	}
	return t.PeerType
}

// GetRemovePrivateAs retrieves the value of the leaf RemovePrivateAs from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemovePrivateAs is set, it can safely use t.GetRemovePrivateAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemovePrivateAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetRemovePrivateAs() E_OpenconfigBgpTypes_RemovePrivateAsOption {
	if t == nil || t.RemovePrivateAs == 0 {
		return 0
	}
	return t.RemovePrivateAs
}

// GetRouteFlapDamping retrieves the value of the leaf RouteFlapDamping from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteFlapDamping is set, it can safely use t.GetRouteFlapDamping()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteFlapDamping == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetRouteFlapDamping() bool {
	if t == nil || t.RouteFlapDamping == nil {
		return false
	}
	return *t.RouteFlapDamping
}

// GetSendCommunity retrieves the value of the leaf SendCommunity from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendCommunity is set, it can safely use t.GetSendCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendCommunity == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetSendCommunity() E_OpenconfigBgpTypes_CommunityType {
	if t == nil || t.SendCommunity == 0 {
		return OpenconfigBgpTypes_CommunityType_NONE
	}
	return t.SendCommunity
}

// GetSessionState retrieves the value of the leaf SessionState from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SessionState is set, it can safely use t.GetSessionState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SessionState == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetSessionState() E_Neighbor_SessionState {
	if t == nil || t.SessionState == 0 {
		return 0
	}
	return t.SessionState
}

// GetSupportedCapabilities retrieves the value of the leaf SupportedCapabilities from the Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SupportedCapabilities is set, it can safely use t.GetSupportedCapabilities()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SupportedCapabilities == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor) GetSupportedCapabilities() []E_OpenconfigBgpTypes_BGP_CAPABILITY {
	if t == nil || t.SupportedCapabilities == nil {
		return nil
	}
	return t.SupportedCapabilities
}

// ΛListKeyMap returns the keys of the Bgp_Neighbor struct, which is a YANG list entry.
func (t *Bgp_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_AfiSafi represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi YANG schema element.
type Bgp_Neighbor_AfiSafi struct {
	ΛMetadata           []ygot.Annotation                        `path:"@" ygotAnnotation:"true"`
	Active              *bool                                    `path:"state/active" module:"openconfig-bgp"`
	ΛActive             []ygot.Annotation                        `path:"state/@active" ygotAnnotation:"true"`
	AddPaths            *Bgp_Neighbor_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-bgp"`
	ΛAddPaths           []ygot.Annotation                        `path:"@add-paths" ygotAnnotation:"true"`
	AfiSafiName         E_OpenconfigBgpTypes_AFI_SAFI_TYPE       `path:"state/afi-safi-name|afi-safi-name" shadow-path:"config/afi-safi-name" module:"openconfig-bgp"`
	ΛAfiSafiName        []ygot.Annotation                        `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	ApplyPolicy         *Bgp_Neighbor_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-bgp"`
	ΛApplyPolicy        []ygot.Annotation                        `path:"@apply-policy" ygotAnnotation:"true"`
	Enabled             *bool                                    `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled            []ygot.Annotation                        `path:"state/@enabled" ygotAnnotation:"true"`
	GracefulRestart     *Bgp_Neighbor_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-bgp"`
	ΛGracefulRestart    []ygot.Annotation                        `path:"@graceful-restart" ygotAnnotation:"true"`
	Ipv4LabeledUnicast  *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-bgp"`
	ΛIpv4LabeledUnicast []ygot.Annotation                        `path:"@ipv4-labeled-unicast" ygotAnnotation:"true"`
	Ipv4Unicast         *Bgp_Neighbor_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-bgp"`
	ΛIpv4Unicast        []ygot.Annotation                        `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6LabeledUnicast  *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-bgp"`
	ΛIpv6LabeledUnicast []ygot.Annotation                        `path:"@ipv6-labeled-unicast" ygotAnnotation:"true"`
	Ipv6Unicast         *Bgp_Neighbor_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-bgp"`
	ΛIpv6Unicast        []ygot.Annotation                        `path:"@ipv6-unicast" ygotAnnotation:"true"`
	L2VpnEvpn           *Bgp_Neighbor_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-bgp"`
	ΛL2VpnEvpn          []ygot.Annotation                        `path:"@l2vpn-evpn" ygotAnnotation:"true"`
	L2VpnVpls           *Bgp_Neighbor_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-bgp"`
	ΛL2VpnVpls          []ygot.Annotation                        `path:"@l2vpn-vpls" ygotAnnotation:"true"`
	L3VpnIpv4Multicast  *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-bgp"`
	ΛL3VpnIpv4Multicast []ygot.Annotation                        `path:"@l3vpn-ipv4-multicast" ygotAnnotation:"true"`
	L3VpnIpv4Unicast    *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-bgp"`
	ΛL3VpnIpv4Unicast   []ygot.Annotation                        `path:"@l3vpn-ipv4-unicast" ygotAnnotation:"true"`
	L3VpnIpv6Multicast  *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-bgp"`
	ΛL3VpnIpv6Multicast []ygot.Annotation                        `path:"@l3vpn-ipv6-multicast" ygotAnnotation:"true"`
	L3VpnIpv6Unicast    *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-bgp"`
	ΛL3VpnIpv6Unicast   []ygot.Annotation                        `path:"@l3vpn-ipv6-unicast" ygotAnnotation:"true"`
	Prefixes            *Bgp_Neighbor_AfiSafi_Prefixes           `path:"state/prefixes" module:"openconfig-bgp"`
	ΛPrefixes           []ygot.Annotation                        `path:"state/@prefixes" ygotAnnotation:"true"`
	SrtePolicyIpv4      *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-bgp"`
	ΛSrtePolicyIpv4     []ygot.Annotation                        `path:"@srte-policy-ipv4" ygotAnnotation:"true"`
	SrtePolicyIpv6      *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-bgp"`
	ΛSrtePolicyIpv6     []ygot.Annotation                        `path:"@srte-policy-ipv6" ygotAnnotation:"true"`
	UseMultiplePaths    *Bgp_Neighbor_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-bgp"`
	ΛUseMultiplePaths   []ygot.Annotation                        `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateAddPaths retrieves the value of the AddPaths field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateAddPaths() *Bgp_Neighbor_AfiSafi_AddPaths {
	if t.AddPaths != nil {
		return t.AddPaths
	}
	t.AddPaths = &Bgp_Neighbor_AfiSafi_AddPaths{}
	return t.AddPaths
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateApplyPolicy() *Bgp_Neighbor_AfiSafi_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &Bgp_Neighbor_AfiSafi_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateGracefulRestart() *Bgp_Neighbor_AfiSafi_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &Bgp_Neighbor_AfiSafi_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateIpv4LabeledUnicast retrieves the value of the Ipv4LabeledUnicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateIpv4LabeledUnicast() *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast {
	if t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	t.Ipv4LabeledUnicast = &Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast{}
	return t.Ipv4LabeledUnicast
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateIpv4Unicast() *Bgp_Neighbor_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &Bgp_Neighbor_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6LabeledUnicast retrieves the value of the Ipv6LabeledUnicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateIpv6LabeledUnicast() *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast {
	if t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	t.Ipv6LabeledUnicast = &Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast{}
	return t.Ipv6LabeledUnicast
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateIpv6Unicast() *Bgp_Neighbor_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &Bgp_Neighbor_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetOrCreateL2VpnEvpn retrieves the value of the L2VpnEvpn field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateL2VpnEvpn() *Bgp_Neighbor_AfiSafi_L2VpnEvpn {
	if t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	t.L2VpnEvpn = &Bgp_Neighbor_AfiSafi_L2VpnEvpn{}
	return t.L2VpnEvpn
}

// GetOrCreateL2VpnVpls retrieves the value of the L2VpnVpls field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateL2VpnVpls() *Bgp_Neighbor_AfiSafi_L2VpnVpls {
	if t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	t.L2VpnVpls = &Bgp_Neighbor_AfiSafi_L2VpnVpls{}
	return t.L2VpnVpls
}

// GetOrCreateL3VpnIpv4Multicast retrieves the value of the L3VpnIpv4Multicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv4Multicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast {
	if t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	t.L3VpnIpv4Multicast = &Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast{}
	return t.L3VpnIpv4Multicast
}

// GetOrCreateL3VpnIpv4Unicast retrieves the value of the L3VpnIpv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv4Unicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast {
	if t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	t.L3VpnIpv4Unicast = &Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast{}
	return t.L3VpnIpv4Unicast
}

// GetOrCreateL3VpnIpv6Multicast retrieves the value of the L3VpnIpv6Multicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv6Multicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast {
	if t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	t.L3VpnIpv6Multicast = &Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast{}
	return t.L3VpnIpv6Multicast
}

// GetOrCreateL3VpnIpv6Unicast retrieves the value of the L3VpnIpv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv6Unicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast {
	if t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	t.L3VpnIpv6Unicast = &Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast{}
	return t.L3VpnIpv6Unicast
}

// GetOrCreatePrefixes retrieves the value of the Prefixes field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreatePrefixes() *Bgp_Neighbor_AfiSafi_Prefixes {
	if t.Prefixes != nil {
		return t.Prefixes
	}
	t.Prefixes = &Bgp_Neighbor_AfiSafi_Prefixes{}
	return t.Prefixes
}

// GetOrCreateSrtePolicyIpv4 retrieves the value of the SrtePolicyIpv4 field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateSrtePolicyIpv4() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 {
	if t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	t.SrtePolicyIpv4 = &Bgp_Neighbor_AfiSafi_SrtePolicyIpv4{}
	return t.SrtePolicyIpv4
}

// GetOrCreateSrtePolicyIpv6 retrieves the value of the SrtePolicyIpv6 field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateSrtePolicyIpv6() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 {
	if t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	t.SrtePolicyIpv6 = &Bgp_Neighbor_AfiSafi_SrtePolicyIpv6{}
	return t.SrtePolicyIpv6
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi) GetOrCreateUseMultiplePaths() *Bgp_Neighbor_AfiSafi_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &Bgp_Neighbor_AfiSafi_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetAddPaths returns the value of the AddPaths struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field AddPaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetAddPaths() *Bgp_Neighbor_AfiSafi_AddPaths {
	if t != nil && t.AddPaths != nil {
		return t.AddPaths
	}
	return nil
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetApplyPolicy() *Bgp_Neighbor_AfiSafi_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetGracefulRestart() *Bgp_Neighbor_AfiSafi_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetIpv4LabeledUnicast returns the value of the Ipv4LabeledUnicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv4LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetIpv4LabeledUnicast() *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast {
	if t != nil && t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetIpv4Unicast() *Bgp_Neighbor_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6LabeledUnicast returns the value of the Ipv6LabeledUnicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv6LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetIpv6LabeledUnicast() *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast {
	if t != nil && t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetIpv6Unicast() *Bgp_Neighbor_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetL2VpnEvpn returns the value of the L2VpnEvpn struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field L2VpnEvpn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetL2VpnEvpn() *Bgp_Neighbor_AfiSafi_L2VpnEvpn {
	if t != nil && t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	return nil
}

// GetL2VpnVpls returns the value of the L2VpnVpls struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field L2VpnVpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetL2VpnVpls() *Bgp_Neighbor_AfiSafi_L2VpnVpls {
	if t != nil && t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	return nil
}

// GetL3VpnIpv4Multicast returns the value of the L3VpnIpv4Multicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv4Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetL3VpnIpv4Multicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast {
	if t != nil && t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	return nil
}

// GetL3VpnIpv4Unicast returns the value of the L3VpnIpv4Unicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetL3VpnIpv4Unicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast {
	if t != nil && t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	return nil
}

// GetL3VpnIpv6Multicast returns the value of the L3VpnIpv6Multicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv6Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetL3VpnIpv6Multicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast {
	if t != nil && t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	return nil
}

// GetL3VpnIpv6Unicast returns the value of the L3VpnIpv6Unicast struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetL3VpnIpv6Unicast() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast {
	if t != nil && t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	return nil
}

// GetPrefixes returns the value of the Prefixes struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field Prefixes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetPrefixes() *Bgp_Neighbor_AfiSafi_Prefixes {
	if t != nil && t.Prefixes != nil {
		return t.Prefixes
	}
	return nil
}

// GetSrtePolicyIpv4 returns the value of the SrtePolicyIpv4 struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field SrtePolicyIpv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetSrtePolicyIpv4() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 {
	if t != nil && t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	return nil
}

// GetSrtePolicyIpv6 returns the value of the SrtePolicyIpv6 struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field SrtePolicyIpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetSrtePolicyIpv6() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 {
	if t != nil && t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from Bgp_Neighbor_AfiSafi. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi) GetUseMultiplePaths() *Bgp_Neighbor_AfiSafi_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetActive retrieves the value of the leaf Active from the Bgp_Neighbor_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the Bgp_Neighbor_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// ΛListKeyMap returns the keys of the Bgp_Neighbor_AfiSafi struct, which is a YANG list entry.
func (t *Bgp_Neighbor_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_AfiSafi_AddPaths represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths YANG schema element.
type Bgp_Neighbor_AfiSafi_AddPaths struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EligiblePrefixPolicy  *string           `path:"state/eligible-prefix-policy" shadow-path:"config/eligible-prefix-policy" module:"openconfig-bgp"`
	ΛEligiblePrefixPolicy []ygot.Annotation `path:"state/@eligible-prefix-policy" ygotAnnotation:"true"`
	Receive               *bool             `path:"state/receive" shadow-path:"config/receive" module:"openconfig-bgp"`
	ΛReceive              []ygot.Annotation `path:"state/@receive" ygotAnnotation:"true"`
	Send                  *bool             `path:"state/send" shadow-path:"config/send" module:"openconfig-bgp"`
	ΛSend                 []ygot.Annotation `path:"state/@send" ygotAnnotation:"true"`
	SendMax               *uint8            `path:"state/send-max" shadow-path:"config/send-max" module:"openconfig-bgp"`
	ΛSendMax              []ygot.Annotation `path:"state/@send-max" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_AddPaths) IsYANGGoStruct() {}

// GetEligiblePrefixPolicy retrieves the value of the leaf EligiblePrefixPolicy from the Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EligiblePrefixPolicy is set, it can safely use t.GetEligiblePrefixPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EligiblePrefixPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_AddPaths) GetEligiblePrefixPolicy() string {
	if t == nil || t.EligiblePrefixPolicy == nil {
		return ""
	}
	return *t.EligiblePrefixPolicy
}

// GetReceive retrieves the value of the leaf Receive from the Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Receive is set, it can safely use t.GetReceive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Receive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_AddPaths) GetReceive() bool {
	if t == nil || t.Receive == nil {
		return false
	}
	return *t.Receive
}

// GetSend retrieves the value of the leaf Send from the Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Send is set, it can safely use t.GetSend()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Send == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_AddPaths) GetSend() bool {
	if t == nil || t.Send == nil {
		return false
	}
	return *t.Send
}

// GetSendMax retrieves the value of the leaf SendMax from the Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendMax is set, it can safely use t.GetSendMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendMax == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_AddPaths) GetSendMax() uint8 {
	if t == nil || t.SendMax == nil {
		return 0
	}
	return *t.SendMax
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_AfiSafi_ApplyPolicy represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy YANG schema element.
type Bgp_Neighbor_AfiSafi_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-bgp"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-bgp"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-bgp"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-bgp"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_GracefulRestart represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart YANG schema element.
type Bgp_Neighbor_AfiSafi_GracefulRestart struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Advertised  *bool             `path:"state/advertised" module:"openconfig-bgp"`
	ΛAdvertised []ygot.Annotation `path:"state/@advertised" ygotAnnotation:"true"`
	Enabled     *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled    []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	Received    *bool             `path:"state/received" module:"openconfig-bgp"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// GetAdvertised retrieves the value of the leaf Advertised from the Bgp_Neighbor_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Advertised is set, it can safely use t.GetAdvertised()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Advertised == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_GracefulRestart) GetAdvertised() bool {
	if t == nil || t.Advertised == nil {
		return false
	}
	return *t.Advertised
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetReceived retrieves the value of the leaf Received from the Bgp_Neighbor_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_GracefulRestart) GetReceived() bool {
	if t == nil || t.Received == nil {
		return false
	}
	return *t.Received
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                    `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv4Unicast struct {
	ΛMetadata         []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit      []ygot.Annotation                             `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                         `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-bgp"`
	ΛSendDefaultRoute []ygot.Annotation                             `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_Ipv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the Bgp_Neighbor_AfiSafi_Ipv4Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                    `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv6Unicast struct {
	ΛMetadata         []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit      []ygot.Annotation                             `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                         `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-bgp"`
	ΛSendDefaultRoute []ygot.Annotation                             `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_Ipv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the Bgp_Neighbor_AfiSafi_Ipv6Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L2VpnEvpn represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type Bgp_Neighbor_AfiSafi_L2VpnEvpn struct {
	ΛMetadata    []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_L2VpnEvpn. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L2VpnVpls represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type Bgp_Neighbor_AfiSafi_L2VpnVpls struct {
	ΛMetadata    []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_L2VpnVpls. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast struct {
	ΛMetadata    []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                    `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast struct {
	ΛMetadata    []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                    `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_Prefixes represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/state/prefixes YANG schema element.
type Bgp_Neighbor_AfiSafi_Prefixes struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Installed          *uint32           `path:"installed" module:"openconfig-bgp"`
	ΛInstalled         []ygot.Annotation `path:"@installed" ygotAnnotation:"true"`
	Received           *uint32           `path:"received" module:"openconfig-bgp"`
	ΛReceived          []ygot.Annotation `path:"@received" ygotAnnotation:"true"`
	ReceivedPrePolicy  *uint32           `path:"received-pre-policy" module:"openconfig-bgp"`
	ΛReceivedPrePolicy []ygot.Annotation `path:"@received-pre-policy" ygotAnnotation:"true"`
	Sent               *uint32           `path:"sent" module:"openconfig-bgp"`
	ΛSent              []ygot.Annotation `path:"@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_Prefixes) IsYANGGoStruct() {}

// GetInstalled retrieves the value of the leaf Installed from the Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Installed is set, it can safely use t.GetInstalled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Installed == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Prefixes) GetInstalled() uint32 {
	if t == nil || t.Installed == nil {
		return 0
	}
	return *t.Installed
}

// GetReceived retrieves the value of the leaf Received from the Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Prefixes) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetReceivedPrePolicy retrieves the value of the leaf ReceivedPrePolicy from the Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReceivedPrePolicy is set, it can safely use t.GetReceivedPrePolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReceivedPrePolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Prefixes) GetReceivedPrePolicy() uint32 {
	if t == nil || t.ReceivedPrePolicy == nil {
		return 0
	}
	return *t.ReceivedPrePolicy
}

// GetSent retrieves the value of the leaf Sent from the Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_Prefixes) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 struct {
	ΛMetadata    []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_SrtePolicyIpv4. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 struct {
	ΛMetadata    []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) GetOrCreatePrefixLimit() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_Neighbor_AfiSafi_SrtePolicyIpv6. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) GetPrefixLimit() *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_UseMultiplePaths represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type Bgp_Neighbor_AfiSafi_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	Ebgp      *Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-bgp"`
	ΛEbgp     []ygot.Annotation                           `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                       `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation                           `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths) GetOrCreateEbgp() *Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from Bgp_Neighbor_AfiSafi_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths) GetEbgp() *Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor_AfiSafi_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-bgp"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_ApplyPolicy represents the /openconfig-bgp/bgp/neighbors/neighbor/apply-policy YANG schema element.
type Bgp_Neighbor_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-bgp"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-bgp"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-bgp"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-bgp"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_AsPathOptions represents the /openconfig-bgp/bgp/neighbors/neighbor/as-path-options YANG schema element.
type Bgp_Neighbor_AsPathOptions struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowOwnAs           *uint8            `path:"state/allow-own-as" shadow-path:"config/allow-own-as" module:"openconfig-bgp"`
	ΛAllowOwnAs          []ygot.Annotation `path:"state/@allow-own-as" ygotAnnotation:"true"`
	DisablePeerAsFilter  *bool             `path:"state/disable-peer-as-filter" shadow-path:"config/disable-peer-as-filter" module:"openconfig-bgp"`
	ΛDisablePeerAsFilter []ygot.Annotation `path:"state/@disable-peer-as-filter" ygotAnnotation:"true"`
	ReplacePeerAs        *bool             `path:"state/replace-peer-as" shadow-path:"config/replace-peer-as" module:"openconfig-bgp"`
	ΛReplacePeerAs       []ygot.Annotation `path:"state/@replace-peer-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_AsPathOptions) IsYANGGoStruct() {}

// GetAllowOwnAs retrieves the value of the leaf AllowOwnAs from the Bgp_Neighbor_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowOwnAs is set, it can safely use t.GetAllowOwnAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowOwnAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AsPathOptions) GetAllowOwnAs() uint8 {
	if t == nil || t.AllowOwnAs == nil {
		return 0
	}
	return *t.AllowOwnAs
}

// GetDisablePeerAsFilter retrieves the value of the leaf DisablePeerAsFilter from the Bgp_Neighbor_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DisablePeerAsFilter is set, it can safely use t.GetDisablePeerAsFilter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DisablePeerAsFilter == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AsPathOptions) GetDisablePeerAsFilter() bool {
	if t == nil || t.DisablePeerAsFilter == nil {
		return false
	}
	return *t.DisablePeerAsFilter
}

// GetReplacePeerAs retrieves the value of the leaf ReplacePeerAs from the Bgp_Neighbor_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReplacePeerAs is set, it can safely use t.GetReplacePeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReplacePeerAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_AsPathOptions) GetReplacePeerAs() bool {
	if t == nil || t.ReplacePeerAs == nil {
		return false
	}
	return *t.ReplacePeerAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_EbgpMultihop represents the /openconfig-bgp/bgp/neighbors/neighbor/ebgp-multihop YANG schema element.
type Bgp_Neighbor_EbgpMultihop struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled      *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled     []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	MultihopTtl  *uint8            `path:"state/multihop-ttl" shadow-path:"config/multihop-ttl" module:"openconfig-bgp"`
	ΛMultihopTtl []ygot.Annotation `path:"state/@multihop-ttl" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_EbgpMultihop) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_EbgpMultihop) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetMultihopTtl retrieves the value of the leaf MultihopTtl from the Bgp_Neighbor_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultihopTtl is set, it can safely use t.GetMultihopTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultihopTtl == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_EbgpMultihop) GetMultihopTtl() uint8 {
	if t == nil || t.MultihopTtl == nil {
		return 0
	}
	return *t.MultihopTtl
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_ErrorHandling represents the /openconfig-bgp/bgp/neighbors/neighbor/error-handling YANG schema element.
type Bgp_Neighbor_ErrorHandling struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ErroneousUpdateMessages  *uint32           `path:"state/erroneous-update-messages" module:"openconfig-bgp"`
	ΛErroneousUpdateMessages []ygot.Annotation `path:"state/@erroneous-update-messages" ygotAnnotation:"true"`
	TreatAsWithdraw          *bool             `path:"state/treat-as-withdraw" shadow-path:"config/treat-as-withdraw" module:"openconfig-bgp"`
	ΛTreatAsWithdraw         []ygot.Annotation `path:"state/@treat-as-withdraw" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_ErrorHandling) IsYANGGoStruct() {}

// GetErroneousUpdateMessages retrieves the value of the leaf ErroneousUpdateMessages from the Bgp_Neighbor_ErrorHandling
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ErroneousUpdateMessages is set, it can safely use t.GetErroneousUpdateMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ErroneousUpdateMessages == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_ErrorHandling) GetErroneousUpdateMessages() uint32 {
	if t == nil || t.ErroneousUpdateMessages == nil {
		return 0
	}
	return *t.ErroneousUpdateMessages
}

// GetTreatAsWithdraw retrieves the value of the leaf TreatAsWithdraw from the Bgp_Neighbor_ErrorHandling
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TreatAsWithdraw is set, it can safely use t.GetTreatAsWithdraw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TreatAsWithdraw == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_ErrorHandling) GetTreatAsWithdraw() bool {
	if t == nil || t.TreatAsWithdraw == nil {
		return false
	}
	return *t.TreatAsWithdraw
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_GracefulRestart represents the /openconfig-bgp/bgp/neighbors/neighbor/graceful-restart YANG schema element.
type Bgp_Neighbor_GracefulRestart struct {
	ΛMetadata        []ygot.Annotation      `path:"@" ygotAnnotation:"true"`
	Enabled          *bool                  `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled         []ygot.Annotation      `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly       *bool                  `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-bgp"`
	ΛHelperOnly      []ygot.Annotation      `path:"state/@helper-only" ygotAnnotation:"true"`
	LocalRestarting  *bool                  `path:"state/local-restarting" module:"openconfig-bgp"`
	ΛLocalRestarting []ygot.Annotation      `path:"state/@local-restarting" ygotAnnotation:"true"`
	Mode             E_GracefulRestart_Mode `path:"state/mode" module:"openconfig-bgp"`
	ΛMode            []ygot.Annotation      `path:"state/@mode" ygotAnnotation:"true"`
	PeerRestartTime  *uint16                `path:"state/peer-restart-time" module:"openconfig-bgp"`
	ΛPeerRestartTime []ygot.Annotation      `path:"state/@peer-restart-time" ygotAnnotation:"true"`
	PeerRestarting   *bool                  `path:"state/peer-restarting" module:"openconfig-bgp"`
	ΛPeerRestarting  []ygot.Annotation      `path:"state/@peer-restarting" ygotAnnotation:"true"`
	RestartTime      *uint16                `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-bgp"`
	ΛRestartTime     []ygot.Annotation      `path:"state/@restart-time" ygotAnnotation:"true"`
	StaleRoutesTime  *float64               `path:"state/stale-routes-time" shadow-path:"config/stale-routes-time" module:"openconfig-bgp"`
	ΛStaleRoutesTime []ygot.Annotation      `path:"state/@stale-routes-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// GetLocalRestarting retrieves the value of the leaf LocalRestarting from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalRestarting is set, it can safely use t.GetLocalRestarting()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalRestarting == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetLocalRestarting() bool {
	if t == nil || t.LocalRestarting == nil {
		return false
	}
	return *t.LocalRestarting
}

// GetMode retrieves the value of the leaf Mode from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetMode() E_GracefulRestart_Mode {
	if t == nil || t.Mode == 0 {
		return 0
	}
	return t.Mode
}

// GetPeerRestartTime retrieves the value of the leaf PeerRestartTime from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerRestartTime is set, it can safely use t.GetPeerRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerRestartTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetPeerRestartTime() uint16 {
	if t == nil || t.PeerRestartTime == nil {
		return 0
	}
	return *t.PeerRestartTime
}

// GetPeerRestarting retrieves the value of the leaf PeerRestarting from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerRestarting is set, it can safely use t.GetPeerRestarting()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerRestarting == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetPeerRestarting() bool {
	if t == nil || t.PeerRestarting == nil {
		return false
	}
	return *t.PeerRestarting
}

// GetRestartTime retrieves the value of the leaf RestartTime from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetRestartTime() uint16 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// GetStaleRoutesTime retrieves the value of the leaf StaleRoutesTime from the Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StaleRoutesTime is set, it can safely use t.GetStaleRoutesTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StaleRoutesTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_GracefulRestart) GetStaleRoutesTime() float64 {
	if t == nil || t.StaleRoutesTime == nil {
		return 0.0
	}
	return *t.StaleRoutesTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_LoggingOptions represents the /openconfig-bgp/bgp/neighbors/neighbor/logging-options YANG schema element.
type Bgp_Neighbor_LoggingOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LogNeighborStateChanges  *bool             `path:"state/log-neighbor-state-changes" shadow-path:"config/log-neighbor-state-changes" module:"openconfig-bgp"`
	ΛLogNeighborStateChanges []ygot.Annotation `path:"state/@log-neighbor-state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_LoggingOptions) IsYANGGoStruct() {}

// GetLogNeighborStateChanges retrieves the value of the leaf LogNeighborStateChanges from the Bgp_Neighbor_LoggingOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogNeighborStateChanges is set, it can safely use t.GetLogNeighborStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogNeighborStateChanges == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_LoggingOptions) GetLogNeighborStateChanges() bool {
	if t == nil || t.LogNeighborStateChanges == nil {
		return true
	}
	return *t.LogNeighborStateChanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_Messages represents the /openconfig-bgp/bgp/neighbors/neighbor/state/messages YANG schema element.
type Bgp_Neighbor_Messages struct {
	ΛMetadata []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Received  *Bgp_Neighbor_Messages_Received `path:"received" module:"openconfig-bgp"`
	ΛReceived []ygot.Annotation               `path:"@received" ygotAnnotation:"true"`
	Sent      *Bgp_Neighbor_Messages_Sent     `path:"sent" module:"openconfig-bgp"`
	ΛSent     []ygot.Annotation               `path:"@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_Messages) IsYANGGoStruct() {}

// GetOrCreateReceived retrieves the value of the Received field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_Messages) GetOrCreateReceived() *Bgp_Neighbor_Messages_Received {
	if t.Received != nil {
		return t.Received
	}
	t.Received = &Bgp_Neighbor_Messages_Received{}
	return t.Received
}

// GetOrCreateSent retrieves the value of the Sent field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_Messages) GetOrCreateSent() *Bgp_Neighbor_Messages_Sent {
	if t.Sent != nil {
		return t.Sent
	}
	t.Sent = &Bgp_Neighbor_Messages_Sent{}
	return t.Sent
}

// GetReceived returns the value of the Received struct pointer
// from Bgp_Neighbor_Messages. If the receiver or the field Received is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_Messages) GetReceived() *Bgp_Neighbor_Messages_Received {
	if t != nil && t.Received != nil {
		return t.Received
	}
	return nil
}

// GetSent returns the value of the Sent struct pointer
// from Bgp_Neighbor_Messages. If the receiver or the field Sent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_Messages) GetSent() *Bgp_Neighbor_Messages_Sent {
	if t != nil && t.Sent != nil {
		return t.Sent
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_Messages) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_Messages_Received represents the /openconfig-bgp/bgp/neighbors/neighbor/state/messages/received YANG schema element.
type Bgp_Neighbor_Messages_Received struct {
	ΛMetadata                     []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	NOTIFICATION                  *uint64                                `path:"NOTIFICATION" module:"openconfig-bgp"`
	ΛNOTIFICATION                 []ygot.Annotation                      `path:"@NOTIFICATION" ygotAnnotation:"true"`
	UPDATE                        *uint64                                `path:"UPDATE" module:"openconfig-bgp"`
	ΛUPDATE                       []ygot.Annotation                      `path:"@UPDATE" ygotAnnotation:"true"`
	LastNotificationErrorCode     E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-bgp"`
	ΛLastNotificationErrorCode    []ygot.Annotation                      `path:"@last-notification-error-code" ygotAnnotation:"true"`
	LastNotificationErrorSubcode  E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-bgp"`
	ΛLastNotificationErrorSubcode []ygot.Annotation                      `path:"@last-notification-error-subcode" ygotAnnotation:"true"`
	LastNotificationTime          *uint64                                `path:"last-notification-time" module:"openconfig-bgp"`
	ΛLastNotificationTime         []ygot.Annotation                      `path:"@last-notification-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_Messages_Received implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_Messages_Received) IsYANGGoStruct() {}

// GetNOTIFICATION retrieves the value of the leaf NOTIFICATION from the Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NOTIFICATION is set, it can safely use t.GetNOTIFICATION()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NOTIFICATION == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Received) GetNOTIFICATION() uint64 {
	if t == nil || t.NOTIFICATION == nil {
		return 0
	}
	return *t.NOTIFICATION
}

// GetUPDATE retrieves the value of the leaf UPDATE from the Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UPDATE is set, it can safely use t.GetUPDATE()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UPDATE == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Received) GetUPDATE() uint64 {
	if t == nil || t.UPDATE == nil {
		return 0
	}
	return *t.UPDATE
}

// GetLastNotificationErrorCode retrieves the value of the leaf LastNotificationErrorCode from the Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorCode is set, it can safely use t.GetLastNotificationErrorCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorCode == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Received) GetLastNotificationErrorCode() E_OpenconfigBgpTypes_BGP_ERROR_CODE {
	if t == nil || t.LastNotificationErrorCode == 0 {
		return 0
	}
	return t.LastNotificationErrorCode
}

// GetLastNotificationErrorSubcode retrieves the value of the leaf LastNotificationErrorSubcode from the Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorSubcode is set, it can safely use t.GetLastNotificationErrorSubcode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorSubcode == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Received) GetLastNotificationErrorSubcode() E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE {
	if t == nil || t.LastNotificationErrorSubcode == 0 {
		return 0
	}
	return t.LastNotificationErrorSubcode
}

// GetLastNotificationTime retrieves the value of the leaf LastNotificationTime from the Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationTime is set, it can safely use t.GetLastNotificationTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Received) GetLastNotificationTime() uint64 {
	if t == nil || t.LastNotificationTime == nil {
		return 0
	}
	return *t.LastNotificationTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_Messages_Received) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_Messages_Received"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_Messages_Received) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Neighbor_Messages_Sent represents the /openconfig-bgp/bgp/neighbors/neighbor/state/messages/sent YANG schema element.
type Bgp_Neighbor_Messages_Sent struct {
	ΛMetadata                     []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	NOTIFICATION                  *uint64                                `path:"NOTIFICATION" module:"openconfig-bgp"`
	ΛNOTIFICATION                 []ygot.Annotation                      `path:"@NOTIFICATION" ygotAnnotation:"true"`
	UPDATE                        *uint64                                `path:"UPDATE" module:"openconfig-bgp"`
	ΛUPDATE                       []ygot.Annotation                      `path:"@UPDATE" ygotAnnotation:"true"`
	LastNotificationErrorCode     E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-bgp"`
	ΛLastNotificationErrorCode    []ygot.Annotation                      `path:"@last-notification-error-code" ygotAnnotation:"true"`
	LastNotificationErrorSubcode  E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-bgp"`
	ΛLastNotificationErrorSubcode []ygot.Annotation                      `path:"@last-notification-error-subcode" ygotAnnotation:"true"`
	LastNotificationTime          *uint64                                `path:"last-notification-time" module:"openconfig-bgp"`
	ΛLastNotificationTime         []ygot.Annotation                      `path:"@last-notification-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_Messages_Sent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_Messages_Sent) IsYANGGoStruct() {}

// GetNOTIFICATION retrieves the value of the leaf NOTIFICATION from the Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NOTIFICATION is set, it can safely use t.GetNOTIFICATION()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NOTIFICATION == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Sent) GetNOTIFICATION() uint64 {
	if t == nil || t.NOTIFICATION == nil {
		return 0
	}
	return *t.NOTIFICATION
}

// GetUPDATE retrieves the value of the leaf UPDATE from the Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UPDATE is set, it can safely use t.GetUPDATE()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UPDATE == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Sent) GetUPDATE() uint64 {
	if t == nil || t.UPDATE == nil {
		return 0
	}
	return *t.UPDATE
}

// GetLastNotificationErrorCode retrieves the value of the leaf LastNotificationErrorCode from the Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorCode is set, it can safely use t.GetLastNotificationErrorCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorCode == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Sent) GetLastNotificationErrorCode() E_OpenconfigBgpTypes_BGP_ERROR_CODE {
	if t == nil || t.LastNotificationErrorCode == 0 {
		return 0
	}
	return t.LastNotificationErrorCode
}

// GetLastNotificationErrorSubcode retrieves the value of the leaf LastNotificationErrorSubcode from the Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorSubcode is set, it can safely use t.GetLastNotificationErrorSubcode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorSubcode == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Sent) GetLastNotificationErrorSubcode() E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE {
	if t == nil || t.LastNotificationErrorSubcode == 0 {
		return 0
	}
	return t.LastNotificationErrorSubcode
}

// GetLastNotificationTime retrieves the value of the leaf LastNotificationTime from the Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationTime is set, it can safely use t.GetLastNotificationTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Messages_Sent) GetLastNotificationTime() uint64 {
	if t == nil || t.LastNotificationTime == nil {
		return 0
	}
	return *t.LastNotificationTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_Messages_Sent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_Messages_Sent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_Messages_Sent) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_Queues represents the /openconfig-bgp/bgp/neighbors/neighbor/state/queues YANG schema element.
type Bgp_Neighbor_Queues struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Input     *uint32           `path:"input" module:"openconfig-bgp"`
	ΛInput    []ygot.Annotation `path:"@input" ygotAnnotation:"true"`
	Output    *uint32           `path:"output" module:"openconfig-bgp"`
	ΛOutput   []ygot.Annotation `path:"@output" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_Queues implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_Queues) IsYANGGoStruct() {}

// GetInput retrieves the value of the leaf Input from the Bgp_Neighbor_Queues
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Input is set, it can safely use t.GetInput()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Input == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Queues) GetInput() uint32 {
	if t == nil || t.Input == nil {
		return 0
	}
	return *t.Input
}

// GetOutput retrieves the value of the leaf Output from the Bgp_Neighbor_Queues
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Output is set, it can safely use t.GetOutput()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Output == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Queues) GetOutput() uint32 {
	if t == nil || t.Output == nil {
		return 0
	}
	return *t.Output
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_Queues) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_Queues"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_Queues) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_RouteReflector represents the /openconfig-bgp/bgp/neighbors/neighbor/route-reflector YANG schema element.
type Bgp_Neighbor_RouteReflector struct {
	ΛMetadata                []ygot.Annotation                                         `path:"@" ygotAnnotation:"true"`
	RouteReflectorClient     *bool                                                     `path:"state/route-reflector-client" shadow-path:"config/route-reflector-client" module:"openconfig-bgp"`
	ΛRouteReflectorClient    []ygot.Annotation                                         `path:"state/@route-reflector-client" ygotAnnotation:"true"`
	RouteReflectorClusterId  Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union `path:"state/route-reflector-cluster-id" shadow-path:"config/route-reflector-cluster-id" module:"openconfig-bgp"`
	ΛRouteReflectorClusterId []ygot.Annotation                                         `path:"state/@route-reflector-cluster-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_RouteReflector) IsYANGGoStruct() {}

// GetRouteReflectorClient retrieves the value of the leaf RouteReflectorClient from the Bgp_Neighbor_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClient is set, it can safely use t.GetRouteReflectorClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClient == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_RouteReflector) GetRouteReflectorClient() bool {
	if t == nil || t.RouteReflectorClient == nil {
		return false
	}
	return *t.RouteReflectorClient
}

// GetRouteReflectorClusterId retrieves the value of the leaf RouteReflectorClusterId from the Bgp_Neighbor_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClusterId is set, it can safely use t.GetRouteReflectorClusterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClusterId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_RouteReflector) GetRouteReflectorClusterId() Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union {
	if t == nil || t.RouteReflectorClusterId == nil {
		return nil
	}
	return t.RouteReflectorClusterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union()
}

// Documentation_for_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union ensures that UnionString
// implements the Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionString) Documentation_for_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union() {}

// Documentation_for_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union ensures that UnionUint32
// implements the Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionUint32) Documentation_for_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union() {}

// To_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Neighbor_RouteReflector) To_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union(i interface{}) (Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union, error) {
	if v, ok := i.(Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// Bgp_Neighbor_Timers represents the /openconfig-bgp/bgp/neighbors/neighbor/timers YANG schema element.
type Bgp_Neighbor_Timers struct {
	ΛMetadata                     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ConnectRetry                  *float64          `path:"state/connect-retry" shadow-path:"config/connect-retry" module:"openconfig-bgp"`
	ΛConnectRetry                 []ygot.Annotation `path:"state/@connect-retry" ygotAnnotation:"true"`
	HoldTime                      *float64          `path:"state/hold-time" shadow-path:"config/hold-time" module:"openconfig-bgp"`
	ΛHoldTime                     []ygot.Annotation `path:"state/@hold-time" ygotAnnotation:"true"`
	KeepaliveInterval             *float64          `path:"state/keepalive-interval" shadow-path:"config/keepalive-interval" module:"openconfig-bgp"`
	ΛKeepaliveInterval            []ygot.Annotation `path:"state/@keepalive-interval" ygotAnnotation:"true"`
	MinimumAdvertisementInterval  *float64          `path:"state/minimum-advertisement-interval" shadow-path:"config/minimum-advertisement-interval" module:"openconfig-bgp"`
	ΛMinimumAdvertisementInterval []ygot.Annotation `path:"state/@minimum-advertisement-interval" ygotAnnotation:"true"`
	NegotiatedHoldTime            *float64          `path:"state/negotiated-hold-time" module:"openconfig-bgp"`
	ΛNegotiatedHoldTime           []ygot.Annotation `path:"state/@negotiated-hold-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_Timers) IsYANGGoStruct() {}

// GetConnectRetry retrieves the value of the leaf ConnectRetry from the Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectRetry is set, it can safely use t.GetConnectRetry()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectRetry == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Timers) GetConnectRetry() float64 {
	if t == nil || t.ConnectRetry == nil {
		return 30
	}
	return *t.ConnectRetry
}

// GetHoldTime retrieves the value of the leaf HoldTime from the Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Timers) GetHoldTime() float64 {
	if t == nil || t.HoldTime == nil {
		return 90
	}
	return *t.HoldTime
}

// GetKeepaliveInterval retrieves the value of the leaf KeepaliveInterval from the Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeepaliveInterval is set, it can safely use t.GetKeepaliveInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeepaliveInterval == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Timers) GetKeepaliveInterval() float64 {
	if t == nil || t.KeepaliveInterval == nil {
		return 30
	}
	return *t.KeepaliveInterval
}

// GetMinimumAdvertisementInterval retrieves the value of the leaf MinimumAdvertisementInterval from the Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinimumAdvertisementInterval is set, it can safely use t.GetMinimumAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinimumAdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Timers) GetMinimumAdvertisementInterval() float64 {
	if t == nil || t.MinimumAdvertisementInterval == nil {
		return 30
	}
	return *t.MinimumAdvertisementInterval
}

// GetNegotiatedHoldTime retrieves the value of the leaf NegotiatedHoldTime from the Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NegotiatedHoldTime is set, it can safely use t.GetNegotiatedHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NegotiatedHoldTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Timers) GetNegotiatedHoldTime() float64 {
	if t == nil || t.NegotiatedHoldTime == nil {
		return 0.0
	}
	return *t.NegotiatedHoldTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_Timers) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_Transport represents the /openconfig-bgp/bgp/neighbors/neighbor/transport YANG schema element.
type Bgp_Neighbor_Transport struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LocalAddress   *string           `path:"state/local-address" shadow-path:"config/local-address" module:"openconfig-bgp"`
	ΛLocalAddress  []ygot.Annotation `path:"state/@local-address" ygotAnnotation:"true"`
	LocalPort      *uint16           `path:"state/local-port" module:"openconfig-bgp"`
	ΛLocalPort     []ygot.Annotation `path:"state/@local-port" ygotAnnotation:"true"`
	MtuDiscovery   *bool             `path:"state/mtu-discovery" shadow-path:"config/mtu-discovery" module:"openconfig-bgp"`
	ΛMtuDiscovery  []ygot.Annotation `path:"state/@mtu-discovery" ygotAnnotation:"true"`
	PassiveMode    *bool             `path:"state/passive-mode" shadow-path:"config/passive-mode" module:"openconfig-bgp"`
	ΛPassiveMode   []ygot.Annotation `path:"state/@passive-mode" ygotAnnotation:"true"`
	RemoteAddress  *string           `path:"state/remote-address" module:"openconfig-bgp"`
	ΛRemoteAddress []ygot.Annotation `path:"state/@remote-address" ygotAnnotation:"true"`
	RemotePort     *uint16           `path:"state/remote-port" module:"openconfig-bgp"`
	ΛRemotePort    []ygot.Annotation `path:"state/@remote-port" ygotAnnotation:"true"`
	TcpMss         *uint16           `path:"state/tcp-mss" shadow-path:"config/tcp-mss" module:"openconfig-bgp"`
	ΛTcpMss        []ygot.Annotation `path:"state/@tcp-mss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_Transport) IsYANGGoStruct() {}

// GetLocalAddress retrieves the value of the leaf LocalAddress from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAddress is set, it can safely use t.GetLocalAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetLocalAddress() string {
	if t == nil || t.LocalAddress == nil {
		return ""
	}
	return *t.LocalAddress
}

// GetLocalPort retrieves the value of the leaf LocalPort from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalPort is set, it can safely use t.GetLocalPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalPort == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetLocalPort() uint16 {
	if t == nil || t.LocalPort == nil {
		return 0
	}
	return *t.LocalPort
}

// GetMtuDiscovery retrieves the value of the leaf MtuDiscovery from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtuDiscovery is set, it can safely use t.GetMtuDiscovery()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtuDiscovery == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetMtuDiscovery() bool {
	if t == nil || t.MtuDiscovery == nil {
		return false
	}
	return *t.MtuDiscovery
}

// GetPassiveMode retrieves the value of the leaf PassiveMode from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PassiveMode is set, it can safely use t.GetPassiveMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PassiveMode == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetPassiveMode() bool {
	if t == nil || t.PassiveMode == nil {
		return false
	}
	return *t.PassiveMode
}

// GetRemoteAddress retrieves the value of the leaf RemoteAddress from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteAddress is set, it can safely use t.GetRemoteAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetRemoteAddress() string {
	if t == nil || t.RemoteAddress == nil {
		return ""
	}
	return *t.RemoteAddress
}

// GetRemotePort retrieves the value of the leaf RemotePort from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemotePort is set, it can safely use t.GetRemotePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemotePort == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetRemotePort() uint16 {
	if t == nil || t.RemotePort == nil {
		return 0
	}
	return *t.RemotePort
}

// GetTcpMss retrieves the value of the leaf TcpMss from the Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TcpMss is set, it can safely use t.GetTcpMss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TcpMss == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_Transport) GetTcpMss() uint16 {
	if t == nil || t.TcpMss == nil {
		return 0
	}
	return *t.TcpMss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_Transport) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_UseMultiplePaths represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths YANG schema element.
type Bgp_Neighbor_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                   `path:"@" ygotAnnotation:"true"`
	Ebgp      *Bgp_Neighbor_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-bgp"`
	ΛEbgp     []ygot.Annotation                   `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                               `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation                   `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *Bgp_Neighbor_UseMultiplePaths) GetOrCreateEbgp() *Bgp_Neighbor_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &Bgp_Neighbor_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from Bgp_Neighbor_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Neighbor_UseMultiplePaths) GetEbgp() *Bgp_Neighbor_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_Neighbor_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Neighbor_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths/ebgp YANG schema element.
type Bgp_Neighbor_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-bgp"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Neighbor_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Neighbor_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the Bgp_Neighbor_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_Neighbor_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Neighbor_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Neighbor_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Neighbor_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup represents the /openconfig-bgp/bgp/peer-groups/peer-group YANG schema element.
type Bgp_PeerGroup struct {
	ΛMetadata         []ygot.Annotation                                             `path:"@" ygotAnnotation:"true"`
	AfiSafi           map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_PeerGroup_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-bgp"`
	ΛAfiSafi          []ygot.Annotation                                             `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	ApplyPolicy       *Bgp_PeerGroup_ApplyPolicy                                    `path:"apply-policy" module:"openconfig-bgp"`
	ΛApplyPolicy      []ygot.Annotation                                             `path:"@apply-policy" ygotAnnotation:"true"`
	AsPathOptions     *Bgp_PeerGroup_AsPathOptions                                  `path:"as-path-options" module:"openconfig-bgp"`
	ΛAsPathOptions    []ygot.Annotation                                             `path:"@as-path-options" ygotAnnotation:"true"`
	AuthPassword      *string                                                       `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-bgp"`
	ΛAuthPassword     []ygot.Annotation                                             `path:"state/@auth-password" ygotAnnotation:"true"`
	Description       *string                                                       `path:"state/description" shadow-path:"config/description" module:"openconfig-bgp"`
	ΛDescription      []ygot.Annotation                                             `path:"state/@description" ygotAnnotation:"true"`
	EbgpMultihop      *Bgp_PeerGroup_EbgpMultihop                                   `path:"ebgp-multihop" module:"openconfig-bgp"`
	ΛEbgpMultihop     []ygot.Annotation                                             `path:"@ebgp-multihop" ygotAnnotation:"true"`
	ErrorHandling     *Bgp_PeerGroup_ErrorHandling                                  `path:"error-handling" module:"openconfig-bgp"`
	ΛErrorHandling    []ygot.Annotation                                             `path:"@error-handling" ygotAnnotation:"true"`
	GracefulRestart   *Bgp_PeerGroup_GracefulRestart                                `path:"graceful-restart" module:"openconfig-bgp"`
	ΛGracefulRestart  []ygot.Annotation                                             `path:"@graceful-restart" ygotAnnotation:"true"`
	LocalAs           *uint32                                                       `path:"state/local-as" shadow-path:"config/local-as" module:"openconfig-bgp"`
	ΛLocalAs          []ygot.Annotation                                             `path:"state/@local-as" ygotAnnotation:"true"`
	LoggingOptions    *Bgp_PeerGroup_LoggingOptions                                 `path:"logging-options" module:"openconfig-bgp"`
	ΛLoggingOptions   []ygot.Annotation                                             `path:"@logging-options" ygotAnnotation:"true"`
	PeerAs            *uint32                                                       `path:"state/peer-as" shadow-path:"config/peer-as" module:"openconfig-bgp"`
	ΛPeerAs           []ygot.Annotation                                             `path:"state/@peer-as" ygotAnnotation:"true"`
	PeerGroupName     *string                                                       `path:"state/peer-group-name|peer-group-name" shadow-path:"config/peer-group-name" module:"openconfig-bgp"`
	ΛPeerGroupName    []ygot.Annotation                                             `path:"state/@peer-group-name|@peer-group-name" ygotAnnotation:"true"`
	PeerType          E_OpenconfigBgpTypes_PeerType                                 `path:"state/peer-type" shadow-path:"config/peer-type" module:"openconfig-bgp"`
	ΛPeerType         []ygot.Annotation                                             `path:"state/@peer-type" ygotAnnotation:"true"`
	RemovePrivateAs   E_OpenconfigBgpTypes_RemovePrivateAsOption                    `path:"state/remove-private-as" shadow-path:"config/remove-private-as" module:"openconfig-bgp"`
	ΛRemovePrivateAs  []ygot.Annotation                                             `path:"state/@remove-private-as" ygotAnnotation:"true"`
	RouteFlapDamping  *bool                                                         `path:"state/route-flap-damping" shadow-path:"config/route-flap-damping" module:"openconfig-bgp"`
	ΛRouteFlapDamping []ygot.Annotation                                             `path:"state/@route-flap-damping" ygotAnnotation:"true"`
	RouteReflector    *Bgp_PeerGroup_RouteReflector                                 `path:"route-reflector" module:"openconfig-bgp"`
	ΛRouteReflector   []ygot.Annotation                                             `path:"@route-reflector" ygotAnnotation:"true"`
	SendCommunity     E_OpenconfigBgpTypes_CommunityType                            `path:"state/send-community" shadow-path:"config/send-community" module:"openconfig-bgp"`
	ΛSendCommunity    []ygot.Annotation                                             `path:"state/@send-community" ygotAnnotation:"true"`
	Timers            *Bgp_PeerGroup_Timers                                         `path:"timers" module:"openconfig-bgp"`
	ΛTimers           []ygot.Annotation                                             `path:"@timers" ygotAnnotation:"true"`
	TotalPaths        *uint32                                                       `path:"state/total-paths" module:"openconfig-bgp"`
	ΛTotalPaths       []ygot.Annotation                                             `path:"state/@total-paths" ygotAnnotation:"true"`
	TotalPrefixes     *uint32                                                       `path:"state/total-prefixes" module:"openconfig-bgp"`
	ΛTotalPrefixes    []ygot.Annotation                                             `path:"state/@total-prefixes" ygotAnnotation:"true"`
	Transport         *Bgp_PeerGroup_Transport                                      `path:"transport" module:"openconfig-bgp"`
	ΛTransport        []ygot.Annotation                                             `path:"@transport" ygotAnnotation:"true"`
	UseMultiplePaths  *Bgp_PeerGroup_UseMultiplePaths                               `path:"use-multiple-paths" module:"openconfig-bgp"`
	ΛUseMultiplePaths []ygot.Annotation                                             `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// Bgp_PeerGroup struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_PeerGroup) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*Bgp_PeerGroup_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_PeerGroup_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &Bgp_PeerGroup_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the Bgp_PeerGroup struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_PeerGroup) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver Bgp_PeerGroup. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_PeerGroup) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_PeerGroup_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of Bgp_PeerGroup. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_PeerGroup) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_PeerGroup_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied Bgp_PeerGroup_AfiSafi struct to the
// list AfiSafi of Bgp_PeerGroup. If the key value(s) specified in
// the supplied Bgp_PeerGroup_AfiSafi already exist in the list, an error is
// returned.
func (t *Bgp_PeerGroup) AppendAfiSafi(v *Bgp_PeerGroup_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_PeerGroup_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateApplyPolicy() *Bgp_PeerGroup_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &Bgp_PeerGroup_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateAsPathOptions retrieves the value of the AsPathOptions field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateAsPathOptions() *Bgp_PeerGroup_AsPathOptions {
	if t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	t.AsPathOptions = &Bgp_PeerGroup_AsPathOptions{}
	return t.AsPathOptions
}

// GetOrCreateEbgpMultihop retrieves the value of the EbgpMultihop field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateEbgpMultihop() *Bgp_PeerGroup_EbgpMultihop {
	if t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	t.EbgpMultihop = &Bgp_PeerGroup_EbgpMultihop{}
	return t.EbgpMultihop
}

// GetOrCreateErrorHandling retrieves the value of the ErrorHandling field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateErrorHandling() *Bgp_PeerGroup_ErrorHandling {
	if t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	t.ErrorHandling = &Bgp_PeerGroup_ErrorHandling{}
	return t.ErrorHandling
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateGracefulRestart() *Bgp_PeerGroup_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &Bgp_PeerGroup_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateLoggingOptions retrieves the value of the LoggingOptions field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateLoggingOptions() *Bgp_PeerGroup_LoggingOptions {
	if t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	t.LoggingOptions = &Bgp_PeerGroup_LoggingOptions{}
	return t.LoggingOptions
}

// GetOrCreateRouteReflector retrieves the value of the RouteReflector field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateRouteReflector() *Bgp_PeerGroup_RouteReflector {
	if t.RouteReflector != nil {
		return t.RouteReflector
	}
	t.RouteReflector = &Bgp_PeerGroup_RouteReflector{}
	return t.RouteReflector
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateTimers() *Bgp_PeerGroup_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &Bgp_PeerGroup_Timers{}
	return t.Timers
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateTransport() *Bgp_PeerGroup_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &Bgp_PeerGroup_Transport{}
	return t.Transport
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup) GetOrCreateUseMultiplePaths() *Bgp_PeerGroup_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &Bgp_PeerGroup_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from Bgp_PeerGroup. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetApplyPolicy() *Bgp_PeerGroup_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetAsPathOptions returns the value of the AsPathOptions struct pointer
// from Bgp_PeerGroup. If the receiver or the field AsPathOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetAsPathOptions() *Bgp_PeerGroup_AsPathOptions {
	if t != nil && t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	return nil
}

// GetEbgpMultihop returns the value of the EbgpMultihop struct pointer
// from Bgp_PeerGroup. If the receiver or the field EbgpMultihop is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetEbgpMultihop() *Bgp_PeerGroup_EbgpMultihop {
	if t != nil && t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	return nil
}

// GetErrorHandling returns the value of the ErrorHandling struct pointer
// from Bgp_PeerGroup. If the receiver or the field ErrorHandling is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetErrorHandling() *Bgp_PeerGroup_ErrorHandling {
	if t != nil && t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from Bgp_PeerGroup. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetGracefulRestart() *Bgp_PeerGroup_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetLoggingOptions returns the value of the LoggingOptions struct pointer
// from Bgp_PeerGroup. If the receiver or the field LoggingOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetLoggingOptions() *Bgp_PeerGroup_LoggingOptions {
	if t != nil && t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	return nil
}

// GetRouteReflector returns the value of the RouteReflector struct pointer
// from Bgp_PeerGroup. If the receiver or the field RouteReflector is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetRouteReflector() *Bgp_PeerGroup_RouteReflector {
	if t != nil && t.RouteReflector != nil {
		return t.RouteReflector
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from Bgp_PeerGroup. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetTimers() *Bgp_PeerGroup_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from Bgp_PeerGroup. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetTransport() *Bgp_PeerGroup_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from Bgp_PeerGroup. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup) GetUseMultiplePaths() *Bgp_PeerGroup_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// GetDescription retrieves the value of the leaf Description from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetLocalAs retrieves the value of the leaf LocalAs from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAs is set, it can safely use t.GetLocalAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetLocalAs() uint32 {
	if t == nil || t.LocalAs == nil {
		return 0
	}
	return *t.LocalAs
}

// GetPeerAs retrieves the value of the leaf PeerAs from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerAs is set, it can safely use t.GetPeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetPeerAs() uint32 {
	if t == nil || t.PeerAs == nil {
		return 0
	}
	return *t.PeerAs
}

// GetPeerGroupName retrieves the value of the leaf PeerGroupName from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerGroupName is set, it can safely use t.GetPeerGroupName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerGroupName == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetPeerGroupName() string {
	if t == nil || t.PeerGroupName == nil {
		return ""
	}
	return *t.PeerGroupName
}

// GetPeerType retrieves the value of the leaf PeerType from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerType is set, it can safely use t.GetPeerType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerType == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetPeerType() E_OpenconfigBgpTypes_PeerType {
	if t == nil || t.PeerType == 0 {
		return 0
	}
	return t.PeerType
}

// GetRemovePrivateAs retrieves the value of the leaf RemovePrivateAs from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemovePrivateAs is set, it can safely use t.GetRemovePrivateAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemovePrivateAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetRemovePrivateAs() E_OpenconfigBgpTypes_RemovePrivateAsOption {
	if t == nil || t.RemovePrivateAs == 0 {
		return 0
	}
	return t.RemovePrivateAs
}

// GetRouteFlapDamping retrieves the value of the leaf RouteFlapDamping from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteFlapDamping is set, it can safely use t.GetRouteFlapDamping()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteFlapDamping == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetRouteFlapDamping() bool {
	if t == nil || t.RouteFlapDamping == nil {
		return false
	}
	return *t.RouteFlapDamping
}

// GetSendCommunity retrieves the value of the leaf SendCommunity from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendCommunity is set, it can safely use t.GetSendCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendCommunity == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetSendCommunity() E_OpenconfigBgpTypes_CommunityType {
	if t == nil || t.SendCommunity == 0 {
		return OpenconfigBgpTypes_CommunityType_NONE
	}
	return t.SendCommunity
}

// GetTotalPaths retrieves the value of the leaf TotalPaths from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPaths is set, it can safely use t.GetTotalPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetTotalPaths() uint32 {
	if t == nil || t.TotalPaths == nil {
		return 0
	}
	return *t.TotalPaths
}

// GetTotalPrefixes retrieves the value of the leaf TotalPrefixes from the Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPrefixes is set, it can safely use t.GetTotalPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup) GetTotalPrefixes() uint32 {
	if t == nil || t.TotalPrefixes == nil {
		return 0
	}
	return *t.TotalPrefixes
}

// ΛListKeyMap returns the keys of the Bgp_PeerGroup struct, which is a YANG list entry.
func (t *Bgp_PeerGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PeerGroupName == nil {
		return nil, fmt.Errorf("nil value for key PeerGroupName")
	}

	return map[string]interface{}{
		"peer-group-name": *t.PeerGroupName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_AfiSafi represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi YANG schema element.
type Bgp_PeerGroup_AfiSafi struct {
	ΛMetadata           []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	AddPaths            *Bgp_PeerGroup_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-bgp"`
	ΛAddPaths           []ygot.Annotation                         `path:"@add-paths" ygotAnnotation:"true"`
	AfiSafiName         E_OpenconfigBgpTypes_AFI_SAFI_TYPE        `path:"state/afi-safi-name|afi-safi-name" shadow-path:"config/afi-safi-name" module:"openconfig-bgp"`
	ΛAfiSafiName        []ygot.Annotation                         `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	ApplyPolicy         *Bgp_PeerGroup_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-bgp"`
	ΛApplyPolicy        []ygot.Annotation                         `path:"@apply-policy" ygotAnnotation:"true"`
	Enabled             *bool                                     `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled            []ygot.Annotation                         `path:"state/@enabled" ygotAnnotation:"true"`
	GracefulRestart     *Bgp_PeerGroup_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-bgp"`
	ΛGracefulRestart    []ygot.Annotation                         `path:"@graceful-restart" ygotAnnotation:"true"`
	Ipv4LabeledUnicast  *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-bgp"`
	ΛIpv4LabeledUnicast []ygot.Annotation                         `path:"@ipv4-labeled-unicast" ygotAnnotation:"true"`
	Ipv4Unicast         *Bgp_PeerGroup_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-bgp"`
	ΛIpv4Unicast        []ygot.Annotation                         `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6LabeledUnicast  *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-bgp"`
	ΛIpv6LabeledUnicast []ygot.Annotation                         `path:"@ipv6-labeled-unicast" ygotAnnotation:"true"`
	Ipv6Unicast         *Bgp_PeerGroup_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-bgp"`
	ΛIpv6Unicast        []ygot.Annotation                         `path:"@ipv6-unicast" ygotAnnotation:"true"`
	L2VpnEvpn           *Bgp_PeerGroup_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-bgp"`
	ΛL2VpnEvpn          []ygot.Annotation                         `path:"@l2vpn-evpn" ygotAnnotation:"true"`
	L2VpnVpls           *Bgp_PeerGroup_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-bgp"`
	ΛL2VpnVpls          []ygot.Annotation                         `path:"@l2vpn-vpls" ygotAnnotation:"true"`
	L3VpnIpv4Multicast  *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-bgp"`
	ΛL3VpnIpv4Multicast []ygot.Annotation                         `path:"@l3vpn-ipv4-multicast" ygotAnnotation:"true"`
	L3VpnIpv4Unicast    *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-bgp"`
	ΛL3VpnIpv4Unicast   []ygot.Annotation                         `path:"@l3vpn-ipv4-unicast" ygotAnnotation:"true"`
	L3VpnIpv6Multicast  *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-bgp"`
	ΛL3VpnIpv6Multicast []ygot.Annotation                         `path:"@l3vpn-ipv6-multicast" ygotAnnotation:"true"`
	L3VpnIpv6Unicast    *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-bgp"`
	ΛL3VpnIpv6Unicast   []ygot.Annotation                         `path:"@l3vpn-ipv6-unicast" ygotAnnotation:"true"`
	SrtePolicyIpv4      *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-bgp"`
	ΛSrtePolicyIpv4     []ygot.Annotation                         `path:"@srte-policy-ipv4" ygotAnnotation:"true"`
	SrtePolicyIpv6      *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-bgp"`
	ΛSrtePolicyIpv6     []ygot.Annotation                         `path:"@srte-policy-ipv6" ygotAnnotation:"true"`
	UseMultiplePaths    *Bgp_PeerGroup_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-bgp"`
	ΛUseMultiplePaths   []ygot.Annotation                         `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateAddPaths retrieves the value of the AddPaths field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateAddPaths() *Bgp_PeerGroup_AfiSafi_AddPaths {
	if t.AddPaths != nil {
		return t.AddPaths
	}
	t.AddPaths = &Bgp_PeerGroup_AfiSafi_AddPaths{}
	return t.AddPaths
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateApplyPolicy() *Bgp_PeerGroup_AfiSafi_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &Bgp_PeerGroup_AfiSafi_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateGracefulRestart() *Bgp_PeerGroup_AfiSafi_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &Bgp_PeerGroup_AfiSafi_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateIpv4LabeledUnicast retrieves the value of the Ipv4LabeledUnicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateIpv4LabeledUnicast() *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast {
	if t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	t.Ipv4LabeledUnicast = &Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast{}
	return t.Ipv4LabeledUnicast
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateIpv4Unicast() *Bgp_PeerGroup_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &Bgp_PeerGroup_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6LabeledUnicast retrieves the value of the Ipv6LabeledUnicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateIpv6LabeledUnicast() *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast {
	if t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	t.Ipv6LabeledUnicast = &Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast{}
	return t.Ipv6LabeledUnicast
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateIpv6Unicast() *Bgp_PeerGroup_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &Bgp_PeerGroup_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetOrCreateL2VpnEvpn retrieves the value of the L2VpnEvpn field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateL2VpnEvpn() *Bgp_PeerGroup_AfiSafi_L2VpnEvpn {
	if t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	t.L2VpnEvpn = &Bgp_PeerGroup_AfiSafi_L2VpnEvpn{}
	return t.L2VpnEvpn
}

// GetOrCreateL2VpnVpls retrieves the value of the L2VpnVpls field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateL2VpnVpls() *Bgp_PeerGroup_AfiSafi_L2VpnVpls {
	if t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	t.L2VpnVpls = &Bgp_PeerGroup_AfiSafi_L2VpnVpls{}
	return t.L2VpnVpls
}

// GetOrCreateL3VpnIpv4Multicast retrieves the value of the L3VpnIpv4Multicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv4Multicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast {
	if t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	t.L3VpnIpv4Multicast = &Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast{}
	return t.L3VpnIpv4Multicast
}

// GetOrCreateL3VpnIpv4Unicast retrieves the value of the L3VpnIpv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv4Unicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast {
	if t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	t.L3VpnIpv4Unicast = &Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast{}
	return t.L3VpnIpv4Unicast
}

// GetOrCreateL3VpnIpv6Multicast retrieves the value of the L3VpnIpv6Multicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv6Multicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast {
	if t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	t.L3VpnIpv6Multicast = &Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast{}
	return t.L3VpnIpv6Multicast
}

// GetOrCreateL3VpnIpv6Unicast retrieves the value of the L3VpnIpv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv6Unicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast {
	if t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	t.L3VpnIpv6Unicast = &Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast{}
	return t.L3VpnIpv6Unicast
}

// GetOrCreateSrtePolicyIpv4 retrieves the value of the SrtePolicyIpv4 field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateSrtePolicyIpv4() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 {
	if t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	t.SrtePolicyIpv4 = &Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4{}
	return t.SrtePolicyIpv4
}

// GetOrCreateSrtePolicyIpv6 retrieves the value of the SrtePolicyIpv6 field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateSrtePolicyIpv6() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 {
	if t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	t.SrtePolicyIpv6 = &Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6{}
	return t.SrtePolicyIpv6
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi) GetOrCreateUseMultiplePaths() *Bgp_PeerGroup_AfiSafi_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &Bgp_PeerGroup_AfiSafi_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetAddPaths returns the value of the AddPaths struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field AddPaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetAddPaths() *Bgp_PeerGroup_AfiSafi_AddPaths {
	if t != nil && t.AddPaths != nil {
		return t.AddPaths
	}
	return nil
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetApplyPolicy() *Bgp_PeerGroup_AfiSafi_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetGracefulRestart() *Bgp_PeerGroup_AfiSafi_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetIpv4LabeledUnicast returns the value of the Ipv4LabeledUnicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv4LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetIpv4LabeledUnicast() *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast {
	if t != nil && t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetIpv4Unicast() *Bgp_PeerGroup_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6LabeledUnicast returns the value of the Ipv6LabeledUnicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv6LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetIpv6LabeledUnicast() *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast {
	if t != nil && t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetIpv6Unicast() *Bgp_PeerGroup_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetL2VpnEvpn returns the value of the L2VpnEvpn struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field L2VpnEvpn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetL2VpnEvpn() *Bgp_PeerGroup_AfiSafi_L2VpnEvpn {
	if t != nil && t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	return nil
}

// GetL2VpnVpls returns the value of the L2VpnVpls struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field L2VpnVpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetL2VpnVpls() *Bgp_PeerGroup_AfiSafi_L2VpnVpls {
	if t != nil && t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	return nil
}

// GetL3VpnIpv4Multicast returns the value of the L3VpnIpv4Multicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv4Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetL3VpnIpv4Multicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast {
	if t != nil && t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	return nil
}

// GetL3VpnIpv4Unicast returns the value of the L3VpnIpv4Unicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetL3VpnIpv4Unicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast {
	if t != nil && t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	return nil
}

// GetL3VpnIpv6Multicast returns the value of the L3VpnIpv6Multicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv6Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetL3VpnIpv6Multicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast {
	if t != nil && t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	return nil
}

// GetL3VpnIpv6Unicast returns the value of the L3VpnIpv6Unicast struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetL3VpnIpv6Unicast() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast {
	if t != nil && t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	return nil
}

// GetSrtePolicyIpv4 returns the value of the SrtePolicyIpv4 struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field SrtePolicyIpv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetSrtePolicyIpv4() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 {
	if t != nil && t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	return nil
}

// GetSrtePolicyIpv6 returns the value of the SrtePolicyIpv6 struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field SrtePolicyIpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetSrtePolicyIpv6() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 {
	if t != nil && t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from Bgp_PeerGroup_AfiSafi. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi) GetUseMultiplePaths() *Bgp_PeerGroup_AfiSafi_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the Bgp_PeerGroup_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_PeerGroup_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// ΛListKeyMap returns the keys of the Bgp_PeerGroup_AfiSafi struct, which is a YANG list entry.
func (t *Bgp_PeerGroup_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_AfiSafi_AddPaths represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths YANG schema element.
type Bgp_PeerGroup_AfiSafi_AddPaths struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EligiblePrefixPolicy  *string           `path:"state/eligible-prefix-policy" shadow-path:"config/eligible-prefix-policy" module:"openconfig-bgp"`
	ΛEligiblePrefixPolicy []ygot.Annotation `path:"state/@eligible-prefix-policy" ygotAnnotation:"true"`
	Receive               *bool             `path:"state/receive" shadow-path:"config/receive" module:"openconfig-bgp"`
	ΛReceive              []ygot.Annotation `path:"state/@receive" ygotAnnotation:"true"`
	Send                  *bool             `path:"state/send" shadow-path:"config/send" module:"openconfig-bgp"`
	ΛSend                 []ygot.Annotation `path:"state/@send" ygotAnnotation:"true"`
	SendMax               *uint8            `path:"state/send-max" shadow-path:"config/send-max" module:"openconfig-bgp"`
	ΛSendMax              []ygot.Annotation `path:"state/@send-max" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_AddPaths) IsYANGGoStruct() {}

// GetEligiblePrefixPolicy retrieves the value of the leaf EligiblePrefixPolicy from the Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EligiblePrefixPolicy is set, it can safely use t.GetEligiblePrefixPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EligiblePrefixPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_AddPaths) GetEligiblePrefixPolicy() string {
	if t == nil || t.EligiblePrefixPolicy == nil {
		return ""
	}
	return *t.EligiblePrefixPolicy
}

// GetReceive retrieves the value of the leaf Receive from the Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Receive is set, it can safely use t.GetReceive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Receive == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_AddPaths) GetReceive() bool {
	if t == nil || t.Receive == nil {
		return false
	}
	return *t.Receive
}

// GetSend retrieves the value of the leaf Send from the Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Send is set, it can safely use t.GetSend()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Send == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_AddPaths) GetSend() bool {
	if t == nil || t.Send == nil {
		return false
	}
	return *t.Send
}

// GetSendMax retrieves the value of the leaf SendMax from the Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendMax is set, it can safely use t.GetSendMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendMax == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_AddPaths) GetSendMax() uint8 {
	if t == nil || t.SendMax == nil {
		return 0
	}
	return *t.SendMax
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_ApplyPolicy represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy YANG schema element.
type Bgp_PeerGroup_AfiSafi_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-bgp"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-bgp"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-bgp"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-bgp"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_GracefulRestart represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart YANG schema element.
type Bgp_PeerGroup_AfiSafi_GracefulRestart struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled   *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_PeerGroup_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                     `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv4Unicast struct {
	ΛMetadata         []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit      []ygot.Annotation                              `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                          `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-bgp"`
	ΛSendDefaultRoute []ygot.Annotation                              `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_Ipv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the Bgp_PeerGroup_AfiSafi_Ipv4Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                     `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv6Unicast struct {
	ΛMetadata         []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit      []ygot.Annotation                              `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                          `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-bgp"`
	ΛSendDefaultRoute []ygot.Annotation                              `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_Ipv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the Bgp_PeerGroup_AfiSafi_Ipv6Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L2VpnEvpn represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type Bgp_PeerGroup_AfiSafi_L2VpnEvpn struct {
	ΛMetadata    []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                            `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_L2VpnEvpn. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L2VpnVpls represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type Bgp_PeerGroup_AfiSafi_L2VpnVpls struct {
	ΛMetadata    []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                            `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_L2VpnVpls. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast struct {
	ΛMetadata    []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                     `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast struct {
	ΛMetadata    []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                   `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast struct {
	ΛMetadata    []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                     `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast struct {
	ΛMetadata    []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                   `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 struct {
	ΛMetadata    []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                 `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 struct {
	ΛMetadata    []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	ΛPrefixLimit []ygot.Annotation                                 `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) GetOrCreatePrefixLimit() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) GetPrefixLimit() *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-bgp"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-bgp"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-bgp"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-bgp"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_UseMultiplePaths represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type Bgp_PeerGroup_AfiSafi_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	Ebgp      *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-bgp"`
	ΛEbgp     []ygot.Annotation                            `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                        `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation                            `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-bgp"`
	ΛIbgp     []ygot.Annotation                            `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetOrCreateEbgp() *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetOrCreateIbgp() *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from Bgp_PeerGroup_AfiSafi_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetEbgp() *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from Bgp_PeerGroup_AfiSafi_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetIbgp() *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_PeerGroup_AfiSafi_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-bgp"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_ApplyPolicy represents the /openconfig-bgp/bgp/peer-groups/peer-group/apply-policy YANG schema element.
type Bgp_PeerGroup_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-bgp"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-bgp"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-bgp"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-bgp"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_AsPathOptions represents the /openconfig-bgp/bgp/peer-groups/peer-group/as-path-options YANG schema element.
type Bgp_PeerGroup_AsPathOptions struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowOwnAs           *uint8            `path:"state/allow-own-as" shadow-path:"config/allow-own-as" module:"openconfig-bgp"`
	ΛAllowOwnAs          []ygot.Annotation `path:"state/@allow-own-as" ygotAnnotation:"true"`
	DisablePeerAsFilter  *bool             `path:"state/disable-peer-as-filter" shadow-path:"config/disable-peer-as-filter" module:"openconfig-bgp"`
	ΛDisablePeerAsFilter []ygot.Annotation `path:"state/@disable-peer-as-filter" ygotAnnotation:"true"`
	ReplacePeerAs        *bool             `path:"state/replace-peer-as" shadow-path:"config/replace-peer-as" module:"openconfig-bgp"`
	ΛReplacePeerAs       []ygot.Annotation `path:"state/@replace-peer-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_AsPathOptions) IsYANGGoStruct() {}

// GetAllowOwnAs retrieves the value of the leaf AllowOwnAs from the Bgp_PeerGroup_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowOwnAs is set, it can safely use t.GetAllowOwnAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowOwnAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AsPathOptions) GetAllowOwnAs() uint8 {
	if t == nil || t.AllowOwnAs == nil {
		return 0
	}
	return *t.AllowOwnAs
}

// GetDisablePeerAsFilter retrieves the value of the leaf DisablePeerAsFilter from the Bgp_PeerGroup_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DisablePeerAsFilter is set, it can safely use t.GetDisablePeerAsFilter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DisablePeerAsFilter == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AsPathOptions) GetDisablePeerAsFilter() bool {
	if t == nil || t.DisablePeerAsFilter == nil {
		return false
	}
	return *t.DisablePeerAsFilter
}

// GetReplacePeerAs retrieves the value of the leaf ReplacePeerAs from the Bgp_PeerGroup_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReplacePeerAs is set, it can safely use t.GetReplacePeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReplacePeerAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_AsPathOptions) GetReplacePeerAs() bool {
	if t == nil || t.ReplacePeerAs == nil {
		return false
	}
	return *t.ReplacePeerAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_EbgpMultihop represents the /openconfig-bgp/bgp/peer-groups/peer-group/ebgp-multihop YANG schema element.
type Bgp_PeerGroup_EbgpMultihop struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled      *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled     []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	MultihopTtl  *uint8            `path:"state/multihop-ttl" shadow-path:"config/multihop-ttl" module:"openconfig-bgp"`
	ΛMultihopTtl []ygot.Annotation `path:"state/@multihop-ttl" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_EbgpMultihop) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_PeerGroup_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_EbgpMultihop) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetMultihopTtl retrieves the value of the leaf MultihopTtl from the Bgp_PeerGroup_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultihopTtl is set, it can safely use t.GetMultihopTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultihopTtl == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_EbgpMultihop) GetMultihopTtl() uint8 {
	if t == nil || t.MultihopTtl == nil {
		return 0
	}
	return *t.MultihopTtl
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_ErrorHandling represents the /openconfig-bgp/bgp/peer-groups/peer-group/error-handling YANG schema element.
type Bgp_PeerGroup_ErrorHandling struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	TreatAsWithdraw  *bool             `path:"state/treat-as-withdraw" shadow-path:"config/treat-as-withdraw" module:"openconfig-bgp"`
	ΛTreatAsWithdraw []ygot.Annotation `path:"state/@treat-as-withdraw" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_ErrorHandling) IsYANGGoStruct() {}

// GetTreatAsWithdraw retrieves the value of the leaf TreatAsWithdraw from the Bgp_PeerGroup_ErrorHandling
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TreatAsWithdraw is set, it can safely use t.GetTreatAsWithdraw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TreatAsWithdraw == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_ErrorHandling) GetTreatAsWithdraw() bool {
	if t == nil || t.TreatAsWithdraw == nil {
		return false
	}
	return *t.TreatAsWithdraw
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_GracefulRestart represents the /openconfig-bgp/bgp/peer-groups/peer-group/graceful-restart YANG schema element.
type Bgp_PeerGroup_GracefulRestart struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled          *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled         []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly       *bool             `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-bgp"`
	ΛHelperOnly      []ygot.Annotation `path:"state/@helper-only" ygotAnnotation:"true"`
	RestartTime      *uint16           `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-bgp"`
	ΛRestartTime     []ygot.Annotation `path:"state/@restart-time" ygotAnnotation:"true"`
	StaleRoutesTime  *float64          `path:"state/stale-routes-time" shadow-path:"config/stale-routes-time" module:"openconfig-bgp"`
	ΛStaleRoutesTime []ygot.Annotation `path:"state/@stale-routes-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// GetRestartTime retrieves the value of the leaf RestartTime from the Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_GracefulRestart) GetRestartTime() uint16 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// GetStaleRoutesTime retrieves the value of the leaf StaleRoutesTime from the Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StaleRoutesTime is set, it can safely use t.GetStaleRoutesTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StaleRoutesTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_GracefulRestart) GetStaleRoutesTime() float64 {
	if t == nil || t.StaleRoutesTime == nil {
		return 0.0
	}
	return *t.StaleRoutesTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_LoggingOptions represents the /openconfig-bgp/bgp/peer-groups/peer-group/logging-options YANG schema element.
type Bgp_PeerGroup_LoggingOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LogNeighborStateChanges  *bool             `path:"state/log-neighbor-state-changes" shadow-path:"config/log-neighbor-state-changes" module:"openconfig-bgp"`
	ΛLogNeighborStateChanges []ygot.Annotation `path:"state/@log-neighbor-state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_LoggingOptions) IsYANGGoStruct() {}

// GetLogNeighborStateChanges retrieves the value of the leaf LogNeighborStateChanges from the Bgp_PeerGroup_LoggingOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogNeighborStateChanges is set, it can safely use t.GetLogNeighborStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogNeighborStateChanges == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_LoggingOptions) GetLogNeighborStateChanges() bool {
	if t == nil || t.LogNeighborStateChanges == nil {
		return true
	}
	return *t.LogNeighborStateChanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_RouteReflector represents the /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector YANG schema element.
type Bgp_PeerGroup_RouteReflector struct {
	ΛMetadata                []ygot.Annotation                                          `path:"@" ygotAnnotation:"true"`
	RouteReflectorClient     *bool                                                      `path:"state/route-reflector-client" shadow-path:"config/route-reflector-client" module:"openconfig-bgp"`
	ΛRouteReflectorClient    []ygot.Annotation                                          `path:"state/@route-reflector-client" ygotAnnotation:"true"`
	RouteReflectorClusterId  Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union `path:"state/route-reflector-cluster-id" shadow-path:"config/route-reflector-cluster-id" module:"openconfig-bgp"`
	ΛRouteReflectorClusterId []ygot.Annotation                                          `path:"state/@route-reflector-cluster-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_RouteReflector) IsYANGGoStruct() {}

// GetRouteReflectorClient retrieves the value of the leaf RouteReflectorClient from the Bgp_PeerGroup_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClient is set, it can safely use t.GetRouteReflectorClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClient == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_RouteReflector) GetRouteReflectorClient() bool {
	if t == nil || t.RouteReflectorClient == nil {
		return false
	}
	return *t.RouteReflectorClient
}

// GetRouteReflectorClusterId retrieves the value of the leaf RouteReflectorClusterId from the Bgp_PeerGroup_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClusterId is set, it can safely use t.GetRouteReflectorClusterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClusterId == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_RouteReflector) GetRouteReflectorClusterId() Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union {
	if t == nil || t.RouteReflectorClusterId == nil {
		return nil
	}
	return t.RouteReflectorClusterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union()
}

// Documentation_for_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union ensures that UnionString
// implements the Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionString) Documentation_for_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union() {}

// Documentation_for_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union ensures that UnionUint32
// implements the Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionUint32) Documentation_for_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union() {}

// To_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_PeerGroup_RouteReflector) To_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union(i interface{}) (Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union, error) {
	if v, ok := i.(Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// Bgp_PeerGroup_Timers represents the /openconfig-bgp/bgp/peer-groups/peer-group/timers YANG schema element.
type Bgp_PeerGroup_Timers struct {
	ΛMetadata                     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ConnectRetry                  *float64          `path:"state/connect-retry" shadow-path:"config/connect-retry" module:"openconfig-bgp"`
	ΛConnectRetry                 []ygot.Annotation `path:"state/@connect-retry" ygotAnnotation:"true"`
	HoldTime                      *float64          `path:"state/hold-time" shadow-path:"config/hold-time" module:"openconfig-bgp"`
	ΛHoldTime                     []ygot.Annotation `path:"state/@hold-time" ygotAnnotation:"true"`
	KeepaliveInterval             *float64          `path:"state/keepalive-interval" shadow-path:"config/keepalive-interval" module:"openconfig-bgp"`
	ΛKeepaliveInterval            []ygot.Annotation `path:"state/@keepalive-interval" ygotAnnotation:"true"`
	MinimumAdvertisementInterval  *float64          `path:"state/minimum-advertisement-interval" shadow-path:"config/minimum-advertisement-interval" module:"openconfig-bgp"`
	ΛMinimumAdvertisementInterval []ygot.Annotation `path:"state/@minimum-advertisement-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_Timers) IsYANGGoStruct() {}

// GetConnectRetry retrieves the value of the leaf ConnectRetry from the Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectRetry is set, it can safely use t.GetConnectRetry()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectRetry == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Timers) GetConnectRetry() float64 {
	if t == nil || t.ConnectRetry == nil {
		return 30
	}
	return *t.ConnectRetry
}

// GetHoldTime retrieves the value of the leaf HoldTime from the Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Timers) GetHoldTime() float64 {
	if t == nil || t.HoldTime == nil {
		return 90
	}
	return *t.HoldTime
}

// GetKeepaliveInterval retrieves the value of the leaf KeepaliveInterval from the Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeepaliveInterval is set, it can safely use t.GetKeepaliveInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeepaliveInterval == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Timers) GetKeepaliveInterval() float64 {
	if t == nil || t.KeepaliveInterval == nil {
		return 30
	}
	return *t.KeepaliveInterval
}

// GetMinimumAdvertisementInterval retrieves the value of the leaf MinimumAdvertisementInterval from the Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinimumAdvertisementInterval is set, it can safely use t.GetMinimumAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinimumAdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Timers) GetMinimumAdvertisementInterval() float64 {
	if t == nil || t.MinimumAdvertisementInterval == nil {
		return 30
	}
	return *t.MinimumAdvertisementInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_Timers) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_Transport represents the /openconfig-bgp/bgp/peer-groups/peer-group/transport YANG schema element.
type Bgp_PeerGroup_Transport struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LocalAddress  *string           `path:"state/local-address" shadow-path:"config/local-address" module:"openconfig-bgp"`
	ΛLocalAddress []ygot.Annotation `path:"state/@local-address" ygotAnnotation:"true"`
	MtuDiscovery  *bool             `path:"state/mtu-discovery" shadow-path:"config/mtu-discovery" module:"openconfig-bgp"`
	ΛMtuDiscovery []ygot.Annotation `path:"state/@mtu-discovery" ygotAnnotation:"true"`
	PassiveMode   *bool             `path:"state/passive-mode" shadow-path:"config/passive-mode" module:"openconfig-bgp"`
	ΛPassiveMode  []ygot.Annotation `path:"state/@passive-mode" ygotAnnotation:"true"`
	TcpMss        *uint16           `path:"state/tcp-mss" shadow-path:"config/tcp-mss" module:"openconfig-bgp"`
	ΛTcpMss       []ygot.Annotation `path:"state/@tcp-mss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_Transport) IsYANGGoStruct() {}

// GetLocalAddress retrieves the value of the leaf LocalAddress from the Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAddress is set, it can safely use t.GetLocalAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Transport) GetLocalAddress() string {
	if t == nil || t.LocalAddress == nil {
		return ""
	}
	return *t.LocalAddress
}

// GetMtuDiscovery retrieves the value of the leaf MtuDiscovery from the Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtuDiscovery is set, it can safely use t.GetMtuDiscovery()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtuDiscovery == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Transport) GetMtuDiscovery() bool {
	if t == nil || t.MtuDiscovery == nil {
		return false
	}
	return *t.MtuDiscovery
}

// GetPassiveMode retrieves the value of the leaf PassiveMode from the Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PassiveMode is set, it can safely use t.GetPassiveMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PassiveMode == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Transport) GetPassiveMode() bool {
	if t == nil || t.PassiveMode == nil {
		return false
	}
	return *t.PassiveMode
}

// GetTcpMss retrieves the value of the leaf TcpMss from the Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TcpMss is set, it can safely use t.GetTcpMss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TcpMss == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_Transport) GetTcpMss() uint16 {
	if t == nil || t.TcpMss == nil {
		return 0
	}
	return *t.TcpMss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_Transport) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_PeerGroup_UseMultiplePaths represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths YANG schema element.
type Bgp_PeerGroup_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                    `path:"@" ygotAnnotation:"true"`
	Ebgp      *Bgp_PeerGroup_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-bgp"`
	ΛEbgp     []ygot.Annotation                    `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-bgp"`
	ΛEnabled  []ygot.Annotation                    `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *Bgp_PeerGroup_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-bgp"`
	ΛIbgp     []ygot.Annotation                    `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_UseMultiplePaths) GetOrCreateEbgp() *Bgp_PeerGroup_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &Bgp_PeerGroup_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *Bgp_PeerGroup_UseMultiplePaths) GetOrCreateIbgp() *Bgp_PeerGroup_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &Bgp_PeerGroup_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from Bgp_PeerGroup_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_UseMultiplePaths) GetEbgp() *Bgp_PeerGroup_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from Bgp_PeerGroup_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_PeerGroup_UseMultiplePaths) GetIbgp() *Bgp_PeerGroup_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Bgp_PeerGroup_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ebgp YANG schema element.
type Bgp_PeerGroup_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-bgp"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the Bgp_PeerGroup_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_PeerGroup_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_PeerGroup_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ibgp YANG schema element.
type Bgp_PeerGroup_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-bgp"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_PeerGroup_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_PeerGroup_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the Bgp_PeerGroup_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_PeerGroup_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_PeerGroup_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib represents the /openconfig-bgp/bgp/rib YANG schema element.
type Bgp_Rib struct {
	ΛMetadata     []ygot.Annotation                                       `path:"@" ygotAnnotation:"true"`
	AfiSafi       map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Rib_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-bgp"`
	ΛAfiSafi      []ygot.Annotation                                       `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	AttrSet       map[uint64]*Bgp_Rib_AttrSet                             `path:"attr-sets/attr-set" module:"openconfig-bgp"`
	ΛAttrSet      []ygot.Annotation                                       `path:"attr-sets/@attr-set" ygotAnnotation:"true"`
	Community     map[uint64]*Bgp_Rib_Community                           `path:"communities/community" module:"openconfig-bgp"`
	ΛCommunity    []ygot.Annotation                                       `path:"communities/@community" ygotAnnotation:"true"`
	ExtCommunity  map[uint64]*Bgp_Rib_ExtCommunity                        `path:"ext-communities/ext-community" module:"openconfig-bgp"`
	ΛExtCommunity []ygot.Annotation                                       `path:"ext-communities/@ext-community" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*Bgp_Rib_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Rib_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &Bgp_Rib_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_Rib_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *Bgp_Rib_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied Bgp_Rib_AfiSafi struct to the
// list AfiSafi of Bgp_Rib. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi already exist in the list, an error is
// returned.
func (t *Bgp_Rib) AppendAfiSafi(v *Bgp_Rib_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*Bgp_Rib_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// NewAttrSet creates a new entry in the AttrSet list of the
// Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib) NewAttrSet(Index uint64) (*Bgp_Rib_AttrSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AttrSet == nil {
		t.AttrSet = make(map[uint64]*Bgp_Rib_AttrSet)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AttrSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AttrSet", key)
	}

	t.AttrSet[key] = &Bgp_Rib_AttrSet{
		Index: &Index,
	}

	return t.AttrSet[key], nil
}

// RenameAttrSet renames an entry in the list AttrSet within
// the Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib) RenameAttrSet(oldK, newK uint64) error {
	if _, ok := t.AttrSet[newK]; ok {
		return fmt.Errorf("key %v already exists in AttrSet", newK)
	}

	e, ok := t.AttrSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AttrSet", oldK)
	}
	e.Index = &newK

	t.AttrSet[newK] = e
	delete(t.AttrSet, oldK)
	return nil
}

// GetOrCreateAttrSet retrieves the value with the specified keys from
// the receiver Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib) GetOrCreateAttrSet(Index uint64) *Bgp_Rib_AttrSet {

	key := Index

	if v, ok := t.AttrSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAttrSet(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAttrSet got unexpected error: %v", err))
	}
	return v
}

// GetAttrSet retrieves the value with the specified key from
// the AttrSet map field of Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib) GetAttrSet(Index uint64) *Bgp_Rib_AttrSet {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.AttrSet[key]; ok {
		return lm
	}
	return nil
}

// AppendAttrSet appends the supplied Bgp_Rib_AttrSet struct to the
// list AttrSet of Bgp_Rib. If the key value(s) specified in
// the supplied Bgp_Rib_AttrSet already exist in the list, an error is
// returned.
func (t *Bgp_Rib) AppendAttrSet(v *Bgp_Rib_AttrSet) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AttrSet == nil {
		t.AttrSet = make(map[uint64]*Bgp_Rib_AttrSet)
	}

	if _, ok := t.AttrSet[key]; ok {
		return fmt.Errorf("duplicate key for list AttrSet %v", key)
	}

	t.AttrSet[key] = v
	return nil
}

// NewCommunity creates a new entry in the Community list of the
// Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib) NewCommunity(Index uint64) (*Bgp_Rib_Community, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Community == nil {
		t.Community = make(map[uint64]*Bgp_Rib_Community)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Community[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Community", key)
	}

	t.Community[key] = &Bgp_Rib_Community{
		Index: &Index,
	}

	return t.Community[key], nil
}

// RenameCommunity renames an entry in the list Community within
// the Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib) RenameCommunity(oldK, newK uint64) error {
	if _, ok := t.Community[newK]; ok {
		return fmt.Errorf("key %v already exists in Community", newK)
	}

	e, ok := t.Community[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Community", oldK)
	}
	e.Index = &newK

	t.Community[newK] = e
	delete(t.Community, oldK)
	return nil
}

// GetOrCreateCommunity retrieves the value with the specified keys from
// the receiver Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib) GetOrCreateCommunity(Index uint64) *Bgp_Rib_Community {

	key := Index

	if v, ok := t.Community[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCommunity(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCommunity got unexpected error: %v", err))
	}
	return v
}

// GetCommunity retrieves the value with the specified key from
// the Community map field of Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib) GetCommunity(Index uint64) *Bgp_Rib_Community {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Community[key]; ok {
		return lm
	}
	return nil
}

// AppendCommunity appends the supplied Bgp_Rib_Community struct to the
// list Community of Bgp_Rib. If the key value(s) specified in
// the supplied Bgp_Rib_Community already exist in the list, an error is
// returned.
func (t *Bgp_Rib) AppendCommunity(v *Bgp_Rib_Community) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Community == nil {
		t.Community = make(map[uint64]*Bgp_Rib_Community)
	}

	if _, ok := t.Community[key]; ok {
		return fmt.Errorf("duplicate key for list Community %v", key)
	}

	t.Community[key] = v
	return nil
}

// NewExtCommunity creates a new entry in the ExtCommunity list of the
// Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib) NewExtCommunity(Index uint64) (*Bgp_Rib_ExtCommunity, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExtCommunity == nil {
		t.ExtCommunity = make(map[uint64]*Bgp_Rib_ExtCommunity)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExtCommunity[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExtCommunity", key)
	}

	t.ExtCommunity[key] = &Bgp_Rib_ExtCommunity{
		Index: &Index,
	}

	return t.ExtCommunity[key], nil
}

// RenameExtCommunity renames an entry in the list ExtCommunity within
// the Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib) RenameExtCommunity(oldK, newK uint64) error {
	if _, ok := t.ExtCommunity[newK]; ok {
		return fmt.Errorf("key %v already exists in ExtCommunity", newK)
	}

	e, ok := t.ExtCommunity[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ExtCommunity", oldK)
	}
	e.Index = &newK

	t.ExtCommunity[newK] = e
	delete(t.ExtCommunity, oldK)
	return nil
}

// GetOrCreateExtCommunity retrieves the value with the specified keys from
// the receiver Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib) GetOrCreateExtCommunity(Index uint64) *Bgp_Rib_ExtCommunity {

	key := Index

	if v, ok := t.ExtCommunity[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewExtCommunity(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateExtCommunity got unexpected error: %v", err))
	}
	return v
}

// GetExtCommunity retrieves the value with the specified key from
// the ExtCommunity map field of Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib) GetExtCommunity(Index uint64) *Bgp_Rib_ExtCommunity {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.ExtCommunity[key]; ok {
		return lm
	}
	return nil
}

// AppendExtCommunity appends the supplied Bgp_Rib_ExtCommunity struct to the
// list ExtCommunity of Bgp_Rib. If the key value(s) specified in
// the supplied Bgp_Rib_ExtCommunity already exist in the list, an error is
// returned.
func (t *Bgp_Rib) AppendExtCommunity(v *Bgp_Rib_ExtCommunity) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExtCommunity == nil {
		t.ExtCommunity = make(map[uint64]*Bgp_Rib_ExtCommunity)
	}

	if _, ok := t.ExtCommunity[key]; ok {
		return fmt.Errorf("duplicate key for list ExtCommunity %v", key)
	}

	t.ExtCommunity[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AfiSafi represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi YANG schema element.
type Bgp_Rib_AfiSafi struct {
	ΛMetadata       []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	AfiSafiName     E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"state/afi-safi-name|afi-safi-name" module:"openconfig-bgp"`
	ΛAfiSafiName    []ygot.Annotation                  `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	Ipv4SrtePolicy  *Bgp_Rib_AfiSafi_Ipv4SrtePolicy    `path:"ipv4-srte-policy" module:"openconfig-bgp"`
	ΛIpv4SrtePolicy []ygot.Annotation                  `path:"@ipv4-srte-policy" ygotAnnotation:"true"`
	Ipv4Unicast     *Bgp_Rib_AfiSafi_Ipv4Unicast       `path:"ipv4-unicast" module:"openconfig-bgp"`
	ΛIpv4Unicast    []ygot.Annotation                  `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6SrtePolicy  *Bgp_Rib_AfiSafi_Ipv6SrtePolicy    `path:"ipv6-srte-policy" module:"openconfig-bgp"`
	ΛIpv6SrtePolicy []ygot.Annotation                  `path:"@ipv6-srte-policy" ygotAnnotation:"true"`
	Ipv6Unicast     *Bgp_Rib_AfiSafi_Ipv6Unicast       `path:"ipv6-unicast" module:"openconfig-bgp"`
	ΛIpv6Unicast    []ygot.Annotation                  `path:"@ipv6-unicast" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateIpv4SrtePolicy retrieves the value of the Ipv4SrtePolicy field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi) GetOrCreateIpv4SrtePolicy() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy {
	if t.Ipv4SrtePolicy != nil {
		return t.Ipv4SrtePolicy
	}
	t.Ipv4SrtePolicy = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy{}
	return t.Ipv4SrtePolicy
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi) GetOrCreateIpv4Unicast() *Bgp_Rib_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &Bgp_Rib_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6SrtePolicy retrieves the value of the Ipv6SrtePolicy field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi) GetOrCreateIpv6SrtePolicy() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy {
	if t.Ipv6SrtePolicy != nil {
		return t.Ipv6SrtePolicy
	}
	t.Ipv6SrtePolicy = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy{}
	return t.Ipv6SrtePolicy
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi) GetOrCreateIpv6Unicast() *Bgp_Rib_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &Bgp_Rib_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetIpv4SrtePolicy returns the value of the Ipv4SrtePolicy struct pointer
// from Bgp_Rib_AfiSafi. If the receiver or the field Ipv4SrtePolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi) GetIpv4SrtePolicy() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy {
	if t != nil && t.Ipv4SrtePolicy != nil {
		return t.Ipv4SrtePolicy
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from Bgp_Rib_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi) GetIpv4Unicast() *Bgp_Rib_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6SrtePolicy returns the value of the Ipv6SrtePolicy struct pointer
// from Bgp_Rib_AfiSafi. If the receiver or the field Ipv6SrtePolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi) GetIpv6SrtePolicy() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy {
	if t != nil && t.Ipv6SrtePolicy != nil {
		return t.Ipv6SrtePolicy
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from Bgp_Rib_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi) GetIpv6Unicast() *Bgp_Rib_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the Bgp_Rib_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy struct {
	ΛMetadata []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	LocRib    *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib              `path:"loc-rib" module:"openconfig-bgp"`
	ΛLocRib   []ygot.Annotation                                   `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor `path:"neighbors/neighbor" module:"openconfig-bgp"`
	ΛNeighbor []ygot.Annotation                                   `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) NewNeighbor(NeighborAddress string) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetOrCreateNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor struct to the
// list Neighbor of Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) AppendNeighbor(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetOrCreateLocRib() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetLocRib() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route {

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                 `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                       `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                 `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                       `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                 `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                       `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                 `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                       `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                 `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                       `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                            `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                       `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                 `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                       `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                 `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                       `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                       `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                   `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                       `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	ΛAdjRibInPost    []ygot.Annotation                                      `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	ΛAdjRibInPre     []ygot.Annotation                                      `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	ΛAdjRibOutPost   []ygot.Annotation                                      `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	ΛAdjRibOutPre    []ygot.Annotation                                      `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                                `path:"state/neighbor-address|neighbor-address" module:"openconfig-bgp"`
	ΛNeighborAddress []ygot.Annotation                                      `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                              `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                              `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                      `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                                  `path:"state/best-path" module:"openconfig-bgp"`
	ΛBestPath          []ygot.Annotation                                                                      `path:"state/@best-path" ygotAnnotation:"true"`
	Color              *uint32                                                                                `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                      `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                      `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                      `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                      `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                           `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                      `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                      `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                      `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                      `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                  `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                      `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                            `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                            `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                               `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                     `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                               `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                     `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                               `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                     `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                               `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                     `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                               `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                     `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                          `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                     `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                               `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                     `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                               `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                     `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                     `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                 `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                     `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                 `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                       `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                 `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                       `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                 `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                       `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                 `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                       `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                 `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                       `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                            `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                       `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                 `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                       `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                 `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                       `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                       `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                   `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                       `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                              `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                              `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                      `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                      `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                      `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                      `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                      `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                           `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                      `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                      `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                      `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                      `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                  `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                      `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast struct {
	ΛMetadata []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	LocRib    *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib              `path:"loc-rib" module:"openconfig-bgp"`
	ΛLocRib   []ygot.Annotation                                `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor `path:"neighbors/neighbor" module:"openconfig-bgp"`
	ΛNeighbor []ygot.Annotation                                `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) NewNeighbor(NeighborAddress string) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Bgp_Rib_AfiSafi_Ipv4Unicast struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) GetOrCreateNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Bgp_Rib_AfiSafi_Ipv4Unicast. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) GetNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor struct to the
// list Neighbor of Bgp_Rib_AfiSafi_Ipv4Unicast. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) AppendNeighbor(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) GetOrCreateLocRib() *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from Bgp_Rib_AfiSafi_Ipv4Unicast. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) GetLocRib() *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib.
type Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key struct {
	Prefix string                                                `path:"prefix"`
	Origin Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union `path:"origin"`
	PathId uint32                                                `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) NewRoute(Prefix string, Origin Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.Origin = newK.Origin
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) GetOrCreateRoute(Prefix string, Origin Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route {

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, Origin, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) GetRoute(Prefix string, Origin Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: *v.Prefix,
		Origin: v.Origin,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                              `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                    `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                              `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                    `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                              `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                    `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                         `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                    `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                              `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                    `path:"state/@last-modified" ygotAnnotation:"true"`
	Origin             Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union                `path:"state/origin|origin" module:"openconfig-bgp"`
	ΛOrigin            []ygot.Annotation                                                    `path:"state/@origin|@origin" ygotAnnotation:"true"`
	PathId             *uint32                                                              `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                    `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                              `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                    `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                    `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                    `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetOrigin retrieves the value of the leaf Origin from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetOrigin() Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union {
	if t == nil || t.Origin == nil {
		return nil
	}
	return t.Origin
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/origin within the YANG schema.
// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString].
type Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union interface {
	// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString]
	Documentation_for_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union()
}

// Documentation_for_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union ensures that E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union interface.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Documentation_for_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union() {
}

// Documentation_for_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union ensures that UnionString
// implements the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union interface.
func (UnionString) Documentation_for_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union() {}

// To_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) To_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union(i interface{}) (Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, error) {
	if v, ok := i.(Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	ΛAdjRibInPost    []ygot.Annotation                                   `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	ΛAdjRibInPre     []ygot.Annotation                                   `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	ΛAdjRibOutPost   []ygot.Annotation                                   `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	ΛAdjRibOutPre    []ygot.Annotation                                   `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                             `path:"state/neighbor-address|neighbor-address" module:"openconfig-bgp"`
	ΛNeighborAddress []ygot.Annotation                                   `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                        `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                        `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                             `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                   `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                               `path:"state/best-path" module:"openconfig-bgp"`
	ΛBestPath          []ygot.Annotation                                                                   `path:"state/@best-path" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                             `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                   `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                             `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                   `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                        `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                   `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                             `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                   `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                             `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                   `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                             `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                   `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                   `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                               `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                   `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                      `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                      `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                            `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                  `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                            `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                  `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                            `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                  `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                       `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                  `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                            `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                  `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                            `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                  `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                            `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                  `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                  `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                              `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                  `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                    `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                              `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                    `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                              `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                    `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                              `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                    `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                         `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                    `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                              `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                    `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                              `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                    `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                              `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                    `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                    `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                    `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                        `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                        `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                             `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                   `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                             `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                   `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                             `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                   `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                        `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                   `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                             `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                   `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                             `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                   `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                             `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                   `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                   `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                               `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                   `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy struct {
	ΛMetadata []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	LocRib    *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib              `path:"loc-rib" module:"openconfig-bgp"`
	ΛLocRib   []ygot.Annotation                                   `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor `path:"neighbors/neighbor" module:"openconfig-bgp"`
	ΛNeighbor []ygot.Annotation                                   `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) NewNeighbor(NeighborAddress string) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetOrCreateNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor struct to the
// list Neighbor of Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) AppendNeighbor(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetOrCreateLocRib() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetLocRib() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route {

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                 `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                       `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                 `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                       `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                 `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                       `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                 `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                       `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                 `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                       `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                            `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                       `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                 `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                       `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                 `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                       `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                       `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                   `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                       `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	ΛAdjRibInPost    []ygot.Annotation                                      `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	ΛAdjRibInPre     []ygot.Annotation                                      `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	ΛAdjRibOutPost   []ygot.Annotation                                      `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	ΛAdjRibOutPre    []ygot.Annotation                                      `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                                `path:"state/neighbor-address|neighbor-address" module:"openconfig-bgp"`
	ΛNeighborAddress []ygot.Annotation                                      `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                              `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                              `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                      `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                                  `path:"state/best-path" module:"openconfig-bgp"`
	ΛBestPath          []ygot.Annotation                                                                      `path:"state/@best-path" ygotAnnotation:"true"`
	Color              *uint32                                                                                `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                      `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                      `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                      `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                      `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                           `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                      `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                      `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                      `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                      `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                  `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                      `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                            `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                            `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                               `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                     `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                               `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                     `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                               `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                     `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                               `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                     `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                               `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                     `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                          `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                     `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                               `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                     `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                               `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                     `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                     `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                 `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                     `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                 `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                       `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                 `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                       `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                 `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                       `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                 `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                       `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                 `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                       `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                            `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                       `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                 `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                       `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                 `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                       `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                       `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                   `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                       `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                              `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                              `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                      `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                `path:"state/color|color" module:"openconfig-bgp"`
	ΛColor             []ygot.Annotation                                                                      `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                      `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint          []ygot.Annotation                                                                      `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                      `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                           `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                      `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                      `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                      `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                      `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                  `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                      `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast struct {
	ΛMetadata []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	LocRib    *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib              `path:"loc-rib" module:"openconfig-bgp"`
	ΛLocRib   []ygot.Annotation                                `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor `path:"neighbors/neighbor" module:"openconfig-bgp"`
	ΛNeighbor []ygot.Annotation                                `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) NewNeighbor(NeighborAddress string) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Bgp_Rib_AfiSafi_Ipv6Unicast struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) GetOrCreateNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Bgp_Rib_AfiSafi_Ipv6Unicast. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) GetNeighbor(NeighborAddress string) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor struct to the
// list Neighbor of Bgp_Rib_AfiSafi_Ipv6Unicast. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) AppendNeighbor(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) GetOrCreateLocRib() *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from Bgp_Rib_AfiSafi_Ipv6Unicast. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) GetLocRib() *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib.
type Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key struct {
	Prefix string                                                `path:"prefix"`
	Origin Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union `path:"origin"`
	PathId uint32                                                `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) NewRoute(Prefix string, Origin Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.Origin = newK.Origin
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) GetOrCreateRoute(Prefix string, Origin Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route {

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, Origin, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) GetRoute(Prefix string, Origin Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: *v.Prefix,
		Origin: v.Origin,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                              `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                    `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                              `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                    `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                              `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                    `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                         `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                    `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                              `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                    `path:"state/@last-modified" ygotAnnotation:"true"`
	Origin             Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union                `path:"state/origin|origin" module:"openconfig-bgp"`
	ΛOrigin            []ygot.Annotation                                                    `path:"state/@origin|@origin" ygotAnnotation:"true"`
	PathId             *uint32                                                              `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                    `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                              `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                    `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                    `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                    `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetOrigin retrieves the value of the leaf Origin from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetOrigin() Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union {
	if t == nil || t.Origin == nil {
		return nil
	}
	return t.Origin
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/origin within the YANG schema.
// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString].
type Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union interface {
	// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString]
	Documentation_for_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union()
}

// Documentation_for_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union ensures that E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union interface.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Documentation_for_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union() {
}

// Documentation_for_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union ensures that UnionString
// implements the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union interface.
func (UnionString) Documentation_for_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union() {}

// To_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) To_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union(i interface{}) (Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, error) {
	if v, ok := i.(Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	ΛAdjRibInPost    []ygot.Annotation                                   `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	ΛAdjRibInPre     []ygot.Annotation                                   `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	ΛAdjRibOutPost   []ygot.Annotation                                   `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	ΛAdjRibOutPre    []ygot.Annotation                                   `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                             `path:"state/neighbor-address|neighbor-address" module:"openconfig-bgp"`
	ΛNeighborAddress []ygot.Annotation                                   `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibInPost() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibInPre() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibOutPost() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibOutPre() *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                        `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                        `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                             `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                   `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                               `path:"state/best-path" module:"openconfig-bgp"`
	ΛBestPath          []ygot.Annotation                                                                   `path:"state/@best-path" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                             `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                   `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                             `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                   `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                        `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                   `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                             `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                   `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                             `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                   `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                             `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                   `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                   `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                               `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                   `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                      `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                      `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                            `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                  `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                            `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                  `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                            `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                  `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                       `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                  `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                            `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                  `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                            `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                  `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                            `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                  `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                  `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                              `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                  `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route {

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                    `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                              `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                    `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                              `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                    `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                              `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                    `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                         `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                    `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                              `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                    `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                              `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                    `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                              `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                    `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                    `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                    `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                        `path:"@" ygotAnnotation:"true"`
	Route     map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-bgp"`
	ΛRoute    []ygot.Annotation                                                                                                        `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) IsYANGGoStruct() {}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) NewRoute(Prefix string, PathId uint32) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route)
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) GetOrCreateRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route {

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) GetRoute(Prefix string, PathId uint32) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct to the
// list Route of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) AppendRoute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                             `path:"state/attr-index" module:"openconfig-bgp"`
	ΛAttrIndex         []ygot.Annotation                                                                   `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                             `path:"state/community-index" module:"openconfig-bgp"`
	ΛCommunityIndex    []ygot.Annotation                                                                   `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                             `path:"state/ext-community-index" module:"openconfig-bgp"`
	ΛExtCommunityIndex []ygot.Annotation                                                                   `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                        `path:"state/invalid-reason" module:"openconfig-bgp"`
	ΛInvalidReason     []ygot.Annotation                                                                   `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                             `path:"state/last-modified" module:"openconfig-bgp"`
	ΛLastModified      []ygot.Annotation                                                                   `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                             `path:"state/path-id|path-id" module:"openconfig-bgp"`
	ΛPathId            []ygot.Annotation                                                                   `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                             `path:"state/prefix|prefix" module:"openconfig-bgp"`
	ΛPrefix            []ygot.Annotation                                                                   `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-bgp"`
	ΛUnknownAttribute  []ygot.Annotation                                                                   `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                               `path:"state/valid-route" module:"openconfig-bgp"`
	ΛValidRoute        []ygot.Annotation                                                                   `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-bgp"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-bgp"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-bgp"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-bgp"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-bgp"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-bgp"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-bgp"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {}

// GetAttrLen retrieves the value of the leaf AttrLen from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set YANG schema element.
type Bgp_Rib_AttrSet struct {
	ΛMetadata            []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Aggregator           *Bgp_Rib_AttrSet_Aggregator            `path:"aggregator" module:"openconfig-bgp"`
	ΛAggregator          []ygot.Annotation                      `path:"@aggregator" ygotAnnotation:"true"`
	Aigp                 *uint64                                `path:"state/aigp" module:"openconfig-bgp"`
	ΛAigp                []ygot.Annotation                      `path:"state/@aigp" ygotAnnotation:"true"`
	AsSegment            []*Bgp_Rib_AttrSet_AsSegment           `path:"as-path/as-segment" module:"openconfig-bgp"`
	ΛAsSegment           []ygot.Annotation                      `path:"as-path/@as-segment" ygotAnnotation:"true"`
	As4Segment           []*Bgp_Rib_AttrSet_As4Segment          `path:"as4-path/as4-segment" module:"openconfig-bgp"`
	ΛAs4Segment          []ygot.Annotation                      `path:"as4-path/@as4-segment" ygotAnnotation:"true"`
	AtomicAggregate      *bool                                  `path:"state/atomic-aggregate" module:"openconfig-bgp"`
	ΛAtomicAggregate     []ygot.Annotation                      `path:"state/@atomic-aggregate" ygotAnnotation:"true"`
	ClusterList          []string                               `path:"state/cluster-list" module:"openconfig-bgp"`
	ΛClusterList         []ygot.Annotation                      `path:"state/@cluster-list" ygotAnnotation:"true"`
	Index                *uint64                                `path:"state/index|index" module:"openconfig-bgp"`
	ΛIndex               []ygot.Annotation                      `path:"state/@index|@index" ygotAnnotation:"true"`
	LocalPref            *uint32                                `path:"state/local-pref" module:"openconfig-bgp"`
	ΛLocalPref           []ygot.Annotation                      `path:"state/@local-pref" ygotAnnotation:"true"`
	Med                  *uint32                                `path:"state/med" module:"openconfig-bgp"`
	ΛMed                 []ygot.Annotation                      `path:"state/@med" ygotAnnotation:"true"`
	NextHop              *string                                `path:"state/next-hop" module:"openconfig-bgp"`
	ΛNextHop             []ygot.Annotation                      `path:"state/@next-hop" ygotAnnotation:"true"`
	Origin               E_OpenconfigBgpTypes_BgpOriginAttrType `path:"state/origin" module:"openconfig-bgp"`
	ΛOrigin              []ygot.Annotation                      `path:"state/@origin" ygotAnnotation:"true"`
	OriginatorId         *string                                `path:"state/originator-id" module:"openconfig-bgp"`
	ΛOriginatorId        []ygot.Annotation                      `path:"state/@originator-id" ygotAnnotation:"true"`
	TunnelEncapsulation  *Bgp_Rib_AttrSet_TunnelEncapsulation   `path:"tunnel-encapsulation" module:"openconfig-bgp"`
	ΛTunnelEncapsulation []ygot.Annotation                      `path:"@tunnel-encapsulation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet) IsYANGGoStruct() {}

// GetOrCreateAggregator retrieves the value of the Aggregator field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AttrSet) GetOrCreateAggregator() *Bgp_Rib_AttrSet_Aggregator {
	if t.Aggregator != nil {
		return t.Aggregator
	}
	t.Aggregator = &Bgp_Rib_AttrSet_Aggregator{}
	return t.Aggregator
}

// GetOrCreateTunnelEncapsulation retrieves the value of the TunnelEncapsulation field
// or returns the existing field if it already exists.
func (t *Bgp_Rib_AttrSet) GetOrCreateTunnelEncapsulation() *Bgp_Rib_AttrSet_TunnelEncapsulation {
	if t.TunnelEncapsulation != nil {
		return t.TunnelEncapsulation
	}
	t.TunnelEncapsulation = &Bgp_Rib_AttrSet_TunnelEncapsulation{}
	return t.TunnelEncapsulation
}

// GetAggregator returns the value of the Aggregator struct pointer
// from Bgp_Rib_AttrSet. If the receiver or the field Aggregator is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AttrSet) GetAggregator() *Bgp_Rib_AttrSet_Aggregator {
	if t != nil && t.Aggregator != nil {
		return t.Aggregator
	}
	return nil
}

// GetTunnelEncapsulation returns the value of the TunnelEncapsulation struct pointer
// from Bgp_Rib_AttrSet. If the receiver or the field TunnelEncapsulation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Bgp_Rib_AttrSet) GetTunnelEncapsulation() *Bgp_Rib_AttrSet_TunnelEncapsulation {
	if t != nil && t.TunnelEncapsulation != nil {
		return t.TunnelEncapsulation
	}
	return nil
}

// GetAigp retrieves the value of the leaf Aigp from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Aigp is set, it can safely use t.GetAigp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Aigp == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetAigp() uint64 {
	if t == nil || t.Aigp == nil {
		return 0
	}
	return *t.Aigp
}

// GetAtomicAggregate retrieves the value of the leaf AtomicAggregate from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AtomicAggregate is set, it can safely use t.GetAtomicAggregate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AtomicAggregate == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetAtomicAggregate() bool {
	if t == nil || t.AtomicAggregate == nil {
		return false
	}
	return *t.AtomicAggregate
}

// GetClusterList retrieves the value of the leaf ClusterList from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ClusterList is set, it can safely use t.GetClusterList()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ClusterList == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetClusterList() []string {
	if t == nil || t.ClusterList == nil {
		return nil
	}
	return t.ClusterList
}

// GetIndex retrieves the value of the leaf Index from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLocalPref retrieves the value of the leaf LocalPref from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalPref is set, it can safely use t.GetLocalPref()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalPref == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetLocalPref() uint32 {
	if t == nil || t.LocalPref == nil {
		return 0
	}
	return *t.LocalPref
}

// GetMed retrieves the value of the leaf Med from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Med is set, it can safely use t.GetMed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Med == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetMed() uint32 {
	if t == nil || t.Med == nil {
		return 0
	}
	return *t.Med
}

// GetNextHop retrieves the value of the leaf NextHop from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetNextHop() string {
	if t == nil || t.NextHop == nil {
		return ""
	}
	return *t.NextHop
}

// GetOrigin retrieves the value of the leaf Origin from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetOrigin() E_OpenconfigBgpTypes_BgpOriginAttrType {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// GetOriginatorId retrieves the value of the leaf OriginatorId from the Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginatorId is set, it can safely use t.GetOriginatorId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginatorId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet) GetOriginatorId() string {
	if t == nil || t.OriginatorId == nil {
		return ""
	}
	return *t.OriginatorId
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AttrSet struct, which is a YANG list entry.
func (t *Bgp_Rib_AttrSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AttrSet_Aggregator represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/aggregator YANG schema element.
type Bgp_Rib_AttrSet_Aggregator struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   *string           `path:"state/address" module:"openconfig-bgp"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
	As        *uint32           `path:"state/as" module:"openconfig-bgp"`
	ΛAs       []ygot.Annotation `path:"state/@as" ygotAnnotation:"true"`
	As4       *uint32           `path:"state/as4" module:"openconfig-bgp"`
	ΛAs4      []ygot.Annotation `path:"state/@as4" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_Aggregator implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_Aggregator) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the Bgp_Rib_AttrSet_Aggregator
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_Aggregator) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetAs retrieves the value of the leaf As from the Bgp_Rib_AttrSet_Aggregator
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As is set, it can safely use t.GetAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_Aggregator) GetAs() uint32 {
	if t == nil || t.As == nil {
		return 0
	}
	return *t.As
}

// GetAs4 retrieves the value of the leaf As4 from the Bgp_Rib_AttrSet_Aggregator
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As4 is set, it can safely use t.GetAs4()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As4 == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_Aggregator) GetAs4() uint32 {
	if t == nil || t.As4 == nil {
		return 0
	}
	return *t.As4
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_Aggregator) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_Aggregator"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_Aggregator) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AttrSet_As4Segment represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as4-path/as4-segment YANG schema element.
type Bgp_Rib_AttrSet_As4Segment struct {
	ΛMetadata []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Member    []uint32                               `path:"state/member" module:"openconfig-bgp"`
	ΛMember   []ygot.Annotation                      `path:"state/@member" ygotAnnotation:"true"`
	Type      E_OpenconfigBgpTypes_AsPathSegmentType `path:"state/type" module:"openconfig-bgp"`
	ΛType     []ygot.Annotation                      `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_As4Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_As4Segment) IsYANGGoStruct() {}

// GetMember retrieves the value of the leaf Member from the Bgp_Rib_AttrSet_As4Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Member is set, it can safely use t.GetMember()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Member == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_As4Segment) GetMember() []uint32 {
	if t == nil || t.Member == nil {
		return nil
	}
	return t.Member
}

// GetType retrieves the value of the leaf Type from the Bgp_Rib_AttrSet_As4Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_As4Segment) GetType() E_OpenconfigBgpTypes_AsPathSegmentType {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_As4Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_As4Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_As4Segment) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AttrSet_AsSegment represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as-path/as-segment YANG schema element.
type Bgp_Rib_AttrSet_AsSegment struct {
	ΛMetadata []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Member    []uint32                               `path:"state/member" module:"openconfig-bgp"`
	ΛMember   []ygot.Annotation                      `path:"state/@member" ygotAnnotation:"true"`
	Type      E_OpenconfigBgpTypes_AsPathSegmentType `path:"state/type" module:"openconfig-bgp"`
	ΛType     []ygot.Annotation                      `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_AsSegment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_AsSegment) IsYANGGoStruct() {}

// GetMember retrieves the value of the leaf Member from the Bgp_Rib_AttrSet_AsSegment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Member is set, it can safely use t.GetMember()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Member == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_AsSegment) GetMember() []uint32 {
	if t == nil || t.Member == nil {
		return nil
	}
	return t.Member
}

// GetType retrieves the value of the leaf Type from the Bgp_Rib_AttrSet_AsSegment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_AsSegment) GetType() E_OpenconfigBgpTypes_AsPathSegmentType {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_AsSegment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_AsSegment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_AsSegment) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_AttrSet_TunnelEncapsulation represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation YANG schema element.
type Bgp_Rib_AttrSet_TunnelEncapsulation struct {
	ΛMetadata []ygot.Annotation                                                                                 `path:"@" ygotAnnotation:"true"`
	Tunnel    map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel `path:"tunnels/tunnel" module:"openconfig-bgp"`
	ΛTunnel   []ygot.Annotation                                                                                 `path:"tunnels/@tunnel" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_TunnelEncapsulation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_TunnelEncapsulation) IsYANGGoStruct() {}

// NewTunnel creates a new entry in the Tunnel list of the
// Bgp_Rib_AttrSet_TunnelEncapsulation struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) NewTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tunnel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tunnel", key)
	}

	t.Tunnel[key] = &Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel{
		Type: Type,
	}

	return t.Tunnel[key], nil
}

// RenameTunnel renames an entry in the list Tunnel within
// the Bgp_Rib_AttrSet_TunnelEncapsulation struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) RenameTunnel(oldK, newK E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) error {
	if _, ok := t.Tunnel[newK]; ok {
		return fmt.Errorf("key %v already exists in Tunnel", newK)
	}

	e, ok := t.Tunnel[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Tunnel", oldK)
	}
	e.Type = newK

	t.Tunnel[newK] = e
	delete(t.Tunnel, oldK)
	return nil
}

// GetOrCreateTunnel retrieves the value with the specified keys from
// the receiver Bgp_Rib_AttrSet_TunnelEncapsulation. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) GetOrCreateTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel {

	key := Type

	if v, ok := t.Tunnel[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTunnel(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTunnel got unexpected error: %v", err))
	}
	return v
}

// GetTunnel retrieves the value with the specified key from
// the Tunnel map field of Bgp_Rib_AttrSet_TunnelEncapsulation. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) GetTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Tunnel[key]; ok {
		return lm
	}
	return nil
}

// AppendTunnel appends the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct to the
// list Tunnel of Bgp_Rib_AttrSet_TunnelEncapsulation. If the key value(s) specified in
// the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) AppendTunnel(v *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel)
	}

	if _, ok := t.Tunnel[key]; ok {
		return fmt.Errorf("duplicate key for list Tunnel %v", key)
	}

	t.Tunnel[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_TunnelEncapsulation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel YANG schema element.
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct {
	ΛMetadata []ygot.Annotation                                                                                               `path:"@" ygotAnnotation:"true"`
	Subtlv    map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv `path:"subtlvs/subtlv" module:"openconfig-bgp"`
	ΛSubtlv   []ygot.Annotation                                                                                               `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	Type      E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE                                                               `path:"state/type|type" module:"openconfig-bgp"`
	ΛType     []ygot.Annotation                                                                                               `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) NewSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) RenameSubtlv(oldK, newK E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) GetOrCreateSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) GetSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct to the
// list Subtlv of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel. If the key value(s) specified in
// the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) AppendSubtlv(v *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// GetType retrieves the value of the leaf Type from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) GetType() E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct, which is a YANG list entry.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv YANG schema element.
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct {
	ΛMetadata       []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	BindingSid      Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union           `path:"state/binding-sid" module:"openconfig-bgp"`
	ΛBindingSid     []ygot.Annotation                                                            `path:"state/@binding-sid" ygotAnnotation:"true"`
	Colors          []uint32                                                                     `path:"state/colors" module:"openconfig-bgp"`
	ΛColors         []ygot.Annotation                                                            `path:"state/@colors" ygotAnnotation:"true"`
	Preference      *uint32                                                                      `path:"state/preference" module:"openconfig-bgp"`
	ΛPreference     []ygot.Annotation                                                            `path:"state/@preference" ygotAnnotation:"true"`
	RemoteEndpoint  map[string]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint `path:"remote-endpoints/remote-endpoint" module:"openconfig-bgp"`
	ΛRemoteEndpoint []ygot.Annotation                                                            `path:"remote-endpoints/@remote-endpoint" ygotAnnotation:"true"`
	SegmentList     map[uint64]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList    `path:"segment-lists/segment-list" module:"openconfig-bgp"`
	ΛSegmentList    []ygot.Annotation                                                            `path:"segment-lists/@segment-list" ygotAnnotation:"true"`
	Type            E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE                     `path:"state/type|type" module:"openconfig-bgp"`
	ΛType           []ygot.Annotation                                                            `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) IsYANGGoStruct() {}

// NewRemoteEndpoint creates a new entry in the RemoteEndpoint list of the
// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) NewRemoteEndpoint(Endpoint string) (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteEndpoint == nil {
		t.RemoteEndpoint = make(map[string]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint)
	}

	key := Endpoint

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RemoteEndpoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RemoteEndpoint", key)
	}

	t.RemoteEndpoint[key] = &Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint{
		Endpoint: &Endpoint,
	}

	return t.RemoteEndpoint[key], nil
}

// RenameRemoteEndpoint renames an entry in the list RemoteEndpoint within
// the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) RenameRemoteEndpoint(oldK, newK string) error {
	if _, ok := t.RemoteEndpoint[newK]; ok {
		return fmt.Errorf("key %v already exists in RemoteEndpoint", newK)
	}

	e, ok := t.RemoteEndpoint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in RemoteEndpoint", oldK)
	}
	e.Endpoint = &newK

	t.RemoteEndpoint[newK] = e
	delete(t.RemoteEndpoint, oldK)
	return nil
}

// GetOrCreateRemoteEndpoint retrieves the value with the specified keys from
// the receiver Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetOrCreateRemoteEndpoint(Endpoint string) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint {

	key := Endpoint

	if v, ok := t.RemoteEndpoint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRemoteEndpoint(Endpoint)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRemoteEndpoint got unexpected error: %v", err))
	}
	return v
}

// GetRemoteEndpoint retrieves the value with the specified key from
// the RemoteEndpoint map field of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetRemoteEndpoint(Endpoint string) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint {

	if t == nil {
		return nil
	}

	key := Endpoint

	if lm, ok := t.RemoteEndpoint[key]; ok {
		return lm
	}
	return nil
}

// AppendRemoteEndpoint appends the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint struct to the
// list RemoteEndpoint of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the key value(s) specified in
// the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) AppendRemoteEndpoint(v *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) error {
	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key received for Endpoint")
	}

	key := *v.Endpoint

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteEndpoint == nil {
		t.RemoteEndpoint = make(map[string]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint)
	}

	if _, ok := t.RemoteEndpoint[key]; ok {
		return fmt.Errorf("duplicate key for list RemoteEndpoint %v", key)
	}

	t.RemoteEndpoint[key] = v
	return nil
}

// NewSegmentList creates a new entry in the SegmentList list of the
// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) NewSegmentList(InstanceId uint64) (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint64]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList)
	}

	key := InstanceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SegmentList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SegmentList", key)
	}

	t.SegmentList[key] = &Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList{
		InstanceId: &InstanceId,
	}

	return t.SegmentList[key], nil
}

// RenameSegmentList renames an entry in the list SegmentList within
// the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) RenameSegmentList(oldK, newK uint64) error {
	if _, ok := t.SegmentList[newK]; ok {
		return fmt.Errorf("key %v already exists in SegmentList", newK)
	}

	e, ok := t.SegmentList[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SegmentList", oldK)
	}
	e.InstanceId = &newK

	t.SegmentList[newK] = e
	delete(t.SegmentList, oldK)
	return nil
}

// GetOrCreateSegmentList retrieves the value with the specified keys from
// the receiver Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetOrCreateSegmentList(InstanceId uint64) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList {

	key := InstanceId

	if v, ok := t.SegmentList[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSegmentList(InstanceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSegmentList got unexpected error: %v", err))
	}
	return v
}

// GetSegmentList retrieves the value with the specified key from
// the SegmentList map field of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetSegmentList(InstanceId uint64) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList {

	if t == nil {
		return nil
	}

	key := InstanceId

	if lm, ok := t.SegmentList[key]; ok {
		return lm
	}
	return nil
}

// AppendSegmentList appends the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct to the
// list SegmentList of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the key value(s) specified in
// the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) AppendSegmentList(v *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) error {
	if v.InstanceId == nil {
		return fmt.Errorf("invalid nil key received for InstanceId")
	}

	key := *v.InstanceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint64]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList)
	}

	if _, ok := t.SegmentList[key]; ok {
		return fmt.Errorf("duplicate key for list SegmentList %v", key)
	}

	t.SegmentList[key] = v
	return nil
}

// GetBindingSid retrieves the value of the leaf BindingSid from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BindingSid is set, it can safely use t.GetBindingSid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BindingSid == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetBindingSid() Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union {
	if t == nil || t.BindingSid == nil {
		return nil
	}
	return t.BindingSid
}

// GetColors retrieves the value of the leaf Colors from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Colors is set, it can safely use t.GetColors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Colors == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetColors() []uint32 {
	if t == nil || t.Colors == nil {
		return nil
	}
	return t.Colors
}

// GetPreference retrieves the value of the leaf Preference from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preference is set, it can safely use t.GetPreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preference == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetPreference() uint32 {
	if t == nil || t.Preference == nil {
		return 100
	}
	return *t.Preference
}

// GetType retrieves the value of the leaf Type from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetType() E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct, which is a YANG list entry.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union()
}

// Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union() {
}

// Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union ensures that UnionString
// implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface.
func (UnionString) Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union() {
}

// Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union ensures that UnionUint32
// implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface.
func (UnionUint32) Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union() {
}

// To_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) To_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union(i interface{}) (Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union, error) {
	if v, ok := i.(Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints/remote-endpoint YANG schema element.
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	As        *uint32           `path:"state/as" module:"openconfig-bgp"`
	ΛAs       []ygot.Annotation `path:"state/@as" ygotAnnotation:"true"`
	Endpoint  *string           `path:"state/endpoint|endpoint" module:"openconfig-bgp"`
	ΛEndpoint []ygot.Annotation `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) IsYANGGoStruct() {}

// GetAs retrieves the value of the leaf As from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As is set, it can safely use t.GetAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) GetAs() uint32 {
	if t == nil || t.As == nil {
		return 0
	}
	return *t.As
}

// GetEndpoint retrieves the value of the leaf Endpoint from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint struct, which is a YANG list entry.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	return map[string]interface{}{
		"endpoint": *t.Endpoint,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list YANG schema element.
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct {
	ΛMetadata   []ygot.Annotation                                                                 `path:"@" ygotAnnotation:"true"`
	InstanceId  *uint64                                                                           `path:"state/instance-id|instance-id" module:"openconfig-bgp"`
	ΛInstanceId []ygot.Annotation                                                                 `path:"state/@instance-id|@instance-id" ygotAnnotation:"true"`
	Segment     map[uint64]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment `path:"segments/segment" module:"openconfig-bgp"`
	ΛSegment    []ygot.Annotation                                                                 `path:"segments/@segment" ygotAnnotation:"true"`
	Weight      *uint32                                                                           `path:"state/weight" module:"openconfig-bgp"`
	ΛWeight     []ygot.Annotation                                                                 `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) IsYANGGoStruct() {}

// NewSegment creates a new entry in the Segment list of the
// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct. The keys of the list are populated from the input
// arguments.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) NewSegment(Index uint64) (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Segment == nil {
		t.Segment = make(map[uint64]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Segment[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Segment", key)
	}

	t.Segment[key] = &Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment{
		Index: &Index,
	}

	return t.Segment[key], nil
}

// RenameSegment renames an entry in the list Segment within
// the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) RenameSegment(oldK, newK uint64) error {
	if _, ok := t.Segment[newK]; ok {
		return fmt.Errorf("key %v already exists in Segment", newK)
	}

	e, ok := t.Segment[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Segment", oldK)
	}
	e.Index = &newK

	t.Segment[newK] = e
	delete(t.Segment, oldK)
	return nil
}

// GetOrCreateSegment retrieves the value with the specified keys from
// the receiver Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetOrCreateSegment(Index uint64) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment {

	key := Index

	if v, ok := t.Segment[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSegment(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSegment got unexpected error: %v", err))
	}
	return v
}

// GetSegment retrieves the value with the specified key from
// the Segment map field of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetSegment(Index uint64) *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Segment[key]; ok {
		return lm
	}
	return nil
}

// AppendSegment appends the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment struct to the
// list Segment of Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList. If the key value(s) specified in
// the supplied Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment already exist in the list, an error is
// returned.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) AppendSegment(v *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Segment == nil {
		t.Segment = make(map[uint64]*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment)
	}

	if _, ok := t.Segment[key]; ok {
		return fmt.Errorf("duplicate key for list Segment %v", key)
	}

	t.Segment[key] = v
	return nil
}

// GetInstanceId retrieves the value of the leaf InstanceId from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstanceId is set, it can safely use t.GetInstanceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstanceId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetInstanceId() uint64 {
	if t == nil || t.InstanceId == nil {
		return 0
	}
	return *t.InstanceId
}

// GetWeight retrieves the value of the leaf Weight from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetWeight() uint32 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct, which is a YANG list entry.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceId == nil {
		return nil, fmt.Errorf("nil value for key InstanceId")
	}

	return map[string]interface{}{
		"instance-id": *t.InstanceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment YANG schema element.
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment struct {
	ΛMetadata          []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	Index              *uint64                                                                         `path:"state/index|index" module:"openconfig-bgp"`
	ΛIndex             []ygot.Annotation                                                               `path:"state/@index|@index" ygotAnnotation:"true"`
	LocalInterfaceId   *uint32                                                                         `path:"state/local-interface-id" module:"openconfig-bgp"`
	ΛLocalInterfaceId  []ygot.Annotation                                                               `path:"state/@local-interface-id" ygotAnnotation:"true"`
	LocalIpv4Address   *string                                                                         `path:"state/local-ipv4-address" module:"openconfig-bgp"`
	ΛLocalIpv4Address  []ygot.Annotation                                                               `path:"state/@local-ipv4-address" ygotAnnotation:"true"`
	LocalIpv6Address   *string                                                                         `path:"state/local-ipv6-address" module:"openconfig-bgp"`
	ΛLocalIpv6Address  []ygot.Annotation                                                               `path:"state/@local-ipv6-address" ygotAnnotation:"true"`
	MplsBos            *bool                                                                           `path:"state/mpls-bos" module:"openconfig-bgp"`
	ΛMplsBos           []ygot.Annotation                                                               `path:"state/@mpls-bos" ygotAnnotation:"true"`
	MplsTc             *uint8                                                                          `path:"state/mpls-tc" module:"openconfig-bgp"`
	ΛMplsTc            []ygot.Annotation                                                               `path:"state/@mpls-tc" ygotAnnotation:"true"`
	MplsTtl            *uint8                                                                          `path:"state/mpls-ttl" module:"openconfig-bgp"`
	ΛMplsTtl           []ygot.Annotation                                                               `path:"state/@mpls-ttl" ygotAnnotation:"true"`
	RemoteIpv4Address  *string                                                                         `path:"state/remote-ipv4-address" module:"openconfig-bgp"`
	ΛRemoteIpv4Address []ygot.Annotation                                                               `path:"state/@remote-ipv4-address" ygotAnnotation:"true"`
	RemoteIpv6Address  *string                                                                         `path:"state/remote-ipv6-address" module:"openconfig-bgp"`
	ΛRemoteIpv6Address []ygot.Annotation                                                               `path:"state/@remote-ipv6-address" ygotAnnotation:"true"`
	Sid                Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union `path:"state/sid" module:"openconfig-bgp"`
	ΛSid               []ygot.Annotation                                                               `path:"state/@sid" ygotAnnotation:"true"`
	Type               E_Segment_Type                                                                  `path:"state/type" module:"openconfig-bgp"`
	ΛType              []ygot.Annotation                                                               `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) IsYANGGoStruct() {}

// GetIndex retrieves the value of the leaf Index from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLocalInterfaceId retrieves the value of the leaf LocalInterfaceId from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalInterfaceId is set, it can safely use t.GetLocalInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalInterfaceId == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetLocalInterfaceId() uint32 {
	if t == nil || t.LocalInterfaceId == nil {
		return 0
	}
	return *t.LocalInterfaceId
}

// GetLocalIpv4Address retrieves the value of the leaf LocalIpv4Address from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpv4Address is set, it can safely use t.GetLocalIpv4Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpv4Address == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetLocalIpv4Address() string {
	if t == nil || t.LocalIpv4Address == nil {
		return ""
	}
	return *t.LocalIpv4Address
}

// GetLocalIpv6Address retrieves the value of the leaf LocalIpv6Address from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpv6Address is set, it can safely use t.GetLocalIpv6Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpv6Address == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetLocalIpv6Address() string {
	if t == nil || t.LocalIpv6Address == nil {
		return ""
	}
	return *t.LocalIpv6Address
}

// GetMplsBos retrieves the value of the leaf MplsBos from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsBos is set, it can safely use t.GetMplsBos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsBos == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetMplsBos() bool {
	if t == nil || t.MplsBos == nil {
		return false
	}
	return *t.MplsBos
}

// GetMplsTc retrieves the value of the leaf MplsTc from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTc is set, it can safely use t.GetMplsTc()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTc == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetMplsTc() uint8 {
	if t == nil || t.MplsTc == nil {
		return 0
	}
	return *t.MplsTc
}

// GetMplsTtl retrieves the value of the leaf MplsTtl from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTtl is set, it can safely use t.GetMplsTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTtl == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetMplsTtl() uint8 {
	if t == nil || t.MplsTtl == nil {
		return 0
	}
	return *t.MplsTtl
}

// GetRemoteIpv4Address retrieves the value of the leaf RemoteIpv4Address from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteIpv4Address is set, it can safely use t.GetRemoteIpv4Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteIpv4Address == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetRemoteIpv4Address() string {
	if t == nil || t.RemoteIpv4Address == nil {
		return ""
	}
	return *t.RemoteIpv4Address
}

// GetRemoteIpv6Address retrieves the value of the leaf RemoteIpv6Address from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteIpv6Address is set, it can safely use t.GetRemoteIpv6Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteIpv6Address == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetRemoteIpv6Address() string {
	if t == nil || t.RemoteIpv6Address == nil {
		return ""
	}
	return *t.RemoteIpv6Address
}

// GetSid retrieves the value of the leaf Sid from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sid is set, it can safely use t.GetSid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sid == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetSid() Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union {
	if t == nil || t.Sid == nil {
		return nil
	}
	return t.Sid
}

// GetType retrieves the value of the leaf Type from the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetType() E_Segment_Type {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment struct, which is a YANG list entry.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union()
}

// Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union() {
}

// Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union ensures that UnionString
// implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface.
func (UnionString) Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union() {
}

// Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union ensures that UnionUint32
// implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface.
func (UnionUint32) Documentation_for_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union() {
}

// To_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) To_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union(i interface{}) (Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union, error) {
	if v, ok := i.(Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// Bgp_Rib_Community represents the /openconfig-bgp/bgp/rib/communities/community YANG schema element.
type Bgp_Rib_Community struct {
	ΛMetadata  []ygot.Annotation                   `path:"@" ygotAnnotation:"true"`
	Community  []Bgp_Rib_Community_Community_Union `path:"state/community" module:"openconfig-bgp"`
	ΛCommunity []ygot.Annotation                   `path:"state/@community" ygotAnnotation:"true"`
	Index      *uint64                             `path:"state/index|index" module:"openconfig-bgp"`
	ΛIndex     []ygot.Annotation                   `path:"state/@index|@index" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_Community implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_Community) IsYANGGoStruct() {}

// GetCommunity retrieves the value of the leaf Community from the Bgp_Rib_Community
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Community is set, it can safely use t.GetCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Community == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_Community) GetCommunity() []Bgp_Rib_Community_Community_Union {
	if t == nil || t.Community == nil {
		return nil
	}
	return t.Community
}

// GetIndex retrieves the value of the leaf Index from the Bgp_Rib_Community
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_Community) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// ΛListKeyMap returns the keys of the Bgp_Rib_Community struct, which is a YANG list entry.
func (t *Bgp_Rib_Community) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_Community) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_Community"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_Community) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_Community_Community_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/communities/community/state/community within the YANG schema.
// Union type can be one of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, UnionString, UnionUint32].
type Bgp_Rib_Community_Community_Union interface {
	// Union type can be one of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, UnionString, UnionUint32]
	Documentation_for_Bgp_Rib_Community_Community_Union()
}

// Documentation_for_Bgp_Rib_Community_Community_Union ensures that E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
// implements the Bgp_Rib_Community_Community_Union interface.
func (E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) Documentation_for_Bgp_Rib_Community_Community_Union() {
}

// Documentation_for_Bgp_Rib_Community_Community_Union ensures that UnionString
// implements the Bgp_Rib_Community_Community_Union interface.
func (UnionString) Documentation_for_Bgp_Rib_Community_Community_Union() {}

// Documentation_for_Bgp_Rib_Community_Community_Union ensures that UnionUint32
// implements the Bgp_Rib_Community_Community_Union interface.
func (UnionUint32) Documentation_for_Bgp_Rib_Community_Community_Union() {}

// To_Bgp_Rib_Community_Community_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Rib_Community_Community_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Rib_Community) To_Bgp_Rib_Community_Community_Union(i interface{}) (Bgp_Rib_Community_Community_Union, error) {
	if v, ok := i.(Bgp_Rib_Community_Community_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Rib_Community_Community_Union, unknown union type, got: %T, want any of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, string, uint32]", i, i)
}

// Bgp_Rib_ExtCommunity represents the /openconfig-bgp/bgp/rib/ext-communities/ext-community YANG schema element.
type Bgp_Rib_ExtCommunity struct {
	ΛMetadata     []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	ExtCommunity  []Bgp_Rib_ExtCommunity_ExtCommunity_Union `path:"state/ext-community" module:"openconfig-bgp"`
	ΛExtCommunity []ygot.Annotation                         `path:"state/@ext-community" ygotAnnotation:"true"`
	Index         *uint64                                   `path:"state/index|index" module:"openconfig-bgp"`
	ΛIndex        []ygot.Annotation                         `path:"state/@index|@index" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Bgp_Rib_ExtCommunity implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Bgp_Rib_ExtCommunity) IsYANGGoStruct() {}

// GetExtCommunity retrieves the value of the leaf ExtCommunity from the Bgp_Rib_ExtCommunity
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunity is set, it can safely use t.GetExtCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunity == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_ExtCommunity) GetExtCommunity() []Bgp_Rib_ExtCommunity_ExtCommunity_Union {
	if t == nil || t.ExtCommunity == nil {
		return nil
	}
	return t.ExtCommunity
}

// GetIndex retrieves the value of the leaf Index from the Bgp_Rib_ExtCommunity
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *Bgp_Rib_ExtCommunity) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// ΛListKeyMap returns the keys of the Bgp_Rib_ExtCommunity struct, which is a YANG list entry.
func (t *Bgp_Rib_ExtCommunity) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Bgp_Rib_ExtCommunity) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Bgp_Rib_ExtCommunity"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Bgp_Rib_ExtCommunity) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Bgp_Rib_ExtCommunity_ExtCommunity_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/ext-communities/ext-community/state/ext-community within the YANG schema.
// Union type can be one of [Binary, UnionString].
type Bgp_Rib_ExtCommunity_ExtCommunity_Union interface {
	// Union type can be one of [Binary, UnionString]
	Documentation_for_Bgp_Rib_ExtCommunity_ExtCommunity_Union()
}

// Documentation_for_Bgp_Rib_ExtCommunity_ExtCommunity_Union ensures that Binary
// implements the Bgp_Rib_ExtCommunity_ExtCommunity_Union interface.
func (Binary) Documentation_for_Bgp_Rib_ExtCommunity_ExtCommunity_Union() {}

// Documentation_for_Bgp_Rib_ExtCommunity_ExtCommunity_Union ensures that UnionString
// implements the Bgp_Rib_ExtCommunity_ExtCommunity_Union interface.
func (UnionString) Documentation_for_Bgp_Rib_ExtCommunity_ExtCommunity_Union() {}

// To_Bgp_Rib_ExtCommunity_ExtCommunity_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Bgp_Rib_ExtCommunity_ExtCommunity_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Bgp_Rib_ExtCommunity) To_Bgp_Rib_ExtCommunity_ExtCommunity_Union(i interface{}) (Bgp_Rib_ExtCommunity_ExtCommunity_Union, error) {
	if v, ok := i.(Bgp_Rib_ExtCommunity_ExtCommunity_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case []byte:
		return Binary(v), nil
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Bgp_Rib_ExtCommunity_ExtCommunity_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
}

// Component represents the /openconfig-platform/components/component YANG schema element.
type Component struct {
	ΛMetadata          []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	AllocatedPower     *uint32                                         `path:"state/allocated-power" module:"openconfig-platform"`
	ΛAllocatedPower    []ygot.Annotation                               `path:"state/@allocated-power" ygotAnnotation:"true"`
	Backplane          *Component_Backplane                            `path:"backplane" module:"openconfig-platform"`
	ΛBackplane         []ygot.Annotation                               `path:"@backplane" ygotAnnotation:"true"`
	Chassis            *Component_Chassis                              `path:"chassis" module:"openconfig-platform"`
	ΛChassis           []ygot.Annotation                               `path:"@chassis" ygotAnnotation:"true"`
	Cpu                *Component_Cpu                                  `path:"cpu" module:"openconfig-platform"`
	ΛCpu               []ygot.Annotation                               `path:"@cpu" ygotAnnotation:"true"`
	Description        *string                                         `path:"state/description" module:"openconfig-platform"`
	ΛDescription       []ygot.Annotation                               `path:"state/@description" ygotAnnotation:"true"`
	Empty              *bool                                           `path:"state/empty" module:"openconfig-platform"`
	ΛEmpty             []ygot.Annotation                               `path:"state/@empty" ygotAnnotation:"true"`
	EquipmentFailure   *bool                                           `path:"state/equipment-failure" module:"openconfig-alarms"`
	ΛEquipmentFailure  []ygot.Annotation                               `path:"state/@equipment-failure" ygotAnnotation:"true"`
	EquipmentMismatch  *bool                                           `path:"state/equipment-mismatch" module:"openconfig-alarms"`
	ΛEquipmentMismatch []ygot.Annotation                               `path:"state/@equipment-mismatch" ygotAnnotation:"true"`
	Fabric             *Component_Fabric                               `path:"fabric" module:"openconfig-platform"`
	ΛFabric            []ygot.Annotation                               `path:"@fabric" ygotAnnotation:"true"`
	Fan                *Component_Fan                                  `path:"fan" module:"openconfig-platform"`
	ΛFan               []ygot.Annotation                               `path:"@fan" ygotAnnotation:"true"`
	FirmwareVersion    *string                                         `path:"state/firmware-version" module:"openconfig-platform"`
	ΛFirmwareVersion   []ygot.Annotation                               `path:"state/@firmware-version" ygotAnnotation:"true"`
	HardwareVersion    *string                                         `path:"state/hardware-version" module:"openconfig-platform"`
	ΛHardwareVersion   []ygot.Annotation                               `path:"state/@hardware-version" ygotAnnotation:"true"`
	Id                 *string                                         `path:"state/id" module:"openconfig-platform"`
	ΛId                []ygot.Annotation                               `path:"state/@id" ygotAnnotation:"true"`
	IntegratedCircuit  *Component_IntegratedCircuit                    `path:"integrated-circuit" module:"openconfig-platform"`
	ΛIntegratedCircuit []ygot.Annotation                               `path:"@integrated-circuit" ygotAnnotation:"true"`
	Location           *string                                         `path:"state/location" module:"openconfig-platform"`
	ΛLocation          []ygot.Annotation                               `path:"state/@location" ygotAnnotation:"true"`
	Memory             *Component_Memory                               `path:"state/memory" module:"openconfig-platform"`
	ΛMemory            []ygot.Annotation                               `path:"state/@memory" ygotAnnotation:"true"`
	MfgDate            *string                                         `path:"state/mfg-date" module:"openconfig-platform"`
	ΛMfgDate           []ygot.Annotation                               `path:"state/@mfg-date" ygotAnnotation:"true"`
	MfgName            *string                                         `path:"state/mfg-name" module:"openconfig-platform"`
	ΛMfgName           []ygot.Annotation                               `path:"state/@mfg-name" ygotAnnotation:"true"`
	Name               *string                                         `path:"state/name|name" shadow-path:"config/name" module:"openconfig-platform"`
	ΛName              []ygot.Annotation                               `path:"state/@name|@name" ygotAnnotation:"true"`
	OperStatus         E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS `path:"state/oper-status" module:"openconfig-platform"`
	ΛOperStatus        []ygot.Annotation                               `path:"state/@oper-status" ygotAnnotation:"true"`
	OpticalChannel     *Component_OpticalChannel                       `path:"optical-channel" module:"openconfig-terminal-device"`
	ΛOpticalChannel    []ygot.Annotation                               `path:"@optical-channel" ygotAnnotation:"true"`
	Parent             *string                                         `path:"state/parent" module:"openconfig-platform"`
	ΛParent            []ygot.Annotation                               `path:"state/@parent" ygotAnnotation:"true"`
	PartNo             *string                                         `path:"state/part-no" module:"openconfig-platform"`
	ΛPartNo            []ygot.Annotation                               `path:"state/@part-no" ygotAnnotation:"true"`
	Port               *Component_Port                                 `path:"port" module:"openconfig-platform"`
	ΛPort              []ygot.Annotation                               `path:"@port" ygotAnnotation:"true"`
	PowerSupply        *Component_PowerSupply                          `path:"power-supply" module:"openconfig-platform"`
	ΛPowerSupply       []ygot.Annotation                               `path:"@power-supply" ygotAnnotation:"true"`
	Property           map[string]*Component_Property                  `path:"properties/property" module:"openconfig-platform"`
	ΛProperty          []ygot.Annotation                               `path:"properties/@property" ygotAnnotation:"true"`
	Removable          *bool                                           `path:"state/removable" module:"openconfig-platform"`
	ΛRemovable         []ygot.Annotation                               `path:"state/@removable" ygotAnnotation:"true"`
	SerialNo           *string                                         `path:"state/serial-no" module:"openconfig-platform"`
	ΛSerialNo          []ygot.Annotation                               `path:"state/@serial-no" ygotAnnotation:"true"`
	SoftwareVersion    *string                                         `path:"state/software-version" module:"openconfig-platform"`
	ΛSoftwareVersion   []ygot.Annotation                               `path:"state/@software-version" ygotAnnotation:"true"`
	Storage            *Component_Storage                              `path:"storage" module:"openconfig-platform"`
	ΛStorage           []ygot.Annotation                               `path:"@storage" ygotAnnotation:"true"`
	Subcomponent       map[string]*Component_Subcomponent              `path:"subcomponents/subcomponent" module:"openconfig-platform"`
	ΛSubcomponent      []ygot.Annotation                               `path:"subcomponents/@subcomponent" ygotAnnotation:"true"`
	Temperature        *Component_Temperature                          `path:"state/temperature" module:"openconfig-platform"`
	ΛTemperature       []ygot.Annotation                               `path:"state/@temperature" ygotAnnotation:"true"`
	Transceiver        *Component_Transceiver                          `path:"transceiver" module:"openconfig-platform-transceiver"`
	ΛTransceiver       []ygot.Annotation                               `path:"@transceiver" ygotAnnotation:"true"`
	Type               Component_Type_Union                            `path:"state/type" module:"openconfig-platform"`
	ΛType              []ygot.Annotation                               `path:"state/@type" ygotAnnotation:"true"`
	UsedPower          *uint32                                         `path:"state/used-power" module:"openconfig-platform"`
	ΛUsedPower         []ygot.Annotation                               `path:"state/@used-power" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component) IsYANGGoStruct() {}

// NewProperty creates a new entry in the Property list of the
// Component struct. The keys of the list are populated from the input
// arguments.
func (t *Component) NewProperty(Name string) (*Component_Property, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Property == nil {
		t.Property = make(map[string]*Component_Property)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Property[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Property", key)
	}

	t.Property[key] = &Component_Property{
		Name: &Name,
	}

	return t.Property[key], nil
}

// RenameProperty renames an entry in the list Property within
// the Component struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Component) RenameProperty(oldK, newK string) error {
	if _, ok := t.Property[newK]; ok {
		return fmt.Errorf("key %v already exists in Property", newK)
	}

	e, ok := t.Property[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Property", oldK)
	}
	e.Name = &newK

	t.Property[newK] = e
	delete(t.Property, oldK)
	return nil
}

// GetOrCreateProperty retrieves the value with the specified keys from
// the receiver Component. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Component) GetOrCreateProperty(Name string) *Component_Property {

	key := Name

	if v, ok := t.Property[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewProperty(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateProperty got unexpected error: %v", err))
	}
	return v
}

// GetProperty retrieves the value with the specified key from
// the Property map field of Component. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Component) GetProperty(Name string) *Component_Property {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Property[key]; ok {
		return lm
	}
	return nil
}

// AppendProperty appends the supplied Component_Property struct to the
// list Property of Component. If the key value(s) specified in
// the supplied Component_Property already exist in the list, an error is
// returned.
func (t *Component) AppendProperty(v *Component_Property) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Property == nil {
		t.Property = make(map[string]*Component_Property)
	}

	if _, ok := t.Property[key]; ok {
		return fmt.Errorf("duplicate key for list Property %v", key)
	}

	t.Property[key] = v
	return nil
}

// NewSubcomponent creates a new entry in the Subcomponent list of the
// Component struct. The keys of the list are populated from the input
// arguments.
func (t *Component) NewSubcomponent(Name string) (*Component_Subcomponent, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subcomponent == nil {
		t.Subcomponent = make(map[string]*Component_Subcomponent)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subcomponent[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subcomponent", key)
	}

	t.Subcomponent[key] = &Component_Subcomponent{
		Name: &Name,
	}

	return t.Subcomponent[key], nil
}

// RenameSubcomponent renames an entry in the list Subcomponent within
// the Component struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Component) RenameSubcomponent(oldK, newK string) error {
	if _, ok := t.Subcomponent[newK]; ok {
		return fmt.Errorf("key %v already exists in Subcomponent", newK)
	}

	e, ok := t.Subcomponent[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subcomponent", oldK)
	}
	e.Name = &newK

	t.Subcomponent[newK] = e
	delete(t.Subcomponent, oldK)
	return nil
}

// GetOrCreateSubcomponent retrieves the value with the specified keys from
// the receiver Component. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Component) GetOrCreateSubcomponent(Name string) *Component_Subcomponent {

	key := Name

	if v, ok := t.Subcomponent[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubcomponent(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubcomponent got unexpected error: %v", err))
	}
	return v
}

// GetSubcomponent retrieves the value with the specified key from
// the Subcomponent map field of Component. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Component) GetSubcomponent(Name string) *Component_Subcomponent {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Subcomponent[key]; ok {
		return lm
	}
	return nil
}

// AppendSubcomponent appends the supplied Component_Subcomponent struct to the
// list Subcomponent of Component. If the key value(s) specified in
// the supplied Component_Subcomponent already exist in the list, an error is
// returned.
func (t *Component) AppendSubcomponent(v *Component_Subcomponent) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subcomponent == nil {
		t.Subcomponent = make(map[string]*Component_Subcomponent)
	}

	if _, ok := t.Subcomponent[key]; ok {
		return fmt.Errorf("duplicate key for list Subcomponent %v", key)
	}

	t.Subcomponent[key] = v
	return nil
}

// GetOrCreateBackplane retrieves the value of the Backplane field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateBackplane() *Component_Backplane {
	if t.Backplane != nil {
		return t.Backplane
	}
	t.Backplane = &Component_Backplane{}
	return t.Backplane
}

// GetOrCreateChassis retrieves the value of the Chassis field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateChassis() *Component_Chassis {
	if t.Chassis != nil {
		return t.Chassis
	}
	t.Chassis = &Component_Chassis{}
	return t.Chassis
}

// GetOrCreateCpu retrieves the value of the Cpu field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateCpu() *Component_Cpu {
	if t.Cpu != nil {
		return t.Cpu
	}
	t.Cpu = &Component_Cpu{}
	return t.Cpu
}

// GetOrCreateFabric retrieves the value of the Fabric field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateFabric() *Component_Fabric {
	if t.Fabric != nil {
		return t.Fabric
	}
	t.Fabric = &Component_Fabric{}
	return t.Fabric
}

// GetOrCreateFan retrieves the value of the Fan field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateFan() *Component_Fan {
	if t.Fan != nil {
		return t.Fan
	}
	t.Fan = &Component_Fan{}
	return t.Fan
}

// GetOrCreateIntegratedCircuit retrieves the value of the IntegratedCircuit field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateIntegratedCircuit() *Component_IntegratedCircuit {
	if t.IntegratedCircuit != nil {
		return t.IntegratedCircuit
	}
	t.IntegratedCircuit = &Component_IntegratedCircuit{}
	return t.IntegratedCircuit
}

// GetOrCreateMemory retrieves the value of the Memory field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateMemory() *Component_Memory {
	if t.Memory != nil {
		return t.Memory
	}
	t.Memory = &Component_Memory{}
	return t.Memory
}

// GetOrCreateOpticalChannel retrieves the value of the OpticalChannel field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateOpticalChannel() *Component_OpticalChannel {
	if t.OpticalChannel != nil {
		return t.OpticalChannel
	}
	t.OpticalChannel = &Component_OpticalChannel{}
	return t.OpticalChannel
}

// GetOrCreatePort retrieves the value of the Port field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreatePort() *Component_Port {
	if t.Port != nil {
		return t.Port
	}
	t.Port = &Component_Port{}
	return t.Port
}

// GetOrCreatePowerSupply retrieves the value of the PowerSupply field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreatePowerSupply() *Component_PowerSupply {
	if t.PowerSupply != nil {
		return t.PowerSupply
	}
	t.PowerSupply = &Component_PowerSupply{}
	return t.PowerSupply
}

// GetOrCreateStorage retrieves the value of the Storage field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateStorage() *Component_Storage {
	if t.Storage != nil {
		return t.Storage
	}
	t.Storage = &Component_Storage{}
	return t.Storage
}

// GetOrCreateTemperature retrieves the value of the Temperature field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateTemperature() *Component_Temperature {
	if t.Temperature != nil {
		return t.Temperature
	}
	t.Temperature = &Component_Temperature{}
	return t.Temperature
}

// GetOrCreateTransceiver retrieves the value of the Transceiver field
// or returns the existing field if it already exists.
func (t *Component) GetOrCreateTransceiver() *Component_Transceiver {
	if t.Transceiver != nil {
		return t.Transceiver
	}
	t.Transceiver = &Component_Transceiver{}
	return t.Transceiver
}

// GetBackplane returns the value of the Backplane struct pointer
// from Component. If the receiver or the field Backplane is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetBackplane() *Component_Backplane {
	if t != nil && t.Backplane != nil {
		return t.Backplane
	}
	return nil
}

// GetChassis returns the value of the Chassis struct pointer
// from Component. If the receiver or the field Chassis is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetChassis() *Component_Chassis {
	if t != nil && t.Chassis != nil {
		return t.Chassis
	}
	return nil
}

// GetCpu returns the value of the Cpu struct pointer
// from Component. If the receiver or the field Cpu is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetCpu() *Component_Cpu {
	if t != nil && t.Cpu != nil {
		return t.Cpu
	}
	return nil
}

// GetFabric returns the value of the Fabric struct pointer
// from Component. If the receiver or the field Fabric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetFabric() *Component_Fabric {
	if t != nil && t.Fabric != nil {
		return t.Fabric
	}
	return nil
}

// GetFan returns the value of the Fan struct pointer
// from Component. If the receiver or the field Fan is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetFan() *Component_Fan {
	if t != nil && t.Fan != nil {
		return t.Fan
	}
	return nil
}

// GetIntegratedCircuit returns the value of the IntegratedCircuit struct pointer
// from Component. If the receiver or the field IntegratedCircuit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetIntegratedCircuit() *Component_IntegratedCircuit {
	if t != nil && t.IntegratedCircuit != nil {
		return t.IntegratedCircuit
	}
	return nil
}

// GetMemory returns the value of the Memory struct pointer
// from Component. If the receiver or the field Memory is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetMemory() *Component_Memory {
	if t != nil && t.Memory != nil {
		return t.Memory
	}
	return nil
}

// GetOpticalChannel returns the value of the OpticalChannel struct pointer
// from Component. If the receiver or the field OpticalChannel is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetOpticalChannel() *Component_OpticalChannel {
	if t != nil && t.OpticalChannel != nil {
		return t.OpticalChannel
	}
	return nil
}

// GetPort returns the value of the Port struct pointer
// from Component. If the receiver or the field Port is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetPort() *Component_Port {
	if t != nil && t.Port != nil {
		return t.Port
	}
	return nil
}

// GetPowerSupply returns the value of the PowerSupply struct pointer
// from Component. If the receiver or the field PowerSupply is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetPowerSupply() *Component_PowerSupply {
	if t != nil && t.PowerSupply != nil {
		return t.PowerSupply
	}
	return nil
}

// GetStorage returns the value of the Storage struct pointer
// from Component. If the receiver or the field Storage is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetStorage() *Component_Storage {
	if t != nil && t.Storage != nil {
		return t.Storage
	}
	return nil
}

// GetTemperature returns the value of the Temperature struct pointer
// from Component. If the receiver or the field Temperature is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetTemperature() *Component_Temperature {
	if t != nil && t.Temperature != nil {
		return t.Temperature
	}
	return nil
}

// GetTransceiver returns the value of the Transceiver struct pointer
// from Component. If the receiver or the field Transceiver is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component) GetTransceiver() *Component_Transceiver {
	if t != nil && t.Transceiver != nil {
		return t.Transceiver
	}
	return nil
}

// GetAllocatedPower retrieves the value of the leaf AllocatedPower from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllocatedPower is set, it can safely use t.GetAllocatedPower()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllocatedPower == nil'
// before retrieving the leaf's value.
func (t *Component) GetAllocatedPower() uint32 {
	if t == nil || t.AllocatedPower == nil {
		return 0
	}
	return *t.AllocatedPower
}

// GetDescription retrieves the value of the leaf Description from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Component) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetEmpty retrieves the value of the leaf Empty from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Empty is set, it can safely use t.GetEmpty()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Empty == nil'
// before retrieving the leaf's value.
func (t *Component) GetEmpty() bool {
	if t == nil || t.Empty == nil {
		return false
	}
	return *t.Empty
}

// GetEquipmentFailure retrieves the value of the leaf EquipmentFailure from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EquipmentFailure is set, it can safely use t.GetEquipmentFailure()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EquipmentFailure == nil'
// before retrieving the leaf's value.
func (t *Component) GetEquipmentFailure() bool {
	if t == nil || t.EquipmentFailure == nil {
		return false
	}
	return *t.EquipmentFailure
}

// GetEquipmentMismatch retrieves the value of the leaf EquipmentMismatch from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EquipmentMismatch is set, it can safely use t.GetEquipmentMismatch()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EquipmentMismatch == nil'
// before retrieving the leaf's value.
func (t *Component) GetEquipmentMismatch() bool {
	if t == nil || t.EquipmentMismatch == nil {
		return false
	}
	return *t.EquipmentMismatch
}

// GetFirmwareVersion retrieves the value of the leaf FirmwareVersion from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FirmwareVersion is set, it can safely use t.GetFirmwareVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FirmwareVersion == nil'
// before retrieving the leaf's value.
func (t *Component) GetFirmwareVersion() string {
	if t == nil || t.FirmwareVersion == nil {
		return ""
	}
	return *t.FirmwareVersion
}

// GetHardwareVersion retrieves the value of the leaf HardwareVersion from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HardwareVersion is set, it can safely use t.GetHardwareVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HardwareVersion == nil'
// before retrieving the leaf's value.
func (t *Component) GetHardwareVersion() string {
	if t == nil || t.HardwareVersion == nil {
		return ""
	}
	return *t.HardwareVersion
}

// GetId retrieves the value of the leaf Id from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *Component) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetLocation retrieves the value of the leaf Location from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Location is set, it can safely use t.GetLocation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Location == nil'
// before retrieving the leaf's value.
func (t *Component) GetLocation() string {
	if t == nil || t.Location == nil {
		return ""
	}
	return *t.Location
}

// GetMfgDate retrieves the value of the leaf MfgDate from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MfgDate is set, it can safely use t.GetMfgDate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MfgDate == nil'
// before retrieving the leaf's value.
func (t *Component) GetMfgDate() string {
	if t == nil || t.MfgDate == nil {
		return ""
	}
	return *t.MfgDate
}

// GetMfgName retrieves the value of the leaf MfgName from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MfgName is set, it can safely use t.GetMfgName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MfgName == nil'
// before retrieving the leaf's value.
func (t *Component) GetMfgName() string {
	if t == nil || t.MfgName == nil {
		return ""
	}
	return *t.MfgName
}

// GetName retrieves the value of the leaf Name from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Component) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetOperStatus retrieves the value of the leaf OperStatus from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OperStatus is set, it can safely use t.GetOperStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OperStatus == nil'
// before retrieving the leaf's value.
func (t *Component) GetOperStatus() E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS {
	if t == nil || t.OperStatus == 0 {
		return 0
	}
	return t.OperStatus
}

// GetParent retrieves the value of the leaf Parent from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Parent is set, it can safely use t.GetParent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Parent == nil'
// before retrieving the leaf's value.
func (t *Component) GetParent() string {
	if t == nil || t.Parent == nil {
		return ""
	}
	return *t.Parent
}

// GetPartNo retrieves the value of the leaf PartNo from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PartNo is set, it can safely use t.GetPartNo()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PartNo == nil'
// before retrieving the leaf's value.
func (t *Component) GetPartNo() string {
	if t == nil || t.PartNo == nil {
		return ""
	}
	return *t.PartNo
}

// GetRemovable retrieves the value of the leaf Removable from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Removable is set, it can safely use t.GetRemovable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Removable == nil'
// before retrieving the leaf's value.
func (t *Component) GetRemovable() bool {
	if t == nil || t.Removable == nil {
		return false
	}
	return *t.Removable
}

// GetSerialNo retrieves the value of the leaf SerialNo from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SerialNo is set, it can safely use t.GetSerialNo()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SerialNo == nil'
// before retrieving the leaf's value.
func (t *Component) GetSerialNo() string {
	if t == nil || t.SerialNo == nil {
		return ""
	}
	return *t.SerialNo
}

// GetSoftwareVersion retrieves the value of the leaf SoftwareVersion from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SoftwareVersion is set, it can safely use t.GetSoftwareVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SoftwareVersion == nil'
// before retrieving the leaf's value.
func (t *Component) GetSoftwareVersion() string {
	if t == nil || t.SoftwareVersion == nil {
		return ""
	}
	return *t.SoftwareVersion
}

// GetType retrieves the value of the leaf Type from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Component) GetType() Component_Type_Union {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// GetUsedPower retrieves the value of the leaf UsedPower from the Component
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UsedPower is set, it can safely use t.GetUsedPower()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UsedPower == nil'
// before retrieving the leaf's value.
func (t *Component) GetUsedPower() uint32 {
	if t == nil || t.UsedPower == nil {
		return 0
	}
	return *t.UsedPower
}

// ΛListKeyMap returns the keys of the Component struct, which is a YANG list entry.
func (t *Component) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-platform/components/component/state/type within the YANG schema.
// Union type can be one of [E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT, E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT].
type Component_Type_Union interface {
	// Union type can be one of [E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT, E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT]
	Documentation_for_Component_Type_Union()
}

// Documentation_for_Component_Type_Union ensures that E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
// implements the Component_Type_Union interface.
func (E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) Documentation_for_Component_Type_Union() {
}

// Documentation_for_Component_Type_Union ensures that E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
// implements the Component_Type_Union interface.
func (E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) Documentation_for_Component_Type_Union() {
}

// To_Component_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Component_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Component) To_Component_Type_Union(i interface{}) (Component_Type_Union, error) {
	if v, ok := i.(Component_Type_Union); ok {
		return v, nil
	}
	return nil, fmt.Errorf("cannot convert %v to Component_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT, E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT]", i, i)
}

// Component_Backplane represents the /openconfig-platform/components/component/backplane YANG schema element.
type Component_Backplane struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Backplane implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Backplane) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Backplane) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Backplane"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Backplane) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Chassis represents the /openconfig-platform/components/component/chassis YANG schema element.
type Component_Chassis struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Chassis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Chassis) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Chassis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Chassis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Chassis) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Cpu represents the /openconfig-platform/components/component/cpu YANG schema element.
type Component_Cpu struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Cpu implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Cpu) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Cpu) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Cpu"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Cpu) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Fabric represents the /openconfig-platform/components/component/fabric YANG schema element.
type Component_Fabric struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Fabric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Fabric) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Fabric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Fabric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Fabric) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Fan represents the /openconfig-platform/components/component/fan YANG schema element.
type Component_Fan struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Fan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Fan) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Fan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Fan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Fan) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_IntegratedCircuit represents the /openconfig-platform/components/component/integrated-circuit YANG schema element.
type Component_IntegratedCircuit struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_IntegratedCircuit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_IntegratedCircuit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_IntegratedCircuit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_IntegratedCircuit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_IntegratedCircuit) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Memory represents the /openconfig-platform/components/component/state/memory YANG schema element.
type Component_Memory struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Available  *uint64           `path:"available" module:"openconfig-platform"`
	ΛAvailable []ygot.Annotation `path:"@available" ygotAnnotation:"true"`
	Utilized   *uint64           `path:"utilized" module:"openconfig-platform"`
	ΛUtilized  []ygot.Annotation `path:"@utilized" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Memory implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Memory) IsYANGGoStruct() {}

// GetAvailable retrieves the value of the leaf Available from the Component_Memory
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Available is set, it can safely use t.GetAvailable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Available == nil'
// before retrieving the leaf's value.
func (t *Component_Memory) GetAvailable() uint64 {
	if t == nil || t.Available == nil {
		return 0
	}
	return *t.Available
}

// GetUtilized retrieves the value of the leaf Utilized from the Component_Memory
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Utilized is set, it can safely use t.GetUtilized()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Utilized == nil'
// before retrieving the leaf's value.
func (t *Component_Memory) GetUtilized() uint64 {
	if t == nil || t.Utilized == nil {
		return 0
	}
	return *t.Utilized
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Memory) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Memory"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Memory) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_OpticalChannel represents the /openconfig-platform/components/component/optical-channel YANG schema element.
type Component_OpticalChannel struct {
	ΛMetadata                              []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	ChromaticDispersion                    *Component_OpticalChannel_ChromaticDispersion                   `path:"state/chromatic-dispersion" module:"openconfig-terminal-device"`
	ΛChromaticDispersion                   []ygot.Annotation                                               `path:"state/@chromatic-dispersion" ygotAnnotation:"true"`
	Frequency                              *uint64                                                         `path:"state/frequency" shadow-path:"config/frequency" module:"openconfig-terminal-device"`
	ΛFrequency                             []ygot.Annotation                                               `path:"state/@frequency" ygotAnnotation:"true"`
	GroupId                                *uint32                                                         `path:"state/group-id" module:"openconfig-terminal-device"`
	ΛGroupId                               []ygot.Annotation                                               `path:"state/@group-id" ygotAnnotation:"true"`
	InputPower                             *Component_OpticalChannel_InputPower                            `path:"state/input-power" module:"openconfig-terminal-device"`
	ΛInputPower                            []ygot.Annotation                                               `path:"state/@input-power" ygotAnnotation:"true"`
	LaserBiasCurrent                       *Component_OpticalChannel_LaserBiasCurrent                      `path:"state/laser-bias-current" module:"openconfig-terminal-device"`
	ΛLaserBiasCurrent                      []ygot.Annotation                                               `path:"state/@laser-bias-current" ygotAnnotation:"true"`
	LinePort                               *string                                                         `path:"state/line-port" shadow-path:"config/line-port" module:"openconfig-terminal-device"`
	ΛLinePort                              []ygot.Annotation                                               `path:"state/@line-port" ygotAnnotation:"true"`
	OperationalMode                        *uint16                                                         `path:"state/operational-mode" shadow-path:"config/operational-mode" module:"openconfig-terminal-device"`
	ΛOperationalMode                       []ygot.Annotation                                               `path:"state/@operational-mode" ygotAnnotation:"true"`
	OutputPower                            *Component_OpticalChannel_OutputPower                           `path:"state/output-power" module:"openconfig-terminal-device"`
	ΛOutputPower                           []ygot.Annotation                                               `path:"state/@output-power" ygotAnnotation:"true"`
	PolarizationDependentLoss              *Component_OpticalChannel_PolarizationDependentLoss             `path:"state/polarization-dependent-loss" module:"openconfig-terminal-device"`
	ΛPolarizationDependentLoss             []ygot.Annotation                                               `path:"state/@polarization-dependent-loss" ygotAnnotation:"true"`
	PolarizationModeDispersion             *Component_OpticalChannel_PolarizationModeDispersion            `path:"state/polarization-mode-dispersion" module:"openconfig-terminal-device"`
	ΛPolarizationModeDispersion            []ygot.Annotation                                               `path:"state/@polarization-mode-dispersion" ygotAnnotation:"true"`
	SecondOrderPolarizationModeDispersion  *Component_OpticalChannel_SecondOrderPolarizationModeDispersion `path:"state/second-order-polarization-mode-dispersion" module:"openconfig-terminal-device"`
	ΛSecondOrderPolarizationModeDispersion []ygot.Annotation                                               `path:"state/@second-order-polarization-mode-dispersion" ygotAnnotation:"true"`
	TargetOutputPower                      *float64                                                        `path:"state/target-output-power" shadow-path:"config/target-output-power" module:"openconfig-terminal-device"`
	ΛTargetOutputPower                     []ygot.Annotation                                               `path:"state/@target-output-power" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel) IsYANGGoStruct() {}

// GetOrCreateChromaticDispersion retrieves the value of the ChromaticDispersion field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreateChromaticDispersion() *Component_OpticalChannel_ChromaticDispersion {
	if t.ChromaticDispersion != nil {
		return t.ChromaticDispersion
	}
	t.ChromaticDispersion = &Component_OpticalChannel_ChromaticDispersion{}
	return t.ChromaticDispersion
}

// GetOrCreateInputPower retrieves the value of the InputPower field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreateInputPower() *Component_OpticalChannel_InputPower {
	if t.InputPower != nil {
		return t.InputPower
	}
	t.InputPower = &Component_OpticalChannel_InputPower{}
	return t.InputPower
}

// GetOrCreateLaserBiasCurrent retrieves the value of the LaserBiasCurrent field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreateLaserBiasCurrent() *Component_OpticalChannel_LaserBiasCurrent {
	if t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	t.LaserBiasCurrent = &Component_OpticalChannel_LaserBiasCurrent{}
	return t.LaserBiasCurrent
}

// GetOrCreateOutputPower retrieves the value of the OutputPower field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreateOutputPower() *Component_OpticalChannel_OutputPower {
	if t.OutputPower != nil {
		return t.OutputPower
	}
	t.OutputPower = &Component_OpticalChannel_OutputPower{}
	return t.OutputPower
}

// GetOrCreatePolarizationDependentLoss retrieves the value of the PolarizationDependentLoss field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreatePolarizationDependentLoss() *Component_OpticalChannel_PolarizationDependentLoss {
	if t.PolarizationDependentLoss != nil {
		return t.PolarizationDependentLoss
	}
	t.PolarizationDependentLoss = &Component_OpticalChannel_PolarizationDependentLoss{}
	return t.PolarizationDependentLoss
}

// GetOrCreatePolarizationModeDispersion retrieves the value of the PolarizationModeDispersion field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreatePolarizationModeDispersion() *Component_OpticalChannel_PolarizationModeDispersion {
	if t.PolarizationModeDispersion != nil {
		return t.PolarizationModeDispersion
	}
	t.PolarizationModeDispersion = &Component_OpticalChannel_PolarizationModeDispersion{}
	return t.PolarizationModeDispersion
}

// GetOrCreateSecondOrderPolarizationModeDispersion retrieves the value of the SecondOrderPolarizationModeDispersion field
// or returns the existing field if it already exists.
func (t *Component_OpticalChannel) GetOrCreateSecondOrderPolarizationModeDispersion() *Component_OpticalChannel_SecondOrderPolarizationModeDispersion {
	if t.SecondOrderPolarizationModeDispersion != nil {
		return t.SecondOrderPolarizationModeDispersion
	}
	t.SecondOrderPolarizationModeDispersion = &Component_OpticalChannel_SecondOrderPolarizationModeDispersion{}
	return t.SecondOrderPolarizationModeDispersion
}

// GetChromaticDispersion returns the value of the ChromaticDispersion struct pointer
// from Component_OpticalChannel. If the receiver or the field ChromaticDispersion is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetChromaticDispersion() *Component_OpticalChannel_ChromaticDispersion {
	if t != nil && t.ChromaticDispersion != nil {
		return t.ChromaticDispersion
	}
	return nil
}

// GetInputPower returns the value of the InputPower struct pointer
// from Component_OpticalChannel. If the receiver or the field InputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetInputPower() *Component_OpticalChannel_InputPower {
	if t != nil && t.InputPower != nil {
		return t.InputPower
	}
	return nil
}

// GetLaserBiasCurrent returns the value of the LaserBiasCurrent struct pointer
// from Component_OpticalChannel. If the receiver or the field LaserBiasCurrent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetLaserBiasCurrent() *Component_OpticalChannel_LaserBiasCurrent {
	if t != nil && t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	return nil
}

// GetOutputPower returns the value of the OutputPower struct pointer
// from Component_OpticalChannel. If the receiver or the field OutputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetOutputPower() *Component_OpticalChannel_OutputPower {
	if t != nil && t.OutputPower != nil {
		return t.OutputPower
	}
	return nil
}

// GetPolarizationDependentLoss returns the value of the PolarizationDependentLoss struct pointer
// from Component_OpticalChannel. If the receiver or the field PolarizationDependentLoss is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetPolarizationDependentLoss() *Component_OpticalChannel_PolarizationDependentLoss {
	if t != nil && t.PolarizationDependentLoss != nil {
		return t.PolarizationDependentLoss
	}
	return nil
}

// GetPolarizationModeDispersion returns the value of the PolarizationModeDispersion struct pointer
// from Component_OpticalChannel. If the receiver or the field PolarizationModeDispersion is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetPolarizationModeDispersion() *Component_OpticalChannel_PolarizationModeDispersion {
	if t != nil && t.PolarizationModeDispersion != nil {
		return t.PolarizationModeDispersion
	}
	return nil
}

// GetSecondOrderPolarizationModeDispersion returns the value of the SecondOrderPolarizationModeDispersion struct pointer
// from Component_OpticalChannel. If the receiver or the field SecondOrderPolarizationModeDispersion is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_OpticalChannel) GetSecondOrderPolarizationModeDispersion() *Component_OpticalChannel_SecondOrderPolarizationModeDispersion {
	if t != nil && t.SecondOrderPolarizationModeDispersion != nil {
		return t.SecondOrderPolarizationModeDispersion
	}
	return nil
}

// GetFrequency retrieves the value of the leaf Frequency from the Component_OpticalChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Frequency is set, it can safely use t.GetFrequency()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Frequency == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel) GetFrequency() uint64 {
	if t == nil || t.Frequency == nil {
		return 0
	}
	return *t.Frequency
}

// GetGroupId retrieves the value of the leaf GroupId from the Component_OpticalChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if GroupId is set, it can safely use t.GetGroupId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.GroupId == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel) GetGroupId() uint32 {
	if t == nil || t.GroupId == nil {
		return 0
	}
	return *t.GroupId
}

// GetLinePort retrieves the value of the leaf LinePort from the Component_OpticalChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinePort is set, it can safely use t.GetLinePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinePort == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel) GetLinePort() string {
	if t == nil || t.LinePort == nil {
		return ""
	}
	return *t.LinePort
}

// GetOperationalMode retrieves the value of the leaf OperationalMode from the Component_OpticalChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OperationalMode is set, it can safely use t.GetOperationalMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OperationalMode == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel) GetOperationalMode() uint16 {
	if t == nil || t.OperationalMode == nil {
		return 0
	}
	return *t.OperationalMode
}

// GetTargetOutputPower retrieves the value of the leaf TargetOutputPower from the Component_OpticalChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetOutputPower is set, it can safely use t.GetTargetOutputPower()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetOutputPower == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel) GetTargetOutputPower() float64 {
	if t == nil || t.TargetOutputPower == nil {
		return 0.0
	}
	return *t.TargetOutputPower
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_OpticalChannel_ChromaticDispersion represents the /openconfig-platform/components/component/optical-channel/state/chromatic-dispersion YANG schema element.
type Component_OpticalChannel_ChromaticDispersion struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_ChromaticDispersion implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_ChromaticDispersion) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_ChromaticDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_ChromaticDispersion) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_ChromaticDispersion) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_ChromaticDispersion"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_ChromaticDispersion) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_OpticalChannel_InputPower represents the /openconfig-platform/components/component/optical-channel/state/input-power YANG schema element.
type Component_OpticalChannel_InputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_InputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_InputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_InputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_InputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_InputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_InputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_OpticalChannel_LaserBiasCurrent represents the /openconfig-platform/components/component/optical-channel/state/laser-bias-current YANG schema element.
type Component_OpticalChannel_LaserBiasCurrent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_LaserBiasCurrent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_LaserBiasCurrent) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_LaserBiasCurrent) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_LaserBiasCurrent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_LaserBiasCurrent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_LaserBiasCurrent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_OpticalChannel_OutputPower represents the /openconfig-platform/components/component/optical-channel/state/output-power YANG schema element.
type Component_OpticalChannel_OutputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_OutputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_OutputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_OutputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_OutputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_OutputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_OutputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_OpticalChannel_PolarizationDependentLoss represents the /openconfig-platform/components/component/optical-channel/state/polarization-dependent-loss YANG schema element.
type Component_OpticalChannel_PolarizationDependentLoss struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_PolarizationDependentLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_PolarizationDependentLoss) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_PolarizationDependentLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationDependentLoss) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_PolarizationDependentLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_PolarizationDependentLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_PolarizationDependentLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_OpticalChannel_PolarizationModeDispersion represents the /openconfig-platform/components/component/optical-channel/state/polarization-mode-dispersion YANG schema element.
type Component_OpticalChannel_PolarizationModeDispersion struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_PolarizationModeDispersion implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_PolarizationModeDispersion) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_PolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_PolarizationModeDispersion) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_PolarizationModeDispersion) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_PolarizationModeDispersion"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_PolarizationModeDispersion) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_OpticalChannel_SecondOrderPolarizationModeDispersion represents the /openconfig-platform/components/component/optical-channel/state/second-order-polarization-mode-dispersion YANG schema element.
type Component_OpticalChannel_SecondOrderPolarizationModeDispersion struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_OpticalChannel_SecondOrderPolarizationModeDispersion implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_OpticalChannel_SecondOrderPolarizationModeDispersion) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_OpticalChannel_SecondOrderPolarizationModeDispersion
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_OpticalChannel_SecondOrderPolarizationModeDispersion"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_OpticalChannel_SecondOrderPolarizationModeDispersion) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Port represents the /openconfig-platform/components/component/port YANG schema element.
type Component_Port struct {
	ΛMetadata     []ygot.Annotation            `path:"@" ygotAnnotation:"true"`
	BreakoutMode  *Component_Port_BreakoutMode `path:"breakout-mode" module:"openconfig-platform-port"`
	ΛBreakoutMode []ygot.Annotation            `path:"@breakout-mode" ygotAnnotation:"true"`
	OpticalPort   *Component_Port_OpticalPort  `path:"optical-port" module:"openconfig-transport-line-common"`
	ΛOpticalPort  []ygot.Annotation            `path:"@optical-port" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Port implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Port) IsYANGGoStruct() {}

// GetOrCreateBreakoutMode retrieves the value of the BreakoutMode field
// or returns the existing field if it already exists.
func (t *Component_Port) GetOrCreateBreakoutMode() *Component_Port_BreakoutMode {
	if t.BreakoutMode != nil {
		return t.BreakoutMode
	}
	t.BreakoutMode = &Component_Port_BreakoutMode{}
	return t.BreakoutMode
}

// GetOrCreateOpticalPort retrieves the value of the OpticalPort field
// or returns the existing field if it already exists.
func (t *Component_Port) GetOrCreateOpticalPort() *Component_Port_OpticalPort {
	if t.OpticalPort != nil {
		return t.OpticalPort
	}
	t.OpticalPort = &Component_Port_OpticalPort{}
	return t.OpticalPort
}

// GetBreakoutMode returns the value of the BreakoutMode struct pointer
// from Component_Port. If the receiver or the field BreakoutMode is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Port) GetBreakoutMode() *Component_Port_BreakoutMode {
	if t != nil && t.BreakoutMode != nil {
		return t.BreakoutMode
	}
	return nil
}

// GetOpticalPort returns the value of the OpticalPort struct pointer
// from Component_Port. If the receiver or the field OpticalPort is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Port) GetOpticalPort() *Component_Port_OpticalPort {
	if t != nil && t.OpticalPort != nil {
		return t.OpticalPort
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Port) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Port"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Port) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Port_BreakoutMode represents the /openconfig-platform/components/component/port/breakout-mode YANG schema element.
type Component_Port_BreakoutMode struct {
	ΛMetadata     []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	ChannelSpeed  E_OpenconfigIfEthernet_ETHERNET_SPEED `path:"state/channel-speed" shadow-path:"config/channel-speed" module:"openconfig-platform-port"`
	ΛChannelSpeed []ygot.Annotation                     `path:"state/@channel-speed" ygotAnnotation:"true"`
	NumChannels   *uint8                                `path:"state/num-channels" shadow-path:"config/num-channels" module:"openconfig-platform-port"`
	ΛNumChannels  []ygot.Annotation                     `path:"state/@num-channels" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Port_BreakoutMode implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Port_BreakoutMode) IsYANGGoStruct() {}

// GetChannelSpeed retrieves the value of the leaf ChannelSpeed from the Component_Port_BreakoutMode
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChannelSpeed is set, it can safely use t.GetChannelSpeed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChannelSpeed == nil'
// before retrieving the leaf's value.
func (t *Component_Port_BreakoutMode) GetChannelSpeed() E_OpenconfigIfEthernet_ETHERNET_SPEED {
	if t == nil || t.ChannelSpeed == 0 {
		return 0
	}
	return t.ChannelSpeed
}

// GetNumChannels retrieves the value of the leaf NumChannels from the Component_Port_BreakoutMode
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NumChannels is set, it can safely use t.GetNumChannels()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NumChannels == nil'
// before retrieving the leaf's value.
func (t *Component_Port_BreakoutMode) GetNumChannels() uint8 {
	if t == nil || t.NumChannels == nil {
		return 0
	}
	return *t.NumChannels
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Port_BreakoutMode) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Port_BreakoutMode"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Port_BreakoutMode) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Port_OpticalPort represents the /openconfig-platform/components/component/port/optical-port YANG schema element.
type Component_Port_OpticalPort struct {
	ΛMetadata        []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	AdminState       E_OpenconfigTransportTypes_AdminStateType    `path:"state/admin-state" shadow-path:"config/admin-state" module:"openconfig-transport-line-common"`
	ΛAdminState      []ygot.Annotation                            `path:"state/@admin-state" ygotAnnotation:"true"`
	InputPower       *Component_Port_OpticalPort_InputPower       `path:"state/input-power" module:"openconfig-transport-line-common"`
	ΛInputPower      []ygot.Annotation                            `path:"state/@input-power" ygotAnnotation:"true"`
	OpticalPortType  E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE `path:"state/optical-port-type" module:"openconfig-transport-line-common"`
	ΛOpticalPortType []ygot.Annotation                            `path:"state/@optical-port-type" ygotAnnotation:"true"`
	OutputPower      *Component_Port_OpticalPort_OutputPower      `path:"state/output-power" module:"openconfig-transport-line-common"`
	ΛOutputPower     []ygot.Annotation                            `path:"state/@output-power" ygotAnnotation:"true"`
	Tilt             *float64                                     `path:"state/tilt" module:"openconfig-transport-line-common"`
	ΛTilt            []ygot.Annotation                            `path:"state/@tilt" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Port_OpticalPort implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Port_OpticalPort) IsYANGGoStruct() {}

// GetOrCreateInputPower retrieves the value of the InputPower field
// or returns the existing field if it already exists.
func (t *Component_Port_OpticalPort) GetOrCreateInputPower() *Component_Port_OpticalPort_InputPower {
	if t.InputPower != nil {
		return t.InputPower
	}
	t.InputPower = &Component_Port_OpticalPort_InputPower{}
	return t.InputPower
}

// GetOrCreateOutputPower retrieves the value of the OutputPower field
// or returns the existing field if it already exists.
func (t *Component_Port_OpticalPort) GetOrCreateOutputPower() *Component_Port_OpticalPort_OutputPower {
	if t.OutputPower != nil {
		return t.OutputPower
	}
	t.OutputPower = &Component_Port_OpticalPort_OutputPower{}
	return t.OutputPower
}

// GetInputPower returns the value of the InputPower struct pointer
// from Component_Port_OpticalPort. If the receiver or the field InputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Port_OpticalPort) GetInputPower() *Component_Port_OpticalPort_InputPower {
	if t != nil && t.InputPower != nil {
		return t.InputPower
	}
	return nil
}

// GetOutputPower returns the value of the OutputPower struct pointer
// from Component_Port_OpticalPort. If the receiver or the field OutputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Port_OpticalPort) GetOutputPower() *Component_Port_OpticalPort_OutputPower {
	if t != nil && t.OutputPower != nil {
		return t.OutputPower
	}
	return nil
}

// GetAdminState retrieves the value of the leaf AdminState from the Component_Port_OpticalPort
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminState is set, it can safely use t.GetAdminState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminState == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort) GetAdminState() E_OpenconfigTransportTypes_AdminStateType {
	if t == nil || t.AdminState == 0 {
		return 0
	}
	return t.AdminState
}

// GetOpticalPortType retrieves the value of the leaf OpticalPortType from the Component_Port_OpticalPort
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OpticalPortType is set, it can safely use t.GetOpticalPortType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OpticalPortType == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort) GetOpticalPortType() E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE {
	if t == nil || t.OpticalPortType == 0 {
		return 0
	}
	return t.OpticalPortType
}

// GetTilt retrieves the value of the leaf Tilt from the Component_Port_OpticalPort
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tilt is set, it can safely use t.GetTilt()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tilt == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort) GetTilt() float64 {
	if t == nil || t.Tilt == nil {
		return 0.0
	}
	return *t.Tilt
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Port_OpticalPort) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Port_OpticalPort"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Port_OpticalPort) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Port_OpticalPort_InputPower represents the /openconfig-platform/components/component/port/optical-port/state/input-power YANG schema element.
type Component_Port_OpticalPort_InputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-common"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-common"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-common"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-common"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-common"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-common"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-common"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Port_OpticalPort_InputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Port_OpticalPort_InputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Port_OpticalPort_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_InputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Port_OpticalPort_InputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Port_OpticalPort_InputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Port_OpticalPort_InputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Port_OpticalPort_OutputPower represents the /openconfig-platform/components/component/port/optical-port/state/output-power YANG schema element.
type Component_Port_OpticalPort_OutputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-transport-line-common"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-transport-line-common"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-transport-line-common"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-transport-line-common"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-transport-line-common"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-transport-line-common"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-transport-line-common"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Port_OpticalPort_OutputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Port_OpticalPort_OutputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Port_OpticalPort_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Port_OpticalPort_OutputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Port_OpticalPort_OutputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Port_OpticalPort_OutputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Port_OpticalPort_OutputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_PowerSupply represents the /openconfig-platform/components/component/power-supply YANG schema element.
type Component_PowerSupply struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_PowerSupply implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_PowerSupply) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_PowerSupply) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_PowerSupply"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_PowerSupply) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Property represents the /openconfig-platform/components/component/properties/property YANG schema element.
type Component_Property struct {
	ΛMetadata     []ygot.Annotation              `path:"@" ygotAnnotation:"true"`
	Configurable  *bool                          `path:"state/configurable" module:"openconfig-platform"`
	ΛConfigurable []ygot.Annotation              `path:"state/@configurable" ygotAnnotation:"true"`
	Name          *string                        `path:"state/name|name" shadow-path:"config/name" module:"openconfig-platform"`
	ΛName         []ygot.Annotation              `path:"state/@name|@name" ygotAnnotation:"true"`
	Value         Component_Property_Value_Union `path:"state/value" shadow-path:"config/value" module:"openconfig-platform"`
	ΛValue        []ygot.Annotation              `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Property implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Property) IsYANGGoStruct() {}

// GetConfigurable retrieves the value of the leaf Configurable from the Component_Property
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Configurable is set, it can safely use t.GetConfigurable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Configurable == nil'
// before retrieving the leaf's value.
func (t *Component_Property) GetConfigurable() bool {
	if t == nil || t.Configurable == nil {
		return false
	}
	return *t.Configurable
}

// GetName retrieves the value of the leaf Name from the Component_Property
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Component_Property) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetValue retrieves the value of the leaf Value from the Component_Property
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *Component_Property) GetValue() Component_Property_Value_Union {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the Component_Property struct, which is a YANG list entry.
func (t *Component_Property) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Property) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Property"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Property) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Property_Value_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-platform/components/component/properties/property/state/value within the YANG schema.
// Union type can be one of [UnionBool, UnionFloat64, UnionInt64, UnionString, UnionUint64].
type Component_Property_Value_Union interface {
	// Union type can be one of [UnionBool, UnionFloat64, UnionInt64, UnionString, UnionUint64]
	Documentation_for_Component_Property_Value_Union()
}

// Documentation_for_Component_Property_Value_Union ensures that UnionBool
// implements the Component_Property_Value_Union interface.
func (UnionBool) Documentation_for_Component_Property_Value_Union() {}

// Documentation_for_Component_Property_Value_Union ensures that UnionFloat64
// implements the Component_Property_Value_Union interface.
func (UnionFloat64) Documentation_for_Component_Property_Value_Union() {}

// Documentation_for_Component_Property_Value_Union ensures that UnionInt64
// implements the Component_Property_Value_Union interface.
func (UnionInt64) Documentation_for_Component_Property_Value_Union() {}

// Documentation_for_Component_Property_Value_Union ensures that UnionString
// implements the Component_Property_Value_Union interface.
func (UnionString) Documentation_for_Component_Property_Value_Union() {}

// Documentation_for_Component_Property_Value_Union ensures that UnionUint64
// implements the Component_Property_Value_Union interface.
func (UnionUint64) Documentation_for_Component_Property_Value_Union() {}

// To_Component_Property_Value_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Component_Property_Value_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Component_Property) To_Component_Property_Value_Union(i interface{}) (Component_Property_Value_Union, error) {
	if v, ok := i.(Component_Property_Value_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case bool:
		return UnionBool(v), nil
	case float64:
		return UnionFloat64(v), nil
	case int64:
		return UnionInt64(v), nil
	case string:
		return UnionString(v), nil
	case uint64:
		return UnionUint64(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Component_Property_Value_Union, unknown union type, got: %T, want any of [bool, float64, int64, string, uint64]", i, i)
}

// Component_Storage represents the /openconfig-platform/components/component/storage YANG schema element.
type Component_Storage struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Storage implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Storage) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Storage) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Storage"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Storage) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Subcomponent represents the /openconfig-platform/components/component/subcomponents/subcomponent YANG schema element.
type Component_Subcomponent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Name      *string           `path:"state/name|name" shadow-path:"config/name" module:"openconfig-platform"`
	ΛName     []ygot.Annotation `path:"state/@name|@name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Subcomponent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Subcomponent) IsYANGGoStruct() {}

// GetName retrieves the value of the leaf Name from the Component_Subcomponent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Component_Subcomponent) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the Component_Subcomponent struct, which is a YANG list entry.
func (t *Component_Subcomponent) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Subcomponent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Subcomponent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Subcomponent) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Temperature represents the /openconfig-platform/components/component/state/temperature YANG schema element.
type Component_Temperature struct {
	ΛMetadata       []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	AlarmSeverity   E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY `path:"alarm-severity" module:"openconfig-platform"`
	ΛAlarmSeverity  []ygot.Annotation                                `path:"@alarm-severity" ygotAnnotation:"true"`
	AlarmStatus     *bool                                            `path:"alarm-status" module:"openconfig-platform"`
	ΛAlarmStatus    []ygot.Annotation                                `path:"@alarm-status" ygotAnnotation:"true"`
	AlarmThreshold  *uint32                                          `path:"alarm-threshold" module:"openconfig-platform"`
	ΛAlarmThreshold []ygot.Annotation                                `path:"@alarm-threshold" ygotAnnotation:"true"`
	Avg             *float64                                         `path:"avg" module:"openconfig-platform"`
	ΛAvg            []ygot.Annotation                                `path:"@avg" ygotAnnotation:"true"`
	Instant         *float64                                         `path:"instant" module:"openconfig-platform"`
	ΛInstant        []ygot.Annotation                                `path:"@instant" ygotAnnotation:"true"`
	Interval        *uint64                                          `path:"interval" module:"openconfig-platform"`
	ΛInterval       []ygot.Annotation                                `path:"@interval" ygotAnnotation:"true"`
	Max             *float64                                         `path:"max" module:"openconfig-platform"`
	ΛMax            []ygot.Annotation                                `path:"@max" ygotAnnotation:"true"`
	MaxTime         *uint64                                          `path:"max-time" module:"openconfig-platform"`
	ΛMaxTime        []ygot.Annotation                                `path:"@max-time" ygotAnnotation:"true"`
	Min             *float64                                         `path:"min" module:"openconfig-platform"`
	ΛMin            []ygot.Annotation                                `path:"@min" ygotAnnotation:"true"`
	MinTime         *uint64                                          `path:"min-time" module:"openconfig-platform"`
	ΛMinTime        []ygot.Annotation                                `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Temperature implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Temperature) IsYANGGoStruct() {}

// GetAlarmSeverity retrieves the value of the leaf AlarmSeverity from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlarmSeverity is set, it can safely use t.GetAlarmSeverity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlarmSeverity == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetAlarmSeverity() E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY {
	if t == nil || t.AlarmSeverity == 0 {
		return 0
	}
	return t.AlarmSeverity
}

// GetAlarmStatus retrieves the value of the leaf AlarmStatus from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlarmStatus is set, it can safely use t.GetAlarmStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlarmStatus == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetAlarmStatus() bool {
	if t == nil || t.AlarmStatus == nil {
		return false
	}
	return *t.AlarmStatus
}

// GetAlarmThreshold retrieves the value of the leaf AlarmThreshold from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlarmThreshold is set, it can safely use t.GetAlarmThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlarmThreshold == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetAlarmThreshold() uint32 {
	if t == nil || t.AlarmThreshold == nil {
		return 0
	}
	return *t.AlarmThreshold
}

// GetAvg retrieves the value of the leaf Avg from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Temperature
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Temperature) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Temperature) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Temperature"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Temperature) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Transceiver represents the /openconfig-platform/components/component/transceiver YANG schema element.
type Component_Transceiver struct {
	ΛMetadata               []ygot.Annotation                                       `path:"@" ygotAnnotation:"true"`
	Channel                 map[uint16]*Component_Transceiver_Channel               `path:"physical-channels/channel" module:"openconfig-platform-transceiver"`
	ΛChannel                []ygot.Annotation                                       `path:"physical-channels/@channel" ygotAnnotation:"true"`
	ConnectorType           E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE         `path:"state/connector-type" module:"openconfig-platform-transceiver"`
	ΛConnectorType          []ygot.Annotation                                       `path:"state/@connector-type" ygotAnnotation:"true"`
	DateCode                *string                                                 `path:"state/date-code" module:"openconfig-platform-transceiver"`
	ΛDateCode               []ygot.Annotation                                       `path:"state/@date-code" ygotAnnotation:"true"`
	Enabled                 *bool                                                   `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-platform-transceiver"`
	ΛEnabled                []ygot.Annotation                                       `path:"state/@enabled" ygotAnnotation:"true"`
	EthernetPmd             E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE            `path:"state/ethernet-pmd" module:"openconfig-platform-transceiver"`
	ΛEthernetPmd            []ygot.Annotation                                       `path:"state/@ethernet-pmd" ygotAnnotation:"true"`
	EthernetPmdPreconf      E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE            `path:"state/ethernet-pmd-preconf" shadow-path:"config/ethernet-pmd-preconf" module:"openconfig-platform-transceiver"`
	ΛEthernetPmdPreconf     []ygot.Annotation                                       `path:"state/@ethernet-pmd-preconf" ygotAnnotation:"true"`
	FaultCondition          *bool                                                   `path:"state/fault-condition" module:"openconfig-platform-transceiver"`
	ΛFaultCondition         []ygot.Annotation                                       `path:"state/@fault-condition" ygotAnnotation:"true"`
	FecCorrectedBits        *uint64                                                 `path:"state/fec-corrected-bits" module:"openconfig-platform-transceiver"`
	ΛFecCorrectedBits       []ygot.Annotation                                       `path:"state/@fec-corrected-bits" ygotAnnotation:"true"`
	FecCorrectedBytes       *uint64                                                 `path:"state/fec-corrected-bytes" module:"openconfig-platform-transceiver"`
	ΛFecCorrectedBytes      []ygot.Annotation                                       `path:"state/@fec-corrected-bytes" ygotAnnotation:"true"`
	FecMode                 E_OpenconfigPlatformTypes_FEC_MODE_TYPE                 `path:"state/fec-mode" shadow-path:"config/fec-mode" module:"openconfig-platform-transceiver"`
	ΛFecMode                []ygot.Annotation                                       `path:"state/@fec-mode" ygotAnnotation:"true"`
	FecStatus               E_OpenconfigPlatformTypes_FEC_STATUS_TYPE               `path:"state/fec-status" module:"openconfig-platform-transceiver"`
	ΛFecStatus              []ygot.Annotation                                       `path:"state/@fec-status" ygotAnnotation:"true"`
	FecUncorrectableBlocks  *uint64                                                 `path:"state/fec-uncorrectable-blocks" module:"openconfig-platform-transceiver"`
	ΛFecUncorrectableBlocks []ygot.Annotation                                       `path:"state/@fec-uncorrectable-blocks" ygotAnnotation:"true"`
	FecUncorrectableWords   *uint64                                                 `path:"state/fec-uncorrectable-words" module:"openconfig-platform-transceiver"`
	ΛFecUncorrectableWords  []ygot.Annotation                                       `path:"state/@fec-uncorrectable-words" ygotAnnotation:"true"`
	FormFactor              E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE `path:"state/form-factor" module:"openconfig-platform-transceiver"`
	ΛFormFactor             []ygot.Annotation                                       `path:"state/@form-factor" ygotAnnotation:"true"`
	FormFactorPreconf       E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE `path:"state/form-factor-preconf" shadow-path:"config/form-factor-preconf" module:"openconfig-platform-transceiver"`
	ΛFormFactorPreconf      []ygot.Annotation                                       `path:"state/@form-factor-preconf" ygotAnnotation:"true"`
	InputPower              *Component_Transceiver_InputPower                       `path:"state/input-power" module:"openconfig-platform-transceiver"`
	ΛInputPower             []ygot.Annotation                                       `path:"state/@input-power" ygotAnnotation:"true"`
	LaserBiasCurrent        *Component_Transceiver_LaserBiasCurrent                 `path:"state/laser-bias-current" module:"openconfig-platform-transceiver"`
	ΛLaserBiasCurrent       []ygot.Annotation                                       `path:"state/@laser-bias-current" ygotAnnotation:"true"`
	OtnComplianceCode       E_OpenconfigTransportTypes_OTN_APPLICATION_CODE         `path:"state/otn-compliance-code" module:"openconfig-platform-transceiver"`
	ΛOtnComplianceCode      []ygot.Annotation                                       `path:"state/@otn-compliance-code" ygotAnnotation:"true"`
	OutputPower             *Component_Transceiver_OutputPower                      `path:"state/output-power" module:"openconfig-platform-transceiver"`
	ΛOutputPower            []ygot.Annotation                                       `path:"state/@output-power" ygotAnnotation:"true"`
	PostFecBer              *Component_Transceiver_PostFecBer                       `path:"state/post-fec-ber" module:"openconfig-platform-transceiver"`
	ΛPostFecBer             []ygot.Annotation                                       `path:"state/@post-fec-ber" ygotAnnotation:"true"`
	PreFecBer               *Component_Transceiver_PreFecBer                        `path:"state/pre-fec-ber" module:"openconfig-platform-transceiver"`
	ΛPreFecBer              []ygot.Annotation                                       `path:"state/@pre-fec-ber" ygotAnnotation:"true"`
	Present                 E_Transceiver_Present                                   `path:"state/present" module:"openconfig-platform-transceiver"`
	ΛPresent                []ygot.Annotation                                       `path:"state/@present" ygotAnnotation:"true"`
	SerialNo                *string                                                 `path:"state/serial-no" module:"openconfig-platform-transceiver"`
	ΛSerialNo               []ygot.Annotation                                       `path:"state/@serial-no" ygotAnnotation:"true"`
	SonetSdhComplianceCode  E_OpenconfigTransportTypes_SONET_APPLICATION_CODE       `path:"state/sonet-sdh-compliance-code" module:"openconfig-platform-transceiver"`
	ΛSonetSdhComplianceCode []ygot.Annotation                                       `path:"state/@sonet-sdh-compliance-code" ygotAnnotation:"true"`
	Vendor                  *string                                                 `path:"state/vendor" module:"openconfig-platform-transceiver"`
	ΛVendor                 []ygot.Annotation                                       `path:"state/@vendor" ygotAnnotation:"true"`
	VendorPart              *string                                                 `path:"state/vendor-part" module:"openconfig-platform-transceiver"`
	ΛVendorPart             []ygot.Annotation                                       `path:"state/@vendor-part" ygotAnnotation:"true"`
	VendorRev               *string                                                 `path:"state/vendor-rev" module:"openconfig-platform-transceiver"`
	ΛVendorRev              []ygot.Annotation                                       `path:"state/@vendor-rev" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver) IsYANGGoStruct() {}

// NewChannel creates a new entry in the Channel list of the
// Component_Transceiver struct. The keys of the list are populated from the input
// arguments.
func (t *Component_Transceiver) NewChannel(Index uint16) (*Component_Transceiver_Channel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Channel == nil {
		t.Channel = make(map[uint16]*Component_Transceiver_Channel)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Channel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Channel", key)
	}

	t.Channel[key] = &Component_Transceiver_Channel{
		Index: &Index,
	}

	return t.Channel[key], nil
}

// RenameChannel renames an entry in the list Channel within
// the Component_Transceiver struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Component_Transceiver) RenameChannel(oldK, newK uint16) error {
	if _, ok := t.Channel[newK]; ok {
		return fmt.Errorf("key %v already exists in Channel", newK)
	}

	e, ok := t.Channel[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Channel", oldK)
	}
	e.Index = &newK

	t.Channel[newK] = e
	delete(t.Channel, oldK)
	return nil
}

// GetOrCreateChannel retrieves the value with the specified keys from
// the receiver Component_Transceiver. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Component_Transceiver) GetOrCreateChannel(Index uint16) *Component_Transceiver_Channel {

	key := Index

	if v, ok := t.Channel[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewChannel(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateChannel got unexpected error: %v", err))
	}
	return v
}

// GetChannel retrieves the value with the specified key from
// the Channel map field of Component_Transceiver. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Component_Transceiver) GetChannel(Index uint16) *Component_Transceiver_Channel {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Channel[key]; ok {
		return lm
	}
	return nil
}

// AppendChannel appends the supplied Component_Transceiver_Channel struct to the
// list Channel of Component_Transceiver. If the key value(s) specified in
// the supplied Component_Transceiver_Channel already exist in the list, an error is
// returned.
func (t *Component_Transceiver) AppendChannel(v *Component_Transceiver_Channel) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Channel == nil {
		t.Channel = make(map[uint16]*Component_Transceiver_Channel)
	}

	if _, ok := t.Channel[key]; ok {
		return fmt.Errorf("duplicate key for list Channel %v", key)
	}

	t.Channel[key] = v
	return nil
}

// GetOrCreateInputPower retrieves the value of the InputPower field
// or returns the existing field if it already exists.
func (t *Component_Transceiver) GetOrCreateInputPower() *Component_Transceiver_InputPower {
	if t.InputPower != nil {
		return t.InputPower
	}
	t.InputPower = &Component_Transceiver_InputPower{}
	return t.InputPower
}

// GetOrCreateLaserBiasCurrent retrieves the value of the LaserBiasCurrent field
// or returns the existing field if it already exists.
func (t *Component_Transceiver) GetOrCreateLaserBiasCurrent() *Component_Transceiver_LaserBiasCurrent {
	if t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	t.LaserBiasCurrent = &Component_Transceiver_LaserBiasCurrent{}
	return t.LaserBiasCurrent
}

// GetOrCreateOutputPower retrieves the value of the OutputPower field
// or returns the existing field if it already exists.
func (t *Component_Transceiver) GetOrCreateOutputPower() *Component_Transceiver_OutputPower {
	if t.OutputPower != nil {
		return t.OutputPower
	}
	t.OutputPower = &Component_Transceiver_OutputPower{}
	return t.OutputPower
}

// GetOrCreatePostFecBer retrieves the value of the PostFecBer field
// or returns the existing field if it already exists.
func (t *Component_Transceiver) GetOrCreatePostFecBer() *Component_Transceiver_PostFecBer {
	if t.PostFecBer != nil {
		return t.PostFecBer
	}
	t.PostFecBer = &Component_Transceiver_PostFecBer{}
	return t.PostFecBer
}

// GetOrCreatePreFecBer retrieves the value of the PreFecBer field
// or returns the existing field if it already exists.
func (t *Component_Transceiver) GetOrCreatePreFecBer() *Component_Transceiver_PreFecBer {
	if t.PreFecBer != nil {
		return t.PreFecBer
	}
	t.PreFecBer = &Component_Transceiver_PreFecBer{}
	return t.PreFecBer
}

// GetInputPower returns the value of the InputPower struct pointer
// from Component_Transceiver. If the receiver or the field InputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver) GetInputPower() *Component_Transceiver_InputPower {
	if t != nil && t.InputPower != nil {
		return t.InputPower
	}
	return nil
}

// GetLaserBiasCurrent returns the value of the LaserBiasCurrent struct pointer
// from Component_Transceiver. If the receiver or the field LaserBiasCurrent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver) GetLaserBiasCurrent() *Component_Transceiver_LaserBiasCurrent {
	if t != nil && t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	return nil
}

// GetOutputPower returns the value of the OutputPower struct pointer
// from Component_Transceiver. If the receiver or the field OutputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver) GetOutputPower() *Component_Transceiver_OutputPower {
	if t != nil && t.OutputPower != nil {
		return t.OutputPower
	}
	return nil
}

// GetPostFecBer returns the value of the PostFecBer struct pointer
// from Component_Transceiver. If the receiver or the field PostFecBer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver) GetPostFecBer() *Component_Transceiver_PostFecBer {
	if t != nil && t.PostFecBer != nil {
		return t.PostFecBer
	}
	return nil
}

// GetPreFecBer returns the value of the PreFecBer struct pointer
// from Component_Transceiver. If the receiver or the field PreFecBer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver) GetPreFecBer() *Component_Transceiver_PreFecBer {
	if t != nil && t.PreFecBer != nil {
		return t.PreFecBer
	}
	return nil
}

// GetConnectorType retrieves the value of the leaf ConnectorType from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectorType is set, it can safely use t.GetConnectorType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectorType == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetConnectorType() E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE {
	if t == nil || t.ConnectorType == 0 {
		return 0
	}
	return t.ConnectorType
}

// GetDateCode retrieves the value of the leaf DateCode from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DateCode is set, it can safely use t.GetDateCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DateCode == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetDateCode() string {
	if t == nil || t.DateCode == nil {
		return ""
	}
	return *t.DateCode
}

// GetEnabled retrieves the value of the leaf Enabled from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetEthernetPmd retrieves the value of the leaf EthernetPmd from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EthernetPmd is set, it can safely use t.GetEthernetPmd()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EthernetPmd == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetEthernetPmd() E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE {
	if t == nil || t.EthernetPmd == 0 {
		return 0
	}
	return t.EthernetPmd
}

// GetEthernetPmdPreconf retrieves the value of the leaf EthernetPmdPreconf from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EthernetPmdPreconf is set, it can safely use t.GetEthernetPmdPreconf()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EthernetPmdPreconf == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetEthernetPmdPreconf() E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE {
	if t == nil || t.EthernetPmdPreconf == 0 {
		return 0
	}
	return t.EthernetPmdPreconf
}

// GetFaultCondition retrieves the value of the leaf FaultCondition from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FaultCondition is set, it can safely use t.GetFaultCondition()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FaultCondition == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFaultCondition() bool {
	if t == nil || t.FaultCondition == nil {
		return false
	}
	return *t.FaultCondition
}

// GetFecCorrectedBits retrieves the value of the leaf FecCorrectedBits from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecCorrectedBits is set, it can safely use t.GetFecCorrectedBits()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecCorrectedBits == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFecCorrectedBits() uint64 {
	if t == nil || t.FecCorrectedBits == nil {
		return 0
	}
	return *t.FecCorrectedBits
}

// GetFecCorrectedBytes retrieves the value of the leaf FecCorrectedBytes from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecCorrectedBytes is set, it can safely use t.GetFecCorrectedBytes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecCorrectedBytes == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFecCorrectedBytes() uint64 {
	if t == nil || t.FecCorrectedBytes == nil {
		return 0
	}
	return *t.FecCorrectedBytes
}

// GetFecMode retrieves the value of the leaf FecMode from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecMode is set, it can safely use t.GetFecMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecMode == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFecMode() E_OpenconfigPlatformTypes_FEC_MODE_TYPE {
	if t == nil || t.FecMode == 0 {
		return 0
	}
	return t.FecMode
}

// GetFecStatus retrieves the value of the leaf FecStatus from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecStatus is set, it can safely use t.GetFecStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecStatus == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFecStatus() E_OpenconfigPlatformTypes_FEC_STATUS_TYPE {
	if t == nil || t.FecStatus == 0 {
		return 0
	}
	return t.FecStatus
}

// GetFecUncorrectableBlocks retrieves the value of the leaf FecUncorrectableBlocks from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecUncorrectableBlocks is set, it can safely use t.GetFecUncorrectableBlocks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecUncorrectableBlocks == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFecUncorrectableBlocks() uint64 {
	if t == nil || t.FecUncorrectableBlocks == nil {
		return 0
	}
	return *t.FecUncorrectableBlocks
}

// GetFecUncorrectableWords retrieves the value of the leaf FecUncorrectableWords from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecUncorrectableWords is set, it can safely use t.GetFecUncorrectableWords()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecUncorrectableWords == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFecUncorrectableWords() uint64 {
	if t == nil || t.FecUncorrectableWords == nil {
		return 0
	}
	return *t.FecUncorrectableWords
}

// GetFormFactor retrieves the value of the leaf FormFactor from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FormFactor is set, it can safely use t.GetFormFactor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FormFactor == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFormFactor() E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE {
	if t == nil || t.FormFactor == 0 {
		return 0
	}
	return t.FormFactor
}

// GetFormFactorPreconf retrieves the value of the leaf FormFactorPreconf from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FormFactorPreconf is set, it can safely use t.GetFormFactorPreconf()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FormFactorPreconf == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetFormFactorPreconf() E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE {
	if t == nil || t.FormFactorPreconf == 0 {
		return 0
	}
	return t.FormFactorPreconf
}

// GetOtnComplianceCode retrieves the value of the leaf OtnComplianceCode from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OtnComplianceCode is set, it can safely use t.GetOtnComplianceCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OtnComplianceCode == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetOtnComplianceCode() E_OpenconfigTransportTypes_OTN_APPLICATION_CODE {
	if t == nil || t.OtnComplianceCode == 0 {
		return 0
	}
	return t.OtnComplianceCode
}

// GetPresent retrieves the value of the leaf Present from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Present is set, it can safely use t.GetPresent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Present == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetPresent() E_Transceiver_Present {
	if t == nil || t.Present == 0 {
		return 0
	}
	return t.Present
}

// GetSerialNo retrieves the value of the leaf SerialNo from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SerialNo is set, it can safely use t.GetSerialNo()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SerialNo == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetSerialNo() string {
	if t == nil || t.SerialNo == nil {
		return ""
	}
	return *t.SerialNo
}

// GetSonetSdhComplianceCode retrieves the value of the leaf SonetSdhComplianceCode from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SonetSdhComplianceCode is set, it can safely use t.GetSonetSdhComplianceCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SonetSdhComplianceCode == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetSonetSdhComplianceCode() E_OpenconfigTransportTypes_SONET_APPLICATION_CODE {
	if t == nil || t.SonetSdhComplianceCode == 0 {
		return 0
	}
	return t.SonetSdhComplianceCode
}

// GetVendor retrieves the value of the leaf Vendor from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Vendor is set, it can safely use t.GetVendor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Vendor == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetVendor() string {
	if t == nil || t.Vendor == nil {
		return ""
	}
	return *t.Vendor
}

// GetVendorPart retrieves the value of the leaf VendorPart from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VendorPart is set, it can safely use t.GetVendorPart()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VendorPart == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetVendorPart() string {
	if t == nil || t.VendorPart == nil {
		return ""
	}
	return *t.VendorPart
}

// GetVendorRev retrieves the value of the leaf VendorRev from the Component_Transceiver
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VendorRev is set, it can safely use t.GetVendorRev()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VendorRev == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver) GetVendorRev() string {
	if t == nil || t.VendorRev == nil {
		return ""
	}
	return *t.VendorRev
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Transceiver_Channel represents the /openconfig-platform/components/component/transceiver/physical-channels/channel YANG schema element.
type Component_Transceiver_Channel struct {
	ΛMetadata          []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	Description        *string                                         `path:"state/description" shadow-path:"config/description" module:"openconfig-platform-transceiver"`
	ΛDescription       []ygot.Annotation                               `path:"state/@description" ygotAnnotation:"true"`
	Index              *uint16                                         `path:"state/index|index" shadow-path:"config/index" module:"openconfig-platform-transceiver"`
	ΛIndex             []ygot.Annotation                               `path:"state/@index|@index" ygotAnnotation:"true"`
	InputPower         *Component_Transceiver_Channel_InputPower       `path:"state/input-power" module:"openconfig-platform-transceiver"`
	ΛInputPower        []ygot.Annotation                               `path:"state/@input-power" ygotAnnotation:"true"`
	LaserBiasCurrent   *Component_Transceiver_Channel_LaserBiasCurrent `path:"state/laser-bias-current" module:"openconfig-platform-transceiver"`
	ΛLaserBiasCurrent  []ygot.Annotation                               `path:"state/@laser-bias-current" ygotAnnotation:"true"`
	OutputFrequency    *uint64                                         `path:"state/output-frequency" module:"openconfig-platform-transceiver"`
	ΛOutputFrequency   []ygot.Annotation                               `path:"state/@output-frequency" ygotAnnotation:"true"`
	OutputPower        *Component_Transceiver_Channel_OutputPower      `path:"state/output-power" module:"openconfig-platform-transceiver"`
	ΛOutputPower       []ygot.Annotation                               `path:"state/@output-power" ygotAnnotation:"true"`
	TargetOutputPower  *float64                                        `path:"state/target-output-power" shadow-path:"config/target-output-power" module:"openconfig-platform-transceiver"`
	ΛTargetOutputPower []ygot.Annotation                               `path:"state/@target-output-power" ygotAnnotation:"true"`
	TxLaser            *bool                                           `path:"state/tx-laser" shadow-path:"config/tx-laser" module:"openconfig-platform-transceiver"`
	ΛTxLaser           []ygot.Annotation                               `path:"state/@tx-laser" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_Channel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_Channel) IsYANGGoStruct() {}

// GetOrCreateInputPower retrieves the value of the InputPower field
// or returns the existing field if it already exists.
func (t *Component_Transceiver_Channel) GetOrCreateInputPower() *Component_Transceiver_Channel_InputPower {
	if t.InputPower != nil {
		return t.InputPower
	}
	t.InputPower = &Component_Transceiver_Channel_InputPower{}
	return t.InputPower
}

// GetOrCreateLaserBiasCurrent retrieves the value of the LaserBiasCurrent field
// or returns the existing field if it already exists.
func (t *Component_Transceiver_Channel) GetOrCreateLaserBiasCurrent() *Component_Transceiver_Channel_LaserBiasCurrent {
	if t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	t.LaserBiasCurrent = &Component_Transceiver_Channel_LaserBiasCurrent{}
	return t.LaserBiasCurrent
}

// GetOrCreateOutputPower retrieves the value of the OutputPower field
// or returns the existing field if it already exists.
func (t *Component_Transceiver_Channel) GetOrCreateOutputPower() *Component_Transceiver_Channel_OutputPower {
	if t.OutputPower != nil {
		return t.OutputPower
	}
	t.OutputPower = &Component_Transceiver_Channel_OutputPower{}
	return t.OutputPower
}

// GetInputPower returns the value of the InputPower struct pointer
// from Component_Transceiver_Channel. If the receiver or the field InputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver_Channel) GetInputPower() *Component_Transceiver_Channel_InputPower {
	if t != nil && t.InputPower != nil {
		return t.InputPower
	}
	return nil
}

// GetLaserBiasCurrent returns the value of the LaserBiasCurrent struct pointer
// from Component_Transceiver_Channel. If the receiver or the field LaserBiasCurrent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver_Channel) GetLaserBiasCurrent() *Component_Transceiver_Channel_LaserBiasCurrent {
	if t != nil && t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	return nil
}

// GetOutputPower returns the value of the OutputPower struct pointer
// from Component_Transceiver_Channel. If the receiver or the field OutputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Component_Transceiver_Channel) GetOutputPower() *Component_Transceiver_Channel_OutputPower {
	if t != nil && t.OutputPower != nil {
		return t.OutputPower
	}
	return nil
}

// GetDescription retrieves the value of the leaf Description from the Component_Transceiver_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetIndex retrieves the value of the leaf Index from the Component_Transceiver_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel) GetIndex() uint16 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetOutputFrequency retrieves the value of the leaf OutputFrequency from the Component_Transceiver_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutputFrequency is set, it can safely use t.GetOutputFrequency()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutputFrequency == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel) GetOutputFrequency() uint64 {
	if t == nil || t.OutputFrequency == nil {
		return 0
	}
	return *t.OutputFrequency
}

// GetTargetOutputPower retrieves the value of the leaf TargetOutputPower from the Component_Transceiver_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetOutputPower is set, it can safely use t.GetTargetOutputPower()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetOutputPower == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel) GetTargetOutputPower() float64 {
	if t == nil || t.TargetOutputPower == nil {
		return 0.0
	}
	return *t.TargetOutputPower
}

// GetTxLaser retrieves the value of the leaf TxLaser from the Component_Transceiver_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TxLaser is set, it can safely use t.GetTxLaser()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TxLaser == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel) GetTxLaser() bool {
	if t == nil || t.TxLaser == nil {
		return false
	}
	return *t.TxLaser
}

// ΛListKeyMap returns the keys of the Component_Transceiver_Channel struct, which is a YANG list entry.
func (t *Component_Transceiver_Channel) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_Channel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_Channel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_Channel) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Component_Transceiver_Channel_InputPower represents the /openconfig-platform/components/component/transceiver/physical-channels/channel/state/input-power YANG schema element.
type Component_Transceiver_Channel_InputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_Channel_InputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_Channel_InputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_Channel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_InputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_Channel_InputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_Channel_InputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_Channel_InputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_Channel_LaserBiasCurrent represents the /openconfig-platform/components/component/transceiver/physical-channels/channel/state/laser-bias-current YANG schema element.
type Component_Transceiver_Channel_LaserBiasCurrent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_Channel_LaserBiasCurrent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_Channel_LaserBiasCurrent) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_Channel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_Channel_LaserBiasCurrent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_Channel_LaserBiasCurrent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_Channel_OutputPower represents the /openconfig-platform/components/component/transceiver/physical-channels/channel/state/output-power YANG schema element.
type Component_Transceiver_Channel_OutputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_Channel_OutputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_Channel_OutputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_Channel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_Channel_OutputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_Channel_OutputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_Channel_OutputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_Channel_OutputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_InputPower represents the /openconfig-platform/components/component/transceiver/state/input-power YANG schema element.
type Component_Transceiver_InputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_InputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_InputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_InputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_InputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_InputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_InputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_LaserBiasCurrent represents the /openconfig-platform/components/component/transceiver/state/laser-bias-current YANG schema element.
type Component_Transceiver_LaserBiasCurrent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_LaserBiasCurrent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_LaserBiasCurrent) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_LaserBiasCurrent) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_LaserBiasCurrent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_LaserBiasCurrent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_LaserBiasCurrent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_OutputPower represents the /openconfig-platform/components/component/transceiver/state/output-power YANG schema element.
type Component_Transceiver_OutputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_OutputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_OutputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_OutputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_OutputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_OutputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_OutputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_PostFecBer represents the /openconfig-platform/components/component/transceiver/state/post-fec-ber YANG schema element.
type Component_Transceiver_PostFecBer struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_PostFecBer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_PostFecBer) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PostFecBer) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_PostFecBer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_PostFecBer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_PostFecBer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Component_Transceiver_PreFecBer represents the /openconfig-platform/components/component/transceiver/state/pre-fec-ber YANG schema element.
type Component_Transceiver_PreFecBer struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-platform-transceiver"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-platform-transceiver"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-platform-transceiver"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-platform-transceiver"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-platform-transceiver"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-platform-transceiver"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-platform-transceiver"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Component_Transceiver_PreFecBer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Component_Transceiver_PreFecBer) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the Component_Transceiver_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *Component_Transceiver_PreFecBer) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Component_Transceiver_PreFecBer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Component_Transceiver_PreFecBer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Component_Transceiver_PreFecBer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Device represents the /device YANG schema element.
type Device struct {
	ΛMetadata         []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	Acl               *Acl                        `path:"acl" module:"openconfig-acl"`
	ΛAcl              []ygot.Annotation           `path:"@acl" ygotAnnotation:"true"`
	Aps               *Aps                        `path:"aps" module:"openconfig-transport-line-protection"`
	ΛAps              []ygot.Annotation           `path:"@aps" ygotAnnotation:"true"`
	Bgp               *Bgp                        `path:"bgp" module:"openconfig-bgp"`
	ΛBgp              []ygot.Annotation           `path:"@bgp" ygotAnnotation:"true"`
	Component         map[string]*Component       `path:"components/component" module:"openconfig-platform"`
	ΛComponent        []ygot.Annotation           `path:"components/@component" ygotAnnotation:"true"`
	Interface         map[string]*Interface       `path:"interfaces/interface" module:"openconfig-interfaces"`
	ΛInterface        []ygot.Annotation           `path:"interfaces/@interface" ygotAnnotation:"true"`
	Lacp              *Lacp                       `path:"lacp" module:"openconfig-lacp"`
	ΛLacp             []ygot.Annotation           `path:"@lacp" ygotAnnotation:"true"`
	Lldp              *Lldp                       `path:"lldp" module:"openconfig-lldp"`
	ΛLldp             []ygot.Annotation           `path:"@lldp" ygotAnnotation:"true"`
	LocalRoutes       *LocalRoutes                `path:"local-routes" module:"openconfig-local-routing"`
	ΛLocalRoutes      []ygot.Annotation           `path:"@local-routes" ygotAnnotation:"true"`
	Messages          *Messages                   `path:"messages" module:"openconfig-messages"`
	ΛMessages         []ygot.Annotation           `path:"@messages" ygotAnnotation:"true"`
	NetworkInstance   map[string]*NetworkInstance `path:"network-instances/network-instance" module:"openconfig-network-instance"`
	ΛNetworkInstance  []ygot.Annotation           `path:"network-instances/@network-instance" ygotAnnotation:"true"`
	OpticalAmplifier  *OpticalAmplifier           `path:"optical-amplifier" module:"openconfig-optical-amplifier"`
	ΛOpticalAmplifier []ygot.Annotation           `path:"@optical-amplifier" ygotAnnotation:"true"`
	RelayAgent        *RelayAgent                 `path:"relay-agent" module:"openconfig-relay-agent"`
	ΛRelayAgent       []ygot.Annotation           `path:"@relay-agent" ygotAnnotation:"true"`
	RoutingPolicy     *RoutingPolicy              `path:"routing-policy" module:"openconfig-routing-policy"`
	ΛRoutingPolicy    []ygot.Annotation           `path:"@routing-policy" ygotAnnotation:"true"`
	Stp               *Stp                        `path:"stp" module:"openconfig-spanning-tree"`
	ΛStp              []ygot.Annotation           `path:"@stp" ygotAnnotation:"true"`
	System            *System                     `path:"system" module:"openconfig-system"`
	ΛSystem           []ygot.Annotation           `path:"@system" ygotAnnotation:"true"`
	TerminalDevice    *TerminalDevice             `path:"terminal-device" module:"openconfig-terminal-device"`
	ΛTerminalDevice   []ygot.Annotation           `path:"@terminal-device" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Device implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Device) IsYANGGoStruct() {}

// NewComponent creates a new entry in the Component list of the
// Device struct. The keys of the list are populated from the input
// arguments.
func (t *Device) NewComponent(Name string) (*Component, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Component == nil {
		t.Component = make(map[string]*Component)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Component[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Component", key)
	}

	t.Component[key] = &Component{
		Name: &Name,
	}

	return t.Component[key], nil
}

// RenameComponent renames an entry in the list Component within
// the Device struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Device) RenameComponent(oldK, newK string) error {
	if _, ok := t.Component[newK]; ok {
		return fmt.Errorf("key %v already exists in Component", newK)
	}

	e, ok := t.Component[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Component", oldK)
	}
	e.Name = &newK

	t.Component[newK] = e
	delete(t.Component, oldK)
	return nil
}

// GetOrCreateComponent retrieves the value with the specified keys from
// the receiver Device. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Device) GetOrCreateComponent(Name string) *Component {

	key := Name

	if v, ok := t.Component[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewComponent(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateComponent got unexpected error: %v", err))
	}
	return v
}

// GetComponent retrieves the value with the specified key from
// the Component map field of Device. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Device) GetComponent(Name string) *Component {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Component[key]; ok {
		return lm
	}
	return nil
}

// AppendComponent appends the supplied Component struct to the
// list Component of Device. If the key value(s) specified in
// the supplied Component already exist in the list, an error is
// returned.
func (t *Device) AppendComponent(v *Component) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Component == nil {
		t.Component = make(map[string]*Component)
	}

	if _, ok := t.Component[key]; ok {
		return fmt.Errorf("duplicate key for list Component %v", key)
	}

	t.Component[key] = v
	return nil
}

// NewInterface creates a new entry in the Interface list of the
// Device struct. The keys of the list are populated from the input
// arguments.
func (t *Device) NewInterface(Name string) (*Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Device struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Device) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Device. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Device) GetOrCreateInterface(Name string) *Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Device. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Device) GetInterface(Name string) *Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Interface struct to the
// list Interface of Device. If the key value(s) specified in
// the supplied Interface already exist in the list, an error is
// returned.
func (t *Device) AppendInterface(v *Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewNetworkInstance creates a new entry in the NetworkInstance list of the
// Device struct. The keys of the list are populated from the input
// arguments.
func (t *Device) NewNetworkInstance(Name string) (*NetworkInstance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NetworkInstance == nil {
		t.NetworkInstance = make(map[string]*NetworkInstance)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NetworkInstance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NetworkInstance", key)
	}

	t.NetworkInstance[key] = &NetworkInstance{
		Name: &Name,
	}

	return t.NetworkInstance[key], nil
}

// RenameNetworkInstance renames an entry in the list NetworkInstance within
// the Device struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Device) RenameNetworkInstance(oldK, newK string) error {
	if _, ok := t.NetworkInstance[newK]; ok {
		return fmt.Errorf("key %v already exists in NetworkInstance", newK)
	}

	e, ok := t.NetworkInstance[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NetworkInstance", oldK)
	}
	e.Name = &newK

	t.NetworkInstance[newK] = e
	delete(t.NetworkInstance, oldK)
	return nil
}

// GetOrCreateNetworkInstance retrieves the value with the specified keys from
// the receiver Device. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Device) GetOrCreateNetworkInstance(Name string) *NetworkInstance {

	key := Name

	if v, ok := t.NetworkInstance[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNetworkInstance(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNetworkInstance got unexpected error: %v", err))
	}
	return v
}

// GetNetworkInstance retrieves the value with the specified key from
// the NetworkInstance map field of Device. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Device) GetNetworkInstance(Name string) *NetworkInstance {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.NetworkInstance[key]; ok {
		return lm
	}
	return nil
}

// AppendNetworkInstance appends the supplied NetworkInstance struct to the
// list NetworkInstance of Device. If the key value(s) specified in
// the supplied NetworkInstance already exist in the list, an error is
// returned.
func (t *Device) AppendNetworkInstance(v *NetworkInstance) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NetworkInstance == nil {
		t.NetworkInstance = make(map[string]*NetworkInstance)
	}

	if _, ok := t.NetworkInstance[key]; ok {
		return fmt.Errorf("duplicate key for list NetworkInstance %v", key)
	}

	t.NetworkInstance[key] = v
	return nil
}

// GetOrCreateAcl retrieves the value of the Acl field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateAcl() *Acl {
	if t.Acl != nil {
		return t.Acl
	}
	t.Acl = &Acl{}
	return t.Acl
}

// GetOrCreateAps retrieves the value of the Aps field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateAps() *Aps {
	if t.Aps != nil {
		return t.Aps
	}
	t.Aps = &Aps{}
	return t.Aps
}

// GetOrCreateBgp retrieves the value of the Bgp field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateBgp() *Bgp {
	if t.Bgp != nil {
		return t.Bgp
	}
	t.Bgp = &Bgp{}
	return t.Bgp
}

// GetOrCreateLacp retrieves the value of the Lacp field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateLacp() *Lacp {
	if t.Lacp != nil {
		return t.Lacp
	}
	t.Lacp = &Lacp{}
	return t.Lacp
}

// GetOrCreateLldp retrieves the value of the Lldp field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateLldp() *Lldp {
	if t.Lldp != nil {
		return t.Lldp
	}
	t.Lldp = &Lldp{}
	return t.Lldp
}

// GetOrCreateLocalRoutes retrieves the value of the LocalRoutes field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateLocalRoutes() *LocalRoutes {
	if t.LocalRoutes != nil {
		return t.LocalRoutes
	}
	t.LocalRoutes = &LocalRoutes{}
	return t.LocalRoutes
}

// GetOrCreateMessages retrieves the value of the Messages field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateMessages() *Messages {
	if t.Messages != nil {
		return t.Messages
	}
	t.Messages = &Messages{}
	return t.Messages
}

// GetOrCreateOpticalAmplifier retrieves the value of the OpticalAmplifier field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateOpticalAmplifier() *OpticalAmplifier {
	if t.OpticalAmplifier != nil {
		return t.OpticalAmplifier
	}
	t.OpticalAmplifier = &OpticalAmplifier{}
	return t.OpticalAmplifier
}

// GetOrCreateRelayAgent retrieves the value of the RelayAgent field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateRelayAgent() *RelayAgent {
	if t.RelayAgent != nil {
		return t.RelayAgent
	}
	t.RelayAgent = &RelayAgent{}
	return t.RelayAgent
}

// GetOrCreateRoutingPolicy retrieves the value of the RoutingPolicy field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateRoutingPolicy() *RoutingPolicy {
	if t.RoutingPolicy != nil {
		return t.RoutingPolicy
	}
	t.RoutingPolicy = &RoutingPolicy{}
	return t.RoutingPolicy
}

// GetOrCreateStp retrieves the value of the Stp field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateStp() *Stp {
	if t.Stp != nil {
		return t.Stp
	}
	t.Stp = &Stp{}
	return t.Stp
}

// GetOrCreateSystem retrieves the value of the System field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateSystem() *System {
	if t.System != nil {
		return t.System
	}
	t.System = &System{}
	return t.System
}

// GetOrCreateTerminalDevice retrieves the value of the TerminalDevice field
// or returns the existing field if it already exists.
func (t *Device) GetOrCreateTerminalDevice() *TerminalDevice {
	if t.TerminalDevice != nil {
		return t.TerminalDevice
	}
	t.TerminalDevice = &TerminalDevice{}
	return t.TerminalDevice
}

// GetAcl returns the value of the Acl struct pointer
// from Device. If the receiver or the field Acl is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetAcl() *Acl {
	if t != nil && t.Acl != nil {
		return t.Acl
	}
	return nil
}

// GetAps returns the value of the Aps struct pointer
// from Device. If the receiver or the field Aps is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetAps() *Aps {
	if t != nil && t.Aps != nil {
		return t.Aps
	}
	return nil
}

// GetBgp returns the value of the Bgp struct pointer
// from Device. If the receiver or the field Bgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetBgp() *Bgp {
	if t != nil && t.Bgp != nil {
		return t.Bgp
	}
	return nil
}

// GetLacp returns the value of the Lacp struct pointer
// from Device. If the receiver or the field Lacp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetLacp() *Lacp {
	if t != nil && t.Lacp != nil {
		return t.Lacp
	}
	return nil
}

// GetLldp returns the value of the Lldp struct pointer
// from Device. If the receiver or the field Lldp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetLldp() *Lldp {
	if t != nil && t.Lldp != nil {
		return t.Lldp
	}
	return nil
}

// GetLocalRoutes returns the value of the LocalRoutes struct pointer
// from Device. If the receiver or the field LocalRoutes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetLocalRoutes() *LocalRoutes {
	if t != nil && t.LocalRoutes != nil {
		return t.LocalRoutes
	}
	return nil
}

// GetMessages returns the value of the Messages struct pointer
// from Device. If the receiver or the field Messages is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetMessages() *Messages {
	if t != nil && t.Messages != nil {
		return t.Messages
	}
	return nil
}

// GetOpticalAmplifier returns the value of the OpticalAmplifier struct pointer
// from Device. If the receiver or the field OpticalAmplifier is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetOpticalAmplifier() *OpticalAmplifier {
	if t != nil && t.OpticalAmplifier != nil {
		return t.OpticalAmplifier
	}
	return nil
}

// GetRelayAgent returns the value of the RelayAgent struct pointer
// from Device. If the receiver or the field RelayAgent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetRelayAgent() *RelayAgent {
	if t != nil && t.RelayAgent != nil {
		return t.RelayAgent
	}
	return nil
}

// GetRoutingPolicy returns the value of the RoutingPolicy struct pointer
// from Device. If the receiver or the field RoutingPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetRoutingPolicy() *RoutingPolicy {
	if t != nil && t.RoutingPolicy != nil {
		return t.RoutingPolicy
	}
	return nil
}

// GetStp returns the value of the Stp struct pointer
// from Device. If the receiver or the field Stp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetStp() *Stp {
	if t != nil && t.Stp != nil {
		return t.Stp
	}
	return nil
}

// GetSystem returns the value of the System struct pointer
// from Device. If the receiver or the field System is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetSystem() *System {
	if t != nil && t.System != nil {
		return t.System
	}
	return nil
}

// GetTerminalDevice returns the value of the TerminalDevice struct pointer
// from Device. If the receiver or the field TerminalDevice is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Device) GetTerminalDevice() *TerminalDevice {
	if t != nil && t.TerminalDevice != nil {
		return t.TerminalDevice
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Device) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Device"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Device) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface represents the /openconfig-interfaces/interfaces/interface YANG schema element.
type Interface struct {
	ΛMetadata        []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	AdminStatus      E_Interface_AdminStatus            `path:"state/admin-status" module:"openconfig-interfaces"`
	ΛAdminStatus     []ygot.Annotation                  `path:"state/@admin-status" ygotAnnotation:"true"`
	Aggregation      *Interface_Aggregation             `path:"aggregation" module:"openconfig-if-aggregate"`
	ΛAggregation     []ygot.Annotation                  `path:"@aggregation" ygotAnnotation:"true"`
	Counters         *Interface_Counters                `path:"state/counters" module:"openconfig-interfaces"`
	ΛCounters        []ygot.Annotation                  `path:"state/@counters" ygotAnnotation:"true"`
	Description      *string                            `path:"state/description" shadow-path:"config/description" module:"openconfig-interfaces"`
	ΛDescription     []ygot.Annotation                  `path:"state/@description" ygotAnnotation:"true"`
	Enabled          *bool                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-interfaces"`
	ΛEnabled         []ygot.Annotation                  `path:"state/@enabled" ygotAnnotation:"true"`
	Ethernet         *Interface_Ethernet                `path:"ethernet" module:"openconfig-if-ethernet"`
	ΛEthernet        []ygot.Annotation                  `path:"@ethernet" ygotAnnotation:"true"`
	HardwarePort     *string                            `path:"state/hardware-port" module:"openconfig-platform-port"`
	ΛHardwarePort    []ygot.Annotation                  `path:"state/@hardware-port" ygotAnnotation:"true"`
	HoldTime         *Interface_HoldTime                `path:"hold-time" module:"openconfig-interfaces"`
	ΛHoldTime        []ygot.Annotation                  `path:"@hold-time" ygotAnnotation:"true"`
	Ifindex          *uint32                            `path:"state/ifindex" module:"openconfig-interfaces"`
	ΛIfindex         []ygot.Annotation                  `path:"state/@ifindex" ygotAnnotation:"true"`
	LastChange       *uint64                            `path:"state/last-change" module:"openconfig-interfaces"`
	ΛLastChange      []ygot.Annotation                  `path:"state/@last-change" ygotAnnotation:"true"`
	Logical          *bool                              `path:"state/logical" module:"openconfig-interfaces"`
	ΛLogical         []ygot.Annotation                  `path:"state/@logical" ygotAnnotation:"true"`
	LoopbackMode     *bool                              `path:"state/loopback-mode" shadow-path:"config/loopback-mode" module:"openconfig-interfaces"`
	ΛLoopbackMode    []ygot.Annotation                  `path:"state/@loopback-mode" ygotAnnotation:"true"`
	Mtu              *uint16                            `path:"state/mtu" shadow-path:"config/mtu" module:"openconfig-interfaces"`
	ΛMtu             []ygot.Annotation                  `path:"state/@mtu" ygotAnnotation:"true"`
	Name             *string                            `path:"state/name|name" shadow-path:"config/name" module:"openconfig-interfaces"`
	ΛName            []ygot.Annotation                  `path:"state/@name|@name" ygotAnnotation:"true"`
	OperStatus       E_Interface_OperStatus             `path:"state/oper-status" module:"openconfig-interfaces"`
	ΛOperStatus      []ygot.Annotation                  `path:"state/@oper-status" ygotAnnotation:"true"`
	PhysicalChannel  []uint16                           `path:"state/physical-channel" module:"openconfig-platform-transceiver"`
	ΛPhysicalChannel []ygot.Annotation                  `path:"state/@physical-channel" ygotAnnotation:"true"`
	RoutedVlan       *Interface_RoutedVlan              `path:"routed-vlan" module:"openconfig-vlan"`
	ΛRoutedVlan      []ygot.Annotation                  `path:"@routed-vlan" ygotAnnotation:"true"`
	Sonet            *Interface_Sonet                   `path:"sonet" module:"openconfig-transport-line-common"`
	ΛSonet           []ygot.Annotation                  `path:"@sonet" ygotAnnotation:"true"`
	Subinterface     map[uint32]*Interface_Subinterface `path:"subinterfaces/subinterface" module:"openconfig-interfaces"`
	ΛSubinterface    []ygot.Annotation                  `path:"subinterfaces/@subinterface" ygotAnnotation:"true"`
	Tpid             E_OpenconfigVlanTypes_TPID_TYPES   `path:"state/tpid" shadow-path:"config/tpid" module:"openconfig-vlan"`
	ΛTpid            []ygot.Annotation                  `path:"state/@tpid" ygotAnnotation:"true"`
	Transceiver      *string                            `path:"state/transceiver" module:"openconfig-platform-transceiver"`
	ΛTransceiver     []ygot.Annotation                  `path:"state/@transceiver" ygotAnnotation:"true"`
	Type             E_IETFInterfaces_InterfaceType     `path:"state/type" shadow-path:"config/type" module:"openconfig-interfaces"`
	ΛType            []ygot.Annotation                  `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface) IsYANGGoStruct() {}

// NewSubinterface creates a new entry in the Subinterface list of the
// Interface struct. The keys of the list are populated from the input
// arguments.
func (t *Interface) NewSubinterface(Index uint32) (*Interface_Subinterface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subinterface == nil {
		t.Subinterface = make(map[uint32]*Interface_Subinterface)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subinterface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subinterface", key)
	}

	t.Subinterface[key] = &Interface_Subinterface{
		Index: &Index,
	}

	return t.Subinterface[key], nil
}

// RenameSubinterface renames an entry in the list Subinterface within
// the Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface) RenameSubinterface(oldK, newK uint32) error {
	if _, ok := t.Subinterface[newK]; ok {
		return fmt.Errorf("key %v already exists in Subinterface", newK)
	}

	e, ok := t.Subinterface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subinterface", oldK)
	}
	e.Index = &newK

	t.Subinterface[newK] = e
	delete(t.Subinterface, oldK)
	return nil
}

// GetOrCreateSubinterface retrieves the value with the specified keys from
// the receiver Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface) GetOrCreateSubinterface(Index uint32) *Interface_Subinterface {

	key := Index

	if v, ok := t.Subinterface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubinterface(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubinterface got unexpected error: %v", err))
	}
	return v
}

// GetSubinterface retrieves the value with the specified key from
// the Subinterface map field of Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface) GetSubinterface(Index uint32) *Interface_Subinterface {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Subinterface[key]; ok {
		return lm
	}
	return nil
}

// AppendSubinterface appends the supplied Interface_Subinterface struct to the
// list Subinterface of Interface. If the key value(s) specified in
// the supplied Interface_Subinterface already exist in the list, an error is
// returned.
func (t *Interface) AppendSubinterface(v *Interface_Subinterface) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subinterface == nil {
		t.Subinterface = make(map[uint32]*Interface_Subinterface)
	}

	if _, ok := t.Subinterface[key]; ok {
		return fmt.Errorf("duplicate key for list Subinterface %v", key)
	}

	t.Subinterface[key] = v
	return nil
}

// GetOrCreateAggregation retrieves the value of the Aggregation field
// or returns the existing field if it already exists.
func (t *Interface) GetOrCreateAggregation() *Interface_Aggregation {
	if t.Aggregation != nil {
		return t.Aggregation
	}
	t.Aggregation = &Interface_Aggregation{}
	return t.Aggregation
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface) GetOrCreateCounters() *Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_Counters{}
	return t.Counters
}

// GetOrCreateEthernet retrieves the value of the Ethernet field
// or returns the existing field if it already exists.
func (t *Interface) GetOrCreateEthernet() *Interface_Ethernet {
	if t.Ethernet != nil {
		return t.Ethernet
	}
	t.Ethernet = &Interface_Ethernet{}
	return t.Ethernet
}

// GetOrCreateHoldTime retrieves the value of the HoldTime field
// or returns the existing field if it already exists.
func (t *Interface) GetOrCreateHoldTime() *Interface_HoldTime {
	if t.HoldTime != nil {
		return t.HoldTime
	}
	t.HoldTime = &Interface_HoldTime{}
	return t.HoldTime
}

// GetOrCreateRoutedVlan retrieves the value of the RoutedVlan field
// or returns the existing field if it already exists.
func (t *Interface) GetOrCreateRoutedVlan() *Interface_RoutedVlan {
	if t.RoutedVlan != nil {
		return t.RoutedVlan
	}
	t.RoutedVlan = &Interface_RoutedVlan{}
	return t.RoutedVlan
}

// GetOrCreateSonet retrieves the value of the Sonet field
// or returns the existing field if it already exists.
func (t *Interface) GetOrCreateSonet() *Interface_Sonet {
	if t.Sonet != nil {
		return t.Sonet
	}
	t.Sonet = &Interface_Sonet{}
	return t.Sonet
}

// GetAggregation returns the value of the Aggregation struct pointer
// from Interface. If the receiver or the field Aggregation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface) GetAggregation() *Interface_Aggregation {
	if t != nil && t.Aggregation != nil {
		return t.Aggregation
	}
	return nil
}

// GetCounters returns the value of the Counters struct pointer
// from Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface) GetCounters() *Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetEthernet returns the value of the Ethernet struct pointer
// from Interface. If the receiver or the field Ethernet is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface) GetEthernet() *Interface_Ethernet {
	if t != nil && t.Ethernet != nil {
		return t.Ethernet
	}
	return nil
}

// GetHoldTime returns the value of the HoldTime struct pointer
// from Interface. If the receiver or the field HoldTime is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface) GetHoldTime() *Interface_HoldTime {
	if t != nil && t.HoldTime != nil {
		return t.HoldTime
	}
	return nil
}

// GetRoutedVlan returns the value of the RoutedVlan struct pointer
// from Interface. If the receiver or the field RoutedVlan is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface) GetRoutedVlan() *Interface_RoutedVlan {
	if t != nil && t.RoutedVlan != nil {
		return t.RoutedVlan
	}
	return nil
}

// GetSonet returns the value of the Sonet struct pointer
// from Interface. If the receiver or the field Sonet is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface) GetSonet() *Interface_Sonet {
	if t != nil && t.Sonet != nil {
		return t.Sonet
	}
	return nil
}

// GetAdminStatus retrieves the value of the leaf AdminStatus from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminStatus is set, it can safely use t.GetAdminStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminStatus == nil'
// before retrieving the leaf's value.
func (t *Interface) GetAdminStatus() E_Interface_AdminStatus {
	if t == nil || t.AdminStatus == 0 {
		return 0
	}
	return t.AdminStatus
}

// GetDescription retrieves the value of the leaf Description from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Interface) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetHardwarePort retrieves the value of the leaf HardwarePort from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HardwarePort is set, it can safely use t.GetHardwarePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HardwarePort == nil'
// before retrieving the leaf's value.
func (t *Interface) GetHardwarePort() string {
	if t == nil || t.HardwarePort == nil {
		return ""
	}
	return *t.HardwarePort
}

// GetIfindex retrieves the value of the leaf Ifindex from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ifindex is set, it can safely use t.GetIfindex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ifindex == nil'
// before retrieving the leaf's value.
func (t *Interface) GetIfindex() uint32 {
	if t == nil || t.Ifindex == nil {
		return 0
	}
	return *t.Ifindex
}

// GetLastChange retrieves the value of the leaf LastChange from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastChange is set, it can safely use t.GetLastChange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastChange == nil'
// before retrieving the leaf's value.
func (t *Interface) GetLastChange() uint64 {
	if t == nil || t.LastChange == nil {
		return 0
	}
	return *t.LastChange
}

// GetLogical retrieves the value of the leaf Logical from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Logical is set, it can safely use t.GetLogical()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Logical == nil'
// before retrieving the leaf's value.
func (t *Interface) GetLogical() bool {
	if t == nil || t.Logical == nil {
		return false
	}
	return *t.Logical
}

// GetLoopbackMode retrieves the value of the leaf LoopbackMode from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LoopbackMode is set, it can safely use t.GetLoopbackMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LoopbackMode == nil'
// before retrieving the leaf's value.
func (t *Interface) GetLoopbackMode() bool {
	if t == nil || t.LoopbackMode == nil {
		return false
	}
	return *t.LoopbackMode
}

// GetMtu retrieves the value of the leaf Mtu from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mtu is set, it can safely use t.GetMtu()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mtu == nil'
// before retrieving the leaf's value.
func (t *Interface) GetMtu() uint16 {
	if t == nil || t.Mtu == nil {
		return 0
	}
	return *t.Mtu
}

// GetName retrieves the value of the leaf Name from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetOperStatus retrieves the value of the leaf OperStatus from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OperStatus is set, it can safely use t.GetOperStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OperStatus == nil'
// before retrieving the leaf's value.
func (t *Interface) GetOperStatus() E_Interface_OperStatus {
	if t == nil || t.OperStatus == 0 {
		return 0
	}
	return t.OperStatus
}

// GetPhysicalChannel retrieves the value of the leaf PhysicalChannel from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PhysicalChannel is set, it can safely use t.GetPhysicalChannel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PhysicalChannel == nil'
// before retrieving the leaf's value.
func (t *Interface) GetPhysicalChannel() []uint16 {
	if t == nil || t.PhysicalChannel == nil {
		return nil
	}
	return t.PhysicalChannel
}

// GetTpid retrieves the value of the leaf Tpid from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tpid is set, it can safely use t.GetTpid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tpid == nil'
// before retrieving the leaf's value.
func (t *Interface) GetTpid() E_OpenconfigVlanTypes_TPID_TYPES {
	if t == nil || t.Tpid == 0 {
		return OpenconfigVlanTypes_TPID_TYPES_TPID_0X8100
	}
	return t.Tpid
}

// GetTransceiver retrieves the value of the leaf Transceiver from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transceiver is set, it can safely use t.GetTransceiver()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transceiver == nil'
// before retrieving the leaf's value.
func (t *Interface) GetTransceiver() string {
	if t == nil || t.Transceiver == nil {
		return ""
	}
	return *t.Transceiver
}

// GetType retrieves the value of the leaf Type from the Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Interface) GetType() E_IETFInterfaces_InterfaceType {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the Interface struct, which is a YANG list entry.
func (t *Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Aggregation represents the /openconfig-interfaces/interfaces/interface/aggregation YANG schema element.
type Interface_Aggregation struct {
	ΛMetadata     []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	LagSpeed      *uint32                                 `path:"state/lag-speed" module:"openconfig-if-aggregate"`
	ΛLagSpeed     []ygot.Annotation                       `path:"state/@lag-speed" ygotAnnotation:"true"`
	LagType       E_OpenconfigIfAggregate_AggregationType `path:"state/lag-type" shadow-path:"config/lag-type" module:"openconfig-if-aggregate"`
	ΛLagType      []ygot.Annotation                       `path:"state/@lag-type" ygotAnnotation:"true"`
	Member        []string                                `path:"state/member" module:"openconfig-if-aggregate"`
	ΛMember       []ygot.Annotation                       `path:"state/@member" ygotAnnotation:"true"`
	MinLinks      *uint16                                 `path:"state/min-links" shadow-path:"config/min-links" module:"openconfig-if-aggregate"`
	ΛMinLinks     []ygot.Annotation                       `path:"state/@min-links" ygotAnnotation:"true"`
	SwitchedVlan  *Interface_Aggregation_SwitchedVlan     `path:"switched-vlan" module:"openconfig-vlan"`
	ΛSwitchedVlan []ygot.Annotation                       `path:"@switched-vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Aggregation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Aggregation) IsYANGGoStruct() {}

// GetOrCreateSwitchedVlan retrieves the value of the SwitchedVlan field
// or returns the existing field if it already exists.
func (t *Interface_Aggregation) GetOrCreateSwitchedVlan() *Interface_Aggregation_SwitchedVlan {
	if t.SwitchedVlan != nil {
		return t.SwitchedVlan
	}
	t.SwitchedVlan = &Interface_Aggregation_SwitchedVlan{}
	return t.SwitchedVlan
}

// GetSwitchedVlan returns the value of the SwitchedVlan struct pointer
// from Interface_Aggregation. If the receiver or the field SwitchedVlan is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Aggregation) GetSwitchedVlan() *Interface_Aggregation_SwitchedVlan {
	if t != nil && t.SwitchedVlan != nil {
		return t.SwitchedVlan
	}
	return nil
}

// GetLagSpeed retrieves the value of the leaf LagSpeed from the Interface_Aggregation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LagSpeed is set, it can safely use t.GetLagSpeed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LagSpeed == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation) GetLagSpeed() uint32 {
	if t == nil || t.LagSpeed == nil {
		return 0
	}
	return *t.LagSpeed
}

// GetLagType retrieves the value of the leaf LagType from the Interface_Aggregation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LagType is set, it can safely use t.GetLagType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LagType == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation) GetLagType() E_OpenconfigIfAggregate_AggregationType {
	if t == nil || t.LagType == 0 {
		return 0
	}
	return t.LagType
}

// GetMember retrieves the value of the leaf Member from the Interface_Aggregation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Member is set, it can safely use t.GetMember()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Member == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation) GetMember() []string {
	if t == nil || t.Member == nil {
		return nil
	}
	return t.Member
}

// GetMinLinks retrieves the value of the leaf MinLinks from the Interface_Aggregation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinLinks is set, it can safely use t.GetMinLinks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinLinks == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation) GetMinLinks() uint16 {
	if t == nil || t.MinLinks == nil {
		return 0
	}
	return *t.MinLinks
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Aggregation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Aggregation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Aggregation) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Aggregation_SwitchedVlan represents the /openconfig-interfaces/interfaces/interface/aggregation/switched-vlan YANG schema element.
type Interface_Aggregation_SwitchedVlan struct {
	ΛMetadata      []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	AccessVlan     *uint16                                               `path:"state/access-vlan" shadow-path:"config/access-vlan" module:"openconfig-vlan"`
	ΛAccessVlan    []ygot.Annotation                                     `path:"state/@access-vlan" ygotAnnotation:"true"`
	InterfaceMode  E_OpenconfigVlanTypes_VlanModeType                    `path:"state/interface-mode" shadow-path:"config/interface-mode" module:"openconfig-vlan"`
	ΛInterfaceMode []ygot.Annotation                                     `path:"state/@interface-mode" ygotAnnotation:"true"`
	NativeVlan     *uint16                                               `path:"state/native-vlan" shadow-path:"config/native-vlan" module:"openconfig-vlan"`
	ΛNativeVlan    []ygot.Annotation                                     `path:"state/@native-vlan" ygotAnnotation:"true"`
	TrunkVlans     []Interface_Aggregation_SwitchedVlan_TrunkVlans_Union `path:"state/trunk-vlans" shadow-path:"config/trunk-vlans" module:"openconfig-vlan"`
	ΛTrunkVlans    []ygot.Annotation                                     `path:"state/@trunk-vlans" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Aggregation_SwitchedVlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Aggregation_SwitchedVlan) IsYANGGoStruct() {}

// GetAccessVlan retrieves the value of the leaf AccessVlan from the Interface_Aggregation_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AccessVlan is set, it can safely use t.GetAccessVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AccessVlan == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation_SwitchedVlan) GetAccessVlan() uint16 {
	if t == nil || t.AccessVlan == nil {
		return 0
	}
	return *t.AccessVlan
}

// GetInterfaceMode retrieves the value of the leaf InterfaceMode from the Interface_Aggregation_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceMode is set, it can safely use t.GetInterfaceMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceMode == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation_SwitchedVlan) GetInterfaceMode() E_OpenconfigVlanTypes_VlanModeType {
	if t == nil || t.InterfaceMode == 0 {
		return 0
	}
	return t.InterfaceMode
}

// GetNativeVlan retrieves the value of the leaf NativeVlan from the Interface_Aggregation_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NativeVlan is set, it can safely use t.GetNativeVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NativeVlan == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation_SwitchedVlan) GetNativeVlan() uint16 {
	if t == nil || t.NativeVlan == nil {
		return 0
	}
	return *t.NativeVlan
}

// GetTrunkVlans retrieves the value of the leaf TrunkVlans from the Interface_Aggregation_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrunkVlans is set, it can safely use t.GetTrunkVlans()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrunkVlans == nil'
// before retrieving the leaf's value.
func (t *Interface_Aggregation_SwitchedVlan) GetTrunkVlans() []Interface_Aggregation_SwitchedVlan_TrunkVlans_Union {
	if t == nil || t.TrunkVlans == nil {
		return nil
	}
	return t.TrunkVlans
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Aggregation_SwitchedVlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Aggregation_SwitchedVlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Aggregation_SwitchedVlan) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Aggregation_SwitchedVlan_TrunkVlans_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-interfaces/interfaces/interface/aggregation/switched-vlan/state/trunk-vlans within the YANG schema.
// Union type can be one of [UnionString, UnionUint16].
type Interface_Aggregation_SwitchedVlan_TrunkVlans_Union interface {
	// Union type can be one of [UnionString, UnionUint16]
	Documentation_for_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union()
}

// Documentation_for_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union ensures that UnionString
// implements the Interface_Aggregation_SwitchedVlan_TrunkVlans_Union interface.
func (UnionString) Documentation_for_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union() {}

// Documentation_for_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union ensures that UnionUint16
// implements the Interface_Aggregation_SwitchedVlan_TrunkVlans_Union interface.
func (UnionUint16) Documentation_for_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union() {}

// To_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Interface_Aggregation_SwitchedVlan_TrunkVlans_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Interface_Aggregation_SwitchedVlan) To_Interface_Aggregation_SwitchedVlan_TrunkVlans_Union(i interface{}) (Interface_Aggregation_SwitchedVlan_TrunkVlans_Union, error) {
	if v, ok := i.(Interface_Aggregation_SwitchedVlan_TrunkVlans_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Interface_Aggregation_SwitchedVlan_TrunkVlans_Union, unknown union type, got: %T, want any of [string, uint16]", i, i)
}

// Interface_Counters represents the /openconfig-interfaces/interfaces/interface/state/counters YANG schema element.
type Interface_Counters struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CarrierTransitions  *uint64           `path:"carrier-transitions" module:"openconfig-interfaces"`
	ΛCarrierTransitions []ygot.Annotation `path:"@carrier-transitions" ygotAnnotation:"true"`
	InBroadcastPkts     *uint64           `path:"in-broadcast-pkts" module:"openconfig-interfaces"`
	ΛInBroadcastPkts    []ygot.Annotation `path:"@in-broadcast-pkts" ygotAnnotation:"true"`
	InDiscards          *uint64           `path:"in-discards" module:"openconfig-interfaces"`
	ΛInDiscards         []ygot.Annotation `path:"@in-discards" ygotAnnotation:"true"`
	InErrors            *uint64           `path:"in-errors" module:"openconfig-interfaces"`
	ΛInErrors           []ygot.Annotation `path:"@in-errors" ygotAnnotation:"true"`
	InFcsErrors         *uint64           `path:"in-fcs-errors" module:"openconfig-interfaces"`
	ΛInFcsErrors        []ygot.Annotation `path:"@in-fcs-errors" ygotAnnotation:"true"`
	InMulticastPkts     *uint64           `path:"in-multicast-pkts" module:"openconfig-interfaces"`
	ΛInMulticastPkts    []ygot.Annotation `path:"@in-multicast-pkts" ygotAnnotation:"true"`
	InOctets            *uint64           `path:"in-octets" module:"openconfig-interfaces"`
	ΛInOctets           []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts              *uint64           `path:"in-pkts" module:"openconfig-interfaces"`
	ΛInPkts             []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	InUnicastPkts       *uint64           `path:"in-unicast-pkts" module:"openconfig-interfaces"`
	ΛInUnicastPkts      []ygot.Annotation `path:"@in-unicast-pkts" ygotAnnotation:"true"`
	InUnknownProtos     *uint64           `path:"in-unknown-protos" module:"openconfig-interfaces"`
	ΛInUnknownProtos    []ygot.Annotation `path:"@in-unknown-protos" ygotAnnotation:"true"`
	LastClear           *uint64           `path:"last-clear" module:"openconfig-interfaces"`
	ΛLastClear          []ygot.Annotation `path:"@last-clear" ygotAnnotation:"true"`
	OutBroadcastPkts    *uint64           `path:"out-broadcast-pkts" module:"openconfig-interfaces"`
	ΛOutBroadcastPkts   []ygot.Annotation `path:"@out-broadcast-pkts" ygotAnnotation:"true"`
	OutDiscards         *uint64           `path:"out-discards" module:"openconfig-interfaces"`
	ΛOutDiscards        []ygot.Annotation `path:"@out-discards" ygotAnnotation:"true"`
	OutErrors           *uint64           `path:"out-errors" module:"openconfig-interfaces"`
	ΛOutErrors          []ygot.Annotation `path:"@out-errors" ygotAnnotation:"true"`
	OutMulticastPkts    *uint64           `path:"out-multicast-pkts" module:"openconfig-interfaces"`
	ΛOutMulticastPkts   []ygot.Annotation `path:"@out-multicast-pkts" ygotAnnotation:"true"`
	OutOctets           *uint64           `path:"out-octets" module:"openconfig-interfaces"`
	ΛOutOctets          []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts             *uint64           `path:"out-pkts" module:"openconfig-interfaces"`
	ΛOutPkts            []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
	OutUnicastPkts      *uint64           `path:"out-unicast-pkts" module:"openconfig-interfaces"`
	ΛOutUnicastPkts     []ygot.Annotation `path:"@out-unicast-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Counters) IsYANGGoStruct() {}

// GetCarrierTransitions retrieves the value of the leaf CarrierTransitions from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CarrierTransitions is set, it can safely use t.GetCarrierTransitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CarrierTransitions == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetCarrierTransitions() uint64 {
	if t == nil || t.CarrierTransitions == nil {
		return 0
	}
	return *t.CarrierTransitions
}

// GetInBroadcastPkts retrieves the value of the leaf InBroadcastPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InBroadcastPkts is set, it can safely use t.GetInBroadcastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InBroadcastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInBroadcastPkts() uint64 {
	if t == nil || t.InBroadcastPkts == nil {
		return 0
	}
	return *t.InBroadcastPkts
}

// GetInDiscards retrieves the value of the leaf InDiscards from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InDiscards is set, it can safely use t.GetInDiscards()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InDiscards == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInDiscards() uint64 {
	if t == nil || t.InDiscards == nil {
		return 0
	}
	return *t.InDiscards
}

// GetInErrors retrieves the value of the leaf InErrors from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InErrors is set, it can safely use t.GetInErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInErrors() uint64 {
	if t == nil || t.InErrors == nil {
		return 0
	}
	return *t.InErrors
}

// GetInFcsErrors retrieves the value of the leaf InFcsErrors from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InFcsErrors is set, it can safely use t.GetInFcsErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InFcsErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInFcsErrors() uint64 {
	if t == nil || t.InFcsErrors == nil {
		return 0
	}
	return *t.InFcsErrors
}

// GetInMulticastPkts retrieves the value of the leaf InMulticastPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InMulticastPkts is set, it can safely use t.GetInMulticastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InMulticastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInMulticastPkts() uint64 {
	if t == nil || t.InMulticastPkts == nil {
		return 0
	}
	return *t.InMulticastPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetInUnicastPkts retrieves the value of the leaf InUnicastPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUnicastPkts is set, it can safely use t.GetInUnicastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUnicastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInUnicastPkts() uint64 {
	if t == nil || t.InUnicastPkts == nil {
		return 0
	}
	return *t.InUnicastPkts
}

// GetInUnknownProtos retrieves the value of the leaf InUnknownProtos from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUnknownProtos is set, it can safely use t.GetInUnknownProtos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUnknownProtos == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetInUnknownProtos() uint64 {
	if t == nil || t.InUnknownProtos == nil {
		return 0
	}
	return *t.InUnknownProtos
}

// GetLastClear retrieves the value of the leaf LastClear from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastClear is set, it can safely use t.GetLastClear()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastClear == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetLastClear() uint64 {
	if t == nil || t.LastClear == nil {
		return 0
	}
	return *t.LastClear
}

// GetOutBroadcastPkts retrieves the value of the leaf OutBroadcastPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutBroadcastPkts is set, it can safely use t.GetOutBroadcastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutBroadcastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutBroadcastPkts() uint64 {
	if t == nil || t.OutBroadcastPkts == nil {
		return 0
	}
	return *t.OutBroadcastPkts
}

// GetOutDiscards retrieves the value of the leaf OutDiscards from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutDiscards is set, it can safely use t.GetOutDiscards()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutDiscards == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutDiscards() uint64 {
	if t == nil || t.OutDiscards == nil {
		return 0
	}
	return *t.OutDiscards
}

// GetOutErrors retrieves the value of the leaf OutErrors from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutErrors is set, it can safely use t.GetOutErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutErrors() uint64 {
	if t == nil || t.OutErrors == nil {
		return 0
	}
	return *t.OutErrors
}

// GetOutMulticastPkts retrieves the value of the leaf OutMulticastPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutMulticastPkts is set, it can safely use t.GetOutMulticastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutMulticastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutMulticastPkts() uint64 {
	if t == nil || t.OutMulticastPkts == nil {
		return 0
	}
	return *t.OutMulticastPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// GetOutUnicastPkts retrieves the value of the leaf OutUnicastPkts from the Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutUnicastPkts is set, it can safely use t.GetOutUnicastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutUnicastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Counters) GetOutUnicastPkts() uint64 {
	if t == nil || t.OutUnicastPkts == nil {
		return 0
	}
	return *t.OutUnicastPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Ethernet represents the /openconfig-interfaces/interfaces/interface/ethernet YANG schema element.
type Interface_Ethernet struct {
	ΛMetadata             []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	AggregateId           *string                               `path:"state/aggregate-id" shadow-path:"config/aggregate-id" module:"openconfig-if-aggregate"`
	ΛAggregateId          []ygot.Annotation                     `path:"state/@aggregate-id" ygotAnnotation:"true"`
	AutoNegotiate         *bool                                 `path:"state/auto-negotiate" shadow-path:"config/auto-negotiate" module:"openconfig-if-ethernet"`
	ΛAutoNegotiate        []ygot.Annotation                     `path:"state/@auto-negotiate" ygotAnnotation:"true"`
	Counters              *Interface_Ethernet_Counters          `path:"state/counters" module:"openconfig-if-ethernet"`
	ΛCounters             []ygot.Annotation                     `path:"state/@counters" ygotAnnotation:"true"`
	DuplexMode            E_Ethernet_DuplexMode                 `path:"state/duplex-mode" shadow-path:"config/duplex-mode" module:"openconfig-if-ethernet"`
	ΛDuplexMode           []ygot.Annotation                     `path:"state/@duplex-mode" ygotAnnotation:"true"`
	EnableFlowControl     *bool                                 `path:"state/enable-flow-control" shadow-path:"config/enable-flow-control" module:"openconfig-if-ethernet"`
	ΛEnableFlowControl    []ygot.Annotation                     `path:"state/@enable-flow-control" ygotAnnotation:"true"`
	HwMacAddress          *string                               `path:"state/hw-mac-address" module:"openconfig-if-ethernet"`
	ΛHwMacAddress         []ygot.Annotation                     `path:"state/@hw-mac-address" ygotAnnotation:"true"`
	MacAddress            *string                               `path:"state/mac-address" shadow-path:"config/mac-address" module:"openconfig-if-ethernet"`
	ΛMacAddress           []ygot.Annotation                     `path:"state/@mac-address" ygotAnnotation:"true"`
	NegotiatedDuplexMode  E_Ethernet_NegotiatedDuplexMode       `path:"state/negotiated-duplex-mode" module:"openconfig-if-ethernet"`
	ΛNegotiatedDuplexMode []ygot.Annotation                     `path:"state/@negotiated-duplex-mode" ygotAnnotation:"true"`
	NegotiatedPortSpeed   E_OpenconfigIfEthernet_ETHERNET_SPEED `path:"state/negotiated-port-speed" module:"openconfig-if-ethernet"`
	ΛNegotiatedPortSpeed  []ygot.Annotation                     `path:"state/@negotiated-port-speed" ygotAnnotation:"true"`
	PortSpeed             E_OpenconfigIfEthernet_ETHERNET_SPEED `path:"state/port-speed" shadow-path:"config/port-speed" module:"openconfig-if-ethernet"`
	ΛPortSpeed            []ygot.Annotation                     `path:"state/@port-speed" ygotAnnotation:"true"`
	SwitchedVlan          *Interface_Ethernet_SwitchedVlan      `path:"switched-vlan" module:"openconfig-vlan"`
	ΛSwitchedVlan         []ygot.Annotation                     `path:"@switched-vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Ethernet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Ethernet) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface_Ethernet) GetOrCreateCounters() *Interface_Ethernet_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_Ethernet_Counters{}
	return t.Counters
}

// GetOrCreateSwitchedVlan retrieves the value of the SwitchedVlan field
// or returns the existing field if it already exists.
func (t *Interface_Ethernet) GetOrCreateSwitchedVlan() *Interface_Ethernet_SwitchedVlan {
	if t.SwitchedVlan != nil {
		return t.SwitchedVlan
	}
	t.SwitchedVlan = &Interface_Ethernet_SwitchedVlan{}
	return t.SwitchedVlan
}

// GetCounters returns the value of the Counters struct pointer
// from Interface_Ethernet. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Ethernet) GetCounters() *Interface_Ethernet_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetSwitchedVlan returns the value of the SwitchedVlan struct pointer
// from Interface_Ethernet. If the receiver or the field SwitchedVlan is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Ethernet) GetSwitchedVlan() *Interface_Ethernet_SwitchedVlan {
	if t != nil && t.SwitchedVlan != nil {
		return t.SwitchedVlan
	}
	return nil
}

// GetAggregateId retrieves the value of the leaf AggregateId from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AggregateId is set, it can safely use t.GetAggregateId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AggregateId == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetAggregateId() string {
	if t == nil || t.AggregateId == nil {
		return ""
	}
	return *t.AggregateId
}

// GetAutoNegotiate retrieves the value of the leaf AutoNegotiate from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AutoNegotiate is set, it can safely use t.GetAutoNegotiate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AutoNegotiate == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetAutoNegotiate() bool {
	if t == nil || t.AutoNegotiate == nil {
		return true
	}
	return *t.AutoNegotiate
}

// GetDuplexMode retrieves the value of the leaf DuplexMode from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DuplexMode is set, it can safely use t.GetDuplexMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DuplexMode == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetDuplexMode() E_Ethernet_DuplexMode {
	if t == nil || t.DuplexMode == 0 {
		return 0
	}
	return t.DuplexMode
}

// GetEnableFlowControl retrieves the value of the leaf EnableFlowControl from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableFlowControl is set, it can safely use t.GetEnableFlowControl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableFlowControl == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetEnableFlowControl() bool {
	if t == nil || t.EnableFlowControl == nil {
		return false
	}
	return *t.EnableFlowControl
}

// GetHwMacAddress retrieves the value of the leaf HwMacAddress from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HwMacAddress is set, it can safely use t.GetHwMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HwMacAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetHwMacAddress() string {
	if t == nil || t.HwMacAddress == nil {
		return ""
	}
	return *t.HwMacAddress
}

// GetMacAddress retrieves the value of the leaf MacAddress from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAddress is set, it can safely use t.GetMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetMacAddress() string {
	if t == nil || t.MacAddress == nil {
		return ""
	}
	return *t.MacAddress
}

// GetNegotiatedDuplexMode retrieves the value of the leaf NegotiatedDuplexMode from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NegotiatedDuplexMode is set, it can safely use t.GetNegotiatedDuplexMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NegotiatedDuplexMode == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetNegotiatedDuplexMode() E_Ethernet_NegotiatedDuplexMode {
	if t == nil || t.NegotiatedDuplexMode == 0 {
		return 0
	}
	return t.NegotiatedDuplexMode
}

// GetNegotiatedPortSpeed retrieves the value of the leaf NegotiatedPortSpeed from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NegotiatedPortSpeed is set, it can safely use t.GetNegotiatedPortSpeed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NegotiatedPortSpeed == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetNegotiatedPortSpeed() E_OpenconfigIfEthernet_ETHERNET_SPEED {
	if t == nil || t.NegotiatedPortSpeed == 0 {
		return 0
	}
	return t.NegotiatedPortSpeed
}

// GetPortSpeed retrieves the value of the leaf PortSpeed from the Interface_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortSpeed is set, it can safely use t.GetPortSpeed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortSpeed == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet) GetPortSpeed() E_OpenconfigIfEthernet_ETHERNET_SPEED {
	if t == nil || t.PortSpeed == 0 {
		return 0
	}
	return t.PortSpeed
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Ethernet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Ethernet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Ethernet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Ethernet_Counters represents the /openconfig-interfaces/interfaces/interface/ethernet/state/counters YANG schema element.
type Interface_Ethernet_Counters struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	In_8021QFrames       *uint64           `path:"in-8021q-frames" module:"openconfig-if-ethernet"`
	ΛIn_8021QFrames      []ygot.Annotation `path:"@in-8021q-frames" ygotAnnotation:"true"`
	InBlockErrors        *uint64           `path:"in-block-errors" module:"openconfig-if-ethernet"`
	ΛInBlockErrors       []ygot.Annotation `path:"@in-block-errors" ygotAnnotation:"true"`
	InCrcErrors          *uint64           `path:"in-crc-errors" module:"openconfig-if-ethernet"`
	ΛInCrcErrors         []ygot.Annotation `path:"@in-crc-errors" ygotAnnotation:"true"`
	InFragmentFrames     *uint64           `path:"in-fragment-frames" module:"openconfig-if-ethernet"`
	ΛInFragmentFrames    []ygot.Annotation `path:"@in-fragment-frames" ygotAnnotation:"true"`
	InJabberFrames       *uint64           `path:"in-jabber-frames" module:"openconfig-if-ethernet"`
	ΛInJabberFrames      []ygot.Annotation `path:"@in-jabber-frames" ygotAnnotation:"true"`
	InMacControlFrames   *uint64           `path:"in-mac-control-frames" module:"openconfig-if-ethernet"`
	ΛInMacControlFrames  []ygot.Annotation `path:"@in-mac-control-frames" ygotAnnotation:"true"`
	InMacPauseFrames     *uint64           `path:"in-mac-pause-frames" module:"openconfig-if-ethernet"`
	ΛInMacPauseFrames    []ygot.Annotation `path:"@in-mac-pause-frames" ygotAnnotation:"true"`
	InOversizeFrames     *uint64           `path:"in-oversize-frames" module:"openconfig-if-ethernet"`
	ΛInOversizeFrames    []ygot.Annotation `path:"@in-oversize-frames" ygotAnnotation:"true"`
	InUndersizeFrames    *uint64           `path:"in-undersize-frames" module:"openconfig-if-ethernet"`
	ΛInUndersizeFrames   []ygot.Annotation `path:"@in-undersize-frames" ygotAnnotation:"true"`
	Out_8021QFrames      *uint64           `path:"out-8021q-frames" module:"openconfig-if-ethernet"`
	ΛOut_8021QFrames     []ygot.Annotation `path:"@out-8021q-frames" ygotAnnotation:"true"`
	OutMacControlFrames  *uint64           `path:"out-mac-control-frames" module:"openconfig-if-ethernet"`
	ΛOutMacControlFrames []ygot.Annotation `path:"@out-mac-control-frames" ygotAnnotation:"true"`
	OutMacPauseFrames    *uint64           `path:"out-mac-pause-frames" module:"openconfig-if-ethernet"`
	ΛOutMacPauseFrames   []ygot.Annotation `path:"@out-mac-pause-frames" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Ethernet_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Ethernet_Counters) IsYANGGoStruct() {}

// GetIn_8021QFrames retrieves the value of the leaf In_8021QFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if In_8021QFrames is set, it can safely use t.GetIn_8021QFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.In_8021QFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetIn_8021QFrames() uint64 {
	if t == nil || t.In_8021QFrames == nil {
		return 0
	}
	return *t.In_8021QFrames
}

// GetInBlockErrors retrieves the value of the leaf InBlockErrors from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InBlockErrors is set, it can safely use t.GetInBlockErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InBlockErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInBlockErrors() uint64 {
	if t == nil || t.InBlockErrors == nil {
		return 0
	}
	return *t.InBlockErrors
}

// GetInCrcErrors retrieves the value of the leaf InCrcErrors from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InCrcErrors is set, it can safely use t.GetInCrcErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InCrcErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInCrcErrors() uint64 {
	if t == nil || t.InCrcErrors == nil {
		return 0
	}
	return *t.InCrcErrors
}

// GetInFragmentFrames retrieves the value of the leaf InFragmentFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InFragmentFrames is set, it can safely use t.GetInFragmentFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InFragmentFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInFragmentFrames() uint64 {
	if t == nil || t.InFragmentFrames == nil {
		return 0
	}
	return *t.InFragmentFrames
}

// GetInJabberFrames retrieves the value of the leaf InJabberFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InJabberFrames is set, it can safely use t.GetInJabberFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InJabberFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInJabberFrames() uint64 {
	if t == nil || t.InJabberFrames == nil {
		return 0
	}
	return *t.InJabberFrames
}

// GetInMacControlFrames retrieves the value of the leaf InMacControlFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InMacControlFrames is set, it can safely use t.GetInMacControlFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InMacControlFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInMacControlFrames() uint64 {
	if t == nil || t.InMacControlFrames == nil {
		return 0
	}
	return *t.InMacControlFrames
}

// GetInMacPauseFrames retrieves the value of the leaf InMacPauseFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InMacPauseFrames is set, it can safely use t.GetInMacPauseFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InMacPauseFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInMacPauseFrames() uint64 {
	if t == nil || t.InMacPauseFrames == nil {
		return 0
	}
	return *t.InMacPauseFrames
}

// GetInOversizeFrames retrieves the value of the leaf InOversizeFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOversizeFrames is set, it can safely use t.GetInOversizeFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOversizeFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInOversizeFrames() uint64 {
	if t == nil || t.InOversizeFrames == nil {
		return 0
	}
	return *t.InOversizeFrames
}

// GetInUndersizeFrames retrieves the value of the leaf InUndersizeFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUndersizeFrames is set, it can safely use t.GetInUndersizeFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUndersizeFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetInUndersizeFrames() uint64 {
	if t == nil || t.InUndersizeFrames == nil {
		return 0
	}
	return *t.InUndersizeFrames
}

// GetOut_8021QFrames retrieves the value of the leaf Out_8021QFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Out_8021QFrames is set, it can safely use t.GetOut_8021QFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Out_8021QFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetOut_8021QFrames() uint64 {
	if t == nil || t.Out_8021QFrames == nil {
		return 0
	}
	return *t.Out_8021QFrames
}

// GetOutMacControlFrames retrieves the value of the leaf OutMacControlFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutMacControlFrames is set, it can safely use t.GetOutMacControlFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutMacControlFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetOutMacControlFrames() uint64 {
	if t == nil || t.OutMacControlFrames == nil {
		return 0
	}
	return *t.OutMacControlFrames
}

// GetOutMacPauseFrames retrieves the value of the leaf OutMacPauseFrames from the Interface_Ethernet_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutMacPauseFrames is set, it can safely use t.GetOutMacPauseFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutMacPauseFrames == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_Counters) GetOutMacPauseFrames() uint64 {
	if t == nil || t.OutMacPauseFrames == nil {
		return 0
	}
	return *t.OutMacPauseFrames
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Ethernet_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Ethernet_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Ethernet_Counters) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Ethernet_SwitchedVlan represents the /openconfig-interfaces/interfaces/interface/ethernet/switched-vlan YANG schema element.
type Interface_Ethernet_SwitchedVlan struct {
	ΛMetadata      []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	AccessVlan     *uint16                                            `path:"state/access-vlan" shadow-path:"config/access-vlan" module:"openconfig-vlan"`
	ΛAccessVlan    []ygot.Annotation                                  `path:"state/@access-vlan" ygotAnnotation:"true"`
	InterfaceMode  E_OpenconfigVlanTypes_VlanModeType                 `path:"state/interface-mode" shadow-path:"config/interface-mode" module:"openconfig-vlan"`
	ΛInterfaceMode []ygot.Annotation                                  `path:"state/@interface-mode" ygotAnnotation:"true"`
	NativeVlan     *uint16                                            `path:"state/native-vlan" shadow-path:"config/native-vlan" module:"openconfig-vlan"`
	ΛNativeVlan    []ygot.Annotation                                  `path:"state/@native-vlan" ygotAnnotation:"true"`
	TrunkVlans     []Interface_Ethernet_SwitchedVlan_TrunkVlans_Union `path:"state/trunk-vlans" shadow-path:"config/trunk-vlans" module:"openconfig-vlan"`
	ΛTrunkVlans    []ygot.Annotation                                  `path:"state/@trunk-vlans" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Ethernet_SwitchedVlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Ethernet_SwitchedVlan) IsYANGGoStruct() {}

// GetAccessVlan retrieves the value of the leaf AccessVlan from the Interface_Ethernet_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AccessVlan is set, it can safely use t.GetAccessVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AccessVlan == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_SwitchedVlan) GetAccessVlan() uint16 {
	if t == nil || t.AccessVlan == nil {
		return 0
	}
	return *t.AccessVlan
}

// GetInterfaceMode retrieves the value of the leaf InterfaceMode from the Interface_Ethernet_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceMode is set, it can safely use t.GetInterfaceMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceMode == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_SwitchedVlan) GetInterfaceMode() E_OpenconfigVlanTypes_VlanModeType {
	if t == nil || t.InterfaceMode == 0 {
		return 0
	}
	return t.InterfaceMode
}

// GetNativeVlan retrieves the value of the leaf NativeVlan from the Interface_Ethernet_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NativeVlan is set, it can safely use t.GetNativeVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NativeVlan == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_SwitchedVlan) GetNativeVlan() uint16 {
	if t == nil || t.NativeVlan == nil {
		return 0
	}
	return *t.NativeVlan
}

// GetTrunkVlans retrieves the value of the leaf TrunkVlans from the Interface_Ethernet_SwitchedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrunkVlans is set, it can safely use t.GetTrunkVlans()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrunkVlans == nil'
// before retrieving the leaf's value.
func (t *Interface_Ethernet_SwitchedVlan) GetTrunkVlans() []Interface_Ethernet_SwitchedVlan_TrunkVlans_Union {
	if t == nil || t.TrunkVlans == nil {
		return nil
	}
	return t.TrunkVlans
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Ethernet_SwitchedVlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Ethernet_SwitchedVlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Ethernet_SwitchedVlan) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Ethernet_SwitchedVlan_TrunkVlans_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-interfaces/interfaces/interface/ethernet/switched-vlan/state/trunk-vlans within the YANG schema.
// Union type can be one of [UnionString, UnionUint16].
type Interface_Ethernet_SwitchedVlan_TrunkVlans_Union interface {
	// Union type can be one of [UnionString, UnionUint16]
	Documentation_for_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union()
}

// Documentation_for_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union ensures that UnionString
// implements the Interface_Ethernet_SwitchedVlan_TrunkVlans_Union interface.
func (UnionString) Documentation_for_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union() {}

// Documentation_for_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union ensures that UnionUint16
// implements the Interface_Ethernet_SwitchedVlan_TrunkVlans_Union interface.
func (UnionUint16) Documentation_for_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union() {}

// To_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Interface_Ethernet_SwitchedVlan_TrunkVlans_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Interface_Ethernet_SwitchedVlan) To_Interface_Ethernet_SwitchedVlan_TrunkVlans_Union(i interface{}) (Interface_Ethernet_SwitchedVlan_TrunkVlans_Union, error) {
	if v, ok := i.(Interface_Ethernet_SwitchedVlan_TrunkVlans_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Interface_Ethernet_SwitchedVlan_TrunkVlans_Union, unknown union type, got: %T, want any of [string, uint16]", i, i)
}

// Interface_HoldTime represents the /openconfig-interfaces/interfaces/interface/hold-time YANG schema element.
type Interface_HoldTime struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Down      *uint32           `path:"state/down" shadow-path:"config/down" module:"openconfig-interfaces"`
	ΛDown     []ygot.Annotation `path:"state/@down" ygotAnnotation:"true"`
	Up        *uint32           `path:"state/up" shadow-path:"config/up" module:"openconfig-interfaces"`
	ΛUp       []ygot.Annotation `path:"state/@up" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_HoldTime implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_HoldTime) IsYANGGoStruct() {}

// GetDown retrieves the value of the leaf Down from the Interface_HoldTime
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Down is set, it can safely use t.GetDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Down == nil'
// before retrieving the leaf's value.
func (t *Interface_HoldTime) GetDown() uint32 {
	if t == nil || t.Down == nil {
		return 0
	}
	return *t.Down
}

// GetUp retrieves the value of the leaf Up from the Interface_HoldTime
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Up is set, it can safely use t.GetUp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Up == nil'
// before retrieving the leaf's value.
func (t *Interface_HoldTime) GetUp() uint32 {
	if t == nil || t.Up == nil {
		return 0
	}
	return *t.Up
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_HoldTime) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_HoldTime"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_HoldTime) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_RoutedVlan represents the /openconfig-interfaces/interfaces/interface/routed-vlan YANG schema element.
type Interface_RoutedVlan struct {
	ΛMetadata []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Ipv4      *Interface_RoutedVlan_Ipv4      `path:"ipv4" module:"openconfig-if-ip"`
	ΛIpv4     []ygot.Annotation               `path:"@ipv4" ygotAnnotation:"true"`
	Ipv6      *Interface_RoutedVlan_Ipv6      `path:"ipv6" module:"openconfig-if-ip"`
	ΛIpv6     []ygot.Annotation               `path:"@ipv6" ygotAnnotation:"true"`
	Vlan      Interface_RoutedVlan_Vlan_Union `path:"state/vlan" shadow-path:"config/vlan" module:"openconfig-vlan"`
	ΛVlan     []ygot.Annotation               `path:"state/@vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan) IsYANGGoStruct() {}

// GetOrCreateIpv4 retrieves the value of the Ipv4 field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan) GetOrCreateIpv4() *Interface_RoutedVlan_Ipv4 {
	if t.Ipv4 != nil {
		return t.Ipv4
	}
	t.Ipv4 = &Interface_RoutedVlan_Ipv4{}
	return t.Ipv4
}

// GetOrCreateIpv6 retrieves the value of the Ipv6 field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan) GetOrCreateIpv6() *Interface_RoutedVlan_Ipv6 {
	if t.Ipv6 != nil {
		return t.Ipv6
	}
	t.Ipv6 = &Interface_RoutedVlan_Ipv6{}
	return t.Ipv6
}

// GetIpv4 returns the value of the Ipv4 struct pointer
// from Interface_RoutedVlan. If the receiver or the field Ipv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan) GetIpv4() *Interface_RoutedVlan_Ipv4 {
	if t != nil && t.Ipv4 != nil {
		return t.Ipv4
	}
	return nil
}

// GetIpv6 returns the value of the Ipv6 struct pointer
// from Interface_RoutedVlan. If the receiver or the field Ipv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan) GetIpv6() *Interface_RoutedVlan_Ipv6 {
	if t != nil && t.Ipv6 != nil {
		return t.Ipv6
	}
	return nil
}

// GetVlan retrieves the value of the leaf Vlan from the Interface_RoutedVlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Vlan is set, it can safely use t.GetVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Vlan == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan) GetVlan() Interface_RoutedVlan_Vlan_Union {
	if t == nil || t.Vlan == nil {
		return nil
	}
	return t.Vlan
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_RoutedVlan_Vlan_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-interfaces/interfaces/interface/routed-vlan/state/vlan within the YANG schema.
// Union type can be one of [UnionString, UnionUint16].
type Interface_RoutedVlan_Vlan_Union interface {
	// Union type can be one of [UnionString, UnionUint16]
	Documentation_for_Interface_RoutedVlan_Vlan_Union()
}

// Documentation_for_Interface_RoutedVlan_Vlan_Union ensures that UnionString
// implements the Interface_RoutedVlan_Vlan_Union interface.
func (UnionString) Documentation_for_Interface_RoutedVlan_Vlan_Union() {}

// Documentation_for_Interface_RoutedVlan_Vlan_Union ensures that UnionUint16
// implements the Interface_RoutedVlan_Vlan_Union interface.
func (UnionUint16) Documentation_for_Interface_RoutedVlan_Vlan_Union() {}

// To_Interface_RoutedVlan_Vlan_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Interface_RoutedVlan_Vlan_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Interface_RoutedVlan) To_Interface_RoutedVlan_Vlan_Union(i interface{}) (Interface_RoutedVlan_Vlan_Union, error) {
	if v, ok := i.(Interface_RoutedVlan_Vlan_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Interface_RoutedVlan_Vlan_Union, unknown union type, got: %T, want any of [string, uint16]", i, i)
}

// Interface_RoutedVlan_Ipv4 represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4 YANG schema element.
type Interface_RoutedVlan_Ipv4 struct {
	ΛMetadata   []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	Address     map[string]*Interface_RoutedVlan_Ipv4_Address  `path:"addresses/address" module:"openconfig-if-ip"`
	ΛAddress    []ygot.Annotation                              `path:"addresses/@address" ygotAnnotation:"true"`
	Counters    *Interface_RoutedVlan_Ipv4_Counters            `path:"state/counters" module:"openconfig-if-ip"`
	ΛCounters   []ygot.Annotation                              `path:"state/@counters" ygotAnnotation:"true"`
	DhcpClient  *bool                                          `path:"state/dhcp-client" shadow-path:"config/dhcp-client" module:"openconfig-if-ip"`
	ΛDhcpClient []ygot.Annotation                              `path:"state/@dhcp-client" ygotAnnotation:"true"`
	Enabled     *bool                                          `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled    []ygot.Annotation                              `path:"state/@enabled" ygotAnnotation:"true"`
	Mtu         *uint16                                        `path:"state/mtu" shadow-path:"config/mtu" module:"openconfig-if-ip"`
	ΛMtu        []ygot.Annotation                              `path:"state/@mtu" ygotAnnotation:"true"`
	Neighbor    map[string]*Interface_RoutedVlan_Ipv4_Neighbor `path:"neighbors/neighbor" module:"openconfig-if-ip"`
	ΛNeighbor   []ygot.Annotation                              `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	ProxyArp    *Interface_RoutedVlan_Ipv4_ProxyArp            `path:"proxy-arp" module:"openconfig-if-ip"`
	ΛProxyArp   []ygot.Annotation                              `path:"@proxy-arp" ygotAnnotation:"true"`
	Unnumbered  *Interface_RoutedVlan_Ipv4_Unnumbered          `path:"unnumbered" module:"openconfig-if-ip"`
	ΛUnnumbered []ygot.Annotation                              `path:"@unnumbered" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4) IsYANGGoStruct() {}

// NewAddress creates a new entry in the Address list of the
// Interface_RoutedVlan_Ipv4 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_RoutedVlan_Ipv4) NewAddress(Ip string) (*Interface_RoutedVlan_Ipv4_Address, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_RoutedVlan_Ipv4_Address)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Address[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Address", key)
	}

	t.Address[key] = &Interface_RoutedVlan_Ipv4_Address{
		Ip: &Ip,
	}

	return t.Address[key], nil
}

// RenameAddress renames an entry in the list Address within
// the Interface_RoutedVlan_Ipv4 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_RoutedVlan_Ipv4) RenameAddress(oldK, newK string) error {
	if _, ok := t.Address[newK]; ok {
		return fmt.Errorf("key %v already exists in Address", newK)
	}

	e, ok := t.Address[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Address", oldK)
	}
	e.Ip = &newK

	t.Address[newK] = e
	delete(t.Address, oldK)
	return nil
}

// GetOrCreateAddress retrieves the value with the specified keys from
// the receiver Interface_RoutedVlan_Ipv4. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_RoutedVlan_Ipv4) GetOrCreateAddress(Ip string) *Interface_RoutedVlan_Ipv4_Address {

	key := Ip

	if v, ok := t.Address[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAddress(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAddress got unexpected error: %v", err))
	}
	return v
}

// GetAddress retrieves the value with the specified key from
// the Address map field of Interface_RoutedVlan_Ipv4. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_RoutedVlan_Ipv4) GetAddress(Ip string) *Interface_RoutedVlan_Ipv4_Address {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Address[key]; ok {
		return lm
	}
	return nil
}

// AppendAddress appends the supplied Interface_RoutedVlan_Ipv4_Address struct to the
// list Address of Interface_RoutedVlan_Ipv4. If the key value(s) specified in
// the supplied Interface_RoutedVlan_Ipv4_Address already exist in the list, an error is
// returned.
func (t *Interface_RoutedVlan_Ipv4) AppendAddress(v *Interface_RoutedVlan_Ipv4_Address) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_RoutedVlan_Ipv4_Address)
	}

	if _, ok := t.Address[key]; ok {
		return fmt.Errorf("duplicate key for list Address %v", key)
	}

	t.Address[key] = v
	return nil
}

// NewNeighbor creates a new entry in the Neighbor list of the
// Interface_RoutedVlan_Ipv4 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_RoutedVlan_Ipv4) NewNeighbor(Ip string) (*Interface_RoutedVlan_Ipv4_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_RoutedVlan_Ipv4_Neighbor)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Interface_RoutedVlan_Ipv4_Neighbor{
		Ip: &Ip,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Interface_RoutedVlan_Ipv4 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_RoutedVlan_Ipv4) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Ip = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Interface_RoutedVlan_Ipv4. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_RoutedVlan_Ipv4) GetOrCreateNeighbor(Ip string) *Interface_RoutedVlan_Ipv4_Neighbor {

	key := Ip

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Interface_RoutedVlan_Ipv4. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_RoutedVlan_Ipv4) GetNeighbor(Ip string) *Interface_RoutedVlan_Ipv4_Neighbor {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Interface_RoutedVlan_Ipv4_Neighbor struct to the
// list Neighbor of Interface_RoutedVlan_Ipv4. If the key value(s) specified in
// the supplied Interface_RoutedVlan_Ipv4_Neighbor already exist in the list, an error is
// returned.
func (t *Interface_RoutedVlan_Ipv4) AppendNeighbor(v *Interface_RoutedVlan_Ipv4_Neighbor) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_RoutedVlan_Ipv4_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv4) GetOrCreateCounters() *Interface_RoutedVlan_Ipv4_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_RoutedVlan_Ipv4_Counters{}
	return t.Counters
}

// GetOrCreateProxyArp retrieves the value of the ProxyArp field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv4) GetOrCreateProxyArp() *Interface_RoutedVlan_Ipv4_ProxyArp {
	if t.ProxyArp != nil {
		return t.ProxyArp
	}
	t.ProxyArp = &Interface_RoutedVlan_Ipv4_ProxyArp{}
	return t.ProxyArp
}

// GetOrCreateUnnumbered retrieves the value of the Unnumbered field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv4) GetOrCreateUnnumbered() *Interface_RoutedVlan_Ipv4_Unnumbered {
	if t.Unnumbered != nil {
		return t.Unnumbered
	}
	t.Unnumbered = &Interface_RoutedVlan_Ipv4_Unnumbered{}
	return t.Unnumbered
}

// GetCounters returns the value of the Counters struct pointer
// from Interface_RoutedVlan_Ipv4. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv4) GetCounters() *Interface_RoutedVlan_Ipv4_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetProxyArp returns the value of the ProxyArp struct pointer
// from Interface_RoutedVlan_Ipv4. If the receiver or the field ProxyArp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv4) GetProxyArp() *Interface_RoutedVlan_Ipv4_ProxyArp {
	if t != nil && t.ProxyArp != nil {
		return t.ProxyArp
	}
	return nil
}

// GetUnnumbered returns the value of the Unnumbered struct pointer
// from Interface_RoutedVlan_Ipv4. If the receiver or the field Unnumbered is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv4) GetUnnumbered() *Interface_RoutedVlan_Ipv4_Unnumbered {
	if t != nil && t.Unnumbered != nil {
		return t.Unnumbered
	}
	return nil
}

// GetDhcpClient retrieves the value of the leaf DhcpClient from the Interface_RoutedVlan_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpClient is set, it can safely use t.GetDhcpClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpClient == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4) GetDhcpClient() bool {
	if t == nil || t.DhcpClient == nil {
		return false
	}
	return *t.DhcpClient
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_RoutedVlan_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetMtu retrieves the value of the leaf Mtu from the Interface_RoutedVlan_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mtu is set, it can safely use t.GetMtu()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mtu == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4) GetMtu() uint16 {
	if t == nil || t.Mtu == nil {
		return 0
	}
	return *t.Mtu
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_RoutedVlan_Ipv4_Address represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/addresses/address YANG schema element.
type Interface_RoutedVlan_Ipv4_Address struct {
	ΛMetadata     []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	Ip            *string                                                `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp           []ygot.Annotation                                      `path:"state/@ip|@ip" ygotAnnotation:"true"`
	Origin        E_OpenconfigIfIp_IpAddressOrigin                       `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin       []ygot.Annotation                                      `path:"state/@origin" ygotAnnotation:"true"`
	PrefixLength  *uint8                                                 `path:"state/prefix-length" shadow-path:"config/prefix-length" module:"openconfig-if-ip"`
	ΛPrefixLength []ygot.Annotation                                      `path:"state/@prefix-length" ygotAnnotation:"true"`
	VrrpGroup     map[uint8]*Interface_RoutedVlan_Ipv4_Address_VrrpGroup `path:"vrrp/vrrp-group" module:"openconfig-if-ip"`
	ΛVrrpGroup    []ygot.Annotation                                      `path:"vrrp/@vrrp-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Address implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Address) IsYANGGoStruct() {}

// NewVrrpGroup creates a new entry in the VrrpGroup list of the
// Interface_RoutedVlan_Ipv4_Address struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_RoutedVlan_Ipv4_Address) NewVrrpGroup(VirtualRouterId uint8) (*Interface_RoutedVlan_Ipv4_Address_VrrpGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_RoutedVlan_Ipv4_Address_VrrpGroup)
	}

	key := VirtualRouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.VrrpGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list VrrpGroup", key)
	}

	t.VrrpGroup[key] = &Interface_RoutedVlan_Ipv4_Address_VrrpGroup{
		VirtualRouterId: &VirtualRouterId,
	}

	return t.VrrpGroup[key], nil
}

// RenameVrrpGroup renames an entry in the list VrrpGroup within
// the Interface_RoutedVlan_Ipv4_Address struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_RoutedVlan_Ipv4_Address) RenameVrrpGroup(oldK, newK uint8) error {
	if _, ok := t.VrrpGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in VrrpGroup", newK)
	}

	e, ok := t.VrrpGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in VrrpGroup", oldK)
	}
	e.VirtualRouterId = &newK

	t.VrrpGroup[newK] = e
	delete(t.VrrpGroup, oldK)
	return nil
}

// GetOrCreateVrrpGroup retrieves the value with the specified keys from
// the receiver Interface_RoutedVlan_Ipv4_Address. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_RoutedVlan_Ipv4_Address) GetOrCreateVrrpGroup(VirtualRouterId uint8) *Interface_RoutedVlan_Ipv4_Address_VrrpGroup {

	key := VirtualRouterId

	if v, ok := t.VrrpGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVrrpGroup(VirtualRouterId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVrrpGroup got unexpected error: %v", err))
	}
	return v
}

// GetVrrpGroup retrieves the value with the specified key from
// the VrrpGroup map field of Interface_RoutedVlan_Ipv4_Address. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_RoutedVlan_Ipv4_Address) GetVrrpGroup(VirtualRouterId uint8) *Interface_RoutedVlan_Ipv4_Address_VrrpGroup {

	if t == nil {
		return nil
	}

	key := VirtualRouterId

	if lm, ok := t.VrrpGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendVrrpGroup appends the supplied Interface_RoutedVlan_Ipv4_Address_VrrpGroup struct to the
// list VrrpGroup of Interface_RoutedVlan_Ipv4_Address. If the key value(s) specified in
// the supplied Interface_RoutedVlan_Ipv4_Address_VrrpGroup already exist in the list, an error is
// returned.
func (t *Interface_RoutedVlan_Ipv4_Address) AppendVrrpGroup(v *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) error {
	if v.VirtualRouterId == nil {
		return fmt.Errorf("invalid nil key received for VirtualRouterId")
	}

	key := *v.VirtualRouterId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_RoutedVlan_Ipv4_Address_VrrpGroup)
	}

	if _, ok := t.VrrpGroup[key]; ok {
		return fmt.Errorf("duplicate key for list VrrpGroup %v", key)
	}

	t.VrrpGroup[key] = v
	return nil
}

// GetIp retrieves the value of the leaf Ip from the Interface_RoutedVlan_Ipv4_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_RoutedVlan_Ipv4_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address) GetOrigin() E_OpenconfigIfIp_IpAddressOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// GetPrefixLength retrieves the value of the leaf PrefixLength from the Interface_RoutedVlan_Ipv4_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixLength is set, it can safely use t.GetPrefixLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixLength == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address) GetPrefixLength() uint8 {
	if t == nil || t.PrefixLength == nil {
		return 0
	}
	return *t.PrefixLength
}

// ΛListKeyMap returns the keys of the Interface_RoutedVlan_Ipv4_Address struct, which is a YANG list entry.
func (t *Interface_RoutedVlan_Ipv4_Address) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Address) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Address"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Address) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_Address_VrrpGroup represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/addresses/address/vrrp/vrrp-group YANG schema element.
type Interface_RoutedVlan_Ipv4_Address_VrrpGroup struct {
	ΛMetadata              []ygot.Annotation                                              `path:"@" ygotAnnotation:"true"`
	AcceptMode             *bool                                                          `path:"state/accept-mode" shadow-path:"config/accept-mode" module:"openconfig-if-ip"`
	ΛAcceptMode            []ygot.Annotation                                              `path:"state/@accept-mode" ygotAnnotation:"true"`
	AdvertisementInterval  *uint16                                                        `path:"state/advertisement-interval" shadow-path:"config/advertisement-interval" module:"openconfig-if-ip"`
	ΛAdvertisementInterval []ygot.Annotation                                              `path:"state/@advertisement-interval" ygotAnnotation:"true"`
	CurrentPriority        *uint8                                                         `path:"state/current-priority" module:"openconfig-if-ip"`
	ΛCurrentPriority       []ygot.Annotation                                              `path:"state/@current-priority" ygotAnnotation:"true"`
	InterfaceTracking      *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking `path:"interface-tracking" module:"openconfig-if-ip"`
	ΛInterfaceTracking     []ygot.Annotation                                              `path:"@interface-tracking" ygotAnnotation:"true"`
	Preempt                *bool                                                          `path:"state/preempt" shadow-path:"config/preempt" module:"openconfig-if-ip"`
	ΛPreempt               []ygot.Annotation                                              `path:"state/@preempt" ygotAnnotation:"true"`
	PreemptDelay           *uint16                                                        `path:"state/preempt-delay" shadow-path:"config/preempt-delay" module:"openconfig-if-ip"`
	ΛPreemptDelay          []ygot.Annotation                                              `path:"state/@preempt-delay" ygotAnnotation:"true"`
	Priority               *uint8                                                         `path:"state/priority" shadow-path:"config/priority" module:"openconfig-if-ip"`
	ΛPriority              []ygot.Annotation                                              `path:"state/@priority" ygotAnnotation:"true"`
	VirtualAddress         []string                                                       `path:"state/virtual-address" shadow-path:"config/virtual-address" module:"openconfig-if-ip"`
	ΛVirtualAddress        []ygot.Annotation                                              `path:"state/@virtual-address" ygotAnnotation:"true"`
	VirtualRouterId        *uint8                                                         `path:"state/virtual-router-id|virtual-router-id" shadow-path:"config/virtual-router-id" module:"openconfig-if-ip"`
	ΛVirtualRouterId       []ygot.Annotation                                              `path:"state/@virtual-router-id|@virtual-router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Address_VrrpGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Address_VrrpGroup) IsYANGGoStruct() {}

// GetOrCreateInterfaceTracking retrieves the value of the InterfaceTracking field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetOrCreateInterfaceTracking() *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking {
	if t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	t.InterfaceTracking = &Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking{}
	return t.InterfaceTracking
}

// GetInterfaceTracking returns the value of the InterfaceTracking struct pointer
// from Interface_RoutedVlan_Ipv4_Address_VrrpGroup. If the receiver or the field InterfaceTracking is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetInterfaceTracking() *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking {
	if t != nil && t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	return nil
}

// GetAcceptMode retrieves the value of the leaf AcceptMode from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AcceptMode is set, it can safely use t.GetAcceptMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AcceptMode == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetAcceptMode() bool {
	if t == nil || t.AcceptMode == nil {
		return false
	}
	return *t.AcceptMode
}

// GetAdvertisementInterval retrieves the value of the leaf AdvertisementInterval from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertisementInterval is set, it can safely use t.GetAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetAdvertisementInterval() uint16 {
	if t == nil || t.AdvertisementInterval == nil {
		return 100
	}
	return *t.AdvertisementInterval
}

// GetCurrentPriority retrieves the value of the leaf CurrentPriority from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CurrentPriority is set, it can safely use t.GetCurrentPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CurrentPriority == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetCurrentPriority() uint8 {
	if t == nil || t.CurrentPriority == nil {
		return 0
	}
	return *t.CurrentPriority
}

// GetPreempt retrieves the value of the leaf Preempt from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preempt is set, it can safely use t.GetPreempt()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preempt == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetPreempt() bool {
	if t == nil || t.Preempt == nil {
		return true
	}
	return *t.Preempt
}

// GetPreemptDelay retrieves the value of the leaf PreemptDelay from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreemptDelay is set, it can safely use t.GetPreemptDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreemptDelay == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetPreemptDelay() uint16 {
	if t == nil || t.PreemptDelay == nil {
		return 0
	}
	return *t.PreemptDelay
}

// GetPriority retrieves the value of the leaf Priority from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 100
	}
	return *t.Priority
}

// GetVirtualAddress retrieves the value of the leaf VirtualAddress from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualAddress is set, it can safely use t.GetVirtualAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetVirtualAddress() []string {
	if t == nil || t.VirtualAddress == nil {
		return nil
	}
	return t.VirtualAddress
}

// GetVirtualRouterId retrieves the value of the leaf VirtualRouterId from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualRouterId is set, it can safely use t.GetVirtualRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualRouterId == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) GetVirtualRouterId() uint8 {
	if t == nil || t.VirtualRouterId == nil {
		return 0
	}
	return *t.VirtualRouterId
}

// ΛListKeyMap returns the keys of the Interface_RoutedVlan_Ipv4_Address_VrrpGroup struct, which is a YANG list entry.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VirtualRouterId == nil {
		return nil, fmt.Errorf("nil value for key VirtualRouterId")
	}

	return map[string]interface{}{
		"virtual-router-id": *t.VirtualRouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Address_VrrpGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/addresses/address/vrrp/vrrp-group/interface-tracking YANG schema element.
type Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PriorityDecrement  *uint8            `path:"state/priority-decrement" shadow-path:"config/priority-decrement" module:"openconfig-if-ip"`
	ΛPriorityDecrement []ygot.Annotation `path:"state/@priority-decrement" ygotAnnotation:"true"`
	TrackInterface     []string          `path:"state/track-interface" shadow-path:"config/track-interface" module:"openconfig-if-ip"`
	ΛTrackInterface    []ygot.Annotation `path:"state/@track-interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking) IsYANGGoStruct() {}

// GetPriorityDecrement retrieves the value of the leaf PriorityDecrement from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PriorityDecrement is set, it can safely use t.GetPriorityDecrement()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PriorityDecrement == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking) GetPriorityDecrement() uint8 {
	if t == nil || t.PriorityDecrement == nil {
		return 0
	}
	return *t.PriorityDecrement
}

// GetTrackInterface retrieves the value of the leaf TrackInterface from the Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrackInterface is set, it can safely use t.GetTrackInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrackInterface == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking) GetTrackInterface() []string {
	if t == nil || t.TrackInterface == nil {
		return nil
	}
	return t.TrackInterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Address_VrrpGroup_InterfaceTracking) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_Counters represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/state/counters YANG schema element.
type Interface_RoutedVlan_Ipv4_Counters struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InDiscardedPkts     *uint64           `path:"in-discarded-pkts" module:"openconfig-if-ip"`
	ΛInDiscardedPkts    []ygot.Annotation `path:"@in-discarded-pkts" ygotAnnotation:"true"`
	InErrorPkts         *uint64           `path:"in-error-pkts" module:"openconfig-if-ip"`
	ΛInErrorPkts        []ygot.Annotation `path:"@in-error-pkts" ygotAnnotation:"true"`
	InForwardedOctets   *uint64           `path:"in-forwarded-octets" module:"openconfig-if-ip"`
	ΛInForwardedOctets  []ygot.Annotation `path:"@in-forwarded-octets" ygotAnnotation:"true"`
	InForwardedPkts     *uint64           `path:"in-forwarded-pkts" module:"openconfig-if-ip"`
	ΛInForwardedPkts    []ygot.Annotation `path:"@in-forwarded-pkts" ygotAnnotation:"true"`
	InOctets            *uint64           `path:"in-octets" module:"openconfig-if-ip"`
	ΛInOctets           []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts              *uint64           `path:"in-pkts" module:"openconfig-if-ip"`
	ΛInPkts             []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	OutDiscardedPkts    *uint64           `path:"out-discarded-pkts" module:"openconfig-if-ip"`
	ΛOutDiscardedPkts   []ygot.Annotation `path:"@out-discarded-pkts" ygotAnnotation:"true"`
	OutErrorPkts        *uint64           `path:"out-error-pkts" module:"openconfig-if-ip"`
	ΛOutErrorPkts       []ygot.Annotation `path:"@out-error-pkts" ygotAnnotation:"true"`
	OutForwardedOctets  *uint64           `path:"out-forwarded-octets" module:"openconfig-if-ip"`
	ΛOutForwardedOctets []ygot.Annotation `path:"@out-forwarded-octets" ygotAnnotation:"true"`
	OutForwardedPkts    *uint64           `path:"out-forwarded-pkts" module:"openconfig-if-ip"`
	ΛOutForwardedPkts   []ygot.Annotation `path:"@out-forwarded-pkts" ygotAnnotation:"true"`
	OutOctets           *uint64           `path:"out-octets" module:"openconfig-if-ip"`
	ΛOutOctets          []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts             *uint64           `path:"out-pkts" module:"openconfig-if-ip"`
	ΛOutPkts            []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Counters) IsYANGGoStruct() {}

// GetInDiscardedPkts retrieves the value of the leaf InDiscardedPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InDiscardedPkts is set, it can safely use t.GetInDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetInDiscardedPkts() uint64 {
	if t == nil || t.InDiscardedPkts == nil {
		return 0
	}
	return *t.InDiscardedPkts
}

// GetInErrorPkts retrieves the value of the leaf InErrorPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InErrorPkts is set, it can safely use t.GetInErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetInErrorPkts() uint64 {
	if t == nil || t.InErrorPkts == nil {
		return 0
	}
	return *t.InErrorPkts
}

// GetInForwardedOctets retrieves the value of the leaf InForwardedOctets from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedOctets is set, it can safely use t.GetInForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetInForwardedOctets() uint64 {
	if t == nil || t.InForwardedOctets == nil {
		return 0
	}
	return *t.InForwardedOctets
}

// GetInForwardedPkts retrieves the value of the leaf InForwardedPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedPkts is set, it can safely use t.GetInForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetInForwardedPkts() uint64 {
	if t == nil || t.InForwardedPkts == nil {
		return 0
	}
	return *t.InForwardedPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetOutDiscardedPkts retrieves the value of the leaf OutDiscardedPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutDiscardedPkts is set, it can safely use t.GetOutDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetOutDiscardedPkts() uint64 {
	if t == nil || t.OutDiscardedPkts == nil {
		return 0
	}
	return *t.OutDiscardedPkts
}

// GetOutErrorPkts retrieves the value of the leaf OutErrorPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutErrorPkts is set, it can safely use t.GetOutErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetOutErrorPkts() uint64 {
	if t == nil || t.OutErrorPkts == nil {
		return 0
	}
	return *t.OutErrorPkts
}

// GetOutForwardedOctets retrieves the value of the leaf OutForwardedOctets from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedOctets is set, it can safely use t.GetOutForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetOutForwardedOctets() uint64 {
	if t == nil || t.OutForwardedOctets == nil {
		return 0
	}
	return *t.OutForwardedOctets
}

// GetOutForwardedPkts retrieves the value of the leaf OutForwardedPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedPkts is set, it can safely use t.GetOutForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetOutForwardedPkts() uint64 {
	if t == nil || t.OutForwardedPkts == nil {
		return 0
	}
	return *t.OutForwardedPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the Interface_RoutedVlan_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_Neighbor represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/neighbors/neighbor YANG schema element.
type Interface_RoutedVlan_Ipv4_Neighbor struct {
	ΛMetadata         []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Ip                *string                         `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp               []ygot.Annotation               `path:"state/@ip|@ip" ygotAnnotation:"true"`
	LinkLayerAddress  *string                         `path:"state/link-layer-address" shadow-path:"config/link-layer-address" module:"openconfig-if-ip"`
	ΛLinkLayerAddress []ygot.Annotation               `path:"state/@link-layer-address" ygotAnnotation:"true"`
	Origin            E_OpenconfigIfIp_NeighborOrigin `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin           []ygot.Annotation               `path:"state/@origin" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Neighbor) IsYANGGoStruct() {}

// GetIp retrieves the value of the leaf Ip from the Interface_RoutedVlan_Ipv4_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Neighbor) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetLinkLayerAddress retrieves the value of the leaf LinkLayerAddress from the Interface_RoutedVlan_Ipv4_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLayerAddress is set, it can safely use t.GetLinkLayerAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLayerAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Neighbor) GetLinkLayerAddress() string {
	if t == nil || t.LinkLayerAddress == nil {
		return ""
	}
	return *t.LinkLayerAddress
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_RoutedVlan_Ipv4_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Neighbor) GetOrigin() E_OpenconfigIfIp_NeighborOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// ΛListKeyMap returns the keys of the Interface_RoutedVlan_Ipv4_Neighbor struct, which is a YANG list entry.
func (t *Interface_RoutedVlan_Ipv4_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_ProxyArp represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/proxy-arp YANG schema element.
type Interface_RoutedVlan_Ipv4_ProxyArp struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Mode      E_ProxyArp_Mode   `path:"state/mode" shadow-path:"config/mode" module:"openconfig-if-ip"`
	ΛMode     []ygot.Annotation `path:"state/@mode" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_ProxyArp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_ProxyArp) IsYANGGoStruct() {}

// GetMode retrieves the value of the leaf Mode from the Interface_RoutedVlan_Ipv4_ProxyArp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_ProxyArp) GetMode() E_ProxyArp_Mode {
	if t == nil || t.Mode == 0 {
		return ProxyArp_Mode_DISABLE
	}
	return t.Mode
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_ProxyArp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_ProxyArp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_ProxyArp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_Unnumbered represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/unnumbered YANG schema element.
type Interface_RoutedVlan_Ipv4_Unnumbered struct {
	ΛMetadata     []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	Enabled       *bool                                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled      []ygot.Annotation                                  `path:"state/@enabled" ygotAnnotation:"true"`
	InterfaceRef  *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef `path:"interface-ref" module:"openconfig-if-ip"`
	ΛInterfaceRef []ygot.Annotation                                  `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Unnumbered implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Unnumbered) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered) GetOrCreateInterfaceRef() *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from Interface_RoutedVlan_Ipv4_Unnumbered. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered) GetInterfaceRef() *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_RoutedVlan_Ipv4_Unnumbered
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Unnumbered"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv4/unnumbered/interface-ref YANG schema element.
type Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-if-ip"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-if-ip"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv4_Unnumbered_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6 represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6 YANG schema element.
type Interface_RoutedVlan_Ipv6 struct {
	ΛMetadata               []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	Address                 map[string]*Interface_RoutedVlan_Ipv6_Address  `path:"addresses/address" module:"openconfig-if-ip"`
	ΛAddress                []ygot.Annotation                              `path:"addresses/@address" ygotAnnotation:"true"`
	Counters                *Interface_RoutedVlan_Ipv6_Counters            `path:"state/counters" module:"openconfig-if-ip"`
	ΛCounters               []ygot.Annotation                              `path:"state/@counters" ygotAnnotation:"true"`
	DhcpClient              *bool                                          `path:"state/dhcp-client" shadow-path:"config/dhcp-client" module:"openconfig-if-ip"`
	ΛDhcpClient             []ygot.Annotation                              `path:"state/@dhcp-client" ygotAnnotation:"true"`
	DupAddrDetectTransmits  *uint32                                        `path:"state/dup-addr-detect-transmits" shadow-path:"config/dup-addr-detect-transmits" module:"openconfig-if-ip"`
	ΛDupAddrDetectTransmits []ygot.Annotation                              `path:"state/@dup-addr-detect-transmits" ygotAnnotation:"true"`
	Enabled                 *bool                                          `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled                []ygot.Annotation                              `path:"state/@enabled" ygotAnnotation:"true"`
	Mtu                     *uint32                                        `path:"state/mtu" shadow-path:"config/mtu" module:"openconfig-if-ip"`
	ΛMtu                    []ygot.Annotation                              `path:"state/@mtu" ygotAnnotation:"true"`
	Neighbor                map[string]*Interface_RoutedVlan_Ipv6_Neighbor `path:"neighbors/neighbor" module:"openconfig-if-ip"`
	ΛNeighbor               []ygot.Annotation                              `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	RouterAdvertisement     *Interface_RoutedVlan_Ipv6_RouterAdvertisement `path:"router-advertisement" module:"openconfig-if-ip"`
	ΛRouterAdvertisement    []ygot.Annotation                              `path:"@router-advertisement" ygotAnnotation:"true"`
	Unnumbered              *Interface_RoutedVlan_Ipv6_Unnumbered          `path:"unnumbered" module:"openconfig-if-ip"`
	ΛUnnumbered             []ygot.Annotation                              `path:"@unnumbered" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6) IsYANGGoStruct() {}

// NewAddress creates a new entry in the Address list of the
// Interface_RoutedVlan_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_RoutedVlan_Ipv6) NewAddress(Ip string) (*Interface_RoutedVlan_Ipv6_Address, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_RoutedVlan_Ipv6_Address)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Address[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Address", key)
	}

	t.Address[key] = &Interface_RoutedVlan_Ipv6_Address{
		Ip: &Ip,
	}

	return t.Address[key], nil
}

// RenameAddress renames an entry in the list Address within
// the Interface_RoutedVlan_Ipv6 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_RoutedVlan_Ipv6) RenameAddress(oldK, newK string) error {
	if _, ok := t.Address[newK]; ok {
		return fmt.Errorf("key %v already exists in Address", newK)
	}

	e, ok := t.Address[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Address", oldK)
	}
	e.Ip = &newK

	t.Address[newK] = e
	delete(t.Address, oldK)
	return nil
}

// GetOrCreateAddress retrieves the value with the specified keys from
// the receiver Interface_RoutedVlan_Ipv6. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_RoutedVlan_Ipv6) GetOrCreateAddress(Ip string) *Interface_RoutedVlan_Ipv6_Address {

	key := Ip

	if v, ok := t.Address[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAddress(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAddress got unexpected error: %v", err))
	}
	return v
}

// GetAddress retrieves the value with the specified key from
// the Address map field of Interface_RoutedVlan_Ipv6. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_RoutedVlan_Ipv6) GetAddress(Ip string) *Interface_RoutedVlan_Ipv6_Address {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Address[key]; ok {
		return lm
	}
	return nil
}

// AppendAddress appends the supplied Interface_RoutedVlan_Ipv6_Address struct to the
// list Address of Interface_RoutedVlan_Ipv6. If the key value(s) specified in
// the supplied Interface_RoutedVlan_Ipv6_Address already exist in the list, an error is
// returned.
func (t *Interface_RoutedVlan_Ipv6) AppendAddress(v *Interface_RoutedVlan_Ipv6_Address) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_RoutedVlan_Ipv6_Address)
	}

	if _, ok := t.Address[key]; ok {
		return fmt.Errorf("duplicate key for list Address %v", key)
	}

	t.Address[key] = v
	return nil
}

// NewNeighbor creates a new entry in the Neighbor list of the
// Interface_RoutedVlan_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_RoutedVlan_Ipv6) NewNeighbor(Ip string) (*Interface_RoutedVlan_Ipv6_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_RoutedVlan_Ipv6_Neighbor)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Interface_RoutedVlan_Ipv6_Neighbor{
		Ip: &Ip,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Interface_RoutedVlan_Ipv6 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_RoutedVlan_Ipv6) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Ip = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Interface_RoutedVlan_Ipv6. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_RoutedVlan_Ipv6) GetOrCreateNeighbor(Ip string) *Interface_RoutedVlan_Ipv6_Neighbor {

	key := Ip

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Interface_RoutedVlan_Ipv6. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_RoutedVlan_Ipv6) GetNeighbor(Ip string) *Interface_RoutedVlan_Ipv6_Neighbor {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Interface_RoutedVlan_Ipv6_Neighbor struct to the
// list Neighbor of Interface_RoutedVlan_Ipv6. If the key value(s) specified in
// the supplied Interface_RoutedVlan_Ipv6_Neighbor already exist in the list, an error is
// returned.
func (t *Interface_RoutedVlan_Ipv6) AppendNeighbor(v *Interface_RoutedVlan_Ipv6_Neighbor) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_RoutedVlan_Ipv6_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv6) GetOrCreateCounters() *Interface_RoutedVlan_Ipv6_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_RoutedVlan_Ipv6_Counters{}
	return t.Counters
}

// GetOrCreateRouterAdvertisement retrieves the value of the RouterAdvertisement field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv6) GetOrCreateRouterAdvertisement() *Interface_RoutedVlan_Ipv6_RouterAdvertisement {
	if t.RouterAdvertisement != nil {
		return t.RouterAdvertisement
	}
	t.RouterAdvertisement = &Interface_RoutedVlan_Ipv6_RouterAdvertisement{}
	return t.RouterAdvertisement
}

// GetOrCreateUnnumbered retrieves the value of the Unnumbered field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv6) GetOrCreateUnnumbered() *Interface_RoutedVlan_Ipv6_Unnumbered {
	if t.Unnumbered != nil {
		return t.Unnumbered
	}
	t.Unnumbered = &Interface_RoutedVlan_Ipv6_Unnumbered{}
	return t.Unnumbered
}

// GetCounters returns the value of the Counters struct pointer
// from Interface_RoutedVlan_Ipv6. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv6) GetCounters() *Interface_RoutedVlan_Ipv6_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetRouterAdvertisement returns the value of the RouterAdvertisement struct pointer
// from Interface_RoutedVlan_Ipv6. If the receiver or the field RouterAdvertisement is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv6) GetRouterAdvertisement() *Interface_RoutedVlan_Ipv6_RouterAdvertisement {
	if t != nil && t.RouterAdvertisement != nil {
		return t.RouterAdvertisement
	}
	return nil
}

// GetUnnumbered returns the value of the Unnumbered struct pointer
// from Interface_RoutedVlan_Ipv6. If the receiver or the field Unnumbered is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv6) GetUnnumbered() *Interface_RoutedVlan_Ipv6_Unnumbered {
	if t != nil && t.Unnumbered != nil {
		return t.Unnumbered
	}
	return nil
}

// GetDhcpClient retrieves the value of the leaf DhcpClient from the Interface_RoutedVlan_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpClient is set, it can safely use t.GetDhcpClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpClient == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6) GetDhcpClient() bool {
	if t == nil || t.DhcpClient == nil {
		return false
	}
	return *t.DhcpClient
}

// GetDupAddrDetectTransmits retrieves the value of the leaf DupAddrDetectTransmits from the Interface_RoutedVlan_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DupAddrDetectTransmits is set, it can safely use t.GetDupAddrDetectTransmits()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DupAddrDetectTransmits == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6) GetDupAddrDetectTransmits() uint32 {
	if t == nil || t.DupAddrDetectTransmits == nil {
		return 1
	}
	return *t.DupAddrDetectTransmits
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_RoutedVlan_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetMtu retrieves the value of the leaf Mtu from the Interface_RoutedVlan_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mtu is set, it can safely use t.GetMtu()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mtu == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6) GetMtu() uint32 {
	if t == nil || t.Mtu == nil {
		return 0
	}
	return *t.Mtu
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_RoutedVlan_Ipv6_Address represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/addresses/address YANG schema element.
type Interface_RoutedVlan_Ipv6_Address struct {
	ΛMetadata     []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	Ip            *string                                                `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp           []ygot.Annotation                                      `path:"state/@ip|@ip" ygotAnnotation:"true"`
	Origin        E_OpenconfigIfIp_IpAddressOrigin                       `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin       []ygot.Annotation                                      `path:"state/@origin" ygotAnnotation:"true"`
	PrefixLength  *uint8                                                 `path:"state/prefix-length" shadow-path:"config/prefix-length" module:"openconfig-if-ip"`
	ΛPrefixLength []ygot.Annotation                                      `path:"state/@prefix-length" ygotAnnotation:"true"`
	Status        E_Address_Status                                       `path:"state/status" module:"openconfig-if-ip"`
	ΛStatus       []ygot.Annotation                                      `path:"state/@status" ygotAnnotation:"true"`
	VrrpGroup     map[uint8]*Interface_RoutedVlan_Ipv6_Address_VrrpGroup `path:"vrrp/vrrp-group" module:"openconfig-if-ip"`
	ΛVrrpGroup    []ygot.Annotation                                      `path:"vrrp/@vrrp-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Address implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Address) IsYANGGoStruct() {}

// NewVrrpGroup creates a new entry in the VrrpGroup list of the
// Interface_RoutedVlan_Ipv6_Address struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_RoutedVlan_Ipv6_Address) NewVrrpGroup(VirtualRouterId uint8) (*Interface_RoutedVlan_Ipv6_Address_VrrpGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_RoutedVlan_Ipv6_Address_VrrpGroup)
	}

	key := VirtualRouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.VrrpGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list VrrpGroup", key)
	}

	t.VrrpGroup[key] = &Interface_RoutedVlan_Ipv6_Address_VrrpGroup{
		VirtualRouterId: &VirtualRouterId,
	}

	return t.VrrpGroup[key], nil
}

// RenameVrrpGroup renames an entry in the list VrrpGroup within
// the Interface_RoutedVlan_Ipv6_Address struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_RoutedVlan_Ipv6_Address) RenameVrrpGroup(oldK, newK uint8) error {
	if _, ok := t.VrrpGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in VrrpGroup", newK)
	}

	e, ok := t.VrrpGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in VrrpGroup", oldK)
	}
	e.VirtualRouterId = &newK

	t.VrrpGroup[newK] = e
	delete(t.VrrpGroup, oldK)
	return nil
}

// GetOrCreateVrrpGroup retrieves the value with the specified keys from
// the receiver Interface_RoutedVlan_Ipv6_Address. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_RoutedVlan_Ipv6_Address) GetOrCreateVrrpGroup(VirtualRouterId uint8) *Interface_RoutedVlan_Ipv6_Address_VrrpGroup {

	key := VirtualRouterId

	if v, ok := t.VrrpGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVrrpGroup(VirtualRouterId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVrrpGroup got unexpected error: %v", err))
	}
	return v
}

// GetVrrpGroup retrieves the value with the specified key from
// the VrrpGroup map field of Interface_RoutedVlan_Ipv6_Address. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_RoutedVlan_Ipv6_Address) GetVrrpGroup(VirtualRouterId uint8) *Interface_RoutedVlan_Ipv6_Address_VrrpGroup {

	if t == nil {
		return nil
	}

	key := VirtualRouterId

	if lm, ok := t.VrrpGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendVrrpGroup appends the supplied Interface_RoutedVlan_Ipv6_Address_VrrpGroup struct to the
// list VrrpGroup of Interface_RoutedVlan_Ipv6_Address. If the key value(s) specified in
// the supplied Interface_RoutedVlan_Ipv6_Address_VrrpGroup already exist in the list, an error is
// returned.
func (t *Interface_RoutedVlan_Ipv6_Address) AppendVrrpGroup(v *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) error {
	if v.VirtualRouterId == nil {
		return fmt.Errorf("invalid nil key received for VirtualRouterId")
	}

	key := *v.VirtualRouterId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_RoutedVlan_Ipv6_Address_VrrpGroup)
	}

	if _, ok := t.VrrpGroup[key]; ok {
		return fmt.Errorf("duplicate key for list VrrpGroup %v", key)
	}

	t.VrrpGroup[key] = v
	return nil
}

// GetIp retrieves the value of the leaf Ip from the Interface_RoutedVlan_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_RoutedVlan_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address) GetOrigin() E_OpenconfigIfIp_IpAddressOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// GetPrefixLength retrieves the value of the leaf PrefixLength from the Interface_RoutedVlan_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixLength is set, it can safely use t.GetPrefixLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixLength == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address) GetPrefixLength() uint8 {
	if t == nil || t.PrefixLength == nil {
		return 0
	}
	return *t.PrefixLength
}

// GetStatus retrieves the value of the leaf Status from the Interface_RoutedVlan_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Status is set, it can safely use t.GetStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Status == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address) GetStatus() E_Address_Status {
	if t == nil || t.Status == 0 {
		return 0
	}
	return t.Status
}

// ΛListKeyMap returns the keys of the Interface_RoutedVlan_Ipv6_Address struct, which is a YANG list entry.
func (t *Interface_RoutedVlan_Ipv6_Address) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Address) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Address"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Address) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_Address_VrrpGroup represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/addresses/address/vrrp/vrrp-group YANG schema element.
type Interface_RoutedVlan_Ipv6_Address_VrrpGroup struct {
	ΛMetadata              []ygot.Annotation                                              `path:"@" ygotAnnotation:"true"`
	AcceptMode             *bool                                                          `path:"state/accept-mode" shadow-path:"config/accept-mode" module:"openconfig-if-ip"`
	ΛAcceptMode            []ygot.Annotation                                              `path:"state/@accept-mode" ygotAnnotation:"true"`
	AdvertisementInterval  *uint16                                                        `path:"state/advertisement-interval" shadow-path:"config/advertisement-interval" module:"openconfig-if-ip"`
	ΛAdvertisementInterval []ygot.Annotation                                              `path:"state/@advertisement-interval" ygotAnnotation:"true"`
	CurrentPriority        *uint8                                                         `path:"state/current-priority" module:"openconfig-if-ip"`
	ΛCurrentPriority       []ygot.Annotation                                              `path:"state/@current-priority" ygotAnnotation:"true"`
	InterfaceTracking      *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking `path:"interface-tracking" module:"openconfig-if-ip"`
	ΛInterfaceTracking     []ygot.Annotation                                              `path:"@interface-tracking" ygotAnnotation:"true"`
	Preempt                *bool                                                          `path:"state/preempt" shadow-path:"config/preempt" module:"openconfig-if-ip"`
	ΛPreempt               []ygot.Annotation                                              `path:"state/@preempt" ygotAnnotation:"true"`
	PreemptDelay           *uint16                                                        `path:"state/preempt-delay" shadow-path:"config/preempt-delay" module:"openconfig-if-ip"`
	ΛPreemptDelay          []ygot.Annotation                                              `path:"state/@preempt-delay" ygotAnnotation:"true"`
	Priority               *uint8                                                         `path:"state/priority" shadow-path:"config/priority" module:"openconfig-if-ip"`
	ΛPriority              []ygot.Annotation                                              `path:"state/@priority" ygotAnnotation:"true"`
	VirtualAddress         []string                                                       `path:"state/virtual-address" shadow-path:"config/virtual-address" module:"openconfig-if-ip"`
	ΛVirtualAddress        []ygot.Annotation                                              `path:"state/@virtual-address" ygotAnnotation:"true"`
	VirtualLinkLocal       *string                                                        `path:"state/virtual-link-local" shadow-path:"config/virtual-link-local" module:"openconfig-if-ip"`
	ΛVirtualLinkLocal      []ygot.Annotation                                              `path:"state/@virtual-link-local" ygotAnnotation:"true"`
	VirtualRouterId        *uint8                                                         `path:"state/virtual-router-id|virtual-router-id" shadow-path:"config/virtual-router-id" module:"openconfig-if-ip"`
	ΛVirtualRouterId       []ygot.Annotation                                              `path:"state/@virtual-router-id|@virtual-router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Address_VrrpGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Address_VrrpGroup) IsYANGGoStruct() {}

// GetOrCreateInterfaceTracking retrieves the value of the InterfaceTracking field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetOrCreateInterfaceTracking() *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking {
	if t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	t.InterfaceTracking = &Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking{}
	return t.InterfaceTracking
}

// GetInterfaceTracking returns the value of the InterfaceTracking struct pointer
// from Interface_RoutedVlan_Ipv6_Address_VrrpGroup. If the receiver or the field InterfaceTracking is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetInterfaceTracking() *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking {
	if t != nil && t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	return nil
}

// GetAcceptMode retrieves the value of the leaf AcceptMode from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AcceptMode is set, it can safely use t.GetAcceptMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AcceptMode == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetAcceptMode() bool {
	if t == nil || t.AcceptMode == nil {
		return false
	}
	return *t.AcceptMode
}

// GetAdvertisementInterval retrieves the value of the leaf AdvertisementInterval from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertisementInterval is set, it can safely use t.GetAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetAdvertisementInterval() uint16 {
	if t == nil || t.AdvertisementInterval == nil {
		return 100
	}
	return *t.AdvertisementInterval
}

// GetCurrentPriority retrieves the value of the leaf CurrentPriority from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CurrentPriority is set, it can safely use t.GetCurrentPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CurrentPriority == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetCurrentPriority() uint8 {
	if t == nil || t.CurrentPriority == nil {
		return 0
	}
	return *t.CurrentPriority
}

// GetPreempt retrieves the value of the leaf Preempt from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preempt is set, it can safely use t.GetPreempt()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preempt == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetPreempt() bool {
	if t == nil || t.Preempt == nil {
		return true
	}
	return *t.Preempt
}

// GetPreemptDelay retrieves the value of the leaf PreemptDelay from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreemptDelay is set, it can safely use t.GetPreemptDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreemptDelay == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetPreemptDelay() uint16 {
	if t == nil || t.PreemptDelay == nil {
		return 0
	}
	return *t.PreemptDelay
}

// GetPriority retrieves the value of the leaf Priority from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 100
	}
	return *t.Priority
}

// GetVirtualAddress retrieves the value of the leaf VirtualAddress from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualAddress is set, it can safely use t.GetVirtualAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetVirtualAddress() []string {
	if t == nil || t.VirtualAddress == nil {
		return nil
	}
	return t.VirtualAddress
}

// GetVirtualLinkLocal retrieves the value of the leaf VirtualLinkLocal from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualLinkLocal is set, it can safely use t.GetVirtualLinkLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualLinkLocal == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetVirtualLinkLocal() string {
	if t == nil || t.VirtualLinkLocal == nil {
		return ""
	}
	return *t.VirtualLinkLocal
}

// GetVirtualRouterId retrieves the value of the leaf VirtualRouterId from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualRouterId is set, it can safely use t.GetVirtualRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualRouterId == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) GetVirtualRouterId() uint8 {
	if t == nil || t.VirtualRouterId == nil {
		return 0
	}
	return *t.VirtualRouterId
}

// ΛListKeyMap returns the keys of the Interface_RoutedVlan_Ipv6_Address_VrrpGroup struct, which is a YANG list entry.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VirtualRouterId == nil {
		return nil, fmt.Errorf("nil value for key VirtualRouterId")
	}

	return map[string]interface{}{
		"virtual-router-id": *t.VirtualRouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Address_VrrpGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/addresses/address/vrrp/vrrp-group/interface-tracking YANG schema element.
type Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PriorityDecrement  *uint8            `path:"state/priority-decrement" shadow-path:"config/priority-decrement" module:"openconfig-if-ip"`
	ΛPriorityDecrement []ygot.Annotation `path:"state/@priority-decrement" ygotAnnotation:"true"`
	TrackInterface     []string          `path:"state/track-interface" shadow-path:"config/track-interface" module:"openconfig-if-ip"`
	ΛTrackInterface    []ygot.Annotation `path:"state/@track-interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking) IsYANGGoStruct() {}

// GetPriorityDecrement retrieves the value of the leaf PriorityDecrement from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PriorityDecrement is set, it can safely use t.GetPriorityDecrement()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PriorityDecrement == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking) GetPriorityDecrement() uint8 {
	if t == nil || t.PriorityDecrement == nil {
		return 0
	}
	return *t.PriorityDecrement
}

// GetTrackInterface retrieves the value of the leaf TrackInterface from the Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrackInterface is set, it can safely use t.GetTrackInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrackInterface == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking) GetTrackInterface() []string {
	if t == nil || t.TrackInterface == nil {
		return nil
	}
	return t.TrackInterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Address_VrrpGroup_InterfaceTracking) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_Counters represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/state/counters YANG schema element.
type Interface_RoutedVlan_Ipv6_Counters struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InDiscardedPkts     *uint64           `path:"in-discarded-pkts" module:"openconfig-if-ip"`
	ΛInDiscardedPkts    []ygot.Annotation `path:"@in-discarded-pkts" ygotAnnotation:"true"`
	InErrorPkts         *uint64           `path:"in-error-pkts" module:"openconfig-if-ip"`
	ΛInErrorPkts        []ygot.Annotation `path:"@in-error-pkts" ygotAnnotation:"true"`
	InForwardedOctets   *uint64           `path:"in-forwarded-octets" module:"openconfig-if-ip"`
	ΛInForwardedOctets  []ygot.Annotation `path:"@in-forwarded-octets" ygotAnnotation:"true"`
	InForwardedPkts     *uint64           `path:"in-forwarded-pkts" module:"openconfig-if-ip"`
	ΛInForwardedPkts    []ygot.Annotation `path:"@in-forwarded-pkts" ygotAnnotation:"true"`
	InOctets            *uint64           `path:"in-octets" module:"openconfig-if-ip"`
	ΛInOctets           []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts              *uint64           `path:"in-pkts" module:"openconfig-if-ip"`
	ΛInPkts             []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	OutDiscardedPkts    *uint64           `path:"out-discarded-pkts" module:"openconfig-if-ip"`
	ΛOutDiscardedPkts   []ygot.Annotation `path:"@out-discarded-pkts" ygotAnnotation:"true"`
	OutErrorPkts        *uint64           `path:"out-error-pkts" module:"openconfig-if-ip"`
	ΛOutErrorPkts       []ygot.Annotation `path:"@out-error-pkts" ygotAnnotation:"true"`
	OutForwardedOctets  *uint64           `path:"out-forwarded-octets" module:"openconfig-if-ip"`
	ΛOutForwardedOctets []ygot.Annotation `path:"@out-forwarded-octets" ygotAnnotation:"true"`
	OutForwardedPkts    *uint64           `path:"out-forwarded-pkts" module:"openconfig-if-ip"`
	ΛOutForwardedPkts   []ygot.Annotation `path:"@out-forwarded-pkts" ygotAnnotation:"true"`
	OutOctets           *uint64           `path:"out-octets" module:"openconfig-if-ip"`
	ΛOutOctets          []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts             *uint64           `path:"out-pkts" module:"openconfig-if-ip"`
	ΛOutPkts            []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Counters) IsYANGGoStruct() {}

// GetInDiscardedPkts retrieves the value of the leaf InDiscardedPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InDiscardedPkts is set, it can safely use t.GetInDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetInDiscardedPkts() uint64 {
	if t == nil || t.InDiscardedPkts == nil {
		return 0
	}
	return *t.InDiscardedPkts
}

// GetInErrorPkts retrieves the value of the leaf InErrorPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InErrorPkts is set, it can safely use t.GetInErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetInErrorPkts() uint64 {
	if t == nil || t.InErrorPkts == nil {
		return 0
	}
	return *t.InErrorPkts
}

// GetInForwardedOctets retrieves the value of the leaf InForwardedOctets from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedOctets is set, it can safely use t.GetInForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetInForwardedOctets() uint64 {
	if t == nil || t.InForwardedOctets == nil {
		return 0
	}
	return *t.InForwardedOctets
}

// GetInForwardedPkts retrieves the value of the leaf InForwardedPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedPkts is set, it can safely use t.GetInForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetInForwardedPkts() uint64 {
	if t == nil || t.InForwardedPkts == nil {
		return 0
	}
	return *t.InForwardedPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetOutDiscardedPkts retrieves the value of the leaf OutDiscardedPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutDiscardedPkts is set, it can safely use t.GetOutDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetOutDiscardedPkts() uint64 {
	if t == nil || t.OutDiscardedPkts == nil {
		return 0
	}
	return *t.OutDiscardedPkts
}

// GetOutErrorPkts retrieves the value of the leaf OutErrorPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutErrorPkts is set, it can safely use t.GetOutErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetOutErrorPkts() uint64 {
	if t == nil || t.OutErrorPkts == nil {
		return 0
	}
	return *t.OutErrorPkts
}

// GetOutForwardedOctets retrieves the value of the leaf OutForwardedOctets from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedOctets is set, it can safely use t.GetOutForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetOutForwardedOctets() uint64 {
	if t == nil || t.OutForwardedOctets == nil {
		return 0
	}
	return *t.OutForwardedOctets
}

// GetOutForwardedPkts retrieves the value of the leaf OutForwardedPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedPkts is set, it can safely use t.GetOutForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetOutForwardedPkts() uint64 {
	if t == nil || t.OutForwardedPkts == nil {
		return 0
	}
	return *t.OutForwardedPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the Interface_RoutedVlan_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_Neighbor represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/neighbors/neighbor YANG schema element.
type Interface_RoutedVlan_Ipv6_Neighbor struct {
	ΛMetadata         []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Ip                *string                         `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp               []ygot.Annotation               `path:"state/@ip|@ip" ygotAnnotation:"true"`
	IsRouter          *bool                           `path:"state/is-router" module:"openconfig-if-ip"`
	ΛIsRouter         []ygot.Annotation               `path:"state/@is-router" ygotAnnotation:"true"`
	LinkLayerAddress  *string                         `path:"state/link-layer-address" shadow-path:"config/link-layer-address" module:"openconfig-if-ip"`
	ΛLinkLayerAddress []ygot.Annotation               `path:"state/@link-layer-address" ygotAnnotation:"true"`
	NeighborState     E_Neighbor_NeighborState        `path:"state/neighbor-state" module:"openconfig-if-ip"`
	ΛNeighborState    []ygot.Annotation               `path:"state/@neighbor-state" ygotAnnotation:"true"`
	Origin            E_OpenconfigIfIp_NeighborOrigin `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin           []ygot.Annotation               `path:"state/@origin" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Neighbor) IsYANGGoStruct() {}

// GetIp retrieves the value of the leaf Ip from the Interface_RoutedVlan_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetIsRouter retrieves the value of the leaf IsRouter from the Interface_RoutedVlan_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IsRouter is set, it can safely use t.GetIsRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IsRouter == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) GetIsRouter() bool {
	if t == nil || t.IsRouter == nil {
		return false
	}
	return *t.IsRouter
}

// GetLinkLayerAddress retrieves the value of the leaf LinkLayerAddress from the Interface_RoutedVlan_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLayerAddress is set, it can safely use t.GetLinkLayerAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLayerAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) GetLinkLayerAddress() string {
	if t == nil || t.LinkLayerAddress == nil {
		return ""
	}
	return *t.LinkLayerAddress
}

// GetNeighborState retrieves the value of the leaf NeighborState from the Interface_RoutedVlan_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborState is set, it can safely use t.GetNeighborState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborState == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) GetNeighborState() E_Neighbor_NeighborState {
	if t == nil || t.NeighborState == 0 {
		return 0
	}
	return t.NeighborState
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_RoutedVlan_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) GetOrigin() E_OpenconfigIfIp_NeighborOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// ΛListKeyMap returns the keys of the Interface_RoutedVlan_Ipv6_Neighbor struct, which is a YANG list entry.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_RouterAdvertisement represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/router-advertisement YANG schema element.
type Interface_RoutedVlan_Ipv6_RouterAdvertisement struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interval  *uint32           `path:"state/interval" shadow-path:"config/interval" module:"openconfig-if-ip"`
	ΛInterval []ygot.Annotation `path:"state/@interval" ygotAnnotation:"true"`
	Lifetime  *uint32           `path:"state/lifetime" shadow-path:"config/lifetime" module:"openconfig-if-ip"`
	ΛLifetime []ygot.Annotation `path:"state/@lifetime" ygotAnnotation:"true"`
	Suppress  *bool             `path:"state/suppress" shadow-path:"config/suppress" module:"openconfig-if-ip"`
	ΛSuppress []ygot.Annotation `path:"state/@suppress" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_RouterAdvertisement implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_RouterAdvertisement) IsYANGGoStruct() {}

// GetInterval retrieves the value of the leaf Interval from the Interface_RoutedVlan_Ipv6_RouterAdvertisement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_RouterAdvertisement) GetInterval() uint32 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetLifetime retrieves the value of the leaf Lifetime from the Interface_RoutedVlan_Ipv6_RouterAdvertisement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Lifetime is set, it can safely use t.GetLifetime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Lifetime == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_RouterAdvertisement) GetLifetime() uint32 {
	if t == nil || t.Lifetime == nil {
		return 0
	}
	return *t.Lifetime
}

// GetSuppress retrieves the value of the leaf Suppress from the Interface_RoutedVlan_Ipv6_RouterAdvertisement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Suppress is set, it can safely use t.GetSuppress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Suppress == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_RouterAdvertisement) GetSuppress() bool {
	if t == nil || t.Suppress == nil {
		return false
	}
	return *t.Suppress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_RouterAdvertisement) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_RouterAdvertisement"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_RouterAdvertisement) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_Unnumbered represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/unnumbered YANG schema element.
type Interface_RoutedVlan_Ipv6_Unnumbered struct {
	ΛMetadata     []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	Enabled       *bool                                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled      []ygot.Annotation                                  `path:"state/@enabled" ygotAnnotation:"true"`
	InterfaceRef  *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef `path:"interface-ref" module:"openconfig-if-ip"`
	ΛInterfaceRef []ygot.Annotation                                  `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Unnumbered implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Unnumbered) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered) GetOrCreateInterfaceRef() *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from Interface_RoutedVlan_Ipv6_Unnumbered. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered) GetInterfaceRef() *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_RoutedVlan_Ipv6_Unnumbered
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Unnumbered"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef represents the /openconfig-interfaces/interfaces/interface/routed-vlan/ipv6/unnumbered/interface-ref YANG schema element.
type Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-if-ip"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-if-ip"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_RoutedVlan_Ipv6_Unnumbered_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Sonet represents the /openconfig-interfaces/interfaces/interface/sonet YANG schema element.
type Interface_Sonet struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Sonet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Sonet) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Sonet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Sonet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Sonet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Subinterface represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface YANG schema element.
type Interface_Subinterface struct {
	ΛMetadata    []ygot.Annotation                `path:"@" ygotAnnotation:"true"`
	AdminStatus  E_Interface_AdminStatus          `path:"state/admin-status" module:"openconfig-interfaces"`
	ΛAdminStatus []ygot.Annotation                `path:"state/@admin-status" ygotAnnotation:"true"`
	Counters     *Interface_Subinterface_Counters `path:"state/counters" module:"openconfig-interfaces"`
	ΛCounters    []ygot.Annotation                `path:"state/@counters" ygotAnnotation:"true"`
	Description  *string                          `path:"state/description" shadow-path:"config/description" module:"openconfig-interfaces"`
	ΛDescription []ygot.Annotation                `path:"state/@description" ygotAnnotation:"true"`
	Enabled      *bool                            `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-interfaces"`
	ΛEnabled     []ygot.Annotation                `path:"state/@enabled" ygotAnnotation:"true"`
	Ifindex      *uint32                          `path:"state/ifindex" module:"openconfig-interfaces"`
	ΛIfindex     []ygot.Annotation                `path:"state/@ifindex" ygotAnnotation:"true"`
	Index        *uint32                          `path:"state/index|index" shadow-path:"config/index" module:"openconfig-interfaces"`
	ΛIndex       []ygot.Annotation                `path:"state/@index|@index" ygotAnnotation:"true"`
	Ipv4         *Interface_Subinterface_Ipv4     `path:"ipv4" module:"openconfig-if-ip"`
	ΛIpv4        []ygot.Annotation                `path:"@ipv4" ygotAnnotation:"true"`
	Ipv6         *Interface_Subinterface_Ipv6     `path:"ipv6" module:"openconfig-if-ip"`
	ΛIpv6        []ygot.Annotation                `path:"@ipv6" ygotAnnotation:"true"`
	LastChange   *uint64                          `path:"state/last-change" module:"openconfig-interfaces"`
	ΛLastChange  []ygot.Annotation                `path:"state/@last-change" ygotAnnotation:"true"`
	Logical      *bool                            `path:"state/logical" module:"openconfig-interfaces"`
	ΛLogical     []ygot.Annotation                `path:"state/@logical" ygotAnnotation:"true"`
	Name         *string                          `path:"state/name" module:"openconfig-interfaces"`
	ΛName        []ygot.Annotation                `path:"state/@name" ygotAnnotation:"true"`
	OperStatus   E_Interface_OperStatus           `path:"state/oper-status" module:"openconfig-interfaces"`
	ΛOperStatus  []ygot.Annotation                `path:"state/@oper-status" ygotAnnotation:"true"`
	Vlan         *Interface_Subinterface_Vlan     `path:"vlan" module:"openconfig-vlan"`
	ΛVlan        []ygot.Annotation                `path:"@vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface) GetOrCreateCounters() *Interface_Subinterface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_Subinterface_Counters{}
	return t.Counters
}

// GetOrCreateIpv4 retrieves the value of the Ipv4 field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface) GetOrCreateIpv4() *Interface_Subinterface_Ipv4 {
	if t.Ipv4 != nil {
		return t.Ipv4
	}
	t.Ipv4 = &Interface_Subinterface_Ipv4{}
	return t.Ipv4
}

// GetOrCreateIpv6 retrieves the value of the Ipv6 field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface) GetOrCreateIpv6() *Interface_Subinterface_Ipv6 {
	if t.Ipv6 != nil {
		return t.Ipv6
	}
	t.Ipv6 = &Interface_Subinterface_Ipv6{}
	return t.Ipv6
}

// GetOrCreateVlan retrieves the value of the Vlan field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface) GetOrCreateVlan() *Interface_Subinterface_Vlan {
	if t.Vlan != nil {
		return t.Vlan
	}
	t.Vlan = &Interface_Subinterface_Vlan{}
	return t.Vlan
}

// GetCounters returns the value of the Counters struct pointer
// from Interface_Subinterface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface) GetCounters() *Interface_Subinterface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetIpv4 returns the value of the Ipv4 struct pointer
// from Interface_Subinterface. If the receiver or the field Ipv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface) GetIpv4() *Interface_Subinterface_Ipv4 {
	if t != nil && t.Ipv4 != nil {
		return t.Ipv4
	}
	return nil
}

// GetIpv6 returns the value of the Ipv6 struct pointer
// from Interface_Subinterface. If the receiver or the field Ipv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface) GetIpv6() *Interface_Subinterface_Ipv6 {
	if t != nil && t.Ipv6 != nil {
		return t.Ipv6
	}
	return nil
}

// GetVlan returns the value of the Vlan struct pointer
// from Interface_Subinterface. If the receiver or the field Vlan is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface) GetVlan() *Interface_Subinterface_Vlan {
	if t != nil && t.Vlan != nil {
		return t.Vlan
	}
	return nil
}

// GetAdminStatus retrieves the value of the leaf AdminStatus from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminStatus is set, it can safely use t.GetAdminStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminStatus == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetAdminStatus() E_Interface_AdminStatus {
	if t == nil || t.AdminStatus == 0 {
		return 0
	}
	return t.AdminStatus
}

// GetDescription retrieves the value of the leaf Description from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetIfindex retrieves the value of the leaf Ifindex from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ifindex is set, it can safely use t.GetIfindex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ifindex == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetIfindex() uint32 {
	if t == nil || t.Ifindex == nil {
		return 0
	}
	return *t.Ifindex
}

// GetIndex retrieves the value of the leaf Index from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetIndex() uint32 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLastChange retrieves the value of the leaf LastChange from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastChange is set, it can safely use t.GetLastChange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastChange == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetLastChange() uint64 {
	if t == nil || t.LastChange == nil {
		return 0
	}
	return *t.LastChange
}

// GetLogical retrieves the value of the leaf Logical from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Logical is set, it can safely use t.GetLogical()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Logical == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetLogical() bool {
	if t == nil || t.Logical == nil {
		return false
	}
	return *t.Logical
}

// GetName retrieves the value of the leaf Name from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetOperStatus retrieves the value of the leaf OperStatus from the Interface_Subinterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OperStatus is set, it can safely use t.GetOperStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OperStatus == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface) GetOperStatus() E_Interface_OperStatus {
	if t == nil || t.OperStatus == 0 {
		return 0
	}
	return t.OperStatus
}

// ΛListKeyMap returns the keys of the Interface_Subinterface struct, which is a YANG list entry.
func (t *Interface_Subinterface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Subinterface_Counters represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/state/counters YANG schema element.
type Interface_Subinterface_Counters struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CarrierTransitions  *uint64           `path:"carrier-transitions" module:"openconfig-interfaces"`
	ΛCarrierTransitions []ygot.Annotation `path:"@carrier-transitions" ygotAnnotation:"true"`
	InBroadcastPkts     *uint64           `path:"in-broadcast-pkts" module:"openconfig-interfaces"`
	ΛInBroadcastPkts    []ygot.Annotation `path:"@in-broadcast-pkts" ygotAnnotation:"true"`
	InDiscards          *uint64           `path:"in-discards" module:"openconfig-interfaces"`
	ΛInDiscards         []ygot.Annotation `path:"@in-discards" ygotAnnotation:"true"`
	InErrors            *uint64           `path:"in-errors" module:"openconfig-interfaces"`
	ΛInErrors           []ygot.Annotation `path:"@in-errors" ygotAnnotation:"true"`
	InFcsErrors         *uint64           `path:"in-fcs-errors" module:"openconfig-interfaces"`
	ΛInFcsErrors        []ygot.Annotation `path:"@in-fcs-errors" ygotAnnotation:"true"`
	InMulticastPkts     *uint64           `path:"in-multicast-pkts" module:"openconfig-interfaces"`
	ΛInMulticastPkts    []ygot.Annotation `path:"@in-multicast-pkts" ygotAnnotation:"true"`
	InOctets            *uint64           `path:"in-octets" module:"openconfig-interfaces"`
	ΛInOctets           []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts              *uint64           `path:"in-pkts" module:"openconfig-interfaces"`
	ΛInPkts             []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	InUnicastPkts       *uint64           `path:"in-unicast-pkts" module:"openconfig-interfaces"`
	ΛInUnicastPkts      []ygot.Annotation `path:"@in-unicast-pkts" ygotAnnotation:"true"`
	InUnknownProtos     *uint64           `path:"in-unknown-protos" module:"openconfig-interfaces"`
	ΛInUnknownProtos    []ygot.Annotation `path:"@in-unknown-protos" ygotAnnotation:"true"`
	LastClear           *uint64           `path:"last-clear" module:"openconfig-interfaces"`
	ΛLastClear          []ygot.Annotation `path:"@last-clear" ygotAnnotation:"true"`
	OutBroadcastPkts    *uint64           `path:"out-broadcast-pkts" module:"openconfig-interfaces"`
	ΛOutBroadcastPkts   []ygot.Annotation `path:"@out-broadcast-pkts" ygotAnnotation:"true"`
	OutDiscards         *uint64           `path:"out-discards" module:"openconfig-interfaces"`
	ΛOutDiscards        []ygot.Annotation `path:"@out-discards" ygotAnnotation:"true"`
	OutErrors           *uint64           `path:"out-errors" module:"openconfig-interfaces"`
	ΛOutErrors          []ygot.Annotation `path:"@out-errors" ygotAnnotation:"true"`
	OutMulticastPkts    *uint64           `path:"out-multicast-pkts" module:"openconfig-interfaces"`
	ΛOutMulticastPkts   []ygot.Annotation `path:"@out-multicast-pkts" ygotAnnotation:"true"`
	OutOctets           *uint64           `path:"out-octets" module:"openconfig-interfaces"`
	ΛOutOctets          []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts             *uint64           `path:"out-pkts" module:"openconfig-interfaces"`
	ΛOutPkts            []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
	OutUnicastPkts      *uint64           `path:"out-unicast-pkts" module:"openconfig-interfaces"`
	ΛOutUnicastPkts     []ygot.Annotation `path:"@out-unicast-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Counters) IsYANGGoStruct() {}

// GetCarrierTransitions retrieves the value of the leaf CarrierTransitions from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CarrierTransitions is set, it can safely use t.GetCarrierTransitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CarrierTransitions == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetCarrierTransitions() uint64 {
	if t == nil || t.CarrierTransitions == nil {
		return 0
	}
	return *t.CarrierTransitions
}

// GetInBroadcastPkts retrieves the value of the leaf InBroadcastPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InBroadcastPkts is set, it can safely use t.GetInBroadcastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InBroadcastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInBroadcastPkts() uint64 {
	if t == nil || t.InBroadcastPkts == nil {
		return 0
	}
	return *t.InBroadcastPkts
}

// GetInDiscards retrieves the value of the leaf InDiscards from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InDiscards is set, it can safely use t.GetInDiscards()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InDiscards == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInDiscards() uint64 {
	if t == nil || t.InDiscards == nil {
		return 0
	}
	return *t.InDiscards
}

// GetInErrors retrieves the value of the leaf InErrors from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InErrors is set, it can safely use t.GetInErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInErrors() uint64 {
	if t == nil || t.InErrors == nil {
		return 0
	}
	return *t.InErrors
}

// GetInFcsErrors retrieves the value of the leaf InFcsErrors from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InFcsErrors is set, it can safely use t.GetInFcsErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InFcsErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInFcsErrors() uint64 {
	if t == nil || t.InFcsErrors == nil {
		return 0
	}
	return *t.InFcsErrors
}

// GetInMulticastPkts retrieves the value of the leaf InMulticastPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InMulticastPkts is set, it can safely use t.GetInMulticastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InMulticastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInMulticastPkts() uint64 {
	if t == nil || t.InMulticastPkts == nil {
		return 0
	}
	return *t.InMulticastPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetInUnicastPkts retrieves the value of the leaf InUnicastPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUnicastPkts is set, it can safely use t.GetInUnicastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUnicastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInUnicastPkts() uint64 {
	if t == nil || t.InUnicastPkts == nil {
		return 0
	}
	return *t.InUnicastPkts
}

// GetInUnknownProtos retrieves the value of the leaf InUnknownProtos from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUnknownProtos is set, it can safely use t.GetInUnknownProtos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUnknownProtos == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetInUnknownProtos() uint64 {
	if t == nil || t.InUnknownProtos == nil {
		return 0
	}
	return *t.InUnknownProtos
}

// GetLastClear retrieves the value of the leaf LastClear from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastClear is set, it can safely use t.GetLastClear()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastClear == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetLastClear() uint64 {
	if t == nil || t.LastClear == nil {
		return 0
	}
	return *t.LastClear
}

// GetOutBroadcastPkts retrieves the value of the leaf OutBroadcastPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutBroadcastPkts is set, it can safely use t.GetOutBroadcastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutBroadcastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutBroadcastPkts() uint64 {
	if t == nil || t.OutBroadcastPkts == nil {
		return 0
	}
	return *t.OutBroadcastPkts
}

// GetOutDiscards retrieves the value of the leaf OutDiscards from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutDiscards is set, it can safely use t.GetOutDiscards()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutDiscards == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutDiscards() uint64 {
	if t == nil || t.OutDiscards == nil {
		return 0
	}
	return *t.OutDiscards
}

// GetOutErrors retrieves the value of the leaf OutErrors from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutErrors is set, it can safely use t.GetOutErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutErrors == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutErrors() uint64 {
	if t == nil || t.OutErrors == nil {
		return 0
	}
	return *t.OutErrors
}

// GetOutMulticastPkts retrieves the value of the leaf OutMulticastPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutMulticastPkts is set, it can safely use t.GetOutMulticastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutMulticastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutMulticastPkts() uint64 {
	if t == nil || t.OutMulticastPkts == nil {
		return 0
	}
	return *t.OutMulticastPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// GetOutUnicastPkts retrieves the value of the leaf OutUnicastPkts from the Interface_Subinterface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutUnicastPkts is set, it can safely use t.GetOutUnicastPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutUnicastPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Counters) GetOutUnicastPkts() uint64 {
	if t == nil || t.OutUnicastPkts == nil {
		return 0
	}
	return *t.OutUnicastPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4 represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4 YANG schema element.
type Interface_Subinterface_Ipv4 struct {
	ΛMetadata   []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	Address     map[string]*Interface_Subinterface_Ipv4_Address  `path:"addresses/address" module:"openconfig-if-ip"`
	ΛAddress    []ygot.Annotation                                `path:"addresses/@address" ygotAnnotation:"true"`
	Counters    *Interface_Subinterface_Ipv4_Counters            `path:"state/counters" module:"openconfig-if-ip"`
	ΛCounters   []ygot.Annotation                                `path:"state/@counters" ygotAnnotation:"true"`
	DhcpClient  *bool                                            `path:"state/dhcp-client" shadow-path:"config/dhcp-client" module:"openconfig-if-ip"`
	ΛDhcpClient []ygot.Annotation                                `path:"state/@dhcp-client" ygotAnnotation:"true"`
	Enabled     *bool                                            `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled    []ygot.Annotation                                `path:"state/@enabled" ygotAnnotation:"true"`
	Mtu         *uint16                                          `path:"state/mtu" shadow-path:"config/mtu" module:"openconfig-if-ip"`
	ΛMtu        []ygot.Annotation                                `path:"state/@mtu" ygotAnnotation:"true"`
	Neighbor    map[string]*Interface_Subinterface_Ipv4_Neighbor `path:"neighbors/neighbor" module:"openconfig-if-ip"`
	ΛNeighbor   []ygot.Annotation                                `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	ProxyArp    *Interface_Subinterface_Ipv4_ProxyArp            `path:"proxy-arp" module:"openconfig-if-ip"`
	ΛProxyArp   []ygot.Annotation                                `path:"@proxy-arp" ygotAnnotation:"true"`
	Unnumbered  *Interface_Subinterface_Ipv4_Unnumbered          `path:"unnumbered" module:"openconfig-if-ip"`
	ΛUnnumbered []ygot.Annotation                                `path:"@unnumbered" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4) IsYANGGoStruct() {}

// NewAddress creates a new entry in the Address list of the
// Interface_Subinterface_Ipv4 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_Subinterface_Ipv4) NewAddress(Ip string) (*Interface_Subinterface_Ipv4_Address, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_Subinterface_Ipv4_Address)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Address[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Address", key)
	}

	t.Address[key] = &Interface_Subinterface_Ipv4_Address{
		Ip: &Ip,
	}

	return t.Address[key], nil
}

// RenameAddress renames an entry in the list Address within
// the Interface_Subinterface_Ipv4 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_Subinterface_Ipv4) RenameAddress(oldK, newK string) error {
	if _, ok := t.Address[newK]; ok {
		return fmt.Errorf("key %v already exists in Address", newK)
	}

	e, ok := t.Address[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Address", oldK)
	}
	e.Ip = &newK

	t.Address[newK] = e
	delete(t.Address, oldK)
	return nil
}

// GetOrCreateAddress retrieves the value with the specified keys from
// the receiver Interface_Subinterface_Ipv4. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_Subinterface_Ipv4) GetOrCreateAddress(Ip string) *Interface_Subinterface_Ipv4_Address {

	key := Ip

	if v, ok := t.Address[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAddress(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAddress got unexpected error: %v", err))
	}
	return v
}

// GetAddress retrieves the value with the specified key from
// the Address map field of Interface_Subinterface_Ipv4. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_Subinterface_Ipv4) GetAddress(Ip string) *Interface_Subinterface_Ipv4_Address {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Address[key]; ok {
		return lm
	}
	return nil
}

// AppendAddress appends the supplied Interface_Subinterface_Ipv4_Address struct to the
// list Address of Interface_Subinterface_Ipv4. If the key value(s) specified in
// the supplied Interface_Subinterface_Ipv4_Address already exist in the list, an error is
// returned.
func (t *Interface_Subinterface_Ipv4) AppendAddress(v *Interface_Subinterface_Ipv4_Address) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_Subinterface_Ipv4_Address)
	}

	if _, ok := t.Address[key]; ok {
		return fmt.Errorf("duplicate key for list Address %v", key)
	}

	t.Address[key] = v
	return nil
}

// NewNeighbor creates a new entry in the Neighbor list of the
// Interface_Subinterface_Ipv4 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_Subinterface_Ipv4) NewNeighbor(Ip string) (*Interface_Subinterface_Ipv4_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_Subinterface_Ipv4_Neighbor)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Interface_Subinterface_Ipv4_Neighbor{
		Ip: &Ip,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Interface_Subinterface_Ipv4 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_Subinterface_Ipv4) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Ip = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Interface_Subinterface_Ipv4. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_Subinterface_Ipv4) GetOrCreateNeighbor(Ip string) *Interface_Subinterface_Ipv4_Neighbor {

	key := Ip

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Interface_Subinterface_Ipv4. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_Subinterface_Ipv4) GetNeighbor(Ip string) *Interface_Subinterface_Ipv4_Neighbor {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Interface_Subinterface_Ipv4_Neighbor struct to the
// list Neighbor of Interface_Subinterface_Ipv4. If the key value(s) specified in
// the supplied Interface_Subinterface_Ipv4_Neighbor already exist in the list, an error is
// returned.
func (t *Interface_Subinterface_Ipv4) AppendNeighbor(v *Interface_Subinterface_Ipv4_Neighbor) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_Subinterface_Ipv4_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv4) GetOrCreateCounters() *Interface_Subinterface_Ipv4_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_Subinterface_Ipv4_Counters{}
	return t.Counters
}

// GetOrCreateProxyArp retrieves the value of the ProxyArp field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv4) GetOrCreateProxyArp() *Interface_Subinterface_Ipv4_ProxyArp {
	if t.ProxyArp != nil {
		return t.ProxyArp
	}
	t.ProxyArp = &Interface_Subinterface_Ipv4_ProxyArp{}
	return t.ProxyArp
}

// GetOrCreateUnnumbered retrieves the value of the Unnumbered field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv4) GetOrCreateUnnumbered() *Interface_Subinterface_Ipv4_Unnumbered {
	if t.Unnumbered != nil {
		return t.Unnumbered
	}
	t.Unnumbered = &Interface_Subinterface_Ipv4_Unnumbered{}
	return t.Unnumbered
}

// GetCounters returns the value of the Counters struct pointer
// from Interface_Subinterface_Ipv4. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv4) GetCounters() *Interface_Subinterface_Ipv4_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetProxyArp returns the value of the ProxyArp struct pointer
// from Interface_Subinterface_Ipv4. If the receiver or the field ProxyArp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv4) GetProxyArp() *Interface_Subinterface_Ipv4_ProxyArp {
	if t != nil && t.ProxyArp != nil {
		return t.ProxyArp
	}
	return nil
}

// GetUnnumbered returns the value of the Unnumbered struct pointer
// from Interface_Subinterface_Ipv4. If the receiver or the field Unnumbered is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv4) GetUnnumbered() *Interface_Subinterface_Ipv4_Unnumbered {
	if t != nil && t.Unnumbered != nil {
		return t.Unnumbered
	}
	return nil
}

// GetDhcpClient retrieves the value of the leaf DhcpClient from the Interface_Subinterface_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpClient is set, it can safely use t.GetDhcpClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpClient == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4) GetDhcpClient() bool {
	if t == nil || t.DhcpClient == nil {
		return false
	}
	return *t.DhcpClient
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_Subinterface_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetMtu retrieves the value of the leaf Mtu from the Interface_Subinterface_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mtu is set, it can safely use t.GetMtu()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mtu == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4) GetMtu() uint16 {
	if t == nil || t.Mtu == nil {
		return 0
	}
	return *t.Mtu
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Subinterface_Ipv4_Address represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/addresses/address YANG schema element.
type Interface_Subinterface_Ipv4_Address struct {
	ΛMetadata     []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	Ip            *string                                                  `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp           []ygot.Annotation                                        `path:"state/@ip|@ip" ygotAnnotation:"true"`
	Origin        E_OpenconfigIfIp_IpAddressOrigin                         `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin       []ygot.Annotation                                        `path:"state/@origin" ygotAnnotation:"true"`
	PrefixLength  *uint8                                                   `path:"state/prefix-length" shadow-path:"config/prefix-length" module:"openconfig-if-ip"`
	ΛPrefixLength []ygot.Annotation                                        `path:"state/@prefix-length" ygotAnnotation:"true"`
	VrrpGroup     map[uint8]*Interface_Subinterface_Ipv4_Address_VrrpGroup `path:"vrrp/vrrp-group" module:"openconfig-if-ip"`
	ΛVrrpGroup    []ygot.Annotation                                        `path:"vrrp/@vrrp-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Address implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Address) IsYANGGoStruct() {}

// NewVrrpGroup creates a new entry in the VrrpGroup list of the
// Interface_Subinterface_Ipv4_Address struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_Subinterface_Ipv4_Address) NewVrrpGroup(VirtualRouterId uint8) (*Interface_Subinterface_Ipv4_Address_VrrpGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_Subinterface_Ipv4_Address_VrrpGroup)
	}

	key := VirtualRouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.VrrpGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list VrrpGroup", key)
	}

	t.VrrpGroup[key] = &Interface_Subinterface_Ipv4_Address_VrrpGroup{
		VirtualRouterId: &VirtualRouterId,
	}

	return t.VrrpGroup[key], nil
}

// RenameVrrpGroup renames an entry in the list VrrpGroup within
// the Interface_Subinterface_Ipv4_Address struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_Subinterface_Ipv4_Address) RenameVrrpGroup(oldK, newK uint8) error {
	if _, ok := t.VrrpGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in VrrpGroup", newK)
	}

	e, ok := t.VrrpGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in VrrpGroup", oldK)
	}
	e.VirtualRouterId = &newK

	t.VrrpGroup[newK] = e
	delete(t.VrrpGroup, oldK)
	return nil
}

// GetOrCreateVrrpGroup retrieves the value with the specified keys from
// the receiver Interface_Subinterface_Ipv4_Address. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_Subinterface_Ipv4_Address) GetOrCreateVrrpGroup(VirtualRouterId uint8) *Interface_Subinterface_Ipv4_Address_VrrpGroup {

	key := VirtualRouterId

	if v, ok := t.VrrpGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVrrpGroup(VirtualRouterId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVrrpGroup got unexpected error: %v", err))
	}
	return v
}

// GetVrrpGroup retrieves the value with the specified key from
// the VrrpGroup map field of Interface_Subinterface_Ipv4_Address. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_Subinterface_Ipv4_Address) GetVrrpGroup(VirtualRouterId uint8) *Interface_Subinterface_Ipv4_Address_VrrpGroup {

	if t == nil {
		return nil
	}

	key := VirtualRouterId

	if lm, ok := t.VrrpGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendVrrpGroup appends the supplied Interface_Subinterface_Ipv4_Address_VrrpGroup struct to the
// list VrrpGroup of Interface_Subinterface_Ipv4_Address. If the key value(s) specified in
// the supplied Interface_Subinterface_Ipv4_Address_VrrpGroup already exist in the list, an error is
// returned.
func (t *Interface_Subinterface_Ipv4_Address) AppendVrrpGroup(v *Interface_Subinterface_Ipv4_Address_VrrpGroup) error {
	if v.VirtualRouterId == nil {
		return fmt.Errorf("invalid nil key received for VirtualRouterId")
	}

	key := *v.VirtualRouterId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_Subinterface_Ipv4_Address_VrrpGroup)
	}

	if _, ok := t.VrrpGroup[key]; ok {
		return fmt.Errorf("duplicate key for list VrrpGroup %v", key)
	}

	t.VrrpGroup[key] = v
	return nil
}

// GetIp retrieves the value of the leaf Ip from the Interface_Subinterface_Ipv4_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_Subinterface_Ipv4_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address) GetOrigin() E_OpenconfigIfIp_IpAddressOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// GetPrefixLength retrieves the value of the leaf PrefixLength from the Interface_Subinterface_Ipv4_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixLength is set, it can safely use t.GetPrefixLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixLength == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address) GetPrefixLength() uint8 {
	if t == nil || t.PrefixLength == nil {
		return 0
	}
	return *t.PrefixLength
}

// ΛListKeyMap returns the keys of the Interface_Subinterface_Ipv4_Address struct, which is a YANG list entry.
func (t *Interface_Subinterface_Ipv4_Address) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Address) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Address"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Address) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_Address_VrrpGroup represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/addresses/address/vrrp/vrrp-group YANG schema element.
type Interface_Subinterface_Ipv4_Address_VrrpGroup struct {
	ΛMetadata              []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	AcceptMode             *bool                                                            `path:"state/accept-mode" shadow-path:"config/accept-mode" module:"openconfig-if-ip"`
	ΛAcceptMode            []ygot.Annotation                                                `path:"state/@accept-mode" ygotAnnotation:"true"`
	AdvertisementInterval  *uint16                                                          `path:"state/advertisement-interval" shadow-path:"config/advertisement-interval" module:"openconfig-if-ip"`
	ΛAdvertisementInterval []ygot.Annotation                                                `path:"state/@advertisement-interval" ygotAnnotation:"true"`
	CurrentPriority        *uint8                                                           `path:"state/current-priority" module:"openconfig-if-ip"`
	ΛCurrentPriority       []ygot.Annotation                                                `path:"state/@current-priority" ygotAnnotation:"true"`
	InterfaceTracking      *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking `path:"interface-tracking" module:"openconfig-if-ip"`
	ΛInterfaceTracking     []ygot.Annotation                                                `path:"@interface-tracking" ygotAnnotation:"true"`
	Preempt                *bool                                                            `path:"state/preempt" shadow-path:"config/preempt" module:"openconfig-if-ip"`
	ΛPreempt               []ygot.Annotation                                                `path:"state/@preempt" ygotAnnotation:"true"`
	PreemptDelay           *uint16                                                          `path:"state/preempt-delay" shadow-path:"config/preempt-delay" module:"openconfig-if-ip"`
	ΛPreemptDelay          []ygot.Annotation                                                `path:"state/@preempt-delay" ygotAnnotation:"true"`
	Priority               *uint8                                                           `path:"state/priority" shadow-path:"config/priority" module:"openconfig-if-ip"`
	ΛPriority              []ygot.Annotation                                                `path:"state/@priority" ygotAnnotation:"true"`
	VirtualAddress         []string                                                         `path:"state/virtual-address" shadow-path:"config/virtual-address" module:"openconfig-if-ip"`
	ΛVirtualAddress        []ygot.Annotation                                                `path:"state/@virtual-address" ygotAnnotation:"true"`
	VirtualRouterId        *uint8                                                           `path:"state/virtual-router-id|virtual-router-id" shadow-path:"config/virtual-router-id" module:"openconfig-if-ip"`
	ΛVirtualRouterId       []ygot.Annotation                                                `path:"state/@virtual-router-id|@virtual-router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Address_VrrpGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Address_VrrpGroup) IsYANGGoStruct() {}

// GetOrCreateInterfaceTracking retrieves the value of the InterfaceTracking field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetOrCreateInterfaceTracking() *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking {
	if t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	t.InterfaceTracking = &Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking{}
	return t.InterfaceTracking
}

// GetInterfaceTracking returns the value of the InterfaceTracking struct pointer
// from Interface_Subinterface_Ipv4_Address_VrrpGroup. If the receiver or the field InterfaceTracking is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetInterfaceTracking() *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking {
	if t != nil && t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	return nil
}

// GetAcceptMode retrieves the value of the leaf AcceptMode from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AcceptMode is set, it can safely use t.GetAcceptMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AcceptMode == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetAcceptMode() bool {
	if t == nil || t.AcceptMode == nil {
		return false
	}
	return *t.AcceptMode
}

// GetAdvertisementInterval retrieves the value of the leaf AdvertisementInterval from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertisementInterval is set, it can safely use t.GetAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetAdvertisementInterval() uint16 {
	if t == nil || t.AdvertisementInterval == nil {
		return 100
	}
	return *t.AdvertisementInterval
}

// GetCurrentPriority retrieves the value of the leaf CurrentPriority from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CurrentPriority is set, it can safely use t.GetCurrentPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CurrentPriority == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetCurrentPriority() uint8 {
	if t == nil || t.CurrentPriority == nil {
		return 0
	}
	return *t.CurrentPriority
}

// GetPreempt retrieves the value of the leaf Preempt from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preempt is set, it can safely use t.GetPreempt()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preempt == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetPreempt() bool {
	if t == nil || t.Preempt == nil {
		return true
	}
	return *t.Preempt
}

// GetPreemptDelay retrieves the value of the leaf PreemptDelay from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreemptDelay is set, it can safely use t.GetPreemptDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreemptDelay == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetPreemptDelay() uint16 {
	if t == nil || t.PreemptDelay == nil {
		return 0
	}
	return *t.PreemptDelay
}

// GetPriority retrieves the value of the leaf Priority from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 100
	}
	return *t.Priority
}

// GetVirtualAddress retrieves the value of the leaf VirtualAddress from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualAddress is set, it can safely use t.GetVirtualAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetVirtualAddress() []string {
	if t == nil || t.VirtualAddress == nil {
		return nil
	}
	return t.VirtualAddress
}

// GetVirtualRouterId retrieves the value of the leaf VirtualRouterId from the Interface_Subinterface_Ipv4_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualRouterId is set, it can safely use t.GetVirtualRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualRouterId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) GetVirtualRouterId() uint8 {
	if t == nil || t.VirtualRouterId == nil {
		return 0
	}
	return *t.VirtualRouterId
}

// ΛListKeyMap returns the keys of the Interface_Subinterface_Ipv4_Address_VrrpGroup struct, which is a YANG list entry.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VirtualRouterId == nil {
		return nil, fmt.Errorf("nil value for key VirtualRouterId")
	}

	return map[string]interface{}{
		"virtual-router-id": *t.VirtualRouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Address_VrrpGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/addresses/address/vrrp/vrrp-group/interface-tracking YANG schema element.
type Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PriorityDecrement  *uint8            `path:"state/priority-decrement" shadow-path:"config/priority-decrement" module:"openconfig-if-ip"`
	ΛPriorityDecrement []ygot.Annotation `path:"state/@priority-decrement" ygotAnnotation:"true"`
	TrackInterface     []string          `path:"state/track-interface" shadow-path:"config/track-interface" module:"openconfig-if-ip"`
	ΛTrackInterface    []ygot.Annotation `path:"state/@track-interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking) IsYANGGoStruct() {}

// GetPriorityDecrement retrieves the value of the leaf PriorityDecrement from the Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PriorityDecrement is set, it can safely use t.GetPriorityDecrement()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PriorityDecrement == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking) GetPriorityDecrement() uint8 {
	if t == nil || t.PriorityDecrement == nil {
		return 0
	}
	return *t.PriorityDecrement
}

// GetTrackInterface retrieves the value of the leaf TrackInterface from the Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrackInterface is set, it can safely use t.GetTrackInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrackInterface == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking) GetTrackInterface() []string {
	if t == nil || t.TrackInterface == nil {
		return nil
	}
	return t.TrackInterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Address_VrrpGroup_InterfaceTracking) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_Counters represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/state/counters YANG schema element.
type Interface_Subinterface_Ipv4_Counters struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InDiscardedPkts     *uint64           `path:"in-discarded-pkts" module:"openconfig-if-ip"`
	ΛInDiscardedPkts    []ygot.Annotation `path:"@in-discarded-pkts" ygotAnnotation:"true"`
	InErrorPkts         *uint64           `path:"in-error-pkts" module:"openconfig-if-ip"`
	ΛInErrorPkts        []ygot.Annotation `path:"@in-error-pkts" ygotAnnotation:"true"`
	InForwardedOctets   *uint64           `path:"in-forwarded-octets" module:"openconfig-if-ip"`
	ΛInForwardedOctets  []ygot.Annotation `path:"@in-forwarded-octets" ygotAnnotation:"true"`
	InForwardedPkts     *uint64           `path:"in-forwarded-pkts" module:"openconfig-if-ip"`
	ΛInForwardedPkts    []ygot.Annotation `path:"@in-forwarded-pkts" ygotAnnotation:"true"`
	InOctets            *uint64           `path:"in-octets" module:"openconfig-if-ip"`
	ΛInOctets           []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts              *uint64           `path:"in-pkts" module:"openconfig-if-ip"`
	ΛInPkts             []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	OutDiscardedPkts    *uint64           `path:"out-discarded-pkts" module:"openconfig-if-ip"`
	ΛOutDiscardedPkts   []ygot.Annotation `path:"@out-discarded-pkts" ygotAnnotation:"true"`
	OutErrorPkts        *uint64           `path:"out-error-pkts" module:"openconfig-if-ip"`
	ΛOutErrorPkts       []ygot.Annotation `path:"@out-error-pkts" ygotAnnotation:"true"`
	OutForwardedOctets  *uint64           `path:"out-forwarded-octets" module:"openconfig-if-ip"`
	ΛOutForwardedOctets []ygot.Annotation `path:"@out-forwarded-octets" ygotAnnotation:"true"`
	OutForwardedPkts    *uint64           `path:"out-forwarded-pkts" module:"openconfig-if-ip"`
	ΛOutForwardedPkts   []ygot.Annotation `path:"@out-forwarded-pkts" ygotAnnotation:"true"`
	OutOctets           *uint64           `path:"out-octets" module:"openconfig-if-ip"`
	ΛOutOctets          []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts             *uint64           `path:"out-pkts" module:"openconfig-if-ip"`
	ΛOutPkts            []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Counters) IsYANGGoStruct() {}

// GetInDiscardedPkts retrieves the value of the leaf InDiscardedPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InDiscardedPkts is set, it can safely use t.GetInDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetInDiscardedPkts() uint64 {
	if t == nil || t.InDiscardedPkts == nil {
		return 0
	}
	return *t.InDiscardedPkts
}

// GetInErrorPkts retrieves the value of the leaf InErrorPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InErrorPkts is set, it can safely use t.GetInErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetInErrorPkts() uint64 {
	if t == nil || t.InErrorPkts == nil {
		return 0
	}
	return *t.InErrorPkts
}

// GetInForwardedOctets retrieves the value of the leaf InForwardedOctets from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedOctets is set, it can safely use t.GetInForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetInForwardedOctets() uint64 {
	if t == nil || t.InForwardedOctets == nil {
		return 0
	}
	return *t.InForwardedOctets
}

// GetInForwardedPkts retrieves the value of the leaf InForwardedPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedPkts is set, it can safely use t.GetInForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetInForwardedPkts() uint64 {
	if t == nil || t.InForwardedPkts == nil {
		return 0
	}
	return *t.InForwardedPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetOutDiscardedPkts retrieves the value of the leaf OutDiscardedPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutDiscardedPkts is set, it can safely use t.GetOutDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetOutDiscardedPkts() uint64 {
	if t == nil || t.OutDiscardedPkts == nil {
		return 0
	}
	return *t.OutDiscardedPkts
}

// GetOutErrorPkts retrieves the value of the leaf OutErrorPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutErrorPkts is set, it can safely use t.GetOutErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetOutErrorPkts() uint64 {
	if t == nil || t.OutErrorPkts == nil {
		return 0
	}
	return *t.OutErrorPkts
}

// GetOutForwardedOctets retrieves the value of the leaf OutForwardedOctets from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedOctets is set, it can safely use t.GetOutForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetOutForwardedOctets() uint64 {
	if t == nil || t.OutForwardedOctets == nil {
		return 0
	}
	return *t.OutForwardedOctets
}

// GetOutForwardedPkts retrieves the value of the leaf OutForwardedPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedPkts is set, it can safely use t.GetOutForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetOutForwardedPkts() uint64 {
	if t == nil || t.OutForwardedPkts == nil {
		return 0
	}
	return *t.OutForwardedPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the Interface_Subinterface_Ipv4_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_Neighbor represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/neighbors/neighbor YANG schema element.
type Interface_Subinterface_Ipv4_Neighbor struct {
	ΛMetadata         []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Ip                *string                         `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp               []ygot.Annotation               `path:"state/@ip|@ip" ygotAnnotation:"true"`
	LinkLayerAddress  *string                         `path:"state/link-layer-address" shadow-path:"config/link-layer-address" module:"openconfig-if-ip"`
	ΛLinkLayerAddress []ygot.Annotation               `path:"state/@link-layer-address" ygotAnnotation:"true"`
	Origin            E_OpenconfigIfIp_NeighborOrigin `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin           []ygot.Annotation               `path:"state/@origin" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Neighbor) IsYANGGoStruct() {}

// GetIp retrieves the value of the leaf Ip from the Interface_Subinterface_Ipv4_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Neighbor) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetLinkLayerAddress retrieves the value of the leaf LinkLayerAddress from the Interface_Subinterface_Ipv4_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLayerAddress is set, it can safely use t.GetLinkLayerAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLayerAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Neighbor) GetLinkLayerAddress() string {
	if t == nil || t.LinkLayerAddress == nil {
		return ""
	}
	return *t.LinkLayerAddress
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_Subinterface_Ipv4_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Neighbor) GetOrigin() E_OpenconfigIfIp_NeighborOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// ΛListKeyMap returns the keys of the Interface_Subinterface_Ipv4_Neighbor struct, which is a YANG list entry.
func (t *Interface_Subinterface_Ipv4_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_ProxyArp represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/proxy-arp YANG schema element.
type Interface_Subinterface_Ipv4_ProxyArp struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Mode      E_ProxyArp_Mode   `path:"state/mode" shadow-path:"config/mode" module:"openconfig-if-ip"`
	ΛMode     []ygot.Annotation `path:"state/@mode" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_ProxyArp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_ProxyArp) IsYANGGoStruct() {}

// GetMode retrieves the value of the leaf Mode from the Interface_Subinterface_Ipv4_ProxyArp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_ProxyArp) GetMode() E_ProxyArp_Mode {
	if t == nil || t.Mode == 0 {
		return ProxyArp_Mode_DISABLE
	}
	return t.Mode
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_ProxyArp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_ProxyArp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_ProxyArp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_Unnumbered represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/unnumbered YANG schema element.
type Interface_Subinterface_Ipv4_Unnumbered struct {
	ΛMetadata     []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	Enabled       *bool                                                `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled      []ygot.Annotation                                    `path:"state/@enabled" ygotAnnotation:"true"`
	InterfaceRef  *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef `path:"interface-ref" module:"openconfig-if-ip"`
	ΛInterfaceRef []ygot.Annotation                                    `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Unnumbered implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Unnumbered) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv4_Unnumbered) GetOrCreateInterfaceRef() *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from Interface_Subinterface_Ipv4_Unnumbered. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv4_Unnumbered) GetInterfaceRef() *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_Subinterface_Ipv4_Unnumbered
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Unnumbered) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Unnumbered) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Unnumbered"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Unnumbered) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv4/unnumbered/interface-ref YANG schema element.
type Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-if-ip"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-if-ip"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv4_Unnumbered_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6 represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6 YANG schema element.
type Interface_Subinterface_Ipv6 struct {
	ΛMetadata               []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	Address                 map[string]*Interface_Subinterface_Ipv6_Address  `path:"addresses/address" module:"openconfig-if-ip"`
	ΛAddress                []ygot.Annotation                                `path:"addresses/@address" ygotAnnotation:"true"`
	Autoconf                *Interface_Subinterface_Ipv6_Autoconf            `path:"autoconf" module:"openconfig-if-ip-ext"`
	ΛAutoconf               []ygot.Annotation                                `path:"@autoconf" ygotAnnotation:"true"`
	Counters                *Interface_Subinterface_Ipv6_Counters            `path:"state/counters" module:"openconfig-if-ip"`
	ΛCounters               []ygot.Annotation                                `path:"state/@counters" ygotAnnotation:"true"`
	DhcpClient              *bool                                            `path:"state/dhcp-client" shadow-path:"config/dhcp-client" module:"openconfig-if-ip"`
	ΛDhcpClient             []ygot.Annotation                                `path:"state/@dhcp-client" ygotAnnotation:"true"`
	DupAddrDetectTransmits  *uint32                                          `path:"state/dup-addr-detect-transmits" shadow-path:"config/dup-addr-detect-transmits" module:"openconfig-if-ip"`
	ΛDupAddrDetectTransmits []ygot.Annotation                                `path:"state/@dup-addr-detect-transmits" ygotAnnotation:"true"`
	Enabled                 *bool                                            `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled                []ygot.Annotation                                `path:"state/@enabled" ygotAnnotation:"true"`
	Mtu                     *uint32                                          `path:"state/mtu" shadow-path:"config/mtu" module:"openconfig-if-ip"`
	ΛMtu                    []ygot.Annotation                                `path:"state/@mtu" ygotAnnotation:"true"`
	Neighbor                map[string]*Interface_Subinterface_Ipv6_Neighbor `path:"neighbors/neighbor" module:"openconfig-if-ip"`
	ΛNeighbor               []ygot.Annotation                                `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	RouterAdvertisement     *Interface_Subinterface_Ipv6_RouterAdvertisement `path:"router-advertisement" module:"openconfig-if-ip"`
	ΛRouterAdvertisement    []ygot.Annotation                                `path:"@router-advertisement" ygotAnnotation:"true"`
	Unnumbered              *Interface_Subinterface_Ipv6_Unnumbered          `path:"unnumbered" module:"openconfig-if-ip"`
	ΛUnnumbered             []ygot.Annotation                                `path:"@unnumbered" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6) IsYANGGoStruct() {}

// NewAddress creates a new entry in the Address list of the
// Interface_Subinterface_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_Subinterface_Ipv6) NewAddress(Ip string) (*Interface_Subinterface_Ipv6_Address, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_Subinterface_Ipv6_Address)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Address[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Address", key)
	}

	t.Address[key] = &Interface_Subinterface_Ipv6_Address{
		Ip: &Ip,
	}

	return t.Address[key], nil
}

// RenameAddress renames an entry in the list Address within
// the Interface_Subinterface_Ipv6 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_Subinterface_Ipv6) RenameAddress(oldK, newK string) error {
	if _, ok := t.Address[newK]; ok {
		return fmt.Errorf("key %v already exists in Address", newK)
	}

	e, ok := t.Address[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Address", oldK)
	}
	e.Ip = &newK

	t.Address[newK] = e
	delete(t.Address, oldK)
	return nil
}

// GetOrCreateAddress retrieves the value with the specified keys from
// the receiver Interface_Subinterface_Ipv6. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_Subinterface_Ipv6) GetOrCreateAddress(Ip string) *Interface_Subinterface_Ipv6_Address {

	key := Ip

	if v, ok := t.Address[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAddress(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAddress got unexpected error: %v", err))
	}
	return v
}

// GetAddress retrieves the value with the specified key from
// the Address map field of Interface_Subinterface_Ipv6. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_Subinterface_Ipv6) GetAddress(Ip string) *Interface_Subinterface_Ipv6_Address {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Address[key]; ok {
		return lm
	}
	return nil
}

// AppendAddress appends the supplied Interface_Subinterface_Ipv6_Address struct to the
// list Address of Interface_Subinterface_Ipv6. If the key value(s) specified in
// the supplied Interface_Subinterface_Ipv6_Address already exist in the list, an error is
// returned.
func (t *Interface_Subinterface_Ipv6) AppendAddress(v *Interface_Subinterface_Ipv6_Address) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Address == nil {
		t.Address = make(map[string]*Interface_Subinterface_Ipv6_Address)
	}

	if _, ok := t.Address[key]; ok {
		return fmt.Errorf("duplicate key for list Address %v", key)
	}

	t.Address[key] = v
	return nil
}

// NewNeighbor creates a new entry in the Neighbor list of the
// Interface_Subinterface_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_Subinterface_Ipv6) NewNeighbor(Ip string) (*Interface_Subinterface_Ipv6_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_Subinterface_Ipv6_Neighbor)
	}

	key := Ip

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Interface_Subinterface_Ipv6_Neighbor{
		Ip: &Ip,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Interface_Subinterface_Ipv6 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_Subinterface_Ipv6) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Ip = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Interface_Subinterface_Ipv6. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_Subinterface_Ipv6) GetOrCreateNeighbor(Ip string) *Interface_Subinterface_Ipv6_Neighbor {

	key := Ip

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Ip)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Interface_Subinterface_Ipv6. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_Subinterface_Ipv6) GetNeighbor(Ip string) *Interface_Subinterface_Ipv6_Neighbor {

	if t == nil {
		return nil
	}

	key := Ip

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Interface_Subinterface_Ipv6_Neighbor struct to the
// list Neighbor of Interface_Subinterface_Ipv6. If the key value(s) specified in
// the supplied Interface_Subinterface_Ipv6_Neighbor already exist in the list, an error is
// returned.
func (t *Interface_Subinterface_Ipv6) AppendNeighbor(v *Interface_Subinterface_Ipv6_Neighbor) error {
	if v.Ip == nil {
		return fmt.Errorf("invalid nil key received for Ip")
	}

	key := *v.Ip

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Interface_Subinterface_Ipv6_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateAutoconf retrieves the value of the Autoconf field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv6) GetOrCreateAutoconf() *Interface_Subinterface_Ipv6_Autoconf {
	if t.Autoconf != nil {
		return t.Autoconf
	}
	t.Autoconf = &Interface_Subinterface_Ipv6_Autoconf{}
	return t.Autoconf
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv6) GetOrCreateCounters() *Interface_Subinterface_Ipv6_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Interface_Subinterface_Ipv6_Counters{}
	return t.Counters
}

// GetOrCreateRouterAdvertisement retrieves the value of the RouterAdvertisement field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv6) GetOrCreateRouterAdvertisement() *Interface_Subinterface_Ipv6_RouterAdvertisement {
	if t.RouterAdvertisement != nil {
		return t.RouterAdvertisement
	}
	t.RouterAdvertisement = &Interface_Subinterface_Ipv6_RouterAdvertisement{}
	return t.RouterAdvertisement
}

// GetOrCreateUnnumbered retrieves the value of the Unnumbered field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv6) GetOrCreateUnnumbered() *Interface_Subinterface_Ipv6_Unnumbered {
	if t.Unnumbered != nil {
		return t.Unnumbered
	}
	t.Unnumbered = &Interface_Subinterface_Ipv6_Unnumbered{}
	return t.Unnumbered
}

// GetAutoconf returns the value of the Autoconf struct pointer
// from Interface_Subinterface_Ipv6. If the receiver or the field Autoconf is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv6) GetAutoconf() *Interface_Subinterface_Ipv6_Autoconf {
	if t != nil && t.Autoconf != nil {
		return t.Autoconf
	}
	return nil
}

// GetCounters returns the value of the Counters struct pointer
// from Interface_Subinterface_Ipv6. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv6) GetCounters() *Interface_Subinterface_Ipv6_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetRouterAdvertisement returns the value of the RouterAdvertisement struct pointer
// from Interface_Subinterface_Ipv6. If the receiver or the field RouterAdvertisement is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv6) GetRouterAdvertisement() *Interface_Subinterface_Ipv6_RouterAdvertisement {
	if t != nil && t.RouterAdvertisement != nil {
		return t.RouterAdvertisement
	}
	return nil
}

// GetUnnumbered returns the value of the Unnumbered struct pointer
// from Interface_Subinterface_Ipv6. If the receiver or the field Unnumbered is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv6) GetUnnumbered() *Interface_Subinterface_Ipv6_Unnumbered {
	if t != nil && t.Unnumbered != nil {
		return t.Unnumbered
	}
	return nil
}

// GetDhcpClient retrieves the value of the leaf DhcpClient from the Interface_Subinterface_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpClient is set, it can safely use t.GetDhcpClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpClient == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6) GetDhcpClient() bool {
	if t == nil || t.DhcpClient == nil {
		return false
	}
	return *t.DhcpClient
}

// GetDupAddrDetectTransmits retrieves the value of the leaf DupAddrDetectTransmits from the Interface_Subinterface_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DupAddrDetectTransmits is set, it can safely use t.GetDupAddrDetectTransmits()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DupAddrDetectTransmits == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6) GetDupAddrDetectTransmits() uint32 {
	if t == nil || t.DupAddrDetectTransmits == nil {
		return 1
	}
	return *t.DupAddrDetectTransmits
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_Subinterface_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetMtu retrieves the value of the leaf Mtu from the Interface_Subinterface_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mtu is set, it can safely use t.GetMtu()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mtu == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6) GetMtu() uint32 {
	if t == nil || t.Mtu == nil {
		return 0
	}
	return *t.Mtu
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Subinterface_Ipv6_Address represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/addresses/address YANG schema element.
type Interface_Subinterface_Ipv6_Address struct {
	ΛMetadata     []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	Ip            *string                                                  `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp           []ygot.Annotation                                        `path:"state/@ip|@ip" ygotAnnotation:"true"`
	Origin        E_OpenconfigIfIp_IpAddressOrigin                         `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin       []ygot.Annotation                                        `path:"state/@origin" ygotAnnotation:"true"`
	PrefixLength  *uint8                                                   `path:"state/prefix-length" shadow-path:"config/prefix-length" module:"openconfig-if-ip"`
	ΛPrefixLength []ygot.Annotation                                        `path:"state/@prefix-length" ygotAnnotation:"true"`
	Status        E_Address_Status                                         `path:"state/status" module:"openconfig-if-ip"`
	ΛStatus       []ygot.Annotation                                        `path:"state/@status" ygotAnnotation:"true"`
	VrrpGroup     map[uint8]*Interface_Subinterface_Ipv6_Address_VrrpGroup `path:"vrrp/vrrp-group" module:"openconfig-if-ip"`
	ΛVrrpGroup    []ygot.Annotation                                        `path:"vrrp/@vrrp-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Address implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Address) IsYANGGoStruct() {}

// NewVrrpGroup creates a new entry in the VrrpGroup list of the
// Interface_Subinterface_Ipv6_Address struct. The keys of the list are populated from the input
// arguments.
func (t *Interface_Subinterface_Ipv6_Address) NewVrrpGroup(VirtualRouterId uint8) (*Interface_Subinterface_Ipv6_Address_VrrpGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_Subinterface_Ipv6_Address_VrrpGroup)
	}

	key := VirtualRouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.VrrpGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list VrrpGroup", key)
	}

	t.VrrpGroup[key] = &Interface_Subinterface_Ipv6_Address_VrrpGroup{
		VirtualRouterId: &VirtualRouterId,
	}

	return t.VrrpGroup[key], nil
}

// RenameVrrpGroup renames an entry in the list VrrpGroup within
// the Interface_Subinterface_Ipv6_Address struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Interface_Subinterface_Ipv6_Address) RenameVrrpGroup(oldK, newK uint8) error {
	if _, ok := t.VrrpGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in VrrpGroup", newK)
	}

	e, ok := t.VrrpGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in VrrpGroup", oldK)
	}
	e.VirtualRouterId = &newK

	t.VrrpGroup[newK] = e
	delete(t.VrrpGroup, oldK)
	return nil
}

// GetOrCreateVrrpGroup retrieves the value with the specified keys from
// the receiver Interface_Subinterface_Ipv6_Address. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Interface_Subinterface_Ipv6_Address) GetOrCreateVrrpGroup(VirtualRouterId uint8) *Interface_Subinterface_Ipv6_Address_VrrpGroup {

	key := VirtualRouterId

	if v, ok := t.VrrpGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVrrpGroup(VirtualRouterId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVrrpGroup got unexpected error: %v", err))
	}
	return v
}

// GetVrrpGroup retrieves the value with the specified key from
// the VrrpGroup map field of Interface_Subinterface_Ipv6_Address. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Interface_Subinterface_Ipv6_Address) GetVrrpGroup(VirtualRouterId uint8) *Interface_Subinterface_Ipv6_Address_VrrpGroup {

	if t == nil {
		return nil
	}

	key := VirtualRouterId

	if lm, ok := t.VrrpGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendVrrpGroup appends the supplied Interface_Subinterface_Ipv6_Address_VrrpGroup struct to the
// list VrrpGroup of Interface_Subinterface_Ipv6_Address. If the key value(s) specified in
// the supplied Interface_Subinterface_Ipv6_Address_VrrpGroup already exist in the list, an error is
// returned.
func (t *Interface_Subinterface_Ipv6_Address) AppendVrrpGroup(v *Interface_Subinterface_Ipv6_Address_VrrpGroup) error {
	if v.VirtualRouterId == nil {
		return fmt.Errorf("invalid nil key received for VirtualRouterId")
	}

	key := *v.VirtualRouterId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VrrpGroup == nil {
		t.VrrpGroup = make(map[uint8]*Interface_Subinterface_Ipv6_Address_VrrpGroup)
	}

	if _, ok := t.VrrpGroup[key]; ok {
		return fmt.Errorf("duplicate key for list VrrpGroup %v", key)
	}

	t.VrrpGroup[key] = v
	return nil
}

// GetIp retrieves the value of the leaf Ip from the Interface_Subinterface_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_Subinterface_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address) GetOrigin() E_OpenconfigIfIp_IpAddressOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// GetPrefixLength retrieves the value of the leaf PrefixLength from the Interface_Subinterface_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixLength is set, it can safely use t.GetPrefixLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixLength == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address) GetPrefixLength() uint8 {
	if t == nil || t.PrefixLength == nil {
		return 0
	}
	return *t.PrefixLength
}

// GetStatus retrieves the value of the leaf Status from the Interface_Subinterface_Ipv6_Address
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Status is set, it can safely use t.GetStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Status == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address) GetStatus() E_Address_Status {
	if t == nil || t.Status == 0 {
		return 0
	}
	return t.Status
}

// ΛListKeyMap returns the keys of the Interface_Subinterface_Ipv6_Address struct, which is a YANG list entry.
func (t *Interface_Subinterface_Ipv6_Address) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Address) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Address"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Address) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Address_VrrpGroup represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/addresses/address/vrrp/vrrp-group YANG schema element.
type Interface_Subinterface_Ipv6_Address_VrrpGroup struct {
	ΛMetadata              []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	AcceptMode             *bool                                                            `path:"state/accept-mode" shadow-path:"config/accept-mode" module:"openconfig-if-ip"`
	ΛAcceptMode            []ygot.Annotation                                                `path:"state/@accept-mode" ygotAnnotation:"true"`
	AdvertisementInterval  *uint16                                                          `path:"state/advertisement-interval" shadow-path:"config/advertisement-interval" module:"openconfig-if-ip"`
	ΛAdvertisementInterval []ygot.Annotation                                                `path:"state/@advertisement-interval" ygotAnnotation:"true"`
	CurrentPriority        *uint8                                                           `path:"state/current-priority" module:"openconfig-if-ip"`
	ΛCurrentPriority       []ygot.Annotation                                                `path:"state/@current-priority" ygotAnnotation:"true"`
	InterfaceTracking      *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking `path:"interface-tracking" module:"openconfig-if-ip"`
	ΛInterfaceTracking     []ygot.Annotation                                                `path:"@interface-tracking" ygotAnnotation:"true"`
	Preempt                *bool                                                            `path:"state/preempt" shadow-path:"config/preempt" module:"openconfig-if-ip"`
	ΛPreempt               []ygot.Annotation                                                `path:"state/@preempt" ygotAnnotation:"true"`
	PreemptDelay           *uint16                                                          `path:"state/preempt-delay" shadow-path:"config/preempt-delay" module:"openconfig-if-ip"`
	ΛPreemptDelay          []ygot.Annotation                                                `path:"state/@preempt-delay" ygotAnnotation:"true"`
	Priority               *uint8                                                           `path:"state/priority" shadow-path:"config/priority" module:"openconfig-if-ip"`
	ΛPriority              []ygot.Annotation                                                `path:"state/@priority" ygotAnnotation:"true"`
	VirtualAddress         []string                                                         `path:"state/virtual-address" shadow-path:"config/virtual-address" module:"openconfig-if-ip"`
	ΛVirtualAddress        []ygot.Annotation                                                `path:"state/@virtual-address" ygotAnnotation:"true"`
	VirtualLinkLocal       *string                                                          `path:"state/virtual-link-local" shadow-path:"config/virtual-link-local" module:"openconfig-if-ip"`
	ΛVirtualLinkLocal      []ygot.Annotation                                                `path:"state/@virtual-link-local" ygotAnnotation:"true"`
	VirtualRouterId        *uint8                                                           `path:"state/virtual-router-id|virtual-router-id" shadow-path:"config/virtual-router-id" module:"openconfig-if-ip"`
	ΛVirtualRouterId       []ygot.Annotation                                                `path:"state/@virtual-router-id|@virtual-router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Address_VrrpGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Address_VrrpGroup) IsYANGGoStruct() {}

// GetOrCreateInterfaceTracking retrieves the value of the InterfaceTracking field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetOrCreateInterfaceTracking() *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking {
	if t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	t.InterfaceTracking = &Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking{}
	return t.InterfaceTracking
}

// GetInterfaceTracking returns the value of the InterfaceTracking struct pointer
// from Interface_Subinterface_Ipv6_Address_VrrpGroup. If the receiver or the field InterfaceTracking is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetInterfaceTracking() *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking {
	if t != nil && t.InterfaceTracking != nil {
		return t.InterfaceTracking
	}
	return nil
}

// GetAcceptMode retrieves the value of the leaf AcceptMode from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AcceptMode is set, it can safely use t.GetAcceptMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AcceptMode == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetAcceptMode() bool {
	if t == nil || t.AcceptMode == nil {
		return false
	}
	return *t.AcceptMode
}

// GetAdvertisementInterval retrieves the value of the leaf AdvertisementInterval from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertisementInterval is set, it can safely use t.GetAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetAdvertisementInterval() uint16 {
	if t == nil || t.AdvertisementInterval == nil {
		return 100
	}
	return *t.AdvertisementInterval
}

// GetCurrentPriority retrieves the value of the leaf CurrentPriority from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CurrentPriority is set, it can safely use t.GetCurrentPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CurrentPriority == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetCurrentPriority() uint8 {
	if t == nil || t.CurrentPriority == nil {
		return 0
	}
	return *t.CurrentPriority
}

// GetPreempt retrieves the value of the leaf Preempt from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preempt is set, it can safely use t.GetPreempt()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preempt == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetPreempt() bool {
	if t == nil || t.Preempt == nil {
		return true
	}
	return *t.Preempt
}

// GetPreemptDelay retrieves the value of the leaf PreemptDelay from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreemptDelay is set, it can safely use t.GetPreemptDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreemptDelay == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetPreemptDelay() uint16 {
	if t == nil || t.PreemptDelay == nil {
		return 0
	}
	return *t.PreemptDelay
}

// GetPriority retrieves the value of the leaf Priority from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 100
	}
	return *t.Priority
}

// GetVirtualAddress retrieves the value of the leaf VirtualAddress from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualAddress is set, it can safely use t.GetVirtualAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetVirtualAddress() []string {
	if t == nil || t.VirtualAddress == nil {
		return nil
	}
	return t.VirtualAddress
}

// GetVirtualLinkLocal retrieves the value of the leaf VirtualLinkLocal from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualLinkLocal is set, it can safely use t.GetVirtualLinkLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualLinkLocal == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetVirtualLinkLocal() string {
	if t == nil || t.VirtualLinkLocal == nil {
		return ""
	}
	return *t.VirtualLinkLocal
}

// GetVirtualRouterId retrieves the value of the leaf VirtualRouterId from the Interface_Subinterface_Ipv6_Address_VrrpGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualRouterId is set, it can safely use t.GetVirtualRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualRouterId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) GetVirtualRouterId() uint8 {
	if t == nil || t.VirtualRouterId == nil {
		return 0
	}
	return *t.VirtualRouterId
}

// ΛListKeyMap returns the keys of the Interface_Subinterface_Ipv6_Address_VrrpGroup struct, which is a YANG list entry.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VirtualRouterId == nil {
		return nil, fmt.Errorf("nil value for key VirtualRouterId")
	}

	return map[string]interface{}{
		"virtual-router-id": *t.VirtualRouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Address_VrrpGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/addresses/address/vrrp/vrrp-group/interface-tracking YANG schema element.
type Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PriorityDecrement  *uint8            `path:"state/priority-decrement" shadow-path:"config/priority-decrement" module:"openconfig-if-ip"`
	ΛPriorityDecrement []ygot.Annotation `path:"state/@priority-decrement" ygotAnnotation:"true"`
	TrackInterface     []string          `path:"state/track-interface" shadow-path:"config/track-interface" module:"openconfig-if-ip"`
	ΛTrackInterface    []ygot.Annotation `path:"state/@track-interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking) IsYANGGoStruct() {}

// GetPriorityDecrement retrieves the value of the leaf PriorityDecrement from the Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PriorityDecrement is set, it can safely use t.GetPriorityDecrement()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PriorityDecrement == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking) GetPriorityDecrement() uint8 {
	if t == nil || t.PriorityDecrement == nil {
		return 0
	}
	return *t.PriorityDecrement
}

// GetTrackInterface retrieves the value of the leaf TrackInterface from the Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrackInterface is set, it can safely use t.GetTrackInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrackInterface == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking) GetTrackInterface() []string {
	if t == nil || t.TrackInterface == nil {
		return nil
	}
	return t.TrackInterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Address_VrrpGroup_InterfaceTracking) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Autoconf represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/autoconf YANG schema element.
type Interface_Subinterface_Ipv6_Autoconf struct {
	ΛMetadata                   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CreateGlobalAddresses       *bool             `path:"state/create-global-addresses" shadow-path:"config/create-global-addresses" module:"openconfig-if-ip-ext"`
	ΛCreateGlobalAddresses      []ygot.Annotation `path:"state/@create-global-addresses" ygotAnnotation:"true"`
	CreateTemporaryAddresses    *bool             `path:"state/create-temporary-addresses" shadow-path:"config/create-temporary-addresses" module:"openconfig-if-ip-ext"`
	ΛCreateTemporaryAddresses   []ygot.Annotation `path:"state/@create-temporary-addresses" ygotAnnotation:"true"`
	TemporaryPreferredLifetime  *uint32           `path:"state/temporary-preferred-lifetime" shadow-path:"config/temporary-preferred-lifetime" module:"openconfig-if-ip-ext"`
	ΛTemporaryPreferredLifetime []ygot.Annotation `path:"state/@temporary-preferred-lifetime" ygotAnnotation:"true"`
	TemporaryValidLifetime      *uint32           `path:"state/temporary-valid-lifetime" shadow-path:"config/temporary-valid-lifetime" module:"openconfig-if-ip-ext"`
	ΛTemporaryValidLifetime     []ygot.Annotation `path:"state/@temporary-valid-lifetime" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Autoconf implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Autoconf) IsYANGGoStruct() {}

// GetCreateGlobalAddresses retrieves the value of the leaf CreateGlobalAddresses from the Interface_Subinterface_Ipv6_Autoconf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CreateGlobalAddresses is set, it can safely use t.GetCreateGlobalAddresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CreateGlobalAddresses == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Autoconf) GetCreateGlobalAddresses() bool {
	if t == nil || t.CreateGlobalAddresses == nil {
		return true
	}
	return *t.CreateGlobalAddresses
}

// GetCreateTemporaryAddresses retrieves the value of the leaf CreateTemporaryAddresses from the Interface_Subinterface_Ipv6_Autoconf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CreateTemporaryAddresses is set, it can safely use t.GetCreateTemporaryAddresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CreateTemporaryAddresses == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Autoconf) GetCreateTemporaryAddresses() bool {
	if t == nil || t.CreateTemporaryAddresses == nil {
		return false
	}
	return *t.CreateTemporaryAddresses
}

// GetTemporaryPreferredLifetime retrieves the value of the leaf TemporaryPreferredLifetime from the Interface_Subinterface_Ipv6_Autoconf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TemporaryPreferredLifetime is set, it can safely use t.GetTemporaryPreferredLifetime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TemporaryPreferredLifetime == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Autoconf) GetTemporaryPreferredLifetime() uint32 {
	if t == nil || t.TemporaryPreferredLifetime == nil {
		return 86400
	}
	return *t.TemporaryPreferredLifetime
}

// GetTemporaryValidLifetime retrieves the value of the leaf TemporaryValidLifetime from the Interface_Subinterface_Ipv6_Autoconf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TemporaryValidLifetime is set, it can safely use t.GetTemporaryValidLifetime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TemporaryValidLifetime == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Autoconf) GetTemporaryValidLifetime() uint32 {
	if t == nil || t.TemporaryValidLifetime == nil {
		return 604800
	}
	return *t.TemporaryValidLifetime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Autoconf) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Autoconf"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Autoconf) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Counters represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/state/counters YANG schema element.
type Interface_Subinterface_Ipv6_Counters struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InDiscardedPkts     *uint64           `path:"in-discarded-pkts" module:"openconfig-if-ip"`
	ΛInDiscardedPkts    []ygot.Annotation `path:"@in-discarded-pkts" ygotAnnotation:"true"`
	InErrorPkts         *uint64           `path:"in-error-pkts" module:"openconfig-if-ip"`
	ΛInErrorPkts        []ygot.Annotation `path:"@in-error-pkts" ygotAnnotation:"true"`
	InForwardedOctets   *uint64           `path:"in-forwarded-octets" module:"openconfig-if-ip"`
	ΛInForwardedOctets  []ygot.Annotation `path:"@in-forwarded-octets" ygotAnnotation:"true"`
	InForwardedPkts     *uint64           `path:"in-forwarded-pkts" module:"openconfig-if-ip"`
	ΛInForwardedPkts    []ygot.Annotation `path:"@in-forwarded-pkts" ygotAnnotation:"true"`
	InOctets            *uint64           `path:"in-octets" module:"openconfig-if-ip"`
	ΛInOctets           []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts              *uint64           `path:"in-pkts" module:"openconfig-if-ip"`
	ΛInPkts             []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	OutDiscardedPkts    *uint64           `path:"out-discarded-pkts" module:"openconfig-if-ip"`
	ΛOutDiscardedPkts   []ygot.Annotation `path:"@out-discarded-pkts" ygotAnnotation:"true"`
	OutErrorPkts        *uint64           `path:"out-error-pkts" module:"openconfig-if-ip"`
	ΛOutErrorPkts       []ygot.Annotation `path:"@out-error-pkts" ygotAnnotation:"true"`
	OutForwardedOctets  *uint64           `path:"out-forwarded-octets" module:"openconfig-if-ip"`
	ΛOutForwardedOctets []ygot.Annotation `path:"@out-forwarded-octets" ygotAnnotation:"true"`
	OutForwardedPkts    *uint64           `path:"out-forwarded-pkts" module:"openconfig-if-ip"`
	ΛOutForwardedPkts   []ygot.Annotation `path:"@out-forwarded-pkts" ygotAnnotation:"true"`
	OutOctets           *uint64           `path:"out-octets" module:"openconfig-if-ip"`
	ΛOutOctets          []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts             *uint64           `path:"out-pkts" module:"openconfig-if-ip"`
	ΛOutPkts            []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Counters) IsYANGGoStruct() {}

// GetInDiscardedPkts retrieves the value of the leaf InDiscardedPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InDiscardedPkts is set, it can safely use t.GetInDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetInDiscardedPkts() uint64 {
	if t == nil || t.InDiscardedPkts == nil {
		return 0
	}
	return *t.InDiscardedPkts
}

// GetInErrorPkts retrieves the value of the leaf InErrorPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InErrorPkts is set, it can safely use t.GetInErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetInErrorPkts() uint64 {
	if t == nil || t.InErrorPkts == nil {
		return 0
	}
	return *t.InErrorPkts
}

// GetInForwardedOctets retrieves the value of the leaf InForwardedOctets from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedOctets is set, it can safely use t.GetInForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetInForwardedOctets() uint64 {
	if t == nil || t.InForwardedOctets == nil {
		return 0
	}
	return *t.InForwardedOctets
}

// GetInForwardedPkts retrieves the value of the leaf InForwardedPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InForwardedPkts is set, it can safely use t.GetInForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetInForwardedPkts() uint64 {
	if t == nil || t.InForwardedPkts == nil {
		return 0
	}
	return *t.InForwardedPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetOutDiscardedPkts retrieves the value of the leaf OutDiscardedPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutDiscardedPkts is set, it can safely use t.GetOutDiscardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutDiscardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetOutDiscardedPkts() uint64 {
	if t == nil || t.OutDiscardedPkts == nil {
		return 0
	}
	return *t.OutDiscardedPkts
}

// GetOutErrorPkts retrieves the value of the leaf OutErrorPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutErrorPkts is set, it can safely use t.GetOutErrorPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutErrorPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetOutErrorPkts() uint64 {
	if t == nil || t.OutErrorPkts == nil {
		return 0
	}
	return *t.OutErrorPkts
}

// GetOutForwardedOctets retrieves the value of the leaf OutForwardedOctets from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedOctets is set, it can safely use t.GetOutForwardedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetOutForwardedOctets() uint64 {
	if t == nil || t.OutForwardedOctets == nil {
		return 0
	}
	return *t.OutForwardedOctets
}

// GetOutForwardedPkts retrieves the value of the leaf OutForwardedPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutForwardedPkts is set, it can safely use t.GetOutForwardedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutForwardedPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetOutForwardedPkts() uint64 {
	if t == nil || t.OutForwardedPkts == nil {
		return 0
	}
	return *t.OutForwardedPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the Interface_Subinterface_Ipv6_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Neighbor represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/neighbors/neighbor YANG schema element.
type Interface_Subinterface_Ipv6_Neighbor struct {
	ΛMetadata         []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Ip                *string                         `path:"state/ip|ip" shadow-path:"config/ip" module:"openconfig-if-ip"`
	ΛIp               []ygot.Annotation               `path:"state/@ip|@ip" ygotAnnotation:"true"`
	IsRouter          *bool                           `path:"state/is-router" module:"openconfig-if-ip"`
	ΛIsRouter         []ygot.Annotation               `path:"state/@is-router" ygotAnnotation:"true"`
	LinkLayerAddress  *string                         `path:"state/link-layer-address" shadow-path:"config/link-layer-address" module:"openconfig-if-ip"`
	ΛLinkLayerAddress []ygot.Annotation               `path:"state/@link-layer-address" ygotAnnotation:"true"`
	NeighborState     E_Neighbor_NeighborState        `path:"state/neighbor-state" module:"openconfig-if-ip"`
	ΛNeighborState    []ygot.Annotation               `path:"state/@neighbor-state" ygotAnnotation:"true"`
	Origin            E_OpenconfigIfIp_NeighborOrigin `path:"state/origin" module:"openconfig-if-ip"`
	ΛOrigin           []ygot.Annotation               `path:"state/@origin" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Neighbor) IsYANGGoStruct() {}

// GetIp retrieves the value of the leaf Ip from the Interface_Subinterface_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ip is set, it can safely use t.GetIp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ip == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Neighbor) GetIp() string {
	if t == nil || t.Ip == nil {
		return ""
	}
	return *t.Ip
}

// GetIsRouter retrieves the value of the leaf IsRouter from the Interface_Subinterface_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IsRouter is set, it can safely use t.GetIsRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IsRouter == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Neighbor) GetIsRouter() bool {
	if t == nil || t.IsRouter == nil {
		return false
	}
	return *t.IsRouter
}

// GetLinkLayerAddress retrieves the value of the leaf LinkLayerAddress from the Interface_Subinterface_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLayerAddress is set, it can safely use t.GetLinkLayerAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLayerAddress == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Neighbor) GetLinkLayerAddress() string {
	if t == nil || t.LinkLayerAddress == nil {
		return ""
	}
	return *t.LinkLayerAddress
}

// GetNeighborState retrieves the value of the leaf NeighborState from the Interface_Subinterface_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborState is set, it can safely use t.GetNeighborState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborState == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Neighbor) GetNeighborState() E_Neighbor_NeighborState {
	if t == nil || t.NeighborState == 0 {
		return 0
	}
	return t.NeighborState
}

// GetOrigin retrieves the value of the leaf Origin from the Interface_Subinterface_Ipv6_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Neighbor) GetOrigin() E_OpenconfigIfIp_NeighborOrigin {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// ΛListKeyMap returns the keys of the Interface_Subinterface_Ipv6_Neighbor struct, which is a YANG list entry.
func (t *Interface_Subinterface_Ipv6_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Ip == nil {
		return nil, fmt.Errorf("nil value for key Ip")
	}

	return map[string]interface{}{
		"ip": *t.Ip,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_RouterAdvertisement represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/router-advertisement YANG schema element.
type Interface_Subinterface_Ipv6_RouterAdvertisement struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interval  *uint32           `path:"state/interval" shadow-path:"config/interval" module:"openconfig-if-ip"`
	ΛInterval []ygot.Annotation `path:"state/@interval" ygotAnnotation:"true"`
	Lifetime  *uint32           `path:"state/lifetime" shadow-path:"config/lifetime" module:"openconfig-if-ip"`
	ΛLifetime []ygot.Annotation `path:"state/@lifetime" ygotAnnotation:"true"`
	Suppress  *bool             `path:"state/suppress" shadow-path:"config/suppress" module:"openconfig-if-ip"`
	ΛSuppress []ygot.Annotation `path:"state/@suppress" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_RouterAdvertisement implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_RouterAdvertisement) IsYANGGoStruct() {}

// GetInterval retrieves the value of the leaf Interval from the Interface_Subinterface_Ipv6_RouterAdvertisement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_RouterAdvertisement) GetInterval() uint32 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetLifetime retrieves the value of the leaf Lifetime from the Interface_Subinterface_Ipv6_RouterAdvertisement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Lifetime is set, it can safely use t.GetLifetime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Lifetime == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_RouterAdvertisement) GetLifetime() uint32 {
	if t == nil || t.Lifetime == nil {
		return 0
	}
	return *t.Lifetime
}

// GetSuppress retrieves the value of the leaf Suppress from the Interface_Subinterface_Ipv6_RouterAdvertisement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Suppress is set, it can safely use t.GetSuppress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Suppress == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_RouterAdvertisement) GetSuppress() bool {
	if t == nil || t.Suppress == nil {
		return false
	}
	return *t.Suppress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_RouterAdvertisement) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_RouterAdvertisement"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_RouterAdvertisement) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Unnumbered represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/unnumbered YANG schema element.
type Interface_Subinterface_Ipv6_Unnumbered struct {
	ΛMetadata     []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	Enabled       *bool                                                `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-if-ip"`
	ΛEnabled      []ygot.Annotation                                    `path:"state/@enabled" ygotAnnotation:"true"`
	InterfaceRef  *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef `path:"interface-ref" module:"openconfig-if-ip"`
	ΛInterfaceRef []ygot.Annotation                                    `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Unnumbered implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Unnumbered) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Ipv6_Unnumbered) GetOrCreateInterfaceRef() *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from Interface_Subinterface_Ipv6_Unnumbered. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Ipv6_Unnumbered) GetInterfaceRef() *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Interface_Subinterface_Ipv6_Unnumbered
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Unnumbered) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Unnumbered) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Unnumbered"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Unnumbered) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/ipv6/unnumbered/interface-ref YANG schema element.
type Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-if-ip"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-if-ip"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Ipv6_Unnumbered_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan YANG schema element.
type Interface_Subinterface_Vlan struct {
	ΛMetadata       []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	EgressMapping   *Interface_Subinterface_Vlan_EgressMapping  `path:"egress-mapping" module:"openconfig-vlan"`
	ΛEgressMapping  []ygot.Annotation                           `path:"@egress-mapping" ygotAnnotation:"true"`
	IngressMapping  *Interface_Subinterface_Vlan_IngressMapping `path:"ingress-mapping" module:"openconfig-vlan"`
	ΛIngressMapping []ygot.Annotation                           `path:"@ingress-mapping" ygotAnnotation:"true"`
	Match           *Interface_Subinterface_Vlan_Match          `path:"match" module:"openconfig-vlan"`
	ΛMatch          []ygot.Annotation                           `path:"@match" ygotAnnotation:"true"`
	VlanId          Interface_Subinterface_Vlan_VlanId_Union    `path:"state/vlan-id" shadow-path:"config/vlan-id" module:"openconfig-vlan"`
	ΛVlanId         []ygot.Annotation                           `path:"state/@vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan) IsYANGGoStruct() {}

// GetOrCreateEgressMapping retrieves the value of the EgressMapping field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan) GetOrCreateEgressMapping() *Interface_Subinterface_Vlan_EgressMapping {
	if t.EgressMapping != nil {
		return t.EgressMapping
	}
	t.EgressMapping = &Interface_Subinterface_Vlan_EgressMapping{}
	return t.EgressMapping
}

// GetOrCreateIngressMapping retrieves the value of the IngressMapping field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan) GetOrCreateIngressMapping() *Interface_Subinterface_Vlan_IngressMapping {
	if t.IngressMapping != nil {
		return t.IngressMapping
	}
	t.IngressMapping = &Interface_Subinterface_Vlan_IngressMapping{}
	return t.IngressMapping
}

// GetOrCreateMatch retrieves the value of the Match field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan) GetOrCreateMatch() *Interface_Subinterface_Vlan_Match {
	if t.Match != nil {
		return t.Match
	}
	t.Match = &Interface_Subinterface_Vlan_Match{}
	return t.Match
}

// GetEgressMapping returns the value of the EgressMapping struct pointer
// from Interface_Subinterface_Vlan. If the receiver or the field EgressMapping is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan) GetEgressMapping() *Interface_Subinterface_Vlan_EgressMapping {
	if t != nil && t.EgressMapping != nil {
		return t.EgressMapping
	}
	return nil
}

// GetIngressMapping returns the value of the IngressMapping struct pointer
// from Interface_Subinterface_Vlan. If the receiver or the field IngressMapping is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan) GetIngressMapping() *Interface_Subinterface_Vlan_IngressMapping {
	if t != nil && t.IngressMapping != nil {
		return t.IngressMapping
	}
	return nil
}

// GetMatch returns the value of the Match struct pointer
// from Interface_Subinterface_Vlan. If the receiver or the field Match is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan) GetMatch() *Interface_Subinterface_Vlan_Match {
	if t != nil && t.Match != nil {
		return t.Match
	}
	return nil
}

// GetVlanId retrieves the value of the leaf VlanId from the Interface_Subinterface_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanId is set, it can safely use t.GetVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan) GetVlanId() Interface_Subinterface_Vlan_VlanId_Union {
	if t == nil || t.VlanId == nil {
		return nil
	}
	return t.VlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Interface_Subinterface_Vlan_VlanId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/state/vlan-id within the YANG schema.
// Union type can be one of [UnionString, UnionUint16].
type Interface_Subinterface_Vlan_VlanId_Union interface {
	// Union type can be one of [UnionString, UnionUint16]
	Documentation_for_Interface_Subinterface_Vlan_VlanId_Union()
}

// Documentation_for_Interface_Subinterface_Vlan_VlanId_Union ensures that UnionString
// implements the Interface_Subinterface_Vlan_VlanId_Union interface.
func (UnionString) Documentation_for_Interface_Subinterface_Vlan_VlanId_Union() {}

// Documentation_for_Interface_Subinterface_Vlan_VlanId_Union ensures that UnionUint16
// implements the Interface_Subinterface_Vlan_VlanId_Union interface.
func (UnionUint16) Documentation_for_Interface_Subinterface_Vlan_VlanId_Union() {}

// To_Interface_Subinterface_Vlan_VlanId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Interface_Subinterface_Vlan_VlanId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Interface_Subinterface_Vlan) To_Interface_Subinterface_Vlan_VlanId_Union(i interface{}) (Interface_Subinterface_Vlan_VlanId_Union, error) {
	if v, ok := i.(Interface_Subinterface_Vlan_VlanId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Interface_Subinterface_Vlan_VlanId_Union, unknown union type, got: %T, want any of [string, uint16]", i, i)
}

// Interface_Subinterface_Vlan_EgressMapping represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/egress-mapping YANG schema element.
type Interface_Subinterface_Vlan_EgressMapping struct {
	ΛMetadata        []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	Tpid             E_OpenconfigVlanTypes_TPID_TYPES      `path:"state/tpid" shadow-path:"config/tpid" module:"openconfig-vlan"`
	ΛTpid            []ygot.Annotation                     `path:"state/@tpid" ygotAnnotation:"true"`
	VlanId           *uint16                               `path:"state/vlan-id" shadow-path:"config/vlan-id" module:"openconfig-vlan"`
	ΛVlanId          []ygot.Annotation                     `path:"state/@vlan-id" ygotAnnotation:"true"`
	VlanStackAction  E_OpenconfigVlanTypes_VlanStackAction `path:"state/vlan-stack-action" shadow-path:"config/vlan-stack-action" module:"openconfig-vlan"`
	ΛVlanStackAction []ygot.Annotation                     `path:"state/@vlan-stack-action" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_EgressMapping implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_EgressMapping) IsYANGGoStruct() {}

// GetTpid retrieves the value of the leaf Tpid from the Interface_Subinterface_Vlan_EgressMapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tpid is set, it can safely use t.GetTpid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tpid == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_EgressMapping) GetTpid() E_OpenconfigVlanTypes_TPID_TYPES {
	if t == nil || t.Tpid == 0 {
		return 0
	}
	return t.Tpid
}

// GetVlanId retrieves the value of the leaf VlanId from the Interface_Subinterface_Vlan_EgressMapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanId is set, it can safely use t.GetVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_EgressMapping) GetVlanId() uint16 {
	if t == nil || t.VlanId == nil {
		return 0
	}
	return *t.VlanId
}

// GetVlanStackAction retrieves the value of the leaf VlanStackAction from the Interface_Subinterface_Vlan_EgressMapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanStackAction is set, it can safely use t.GetVlanStackAction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanStackAction == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_EgressMapping) GetVlanStackAction() E_OpenconfigVlanTypes_VlanStackAction {
	if t == nil || t.VlanStackAction == 0 {
		return 0
	}
	return t.VlanStackAction
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_EgressMapping) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_EgressMapping"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_EgressMapping) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_IngressMapping represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/ingress-mapping YANG schema element.
type Interface_Subinterface_Vlan_IngressMapping struct {
	ΛMetadata        []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	Tpid             E_OpenconfigVlanTypes_TPID_TYPES      `path:"state/tpid" shadow-path:"config/tpid" module:"openconfig-vlan"`
	ΛTpid            []ygot.Annotation                     `path:"state/@tpid" ygotAnnotation:"true"`
	VlanId           *uint16                               `path:"state/vlan-id" shadow-path:"config/vlan-id" module:"openconfig-vlan"`
	ΛVlanId          []ygot.Annotation                     `path:"state/@vlan-id" ygotAnnotation:"true"`
	VlanStackAction  E_OpenconfigVlanTypes_VlanStackAction `path:"state/vlan-stack-action" shadow-path:"config/vlan-stack-action" module:"openconfig-vlan"`
	ΛVlanStackAction []ygot.Annotation                     `path:"state/@vlan-stack-action" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_IngressMapping implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_IngressMapping) IsYANGGoStruct() {}

// GetTpid retrieves the value of the leaf Tpid from the Interface_Subinterface_Vlan_IngressMapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tpid is set, it can safely use t.GetTpid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tpid == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_IngressMapping) GetTpid() E_OpenconfigVlanTypes_TPID_TYPES {
	if t == nil || t.Tpid == 0 {
		return 0
	}
	return t.Tpid
}

// GetVlanId retrieves the value of the leaf VlanId from the Interface_Subinterface_Vlan_IngressMapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanId is set, it can safely use t.GetVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_IngressMapping) GetVlanId() uint16 {
	if t == nil || t.VlanId == nil {
		return 0
	}
	return *t.VlanId
}

// GetVlanStackAction retrieves the value of the leaf VlanStackAction from the Interface_Subinterface_Vlan_IngressMapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanStackAction is set, it can safely use t.GetVlanStackAction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanStackAction == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_IngressMapping) GetVlanStackAction() E_OpenconfigVlanTypes_VlanStackAction {
	if t == nil || t.VlanStackAction == 0 {
		return 0
	}
	return t.VlanStackAction
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_IngressMapping) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_IngressMapping"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_IngressMapping) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match YANG schema element.
type Interface_Subinterface_Vlan_Match struct {
	ΛMetadata                    []ygot.Annotation                                              `path:"@" ygotAnnotation:"true"`
	DoubleTagged                 *Interface_Subinterface_Vlan_Match_DoubleTagged                `path:"double-tagged" module:"openconfig-vlan"`
	ΛDoubleTagged                []ygot.Annotation                                              `path:"@double-tagged" ygotAnnotation:"true"`
	DoubleTaggedInnerList        *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList       `path:"double-tagged-inner-list" module:"openconfig-vlan"`
	ΛDoubleTaggedInnerList       []ygot.Annotation                                              `path:"@double-tagged-inner-list" ygotAnnotation:"true"`
	DoubleTaggedInnerOuterRange  *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange `path:"double-tagged-inner-outer-range" module:"openconfig-vlan"`
	ΛDoubleTaggedInnerOuterRange []ygot.Annotation                                              `path:"@double-tagged-inner-outer-range" ygotAnnotation:"true"`
	DoubleTaggedInnerRange       *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange      `path:"double-tagged-inner-range" module:"openconfig-vlan"`
	ΛDoubleTaggedInnerRange      []ygot.Annotation                                              `path:"@double-tagged-inner-range" ygotAnnotation:"true"`
	DoubleTaggedOuterList        *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList       `path:"double-tagged-outer-list" module:"openconfig-vlan"`
	ΛDoubleTaggedOuterList       []ygot.Annotation                                              `path:"@double-tagged-outer-list" ygotAnnotation:"true"`
	DoubleTaggedOuterRange       *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange      `path:"double-tagged-outer-range" module:"openconfig-vlan"`
	ΛDoubleTaggedOuterRange      []ygot.Annotation                                              `path:"@double-tagged-outer-range" ygotAnnotation:"true"`
	SingleTagged                 *Interface_Subinterface_Vlan_Match_SingleTagged                `path:"single-tagged" module:"openconfig-vlan"`
	ΛSingleTagged                []ygot.Annotation                                              `path:"@single-tagged" ygotAnnotation:"true"`
	SingleTaggedList             *Interface_Subinterface_Vlan_Match_SingleTaggedList            `path:"single-tagged-list" module:"openconfig-vlan"`
	ΛSingleTaggedList            []ygot.Annotation                                              `path:"@single-tagged-list" ygotAnnotation:"true"`
	SingleTaggedRange            *Interface_Subinterface_Vlan_Match_SingleTaggedRange           `path:"single-tagged-range" module:"openconfig-vlan"`
	ΛSingleTaggedRange           []ygot.Annotation                                              `path:"@single-tagged-range" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match) IsYANGGoStruct() {}

// GetOrCreateDoubleTagged retrieves the value of the DoubleTagged field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateDoubleTagged() *Interface_Subinterface_Vlan_Match_DoubleTagged {
	if t.DoubleTagged != nil {
		return t.DoubleTagged
	}
	t.DoubleTagged = &Interface_Subinterface_Vlan_Match_DoubleTagged{}
	return t.DoubleTagged
}

// GetOrCreateDoubleTaggedInnerList retrieves the value of the DoubleTaggedInnerList field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateDoubleTaggedInnerList() *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList {
	if t.DoubleTaggedInnerList != nil {
		return t.DoubleTaggedInnerList
	}
	t.DoubleTaggedInnerList = &Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList{}
	return t.DoubleTaggedInnerList
}

// GetOrCreateDoubleTaggedInnerOuterRange retrieves the value of the DoubleTaggedInnerOuterRange field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateDoubleTaggedInnerOuterRange() *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange {
	if t.DoubleTaggedInnerOuterRange != nil {
		return t.DoubleTaggedInnerOuterRange
	}
	t.DoubleTaggedInnerOuterRange = &Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange{}
	return t.DoubleTaggedInnerOuterRange
}

// GetOrCreateDoubleTaggedInnerRange retrieves the value of the DoubleTaggedInnerRange field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateDoubleTaggedInnerRange() *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange {
	if t.DoubleTaggedInnerRange != nil {
		return t.DoubleTaggedInnerRange
	}
	t.DoubleTaggedInnerRange = &Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange{}
	return t.DoubleTaggedInnerRange
}

// GetOrCreateDoubleTaggedOuterList retrieves the value of the DoubleTaggedOuterList field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateDoubleTaggedOuterList() *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList {
	if t.DoubleTaggedOuterList != nil {
		return t.DoubleTaggedOuterList
	}
	t.DoubleTaggedOuterList = &Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList{}
	return t.DoubleTaggedOuterList
}

// GetOrCreateDoubleTaggedOuterRange retrieves the value of the DoubleTaggedOuterRange field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateDoubleTaggedOuterRange() *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange {
	if t.DoubleTaggedOuterRange != nil {
		return t.DoubleTaggedOuterRange
	}
	t.DoubleTaggedOuterRange = &Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange{}
	return t.DoubleTaggedOuterRange
}

// GetOrCreateSingleTagged retrieves the value of the SingleTagged field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateSingleTagged() *Interface_Subinterface_Vlan_Match_SingleTagged {
	if t.SingleTagged != nil {
		return t.SingleTagged
	}
	t.SingleTagged = &Interface_Subinterface_Vlan_Match_SingleTagged{}
	return t.SingleTagged
}

// GetOrCreateSingleTaggedList retrieves the value of the SingleTaggedList field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateSingleTaggedList() *Interface_Subinterface_Vlan_Match_SingleTaggedList {
	if t.SingleTaggedList != nil {
		return t.SingleTaggedList
	}
	t.SingleTaggedList = &Interface_Subinterface_Vlan_Match_SingleTaggedList{}
	return t.SingleTaggedList
}

// GetOrCreateSingleTaggedRange retrieves the value of the SingleTaggedRange field
// or returns the existing field if it already exists.
func (t *Interface_Subinterface_Vlan_Match) GetOrCreateSingleTaggedRange() *Interface_Subinterface_Vlan_Match_SingleTaggedRange {
	if t.SingleTaggedRange != nil {
		return t.SingleTaggedRange
	}
	t.SingleTaggedRange = &Interface_Subinterface_Vlan_Match_SingleTaggedRange{}
	return t.SingleTaggedRange
}

// GetDoubleTagged returns the value of the DoubleTagged struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field DoubleTagged is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetDoubleTagged() *Interface_Subinterface_Vlan_Match_DoubleTagged {
	if t != nil && t.DoubleTagged != nil {
		return t.DoubleTagged
	}
	return nil
}

// GetDoubleTaggedInnerList returns the value of the DoubleTaggedInnerList struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field DoubleTaggedInnerList is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetDoubleTaggedInnerList() *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList {
	if t != nil && t.DoubleTaggedInnerList != nil {
		return t.DoubleTaggedInnerList
	}
	return nil
}

// GetDoubleTaggedInnerOuterRange returns the value of the DoubleTaggedInnerOuterRange struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field DoubleTaggedInnerOuterRange is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetDoubleTaggedInnerOuterRange() *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange {
	if t != nil && t.DoubleTaggedInnerOuterRange != nil {
		return t.DoubleTaggedInnerOuterRange
	}
	return nil
}

// GetDoubleTaggedInnerRange returns the value of the DoubleTaggedInnerRange struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field DoubleTaggedInnerRange is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetDoubleTaggedInnerRange() *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange {
	if t != nil && t.DoubleTaggedInnerRange != nil {
		return t.DoubleTaggedInnerRange
	}
	return nil
}

// GetDoubleTaggedOuterList returns the value of the DoubleTaggedOuterList struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field DoubleTaggedOuterList is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetDoubleTaggedOuterList() *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList {
	if t != nil && t.DoubleTaggedOuterList != nil {
		return t.DoubleTaggedOuterList
	}
	return nil
}

// GetDoubleTaggedOuterRange returns the value of the DoubleTaggedOuterRange struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field DoubleTaggedOuterRange is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetDoubleTaggedOuterRange() *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange {
	if t != nil && t.DoubleTaggedOuterRange != nil {
		return t.DoubleTaggedOuterRange
	}
	return nil
}

// GetSingleTagged returns the value of the SingleTagged struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field SingleTagged is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetSingleTagged() *Interface_Subinterface_Vlan_Match_SingleTagged {
	if t != nil && t.SingleTagged != nil {
		return t.SingleTagged
	}
	return nil
}

// GetSingleTaggedList returns the value of the SingleTaggedList struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field SingleTaggedList is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetSingleTaggedList() *Interface_Subinterface_Vlan_Match_SingleTaggedList {
	if t != nil && t.SingleTaggedList != nil {
		return t.SingleTaggedList
	}
	return nil
}

// GetSingleTaggedRange returns the value of the SingleTaggedRange struct pointer
// from Interface_Subinterface_Vlan_Match. If the receiver or the field SingleTaggedRange is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Interface_Subinterface_Vlan_Match) GetSingleTaggedRange() *Interface_Subinterface_Vlan_Match_SingleTaggedRange {
	if t != nil && t.SingleTaggedRange != nil {
		return t.SingleTaggedRange
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_DoubleTagged represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/double-tagged YANG schema element.
type Interface_Subinterface_Vlan_Match_DoubleTagged struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InnerVlanId  *uint16           `path:"state/inner-vlan-id" shadow-path:"config/inner-vlan-id" module:"openconfig-vlan"`
	ΛInnerVlanId []ygot.Annotation `path:"state/@inner-vlan-id" ygotAnnotation:"true"`
	OuterVlanId  *uint16           `path:"state/outer-vlan-id" shadow-path:"config/outer-vlan-id" module:"openconfig-vlan"`
	ΛOuterVlanId []ygot.Annotation `path:"state/@outer-vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_DoubleTagged implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_DoubleTagged) IsYANGGoStruct() {}

// GetInnerVlanId retrieves the value of the leaf InnerVlanId from the Interface_Subinterface_Vlan_Match_DoubleTagged
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerVlanId is set, it can safely use t.GetInnerVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTagged) GetInnerVlanId() uint16 {
	if t == nil || t.InnerVlanId == nil {
		return 0
	}
	return *t.InnerVlanId
}

// GetOuterVlanId retrieves the value of the leaf OuterVlanId from the Interface_Subinterface_Vlan_Match_DoubleTagged
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterVlanId is set, it can safely use t.GetOuterVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTagged) GetOuterVlanId() uint16 {
	if t == nil || t.OuterVlanId == nil {
		return 0
	}
	return *t.OuterVlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_DoubleTagged) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_DoubleTagged"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_DoubleTagged) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/double-tagged-inner-list YANG schema element.
type Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InnerVlanIds  []uint16          `path:"state/inner-vlan-ids" shadow-path:"config/inner-vlan-ids" module:"openconfig-vlan"`
	ΛInnerVlanIds []ygot.Annotation `path:"state/@inner-vlan-ids" ygotAnnotation:"true"`
	OuterVlanId   *uint16           `path:"state/outer-vlan-id" shadow-path:"config/outer-vlan-id" module:"openconfig-vlan"`
	ΛOuterVlanId  []ygot.Annotation `path:"state/@outer-vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList) IsYANGGoStruct() {}

// GetInnerVlanIds retrieves the value of the leaf InnerVlanIds from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerVlanIds is set, it can safely use t.GetInnerVlanIds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerVlanIds == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList) GetInnerVlanIds() []uint16 {
	if t == nil || t.InnerVlanIds == nil {
		return nil
	}
	return t.InnerVlanIds
}

// GetOuterVlanId retrieves the value of the leaf OuterVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterVlanId is set, it can safely use t.GetOuterVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList) GetOuterVlanId() uint16 {
	if t == nil || t.OuterVlanId == nil {
		return 0
	}
	return *t.OuterVlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/double-tagged-inner-outer-range YANG schema element.
type Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InnerHighVlanId  *uint16           `path:"state/inner-high-vlan-id" shadow-path:"config/inner-high-vlan-id" module:"openconfig-vlan"`
	ΛInnerHighVlanId []ygot.Annotation `path:"state/@inner-high-vlan-id" ygotAnnotation:"true"`
	InnerLowVlanId   *uint16           `path:"state/inner-low-vlan-id" shadow-path:"config/inner-low-vlan-id" module:"openconfig-vlan"`
	ΛInnerLowVlanId  []ygot.Annotation `path:"state/@inner-low-vlan-id" ygotAnnotation:"true"`
	OuterHighVlanId  *uint16           `path:"state/outer-high-vlan-id" shadow-path:"config/outer-high-vlan-id" module:"openconfig-vlan"`
	ΛOuterHighVlanId []ygot.Annotation `path:"state/@outer-high-vlan-id" ygotAnnotation:"true"`
	OuterLowVlanId   *uint16           `path:"state/outer-low-vlan-id" shadow-path:"config/outer-low-vlan-id" module:"openconfig-vlan"`
	ΛOuterLowVlanId  []ygot.Annotation `path:"state/@outer-low-vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) IsYANGGoStruct() {}

// GetInnerHighVlanId retrieves the value of the leaf InnerHighVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerHighVlanId is set, it can safely use t.GetInnerHighVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerHighVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) GetInnerHighVlanId() uint16 {
	if t == nil || t.InnerHighVlanId == nil {
		return 0
	}
	return *t.InnerHighVlanId
}

// GetInnerLowVlanId retrieves the value of the leaf InnerLowVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerLowVlanId is set, it can safely use t.GetInnerLowVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerLowVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) GetInnerLowVlanId() uint16 {
	if t == nil || t.InnerLowVlanId == nil {
		return 0
	}
	return *t.InnerLowVlanId
}

// GetOuterHighVlanId retrieves the value of the leaf OuterHighVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterHighVlanId is set, it can safely use t.GetOuterHighVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterHighVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) GetOuterHighVlanId() uint16 {
	if t == nil || t.OuterHighVlanId == nil {
		return 0
	}
	return *t.OuterHighVlanId
}

// GetOuterLowVlanId retrieves the value of the leaf OuterLowVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterLowVlanId is set, it can safely use t.GetOuterLowVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterLowVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) GetOuterLowVlanId() uint16 {
	if t == nil || t.OuterLowVlanId == nil {
		return 0
	}
	return *t.OuterLowVlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerOuterRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/double-tagged-inner-range YANG schema element.
type Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InnerHighVlanId  *uint16           `path:"state/inner-high-vlan-id" shadow-path:"config/inner-high-vlan-id" module:"openconfig-vlan"`
	ΛInnerHighVlanId []ygot.Annotation `path:"state/@inner-high-vlan-id" ygotAnnotation:"true"`
	InnerLowVlanId   *uint16           `path:"state/inner-low-vlan-id" shadow-path:"config/inner-low-vlan-id" module:"openconfig-vlan"`
	ΛInnerLowVlanId  []ygot.Annotation `path:"state/@inner-low-vlan-id" ygotAnnotation:"true"`
	OuterVlanId      []uint16          `path:"state/outer-vlan-id" shadow-path:"config/outer-vlan-id" module:"openconfig-vlan"`
	ΛOuterVlanId     []ygot.Annotation `path:"state/@outer-vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange) IsYANGGoStruct() {}

// GetInnerHighVlanId retrieves the value of the leaf InnerHighVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerHighVlanId is set, it can safely use t.GetInnerHighVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerHighVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange) GetInnerHighVlanId() uint16 {
	if t == nil || t.InnerHighVlanId == nil {
		return 0
	}
	return *t.InnerHighVlanId
}

// GetInnerLowVlanId retrieves the value of the leaf InnerLowVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerLowVlanId is set, it can safely use t.GetInnerLowVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerLowVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange) GetInnerLowVlanId() uint16 {
	if t == nil || t.InnerLowVlanId == nil {
		return 0
	}
	return *t.InnerLowVlanId
}

// GetOuterVlanId retrieves the value of the leaf OuterVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterVlanId is set, it can safely use t.GetOuterVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange) GetOuterVlanId() []uint16 {
	if t == nil || t.OuterVlanId == nil {
		return nil
	}
	return t.OuterVlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedInnerRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/double-tagged-outer-list YANG schema element.
type Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InnerVlanId   *uint16           `path:"state/inner-vlan-id" shadow-path:"config/inner-vlan-id" module:"openconfig-vlan"`
	ΛInnerVlanId  []ygot.Annotation `path:"state/@inner-vlan-id" ygotAnnotation:"true"`
	OuterVlanIds  []uint16          `path:"state/outer-vlan-ids" shadow-path:"config/outer-vlan-ids" module:"openconfig-vlan"`
	ΛOuterVlanIds []ygot.Annotation `path:"state/@outer-vlan-ids" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList) IsYANGGoStruct() {}

// GetInnerVlanId retrieves the value of the leaf InnerVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerVlanId is set, it can safely use t.GetInnerVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList) GetInnerVlanId() uint16 {
	if t == nil || t.InnerVlanId == nil {
		return 0
	}
	return *t.InnerVlanId
}

// GetOuterVlanIds retrieves the value of the leaf OuterVlanIds from the Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterVlanIds is set, it can safely use t.GetOuterVlanIds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterVlanIds == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList) GetOuterVlanIds() []uint16 {
	if t == nil || t.OuterVlanIds == nil {
		return nil
	}
	return t.OuterVlanIds
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/double-tagged-outer-range YANG schema element.
type Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InnerVlanId      *uint16           `path:"state/inner-vlan-id" shadow-path:"config/inner-vlan-id" module:"openconfig-vlan"`
	ΛInnerVlanId     []ygot.Annotation `path:"state/@inner-vlan-id" ygotAnnotation:"true"`
	OuterHighVlanId  *uint16           `path:"state/outer-high-vlan-id" shadow-path:"config/outer-high-vlan-id" module:"openconfig-vlan"`
	ΛOuterHighVlanId []ygot.Annotation `path:"state/@outer-high-vlan-id" ygotAnnotation:"true"`
	OuterLowVlanId   *uint16           `path:"state/outer-low-vlan-id" shadow-path:"config/outer-low-vlan-id" module:"openconfig-vlan"`
	ΛOuterLowVlanId  []ygot.Annotation `path:"state/@outer-low-vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange) IsYANGGoStruct() {}

// GetInnerVlanId retrieves the value of the leaf InnerVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InnerVlanId is set, it can safely use t.GetInnerVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InnerVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange) GetInnerVlanId() uint16 {
	if t == nil || t.InnerVlanId == nil {
		return 0
	}
	return *t.InnerVlanId
}

// GetOuterHighVlanId retrieves the value of the leaf OuterHighVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterHighVlanId is set, it can safely use t.GetOuterHighVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterHighVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange) GetOuterHighVlanId() uint16 {
	if t == nil || t.OuterHighVlanId == nil {
		return 0
	}
	return *t.OuterHighVlanId
}

// GetOuterLowVlanId retrieves the value of the leaf OuterLowVlanId from the Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuterLowVlanId is set, it can safely use t.GetOuterLowVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuterLowVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange) GetOuterLowVlanId() uint16 {
	if t == nil || t.OuterLowVlanId == nil {
		return 0
	}
	return *t.OuterLowVlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_DoubleTaggedOuterRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_SingleTagged represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/single-tagged YANG schema element.
type Interface_Subinterface_Vlan_Match_SingleTagged struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	VlanId    *uint16           `path:"state/vlan-id" shadow-path:"config/vlan-id" module:"openconfig-vlan"`
	ΛVlanId   []ygot.Annotation `path:"state/@vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_SingleTagged implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_SingleTagged) IsYANGGoStruct() {}

// GetVlanId retrieves the value of the leaf VlanId from the Interface_Subinterface_Vlan_Match_SingleTagged
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanId is set, it can safely use t.GetVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_SingleTagged) GetVlanId() uint16 {
	if t == nil || t.VlanId == nil {
		return 0
	}
	return *t.VlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_SingleTagged) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_SingleTagged"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_SingleTagged) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_SingleTaggedList represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/single-tagged-list YANG schema element.
type Interface_Subinterface_Vlan_Match_SingleTaggedList struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	VlanIds   []uint16          `path:"state/vlan-ids" shadow-path:"config/vlan-ids" module:"openconfig-vlan"`
	ΛVlanIds  []ygot.Annotation `path:"state/@vlan-ids" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_SingleTaggedList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_SingleTaggedList) IsYANGGoStruct() {}

// GetVlanIds retrieves the value of the leaf VlanIds from the Interface_Subinterface_Vlan_Match_SingleTaggedList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanIds is set, it can safely use t.GetVlanIds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanIds == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedList) GetVlanIds() []uint16 {
	if t == nil || t.VlanIds == nil {
		return nil
	}
	return t.VlanIds
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_SingleTaggedList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Interface_Subinterface_Vlan_Match_SingleTaggedRange represents the /openconfig-interfaces/interfaces/interface/subinterfaces/subinterface/vlan/match/single-tagged-range YANG schema element.
type Interface_Subinterface_Vlan_Match_SingleTaggedRange struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	HighVlanId  *uint16           `path:"state/high-vlan-id" shadow-path:"config/high-vlan-id" module:"openconfig-vlan"`
	ΛHighVlanId []ygot.Annotation `path:"state/@high-vlan-id" ygotAnnotation:"true"`
	LowVlanId   *uint16           `path:"state/low-vlan-id" shadow-path:"config/low-vlan-id" module:"openconfig-vlan"`
	ΛLowVlanId  []ygot.Annotation `path:"state/@low-vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Interface_Subinterface_Vlan_Match_SingleTaggedRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Interface_Subinterface_Vlan_Match_SingleTaggedRange) IsYANGGoStruct() {}

// GetHighVlanId retrieves the value of the leaf HighVlanId from the Interface_Subinterface_Vlan_Match_SingleTaggedRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HighVlanId is set, it can safely use t.GetHighVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HighVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedRange) GetHighVlanId() uint16 {
	if t == nil || t.HighVlanId == nil {
		return 0
	}
	return *t.HighVlanId
}

// GetLowVlanId retrieves the value of the leaf LowVlanId from the Interface_Subinterface_Vlan_Match_SingleTaggedRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LowVlanId is set, it can safely use t.GetLowVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LowVlanId == nil'
// before retrieving the leaf's value.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedRange) GetLowVlanId() uint16 {
	if t == nil || t.LowVlanId == nil {
		return 0
	}
	return *t.LowVlanId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Interface_Subinterface_Vlan_Match_SingleTaggedRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Interface_Subinterface_Vlan_Match_SingleTaggedRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Lacp represents the /openconfig-lacp/lacp YANG schema element.
type Lacp struct {
	ΛMetadata       []ygot.Annotation          `path:"@" ygotAnnotation:"true"`
	Interface       map[string]*Lacp_Interface `path:"interfaces/interface" module:"openconfig-lacp"`
	ΛInterface      []ygot.Annotation          `path:"interfaces/@interface" ygotAnnotation:"true"`
	SystemPriority  *uint16                    `path:"state/system-priority" shadow-path:"config/system-priority" module:"openconfig-lacp"`
	ΛSystemPriority []ygot.Annotation          `path:"state/@system-priority" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lacp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lacp) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// Lacp struct. The keys of the list are populated from the input
// arguments.
func (t *Lacp) NewInterface(Name string) (*Lacp_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Lacp_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Lacp_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Lacp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Lacp) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Lacp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Lacp) GetOrCreateInterface(Name string) *Lacp_Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Lacp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Lacp) GetInterface(Name string) *Lacp_Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Lacp_Interface struct to the
// list Interface of Lacp. If the key value(s) specified in
// the supplied Lacp_Interface already exist in the list, an error is
// returned.
func (t *Lacp) AppendInterface(v *Lacp_Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Lacp_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetSystemPriority retrieves the value of the leaf SystemPriority from the Lacp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemPriority is set, it can safely use t.GetSystemPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemPriority == nil'
// before retrieving the leaf's value.
func (t *Lacp) GetSystemPriority() uint16 {
	if t == nil || t.SystemPriority == nil {
		return 0
	}
	return *t.SystemPriority
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lacp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lacp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lacp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lacp_Interface represents the /openconfig-lacp/lacp/interfaces/interface YANG schema element.
type Lacp_Interface struct {
	ΛMetadata       []ygot.Annotation                 `path:"@" ygotAnnotation:"true"`
	Interval        E_OpenconfigLacp_LacpPeriodType   `path:"state/interval" shadow-path:"config/interval" module:"openconfig-lacp"`
	ΛInterval       []ygot.Annotation                 `path:"state/@interval" ygotAnnotation:"true"`
	LacpMode        E_OpenconfigLacp_LacpActivityType `path:"state/lacp-mode" shadow-path:"config/lacp-mode" module:"openconfig-lacp"`
	ΛLacpMode       []ygot.Annotation                 `path:"state/@lacp-mode" ygotAnnotation:"true"`
	Member          map[string]*Lacp_Interface_Member `path:"members/member" module:"openconfig-lacp"`
	ΛMember         []ygot.Annotation                 `path:"members/@member" ygotAnnotation:"true"`
	Name            *string                           `path:"state/name|name" shadow-path:"config/name" module:"openconfig-lacp"`
	ΛName           []ygot.Annotation                 `path:"state/@name|@name" ygotAnnotation:"true"`
	SystemIdMac     *string                           `path:"state/system-id-mac" shadow-path:"config/system-id-mac" module:"openconfig-lacp"`
	ΛSystemIdMac    []ygot.Annotation                 `path:"state/@system-id-mac" ygotAnnotation:"true"`
	SystemPriority  *uint16                           `path:"state/system-priority" shadow-path:"config/system-priority" module:"openconfig-lacp"`
	ΛSystemPriority []ygot.Annotation                 `path:"state/@system-priority" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lacp_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lacp_Interface) IsYANGGoStruct() {}

// NewMember creates a new entry in the Member list of the
// Lacp_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *Lacp_Interface) NewMember(Interface string) (*Lacp_Interface_Member, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Member == nil {
		t.Member = make(map[string]*Lacp_Interface_Member)
	}

	key := Interface

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Member[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Member", key)
	}

	t.Member[key] = &Lacp_Interface_Member{
		Interface: &Interface,
	}

	return t.Member[key], nil
}

// RenameMember renames an entry in the list Member within
// the Lacp_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Lacp_Interface) RenameMember(oldK, newK string) error {
	if _, ok := t.Member[newK]; ok {
		return fmt.Errorf("key %v already exists in Member", newK)
	}

	e, ok := t.Member[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Member", oldK)
	}
	e.Interface = &newK

	t.Member[newK] = e
	delete(t.Member, oldK)
	return nil
}

// GetOrCreateMember retrieves the value with the specified keys from
// the receiver Lacp_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Lacp_Interface) GetOrCreateMember(Interface string) *Lacp_Interface_Member {

	key := Interface

	if v, ok := t.Member[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewMember(Interface)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateMember got unexpected error: %v", err))
	}
	return v
}

// GetMember retrieves the value with the specified key from
// the Member map field of Lacp_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Lacp_Interface) GetMember(Interface string) *Lacp_Interface_Member {

	if t == nil {
		return nil
	}

	key := Interface

	if lm, ok := t.Member[key]; ok {
		return lm
	}
	return nil
}

// AppendMember appends the supplied Lacp_Interface_Member struct to the
// list Member of Lacp_Interface. If the key value(s) specified in
// the supplied Lacp_Interface_Member already exist in the list, an error is
// returned.
func (t *Lacp_Interface) AppendMember(v *Lacp_Interface_Member) error {
	if v.Interface == nil {
		return fmt.Errorf("invalid nil key received for Interface")
	}

	key := *v.Interface

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Member == nil {
		t.Member = make(map[string]*Lacp_Interface_Member)
	}

	if _, ok := t.Member[key]; ok {
		return fmt.Errorf("duplicate key for list Member %v", key)
	}

	t.Member[key] = v
	return nil
}

// GetInterval retrieves the value of the leaf Interval from the Lacp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface) GetInterval() E_OpenconfigLacp_LacpPeriodType {
	if t == nil || t.Interval == 0 {
		return OpenconfigLacp_LacpPeriodType_SLOW
	}
	return t.Interval
}

// GetLacpMode retrieves the value of the leaf LacpMode from the Lacp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpMode is set, it can safely use t.GetLacpMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpMode == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface) GetLacpMode() E_OpenconfigLacp_LacpActivityType {
	if t == nil || t.LacpMode == 0 {
		return OpenconfigLacp_LacpActivityType_ACTIVE
	}
	return t.LacpMode
}

// GetName retrieves the value of the leaf Name from the Lacp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetSystemIdMac retrieves the value of the leaf SystemIdMac from the Lacp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemIdMac is set, it can safely use t.GetSystemIdMac()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemIdMac == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface) GetSystemIdMac() string {
	if t == nil || t.SystemIdMac == nil {
		return ""
	}
	return *t.SystemIdMac
}

// GetSystemPriority retrieves the value of the leaf SystemPriority from the Lacp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemPriority is set, it can safely use t.GetSystemPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemPriority == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface) GetSystemPriority() uint16 {
	if t == nil || t.SystemPriority == nil {
		return 0
	}
	return *t.SystemPriority
}

// ΛListKeyMap returns the keys of the Lacp_Interface struct, which is a YANG list entry.
func (t *Lacp_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lacp_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lacp_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lacp_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lacp_Interface_Member represents the /openconfig-lacp/lacp/interfaces/interface/members/member YANG schema element.
type Lacp_Interface_Member struct {
	ΛMetadata        []ygot.Annotation                        `path:"@" ygotAnnotation:"true"`
	Activity         E_OpenconfigLacp_LacpActivityType        `path:"state/activity" module:"openconfig-lacp"`
	ΛActivity        []ygot.Annotation                        `path:"state/@activity" ygotAnnotation:"true"`
	Aggregatable     *bool                                    `path:"state/aggregatable" module:"openconfig-lacp"`
	ΛAggregatable    []ygot.Annotation                        `path:"state/@aggregatable" ygotAnnotation:"true"`
	Collecting       *bool                                    `path:"state/collecting" module:"openconfig-lacp"`
	ΛCollecting      []ygot.Annotation                        `path:"state/@collecting" ygotAnnotation:"true"`
	Counters         *Lacp_Interface_Member_Counters          `path:"state/counters" module:"openconfig-lacp"`
	ΛCounters        []ygot.Annotation                        `path:"state/@counters" ygotAnnotation:"true"`
	Distributing     *bool                                    `path:"state/distributing" module:"openconfig-lacp"`
	ΛDistributing    []ygot.Annotation                        `path:"state/@distributing" ygotAnnotation:"true"`
	Interface        *string                                  `path:"state/interface|interface" module:"openconfig-lacp"`
	ΛInterface       []ygot.Annotation                        `path:"state/@interface|@interface" ygotAnnotation:"true"`
	OperKey          *uint16                                  `path:"state/oper-key" module:"openconfig-lacp"`
	ΛOperKey         []ygot.Annotation                        `path:"state/@oper-key" ygotAnnotation:"true"`
	PartnerId        *string                                  `path:"state/partner-id" module:"openconfig-lacp"`
	ΛPartnerId       []ygot.Annotation                        `path:"state/@partner-id" ygotAnnotation:"true"`
	PartnerKey       *uint16                                  `path:"state/partner-key" module:"openconfig-lacp"`
	ΛPartnerKey      []ygot.Annotation                        `path:"state/@partner-key" ygotAnnotation:"true"`
	PartnerPortNum   *uint16                                  `path:"state/partner-port-num" module:"openconfig-lacp"`
	ΛPartnerPortNum  []ygot.Annotation                        `path:"state/@partner-port-num" ygotAnnotation:"true"`
	PortNum          *uint16                                  `path:"state/port-num" module:"openconfig-lacp"`
	ΛPortNum         []ygot.Annotation                        `path:"state/@port-num" ygotAnnotation:"true"`
	Synchronization  E_OpenconfigLacp_LacpSynchronizationType `path:"state/synchronization" module:"openconfig-lacp"`
	ΛSynchronization []ygot.Annotation                        `path:"state/@synchronization" ygotAnnotation:"true"`
	SystemId         *string                                  `path:"state/system-id" module:"openconfig-lacp"`
	ΛSystemId        []ygot.Annotation                        `path:"state/@system-id" ygotAnnotation:"true"`
	Timeout          E_OpenconfigLacp_LacpTimeoutType         `path:"state/timeout" module:"openconfig-lacp"`
	ΛTimeout         []ygot.Annotation                        `path:"state/@timeout" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lacp_Interface_Member implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lacp_Interface_Member) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Lacp_Interface_Member) GetOrCreateCounters() *Lacp_Interface_Member_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Lacp_Interface_Member_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from Lacp_Interface_Member. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Lacp_Interface_Member) GetCounters() *Lacp_Interface_Member_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetActivity retrieves the value of the leaf Activity from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Activity is set, it can safely use t.GetActivity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Activity == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetActivity() E_OpenconfigLacp_LacpActivityType {
	if t == nil || t.Activity == 0 {
		return 0
	}
	return t.Activity
}

// GetAggregatable retrieves the value of the leaf Aggregatable from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Aggregatable is set, it can safely use t.GetAggregatable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Aggregatable == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetAggregatable() bool {
	if t == nil || t.Aggregatable == nil {
		return false
	}
	return *t.Aggregatable
}

// GetCollecting retrieves the value of the leaf Collecting from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Collecting is set, it can safely use t.GetCollecting()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Collecting == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetCollecting() bool {
	if t == nil || t.Collecting == nil {
		return false
	}
	return *t.Collecting
}

// GetDistributing retrieves the value of the leaf Distributing from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Distributing is set, it can safely use t.GetDistributing()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Distributing == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetDistributing() bool {
	if t == nil || t.Distributing == nil {
		return false
	}
	return *t.Distributing
}

// GetInterface retrieves the value of the leaf Interface from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetOperKey retrieves the value of the leaf OperKey from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OperKey is set, it can safely use t.GetOperKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OperKey == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetOperKey() uint16 {
	if t == nil || t.OperKey == nil {
		return 0
	}
	return *t.OperKey
}

// GetPartnerId retrieves the value of the leaf PartnerId from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PartnerId is set, it can safely use t.GetPartnerId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PartnerId == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetPartnerId() string {
	if t == nil || t.PartnerId == nil {
		return ""
	}
	return *t.PartnerId
}

// GetPartnerKey retrieves the value of the leaf PartnerKey from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PartnerKey is set, it can safely use t.GetPartnerKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PartnerKey == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetPartnerKey() uint16 {
	if t == nil || t.PartnerKey == nil {
		return 0
	}
	return *t.PartnerKey
}

// GetPartnerPortNum retrieves the value of the leaf PartnerPortNum from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PartnerPortNum is set, it can safely use t.GetPartnerPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PartnerPortNum == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetPartnerPortNum() uint16 {
	if t == nil || t.PartnerPortNum == nil {
		return 0
	}
	return *t.PartnerPortNum
}

// GetPortNum retrieves the value of the leaf PortNum from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortNum is set, it can safely use t.GetPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortNum == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetPortNum() uint16 {
	if t == nil || t.PortNum == nil {
		return 0
	}
	return *t.PortNum
}

// GetSynchronization retrieves the value of the leaf Synchronization from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Synchronization is set, it can safely use t.GetSynchronization()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Synchronization == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetSynchronization() E_OpenconfigLacp_LacpSynchronizationType {
	if t == nil || t.Synchronization == 0 {
		return 0
	}
	return t.Synchronization
}

// GetSystemId retrieves the value of the leaf SystemId from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// GetTimeout retrieves the value of the leaf Timeout from the Lacp_Interface_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Timeout is set, it can safely use t.GetTimeout()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Timeout == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member) GetTimeout() E_OpenconfigLacp_LacpTimeoutType {
	if t == nil || t.Timeout == 0 {
		return 0
	}
	return t.Timeout
}

// ΛListKeyMap returns the keys of the Lacp_Interface_Member struct, which is a YANG list entry.
func (t *Lacp_Interface_Member) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Interface == nil {
		return nil, fmt.Errorf("nil value for key Interface")
	}

	return map[string]interface{}{
		"interface": *t.Interface,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lacp_Interface_Member) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lacp_Interface_Member"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lacp_Interface_Member) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lacp_Interface_Member_Counters represents the /openconfig-lacp/lacp/interfaces/interface/members/member/state/counters YANG schema element.
type Lacp_Interface_Member_Counters struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LacpErrors         *uint64           `path:"lacp-errors" module:"openconfig-lacp"`
	ΛLacpErrors        []ygot.Annotation `path:"@lacp-errors" ygotAnnotation:"true"`
	LacpInPkts         *uint64           `path:"lacp-in-pkts" module:"openconfig-lacp"`
	ΛLacpInPkts        []ygot.Annotation `path:"@lacp-in-pkts" ygotAnnotation:"true"`
	LacpOutPkts        *uint64           `path:"lacp-out-pkts" module:"openconfig-lacp"`
	ΛLacpOutPkts       []ygot.Annotation `path:"@lacp-out-pkts" ygotAnnotation:"true"`
	LacpRxErrors       *uint64           `path:"lacp-rx-errors" module:"openconfig-lacp"`
	ΛLacpRxErrors      []ygot.Annotation `path:"@lacp-rx-errors" ygotAnnotation:"true"`
	LacpTxErrors       *uint64           `path:"lacp-tx-errors" module:"openconfig-lacp"`
	ΛLacpTxErrors      []ygot.Annotation `path:"@lacp-tx-errors" ygotAnnotation:"true"`
	LacpUnknownErrors  *uint64           `path:"lacp-unknown-errors" module:"openconfig-lacp"`
	ΛLacpUnknownErrors []ygot.Annotation `path:"@lacp-unknown-errors" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lacp_Interface_Member_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lacp_Interface_Member_Counters) IsYANGGoStruct() {}

// GetLacpErrors retrieves the value of the leaf LacpErrors from the Lacp_Interface_Member_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpErrors is set, it can safely use t.GetLacpErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpErrors == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member_Counters) GetLacpErrors() uint64 {
	if t == nil || t.LacpErrors == nil {
		return 0
	}
	return *t.LacpErrors
}

// GetLacpInPkts retrieves the value of the leaf LacpInPkts from the Lacp_Interface_Member_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpInPkts is set, it can safely use t.GetLacpInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpInPkts == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member_Counters) GetLacpInPkts() uint64 {
	if t == nil || t.LacpInPkts == nil {
		return 0
	}
	return *t.LacpInPkts
}

// GetLacpOutPkts retrieves the value of the leaf LacpOutPkts from the Lacp_Interface_Member_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpOutPkts is set, it can safely use t.GetLacpOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpOutPkts == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member_Counters) GetLacpOutPkts() uint64 {
	if t == nil || t.LacpOutPkts == nil {
		return 0
	}
	return *t.LacpOutPkts
}

// GetLacpRxErrors retrieves the value of the leaf LacpRxErrors from the Lacp_Interface_Member_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpRxErrors is set, it can safely use t.GetLacpRxErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpRxErrors == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member_Counters) GetLacpRxErrors() uint64 {
	if t == nil || t.LacpRxErrors == nil {
		return 0
	}
	return *t.LacpRxErrors
}

// GetLacpTxErrors retrieves the value of the leaf LacpTxErrors from the Lacp_Interface_Member_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpTxErrors is set, it can safely use t.GetLacpTxErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpTxErrors == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member_Counters) GetLacpTxErrors() uint64 {
	if t == nil || t.LacpTxErrors == nil {
		return 0
	}
	return *t.LacpTxErrors
}

// GetLacpUnknownErrors retrieves the value of the leaf LacpUnknownErrors from the Lacp_Interface_Member_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LacpUnknownErrors is set, it can safely use t.GetLacpUnknownErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LacpUnknownErrors == nil'
// before retrieving the leaf's value.
func (t *Lacp_Interface_Member_Counters) GetLacpUnknownErrors() uint64 {
	if t == nil || t.LacpUnknownErrors == nil {
		return 0
	}
	return *t.LacpUnknownErrors
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lacp_Interface_Member_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lacp_Interface_Member_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lacp_Interface_Member_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Lldp represents the /openconfig-lldp/lldp YANG schema element.
type Lldp struct {
	ΛMetadata                 []ygot.Annotation                   `path:"@" ygotAnnotation:"true"`
	ChassisId                 *string                             `path:"state/chassis-id" shadow-path:"config/chassis-id" module:"openconfig-lldp"`
	ΛChassisId                []ygot.Annotation                   `path:"state/@chassis-id" ygotAnnotation:"true"`
	ChassisIdType             E_OpenconfigLldpTypes_ChassisIdType `path:"state/chassis-id-type" shadow-path:"config/chassis-id-type" module:"openconfig-lldp"`
	ΛChassisIdType            []ygot.Annotation                   `path:"state/@chassis-id-type" ygotAnnotation:"true"`
	Counters                  *Lldp_Counters                      `path:"state/counters" module:"openconfig-lldp"`
	ΛCounters                 []ygot.Annotation                   `path:"state/@counters" ygotAnnotation:"true"`
	Enabled                   *bool                               `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-lldp"`
	ΛEnabled                  []ygot.Annotation                   `path:"state/@enabled" ygotAnnotation:"true"`
	HelloTimer                *uint64                             `path:"state/hello-timer" shadow-path:"config/hello-timer" module:"openconfig-lldp"`
	ΛHelloTimer               []ygot.Annotation                   `path:"state/@hello-timer" ygotAnnotation:"true"`
	Interface                 map[string]*Lldp_Interface          `path:"interfaces/interface" module:"openconfig-lldp"`
	ΛInterface                []ygot.Annotation                   `path:"interfaces/@interface" ygotAnnotation:"true"`
	SuppressTlvAdvertisement  []E_OpenconfigLldpTypes_LLDP_TLV    `path:"state/suppress-tlv-advertisement" shadow-path:"config/suppress-tlv-advertisement" module:"openconfig-lldp"`
	ΛSuppressTlvAdvertisement []ygot.Annotation                   `path:"state/@suppress-tlv-advertisement" ygotAnnotation:"true"`
	SystemDescription         *string                             `path:"state/system-description" shadow-path:"config/system-description" module:"openconfig-lldp"`
	ΛSystemDescription        []ygot.Annotation                   `path:"state/@system-description" ygotAnnotation:"true"`
	SystemName                *string                             `path:"state/system-name" shadow-path:"config/system-name" module:"openconfig-lldp"`
	ΛSystemName               []ygot.Annotation                   `path:"state/@system-name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// Lldp struct. The keys of the list are populated from the input
// arguments.
func (t *Lldp) NewInterface(Name string) (*Lldp_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Lldp_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Lldp_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Lldp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Lldp) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Lldp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Lldp) GetOrCreateInterface(Name string) *Lldp_Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Lldp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Lldp) GetInterface(Name string) *Lldp_Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Lldp_Interface struct to the
// list Interface of Lldp. If the key value(s) specified in
// the supplied Lldp_Interface already exist in the list, an error is
// returned.
func (t *Lldp) AppendInterface(v *Lldp_Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Lldp_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Lldp) GetOrCreateCounters() *Lldp_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Lldp_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from Lldp. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Lldp) GetCounters() *Lldp_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetChassisId retrieves the value of the leaf ChassisId from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChassisId is set, it can safely use t.GetChassisId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChassisId == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetChassisId() string {
	if t == nil || t.ChassisId == nil {
		return ""
	}
	return *t.ChassisId
}

// GetChassisIdType retrieves the value of the leaf ChassisIdType from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChassisIdType is set, it can safely use t.GetChassisIdType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChassisIdType == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetChassisIdType() E_OpenconfigLldpTypes_ChassisIdType {
	if t == nil || t.ChassisIdType == 0 {
		return 0
	}
	return t.ChassisIdType
}

// GetEnabled retrieves the value of the leaf Enabled from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetHelloTimer retrieves the value of the leaf HelloTimer from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloTimer is set, it can safely use t.GetHelloTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloTimer == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetHelloTimer() uint64 {
	if t == nil || t.HelloTimer == nil {
		return 0
	}
	return *t.HelloTimer
}

// GetSuppressTlvAdvertisement retrieves the value of the leaf SuppressTlvAdvertisement from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SuppressTlvAdvertisement is set, it can safely use t.GetSuppressTlvAdvertisement()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SuppressTlvAdvertisement == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetSuppressTlvAdvertisement() []E_OpenconfigLldpTypes_LLDP_TLV {
	if t == nil || t.SuppressTlvAdvertisement == nil {
		return nil
	}
	return t.SuppressTlvAdvertisement
}

// GetSystemDescription retrieves the value of the leaf SystemDescription from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemDescription is set, it can safely use t.GetSystemDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemDescription == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetSystemDescription() string {
	if t == nil || t.SystemDescription == nil {
		return ""
	}
	return *t.SystemDescription
}

// GetSystemName retrieves the value of the leaf SystemName from the Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemName is set, it can safely use t.GetSystemName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemName == nil'
// before retrieving the leaf's value.
func (t *Lldp) GetSystemName() string {
	if t == nil || t.SystemName == nil {
		return ""
	}
	return *t.SystemName
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lldp_Counters represents the /openconfig-lldp/lldp/state/counters YANG schema element.
type Lldp_Counters struct {
	ΛMetadata       []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EntriesAgedOut  *uint64           `path:"entries-aged-out" module:"openconfig-lldp"`
	ΛEntriesAgedOut []ygot.Annotation `path:"@entries-aged-out" ygotAnnotation:"true"`
	FrameDiscard    *uint64           `path:"frame-discard" module:"openconfig-lldp"`
	ΛFrameDiscard   []ygot.Annotation `path:"@frame-discard" ygotAnnotation:"true"`
	FrameErrorIn    *uint64           `path:"frame-error-in" module:"openconfig-lldp"`
	ΛFrameErrorIn   []ygot.Annotation `path:"@frame-error-in" ygotAnnotation:"true"`
	FrameIn         *uint64           `path:"frame-in" module:"openconfig-lldp"`
	ΛFrameIn        []ygot.Annotation `path:"@frame-in" ygotAnnotation:"true"`
	FrameOut        *uint64           `path:"frame-out" module:"openconfig-lldp"`
	ΛFrameOut       []ygot.Annotation `path:"@frame-out" ygotAnnotation:"true"`
	LastClear       *string           `path:"last-clear" module:"openconfig-lldp"`
	ΛLastClear      []ygot.Annotation `path:"@last-clear" ygotAnnotation:"true"`
	TlvAccepted     *uint64           `path:"tlv-accepted" module:"openconfig-lldp"`
	ΛTlvAccepted    []ygot.Annotation `path:"@tlv-accepted" ygotAnnotation:"true"`
	TlvDiscard      *uint64           `path:"tlv-discard" module:"openconfig-lldp"`
	ΛTlvDiscard     []ygot.Annotation `path:"@tlv-discard" ygotAnnotation:"true"`
	TlvUnknown      *uint64           `path:"tlv-unknown" module:"openconfig-lldp"`
	ΛTlvUnknown     []ygot.Annotation `path:"@tlv-unknown" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp_Counters) IsYANGGoStruct() {}

// GetEntriesAgedOut retrieves the value of the leaf EntriesAgedOut from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EntriesAgedOut is set, it can safely use t.GetEntriesAgedOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EntriesAgedOut == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetEntriesAgedOut() uint64 {
	if t == nil || t.EntriesAgedOut == nil {
		return 0
	}
	return *t.EntriesAgedOut
}

// GetFrameDiscard retrieves the value of the leaf FrameDiscard from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameDiscard is set, it can safely use t.GetFrameDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameDiscard == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetFrameDiscard() uint64 {
	if t == nil || t.FrameDiscard == nil {
		return 0
	}
	return *t.FrameDiscard
}

// GetFrameErrorIn retrieves the value of the leaf FrameErrorIn from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameErrorIn is set, it can safely use t.GetFrameErrorIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameErrorIn == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetFrameErrorIn() uint64 {
	if t == nil || t.FrameErrorIn == nil {
		return 0
	}
	return *t.FrameErrorIn
}

// GetFrameIn retrieves the value of the leaf FrameIn from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameIn is set, it can safely use t.GetFrameIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameIn == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetFrameIn() uint64 {
	if t == nil || t.FrameIn == nil {
		return 0
	}
	return *t.FrameIn
}

// GetFrameOut retrieves the value of the leaf FrameOut from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameOut is set, it can safely use t.GetFrameOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameOut == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetFrameOut() uint64 {
	if t == nil || t.FrameOut == nil {
		return 0
	}
	return *t.FrameOut
}

// GetLastClear retrieves the value of the leaf LastClear from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastClear is set, it can safely use t.GetLastClear()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastClear == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetLastClear() string {
	if t == nil || t.LastClear == nil {
		return ""
	}
	return *t.LastClear
}

// GetTlvAccepted retrieves the value of the leaf TlvAccepted from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvAccepted is set, it can safely use t.GetTlvAccepted()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvAccepted == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetTlvAccepted() uint64 {
	if t == nil || t.TlvAccepted == nil {
		return 0
	}
	return *t.TlvAccepted
}

// GetTlvDiscard retrieves the value of the leaf TlvDiscard from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvDiscard is set, it can safely use t.GetTlvDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvDiscard == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetTlvDiscard() uint64 {
	if t == nil || t.TlvDiscard == nil {
		return 0
	}
	return *t.TlvDiscard
}

// GetTlvUnknown retrieves the value of the leaf TlvUnknown from the Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvUnknown is set, it can safely use t.GetTlvUnknown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvUnknown == nil'
// before retrieving the leaf's value.
func (t *Lldp_Counters) GetTlvUnknown() uint64 {
	if t == nil || t.TlvUnknown == nil {
		return 0
	}
	return *t.TlvUnknown
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp_Counters) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lldp_Interface represents the /openconfig-lldp/lldp/interfaces/interface YANG schema element.
type Lldp_Interface struct {
	ΛMetadata []ygot.Annotation                   `path:"@" ygotAnnotation:"true"`
	Counters  *Lldp_Interface_Counters            `path:"state/counters" module:"openconfig-lldp"`
	ΛCounters []ygot.Annotation                   `path:"state/@counters" ygotAnnotation:"true"`
	Enabled   *bool                               `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-lldp"`
	ΛEnabled  []ygot.Annotation                   `path:"state/@enabled" ygotAnnotation:"true"`
	Name      *string                             `path:"state/name|name" shadow-path:"config/name" module:"openconfig-lldp"`
	ΛName     []ygot.Annotation                   `path:"state/@name|@name" ygotAnnotation:"true"`
	Neighbor  map[string]*Lldp_Interface_Neighbor `path:"neighbors/neighbor" module:"openconfig-lldp"`
	ΛNeighbor []ygot.Annotation                   `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp_Interface) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// Lldp_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *Lldp_Interface) NewNeighbor(Id string) (*Lldp_Interface_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Lldp_Interface_Neighbor)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &Lldp_Interface_Neighbor{
		Id: &Id,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the Lldp_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Lldp_Interface) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Id = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver Lldp_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Lldp_Interface) GetOrCreateNeighbor(Id string) *Lldp_Interface_Neighbor {

	key := Id

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of Lldp_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Lldp_Interface) GetNeighbor(Id string) *Lldp_Interface_Neighbor {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied Lldp_Interface_Neighbor struct to the
// list Neighbor of Lldp_Interface. If the key value(s) specified in
// the supplied Lldp_Interface_Neighbor already exist in the list, an error is
// returned.
func (t *Lldp_Interface) AppendNeighbor(v *Lldp_Interface_Neighbor) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*Lldp_Interface_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Lldp_Interface) GetOrCreateCounters() *Lldp_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Lldp_Interface_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from Lldp_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Lldp_Interface) GetCounters() *Lldp_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the Lldp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetName retrieves the value of the leaf Name from the Lldp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the Lldp_Interface struct, which is a YANG list entry.
func (t *Lldp_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lldp_Interface_Counters represents the /openconfig-lldp/lldp/interfaces/interface/state/counters YANG schema element.
type Lldp_Interface_Counters struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	FrameDiscard   *uint64           `path:"frame-discard" module:"openconfig-lldp"`
	ΛFrameDiscard  []ygot.Annotation `path:"@frame-discard" ygotAnnotation:"true"`
	FrameErrorIn   *uint64           `path:"frame-error-in" module:"openconfig-lldp"`
	ΛFrameErrorIn  []ygot.Annotation `path:"@frame-error-in" ygotAnnotation:"true"`
	FrameErrorOut  *uint64           `path:"frame-error-out" module:"openconfig-lldp"`
	ΛFrameErrorOut []ygot.Annotation `path:"@frame-error-out" ygotAnnotation:"true"`
	FrameIn        *uint64           `path:"frame-in" module:"openconfig-lldp"`
	ΛFrameIn       []ygot.Annotation `path:"@frame-in" ygotAnnotation:"true"`
	FrameOut       *uint64           `path:"frame-out" module:"openconfig-lldp"`
	ΛFrameOut      []ygot.Annotation `path:"@frame-out" ygotAnnotation:"true"`
	LastClear      *string           `path:"last-clear" module:"openconfig-lldp"`
	ΛLastClear     []ygot.Annotation `path:"@last-clear" ygotAnnotation:"true"`
	TlvDiscard     *uint64           `path:"tlv-discard" module:"openconfig-lldp"`
	ΛTlvDiscard    []ygot.Annotation `path:"@tlv-discard" ygotAnnotation:"true"`
	TlvUnknown     *uint64           `path:"tlv-unknown" module:"openconfig-lldp"`
	ΛTlvUnknown    []ygot.Annotation `path:"@tlv-unknown" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp_Interface_Counters) IsYANGGoStruct() {}

// GetFrameDiscard retrieves the value of the leaf FrameDiscard from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameDiscard is set, it can safely use t.GetFrameDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameDiscard == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetFrameDiscard() uint64 {
	if t == nil || t.FrameDiscard == nil {
		return 0
	}
	return *t.FrameDiscard
}

// GetFrameErrorIn retrieves the value of the leaf FrameErrorIn from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameErrorIn is set, it can safely use t.GetFrameErrorIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameErrorIn == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetFrameErrorIn() uint64 {
	if t == nil || t.FrameErrorIn == nil {
		return 0
	}
	return *t.FrameErrorIn
}

// GetFrameErrorOut retrieves the value of the leaf FrameErrorOut from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameErrorOut is set, it can safely use t.GetFrameErrorOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameErrorOut == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetFrameErrorOut() uint64 {
	if t == nil || t.FrameErrorOut == nil {
		return 0
	}
	return *t.FrameErrorOut
}

// GetFrameIn retrieves the value of the leaf FrameIn from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameIn is set, it can safely use t.GetFrameIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameIn == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetFrameIn() uint64 {
	if t == nil || t.FrameIn == nil {
		return 0
	}
	return *t.FrameIn
}

// GetFrameOut retrieves the value of the leaf FrameOut from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameOut is set, it can safely use t.GetFrameOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameOut == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetFrameOut() uint64 {
	if t == nil || t.FrameOut == nil {
		return 0
	}
	return *t.FrameOut
}

// GetLastClear retrieves the value of the leaf LastClear from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastClear is set, it can safely use t.GetLastClear()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastClear == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetLastClear() string {
	if t == nil || t.LastClear == nil {
		return ""
	}
	return *t.LastClear
}

// GetTlvDiscard retrieves the value of the leaf TlvDiscard from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvDiscard is set, it can safely use t.GetTlvDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvDiscard == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetTlvDiscard() uint64 {
	if t == nil || t.TlvDiscard == nil {
		return 0
	}
	return *t.TlvDiscard
}

// GetTlvUnknown retrieves the value of the leaf TlvUnknown from the Lldp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvUnknown is set, it can safely use t.GetTlvUnknown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvUnknown == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Counters) GetTlvUnknown() uint64 {
	if t == nil || t.TlvUnknown == nil {
		return 0
	}
	return *t.TlvUnknown
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lldp_Interface_Neighbor represents the /openconfig-lldp/lldp/interfaces/interface/neighbors/neighbor YANG schema element.
type Lldp_Interface_Neighbor struct {
	ΛMetadata              []ygot.Annotation                                                                    `path:"@" ygotAnnotation:"true"`
	Age                    *uint64                                                                              `path:"state/age" module:"openconfig-lldp"`
	ΛAge                   []ygot.Annotation                                                                    `path:"state/@age" ygotAnnotation:"true"`
	Capability             map[E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY]*Lldp_Interface_Neighbor_Capability `path:"capabilities/capability" module:"openconfig-lldp"`
	ΛCapability            []ygot.Annotation                                                                    `path:"capabilities/@capability" ygotAnnotation:"true"`
	ChassisId              *string                                                                              `path:"state/chassis-id" module:"openconfig-lldp"`
	ΛChassisId             []ygot.Annotation                                                                    `path:"state/@chassis-id" ygotAnnotation:"true"`
	ChassisIdType          E_OpenconfigLldpTypes_ChassisIdType                                                  `path:"state/chassis-id-type" module:"openconfig-lldp"`
	ΛChassisIdType         []ygot.Annotation                                                                    `path:"state/@chassis-id-type" ygotAnnotation:"true"`
	Id                     *string                                                                              `path:"state/id|id" module:"openconfig-lldp"`
	ΛId                    []ygot.Annotation                                                                    `path:"state/@id|@id" ygotAnnotation:"true"`
	LastUpdate             *int64                                                                               `path:"state/last-update" module:"openconfig-lldp"`
	ΛLastUpdate            []ygot.Annotation                                                                    `path:"state/@last-update" ygotAnnotation:"true"`
	ManagementAddress      *string                                                                              `path:"state/management-address" module:"openconfig-lldp"`
	ΛManagementAddress     []ygot.Annotation                                                                    `path:"state/@management-address" ygotAnnotation:"true"`
	ManagementAddressType  *string                                                                              `path:"state/management-address-type" module:"openconfig-lldp"`
	ΛManagementAddressType []ygot.Annotation                                                                    `path:"state/@management-address-type" ygotAnnotation:"true"`
	PortDescription        *string                                                                              `path:"state/port-description" module:"openconfig-lldp"`
	ΛPortDescription       []ygot.Annotation                                                                    `path:"state/@port-description" ygotAnnotation:"true"`
	PortId                 *string                                                                              `path:"state/port-id" module:"openconfig-lldp"`
	ΛPortId                []ygot.Annotation                                                                    `path:"state/@port-id" ygotAnnotation:"true"`
	PortIdType             E_OpenconfigLldpTypes_PortIdType                                                     `path:"state/port-id-type" module:"openconfig-lldp"`
	ΛPortIdType            []ygot.Annotation                                                                    `path:"state/@port-id-type" ygotAnnotation:"true"`
	SystemDescription      *string                                                                              `path:"state/system-description" module:"openconfig-lldp"`
	ΛSystemDescription     []ygot.Annotation                                                                    `path:"state/@system-description" ygotAnnotation:"true"`
	SystemName             *string                                                                              `path:"state/system-name" module:"openconfig-lldp"`
	ΛSystemName            []ygot.Annotation                                                                    `path:"state/@system-name" ygotAnnotation:"true"`
	Tlv                    map[Lldp_Interface_Neighbor_Tlv_Key]*Lldp_Interface_Neighbor_Tlv                     `path:"custom-tlvs/tlv" module:"openconfig-lldp"`
	ΛTlv                   []ygot.Annotation                                                                    `path:"custom-tlvs/@tlv" ygotAnnotation:"true"`
	Ttl                    *uint16                                                                              `path:"state/ttl" module:"openconfig-lldp"`
	ΛTtl                   []ygot.Annotation                                                                    `path:"state/@ttl" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp_Interface_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp_Interface_Neighbor) IsYANGGoStruct() {}

// Lldp_Interface_Neighbor_Tlv_Key represents the key for list Tlv of element /openconfig-lldp/lldp/interfaces/interface/neighbors/neighbor.
type Lldp_Interface_Neighbor_Tlv_Key struct {
	Type       int32  `path:"type"`
	Oui        string `path:"oui"`
	OuiSubtype string `path:"oui-subtype"`
}

// NewCapability creates a new entry in the Capability list of the
// Lldp_Interface_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *Lldp_Interface_Neighbor) NewCapability(Name E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) (*Lldp_Interface_Neighbor_Capability, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Capability == nil {
		t.Capability = make(map[E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY]*Lldp_Interface_Neighbor_Capability)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Capability[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Capability", key)
	}

	t.Capability[key] = &Lldp_Interface_Neighbor_Capability{
		Name: Name,
	}

	return t.Capability[key], nil
}

// RenameCapability renames an entry in the list Capability within
// the Lldp_Interface_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Lldp_Interface_Neighbor) RenameCapability(oldK, newK E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) error {
	if _, ok := t.Capability[newK]; ok {
		return fmt.Errorf("key %v already exists in Capability", newK)
	}

	e, ok := t.Capability[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Capability", oldK)
	}
	e.Name = newK

	t.Capability[newK] = e
	delete(t.Capability, oldK)
	return nil
}

// GetOrCreateCapability retrieves the value with the specified keys from
// the receiver Lldp_Interface_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Lldp_Interface_Neighbor) GetOrCreateCapability(Name E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) *Lldp_Interface_Neighbor_Capability {

	key := Name

	if v, ok := t.Capability[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCapability(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCapability got unexpected error: %v", err))
	}
	return v
}

// GetCapability retrieves the value with the specified key from
// the Capability map field of Lldp_Interface_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Lldp_Interface_Neighbor) GetCapability(Name E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) *Lldp_Interface_Neighbor_Capability {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Capability[key]; ok {
		return lm
	}
	return nil
}

// AppendCapability appends the supplied Lldp_Interface_Neighbor_Capability struct to the
// list Capability of Lldp_Interface_Neighbor. If the key value(s) specified in
// the supplied Lldp_Interface_Neighbor_Capability already exist in the list, an error is
// returned.
func (t *Lldp_Interface_Neighbor) AppendCapability(v *Lldp_Interface_Neighbor_Capability) error {
	key := v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Capability == nil {
		t.Capability = make(map[E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY]*Lldp_Interface_Neighbor_Capability)
	}

	if _, ok := t.Capability[key]; ok {
		return fmt.Errorf("duplicate key for list Capability %v", key)
	}

	t.Capability[key] = v
	return nil
}

// NewTlv creates a new entry in the Tlv list of the
// Lldp_Interface_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *Lldp_Interface_Neighbor) NewTlv(Type int32, Oui string, OuiSubtype string) (*Lldp_Interface_Neighbor_Tlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[Lldp_Interface_Neighbor_Tlv_Key]*Lldp_Interface_Neighbor_Tlv)
	}

	key := Lldp_Interface_Neighbor_Tlv_Key{
		Type:       Type,
		Oui:        Oui,
		OuiSubtype: OuiSubtype,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tlv", key)
	}

	t.Tlv[key] = &Lldp_Interface_Neighbor_Tlv{
		Type:       &Type,
		Oui:        &Oui,
		OuiSubtype: &OuiSubtype,
	}

	return t.Tlv[key], nil
}

// RenameTlv renames an entry in the list Tlv within
// the Lldp_Interface_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Lldp_Interface_Neighbor) RenameTlv(oldK, newK Lldp_Interface_Neighbor_Tlv_Key) error {
	if _, ok := t.Tlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Tlv", newK)
	}

	e, ok := t.Tlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Tlv", oldK)
	}
	e.Type = &newK.Type
	e.Oui = &newK.Oui
	e.OuiSubtype = &newK.OuiSubtype

	t.Tlv[newK] = e
	delete(t.Tlv, oldK)
	return nil
}

// GetOrCreateTlv retrieves the value with the specified keys from
// the receiver Lldp_Interface_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Lldp_Interface_Neighbor) GetOrCreateTlv(Type int32, Oui string, OuiSubtype string) *Lldp_Interface_Neighbor_Tlv {

	key := Lldp_Interface_Neighbor_Tlv_Key{
		Type:       Type,
		Oui:        Oui,
		OuiSubtype: OuiSubtype,
	}

	if v, ok := t.Tlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTlv(Type, Oui, OuiSubtype)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTlv got unexpected error: %v", err))
	}
	return v
}

// GetTlv retrieves the value with the specified key from
// the Tlv map field of Lldp_Interface_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Lldp_Interface_Neighbor) GetTlv(Type int32, Oui string, OuiSubtype string) *Lldp_Interface_Neighbor_Tlv {

	if t == nil {
		return nil
	}

	key := Lldp_Interface_Neighbor_Tlv_Key{
		Type:       Type,
		Oui:        Oui,
		OuiSubtype: OuiSubtype,
	}

	if lm, ok := t.Tlv[key]; ok {
		return lm
	}
	return nil
}

// AppendTlv appends the supplied Lldp_Interface_Neighbor_Tlv struct to the
// list Tlv of Lldp_Interface_Neighbor. If the key value(s) specified in
// the supplied Lldp_Interface_Neighbor_Tlv already exist in the list, an error is
// returned.
func (t *Lldp_Interface_Neighbor) AppendTlv(v *Lldp_Interface_Neighbor_Tlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key for Type")
	}

	if v.Oui == nil {
		return fmt.Errorf("invalid nil key for Oui")
	}

	if v.OuiSubtype == nil {
		return fmt.Errorf("invalid nil key for OuiSubtype")
	}

	key := Lldp_Interface_Neighbor_Tlv_Key{
		Type:       *v.Type,
		Oui:        *v.Oui,
		OuiSubtype: *v.OuiSubtype,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[Lldp_Interface_Neighbor_Tlv_Key]*Lldp_Interface_Neighbor_Tlv)
	}

	if _, ok := t.Tlv[key]; ok {
		return fmt.Errorf("duplicate key for list Tlv %v", key)
	}

	t.Tlv[key] = v
	return nil
}

// GetAge retrieves the value of the leaf Age from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Age is set, it can safely use t.GetAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Age == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetAge() uint64 {
	if t == nil || t.Age == nil {
		return 0
	}
	return *t.Age
}

// GetChassisId retrieves the value of the leaf ChassisId from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChassisId is set, it can safely use t.GetChassisId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChassisId == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetChassisId() string {
	if t == nil || t.ChassisId == nil {
		return ""
	}
	return *t.ChassisId
}

// GetChassisIdType retrieves the value of the leaf ChassisIdType from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChassisIdType is set, it can safely use t.GetChassisIdType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChassisIdType == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetChassisIdType() E_OpenconfigLldpTypes_ChassisIdType {
	if t == nil || t.ChassisIdType == 0 {
		return 0
	}
	return t.ChassisIdType
}

// GetId retrieves the value of the leaf Id from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetLastUpdate retrieves the value of the leaf LastUpdate from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastUpdate is set, it can safely use t.GetLastUpdate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastUpdate == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetLastUpdate() int64 {
	if t == nil || t.LastUpdate == nil {
		return 0
	}
	return *t.LastUpdate
}

// GetManagementAddress retrieves the value of the leaf ManagementAddress from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ManagementAddress is set, it can safely use t.GetManagementAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ManagementAddress == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetManagementAddress() string {
	if t == nil || t.ManagementAddress == nil {
		return ""
	}
	return *t.ManagementAddress
}

// GetManagementAddressType retrieves the value of the leaf ManagementAddressType from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ManagementAddressType is set, it can safely use t.GetManagementAddressType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ManagementAddressType == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetManagementAddressType() string {
	if t == nil || t.ManagementAddressType == nil {
		return ""
	}
	return *t.ManagementAddressType
}

// GetPortDescription retrieves the value of the leaf PortDescription from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortDescription is set, it can safely use t.GetPortDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortDescription == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetPortDescription() string {
	if t == nil || t.PortDescription == nil {
		return ""
	}
	return *t.PortDescription
}

// GetPortId retrieves the value of the leaf PortId from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortId is set, it can safely use t.GetPortId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortId == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetPortId() string {
	if t == nil || t.PortId == nil {
		return ""
	}
	return *t.PortId
}

// GetPortIdType retrieves the value of the leaf PortIdType from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortIdType is set, it can safely use t.GetPortIdType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortIdType == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetPortIdType() E_OpenconfigLldpTypes_PortIdType {
	if t == nil || t.PortIdType == 0 {
		return 0
	}
	return t.PortIdType
}

// GetSystemDescription retrieves the value of the leaf SystemDescription from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemDescription is set, it can safely use t.GetSystemDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemDescription == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetSystemDescription() string {
	if t == nil || t.SystemDescription == nil {
		return ""
	}
	return *t.SystemDescription
}

// GetSystemName retrieves the value of the leaf SystemName from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemName is set, it can safely use t.GetSystemName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemName == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetSystemName() string {
	if t == nil || t.SystemName == nil {
		return ""
	}
	return *t.SystemName
}

// GetTtl retrieves the value of the leaf Ttl from the Lldp_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ttl is set, it can safely use t.GetTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ttl == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor) GetTtl() uint16 {
	if t == nil || t.Ttl == nil {
		return 0
	}
	return *t.Ttl
}

// ΛListKeyMap returns the keys of the Lldp_Interface_Neighbor struct, which is a YANG list entry.
func (t *Lldp_Interface_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp_Interface_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp_Interface_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp_Interface_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Lldp_Interface_Neighbor_Capability represents the /openconfig-lldp/lldp/interfaces/interface/neighbors/neighbor/capabilities/capability YANG schema element.
type Lldp_Interface_Neighbor_Capability struct {
	ΛMetadata []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	Enabled   *bool                                        `path:"state/enabled" module:"openconfig-lldp"`
	ΛEnabled  []ygot.Annotation                            `path:"state/@enabled" ygotAnnotation:"true"`
	Name      E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY `path:"state/name|name" module:"openconfig-lldp"`
	ΛName     []ygot.Annotation                            `path:"state/@name|@name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp_Interface_Neighbor_Capability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp_Interface_Neighbor_Capability) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Lldp_Interface_Neighbor_Capability
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor_Capability) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetName retrieves the value of the leaf Name from the Lldp_Interface_Neighbor_Capability
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor_Capability) GetName() E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY {
	if t == nil || t.Name == 0 {
		return 0
	}
	return t.Name
}

// ΛListKeyMap returns the keys of the Lldp_Interface_Neighbor_Capability struct, which is a YANG list entry.
func (t *Lldp_Interface_Neighbor_Capability) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"name": t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp_Interface_Neighbor_Capability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp_Interface_Neighbor_Capability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp_Interface_Neighbor_Capability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Lldp_Interface_Neighbor_Tlv represents the /openconfig-lldp/lldp/interfaces/interface/neighbors/neighbor/custom-tlvs/tlv YANG schema element.
type Lldp_Interface_Neighbor_Tlv struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Oui         *string           `path:"state/oui|oui" module:"openconfig-lldp"`
	ΛOui        []ygot.Annotation `path:"state/@oui|@oui" ygotAnnotation:"true"`
	OuiSubtype  *string           `path:"state/oui-subtype|oui-subtype" module:"openconfig-lldp"`
	ΛOuiSubtype []ygot.Annotation `path:"state/@oui-subtype|@oui-subtype" ygotAnnotation:"true"`
	Type        *int32            `path:"state/type|type" module:"openconfig-lldp"`
	ΛType       []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value       Binary            `path:"state/value" module:"openconfig-lldp"`
	ΛValue      []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Lldp_Interface_Neighbor_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Lldp_Interface_Neighbor_Tlv) IsYANGGoStruct() {}

// GetOui retrieves the value of the leaf Oui from the Lldp_Interface_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Oui is set, it can safely use t.GetOui()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Oui == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor_Tlv) GetOui() string {
	if t == nil || t.Oui == nil {
		return ""
	}
	return *t.Oui
}

// GetOuiSubtype retrieves the value of the leaf OuiSubtype from the Lldp_Interface_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuiSubtype is set, it can safely use t.GetOuiSubtype()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuiSubtype == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor_Tlv) GetOuiSubtype() string {
	if t == nil || t.OuiSubtype == nil {
		return ""
	}
	return *t.OuiSubtype
}

// GetType retrieves the value of the leaf Type from the Lldp_Interface_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor_Tlv) GetType() int32 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the Lldp_Interface_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *Lldp_Interface_Neighbor_Tlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the Lldp_Interface_Neighbor_Tlv struct, which is a YANG list entry.
func (t *Lldp_Interface_Neighbor_Tlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Oui == nil {
		return nil, fmt.Errorf("nil value for key Oui")
	}

	if t.OuiSubtype == nil {
		return nil, fmt.Errorf("nil value for key OuiSubtype")
	}

	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"oui":         *t.Oui,
		"oui-subtype": *t.OuiSubtype,
		"type":        *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Lldp_Interface_Neighbor_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Lldp_Interface_Neighbor_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Lldp_Interface_Neighbor_Tlv) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// LocalRoutes represents the /openconfig-local-routing/local-routes YANG schema element.
type LocalRoutes struct {
	ΛMetadata  []ygot.Annotation                 `path:"@" ygotAnnotation:"true"`
	Aggregate  map[string]*LocalRoutes_Aggregate `path:"local-aggregates/aggregate" module:"openconfig-local-routing"`
	ΛAggregate []ygot.Annotation                 `path:"local-aggregates/@aggregate" ygotAnnotation:"true"`
	Static     map[string]*LocalRoutes_Static    `path:"static-routes/static" module:"openconfig-local-routing"`
	ΛStatic    []ygot.Annotation                 `path:"static-routes/@static" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that LocalRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*LocalRoutes) IsYANGGoStruct() {}

// NewAggregate creates a new entry in the Aggregate list of the
// LocalRoutes struct. The keys of the list are populated from the input
// arguments.
func (t *LocalRoutes) NewAggregate(Prefix string) (*LocalRoutes_Aggregate, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Aggregate == nil {
		t.Aggregate = make(map[string]*LocalRoutes_Aggregate)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Aggregate[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Aggregate", key)
	}

	t.Aggregate[key] = &LocalRoutes_Aggregate{
		Prefix: &Prefix,
	}

	return t.Aggregate[key], nil
}

// RenameAggregate renames an entry in the list Aggregate within
// the LocalRoutes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *LocalRoutes) RenameAggregate(oldK, newK string) error {
	if _, ok := t.Aggregate[newK]; ok {
		return fmt.Errorf("key %v already exists in Aggregate", newK)
	}

	e, ok := t.Aggregate[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Aggregate", oldK)
	}
	e.Prefix = &newK

	t.Aggregate[newK] = e
	delete(t.Aggregate, oldK)
	return nil
}

// GetOrCreateAggregate retrieves the value with the specified keys from
// the receiver LocalRoutes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *LocalRoutes) GetOrCreateAggregate(Prefix string) *LocalRoutes_Aggregate {

	key := Prefix

	if v, ok := t.Aggregate[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAggregate(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAggregate got unexpected error: %v", err))
	}
	return v
}

// GetAggregate retrieves the value with the specified key from
// the Aggregate map field of LocalRoutes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *LocalRoutes) GetAggregate(Prefix string) *LocalRoutes_Aggregate {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Aggregate[key]; ok {
		return lm
	}
	return nil
}

// AppendAggregate appends the supplied LocalRoutes_Aggregate struct to the
// list Aggregate of LocalRoutes. If the key value(s) specified in
// the supplied LocalRoutes_Aggregate already exist in the list, an error is
// returned.
func (t *LocalRoutes) AppendAggregate(v *LocalRoutes_Aggregate) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Aggregate == nil {
		t.Aggregate = make(map[string]*LocalRoutes_Aggregate)
	}

	if _, ok := t.Aggregate[key]; ok {
		return fmt.Errorf("duplicate key for list Aggregate %v", key)
	}

	t.Aggregate[key] = v
	return nil
}

// NewStatic creates a new entry in the Static list of the
// LocalRoutes struct. The keys of the list are populated from the input
// arguments.
func (t *LocalRoutes) NewStatic(Prefix string) (*LocalRoutes_Static, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Static == nil {
		t.Static = make(map[string]*LocalRoutes_Static)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Static[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Static", key)
	}

	t.Static[key] = &LocalRoutes_Static{
		Prefix: &Prefix,
	}

	return t.Static[key], nil
}

// RenameStatic renames an entry in the list Static within
// the LocalRoutes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *LocalRoutes) RenameStatic(oldK, newK string) error {
	if _, ok := t.Static[newK]; ok {
		return fmt.Errorf("key %v already exists in Static", newK)
	}

	e, ok := t.Static[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Static", oldK)
	}
	e.Prefix = &newK

	t.Static[newK] = e
	delete(t.Static, oldK)
	return nil
}

// GetOrCreateStatic retrieves the value with the specified keys from
// the receiver LocalRoutes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *LocalRoutes) GetOrCreateStatic(Prefix string) *LocalRoutes_Static {

	key := Prefix

	if v, ok := t.Static[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewStatic(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateStatic got unexpected error: %v", err))
	}
	return v
}

// GetStatic retrieves the value with the specified key from
// the Static map field of LocalRoutes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *LocalRoutes) GetStatic(Prefix string) *LocalRoutes_Static {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Static[key]; ok {
		return lm
	}
	return nil
}

// AppendStatic appends the supplied LocalRoutes_Static struct to the
// list Static of LocalRoutes. If the key value(s) specified in
// the supplied LocalRoutes_Static already exist in the list, an error is
// returned.
func (t *LocalRoutes) AppendStatic(v *LocalRoutes_Static) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Static == nil {
		t.Static = make(map[string]*LocalRoutes_Static)
	}

	if _, ok := t.Static[key]; ok {
		return fmt.Errorf("duplicate key for list Static %v", key)
	}

	t.Static[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *LocalRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["LocalRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *LocalRoutes) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// LocalRoutes_Aggregate represents the /openconfig-local-routing/local-routes/local-aggregates/aggregate YANG schema element.
type LocalRoutes_Aggregate struct {
	ΛMetadata    []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Description  *string                            `path:"state/description" shadow-path:"config/description" module:"openconfig-local-routing"`
	ΛDescription []ygot.Annotation                  `path:"state/@description" ygotAnnotation:"true"`
	Discard      *bool                              `path:"state/discard" shadow-path:"config/discard" module:"openconfig-local-routing"`
	ΛDiscard     []ygot.Annotation                  `path:"state/@discard" ygotAnnotation:"true"`
	Prefix       *string                            `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-local-routing"`
	ΛPrefix      []ygot.Annotation                  `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SetTag       LocalRoutes_Aggregate_SetTag_Union `path:"state/set-tag" shadow-path:"config/set-tag" module:"openconfig-local-routing"`
	ΛSetTag      []ygot.Annotation                  `path:"state/@set-tag" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that LocalRoutes_Aggregate implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*LocalRoutes_Aggregate) IsYANGGoStruct() {}

// GetDescription retrieves the value of the leaf Description from the LocalRoutes_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Aggregate) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetDiscard retrieves the value of the leaf Discard from the LocalRoutes_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Discard is set, it can safely use t.GetDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Discard == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Aggregate) GetDiscard() bool {
	if t == nil || t.Discard == nil {
		return false
	}
	return *t.Discard
}

// GetPrefix retrieves the value of the leaf Prefix from the LocalRoutes_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Aggregate) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSetTag retrieves the value of the leaf SetTag from the LocalRoutes_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetTag is set, it can safely use t.GetSetTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetTag == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Aggregate) GetSetTag() LocalRoutes_Aggregate_SetTag_Union {
	if t == nil || t.SetTag == nil {
		return nil
	}
	return t.SetTag
}

// ΛListKeyMap returns the keys of the LocalRoutes_Aggregate struct, which is a YANG list entry.
func (t *LocalRoutes_Aggregate) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *LocalRoutes_Aggregate) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["LocalRoutes_Aggregate"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *LocalRoutes_Aggregate) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// LocalRoutes_Aggregate_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/local-aggregates/aggregate/state/set-tag within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type LocalRoutes_Aggregate_SetTag_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_LocalRoutes_Aggregate_SetTag_Union()
}

// Documentation_for_LocalRoutes_Aggregate_SetTag_Union ensures that UnionString
// implements the LocalRoutes_Aggregate_SetTag_Union interface.
func (UnionString) Documentation_for_LocalRoutes_Aggregate_SetTag_Union() {}

// Documentation_for_LocalRoutes_Aggregate_SetTag_Union ensures that UnionUint32
// implements the LocalRoutes_Aggregate_SetTag_Union interface.
func (UnionUint32) Documentation_for_LocalRoutes_Aggregate_SetTag_Union() {}

// To_LocalRoutes_Aggregate_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the LocalRoutes_Aggregate_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *LocalRoutes_Aggregate) To_LocalRoutes_Aggregate_SetTag_Union(i interface{}) (LocalRoutes_Aggregate_SetTag_Union, error) {
	if v, ok := i.(LocalRoutes_Aggregate_SetTag_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to LocalRoutes_Aggregate_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// LocalRoutes_Static represents the /openconfig-local-routing/local-routes/static-routes/static YANG schema element.
type LocalRoutes_Static struct {
	ΛMetadata    []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Description  *string                                `path:"state/description" shadow-path:"config/description" module:"openconfig-local-routing"`
	ΛDescription []ygot.Annotation                      `path:"state/@description" ygotAnnotation:"true"`
	NextHop      map[string]*LocalRoutes_Static_NextHop `path:"next-hops/next-hop" module:"openconfig-local-routing"`
	ΛNextHop     []ygot.Annotation                      `path:"next-hops/@next-hop" ygotAnnotation:"true"`
	Prefix       *string                                `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-local-routing"`
	ΛPrefix      []ygot.Annotation                      `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SetTag       LocalRoutes_Static_SetTag_Union        `path:"state/set-tag" shadow-path:"config/set-tag" module:"openconfig-local-routing"`
	ΛSetTag      []ygot.Annotation                      `path:"state/@set-tag" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that LocalRoutes_Static implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*LocalRoutes_Static) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// LocalRoutes_Static struct. The keys of the list are populated from the input
// arguments.
func (t *LocalRoutes_Static) NewNextHop(Index string) (*LocalRoutes_Static_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[string]*LocalRoutes_Static_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &LocalRoutes_Static_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// RenameNextHop renames an entry in the list NextHop within
// the LocalRoutes_Static struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *LocalRoutes_Static) RenameNextHop(oldK, newK string) error {
	if _, ok := t.NextHop[newK]; ok {
		return fmt.Errorf("key %v already exists in NextHop", newK)
	}

	e, ok := t.NextHop[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NextHop", oldK)
	}
	e.Index = &newK

	t.NextHop[newK] = e
	delete(t.NextHop, oldK)
	return nil
}

// GetOrCreateNextHop retrieves the value with the specified keys from
// the receiver LocalRoutes_Static. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *LocalRoutes_Static) GetOrCreateNextHop(Index string) *LocalRoutes_Static_NextHop {

	key := Index

	if v, ok := t.NextHop[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNextHop(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNextHop got unexpected error: %v", err))
	}
	return v
}

// GetNextHop retrieves the value with the specified key from
// the NextHop map field of LocalRoutes_Static. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *LocalRoutes_Static) GetNextHop(Index string) *LocalRoutes_Static_NextHop {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.NextHop[key]; ok {
		return lm
	}
	return nil
}

// AppendNextHop appends the supplied LocalRoutes_Static_NextHop struct to the
// list NextHop of LocalRoutes_Static. If the key value(s) specified in
// the supplied LocalRoutes_Static_NextHop already exist in the list, an error is
// returned.
func (t *LocalRoutes_Static) AppendNextHop(v *LocalRoutes_Static_NextHop) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[string]*LocalRoutes_Static_NextHop)
	}

	if _, ok := t.NextHop[key]; ok {
		return fmt.Errorf("duplicate key for list NextHop %v", key)
	}

	t.NextHop[key] = v
	return nil
}

// GetDescription retrieves the value of the leaf Description from the LocalRoutes_Static
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetPrefix retrieves the value of the leaf Prefix from the LocalRoutes_Static
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSetTag retrieves the value of the leaf SetTag from the LocalRoutes_Static
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetTag is set, it can safely use t.GetSetTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetTag == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static) GetSetTag() LocalRoutes_Static_SetTag_Union {
	if t == nil || t.SetTag == nil {
		return nil
	}
	return t.SetTag
}

// ΛListKeyMap returns the keys of the LocalRoutes_Static struct, which is a YANG list entry.
func (t *LocalRoutes_Static) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *LocalRoutes_Static) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["LocalRoutes_Static"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *LocalRoutes_Static) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// LocalRoutes_Static_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/static-routes/static/state/set-tag within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type LocalRoutes_Static_SetTag_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_LocalRoutes_Static_SetTag_Union()
}

// Documentation_for_LocalRoutes_Static_SetTag_Union ensures that UnionString
// implements the LocalRoutes_Static_SetTag_Union interface.
func (UnionString) Documentation_for_LocalRoutes_Static_SetTag_Union() {}

// Documentation_for_LocalRoutes_Static_SetTag_Union ensures that UnionUint32
// implements the LocalRoutes_Static_SetTag_Union interface.
func (UnionUint32) Documentation_for_LocalRoutes_Static_SetTag_Union() {}

// To_LocalRoutes_Static_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the LocalRoutes_Static_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *LocalRoutes_Static) To_LocalRoutes_Static_SetTag_Union(i interface{}) (LocalRoutes_Static_SetTag_Union, error) {
	if v, ok := i.(LocalRoutes_Static_SetTag_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to LocalRoutes_Static_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// LocalRoutes_Static_NextHop represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop YANG schema element.
type LocalRoutes_Static_NextHop struct {
	ΛMetadata     []ygot.Annotation                        `path:"@" ygotAnnotation:"true"`
	Index         *string                                  `path:"state/index|index" shadow-path:"config/index" module:"openconfig-local-routing"`
	ΛIndex        []ygot.Annotation                        `path:"state/@index|@index" ygotAnnotation:"true"`
	InterfaceRef  *LocalRoutes_Static_NextHop_InterfaceRef `path:"interface-ref" module:"openconfig-local-routing"`
	ΛInterfaceRef []ygot.Annotation                        `path:"@interface-ref" ygotAnnotation:"true"`
	Metric        *uint32                                  `path:"state/metric" shadow-path:"config/metric" module:"openconfig-local-routing"`
	ΛMetric       []ygot.Annotation                        `path:"state/@metric" ygotAnnotation:"true"`
	NextHop       LocalRoutes_Static_NextHop_NextHop_Union `path:"state/next-hop" shadow-path:"config/next-hop" module:"openconfig-local-routing"`
	ΛNextHop      []ygot.Annotation                        `path:"state/@next-hop" ygotAnnotation:"true"`
	Recurse       *bool                                    `path:"state/recurse" shadow-path:"config/recurse" module:"openconfig-local-routing"`
	ΛRecurse      []ygot.Annotation                        `path:"state/@recurse" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that LocalRoutes_Static_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*LocalRoutes_Static_NextHop) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *LocalRoutes_Static_NextHop) GetOrCreateInterfaceRef() *LocalRoutes_Static_NextHop_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &LocalRoutes_Static_NextHop_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from LocalRoutes_Static_NextHop. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *LocalRoutes_Static_NextHop) GetInterfaceRef() *LocalRoutes_Static_NextHop_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetIndex retrieves the value of the leaf Index from the LocalRoutes_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static_NextHop) GetIndex() string {
	if t == nil || t.Index == nil {
		return ""
	}
	return *t.Index
}

// GetMetric retrieves the value of the leaf Metric from the LocalRoutes_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static_NextHop) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetNextHop retrieves the value of the leaf NextHop from the LocalRoutes_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static_NextHop) GetNextHop() LocalRoutes_Static_NextHop_NextHop_Union {
	if t == nil || t.NextHop == nil {
		return nil
	}
	return t.NextHop
}

// GetRecurse retrieves the value of the leaf Recurse from the LocalRoutes_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Recurse is set, it can safely use t.GetRecurse()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Recurse == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static_NextHop) GetRecurse() bool {
	if t == nil || t.Recurse == nil {
		return false
	}
	return *t.Recurse
}

// ΛListKeyMap returns the keys of the LocalRoutes_Static_NextHop struct, which is a YANG list entry.
func (t *LocalRoutes_Static_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *LocalRoutes_Static_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["LocalRoutes_Static_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *LocalRoutes_Static_NextHop) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// LocalRoutes_Static_NextHop_NextHop_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/state/next-hop within the YANG schema.
// Union type can be one of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, UnionString].
type LocalRoutes_Static_NextHop_NextHop_Union interface {
	// Union type can be one of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, UnionString]
	Documentation_for_LocalRoutes_Static_NextHop_NextHop_Union()
}

// Documentation_for_LocalRoutes_Static_NextHop_NextHop_Union ensures that E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
// implements the LocalRoutes_Static_NextHop_NextHop_Union interface.
func (E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) Documentation_for_LocalRoutes_Static_NextHop_NextHop_Union() {
}

// Documentation_for_LocalRoutes_Static_NextHop_NextHop_Union ensures that UnionString
// implements the LocalRoutes_Static_NextHop_NextHop_Union interface.
func (UnionString) Documentation_for_LocalRoutes_Static_NextHop_NextHop_Union() {}

// To_LocalRoutes_Static_NextHop_NextHop_Union takes an input interface{} and attempts to convert it to a struct
// which implements the LocalRoutes_Static_NextHop_NextHop_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *LocalRoutes_Static_NextHop) To_LocalRoutes_Static_NextHop_NextHop_Union(i interface{}) (LocalRoutes_Static_NextHop_NextHop_Union, error) {
	if v, ok := i.(LocalRoutes_Static_NextHop_NextHop_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to LocalRoutes_Static_NextHop_NextHop_Union, unknown union type, got: %T, want any of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, string]", i, i)
}

// LocalRoutes_Static_NextHop_InterfaceRef represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/interface-ref YANG schema element.
type LocalRoutes_Static_NextHop_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-local-routing"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-local-routing"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that LocalRoutes_Static_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*LocalRoutes_Static_NextHop_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the LocalRoutes_Static_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static_NextHop_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the LocalRoutes_Static_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *LocalRoutes_Static_NextHop_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *LocalRoutes_Static_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["LocalRoutes_Static_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *LocalRoutes_Static_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Messages represents the /openconfig-messages/messages YANG schema element.
type Messages struct {
	ΛMetadata     []ygot.Annotation                                             `path:"@" ygotAnnotation:"true"`
	DebugService  map[E_OpenconfigMessages_DEBUG_SERVICE]*Messages_DebugService `path:"debug-entries/debug-service" module:"openconfig-messages"`
	ΛDebugService []ygot.Annotation                                             `path:"debug-entries/@debug-service" ygotAnnotation:"true"`
	Message       *Messages_Message                                             `path:"state/message" module:"openconfig-messages"`
	ΛMessage      []ygot.Annotation                                             `path:"state/@message" ygotAnnotation:"true"`
	Severity      E_OpenconfigSystemLogging_SyslogSeverity                      `path:"state/severity" shadow-path:"config/severity" module:"openconfig-messages"`
	ΛSeverity     []ygot.Annotation                                             `path:"state/@severity" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Messages) IsYANGGoStruct() {}

// NewDebugService creates a new entry in the DebugService list of the
// Messages struct. The keys of the list are populated from the input
// arguments.
func (t *Messages) NewDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) (*Messages_DebugService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DebugService == nil {
		t.DebugService = make(map[E_OpenconfigMessages_DEBUG_SERVICE]*Messages_DebugService)
	}

	key := Service

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DebugService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DebugService", key)
	}

	t.DebugService[key] = &Messages_DebugService{
		Service: Service,
	}

	return t.DebugService[key], nil
}

// RenameDebugService renames an entry in the list DebugService within
// the Messages struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Messages) RenameDebugService(oldK, newK E_OpenconfigMessages_DEBUG_SERVICE) error {
	if _, ok := t.DebugService[newK]; ok {
		return fmt.Errorf("key %v already exists in DebugService", newK)
	}

	e, ok := t.DebugService[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in DebugService", oldK)
	}
	e.Service = newK

	t.DebugService[newK] = e
	delete(t.DebugService, oldK)
	return nil
}

// GetOrCreateDebugService retrieves the value with the specified keys from
// the receiver Messages. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Messages) GetOrCreateDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) *Messages_DebugService {

	key := Service

	if v, ok := t.DebugService[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewDebugService(Service)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateDebugService got unexpected error: %v", err))
	}
	return v
}

// GetDebugService retrieves the value with the specified key from
// the DebugService map field of Messages. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Messages) GetDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) *Messages_DebugService {

	if t == nil {
		return nil
	}

	key := Service

	if lm, ok := t.DebugService[key]; ok {
		return lm
	}
	return nil
}

// AppendDebugService appends the supplied Messages_DebugService struct to the
// list DebugService of Messages. If the key value(s) specified in
// the supplied Messages_DebugService already exist in the list, an error is
// returned.
func (t *Messages) AppendDebugService(v *Messages_DebugService) error {
	key := v.Service

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DebugService == nil {
		t.DebugService = make(map[E_OpenconfigMessages_DEBUG_SERVICE]*Messages_DebugService)
	}

	if _, ok := t.DebugService[key]; ok {
		return fmt.Errorf("duplicate key for list DebugService %v", key)
	}

	t.DebugService[key] = v
	return nil
}

// GetOrCreateMessage retrieves the value of the Message field
// or returns the existing field if it already exists.
func (t *Messages) GetOrCreateMessage() *Messages_Message {
	if t.Message != nil {
		return t.Message
	}
	t.Message = &Messages_Message{}
	return t.Message
}

// GetMessage returns the value of the Message struct pointer
// from Messages. If the receiver or the field Message is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Messages) GetMessage() *Messages_Message {
	if t != nil && t.Message != nil {
		return t.Message
	}
	return nil
}

// GetSeverity retrieves the value of the leaf Severity from the Messages
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Severity is set, it can safely use t.GetSeverity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Severity == nil'
// before retrieving the leaf's value.
func (t *Messages) GetSeverity() E_OpenconfigSystemLogging_SyslogSeverity {
	if t == nil || t.Severity == 0 {
		return 0
	}
	return t.Severity
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Messages) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Messages_DebugService represents the /openconfig-messages/messages/debug-entries/debug-service YANG schema element.
type Messages_DebugService struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Enabled   *bool                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-messages"`
	ΛEnabled  []ygot.Annotation                  `path:"state/@enabled" ygotAnnotation:"true"`
	Service   E_OpenconfigMessages_DEBUG_SERVICE `path:"state/service|service" shadow-path:"config/service" module:"openconfig-messages"`
	ΛService  []ygot.Annotation                  `path:"state/@service|@service" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Messages_DebugService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Messages_DebugService) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the Messages_DebugService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *Messages_DebugService) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetService retrieves the value of the leaf Service from the Messages_DebugService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Service is set, it can safely use t.GetService()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Service == nil'
// before retrieving the leaf's value.
func (t *Messages_DebugService) GetService() E_OpenconfigMessages_DEBUG_SERVICE {
	if t == nil || t.Service == 0 {
		return 0
	}
	return t.Service
}

// ΛListKeyMap returns the keys of the Messages_DebugService struct, which is a YANG list entry.
func (t *Messages_DebugService) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"service": t.Service,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Messages_DebugService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Messages_DebugService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Messages_DebugService) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Messages_Message represents the /openconfig-messages/messages/state/message YANG schema element.
type Messages_Message struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AppName   *string           `path:"app-name" module:"openconfig-messages"`
	ΛAppName  []ygot.Annotation `path:"@app-name" ygotAnnotation:"true"`
	Msg       *string           `path:"msg" module:"openconfig-messages"`
	ΛMsg      []ygot.Annotation `path:"@msg" ygotAnnotation:"true"`
	Msgid     *string           `path:"msgid" module:"openconfig-messages"`
	ΛMsgid    []ygot.Annotation `path:"@msgid" ygotAnnotation:"true"`
	Priority  *uint8            `path:"priority" module:"openconfig-messages"`
	ΛPriority []ygot.Annotation `path:"@priority" ygotAnnotation:"true"`
	Procid    *string           `path:"procid" module:"openconfig-messages"`
	ΛProcid   []ygot.Annotation `path:"@procid" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Messages_Message implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Messages_Message) IsYANGGoStruct() {}

// GetAppName retrieves the value of the leaf AppName from the Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AppName is set, it can safely use t.GetAppName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AppName == nil'
// before retrieving the leaf's value.
func (t *Messages_Message) GetAppName() string {
	if t == nil || t.AppName == nil {
		return ""
	}
	return *t.AppName
}

// GetMsg retrieves the value of the leaf Msg from the Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Msg is set, it can safely use t.GetMsg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Msg == nil'
// before retrieving the leaf's value.
func (t *Messages_Message) GetMsg() string {
	if t == nil || t.Msg == nil {
		return ""
	}
	return *t.Msg
}

// GetMsgid retrieves the value of the leaf Msgid from the Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Msgid is set, it can safely use t.GetMsgid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Msgid == nil'
// before retrieving the leaf's value.
func (t *Messages_Message) GetMsgid() string {
	if t == nil || t.Msgid == nil {
		return ""
	}
	return *t.Msgid
}

// GetPriority retrieves the value of the leaf Priority from the Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *Messages_Message) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetProcid retrieves the value of the leaf Procid from the Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Procid is set, it can safely use t.GetProcid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Procid == nil'
// before retrieving the leaf's value.
func (t *Messages_Message) GetProcid() string {
	if t == nil || t.Procid == nil {
		return ""
	}
	return *t.Procid
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Messages_Message) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Messages_Message"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Messages_Message) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance represents the /openconfig-network-instance/network-instances/network-instance YANG schema element.
type NetworkInstance struct {
	ΛMetadata               []ygot.Annotation                                                        `path:"@" ygotAnnotation:"true"`
	Afts                    *NetworkInstance_Afts                                                    `path:"afts" module:"openconfig-network-instance"`
	ΛAfts                   []ygot.Annotation                                                        `path:"@afts" ygotAnnotation:"true"`
	ConnectionPoint         map[string]*NetworkInstance_ConnectionPoint                              `path:"connection-points/connection-point" module:"openconfig-network-instance"`
	ΛConnectionPoint        []ygot.Annotation                                                        `path:"connection-points/@connection-point" ygotAnnotation:"true"`
	Description             *string                                                                  `path:"state/description" shadow-path:"config/description" module:"openconfig-network-instance"`
	ΛDescription            []ygot.Annotation                                                        `path:"state/@description" ygotAnnotation:"true"`
	Enabled                 *bool                                                                    `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled                []ygot.Annotation                                                        `path:"state/@enabled" ygotAnnotation:"true"`
	EnabledAddressFamilies  []E_OpenconfigTypes_ADDRESS_FAMILY                                       `path:"state/enabled-address-families" shadow-path:"config/enabled-address-families" module:"openconfig-network-instance"`
	ΛEnabledAddressFamilies []ygot.Annotation                                                        `path:"state/@enabled-address-families" ygotAnnotation:"true"`
	Encapsulation           *NetworkInstance_Encapsulation                                           `path:"encapsulation" module:"openconfig-network-instance"`
	ΛEncapsulation          []ygot.Annotation                                                        `path:"@encapsulation" ygotAnnotation:"true"`
	Fdb                     *NetworkInstance_Fdb                                                     `path:"fdb" module:"openconfig-network-instance"`
	ΛFdb                    []ygot.Annotation                                                        `path:"@fdb" ygotAnnotation:"true"`
	InterInstancePolicies   *NetworkInstance_InterInstancePolicies                                   `path:"inter-instance-policies" module:"openconfig-network-instance"`
	ΛInterInstancePolicies  []ygot.Annotation                                                        `path:"@inter-instance-policies" ygotAnnotation:"true"`
	Interface               map[string]*NetworkInstance_Interface                                    `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface              []ygot.Annotation                                                        `path:"interfaces/@interface" ygotAnnotation:"true"`
	Mpls                    *NetworkInstance_Mpls                                                    `path:"mpls" module:"openconfig-network-instance"`
	ΛMpls                   []ygot.Annotation                                                        `path:"@mpls" ygotAnnotation:"true"`
	Mtu                     *uint16                                                                  `path:"state/mtu" shadow-path:"config/mtu" module:"openconfig-network-instance"`
	ΛMtu                    []ygot.Annotation                                                        `path:"state/@mtu" ygotAnnotation:"true"`
	Name                    *string                                                                  `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName                   []ygot.Annotation                                                        `path:"state/@name|@name" ygotAnnotation:"true"`
	PolicyForwarding        *NetworkInstance_PolicyForwarding                                        `path:"policy-forwarding" module:"openconfig-network-instance"`
	ΛPolicyForwarding       []ygot.Annotation                                                        `path:"@policy-forwarding" ygotAnnotation:"true"`
	Protocol                map[NetworkInstance_Protocol_Key]*NetworkInstance_Protocol               `path:"protocols/protocol" module:"openconfig-network-instance"`
	ΛProtocol               []ygot.Annotation                                                        `path:"protocols/@protocol" ygotAnnotation:"true"`
	RouteDistinguisher      *string                                                                  `path:"state/route-distinguisher" shadow-path:"config/route-distinguisher" module:"openconfig-network-instance"`
	ΛRouteDistinguisher     []ygot.Annotation                                                        `path:"state/@route-distinguisher" ygotAnnotation:"true"`
	RouteLimit              map[E_OpenconfigTypes_ADDRESS_FAMILY]*NetworkInstance_RouteLimit         `path:"route-limits/route-limit" module:"openconfig-network-instance"`
	ΛRouteLimit             []ygot.Annotation                                                        `path:"route-limits/@route-limit" ygotAnnotation:"true"`
	RouterId                *string                                                                  `path:"state/router-id" shadow-path:"config/router-id" module:"openconfig-network-instance"`
	ΛRouterId               []ygot.Annotation                                                        `path:"state/@router-id" ygotAnnotation:"true"`
	SegmentRouting          *NetworkInstance_SegmentRouting                                          `path:"segment-routing" module:"openconfig-network-instance"`
	ΛSegmentRouting         []ygot.Annotation                                                        `path:"@segment-routing" ygotAnnotation:"true"`
	Table                   map[NetworkInstance_Table_Key]*NetworkInstance_Table                     `path:"tables/table" module:"openconfig-network-instance"`
	ΛTable                  []ygot.Annotation                                                        `path:"tables/@table" ygotAnnotation:"true"`
	TableConnection         map[NetworkInstance_TableConnection_Key]*NetworkInstance_TableConnection `path:"table-connections/table-connection" module:"openconfig-network-instance"`
	ΛTableConnection        []ygot.Annotation                                                        `path:"table-connections/@table-connection" ygotAnnotation:"true"`
	Type                    E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE                   `path:"state/type" shadow-path:"config/type" module:"openconfig-network-instance"`
	ΛType                   []ygot.Annotation                                                        `path:"state/@type" ygotAnnotation:"true"`
	Vlan                    map[uint16]*NetworkInstance_Vlan                                         `path:"vlans/vlan" module:"openconfig-network-instance"`
	ΛVlan                   []ygot.Annotation                                                        `path:"vlans/@vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Key represents the key for list Protocol of element /openconfig-network-instance/network-instances/network-instance.
type NetworkInstance_Protocol_Key struct {
	Identifier E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"identifier"`
	Name       string                                        `path:"name"`
}

// NetworkInstance_Table_Key represents the key for list Table of element /openconfig-network-instance/network-instances/network-instance.
type NetworkInstance_Table_Key struct {
	Protocol      E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"protocol"`
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family"`
}

// NetworkInstance_TableConnection_Key represents the key for list TableConnection of element /openconfig-network-instance/network-instances/network-instance.
type NetworkInstance_TableConnection_Key struct {
	SrcProtocol   E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"src-protocol"`
	DstProtocol   E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"dst-protocol"`
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family"`
}

// NewConnectionPoint creates a new entry in the ConnectionPoint list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewConnectionPoint(ConnectionPointId string) (*NetworkInstance_ConnectionPoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ConnectionPoint == nil {
		t.ConnectionPoint = make(map[string]*NetworkInstance_ConnectionPoint)
	}

	key := ConnectionPointId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ConnectionPoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ConnectionPoint", key)
	}

	t.ConnectionPoint[key] = &NetworkInstance_ConnectionPoint{
		ConnectionPointId: &ConnectionPointId,
	}

	return t.ConnectionPoint[key], nil
}

// RenameConnectionPoint renames an entry in the list ConnectionPoint within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameConnectionPoint(oldK, newK string) error {
	if _, ok := t.ConnectionPoint[newK]; ok {
		return fmt.Errorf("key %v already exists in ConnectionPoint", newK)
	}

	e, ok := t.ConnectionPoint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ConnectionPoint", oldK)
	}
	e.ConnectionPointId = &newK

	t.ConnectionPoint[newK] = e
	delete(t.ConnectionPoint, oldK)
	return nil
}

// GetOrCreateConnectionPoint retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateConnectionPoint(ConnectionPointId string) *NetworkInstance_ConnectionPoint {

	key := ConnectionPointId

	if v, ok := t.ConnectionPoint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewConnectionPoint(ConnectionPointId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateConnectionPoint got unexpected error: %v", err))
	}
	return v
}

// GetConnectionPoint retrieves the value with the specified key from
// the ConnectionPoint map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetConnectionPoint(ConnectionPointId string) *NetworkInstance_ConnectionPoint {

	if t == nil {
		return nil
	}

	key := ConnectionPointId

	if lm, ok := t.ConnectionPoint[key]; ok {
		return lm
	}
	return nil
}

// AppendConnectionPoint appends the supplied NetworkInstance_ConnectionPoint struct to the
// list ConnectionPoint of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_ConnectionPoint already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendConnectionPoint(v *NetworkInstance_ConnectionPoint) error {
	if v.ConnectionPointId == nil {
		return fmt.Errorf("invalid nil key received for ConnectionPointId")
	}

	key := *v.ConnectionPointId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ConnectionPoint == nil {
		t.ConnectionPoint = make(map[string]*NetworkInstance_ConnectionPoint)
	}

	if _, ok := t.ConnectionPoint[key]; ok {
		return fmt.Errorf("duplicate key for list ConnectionPoint %v", key)
	}

	t.ConnectionPoint[key] = v
	return nil
}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewInterface(Id string) (*NetworkInstance_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Id = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateInterface(Id string) *NetworkInstance_Interface {

	key := Id

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetInterface(Id string) *NetworkInstance_Interface {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Interface struct to the
// list Interface of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendInterface(v *NetworkInstance_Interface) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewProtocol creates a new entry in the Protocol list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewProtocol(Identifier E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, Name string) (*NetworkInstance_Protocol, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Protocol == nil {
		t.Protocol = make(map[NetworkInstance_Protocol_Key]*NetworkInstance_Protocol)
	}

	key := NetworkInstance_Protocol_Key{
		Identifier: Identifier,
		Name:       Name,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Protocol[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Protocol", key)
	}

	t.Protocol[key] = &NetworkInstance_Protocol{
		Identifier: Identifier,
		Name:       &Name,
	}

	return t.Protocol[key], nil
}

// RenameProtocol renames an entry in the list Protocol within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameProtocol(oldK, newK NetworkInstance_Protocol_Key) error {
	if _, ok := t.Protocol[newK]; ok {
		return fmt.Errorf("key %v already exists in Protocol", newK)
	}

	e, ok := t.Protocol[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Protocol", oldK)
	}
	e.Identifier = newK.Identifier
	e.Name = &newK.Name

	t.Protocol[newK] = e
	delete(t.Protocol, oldK)
	return nil
}

// GetOrCreateProtocol retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateProtocol(Identifier E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, Name string) *NetworkInstance_Protocol {

	key := NetworkInstance_Protocol_Key{
		Identifier: Identifier,
		Name:       Name,
	}

	if v, ok := t.Protocol[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewProtocol(Identifier, Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateProtocol got unexpected error: %v", err))
	}
	return v
}

// GetProtocol retrieves the value with the specified key from
// the Protocol map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetProtocol(Identifier E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, Name string) *NetworkInstance_Protocol {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Key{
		Identifier: Identifier,
		Name:       Name,
	}

	if lm, ok := t.Protocol[key]; ok {
		return lm
	}
	return nil
}

// AppendProtocol appends the supplied NetworkInstance_Protocol struct to the
// list Protocol of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendProtocol(v *NetworkInstance_Protocol) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key for Name")
	}

	key := NetworkInstance_Protocol_Key{
		Identifier: v.Identifier,
		Name:       *v.Name,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Protocol == nil {
		t.Protocol = make(map[NetworkInstance_Protocol_Key]*NetworkInstance_Protocol)
	}

	if _, ok := t.Protocol[key]; ok {
		return fmt.Errorf("duplicate key for list Protocol %v", key)
	}

	t.Protocol[key] = v
	return nil
}

// NewRouteLimit creates a new entry in the RouteLimit list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewRouteLimit(Afi E_OpenconfigTypes_ADDRESS_FAMILY) (*NetworkInstance_RouteLimit, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RouteLimit == nil {
		t.RouteLimit = make(map[E_OpenconfigTypes_ADDRESS_FAMILY]*NetworkInstance_RouteLimit)
	}

	key := Afi

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RouteLimit[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RouteLimit", key)
	}

	t.RouteLimit[key] = &NetworkInstance_RouteLimit{
		Afi: Afi,
	}

	return t.RouteLimit[key], nil
}

// RenameRouteLimit renames an entry in the list RouteLimit within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameRouteLimit(oldK, newK E_OpenconfigTypes_ADDRESS_FAMILY) error {
	if _, ok := t.RouteLimit[newK]; ok {
		return fmt.Errorf("key %v already exists in RouteLimit", newK)
	}

	e, ok := t.RouteLimit[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in RouteLimit", oldK)
	}
	e.Afi = newK

	t.RouteLimit[newK] = e
	delete(t.RouteLimit, oldK)
	return nil
}

// GetOrCreateRouteLimit retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateRouteLimit(Afi E_OpenconfigTypes_ADDRESS_FAMILY) *NetworkInstance_RouteLimit {

	key := Afi

	if v, ok := t.RouteLimit[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRouteLimit(Afi)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRouteLimit got unexpected error: %v", err))
	}
	return v
}

// GetRouteLimit retrieves the value with the specified key from
// the RouteLimit map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetRouteLimit(Afi E_OpenconfigTypes_ADDRESS_FAMILY) *NetworkInstance_RouteLimit {

	if t == nil {
		return nil
	}

	key := Afi

	if lm, ok := t.RouteLimit[key]; ok {
		return lm
	}
	return nil
}

// AppendRouteLimit appends the supplied NetworkInstance_RouteLimit struct to the
// list RouteLimit of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_RouteLimit already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendRouteLimit(v *NetworkInstance_RouteLimit) error {
	key := v.Afi

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RouteLimit == nil {
		t.RouteLimit = make(map[E_OpenconfigTypes_ADDRESS_FAMILY]*NetworkInstance_RouteLimit)
	}

	if _, ok := t.RouteLimit[key]; ok {
		return fmt.Errorf("duplicate key for list RouteLimit %v", key)
	}

	t.RouteLimit[key] = v
	return nil
}

// NewTable creates a new entry in the Table list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewTable(Protocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) (*NetworkInstance_Table, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Table == nil {
		t.Table = make(map[NetworkInstance_Table_Key]*NetworkInstance_Table)
	}

	key := NetworkInstance_Table_Key{
		Protocol:      Protocol,
		AddressFamily: AddressFamily,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Table[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Table", key)
	}

	t.Table[key] = &NetworkInstance_Table{
		Protocol:      Protocol,
		AddressFamily: AddressFamily,
	}

	return t.Table[key], nil
}

// RenameTable renames an entry in the list Table within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameTable(oldK, newK NetworkInstance_Table_Key) error {
	if _, ok := t.Table[newK]; ok {
		return fmt.Errorf("key %v already exists in Table", newK)
	}

	e, ok := t.Table[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Table", oldK)
	}
	e.Protocol = newK.Protocol
	e.AddressFamily = newK.AddressFamily

	t.Table[newK] = e
	delete(t.Table, oldK)
	return nil
}

// GetOrCreateTable retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateTable(Protocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) *NetworkInstance_Table {

	key := NetworkInstance_Table_Key{
		Protocol:      Protocol,
		AddressFamily: AddressFamily,
	}

	if v, ok := t.Table[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTable(Protocol, AddressFamily)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTable got unexpected error: %v", err))
	}
	return v
}

// GetTable retrieves the value with the specified key from
// the Table map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetTable(Protocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) *NetworkInstance_Table {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Table_Key{
		Protocol:      Protocol,
		AddressFamily: AddressFamily,
	}

	if lm, ok := t.Table[key]; ok {
		return lm
	}
	return nil
}

// AppendTable appends the supplied NetworkInstance_Table struct to the
// list Table of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_Table already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendTable(v *NetworkInstance_Table) error {
	key := NetworkInstance_Table_Key{
		Protocol:      v.Protocol,
		AddressFamily: v.AddressFamily,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Table == nil {
		t.Table = make(map[NetworkInstance_Table_Key]*NetworkInstance_Table)
	}

	if _, ok := t.Table[key]; ok {
		return fmt.Errorf("duplicate key for list Table %v", key)
	}

	t.Table[key] = v
	return nil
}

// NewTableConnection creates a new entry in the TableConnection list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewTableConnection(SrcProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, DstProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) (*NetworkInstance_TableConnection, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TableConnection == nil {
		t.TableConnection = make(map[NetworkInstance_TableConnection_Key]*NetworkInstance_TableConnection)
	}

	key := NetworkInstance_TableConnection_Key{
		SrcProtocol:   SrcProtocol,
		DstProtocol:   DstProtocol,
		AddressFamily: AddressFamily,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TableConnection[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TableConnection", key)
	}

	t.TableConnection[key] = &NetworkInstance_TableConnection{
		SrcProtocol:   SrcProtocol,
		DstProtocol:   DstProtocol,
		AddressFamily: AddressFamily,
	}

	return t.TableConnection[key], nil
}

// RenameTableConnection renames an entry in the list TableConnection within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameTableConnection(oldK, newK NetworkInstance_TableConnection_Key) error {
	if _, ok := t.TableConnection[newK]; ok {
		return fmt.Errorf("key %v already exists in TableConnection", newK)
	}

	e, ok := t.TableConnection[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TableConnection", oldK)
	}
	e.SrcProtocol = newK.SrcProtocol
	e.DstProtocol = newK.DstProtocol
	e.AddressFamily = newK.AddressFamily

	t.TableConnection[newK] = e
	delete(t.TableConnection, oldK)
	return nil
}

// GetOrCreateTableConnection retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateTableConnection(SrcProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, DstProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) *NetworkInstance_TableConnection {

	key := NetworkInstance_TableConnection_Key{
		SrcProtocol:   SrcProtocol,
		DstProtocol:   DstProtocol,
		AddressFamily: AddressFamily,
	}

	if v, ok := t.TableConnection[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTableConnection(SrcProtocol, DstProtocol, AddressFamily)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTableConnection got unexpected error: %v", err))
	}
	return v
}

// GetTableConnection retrieves the value with the specified key from
// the TableConnection map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetTableConnection(SrcProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, DstProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) *NetworkInstance_TableConnection {

	if t == nil {
		return nil
	}

	key := NetworkInstance_TableConnection_Key{
		SrcProtocol:   SrcProtocol,
		DstProtocol:   DstProtocol,
		AddressFamily: AddressFamily,
	}

	if lm, ok := t.TableConnection[key]; ok {
		return lm
	}
	return nil
}

// AppendTableConnection appends the supplied NetworkInstance_TableConnection struct to the
// list TableConnection of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_TableConnection already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendTableConnection(v *NetworkInstance_TableConnection) error {
	key := NetworkInstance_TableConnection_Key{
		SrcProtocol:   v.SrcProtocol,
		DstProtocol:   v.DstProtocol,
		AddressFamily: v.AddressFamily,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TableConnection == nil {
		t.TableConnection = make(map[NetworkInstance_TableConnection_Key]*NetworkInstance_TableConnection)
	}

	if _, ok := t.TableConnection[key]; ok {
		return fmt.Errorf("duplicate key for list TableConnection %v", key)
	}

	t.TableConnection[key] = v
	return nil
}

// NewVlan creates a new entry in the Vlan list of the
// NetworkInstance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance) NewVlan(VlanId uint16) (*NetworkInstance_Vlan, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Vlan == nil {
		t.Vlan = make(map[uint16]*NetworkInstance_Vlan)
	}

	key := VlanId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Vlan[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Vlan", key)
	}

	t.Vlan[key] = &NetworkInstance_Vlan{
		VlanId: &VlanId,
	}

	return t.Vlan[key], nil
}

// RenameVlan renames an entry in the list Vlan within
// the NetworkInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance) RenameVlan(oldK, newK uint16) error {
	if _, ok := t.Vlan[newK]; ok {
		return fmt.Errorf("key %v already exists in Vlan", newK)
	}

	e, ok := t.Vlan[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Vlan", oldK)
	}
	e.VlanId = &newK

	t.Vlan[newK] = e
	delete(t.Vlan, oldK)
	return nil
}

// GetOrCreateVlan retrieves the value with the specified keys from
// the receiver NetworkInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance) GetOrCreateVlan(VlanId uint16) *NetworkInstance_Vlan {

	key := VlanId

	if v, ok := t.Vlan[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVlan(VlanId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVlan got unexpected error: %v", err))
	}
	return v
}

// GetVlan retrieves the value with the specified key from
// the Vlan map field of NetworkInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance) GetVlan(VlanId uint16) *NetworkInstance_Vlan {

	if t == nil {
		return nil
	}

	key := VlanId

	if lm, ok := t.Vlan[key]; ok {
		return lm
	}
	return nil
}

// AppendVlan appends the supplied NetworkInstance_Vlan struct to the
// list Vlan of NetworkInstance. If the key value(s) specified in
// the supplied NetworkInstance_Vlan already exist in the list, an error is
// returned.
func (t *NetworkInstance) AppendVlan(v *NetworkInstance_Vlan) error {
	if v.VlanId == nil {
		return fmt.Errorf("invalid nil key received for VlanId")
	}

	key := *v.VlanId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Vlan == nil {
		t.Vlan = make(map[uint16]*NetworkInstance_Vlan)
	}

	if _, ok := t.Vlan[key]; ok {
		return fmt.Errorf("duplicate key for list Vlan %v", key)
	}

	t.Vlan[key] = v
	return nil
}

// GetOrCreateAfts retrieves the value of the Afts field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreateAfts() *NetworkInstance_Afts {
	if t.Afts != nil {
		return t.Afts
	}
	t.Afts = &NetworkInstance_Afts{}
	return t.Afts
}

// GetOrCreateEncapsulation retrieves the value of the Encapsulation field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreateEncapsulation() *NetworkInstance_Encapsulation {
	if t.Encapsulation != nil {
		return t.Encapsulation
	}
	t.Encapsulation = &NetworkInstance_Encapsulation{}
	return t.Encapsulation
}

// GetOrCreateFdb retrieves the value of the Fdb field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreateFdb() *NetworkInstance_Fdb {
	if t.Fdb != nil {
		return t.Fdb
	}
	t.Fdb = &NetworkInstance_Fdb{}
	return t.Fdb
}

// GetOrCreateInterInstancePolicies retrieves the value of the InterInstancePolicies field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreateInterInstancePolicies() *NetworkInstance_InterInstancePolicies {
	if t.InterInstancePolicies != nil {
		return t.InterInstancePolicies
	}
	t.InterInstancePolicies = &NetworkInstance_InterInstancePolicies{}
	return t.InterInstancePolicies
}

// GetOrCreateMpls retrieves the value of the Mpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreateMpls() *NetworkInstance_Mpls {
	if t.Mpls != nil {
		return t.Mpls
	}
	t.Mpls = &NetworkInstance_Mpls{}
	return t.Mpls
}

// GetOrCreatePolicyForwarding retrieves the value of the PolicyForwarding field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreatePolicyForwarding() *NetworkInstance_PolicyForwarding {
	if t.PolicyForwarding != nil {
		return t.PolicyForwarding
	}
	t.PolicyForwarding = &NetworkInstance_PolicyForwarding{}
	return t.PolicyForwarding
}

// GetOrCreateSegmentRouting retrieves the value of the SegmentRouting field
// or returns the existing field if it already exists.
func (t *NetworkInstance) GetOrCreateSegmentRouting() *NetworkInstance_SegmentRouting {
	if t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	t.SegmentRouting = &NetworkInstance_SegmentRouting{}
	return t.SegmentRouting
}

// GetAfts returns the value of the Afts struct pointer
// from NetworkInstance. If the receiver or the field Afts is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetAfts() *NetworkInstance_Afts {
	if t != nil && t.Afts != nil {
		return t.Afts
	}
	return nil
}

// GetEncapsulation returns the value of the Encapsulation struct pointer
// from NetworkInstance. If the receiver or the field Encapsulation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetEncapsulation() *NetworkInstance_Encapsulation {
	if t != nil && t.Encapsulation != nil {
		return t.Encapsulation
	}
	return nil
}

// GetFdb returns the value of the Fdb struct pointer
// from NetworkInstance. If the receiver or the field Fdb is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetFdb() *NetworkInstance_Fdb {
	if t != nil && t.Fdb != nil {
		return t.Fdb
	}
	return nil
}

// GetInterInstancePolicies returns the value of the InterInstancePolicies struct pointer
// from NetworkInstance. If the receiver or the field InterInstancePolicies is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetInterInstancePolicies() *NetworkInstance_InterInstancePolicies {
	if t != nil && t.InterInstancePolicies != nil {
		return t.InterInstancePolicies
	}
	return nil
}

// GetMpls returns the value of the Mpls struct pointer
// from NetworkInstance. If the receiver or the field Mpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetMpls() *NetworkInstance_Mpls {
	if t != nil && t.Mpls != nil {
		return t.Mpls
	}
	return nil
}

// GetPolicyForwarding returns the value of the PolicyForwarding struct pointer
// from NetworkInstance. If the receiver or the field PolicyForwarding is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetPolicyForwarding() *NetworkInstance_PolicyForwarding {
	if t != nil && t.PolicyForwarding != nil {
		return t.PolicyForwarding
	}
	return nil
}

// GetSegmentRouting returns the value of the SegmentRouting struct pointer
// from NetworkInstance. If the receiver or the field SegmentRouting is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance) GetSegmentRouting() *NetworkInstance_SegmentRouting {
	if t != nil && t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	return nil
}

// GetDescription retrieves the value of the leaf Description from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetEnabledAddressFamilies retrieves the value of the leaf EnabledAddressFamilies from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnabledAddressFamilies is set, it can safely use t.GetEnabledAddressFamilies()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnabledAddressFamilies == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetEnabledAddressFamilies() []E_OpenconfigTypes_ADDRESS_FAMILY {
	if t == nil || t.EnabledAddressFamilies == nil {
		return nil
	}
	return t.EnabledAddressFamilies
}

// GetMtu retrieves the value of the leaf Mtu from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mtu is set, it can safely use t.GetMtu()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mtu == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetMtu() uint16 {
	if t == nil || t.Mtu == nil {
		return 0
	}
	return *t.Mtu
}

// GetName retrieves the value of the leaf Name from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetRouteDistinguisher retrieves the value of the leaf RouteDistinguisher from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteDistinguisher is set, it can safely use t.GetRouteDistinguisher()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteDistinguisher == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetRouteDistinguisher() string {
	if t == nil || t.RouteDistinguisher == nil {
		return ""
	}
	return *t.RouteDistinguisher
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance) GetType() E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance struct, which is a YANG list entry.
func (t *NetworkInstance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Afts represents the /openconfig-network-instance/network-instances/network-instance/afts YANG schema element.
type NetworkInstance_Afts struct {
	ΛMetadata              []ygot.Annotation                                                                `path:"@" ygotAnnotation:"true"`
	Ipv4Entry              map[string]*NetworkInstance_Afts_Ipv4Entry                                       `path:"ipv4-unicast/ipv4-entry" module:"openconfig-network-instance"`
	ΛIpv4Entry             []ygot.Annotation                                                                `path:"ipv4-unicast/@ipv4-entry" ygotAnnotation:"true"`
	Ipv6Entry              map[string]*NetworkInstance_Afts_Ipv6Entry                                       `path:"ipv6-unicast/ipv6-entry" module:"openconfig-network-instance"`
	ΛIpv6Entry             []ygot.Annotation                                                                `path:"ipv6-unicast/@ipv6-entry" ygotAnnotation:"true"`
	LabelEntry             map[NetworkInstance_Afts_LabelEntry_Label_Union]*NetworkInstance_Afts_LabelEntry `path:"mpls/label-entry" module:"openconfig-network-instance"`
	ΛLabelEntry            []ygot.Annotation                                                                `path:"mpls/@label-entry" ygotAnnotation:"true"`
	MacEntry               map[string]*NetworkInstance_Afts_MacEntry                                        `path:"ethernet/mac-entry" module:"openconfig-network-instance"`
	ΛMacEntry              []ygot.Annotation                                                                `path:"ethernet/@mac-entry" ygotAnnotation:"true"`
	NextHop                map[uint64]*NetworkInstance_Afts_NextHop                                         `path:"next-hops/next-hop" module:"openconfig-network-instance"`
	ΛNextHop               []ygot.Annotation                                                                `path:"next-hops/@next-hop" ygotAnnotation:"true"`
	NextHopGroup           map[uint64]*NetworkInstance_Afts_NextHopGroup                                    `path:"next-hop-groups/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup          []ygot.Annotation                                                                `path:"next-hop-groups/@next-hop-group" ygotAnnotation:"true"`
	PolicyForwardingEntry  map[uint64]*NetworkInstance_Afts_PolicyForwardingEntry                           `path:"policy-forwarding/policy-forwarding-entry" module:"openconfig-network-instance"`
	ΛPolicyForwardingEntry []ygot.Annotation                                                                `path:"policy-forwarding/@policy-forwarding-entry" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts) IsYANGGoStruct() {}

// NewIpv4Entry creates a new entry in the Ipv4Entry list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewIpv4Entry(Prefix string) (*NetworkInstance_Afts_Ipv4Entry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4Entry == nil {
		t.Ipv4Entry = make(map[string]*NetworkInstance_Afts_Ipv4Entry)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4Entry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4Entry", key)
	}

	t.Ipv4Entry[key] = &NetworkInstance_Afts_Ipv4Entry{
		Prefix: &Prefix,
	}

	return t.Ipv4Entry[key], nil
}

// RenameIpv4Entry renames an entry in the list Ipv4Entry within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenameIpv4Entry(oldK, newK string) error {
	if _, ok := t.Ipv4Entry[newK]; ok {
		return fmt.Errorf("key %v already exists in Ipv4Entry", newK)
	}

	e, ok := t.Ipv4Entry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Ipv4Entry", oldK)
	}
	e.Prefix = &newK

	t.Ipv4Entry[newK] = e
	delete(t.Ipv4Entry, oldK)
	return nil
}

// GetOrCreateIpv4Entry retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreateIpv4Entry(Prefix string) *NetworkInstance_Afts_Ipv4Entry {

	key := Prefix

	if v, ok := t.Ipv4Entry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewIpv4Entry(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateIpv4Entry got unexpected error: %v", err))
	}
	return v
}

// GetIpv4Entry retrieves the value with the specified key from
// the Ipv4Entry map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetIpv4Entry(Prefix string) *NetworkInstance_Afts_Ipv4Entry {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Ipv4Entry[key]; ok {
		return lm
	}
	return nil
}

// AppendIpv4Entry appends the supplied NetworkInstance_Afts_Ipv4Entry struct to the
// list Ipv4Entry of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_Ipv4Entry already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendIpv4Entry(v *NetworkInstance_Afts_Ipv4Entry) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4Entry == nil {
		t.Ipv4Entry = make(map[string]*NetworkInstance_Afts_Ipv4Entry)
	}

	if _, ok := t.Ipv4Entry[key]; ok {
		return fmt.Errorf("duplicate key for list Ipv4Entry %v", key)
	}

	t.Ipv4Entry[key] = v
	return nil
}

// NewIpv6Entry creates a new entry in the Ipv6Entry list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewIpv6Entry(Prefix string) (*NetworkInstance_Afts_Ipv6Entry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6Entry == nil {
		t.Ipv6Entry = make(map[string]*NetworkInstance_Afts_Ipv6Entry)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6Entry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6Entry", key)
	}

	t.Ipv6Entry[key] = &NetworkInstance_Afts_Ipv6Entry{
		Prefix: &Prefix,
	}

	return t.Ipv6Entry[key], nil
}

// RenameIpv6Entry renames an entry in the list Ipv6Entry within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenameIpv6Entry(oldK, newK string) error {
	if _, ok := t.Ipv6Entry[newK]; ok {
		return fmt.Errorf("key %v already exists in Ipv6Entry", newK)
	}

	e, ok := t.Ipv6Entry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Ipv6Entry", oldK)
	}
	e.Prefix = &newK

	t.Ipv6Entry[newK] = e
	delete(t.Ipv6Entry, oldK)
	return nil
}

// GetOrCreateIpv6Entry retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreateIpv6Entry(Prefix string) *NetworkInstance_Afts_Ipv6Entry {

	key := Prefix

	if v, ok := t.Ipv6Entry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewIpv6Entry(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateIpv6Entry got unexpected error: %v", err))
	}
	return v
}

// GetIpv6Entry retrieves the value with the specified key from
// the Ipv6Entry map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetIpv6Entry(Prefix string) *NetworkInstance_Afts_Ipv6Entry {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Ipv6Entry[key]; ok {
		return lm
	}
	return nil
}

// AppendIpv6Entry appends the supplied NetworkInstance_Afts_Ipv6Entry struct to the
// list Ipv6Entry of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_Ipv6Entry already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendIpv6Entry(v *NetworkInstance_Afts_Ipv6Entry) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6Entry == nil {
		t.Ipv6Entry = make(map[string]*NetworkInstance_Afts_Ipv6Entry)
	}

	if _, ok := t.Ipv6Entry[key]; ok {
		return fmt.Errorf("duplicate key for list Ipv6Entry %v", key)
	}

	t.Ipv6Entry[key] = v
	return nil
}

// NewLabelEntry creates a new entry in the LabelEntry list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewLabelEntry(Label NetworkInstance_Afts_LabelEntry_Label_Union) (*NetworkInstance_Afts_LabelEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LabelEntry == nil {
		t.LabelEntry = make(map[NetworkInstance_Afts_LabelEntry_Label_Union]*NetworkInstance_Afts_LabelEntry)
	}

	key := Label

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LabelEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LabelEntry", key)
	}

	t.LabelEntry[key] = &NetworkInstance_Afts_LabelEntry{
		Label: Label,
	}

	return t.LabelEntry[key], nil
}

// RenameLabelEntry renames an entry in the list LabelEntry within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenameLabelEntry(oldK, newK NetworkInstance_Afts_LabelEntry_Label_Union) error {
	if _, ok := t.LabelEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in LabelEntry", newK)
	}

	e, ok := t.LabelEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in LabelEntry", oldK)
	}
	e.Label = newK

	t.LabelEntry[newK] = e
	delete(t.LabelEntry, oldK)
	return nil
}

// GetOrCreateLabelEntry retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreateLabelEntry(Label NetworkInstance_Afts_LabelEntry_Label_Union) *NetworkInstance_Afts_LabelEntry {

	key := Label

	if v, ok := t.LabelEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLabelEntry(Label)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLabelEntry got unexpected error: %v", err))
	}
	return v
}

// GetLabelEntry retrieves the value with the specified key from
// the LabelEntry map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetLabelEntry(Label NetworkInstance_Afts_LabelEntry_Label_Union) *NetworkInstance_Afts_LabelEntry {

	if t == nil {
		return nil
	}

	key := Label

	if lm, ok := t.LabelEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendLabelEntry appends the supplied NetworkInstance_Afts_LabelEntry struct to the
// list LabelEntry of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_LabelEntry already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendLabelEntry(v *NetworkInstance_Afts_LabelEntry) error {
	key := v.Label

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LabelEntry == nil {
		t.LabelEntry = make(map[NetworkInstance_Afts_LabelEntry_Label_Union]*NetworkInstance_Afts_LabelEntry)
	}

	if _, ok := t.LabelEntry[key]; ok {
		return fmt.Errorf("duplicate key for list LabelEntry %v", key)
	}

	t.LabelEntry[key] = v
	return nil
}

// NewMacEntry creates a new entry in the MacEntry list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewMacEntry(MacAddress string) (*NetworkInstance_Afts_MacEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MacEntry == nil {
		t.MacEntry = make(map[string]*NetworkInstance_Afts_MacEntry)
	}

	key := MacAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.MacEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list MacEntry", key)
	}

	t.MacEntry[key] = &NetworkInstance_Afts_MacEntry{
		MacAddress: &MacAddress,
	}

	return t.MacEntry[key], nil
}

// RenameMacEntry renames an entry in the list MacEntry within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenameMacEntry(oldK, newK string) error {
	if _, ok := t.MacEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in MacEntry", newK)
	}

	e, ok := t.MacEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in MacEntry", oldK)
	}
	e.MacAddress = &newK

	t.MacEntry[newK] = e
	delete(t.MacEntry, oldK)
	return nil
}

// GetOrCreateMacEntry retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreateMacEntry(MacAddress string) *NetworkInstance_Afts_MacEntry {

	key := MacAddress

	if v, ok := t.MacEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewMacEntry(MacAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateMacEntry got unexpected error: %v", err))
	}
	return v
}

// GetMacEntry retrieves the value with the specified key from
// the MacEntry map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetMacEntry(MacAddress string) *NetworkInstance_Afts_MacEntry {

	if t == nil {
		return nil
	}

	key := MacAddress

	if lm, ok := t.MacEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendMacEntry appends the supplied NetworkInstance_Afts_MacEntry struct to the
// list MacEntry of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_MacEntry already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendMacEntry(v *NetworkInstance_Afts_MacEntry) error {
	if v.MacAddress == nil {
		return fmt.Errorf("invalid nil key received for MacAddress")
	}

	key := *v.MacAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MacEntry == nil {
		t.MacEntry = make(map[string]*NetworkInstance_Afts_MacEntry)
	}

	if _, ok := t.MacEntry[key]; ok {
		return fmt.Errorf("duplicate key for list MacEntry %v", key)
	}

	t.MacEntry[key] = v
	return nil
}

// NewNextHop creates a new entry in the NextHop list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewNextHop(Index uint64) (*NetworkInstance_Afts_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*NetworkInstance_Afts_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &NetworkInstance_Afts_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// RenameNextHop renames an entry in the list NextHop within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenameNextHop(oldK, newK uint64) error {
	if _, ok := t.NextHop[newK]; ok {
		return fmt.Errorf("key %v already exists in NextHop", newK)
	}

	e, ok := t.NextHop[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NextHop", oldK)
	}
	e.Index = &newK

	t.NextHop[newK] = e
	delete(t.NextHop, oldK)
	return nil
}

// GetOrCreateNextHop retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreateNextHop(Index uint64) *NetworkInstance_Afts_NextHop {

	key := Index

	if v, ok := t.NextHop[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNextHop(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNextHop got unexpected error: %v", err))
	}
	return v
}

// GetNextHop retrieves the value with the specified key from
// the NextHop map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetNextHop(Index uint64) *NetworkInstance_Afts_NextHop {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.NextHop[key]; ok {
		return lm
	}
	return nil
}

// AppendNextHop appends the supplied NetworkInstance_Afts_NextHop struct to the
// list NextHop of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_NextHop already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendNextHop(v *NetworkInstance_Afts_NextHop) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*NetworkInstance_Afts_NextHop)
	}

	if _, ok := t.NextHop[key]; ok {
		return fmt.Errorf("duplicate key for list NextHop %v", key)
	}

	t.NextHop[key] = v
	return nil
}

// NewNextHopGroup creates a new entry in the NextHopGroup list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewNextHopGroup(Id uint64) (*NetworkInstance_Afts_NextHopGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHopGroup == nil {
		t.NextHopGroup = make(map[uint64]*NetworkInstance_Afts_NextHopGroup)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHopGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHopGroup", key)
	}

	t.NextHopGroup[key] = &NetworkInstance_Afts_NextHopGroup{
		Id: &Id,
	}

	return t.NextHopGroup[key], nil
}

// RenameNextHopGroup renames an entry in the list NextHopGroup within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenameNextHopGroup(oldK, newK uint64) error {
	if _, ok := t.NextHopGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in NextHopGroup", newK)
	}

	e, ok := t.NextHopGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NextHopGroup", oldK)
	}
	e.Id = &newK

	t.NextHopGroup[newK] = e
	delete(t.NextHopGroup, oldK)
	return nil
}

// GetOrCreateNextHopGroup retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreateNextHopGroup(Id uint64) *NetworkInstance_Afts_NextHopGroup {

	key := Id

	if v, ok := t.NextHopGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNextHopGroup(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNextHopGroup got unexpected error: %v", err))
	}
	return v
}

// GetNextHopGroup retrieves the value with the specified key from
// the NextHopGroup map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetNextHopGroup(Id uint64) *NetworkInstance_Afts_NextHopGroup {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.NextHopGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendNextHopGroup appends the supplied NetworkInstance_Afts_NextHopGroup struct to the
// list NextHopGroup of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_NextHopGroup already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendNextHopGroup(v *NetworkInstance_Afts_NextHopGroup) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHopGroup == nil {
		t.NextHopGroup = make(map[uint64]*NetworkInstance_Afts_NextHopGroup)
	}

	if _, ok := t.NextHopGroup[key]; ok {
		return fmt.Errorf("duplicate key for list NextHopGroup %v", key)
	}

	t.NextHopGroup[key] = v
	return nil
}

// NewPolicyForwardingEntry creates a new entry in the PolicyForwardingEntry list of the
// NetworkInstance_Afts struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts) NewPolicyForwardingEntry(Index uint64) (*NetworkInstance_Afts_PolicyForwardingEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PolicyForwardingEntry == nil {
		t.PolicyForwardingEntry = make(map[uint64]*NetworkInstance_Afts_PolicyForwardingEntry)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PolicyForwardingEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PolicyForwardingEntry", key)
	}

	t.PolicyForwardingEntry[key] = &NetworkInstance_Afts_PolicyForwardingEntry{
		Index: &Index,
	}

	return t.PolicyForwardingEntry[key], nil
}

// RenamePolicyForwardingEntry renames an entry in the list PolicyForwardingEntry within
// the NetworkInstance_Afts struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts) RenamePolicyForwardingEntry(oldK, newK uint64) error {
	if _, ok := t.PolicyForwardingEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in PolicyForwardingEntry", newK)
	}

	e, ok := t.PolicyForwardingEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PolicyForwardingEntry", oldK)
	}
	e.Index = &newK

	t.PolicyForwardingEntry[newK] = e
	delete(t.PolicyForwardingEntry, oldK)
	return nil
}

// GetOrCreatePolicyForwardingEntry retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts) GetOrCreatePolicyForwardingEntry(Index uint64) *NetworkInstance_Afts_PolicyForwardingEntry {

	key := Index

	if v, ok := t.PolicyForwardingEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPolicyForwardingEntry(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePolicyForwardingEntry got unexpected error: %v", err))
	}
	return v
}

// GetPolicyForwardingEntry retrieves the value with the specified key from
// the PolicyForwardingEntry map field of NetworkInstance_Afts. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts) GetPolicyForwardingEntry(Index uint64) *NetworkInstance_Afts_PolicyForwardingEntry {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.PolicyForwardingEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendPolicyForwardingEntry appends the supplied NetworkInstance_Afts_PolicyForwardingEntry struct to the
// list PolicyForwardingEntry of NetworkInstance_Afts. If the key value(s) specified in
// the supplied NetworkInstance_Afts_PolicyForwardingEntry already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts) AppendPolicyForwardingEntry(v *NetworkInstance_Afts_PolicyForwardingEntry) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PolicyForwardingEntry == nil {
		t.PolicyForwardingEntry = make(map[uint64]*NetworkInstance_Afts_PolicyForwardingEntry)
	}

	if _, ok := t.PolicyForwardingEntry[key]; ok {
		return fmt.Errorf("duplicate key for list PolicyForwardingEntry %v", key)
	}

	t.PolicyForwardingEntry[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Afts_Ipv4Entry represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry YANG schema element.
type NetworkInstance_Afts_Ipv4Entry struct {
	ΛMetadata          []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	DecapsulateHeader  E_OpenconfigAftTypes_EncapsulationHeaderType  `path:"state/decapsulate-header" module:"openconfig-network-instance"`
	ΛDecapsulateHeader []ygot.Annotation                             `path:"state/@decapsulate-header" ygotAnnotation:"true"`
	NextHopGroup       *uint64                                       `path:"state/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup      []ygot.Annotation                             `path:"state/@next-hop-group" ygotAnnotation:"true"`
	OctetsForwarded    *uint64                                       `path:"state/octets-forwarded" module:"openconfig-network-instance"`
	ΛOctetsForwarded   []ygot.Annotation                             `path:"state/@octets-forwarded" ygotAnnotation:"true"`
	OriginProtocol     E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"state/origin-protocol" module:"openconfig-network-instance"`
	ΛOriginProtocol    []ygot.Annotation                             `path:"state/@origin-protocol" ygotAnnotation:"true"`
	PacketsForwarded   *uint64                                       `path:"state/packets-forwarded" module:"openconfig-network-instance"`
	ΛPacketsForwarded  []ygot.Annotation                             `path:"state/@packets-forwarded" ygotAnnotation:"true"`
	Prefix             *string                                       `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                             `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_Ipv4Entry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_Ipv4Entry) IsYANGGoStruct() {}

// GetDecapsulateHeader retrieves the value of the leaf DecapsulateHeader from the NetworkInstance_Afts_Ipv4Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DecapsulateHeader is set, it can safely use t.GetDecapsulateHeader()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DecapsulateHeader == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv4Entry) GetDecapsulateHeader() E_OpenconfigAftTypes_EncapsulationHeaderType {
	if t == nil || t.DecapsulateHeader == 0 {
		return 0
	}
	return t.DecapsulateHeader
}

// GetNextHopGroup retrieves the value of the leaf NextHopGroup from the NetworkInstance_Afts_Ipv4Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHopGroup is set, it can safely use t.GetNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv4Entry) GetNextHopGroup() uint64 {
	if t == nil || t.NextHopGroup == nil {
		return 0
	}
	return *t.NextHopGroup
}

// GetOctetsForwarded retrieves the value of the leaf OctetsForwarded from the NetworkInstance_Afts_Ipv4Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OctetsForwarded is set, it can safely use t.GetOctetsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OctetsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv4Entry) GetOctetsForwarded() uint64 {
	if t == nil || t.OctetsForwarded == nil {
		return 0
	}
	return *t.OctetsForwarded
}

// GetOriginProtocol retrieves the value of the leaf OriginProtocol from the NetworkInstance_Afts_Ipv4Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginProtocol is set, it can safely use t.GetOriginProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv4Entry) GetOriginProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.OriginProtocol == 0 {
		return 0
	}
	return t.OriginProtocol
}

// GetPacketsForwarded retrieves the value of the leaf PacketsForwarded from the NetworkInstance_Afts_Ipv4Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PacketsForwarded is set, it can safely use t.GetPacketsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PacketsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv4Entry) GetPacketsForwarded() uint64 {
	if t == nil || t.PacketsForwarded == nil {
		return 0
	}
	return *t.PacketsForwarded
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Afts_Ipv4Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv4Entry) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_Ipv4Entry struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_Ipv4Entry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_Ipv4Entry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_Ipv4Entry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_Ipv4Entry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_Ipv6Entry represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry YANG schema element.
type NetworkInstance_Afts_Ipv6Entry struct {
	ΛMetadata          []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	DecapsulateHeader  E_OpenconfigAftTypes_EncapsulationHeaderType  `path:"state/decapsulate-header" module:"openconfig-network-instance"`
	ΛDecapsulateHeader []ygot.Annotation                             `path:"state/@decapsulate-header" ygotAnnotation:"true"`
	NextHopGroup       *uint64                                       `path:"state/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup      []ygot.Annotation                             `path:"state/@next-hop-group" ygotAnnotation:"true"`
	OctetsForwarded    *uint64                                       `path:"state/octets-forwarded" module:"openconfig-network-instance"`
	ΛOctetsForwarded   []ygot.Annotation                             `path:"state/@octets-forwarded" ygotAnnotation:"true"`
	OriginProtocol     E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"state/origin-protocol" module:"openconfig-network-instance"`
	ΛOriginProtocol    []ygot.Annotation                             `path:"state/@origin-protocol" ygotAnnotation:"true"`
	PacketsForwarded   *uint64                                       `path:"state/packets-forwarded" module:"openconfig-network-instance"`
	ΛPacketsForwarded  []ygot.Annotation                             `path:"state/@packets-forwarded" ygotAnnotation:"true"`
	Prefix             *string                                       `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                             `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_Ipv6Entry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_Ipv6Entry) IsYANGGoStruct() {}

// GetDecapsulateHeader retrieves the value of the leaf DecapsulateHeader from the NetworkInstance_Afts_Ipv6Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DecapsulateHeader is set, it can safely use t.GetDecapsulateHeader()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DecapsulateHeader == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv6Entry) GetDecapsulateHeader() E_OpenconfigAftTypes_EncapsulationHeaderType {
	if t == nil || t.DecapsulateHeader == 0 {
		return 0
	}
	return t.DecapsulateHeader
}

// GetNextHopGroup retrieves the value of the leaf NextHopGroup from the NetworkInstance_Afts_Ipv6Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHopGroup is set, it can safely use t.GetNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv6Entry) GetNextHopGroup() uint64 {
	if t == nil || t.NextHopGroup == nil {
		return 0
	}
	return *t.NextHopGroup
}

// GetOctetsForwarded retrieves the value of the leaf OctetsForwarded from the NetworkInstance_Afts_Ipv6Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OctetsForwarded is set, it can safely use t.GetOctetsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OctetsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv6Entry) GetOctetsForwarded() uint64 {
	if t == nil || t.OctetsForwarded == nil {
		return 0
	}
	return *t.OctetsForwarded
}

// GetOriginProtocol retrieves the value of the leaf OriginProtocol from the NetworkInstance_Afts_Ipv6Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginProtocol is set, it can safely use t.GetOriginProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv6Entry) GetOriginProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.OriginProtocol == 0 {
		return 0
	}
	return t.OriginProtocol
}

// GetPacketsForwarded retrieves the value of the leaf PacketsForwarded from the NetworkInstance_Afts_Ipv6Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PacketsForwarded is set, it can safely use t.GetPacketsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PacketsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv6Entry) GetPacketsForwarded() uint64 {
	if t == nil || t.PacketsForwarded == nil {
		return 0
	}
	return *t.PacketsForwarded
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Afts_Ipv6Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_Ipv6Entry) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_Ipv6Entry struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_Ipv6Entry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_Ipv6Entry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_Ipv6Entry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_Ipv6Entry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_LabelEntry represents the /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry YANG schema element.
type NetworkInstance_Afts_LabelEntry struct {
	ΛMetadata             []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	Label                 NetworkInstance_Afts_LabelEntry_Label_Union                  `path:"state/label|label" module:"openconfig-network-instance"`
	ΛLabel                []ygot.Annotation                                            `path:"state/@label|@label" ygotAnnotation:"true"`
	NextHopGroup          *uint64                                                      `path:"state/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup         []ygot.Annotation                                            `path:"state/@next-hop-group" ygotAnnotation:"true"`
	OctetsForwarded       *uint64                                                      `path:"state/octets-forwarded" module:"openconfig-network-instance"`
	ΛOctetsForwarded      []ygot.Annotation                                            `path:"state/@octets-forwarded" ygotAnnotation:"true"`
	PacketsForwarded      *uint64                                                      `path:"state/packets-forwarded" module:"openconfig-network-instance"`
	ΛPacketsForwarded     []ygot.Annotation                                            `path:"state/@packets-forwarded" ygotAnnotation:"true"`
	PoppedMplsLabelStack  []NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union `path:"state/popped-mpls-label-stack" module:"openconfig-network-instance"`
	ΛPoppedMplsLabelStack []ygot.Annotation                                            `path:"state/@popped-mpls-label-stack" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_LabelEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_LabelEntry) IsYANGGoStruct() {}

// GetLabel retrieves the value of the leaf Label from the NetworkInstance_Afts_LabelEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Label is set, it can safely use t.GetLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Label == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_LabelEntry) GetLabel() NetworkInstance_Afts_LabelEntry_Label_Union {
	if t == nil || t.Label == nil {
		return nil
	}
	return t.Label
}

// GetNextHopGroup retrieves the value of the leaf NextHopGroup from the NetworkInstance_Afts_LabelEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHopGroup is set, it can safely use t.GetNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_LabelEntry) GetNextHopGroup() uint64 {
	if t == nil || t.NextHopGroup == nil {
		return 0
	}
	return *t.NextHopGroup
}

// GetOctetsForwarded retrieves the value of the leaf OctetsForwarded from the NetworkInstance_Afts_LabelEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OctetsForwarded is set, it can safely use t.GetOctetsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OctetsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_LabelEntry) GetOctetsForwarded() uint64 {
	if t == nil || t.OctetsForwarded == nil {
		return 0
	}
	return *t.OctetsForwarded
}

// GetPacketsForwarded retrieves the value of the leaf PacketsForwarded from the NetworkInstance_Afts_LabelEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PacketsForwarded is set, it can safely use t.GetPacketsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PacketsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_LabelEntry) GetPacketsForwarded() uint64 {
	if t == nil || t.PacketsForwarded == nil {
		return 0
	}
	return *t.PacketsForwarded
}

// GetPoppedMplsLabelStack retrieves the value of the leaf PoppedMplsLabelStack from the NetworkInstance_Afts_LabelEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PoppedMplsLabelStack is set, it can safely use t.GetPoppedMplsLabelStack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PoppedMplsLabelStack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_LabelEntry) GetPoppedMplsLabelStack() []NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union {
	if t == nil || t.PoppedMplsLabelStack == nil {
		return nil
	}
	return t.PoppedMplsLabelStack
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_LabelEntry struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_LabelEntry) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"label": t.Label,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_LabelEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_LabelEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_LabelEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_LabelEntry_Label_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/state/label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Afts_LabelEntry_Label_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Afts_LabelEntry_Label_Union()
}

// Documentation_for_NetworkInstance_Afts_LabelEntry_Label_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Afts_LabelEntry_Label_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Afts_LabelEntry_Label_Union() {
}

// Documentation_for_NetworkInstance_Afts_LabelEntry_Label_Union ensures that UnionUint32
// implements the NetworkInstance_Afts_LabelEntry_Label_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Afts_LabelEntry_Label_Union() {}

// To_NetworkInstance_Afts_LabelEntry_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Afts_LabelEntry_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Afts_LabelEntry) To_NetworkInstance_Afts_LabelEntry_Label_Union(i interface{}) (NetworkInstance_Afts_LabelEntry_Label_Union, error) {
	if v, ok := i.(NetworkInstance_Afts_LabelEntry_Label_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Afts_LabelEntry_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/state/popped-mpls-label-stack within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union()
}

// Documentation_for_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union() {
}

// Documentation_for_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union ensures that UnionUint32
// implements the NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union() {}

// To_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Afts_LabelEntry) To_NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union(i interface{}) (NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union, error) {
	if v, ok := i.(NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Afts_LabelEntry_PoppedMplsLabelStack_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Afts_MacEntry represents the /openconfig-network-instance/network-instances/network-instance/afts/ethernet/mac-entry YANG schema element.
type NetworkInstance_Afts_MacEntry struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MacAddress        *string           `path:"state/mac-address|mac-address" module:"openconfig-network-instance"`
	ΛMacAddress       []ygot.Annotation `path:"state/@mac-address|@mac-address" ygotAnnotation:"true"`
	NextHopGroup      *uint64           `path:"state/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup     []ygot.Annotation `path:"state/@next-hop-group" ygotAnnotation:"true"`
	OctetsForwarded   *uint64           `path:"state/octets-forwarded" module:"openconfig-network-instance"`
	ΛOctetsForwarded  []ygot.Annotation `path:"state/@octets-forwarded" ygotAnnotation:"true"`
	PacketsForwarded  *uint64           `path:"state/packets-forwarded" module:"openconfig-network-instance"`
	ΛPacketsForwarded []ygot.Annotation `path:"state/@packets-forwarded" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_MacEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_MacEntry) IsYANGGoStruct() {}

// GetMacAddress retrieves the value of the leaf MacAddress from the NetworkInstance_Afts_MacEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAddress is set, it can safely use t.GetMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_MacEntry) GetMacAddress() string {
	if t == nil || t.MacAddress == nil {
		return ""
	}
	return *t.MacAddress
}

// GetNextHopGroup retrieves the value of the leaf NextHopGroup from the NetworkInstance_Afts_MacEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHopGroup is set, it can safely use t.GetNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_MacEntry) GetNextHopGroup() uint64 {
	if t == nil || t.NextHopGroup == nil {
		return 0
	}
	return *t.NextHopGroup
}

// GetOctetsForwarded retrieves the value of the leaf OctetsForwarded from the NetworkInstance_Afts_MacEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OctetsForwarded is set, it can safely use t.GetOctetsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OctetsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_MacEntry) GetOctetsForwarded() uint64 {
	if t == nil || t.OctetsForwarded == nil {
		return 0
	}
	return *t.OctetsForwarded
}

// GetPacketsForwarded retrieves the value of the leaf PacketsForwarded from the NetworkInstance_Afts_MacEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PacketsForwarded is set, it can safely use t.GetPacketsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PacketsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_MacEntry) GetPacketsForwarded() uint64 {
	if t == nil || t.PacketsForwarded == nil {
		return 0
	}
	return *t.PacketsForwarded
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_MacEntry struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_MacEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MacAddress == nil {
		return nil, fmt.Errorf("nil value for key MacAddress")
	}

	return map[string]interface{}{
		"mac-address": *t.MacAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_MacEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_MacEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_MacEntry) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Afts_NextHop represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop YANG schema element.
type NetworkInstance_Afts_NextHop struct {
	ΛMetadata             []ygot.Annotation                                         `path:"@" ygotAnnotation:"true"`
	EncapsulateHeader     E_OpenconfigAftTypes_EncapsulationHeaderType              `path:"state/encapsulate-header" module:"openconfig-network-instance"`
	ΛEncapsulateHeader    []ygot.Annotation                                         `path:"state/@encapsulate-header" ygotAnnotation:"true"`
	Index                 *uint64                                                   `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex                []ygot.Annotation                                         `path:"state/@index|@index" ygotAnnotation:"true"`
	InterfaceRef          *NetworkInstance_Afts_NextHop_InterfaceRef                `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef         []ygot.Annotation                                         `path:"@interface-ref" ygotAnnotation:"true"`
	IpAddress             *string                                                   `path:"state/ip-address" module:"openconfig-network-instance"`
	ΛIpAddress            []ygot.Annotation                                         `path:"state/@ip-address" ygotAnnotation:"true"`
	LspName               *string                                                   `path:"state/lsp-name" module:"openconfig-network-instance"`
	ΛLspName              []ygot.Annotation                                         `path:"state/@lsp-name" ygotAnnotation:"true"`
	MacAddress            *string                                                   `path:"state/mac-address" module:"openconfig-network-instance"`
	ΛMacAddress           []ygot.Annotation                                         `path:"state/@mac-address" ygotAnnotation:"true"`
	OriginProtocol        E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE             `path:"state/origin-protocol" module:"openconfig-network-instance"`
	ΛOriginProtocol       []ygot.Annotation                                         `path:"state/@origin-protocol" ygotAnnotation:"true"`
	PushedMplsLabelStack  []NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union `path:"state/pushed-mpls-label-stack" module:"openconfig-network-instance"`
	ΛPushedMplsLabelStack []ygot.Annotation                                         `path:"state/@pushed-mpls-label-stack" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_NextHop) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Afts_NextHop) GetOrCreateInterfaceRef() *NetworkInstance_Afts_NextHop_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Afts_NextHop_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Afts_NextHop. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Afts_NextHop) GetInterfaceRef() *NetworkInstance_Afts_NextHop_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEncapsulateHeader retrieves the value of the leaf EncapsulateHeader from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EncapsulateHeader is set, it can safely use t.GetEncapsulateHeader()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EncapsulateHeader == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetEncapsulateHeader() E_OpenconfigAftTypes_EncapsulationHeaderType {
	if t == nil || t.EncapsulateHeader == 0 {
		return 0
	}
	return t.EncapsulateHeader
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetIpAddress retrieves the value of the leaf IpAddress from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpAddress is set, it can safely use t.GetIpAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetIpAddress() string {
	if t == nil || t.IpAddress == nil {
		return ""
	}
	return *t.IpAddress
}

// GetLspName retrieves the value of the leaf LspName from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspName is set, it can safely use t.GetLspName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetLspName() string {
	if t == nil || t.LspName == nil {
		return ""
	}
	return *t.LspName
}

// GetMacAddress retrieves the value of the leaf MacAddress from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAddress is set, it can safely use t.GetMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetMacAddress() string {
	if t == nil || t.MacAddress == nil {
		return ""
	}
	return *t.MacAddress
}

// GetOriginProtocol retrieves the value of the leaf OriginProtocol from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginProtocol is set, it can safely use t.GetOriginProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetOriginProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.OriginProtocol == 0 {
		return 0
	}
	return t.OriginProtocol
}

// GetPushedMplsLabelStack retrieves the value of the leaf PushedMplsLabelStack from the NetworkInstance_Afts_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PushedMplsLabelStack is set, it can safely use t.GetPushedMplsLabelStack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PushedMplsLabelStack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop) GetPushedMplsLabelStack() []NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union {
	if t == nil || t.PushedMplsLabelStack == nil {
		return nil
	}
	return t.PushedMplsLabelStack
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_NextHop struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_NextHop) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/state/pushed-mpls-label-stack within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union()
}

// Documentation_for_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union() {
}

// Documentation_for_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union ensures that UnionUint32
// implements the NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union() {}

// To_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Afts_NextHop) To_NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union(i interface{}) (NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union, error) {
	if v, ok := i.(NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Afts_NextHop_PushedMplsLabelStack_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Afts_NextHopGroup represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group YANG schema element.
type NetworkInstance_Afts_NextHopGroup struct {
	ΛMetadata           []ygot.Annotation                                       `path:"@" ygotAnnotation:"true"`
	BackupNextHopGroup  *uint64                                                 `path:"state/backup-next-hop-group" module:"openconfig-network-instance"`
	ΛBackupNextHopGroup []ygot.Annotation                                       `path:"state/@backup-next-hop-group" ygotAnnotation:"true"`
	Color               *uint64                                                 `path:"state/color" module:"openconfig-network-instance"`
	ΛColor              []ygot.Annotation                                       `path:"state/@color" ygotAnnotation:"true"`
	Condition           map[uint64]*NetworkInstance_Afts_NextHopGroup_Condition `path:"conditional/condition" module:"openconfig-network-instance"`
	ΛCondition          []ygot.Annotation                                       `path:"conditional/@condition" ygotAnnotation:"true"`
	Id                  *uint64                                                 `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId                 []ygot.Annotation                                       `path:"state/@id|@id" ygotAnnotation:"true"`
	NextHop             map[uint64]*NetworkInstance_Afts_NextHopGroup_NextHop   `path:"next-hops/next-hop" module:"openconfig-network-instance"`
	ΛNextHop            []ygot.Annotation                                       `path:"next-hops/@next-hop" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_NextHopGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_NextHopGroup) IsYANGGoStruct() {}

// NewCondition creates a new entry in the Condition list of the
// NetworkInstance_Afts_NextHopGroup struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts_NextHopGroup) NewCondition(Id uint64) (*NetworkInstance_Afts_NextHopGroup_Condition, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Condition == nil {
		t.Condition = make(map[uint64]*NetworkInstance_Afts_NextHopGroup_Condition)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Condition[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Condition", key)
	}

	t.Condition[key] = &NetworkInstance_Afts_NextHopGroup_Condition{
		Id: &Id,
	}

	return t.Condition[key], nil
}

// RenameCondition renames an entry in the list Condition within
// the NetworkInstance_Afts_NextHopGroup struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts_NextHopGroup) RenameCondition(oldK, newK uint64) error {
	if _, ok := t.Condition[newK]; ok {
		return fmt.Errorf("key %v already exists in Condition", newK)
	}

	e, ok := t.Condition[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Condition", oldK)
	}
	e.Id = &newK

	t.Condition[newK] = e
	delete(t.Condition, oldK)
	return nil
}

// GetOrCreateCondition retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts_NextHopGroup. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts_NextHopGroup) GetOrCreateCondition(Id uint64) *NetworkInstance_Afts_NextHopGroup_Condition {

	key := Id

	if v, ok := t.Condition[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCondition(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCondition got unexpected error: %v", err))
	}
	return v
}

// GetCondition retrieves the value with the specified key from
// the Condition map field of NetworkInstance_Afts_NextHopGroup. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts_NextHopGroup) GetCondition(Id uint64) *NetworkInstance_Afts_NextHopGroup_Condition {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Condition[key]; ok {
		return lm
	}
	return nil
}

// AppendCondition appends the supplied NetworkInstance_Afts_NextHopGroup_Condition struct to the
// list Condition of NetworkInstance_Afts_NextHopGroup. If the key value(s) specified in
// the supplied NetworkInstance_Afts_NextHopGroup_Condition already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts_NextHopGroup) AppendCondition(v *NetworkInstance_Afts_NextHopGroup_Condition) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Condition == nil {
		t.Condition = make(map[uint64]*NetworkInstance_Afts_NextHopGroup_Condition)
	}

	if _, ok := t.Condition[key]; ok {
		return fmt.Errorf("duplicate key for list Condition %v", key)
	}

	t.Condition[key] = v
	return nil
}

// NewNextHop creates a new entry in the NextHop list of the
// NetworkInstance_Afts_NextHopGroup struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts_NextHopGroup) NewNextHop(Index uint64) (*NetworkInstance_Afts_NextHopGroup_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*NetworkInstance_Afts_NextHopGroup_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &NetworkInstance_Afts_NextHopGroup_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// RenameNextHop renames an entry in the list NextHop within
// the NetworkInstance_Afts_NextHopGroup struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts_NextHopGroup) RenameNextHop(oldK, newK uint64) error {
	if _, ok := t.NextHop[newK]; ok {
		return fmt.Errorf("key %v already exists in NextHop", newK)
	}

	e, ok := t.NextHop[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NextHop", oldK)
	}
	e.Index = &newK

	t.NextHop[newK] = e
	delete(t.NextHop, oldK)
	return nil
}

// GetOrCreateNextHop retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts_NextHopGroup. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts_NextHopGroup) GetOrCreateNextHop(Index uint64) *NetworkInstance_Afts_NextHopGroup_NextHop {

	key := Index

	if v, ok := t.NextHop[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNextHop(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNextHop got unexpected error: %v", err))
	}
	return v
}

// GetNextHop retrieves the value with the specified key from
// the NextHop map field of NetworkInstance_Afts_NextHopGroup. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts_NextHopGroup) GetNextHop(Index uint64) *NetworkInstance_Afts_NextHopGroup_NextHop {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.NextHop[key]; ok {
		return lm
	}
	return nil
}

// AppendNextHop appends the supplied NetworkInstance_Afts_NextHopGroup_NextHop struct to the
// list NextHop of NetworkInstance_Afts_NextHopGroup. If the key value(s) specified in
// the supplied NetworkInstance_Afts_NextHopGroup_NextHop already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts_NextHopGroup) AppendNextHop(v *NetworkInstance_Afts_NextHopGroup_NextHop) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*NetworkInstance_Afts_NextHopGroup_NextHop)
	}

	if _, ok := t.NextHop[key]; ok {
		return fmt.Errorf("duplicate key for list NextHop %v", key)
	}

	t.NextHop[key] = v
	return nil
}

// GetBackupNextHopGroup retrieves the value of the leaf BackupNextHopGroup from the NetworkInstance_Afts_NextHopGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BackupNextHopGroup is set, it can safely use t.GetBackupNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BackupNextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup) GetBackupNextHopGroup() uint64 {
	if t == nil || t.BackupNextHopGroup == nil {
		return 0
	}
	return *t.BackupNextHopGroup
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Afts_NextHopGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup) GetColor() uint64 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Afts_NextHopGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup) GetId() uint64 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_NextHopGroup struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_NextHopGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_NextHopGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_NextHopGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_NextHopGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_NextHopGroup_Condition represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition YANG schema element.
type NetworkInstance_Afts_NextHopGroup_Condition struct {
	ΛMetadata       []ygot.Annotation                                                      `path:"@" ygotAnnotation:"true"`
	Dscp            []uint8                                                                `path:"state/dscp" module:"openconfig-network-instance"`
	ΛDscp           []ygot.Annotation                                                      `path:"state/@dscp" ygotAnnotation:"true"`
	Id              *uint64                                                                `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId             []ygot.Annotation                                                      `path:"state/@id|@id" ygotAnnotation:"true"`
	InputInterface  map[string]*NetworkInstance_Afts_NextHopGroup_Condition_InputInterface `path:"input-interfaces/input-interface" module:"openconfig-network-instance"`
	ΛInputInterface []ygot.Annotation                                                      `path:"input-interfaces/@input-interface" ygotAnnotation:"true"`
	NextHopGroup    *uint64                                                                `path:"state/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup   []ygot.Annotation                                                      `path:"state/@next-hop-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_NextHopGroup_Condition implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_NextHopGroup_Condition) IsYANGGoStruct() {}

// NewInputInterface creates a new entry in the InputInterface list of the
// NetworkInstance_Afts_NextHopGroup_Condition struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) NewInputInterface(Id string) (*NetworkInstance_Afts_NextHopGroup_Condition_InputInterface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InputInterface == nil {
		t.InputInterface = make(map[string]*NetworkInstance_Afts_NextHopGroup_Condition_InputInterface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.InputInterface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list InputInterface", key)
	}

	t.InputInterface[key] = &NetworkInstance_Afts_NextHopGroup_Condition_InputInterface{
		Id: &Id,
	}

	return t.InputInterface[key], nil
}

// RenameInputInterface renames an entry in the list InputInterface within
// the NetworkInstance_Afts_NextHopGroup_Condition struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) RenameInputInterface(oldK, newK string) error {
	if _, ok := t.InputInterface[newK]; ok {
		return fmt.Errorf("key %v already exists in InputInterface", newK)
	}

	e, ok := t.InputInterface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in InputInterface", oldK)
	}
	e.Id = &newK

	t.InputInterface[newK] = e
	delete(t.InputInterface, oldK)
	return nil
}

// GetOrCreateInputInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Afts_NextHopGroup_Condition. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) GetOrCreateInputInterface(Id string) *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface {

	key := Id

	if v, ok := t.InputInterface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInputInterface(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInputInterface got unexpected error: %v", err))
	}
	return v
}

// GetInputInterface retrieves the value with the specified key from
// the InputInterface map field of NetworkInstance_Afts_NextHopGroup_Condition. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) GetInputInterface(Id string) *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.InputInterface[key]; ok {
		return lm
	}
	return nil
}

// AppendInputInterface appends the supplied NetworkInstance_Afts_NextHopGroup_Condition_InputInterface struct to the
// list InputInterface of NetworkInstance_Afts_NextHopGroup_Condition. If the key value(s) specified in
// the supplied NetworkInstance_Afts_NextHopGroup_Condition_InputInterface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) AppendInputInterface(v *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InputInterface == nil {
		t.InputInterface = make(map[string]*NetworkInstance_Afts_NextHopGroup_Condition_InputInterface)
	}

	if _, ok := t.InputInterface[key]; ok {
		return fmt.Errorf("duplicate key for list InputInterface %v", key)
	}

	t.InputInterface[key] = v
	return nil
}

// GetDscp retrieves the value of the leaf Dscp from the NetworkInstance_Afts_NextHopGroup_Condition
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dscp is set, it can safely use t.GetDscp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dscp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) GetDscp() []uint8 {
	if t == nil || t.Dscp == nil {
		return nil
	}
	return t.Dscp
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Afts_NextHopGroup_Condition
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) GetId() uint64 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// GetNextHopGroup retrieves the value of the leaf NextHopGroup from the NetworkInstance_Afts_NextHopGroup_Condition
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHopGroup is set, it can safely use t.GetNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) GetNextHopGroup() uint64 {
	if t == nil || t.NextHopGroup == nil {
		return 0
	}
	return *t.NextHopGroup
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_NextHopGroup_Condition struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_NextHopGroup_Condition"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_NextHopGroup_Condition) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_NextHopGroup_Condition_InputInterface represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition/input-interfaces/input-interface YANG schema element.
type NetworkInstance_Afts_NextHopGroup_Condition_InputInterface struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Id            *string           `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId           []ygot.Annotation `path:"state/@id|@id" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_NextHopGroup_Condition_InputInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) IsYANGGoStruct() {}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Afts_NextHopGroup_Condition_InputInterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Afts_NextHopGroup_Condition_InputInterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Afts_NextHopGroup_Condition_InputInterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_NextHopGroup_Condition_InputInterface struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_NextHopGroup_Condition_InputInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_NextHopGroup_Condition_InputInterface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_NextHopGroup_NextHop represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/next-hops/next-hop YANG schema element.
type NetworkInstance_Afts_NextHopGroup_NextHop struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Index     *uint64           `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex    []ygot.Annotation `path:"state/@index|@index" ygotAnnotation:"true"`
	Weight    *uint64           `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight   []ygot.Annotation `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_NextHopGroup_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_NextHopGroup_NextHop) IsYANGGoStruct() {}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Afts_NextHopGroup_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_NextHop) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Afts_NextHopGroup_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHopGroup_NextHop) GetWeight() uint64 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_NextHopGroup_NextHop struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_NextHopGroup_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_NextHopGroup_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_NextHopGroup_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_NextHopGroup_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_NextHop_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/interface-ref YANG schema element.
type NetworkInstance_Afts_NextHop_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_NextHop_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Afts_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Afts_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_NextHop_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_PolicyForwardingEntry represents the /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry YANG schema element.
type NetworkInstance_Afts_PolicyForwardingEntry struct {
	ΛMetadata         []ygot.Annotation                                           `path:"@" ygotAnnotation:"true"`
	Index             *uint64                                                     `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex            []ygot.Annotation                                           `path:"state/@index|@index" ygotAnnotation:"true"`
	IpDscp            *uint8                                                      `path:"state/ip-dscp" module:"openconfig-network-instance"`
	ΛIpDscp           []ygot.Annotation                                           `path:"state/@ip-dscp" ygotAnnotation:"true"`
	IpPrefix          *string                                                     `path:"state/ip-prefix" module:"openconfig-network-instance"`
	ΛIpPrefix         []ygot.Annotation                                           `path:"state/@ip-prefix" ygotAnnotation:"true"`
	IpProtocol        NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union `path:"state/ip-protocol" module:"openconfig-network-instance"`
	ΛIpProtocol       []ygot.Annotation                                           `path:"state/@ip-protocol" ygotAnnotation:"true"`
	L4DstPort         *uint16                                                     `path:"state/l4-dst-port" module:"openconfig-network-instance"`
	ΛL4DstPort        []ygot.Annotation                                           `path:"state/@l4-dst-port" ygotAnnotation:"true"`
	L4SrcPort         *uint16                                                     `path:"state/l4-src-port" module:"openconfig-network-instance"`
	ΛL4SrcPort        []ygot.Annotation                                           `path:"state/@l4-src-port" ygotAnnotation:"true"`
	MacAddress        *string                                                     `path:"state/mac-address" module:"openconfig-network-instance"`
	ΛMacAddress       []ygot.Annotation                                           `path:"state/@mac-address" ygotAnnotation:"true"`
	MplsLabel         NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union  `path:"state/mpls-label" module:"openconfig-network-instance"`
	ΛMplsLabel        []ygot.Annotation                                           `path:"state/@mpls-label" ygotAnnotation:"true"`
	MplsTc            *uint8                                                      `path:"state/mpls-tc" module:"openconfig-network-instance"`
	ΛMplsTc           []ygot.Annotation                                           `path:"state/@mpls-tc" ygotAnnotation:"true"`
	NextHopGroup      *uint64                                                     `path:"state/next-hop-group" module:"openconfig-network-instance"`
	ΛNextHopGroup     []ygot.Annotation                                           `path:"state/@next-hop-group" ygotAnnotation:"true"`
	OctetsForwarded   *uint64                                                     `path:"state/octets-forwarded" module:"openconfig-network-instance"`
	ΛOctetsForwarded  []ygot.Annotation                                           `path:"state/@octets-forwarded" ygotAnnotation:"true"`
	PacketsForwarded  *uint64                                                     `path:"state/packets-forwarded" module:"openconfig-network-instance"`
	ΛPacketsForwarded []ygot.Annotation                                           `path:"state/@packets-forwarded" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Afts_PolicyForwardingEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Afts_PolicyForwardingEntry) IsYANGGoStruct() {}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetIpDscp retrieves the value of the leaf IpDscp from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpDscp is set, it can safely use t.GetIpDscp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpDscp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetIpDscp() uint8 {
	if t == nil || t.IpDscp == nil {
		return 0
	}
	return *t.IpDscp
}

// GetIpPrefix retrieves the value of the leaf IpPrefix from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpPrefix is set, it can safely use t.GetIpPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpPrefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetIpPrefix() string {
	if t == nil || t.IpPrefix == nil {
		return ""
	}
	return *t.IpPrefix
}

// GetIpProtocol retrieves the value of the leaf IpProtocol from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpProtocol is set, it can safely use t.GetIpProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetIpProtocol() NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union {
	if t == nil || t.IpProtocol == nil {
		return nil
	}
	return t.IpProtocol
}

// GetL4DstPort retrieves the value of the leaf L4DstPort from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if L4DstPort is set, it can safely use t.GetL4DstPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.L4DstPort == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetL4DstPort() uint16 {
	if t == nil || t.L4DstPort == nil {
		return 0
	}
	return *t.L4DstPort
}

// GetL4SrcPort retrieves the value of the leaf L4SrcPort from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if L4SrcPort is set, it can safely use t.GetL4SrcPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.L4SrcPort == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetL4SrcPort() uint16 {
	if t == nil || t.L4SrcPort == nil {
		return 0
	}
	return *t.L4SrcPort
}

// GetMacAddress retrieves the value of the leaf MacAddress from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAddress is set, it can safely use t.GetMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetMacAddress() string {
	if t == nil || t.MacAddress == nil {
		return ""
	}
	return *t.MacAddress
}

// GetMplsLabel retrieves the value of the leaf MplsLabel from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsLabel is set, it can safely use t.GetMplsLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetMplsLabel() NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union {
	if t == nil || t.MplsLabel == nil {
		return nil
	}
	return t.MplsLabel
}

// GetMplsTc retrieves the value of the leaf MplsTc from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTc is set, it can safely use t.GetMplsTc()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTc == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetMplsTc() uint8 {
	if t == nil || t.MplsTc == nil {
		return 0
	}
	return *t.MplsTc
}

// GetNextHopGroup retrieves the value of the leaf NextHopGroup from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHopGroup is set, it can safely use t.GetNextHopGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHopGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetNextHopGroup() uint64 {
	if t == nil || t.NextHopGroup == nil {
		return 0
	}
	return *t.NextHopGroup
}

// GetOctetsForwarded retrieves the value of the leaf OctetsForwarded from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OctetsForwarded is set, it can safely use t.GetOctetsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OctetsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetOctetsForwarded() uint64 {
	if t == nil || t.OctetsForwarded == nil {
		return 0
	}
	return *t.OctetsForwarded
}

// GetPacketsForwarded retrieves the value of the leaf PacketsForwarded from the NetworkInstance_Afts_PolicyForwardingEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PacketsForwarded is set, it can safely use t.GetPacketsForwarded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PacketsForwarded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) GetPacketsForwarded() uint64 {
	if t == nil || t.PacketsForwarded == nil {
		return 0
	}
	return *t.PacketsForwarded
}

// ΛListKeyMap returns the keys of the NetworkInstance_Afts_PolicyForwardingEntry struct, which is a YANG list entry.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Afts_PolicyForwardingEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/ip-protocol within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8].
type NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8]
	Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union()
}

// Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union ensures that E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union interface.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union() {
}

// Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union ensures that UnionUint8
// implements the NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union interface.
func (UnionUint8) Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union() {}

// To_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) To_NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union(i interface{}) (NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union, error) {
	if v, ok := i.(NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint8:
		return UnionUint8(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Afts_PolicyForwardingEntry_IpProtocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
}

// NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/mpls-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union()
}

// Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union() {
}

// Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union() {}

// To_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Afts_PolicyForwardingEntry) To_NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union(i interface{}) (NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Afts_PolicyForwardingEntry_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_ConnectionPoint represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point YANG schema element.
type NetworkInstance_ConnectionPoint struct {
	ΛMetadata          []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	ConnectionPointId  *string                                              `path:"state/connection-point-id|connection-point-id" shadow-path:"config/connection-point-id" module:"openconfig-network-instance"`
	ΛConnectionPointId []ygot.Annotation                                    `path:"state/@connection-point-id|@connection-point-id" ygotAnnotation:"true"`
	Endpoint           map[string]*NetworkInstance_ConnectionPoint_Endpoint `path:"endpoints/endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                    `path:"endpoints/@endpoint" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_ConnectionPoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_ConnectionPoint) IsYANGGoStruct() {}

// NewEndpoint creates a new entry in the Endpoint list of the
// NetworkInstance_ConnectionPoint struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_ConnectionPoint) NewEndpoint(EndpointId string) (*NetworkInstance_ConnectionPoint_Endpoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Endpoint == nil {
		t.Endpoint = make(map[string]*NetworkInstance_ConnectionPoint_Endpoint)
	}

	key := EndpointId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Endpoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Endpoint", key)
	}

	t.Endpoint[key] = &NetworkInstance_ConnectionPoint_Endpoint{
		EndpointId: &EndpointId,
	}

	return t.Endpoint[key], nil
}

// RenameEndpoint renames an entry in the list Endpoint within
// the NetworkInstance_ConnectionPoint struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_ConnectionPoint) RenameEndpoint(oldK, newK string) error {
	if _, ok := t.Endpoint[newK]; ok {
		return fmt.Errorf("key %v already exists in Endpoint", newK)
	}

	e, ok := t.Endpoint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Endpoint", oldK)
	}
	e.EndpointId = &newK

	t.Endpoint[newK] = e
	delete(t.Endpoint, oldK)
	return nil
}

// GetOrCreateEndpoint retrieves the value with the specified keys from
// the receiver NetworkInstance_ConnectionPoint. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_ConnectionPoint) GetOrCreateEndpoint(EndpointId string) *NetworkInstance_ConnectionPoint_Endpoint {

	key := EndpointId

	if v, ok := t.Endpoint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewEndpoint(EndpointId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateEndpoint got unexpected error: %v", err))
	}
	return v
}

// GetEndpoint retrieves the value with the specified key from
// the Endpoint map field of NetworkInstance_ConnectionPoint. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_ConnectionPoint) GetEndpoint(EndpointId string) *NetworkInstance_ConnectionPoint_Endpoint {

	if t == nil {
		return nil
	}

	key := EndpointId

	if lm, ok := t.Endpoint[key]; ok {
		return lm
	}
	return nil
}

// AppendEndpoint appends the supplied NetworkInstance_ConnectionPoint_Endpoint struct to the
// list Endpoint of NetworkInstance_ConnectionPoint. If the key value(s) specified in
// the supplied NetworkInstance_ConnectionPoint_Endpoint already exist in the list, an error is
// returned.
func (t *NetworkInstance_ConnectionPoint) AppendEndpoint(v *NetworkInstance_ConnectionPoint_Endpoint) error {
	if v.EndpointId == nil {
		return fmt.Errorf("invalid nil key received for EndpointId")
	}

	key := *v.EndpointId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Endpoint == nil {
		t.Endpoint = make(map[string]*NetworkInstance_ConnectionPoint_Endpoint)
	}

	if _, ok := t.Endpoint[key]; ok {
		return fmt.Errorf("duplicate key for list Endpoint %v", key)
	}

	t.Endpoint[key] = v
	return nil
}

// GetConnectionPointId retrieves the value of the leaf ConnectionPointId from the NetworkInstance_ConnectionPoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectionPointId is set, it can safely use t.GetConnectionPointId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectionPointId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint) GetConnectionPointId() string {
	if t == nil || t.ConnectionPointId == nil {
		return ""
	}
	return *t.ConnectionPointId
}

// ΛListKeyMap returns the keys of the NetworkInstance_ConnectionPoint struct, which is a YANG list entry.
func (t *NetworkInstance_ConnectionPoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConnectionPointId == nil {
		return nil, fmt.Errorf("nil value for key ConnectionPointId")
	}

	return map[string]interface{}{
		"connection-point-id": *t.ConnectionPointId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_ConnectionPoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_ConnectionPoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_ConnectionPoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_ConnectionPoint_Endpoint represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint YANG schema element.
type NetworkInstance_ConnectionPoint_Endpoint struct {
	ΛMetadata   []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	Active      *bool                                            `path:"state/active" module:"openconfig-network-instance"`
	ΛActive     []ygot.Annotation                                `path:"state/@active" ygotAnnotation:"true"`
	EndpointId  *string                                          `path:"state/endpoint-id|endpoint-id" shadow-path:"config/endpoint-id" module:"openconfig-network-instance"`
	ΛEndpointId []ygot.Annotation                                `path:"state/@endpoint-id|@endpoint-id" ygotAnnotation:"true"`
	Local       *NetworkInstance_ConnectionPoint_Endpoint_Local  `path:"local" module:"openconfig-network-instance"`
	ΛLocal      []ygot.Annotation                                `path:"@local" ygotAnnotation:"true"`
	Precedence  *uint16                                          `path:"state/precedence" shadow-path:"config/precedence" module:"openconfig-network-instance"`
	ΛPrecedence []ygot.Annotation                                `path:"state/@precedence" ygotAnnotation:"true"`
	Remote      *NetworkInstance_ConnectionPoint_Endpoint_Remote `path:"remote" module:"openconfig-network-instance"`
	ΛRemote     []ygot.Annotation                                `path:"@remote" ygotAnnotation:"true"`
	Type        E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE   `path:"state/type" shadow-path:"config/type" module:"openconfig-network-instance"`
	ΛType       []ygot.Annotation                                `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_ConnectionPoint_Endpoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_ConnectionPoint_Endpoint) IsYANGGoStruct() {}

// GetOrCreateLocal retrieves the value of the Local field
// or returns the existing field if it already exists.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetOrCreateLocal() *NetworkInstance_ConnectionPoint_Endpoint_Local {
	if t.Local != nil {
		return t.Local
	}
	t.Local = &NetworkInstance_ConnectionPoint_Endpoint_Local{}
	return t.Local
}

// GetOrCreateRemote retrieves the value of the Remote field
// or returns the existing field if it already exists.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetOrCreateRemote() *NetworkInstance_ConnectionPoint_Endpoint_Remote {
	if t.Remote != nil {
		return t.Remote
	}
	t.Remote = &NetworkInstance_ConnectionPoint_Endpoint_Remote{}
	return t.Remote
}

// GetLocal returns the value of the Local struct pointer
// from NetworkInstance_ConnectionPoint_Endpoint. If the receiver or the field Local is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetLocal() *NetworkInstance_ConnectionPoint_Endpoint_Local {
	if t != nil && t.Local != nil {
		return t.Local
	}
	return nil
}

// GetRemote returns the value of the Remote struct pointer
// from NetworkInstance_ConnectionPoint_Endpoint. If the receiver or the field Remote is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetRemote() *NetworkInstance_ConnectionPoint_Endpoint_Remote {
	if t != nil && t.Remote != nil {
		return t.Remote
	}
	return nil
}

// GetActive retrieves the value of the leaf Active from the NetworkInstance_ConnectionPoint_Endpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetEndpointId retrieves the value of the leaf EndpointId from the NetworkInstance_ConnectionPoint_Endpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EndpointId is set, it can safely use t.GetEndpointId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EndpointId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetEndpointId() string {
	if t == nil || t.EndpointId == nil {
		return ""
	}
	return *t.EndpointId
}

// GetPrecedence retrieves the value of the leaf Precedence from the NetworkInstance_ConnectionPoint_Endpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Precedence is set, it can safely use t.GetPrecedence()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Precedence == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetPrecedence() uint16 {
	if t == nil || t.Precedence == nil {
		return 0
	}
	return *t.Precedence
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_ConnectionPoint_Endpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint) GetType() E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_ConnectionPoint_Endpoint struct, which is a YANG list entry.
func (t *NetworkInstance_ConnectionPoint_Endpoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.EndpointId == nil {
		return nil, fmt.Errorf("nil value for key EndpointId")
	}

	return map[string]interface{}{
		"endpoint-id": *t.EndpointId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_ConnectionPoint_Endpoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_ConnectionPoint_Endpoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_ConnectionPoint_Endpoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_ConnectionPoint_Endpoint_Local represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/local YANG schema element.
type NetworkInstance_ConnectionPoint_Endpoint_Local struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface             *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface            []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	SiteId                *uint16           `path:"state/site-id" shadow-path:"config/site-id" module:"openconfig-network-instance"`
	ΛSiteId               []ygot.Annotation `path:"state/@site-id" ygotAnnotation:"true"`
	SiteLabelBlockOffset  *uint16           `path:"state/site-label-block-offset" shadow-path:"config/site-label-block-offset" module:"openconfig-network-instance"`
	ΛSiteLabelBlockOffset []ygot.Annotation `path:"state/@site-label-block-offset" ygotAnnotation:"true"`
	SiteLabelBlockSize    *uint16           `path:"state/site-label-block-size" shadow-path:"config/site-label-block-size" module:"openconfig-network-instance"`
	ΛSiteLabelBlockSize   []ygot.Annotation `path:"state/@site-label-block-size" ygotAnnotation:"true"`
	Subinterface          *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface         []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_ConnectionPoint_Endpoint_Local implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_ConnectionPoint_Endpoint_Local) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_ConnectionPoint_Endpoint_Local
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSiteId retrieves the value of the leaf SiteId from the NetworkInstance_ConnectionPoint_Endpoint_Local
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SiteId is set, it can safely use t.GetSiteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SiteId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) GetSiteId() uint16 {
	if t == nil || t.SiteId == nil {
		return 0
	}
	return *t.SiteId
}

// GetSiteLabelBlockOffset retrieves the value of the leaf SiteLabelBlockOffset from the NetworkInstance_ConnectionPoint_Endpoint_Local
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SiteLabelBlockOffset is set, it can safely use t.GetSiteLabelBlockOffset()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SiteLabelBlockOffset == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) GetSiteLabelBlockOffset() uint16 {
	if t == nil || t.SiteLabelBlockOffset == nil {
		return 0
	}
	return *t.SiteLabelBlockOffset
}

// GetSiteLabelBlockSize retrieves the value of the leaf SiteLabelBlockSize from the NetworkInstance_ConnectionPoint_Endpoint_Local
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SiteLabelBlockSize is set, it can safely use t.GetSiteLabelBlockSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SiteLabelBlockSize == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) GetSiteLabelBlockSize() uint16 {
	if t == nil || t.SiteLabelBlockSize == nil {
		return 0
	}
	return *t.SiteLabelBlockSize
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_ConnectionPoint_Endpoint_Local
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_ConnectionPoint_Endpoint_Local"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Local) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_ConnectionPoint_Endpoint_Remote represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/remote YANG schema element.
type NetworkInstance_ConnectionPoint_Endpoint_Remote struct {
	ΛMetadata                 []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	RemoteSystem              *string           `path:"state/remote-system" shadow-path:"config/remote-system" module:"openconfig-network-instance"`
	ΛRemoteSystem             []ygot.Annotation `path:"state/@remote-system" ygotAnnotation:"true"`
	SiteId                    *uint16           `path:"state/site-id" shadow-path:"config/site-id" module:"openconfig-network-instance"`
	ΛSiteId                   []ygot.Annotation `path:"state/@site-id" ygotAnnotation:"true"`
	VirtualCircuitIdentifier  *uint32           `path:"state/virtual-circuit-identifier" shadow-path:"config/virtual-circuit-identifier" module:"openconfig-network-instance"`
	ΛVirtualCircuitIdentifier []ygot.Annotation `path:"state/@virtual-circuit-identifier" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_ConnectionPoint_Endpoint_Remote implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_ConnectionPoint_Endpoint_Remote) IsYANGGoStruct() {}

// GetRemoteSystem retrieves the value of the leaf RemoteSystem from the NetworkInstance_ConnectionPoint_Endpoint_Remote
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteSystem is set, it can safely use t.GetRemoteSystem()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteSystem == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Remote) GetRemoteSystem() string {
	if t == nil || t.RemoteSystem == nil {
		return ""
	}
	return *t.RemoteSystem
}

// GetSiteId retrieves the value of the leaf SiteId from the NetworkInstance_ConnectionPoint_Endpoint_Remote
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SiteId is set, it can safely use t.GetSiteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SiteId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Remote) GetSiteId() uint16 {
	if t == nil || t.SiteId == nil {
		return 0
	}
	return *t.SiteId
}

// GetVirtualCircuitIdentifier retrieves the value of the leaf VirtualCircuitIdentifier from the NetworkInstance_ConnectionPoint_Endpoint_Remote
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VirtualCircuitIdentifier is set, it can safely use t.GetVirtualCircuitIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VirtualCircuitIdentifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Remote) GetVirtualCircuitIdentifier() uint32 {
	if t == nil || t.VirtualCircuitIdentifier == nil {
		return 0
	}
	return *t.VirtualCircuitIdentifier
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Remote) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_ConnectionPoint_Endpoint_Remote"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_ConnectionPoint_Endpoint_Remote) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Encapsulation represents the /openconfig-network-instance/network-instances/network-instance/encapsulation YANG schema element.
type NetworkInstance_Encapsulation struct {
	ΛMetadata            []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	ControlWord          *bool                                                  `path:"state/control-word" shadow-path:"config/control-word" module:"openconfig-network-instance"`
	ΛControlWord         []ygot.Annotation                                      `path:"state/@control-word" ygotAnnotation:"true"`
	EncapsulationType    E_OpenconfigNetworkInstanceTypes_ENCAPSULATION         `path:"state/encapsulation-type" shadow-path:"config/encapsulation-type" module:"openconfig-network-instance"`
	ΛEncapsulationType   []ygot.Annotation                                      `path:"state/@encapsulation-type" ygotAnnotation:"true"`
	LabelAllocationMode  E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE `path:"state/label-allocation-mode" shadow-path:"config/label-allocation-mode" module:"openconfig-network-instance"`
	ΛLabelAllocationMode []ygot.Annotation                                      `path:"state/@label-allocation-mode" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Encapsulation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Encapsulation) IsYANGGoStruct() {}

// GetControlWord retrieves the value of the leaf ControlWord from the NetworkInstance_Encapsulation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ControlWord is set, it can safely use t.GetControlWord()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ControlWord == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Encapsulation) GetControlWord() bool {
	if t == nil || t.ControlWord == nil {
		return false
	}
	return *t.ControlWord
}

// GetEncapsulationType retrieves the value of the leaf EncapsulationType from the NetworkInstance_Encapsulation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EncapsulationType is set, it can safely use t.GetEncapsulationType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EncapsulationType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Encapsulation) GetEncapsulationType() E_OpenconfigNetworkInstanceTypes_ENCAPSULATION {
	if t == nil || t.EncapsulationType == 0 {
		return 0
	}
	return t.EncapsulationType
}

// GetLabelAllocationMode retrieves the value of the leaf LabelAllocationMode from the NetworkInstance_Encapsulation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LabelAllocationMode is set, it can safely use t.GetLabelAllocationMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LabelAllocationMode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Encapsulation) GetLabelAllocationMode() E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE {
	if t == nil || t.LabelAllocationMode == 0 {
		return 0
	}
	return t.LabelAllocationMode
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Encapsulation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Encapsulation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Encapsulation) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Fdb represents the /openconfig-network-instance/network-instances/network-instance/fdb YANG schema element.
type NetworkInstance_Fdb struct {
	ΛMetadata       []ygot.Annotation             `path:"@" ygotAnnotation:"true"`
	MacAgingTime    *uint16                       `path:"state/mac-aging-time" shadow-path:"config/mac-aging-time" module:"openconfig-network-instance"`
	ΛMacAgingTime   []ygot.Annotation             `path:"state/@mac-aging-time" ygotAnnotation:"true"`
	MacLearning     *bool                         `path:"state/mac-learning" shadow-path:"config/mac-learning" module:"openconfig-network-instance"`
	ΛMacLearning    []ygot.Annotation             `path:"state/@mac-learning" ygotAnnotation:"true"`
	MacTable        *NetworkInstance_Fdb_MacTable `path:"mac-table" module:"openconfig-network-instance"`
	ΛMacTable       []ygot.Annotation             `path:"@mac-table" ygotAnnotation:"true"`
	MaximumEntries  *uint16                       `path:"state/maximum-entries" shadow-path:"config/maximum-entries" module:"openconfig-network-instance"`
	ΛMaximumEntries []ygot.Annotation             `path:"state/@maximum-entries" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Fdb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Fdb) IsYANGGoStruct() {}

// GetOrCreateMacTable retrieves the value of the MacTable field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Fdb) GetOrCreateMacTable() *NetworkInstance_Fdb_MacTable {
	if t.MacTable != nil {
		return t.MacTable
	}
	t.MacTable = &NetworkInstance_Fdb_MacTable{}
	return t.MacTable
}

// GetMacTable returns the value of the MacTable struct pointer
// from NetworkInstance_Fdb. If the receiver or the field MacTable is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Fdb) GetMacTable() *NetworkInstance_Fdb_MacTable {
	if t != nil && t.MacTable != nil {
		return t.MacTable
	}
	return nil
}

// GetMacAgingTime retrieves the value of the leaf MacAgingTime from the NetworkInstance_Fdb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAgingTime is set, it can safely use t.GetMacAgingTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAgingTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb) GetMacAgingTime() uint16 {
	if t == nil || t.MacAgingTime == nil {
		return 0
	}
	return *t.MacAgingTime
}

// GetMacLearning retrieves the value of the leaf MacLearning from the NetworkInstance_Fdb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacLearning is set, it can safely use t.GetMacLearning()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacLearning == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb) GetMacLearning() bool {
	if t == nil || t.MacLearning == nil {
		return false
	}
	return *t.MacLearning
}

// GetMaximumEntries retrieves the value of the leaf MaximumEntries from the NetworkInstance_Fdb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumEntries is set, it can safely use t.GetMaximumEntries()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumEntries == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb) GetMaximumEntries() uint16 {
	if t == nil || t.MaximumEntries == nil {
		return 0
	}
	return *t.MaximumEntries
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Fdb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Fdb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Fdb) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Fdb_MacTable represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table YANG schema element.
type NetworkInstance_Fdb_MacTable struct {
	ΛMetadata []ygot.Annotation                                                              `path:"@" ygotAnnotation:"true"`
	Entry     map[NetworkInstance_Fdb_MacTable_Entry_Key]*NetworkInstance_Fdb_MacTable_Entry `path:"entries/entry" module:"openconfig-network-instance"`
	ΛEntry    []ygot.Annotation                                                              `path:"entries/@entry" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Fdb_MacTable implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Fdb_MacTable) IsYANGGoStruct() {}

// NetworkInstance_Fdb_MacTable_Entry_Key represents the key for list Entry of element /openconfig-network-instance/network-instances/network-instance/fdb/mac-table.
type NetworkInstance_Fdb_MacTable_Entry_Key struct {
	MacAddress string `path:"mac-address"`
	Vlan       uint16 `path:"vlan"`
}

// NewEntry creates a new entry in the Entry list of the
// NetworkInstance_Fdb_MacTable struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Fdb_MacTable) NewEntry(MacAddress string, Vlan uint16) (*NetworkInstance_Fdb_MacTable_Entry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Entry == nil {
		t.Entry = make(map[NetworkInstance_Fdb_MacTable_Entry_Key]*NetworkInstance_Fdb_MacTable_Entry)
	}

	key := NetworkInstance_Fdb_MacTable_Entry_Key{
		MacAddress: MacAddress,
		Vlan:       Vlan,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Entry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Entry", key)
	}

	t.Entry[key] = &NetworkInstance_Fdb_MacTable_Entry{
		MacAddress: &MacAddress,
		Vlan:       &Vlan,
	}

	return t.Entry[key], nil
}

// RenameEntry renames an entry in the list Entry within
// the NetworkInstance_Fdb_MacTable struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Fdb_MacTable) RenameEntry(oldK, newK NetworkInstance_Fdb_MacTable_Entry_Key) error {
	if _, ok := t.Entry[newK]; ok {
		return fmt.Errorf("key %v already exists in Entry", newK)
	}

	e, ok := t.Entry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Entry", oldK)
	}
	e.MacAddress = &newK.MacAddress
	e.Vlan = &newK.Vlan

	t.Entry[newK] = e
	delete(t.Entry, oldK)
	return nil
}

// GetOrCreateEntry retrieves the value with the specified keys from
// the receiver NetworkInstance_Fdb_MacTable. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Fdb_MacTable) GetOrCreateEntry(MacAddress string, Vlan uint16) *NetworkInstance_Fdb_MacTable_Entry {

	key := NetworkInstance_Fdb_MacTable_Entry_Key{
		MacAddress: MacAddress,
		Vlan:       Vlan,
	}

	if v, ok := t.Entry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewEntry(MacAddress, Vlan)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateEntry got unexpected error: %v", err))
	}
	return v
}

// GetEntry retrieves the value with the specified key from
// the Entry map field of NetworkInstance_Fdb_MacTable. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Fdb_MacTable) GetEntry(MacAddress string, Vlan uint16) *NetworkInstance_Fdb_MacTable_Entry {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Fdb_MacTable_Entry_Key{
		MacAddress: MacAddress,
		Vlan:       Vlan,
	}

	if lm, ok := t.Entry[key]; ok {
		return lm
	}
	return nil
}

// AppendEntry appends the supplied NetworkInstance_Fdb_MacTable_Entry struct to the
// list Entry of NetworkInstance_Fdb_MacTable. If the key value(s) specified in
// the supplied NetworkInstance_Fdb_MacTable_Entry already exist in the list, an error is
// returned.
func (t *NetworkInstance_Fdb_MacTable) AppendEntry(v *NetworkInstance_Fdb_MacTable_Entry) error {
	if v.MacAddress == nil {
		return fmt.Errorf("invalid nil key for MacAddress")
	}

	if v.Vlan == nil {
		return fmt.Errorf("invalid nil key for Vlan")
	}

	key := NetworkInstance_Fdb_MacTable_Entry_Key{
		MacAddress: *v.MacAddress,
		Vlan:       *v.Vlan,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Entry == nil {
		t.Entry = make(map[NetworkInstance_Fdb_MacTable_Entry_Key]*NetworkInstance_Fdb_MacTable_Entry)
	}

	if _, ok := t.Entry[key]; ok {
		return fmt.Errorf("duplicate key for list Entry %v", key)
	}

	t.Entry[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Fdb_MacTable) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Fdb_MacTable"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Fdb_MacTable) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Fdb_MacTable_Entry represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry YANG schema element.
type NetworkInstance_Fdb_MacTable_Entry struct {
	ΛMetadata   []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	Age         *uint64                                       `path:"state/age" module:"openconfig-network-instance"`
	ΛAge        []ygot.Annotation                             `path:"state/@age" ygotAnnotation:"true"`
	EntryType   E_Entry_EntryType                             `path:"state/entry-type" module:"openconfig-network-instance"`
	ΛEntryType  []ygot.Annotation                             `path:"state/@entry-type" ygotAnnotation:"true"`
	Interface   *NetworkInstance_Fdb_MacTable_Entry_Interface `path:"interface" module:"openconfig-network-instance"`
	ΛInterface  []ygot.Annotation                             `path:"@interface" ygotAnnotation:"true"`
	MacAddress  *string                                       `path:"state/mac-address|mac-address" shadow-path:"config/mac-address" module:"openconfig-network-instance"`
	ΛMacAddress []ygot.Annotation                             `path:"state/@mac-address|@mac-address" ygotAnnotation:"true"`
	Vlan        *uint16                                       `path:"state/vlan|vlan" shadow-path:"config/vlan" module:"openconfig-network-instance"`
	ΛVlan       []ygot.Annotation                             `path:"state/@vlan|@vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Fdb_MacTable_Entry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Fdb_MacTable_Entry) IsYANGGoStruct() {}

// GetOrCreateInterface retrieves the value of the Interface field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Fdb_MacTable_Entry) GetOrCreateInterface() *NetworkInstance_Fdb_MacTable_Entry_Interface {
	if t.Interface != nil {
		return t.Interface
	}
	t.Interface = &NetworkInstance_Fdb_MacTable_Entry_Interface{}
	return t.Interface
}

// GetInterface returns the value of the Interface struct pointer
// from NetworkInstance_Fdb_MacTable_Entry. If the receiver or the field Interface is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Fdb_MacTable_Entry) GetInterface() *NetworkInstance_Fdb_MacTable_Entry_Interface {
	if t != nil && t.Interface != nil {
		return t.Interface
	}
	return nil
}

// GetAge retrieves the value of the leaf Age from the NetworkInstance_Fdb_MacTable_Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Age is set, it can safely use t.GetAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Age == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb_MacTable_Entry) GetAge() uint64 {
	if t == nil || t.Age == nil {
		return 0
	}
	return *t.Age
}

// GetEntryType retrieves the value of the leaf EntryType from the NetworkInstance_Fdb_MacTable_Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EntryType is set, it can safely use t.GetEntryType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EntryType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb_MacTable_Entry) GetEntryType() E_Entry_EntryType {
	if t == nil || t.EntryType == 0 {
		return 0
	}
	return t.EntryType
}

// GetMacAddress retrieves the value of the leaf MacAddress from the NetworkInstance_Fdb_MacTable_Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAddress is set, it can safely use t.GetMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb_MacTable_Entry) GetMacAddress() string {
	if t == nil || t.MacAddress == nil {
		return ""
	}
	return *t.MacAddress
}

// GetVlan retrieves the value of the leaf Vlan from the NetworkInstance_Fdb_MacTable_Entry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Vlan is set, it can safely use t.GetVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Vlan == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb_MacTable_Entry) GetVlan() uint16 {
	if t == nil || t.Vlan == nil {
		return 0
	}
	return *t.Vlan
}

// ΛListKeyMap returns the keys of the NetworkInstance_Fdb_MacTable_Entry struct, which is a YANG list entry.
func (t *NetworkInstance_Fdb_MacTable_Entry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MacAddress == nil {
		return nil, fmt.Errorf("nil value for key MacAddress")
	}

	if t.Vlan == nil {
		return nil, fmt.Errorf("nil value for key Vlan")
	}

	return map[string]interface{}{
		"mac-address": *t.MacAddress,
		"vlan":        *t.Vlan,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Fdb_MacTable_Entry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Fdb_MacTable_Entry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Fdb_MacTable_Entry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Fdb_MacTable_Entry_Interface represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/interface YANG schema element.
type NetworkInstance_Fdb_MacTable_Entry_Interface struct {
	ΛMetadata     []ygot.Annotation                                          `path:"@" ygotAnnotation:"true"`
	InterfaceRef  *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef []ygot.Annotation                                          `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Fdb_MacTable_Entry_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Fdb_MacTable_Entry_Interface) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Fdb_MacTable_Entry_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface) GetInterfaceRef() *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Fdb_MacTable_Entry_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/interface/interface-ref YANG schema element.
type NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Fdb_MacTable_Entry_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_InterInstancePolicies represents the /openconfig-network-instance/network-instances/network-instance/inter-instance-policies YANG schema element.
type NetworkInstance_InterInstancePolicies struct {
	ΛMetadata    []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	ApplyPolicy  *NetworkInstance_InterInstancePolicies_ApplyPolicy `path:"apply-policy" module:"openconfig-network-instance"`
	ΛApplyPolicy []ygot.Annotation                                  `path:"@apply-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_InterInstancePolicies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_InterInstancePolicies) IsYANGGoStruct() {}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_InterInstancePolicies) GetOrCreateApplyPolicy() *NetworkInstance_InterInstancePolicies_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &NetworkInstance_InterInstancePolicies_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from NetworkInstance_InterInstancePolicies. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_InterInstancePolicies) GetApplyPolicy() *NetworkInstance_InterInstancePolicies_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_InterInstancePolicies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_InterInstancePolicies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_InterInstancePolicies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_InterInstancePolicies_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/inter-instance-policies/apply-policy YANG schema element.
type NetworkInstance_InterInstancePolicies_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-network-instance"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-network-instance"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_InterInstancePolicies_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_InterInstancePolicies_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the NetworkInstance_InterInstancePolicies_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_InterInstancePolicies_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_InterInstancePolicies_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_InterInstancePolicies_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the NetworkInstance_InterInstancePolicies_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_InterInstancePolicies_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_InterInstancePolicies_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_InterInstancePolicies_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_InterInstancePolicies_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_InterInstancePolicies_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_InterInstancePolicies_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Interface represents the /openconfig-network-instance/network-instances/network-instance/interfaces/interface YANG schema element.
type NetworkInstance_Interface struct {
	ΛMetadata                  []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	AssociatedAddressFamilies  []E_OpenconfigTypes_ADDRESS_FAMILY `path:"state/associated-address-families" shadow-path:"config/associated-address-families" module:"openconfig-network-instance"`
	ΛAssociatedAddressFamilies []ygot.Annotation                  `path:"state/@associated-address-families" ygotAnnotation:"true"`
	Id                         *string                            `path:"state/id|id" shadow-path:"config/id" module:"openconfig-network-instance"`
	ΛId                        []ygot.Annotation                  `path:"state/@id|@id" ygotAnnotation:"true"`
	Interface                  *string                            `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface                 []ygot.Annotation                  `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface               *uint32                            `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface              []ygot.Annotation                  `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Interface) IsYANGGoStruct() {}

// GetAssociatedAddressFamilies retrieves the value of the leaf AssociatedAddressFamilies from the NetworkInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AssociatedAddressFamilies is set, it can safely use t.GetAssociatedAddressFamilies()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AssociatedAddressFamilies == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Interface) GetAssociatedAddressFamilies() []E_OpenconfigTypes_ADDRESS_FAMILY {
	if t == nil || t.AssociatedAddressFamilies == nil {
		return nil
	}
	return t.AssociatedAddressFamilies
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Interface) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Interface) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Interface) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// ΛListKeyMap returns the keys of the NetworkInstance_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Mpls represents the /openconfig-network-instance/network-instances/network-instance/mpls YANG schema element.
type NetworkInstance_Mpls struct {
	ΛMetadata           []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Global              *NetworkInstance_Mpls_Global               `path:"global" module:"openconfig-network-instance"`
	ΛGlobal             []ygot.Annotation                          `path:"@global" ygotAnnotation:"true"`
	Interface           map[string]*NetworkInstance_Mpls_Interface `path:"te-interface-attributes/interface" module:"openconfig-network-instance"`
	ΛInterface          []ygot.Annotation                          `path:"te-interface-attributes/@interface" ygotAnnotation:"true"`
	Lsps                *NetworkInstance_Mpls_Lsps                 `path:"lsps" module:"openconfig-network-instance"`
	ΛLsps               []ygot.Annotation                          `path:"@lsps" ygotAnnotation:"true"`
	SignalingProtocols  *NetworkInstance_Mpls_SignalingProtocols   `path:"signaling-protocols" module:"openconfig-network-instance"`
	ΛSignalingProtocols []ygot.Annotation                          `path:"@signaling-protocols" ygotAnnotation:"true"`
	TeGlobalAttributes  *NetworkInstance_Mpls_TeGlobalAttributes   `path:"te-global-attributes" module:"openconfig-network-instance"`
	ΛTeGlobalAttributes []ygot.Annotation                          `path:"@te-global-attributes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Mpls struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls) NewInterface(InterfaceId string) (*NetworkInstance_Mpls_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Mpls_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Mpls struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Mpls_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Mpls. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls) GetInterface(InterfaceId string) *NetworkInstance_Mpls_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Mpls_Interface struct to the
// list Interface of NetworkInstance_Mpls. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls) AppendInterface(v *NetworkInstance_Mpls_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls) GetOrCreateGlobal() *NetworkInstance_Mpls_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Mpls_Global{}
	return t.Global
}

// GetOrCreateLsps retrieves the value of the Lsps field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls) GetOrCreateLsps() *NetworkInstance_Mpls_Lsps {
	if t.Lsps != nil {
		return t.Lsps
	}
	t.Lsps = &NetworkInstance_Mpls_Lsps{}
	return t.Lsps
}

// GetOrCreateSignalingProtocols retrieves the value of the SignalingProtocols field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls) GetOrCreateSignalingProtocols() *NetworkInstance_Mpls_SignalingProtocols {
	if t.SignalingProtocols != nil {
		return t.SignalingProtocols
	}
	t.SignalingProtocols = &NetworkInstance_Mpls_SignalingProtocols{}
	return t.SignalingProtocols
}

// GetOrCreateTeGlobalAttributes retrieves the value of the TeGlobalAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls) GetOrCreateTeGlobalAttributes() *NetworkInstance_Mpls_TeGlobalAttributes {
	if t.TeGlobalAttributes != nil {
		return t.TeGlobalAttributes
	}
	t.TeGlobalAttributes = &NetworkInstance_Mpls_TeGlobalAttributes{}
	return t.TeGlobalAttributes
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Mpls. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls) GetGlobal() *NetworkInstance_Mpls_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// GetLsps returns the value of the Lsps struct pointer
// from NetworkInstance_Mpls. If the receiver or the field Lsps is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls) GetLsps() *NetworkInstance_Mpls_Lsps {
	if t != nil && t.Lsps != nil {
		return t.Lsps
	}
	return nil
}

// GetSignalingProtocols returns the value of the SignalingProtocols struct pointer
// from NetworkInstance_Mpls. If the receiver or the field SignalingProtocols is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls) GetSignalingProtocols() *NetworkInstance_Mpls_SignalingProtocols {
	if t != nil && t.SignalingProtocols != nil {
		return t.SignalingProtocols
	}
	return nil
}

// GetTeGlobalAttributes returns the value of the TeGlobalAttributes struct pointer
// from NetworkInstance_Mpls. If the receiver or the field TeGlobalAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls) GetTeGlobalAttributes() *NetworkInstance_Mpls_TeGlobalAttributes {
	if t != nil && t.TeGlobalAttributes != nil {
		return t.TeGlobalAttributes
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Mpls_Global represents the /openconfig-network-instance/network-instances/network-instance/mpls/global YANG schema element.
type NetworkInstance_Mpls_Global struct {
	ΛMetadata           []ygot.Annotation                                          `path:"@" ygotAnnotation:"true"`
	Interface           map[string]*NetworkInstance_Mpls_Global_Interface          `path:"interface-attributes/interface" module:"openconfig-network-instance"`
	ΛInterface          []ygot.Annotation                                          `path:"interface-attributes/@interface" ygotAnnotation:"true"`
	NullLabel           E_OpenconfigMplsTypes_NULL_LABEL_TYPE                      `path:"state/null-label" shadow-path:"config/null-label" module:"openconfig-network-instance"`
	ΛNullLabel          []ygot.Annotation                                          `path:"state/@null-label" ygotAnnotation:"true"`
	PwEncapsulation     E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION             `path:"state/pw-encapsulation" shadow-path:"config/pw-encapsulation" module:"openconfig-network-instance"`
	ΛPwEncapsulation    []ygot.Annotation                                          `path:"state/@pw-encapsulation" ygotAnnotation:"true"`
	ReservedLabelBlock  map[string]*NetworkInstance_Mpls_Global_ReservedLabelBlock `path:"reserved-label-blocks/reserved-label-block" module:"openconfig-network-instance"`
	ΛReservedLabelBlock []ygot.Annotation                                          `path:"reserved-label-blocks/@reserved-label-block" ygotAnnotation:"true"`
	TtlPropagation      *bool                                                      `path:"state/ttl-propagation" shadow-path:"config/ttl-propagation" module:"openconfig-network-instance"`
	ΛTtlPropagation     []ygot.Annotation                                          `path:"state/@ttl-propagation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Global) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Mpls_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Global) NewInterface(InterfaceId string) (*NetworkInstance_Mpls_Global_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_Global_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Mpls_Global_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Mpls_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Global) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Global) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Mpls_Global_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Mpls_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Global) GetInterface(InterfaceId string) *NetworkInstance_Mpls_Global_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Mpls_Global_Interface struct to the
// list Interface of NetworkInstance_Mpls_Global. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Global_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Global) AppendInterface(v *NetworkInstance_Mpls_Global_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_Global_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewReservedLabelBlock creates a new entry in the ReservedLabelBlock list of the
// NetworkInstance_Mpls_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Global) NewReservedLabelBlock(LocalId string) (*NetworkInstance_Mpls_Global_ReservedLabelBlock, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ReservedLabelBlock == nil {
		t.ReservedLabelBlock = make(map[string]*NetworkInstance_Mpls_Global_ReservedLabelBlock)
	}

	key := LocalId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ReservedLabelBlock[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ReservedLabelBlock", key)
	}

	t.ReservedLabelBlock[key] = &NetworkInstance_Mpls_Global_ReservedLabelBlock{
		LocalId: &LocalId,
	}

	return t.ReservedLabelBlock[key], nil
}

// RenameReservedLabelBlock renames an entry in the list ReservedLabelBlock within
// the NetworkInstance_Mpls_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Global) RenameReservedLabelBlock(oldK, newK string) error {
	if _, ok := t.ReservedLabelBlock[newK]; ok {
		return fmt.Errorf("key %v already exists in ReservedLabelBlock", newK)
	}

	e, ok := t.ReservedLabelBlock[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ReservedLabelBlock", oldK)
	}
	e.LocalId = &newK

	t.ReservedLabelBlock[newK] = e
	delete(t.ReservedLabelBlock, oldK)
	return nil
}

// GetOrCreateReservedLabelBlock retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Global) GetOrCreateReservedLabelBlock(LocalId string) *NetworkInstance_Mpls_Global_ReservedLabelBlock {

	key := LocalId

	if v, ok := t.ReservedLabelBlock[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewReservedLabelBlock(LocalId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateReservedLabelBlock got unexpected error: %v", err))
	}
	return v
}

// GetReservedLabelBlock retrieves the value with the specified key from
// the ReservedLabelBlock map field of NetworkInstance_Mpls_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Global) GetReservedLabelBlock(LocalId string) *NetworkInstance_Mpls_Global_ReservedLabelBlock {

	if t == nil {
		return nil
	}

	key := LocalId

	if lm, ok := t.ReservedLabelBlock[key]; ok {
		return lm
	}
	return nil
}

// AppendReservedLabelBlock appends the supplied NetworkInstance_Mpls_Global_ReservedLabelBlock struct to the
// list ReservedLabelBlock of NetworkInstance_Mpls_Global. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Global_ReservedLabelBlock already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Global) AppendReservedLabelBlock(v *NetworkInstance_Mpls_Global_ReservedLabelBlock) error {
	if v.LocalId == nil {
		return fmt.Errorf("invalid nil key received for LocalId")
	}

	key := *v.LocalId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ReservedLabelBlock == nil {
		t.ReservedLabelBlock = make(map[string]*NetworkInstance_Mpls_Global_ReservedLabelBlock)
	}

	if _, ok := t.ReservedLabelBlock[key]; ok {
		return fmt.Errorf("duplicate key for list ReservedLabelBlock %v", key)
	}

	t.ReservedLabelBlock[key] = v
	return nil
}

// GetNullLabel retrieves the value of the leaf NullLabel from the NetworkInstance_Mpls_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NullLabel is set, it can safely use t.GetNullLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NullLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global) GetNullLabel() E_OpenconfigMplsTypes_NULL_LABEL_TYPE {
	if t == nil || t.NullLabel == 0 {
		return OpenconfigMplsTypes_NULL_LABEL_TYPE_IMPLICIT
	}
	return t.NullLabel
}

// GetPwEncapsulation retrieves the value of the leaf PwEncapsulation from the NetworkInstance_Mpls_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PwEncapsulation is set, it can safely use t.GetPwEncapsulation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PwEncapsulation == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global) GetPwEncapsulation() E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION {
	if t == nil || t.PwEncapsulation == 0 {
		return 0
	}
	return t.PwEncapsulation
}

// GetTtlPropagation retrieves the value of the leaf TtlPropagation from the NetworkInstance_Mpls_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TtlPropagation is set, it can safely use t.GetTtlPropagation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TtlPropagation == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global) GetTtlPropagation() bool {
	if t == nil || t.TtlPropagation == nil {
		return true
	}
	return *t.TtlPropagation
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Global) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Mpls_Global_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface YANG schema element.
type NetworkInstance_Mpls_Global_Interface struct {
	ΛMetadata     []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	InterfaceId   *string                                             `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId  []ygot.Annotation                                   `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef  *NetworkInstance_Mpls_Global_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef []ygot.Annotation                                   `path:"@interface-ref" ygotAnnotation:"true"`
	MplsEnabled   *bool                                               `path:"state/mpls-enabled" shadow-path:"config/mpls-enabled" module:"openconfig-network-instance"`
	ΛMplsEnabled  []ygot.Annotation                                   `path:"state/@mpls-enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Global_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Global_Interface) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Global_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Mpls_Global_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Mpls_Global_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Mpls_Global_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Global_Interface) GetInterfaceRef() *NetworkInstance_Mpls_Global_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Mpls_Global_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetMplsEnabled retrieves the value of the leaf MplsEnabled from the NetworkInstance_Mpls_Global_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsEnabled is set, it can safely use t.GetMplsEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsEnabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_Interface) GetMplsEnabled() bool {
	if t == nil || t.MplsEnabled == nil {
		return false
	}
	return *t.MplsEnabled
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Global_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Global_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Global_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Global_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Global_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Global_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface/interface-ref YANG schema element.
type NetworkInstance_Mpls_Global_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Global_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Global_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Mpls_Global_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Mpls_Global_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Global_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Global_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Global_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Global_ReservedLabelBlock represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block YANG schema element.
type NetworkInstance_Mpls_Global_ReservedLabelBlock struct {
	ΛMetadata   []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	LocalId     *string                                                         `path:"state/local-id|local-id" shadow-path:"config/local-id" module:"openconfig-network-instance"`
	ΛLocalId    []ygot.Annotation                                               `path:"state/@local-id|@local-id" ygotAnnotation:"true"`
	LowerBound  NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union `path:"state/lower-bound" shadow-path:"config/lower-bound" module:"openconfig-network-instance"`
	ΛLowerBound []ygot.Annotation                                               `path:"state/@lower-bound" ygotAnnotation:"true"`
	UpperBound  NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union `path:"state/upper-bound" shadow-path:"config/upper-bound" module:"openconfig-network-instance"`
	ΛUpperBound []ygot.Annotation                                               `path:"state/@upper-bound" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Global_ReservedLabelBlock implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Global_ReservedLabelBlock) IsYANGGoStruct() {}

// GetLocalId retrieves the value of the leaf LocalId from the NetworkInstance_Mpls_Global_ReservedLabelBlock
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalId is set, it can safely use t.GetLocalId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) GetLocalId() string {
	if t == nil || t.LocalId == nil {
		return ""
	}
	return *t.LocalId
}

// GetLowerBound retrieves the value of the leaf LowerBound from the NetworkInstance_Mpls_Global_ReservedLabelBlock
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LowerBound is set, it can safely use t.GetLowerBound()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LowerBound == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) GetLowerBound() NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union {
	if t == nil || t.LowerBound == nil {
		return nil
	}
	return t.LowerBound
}

// GetUpperBound retrieves the value of the leaf UpperBound from the NetworkInstance_Mpls_Global_ReservedLabelBlock
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpperBound is set, it can safely use t.GetUpperBound()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpperBound == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) GetUpperBound() NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union {
	if t == nil || t.UpperBound == nil {
		return nil
	}
	return t.UpperBound
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Global_ReservedLabelBlock struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalId == nil {
		return nil, fmt.Errorf("nil value for key LocalId")
	}

	return map[string]interface{}{
		"local-id": *t.LocalId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Global_ReservedLabelBlock"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/lower-bound within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union()
}

// Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union() {
}

// To_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) To_NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union(i interface{}) (NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Global_ReservedLabelBlock_LowerBound_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/upper-bound within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union()
}

// Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union() {
}

// To_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Global_ReservedLabelBlock) To_NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union(i interface{}) (NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Global_ReservedLabelBlock_UpperBound_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface YANG schema element.
type NetworkInstance_Mpls_Interface struct {
	ΛMetadata             []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	AdminGroup            []string                                             `path:"state/admin-group" shadow-path:"config/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup           []ygot.Annotation                                    `path:"state/@admin-group" ygotAnnotation:"true"`
	IgpFloodingBandwidth  *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth `path:"igp-flooding-bandwidth" module:"openconfig-network-instance"`
	ΛIgpFloodingBandwidth []ygot.Annotation                                    `path:"@igp-flooding-bandwidth" ygotAnnotation:"true"`
	InterfaceId           *string                                              `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId          []ygot.Annotation                                    `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef          *NetworkInstance_Mpls_Interface_InterfaceRef         `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef         []ygot.Annotation                                    `path:"@interface-ref" ygotAnnotation:"true"`
	SrlgMembership        []string                                             `path:"state/srlg-membership" shadow-path:"config/srlg-membership" module:"openconfig-network-instance"`
	ΛSrlgMembership       []ygot.Annotation                                    `path:"state/@srlg-membership" ygotAnnotation:"true"`
	TeMetric              *uint32                                              `path:"state/te-metric" shadow-path:"config/te-metric" module:"openconfig-network-instance"`
	ΛTeMetric             []ygot.Annotation                                    `path:"state/@te-metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Interface) IsYANGGoStruct() {}

// GetOrCreateIgpFloodingBandwidth retrieves the value of the IgpFloodingBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Interface) GetOrCreateIgpFloodingBandwidth() *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth {
	if t.IgpFloodingBandwidth != nil {
		return t.IgpFloodingBandwidth
	}
	t.IgpFloodingBandwidth = &NetworkInstance_Mpls_Interface_IgpFloodingBandwidth{}
	return t.IgpFloodingBandwidth
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Mpls_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Mpls_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetIgpFloodingBandwidth returns the value of the IgpFloodingBandwidth struct pointer
// from NetworkInstance_Mpls_Interface. If the receiver or the field IgpFloodingBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Interface) GetIgpFloodingBandwidth() *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth {
	if t != nil && t.IgpFloodingBandwidth != nil {
		return t.IgpFloodingBandwidth
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Mpls_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Interface) GetInterfaceRef() *NetworkInstance_Mpls_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetAdminGroup retrieves the value of the leaf AdminGroup from the NetworkInstance_Mpls_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminGroup is set, it can safely use t.GetAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface) GetAdminGroup() []string {
	if t == nil || t.AdminGroup == nil {
		return nil
	}
	return t.AdminGroup
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Mpls_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetSrlgMembership retrieves the value of the leaf SrlgMembership from the NetworkInstance_Mpls_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SrlgMembership is set, it can safely use t.GetSrlgMembership()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SrlgMembership == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface) GetSrlgMembership() []string {
	if t == nil || t.SrlgMembership == nil {
		return nil
	}
	return t.SrlgMembership
}

// GetTeMetric retrieves the value of the leaf TeMetric from the NetworkInstance_Mpls_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TeMetric is set, it can safely use t.GetTeMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TeMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface) GetTeMetric() uint32 {
	if t == nil || t.TeMetric == nil {
		return 0
	}
	return *t.TeMetric
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Interface_IgpFloodingBandwidth represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth YANG schema element.
type NetworkInstance_Mpls_Interface_IgpFloodingBandwidth struct {
	ΛMetadata               []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	DeltaPercentage         *uint8                                        `path:"state/delta-percentage" shadow-path:"config/delta-percentage" module:"openconfig-network-instance"`
	ΛDeltaPercentage        []ygot.Annotation                             `path:"state/@delta-percentage" ygotAnnotation:"true"`
	DownThresholds          []uint8                                       `path:"state/down-thresholds" shadow-path:"config/down-thresholds" module:"openconfig-network-instance"`
	ΛDownThresholds         []ygot.Annotation                             `path:"state/@down-thresholds" ygotAnnotation:"true"`
	ThresholdSpecification  E_IgpFloodingBandwidth_ThresholdSpecification `path:"state/threshold-specification" shadow-path:"config/threshold-specification" module:"openconfig-network-instance"`
	ΛThresholdSpecification []ygot.Annotation                             `path:"state/@threshold-specification" ygotAnnotation:"true"`
	ThresholdType           E_IgpFloodingBandwidth_ThresholdType          `path:"state/threshold-type" shadow-path:"config/threshold-type" module:"openconfig-network-instance"`
	ΛThresholdType          []ygot.Annotation                             `path:"state/@threshold-type" ygotAnnotation:"true"`
	UpDownThresholds        []uint8                                       `path:"state/up-down-thresholds" shadow-path:"config/up-down-thresholds" module:"openconfig-network-instance"`
	ΛUpDownThresholds       []ygot.Annotation                             `path:"state/@up-down-thresholds" ygotAnnotation:"true"`
	UpThresholds            []uint8                                       `path:"state/up-thresholds" shadow-path:"config/up-thresholds" module:"openconfig-network-instance"`
	ΛUpThresholds           []ygot.Annotation                             `path:"state/@up-thresholds" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Interface_IgpFloodingBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) IsYANGGoStruct() {}

// GetDeltaPercentage retrieves the value of the leaf DeltaPercentage from the NetworkInstance_Mpls_Interface_IgpFloodingBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DeltaPercentage is set, it can safely use t.GetDeltaPercentage()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DeltaPercentage == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) GetDeltaPercentage() uint8 {
	if t == nil || t.DeltaPercentage == nil {
		return 0
	}
	return *t.DeltaPercentage
}

// GetDownThresholds retrieves the value of the leaf DownThresholds from the NetworkInstance_Mpls_Interface_IgpFloodingBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DownThresholds is set, it can safely use t.GetDownThresholds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DownThresholds == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) GetDownThresholds() []uint8 {
	if t == nil || t.DownThresholds == nil {
		return nil
	}
	return t.DownThresholds
}

// GetThresholdSpecification retrieves the value of the leaf ThresholdSpecification from the NetworkInstance_Mpls_Interface_IgpFloodingBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ThresholdSpecification is set, it can safely use t.GetThresholdSpecification()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ThresholdSpecification == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) GetThresholdSpecification() E_IgpFloodingBandwidth_ThresholdSpecification {
	if t == nil || t.ThresholdSpecification == 0 {
		return 0
	}
	return t.ThresholdSpecification
}

// GetThresholdType retrieves the value of the leaf ThresholdType from the NetworkInstance_Mpls_Interface_IgpFloodingBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ThresholdType is set, it can safely use t.GetThresholdType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ThresholdType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) GetThresholdType() E_IgpFloodingBandwidth_ThresholdType {
	if t == nil || t.ThresholdType == 0 {
		return 0
	}
	return t.ThresholdType
}

// GetUpDownThresholds retrieves the value of the leaf UpDownThresholds from the NetworkInstance_Mpls_Interface_IgpFloodingBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDownThresholds is set, it can safely use t.GetUpDownThresholds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDownThresholds == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) GetUpDownThresholds() []uint8 {
	if t == nil || t.UpDownThresholds == nil {
		return nil
	}
	return t.UpDownThresholds
}

// GetUpThresholds retrieves the value of the leaf UpThresholds from the NetworkInstance_Mpls_Interface_IgpFloodingBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpThresholds is set, it can safely use t.GetUpThresholds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpThresholds == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) GetUpThresholds() []uint8 {
	if t == nil || t.UpThresholds == nil {
		return nil
	}
	return t.UpThresholds
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Interface_IgpFloodingBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Interface_IgpFloodingBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/interface-ref YANG schema element.
type NetworkInstance_Mpls_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Mpls_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Mpls_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps YANG schema element.
type NetworkInstance_Mpls_Lsps struct {
	ΛMetadata          []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	ConstrainedPath    *NetworkInstance_Mpls_Lsps_ConstrainedPath      `path:"constrained-path" module:"openconfig-network-instance"`
	ΛConstrainedPath   []ygot.Annotation                               `path:"@constrained-path" ygotAnnotation:"true"`
	StaticLsp          map[string]*NetworkInstance_Mpls_Lsps_StaticLsp `path:"static-lsps/static-lsp" module:"openconfig-network-instance"`
	ΛStaticLsp         []ygot.Annotation                               `path:"static-lsps/@static-lsp" ygotAnnotation:"true"`
	UnconstrainedPath  *NetworkInstance_Mpls_Lsps_UnconstrainedPath    `path:"unconstrained-path" module:"openconfig-network-instance"`
	ΛUnconstrainedPath []ygot.Annotation                               `path:"@unconstrained-path" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps) IsYANGGoStruct() {}

// NewStaticLsp creates a new entry in the StaticLsp list of the
// NetworkInstance_Mpls_Lsps struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps) NewStaticLsp(Name string) (*NetworkInstance_Mpls_Lsps_StaticLsp, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.StaticLsp == nil {
		t.StaticLsp = make(map[string]*NetworkInstance_Mpls_Lsps_StaticLsp)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.StaticLsp[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list StaticLsp", key)
	}

	t.StaticLsp[key] = &NetworkInstance_Mpls_Lsps_StaticLsp{
		Name: &Name,
	}

	return t.StaticLsp[key], nil
}

// RenameStaticLsp renames an entry in the list StaticLsp within
// the NetworkInstance_Mpls_Lsps struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps) RenameStaticLsp(oldK, newK string) error {
	if _, ok := t.StaticLsp[newK]; ok {
		return fmt.Errorf("key %v already exists in StaticLsp", newK)
	}

	e, ok := t.StaticLsp[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in StaticLsp", oldK)
	}
	e.Name = &newK

	t.StaticLsp[newK] = e
	delete(t.StaticLsp, oldK)
	return nil
}

// GetOrCreateStaticLsp retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps) GetOrCreateStaticLsp(Name string) *NetworkInstance_Mpls_Lsps_StaticLsp {

	key := Name

	if v, ok := t.StaticLsp[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewStaticLsp(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateStaticLsp got unexpected error: %v", err))
	}
	return v
}

// GetStaticLsp retrieves the value with the specified key from
// the StaticLsp map field of NetworkInstance_Mpls_Lsps. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps) GetStaticLsp(Name string) *NetworkInstance_Mpls_Lsps_StaticLsp {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.StaticLsp[key]; ok {
		return lm
	}
	return nil
}

// AppendStaticLsp appends the supplied NetworkInstance_Mpls_Lsps_StaticLsp struct to the
// list StaticLsp of NetworkInstance_Mpls_Lsps. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_StaticLsp already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps) AppendStaticLsp(v *NetworkInstance_Mpls_Lsps_StaticLsp) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.StaticLsp == nil {
		t.StaticLsp = make(map[string]*NetworkInstance_Mpls_Lsps_StaticLsp)
	}

	if _, ok := t.StaticLsp[key]; ok {
		return fmt.Errorf("duplicate key for list StaticLsp %v", key)
	}

	t.StaticLsp[key] = v
	return nil
}

// GetOrCreateConstrainedPath retrieves the value of the ConstrainedPath field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps) GetOrCreateConstrainedPath() *NetworkInstance_Mpls_Lsps_ConstrainedPath {
	if t.ConstrainedPath != nil {
		return t.ConstrainedPath
	}
	t.ConstrainedPath = &NetworkInstance_Mpls_Lsps_ConstrainedPath{}
	return t.ConstrainedPath
}

// GetOrCreateUnconstrainedPath retrieves the value of the UnconstrainedPath field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps) GetOrCreateUnconstrainedPath() *NetworkInstance_Mpls_Lsps_UnconstrainedPath {
	if t.UnconstrainedPath != nil {
		return t.UnconstrainedPath
	}
	t.UnconstrainedPath = &NetworkInstance_Mpls_Lsps_UnconstrainedPath{}
	return t.UnconstrainedPath
}

// GetConstrainedPath returns the value of the ConstrainedPath struct pointer
// from NetworkInstance_Mpls_Lsps. If the receiver or the field ConstrainedPath is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps) GetConstrainedPath() *NetworkInstance_Mpls_Lsps_ConstrainedPath {
	if t != nil && t.ConstrainedPath != nil {
		return t.ConstrainedPath
	}
	return nil
}

// GetUnconstrainedPath returns the value of the UnconstrainedPath struct pointer
// from NetworkInstance_Mpls_Lsps. If the receiver or the field UnconstrainedPath is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps) GetUnconstrainedPath() *NetworkInstance_Mpls_Lsps_UnconstrainedPath {
	if t != nil && t.UnconstrainedPath != nil {
		return t.UnconstrainedPath
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Mpls_Lsps_ConstrainedPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath struct {
	ΛMetadata          []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	NamedExplicitPath  map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath `path:"named-explicit-paths/named-explicit-path" module:"openconfig-network-instance"`
	ΛNamedExplicitPath []ygot.Annotation                                                       `path:"named-explicit-paths/@named-explicit-path" ygotAnnotation:"true"`
	Tunnel             map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel            `path:"tunnels/tunnel" module:"openconfig-network-instance"`
	ΛTunnel            []ygot.Annotation                                                       `path:"tunnels/@tunnel" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath) IsYANGGoStruct() {}

// NewNamedExplicitPath creates a new entry in the NamedExplicitPath list of the
// NetworkInstance_Mpls_Lsps_ConstrainedPath struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) NewNamedExplicitPath(Name string) (*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NamedExplicitPath == nil {
		t.NamedExplicitPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NamedExplicitPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NamedExplicitPath", key)
	}

	t.NamedExplicitPath[key] = &NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath{
		Name: &Name,
	}

	return t.NamedExplicitPath[key], nil
}

// RenameNamedExplicitPath renames an entry in the list NamedExplicitPath within
// the NetworkInstance_Mpls_Lsps_ConstrainedPath struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) RenameNamedExplicitPath(oldK, newK string) error {
	if _, ok := t.NamedExplicitPath[newK]; ok {
		return fmt.Errorf("key %v already exists in NamedExplicitPath", newK)
	}

	e, ok := t.NamedExplicitPath[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NamedExplicitPath", oldK)
	}
	e.Name = &newK

	t.NamedExplicitPath[newK] = e
	delete(t.NamedExplicitPath, oldK)
	return nil
}

// GetOrCreateNamedExplicitPath retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps_ConstrainedPath. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) GetOrCreateNamedExplicitPath(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath {

	key := Name

	if v, ok := t.NamedExplicitPath[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNamedExplicitPath(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNamedExplicitPath got unexpected error: %v", err))
	}
	return v
}

// GetNamedExplicitPath retrieves the value with the specified key from
// the NamedExplicitPath map field of NetworkInstance_Mpls_Lsps_ConstrainedPath. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) GetNamedExplicitPath(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.NamedExplicitPath[key]; ok {
		return lm
	}
	return nil
}

// AppendNamedExplicitPath appends the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath struct to the
// list NamedExplicitPath of NetworkInstance_Mpls_Lsps_ConstrainedPath. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) AppendNamedExplicitPath(v *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NamedExplicitPath == nil {
		t.NamedExplicitPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath)
	}

	if _, ok := t.NamedExplicitPath[key]; ok {
		return fmt.Errorf("duplicate key for list NamedExplicitPath %v", key)
	}

	t.NamedExplicitPath[key] = v
	return nil
}

// NewTunnel creates a new entry in the Tunnel list of the
// NetworkInstance_Mpls_Lsps_ConstrainedPath struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) NewTunnel(Name string) (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tunnel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tunnel", key)
	}

	t.Tunnel[key] = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel{
		Name: &Name,
	}

	return t.Tunnel[key], nil
}

// RenameTunnel renames an entry in the list Tunnel within
// the NetworkInstance_Mpls_Lsps_ConstrainedPath struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) RenameTunnel(oldK, newK string) error {
	if _, ok := t.Tunnel[newK]; ok {
		return fmt.Errorf("key %v already exists in Tunnel", newK)
	}

	e, ok := t.Tunnel[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Tunnel", oldK)
	}
	e.Name = &newK

	t.Tunnel[newK] = e
	delete(t.Tunnel, oldK)
	return nil
}

// GetOrCreateTunnel retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps_ConstrainedPath. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) GetOrCreateTunnel(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel {

	key := Name

	if v, ok := t.Tunnel[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTunnel(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTunnel got unexpected error: %v", err))
	}
	return v
}

// GetTunnel retrieves the value with the specified key from
// the Tunnel map field of NetworkInstance_Mpls_Lsps_ConstrainedPath. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) GetTunnel(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Tunnel[key]; ok {
		return lm
	}
	return nil
}

// AppendTunnel appends the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel struct to the
// list Tunnel of NetworkInstance_Mpls_Lsps_ConstrainedPath. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) AppendTunnel(v *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel)
	}

	if _, ok := t.Tunnel[key]; ok {
		return fmt.Errorf("duplicate key for list Tunnel %v", key)
	}

	t.Tunnel[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath struct {
	ΛMetadata              []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	ExplicitRouteObject    map[uint8]*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject `path:"explicit-route-objects/explicit-route-object" module:"openconfig-network-instance"`
	ΛExplicitRouteObject   []ygot.Annotation                                                                          `path:"explicit-route-objects/@explicit-route-object" ygotAnnotation:"true"`
	Name                   *string                                                                                    `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName                  []ygot.Annotation                                                                          `path:"state/@name|@name" ygotAnnotation:"true"`
	SidProtectionRequired  *bool                                                                                      `path:"state/sid-protection-required" shadow-path:"config/sid-protection-required" module:"openconfig-network-instance"`
	ΛSidProtectionRequired []ygot.Annotation                                                                          `path:"state/@sid-protection-required" ygotAnnotation:"true"`
	SidSelectionMode       E_NamedExplicitPath_SidSelectionMode                                                       `path:"state/sid-selection-mode" shadow-path:"config/sid-selection-mode" module:"openconfig-network-instance"`
	ΛSidSelectionMode      []ygot.Annotation                                                                          `path:"state/@sid-selection-mode" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) IsYANGGoStruct() {}

// NewExplicitRouteObject creates a new entry in the ExplicitRouteObject list of the
// NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) NewExplicitRouteObject(Index uint8) (*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExplicitRouteObject == nil {
		t.ExplicitRouteObject = make(map[uint8]*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExplicitRouteObject[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExplicitRouteObject", key)
	}

	t.ExplicitRouteObject[key] = &NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject{
		Index: &Index,
	}

	return t.ExplicitRouteObject[key], nil
}

// RenameExplicitRouteObject renames an entry in the list ExplicitRouteObject within
// the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) RenameExplicitRouteObject(oldK, newK uint8) error {
	if _, ok := t.ExplicitRouteObject[newK]; ok {
		return fmt.Errorf("key %v already exists in ExplicitRouteObject", newK)
	}

	e, ok := t.ExplicitRouteObject[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ExplicitRouteObject", oldK)
	}
	e.Index = &newK

	t.ExplicitRouteObject[newK] = e
	delete(t.ExplicitRouteObject, oldK)
	return nil
}

// GetOrCreateExplicitRouteObject retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) GetOrCreateExplicitRouteObject(Index uint8) *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject {

	key := Index

	if v, ok := t.ExplicitRouteObject[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewExplicitRouteObject(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateExplicitRouteObject got unexpected error: %v", err))
	}
	return v
}

// GetExplicitRouteObject retrieves the value with the specified key from
// the ExplicitRouteObject map field of NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) GetExplicitRouteObject(Index uint8) *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.ExplicitRouteObject[key]; ok {
		return lm
	}
	return nil
}

// AppendExplicitRouteObject appends the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject struct to the
// list ExplicitRouteObject of NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) AppendExplicitRouteObject(v *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExplicitRouteObject == nil {
		t.ExplicitRouteObject = make(map[uint8]*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject)
	}

	if _, ok := t.ExplicitRouteObject[key]; ok {
		return fmt.Errorf("duplicate key for list ExplicitRouteObject %v", key)
	}

	t.ExplicitRouteObject[key] = v
	return nil
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetSidProtectionRequired retrieves the value of the leaf SidProtectionRequired from the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidProtectionRequired is set, it can safely use t.GetSidProtectionRequired()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidProtectionRequired == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) GetSidProtectionRequired() bool {
	if t == nil || t.SidProtectionRequired == nil {
		return false
	}
	return *t.SidProtectionRequired
}

// GetSidSelectionMode retrieves the value of the leaf SidSelectionMode from the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidSelectionMode is set, it can safely use t.GetSidSelectionMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidSelectionMode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) GetSidSelectionMode() E_NamedExplicitPath_SidSelectionMode {
	if t == nil || t.SidSelectionMode == 0 {
		return NamedExplicitPath_SidSelectionMode_MIXED_MODE
	}
	return t.SidSelectionMode
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject struct {
	ΛMetadata []ygot.Annotation            `path:"@" ygotAnnotation:"true"`
	Address   *string                      `path:"state/address" shadow-path:"config/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation            `path:"state/@address" ygotAnnotation:"true"`
	HopType   E_OpenconfigMpls_MplsHopType `path:"state/hop-type" shadow-path:"config/hop-type" module:"openconfig-network-instance"`
	ΛHopType  []ygot.Annotation            `path:"state/@hop-type" ygotAnnotation:"true"`
	Index     *uint8                       `path:"state/index|index" shadow-path:"config/index" module:"openconfig-network-instance"`
	ΛIndex    []ygot.Annotation            `path:"state/@index|@index" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetHopType retrieves the value of the leaf HopType from the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HopType is set, it can safely use t.GetHopType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HopType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) GetHopType() E_OpenconfigMpls_MplsHopType {
	if t == nil || t.HopType == 0 {
		return 0
	}
	return t.HopType
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) GetIndex() uint8 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPath_ExplicitRouteObject) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel struct {
	ΛMetadata                 []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	AdminStatus               E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS                             `path:"state/admin-status" shadow-path:"config/admin-status" module:"openconfig-network-instance"`
	ΛAdminStatus              []ygot.Annotation                                                     `path:"state/@admin-status" ygotAnnotation:"true"`
	AutoGenerated             *bool                                                                 `path:"state/auto-generated" module:"openconfig-network-instance"`
	ΛAutoGenerated            []ygot.Annotation                                                     `path:"state/@auto-generated" ygotAnnotation:"true"`
	Bandwidth                 *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth           `path:"bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth                []ygot.Annotation                                                     `path:"@bandwidth" ygotAnnotation:"true"`
	Counters                  *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters            `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters                 []ygot.Annotation                                                     `path:"state/@counters" ygotAnnotation:"true"`
	Description               *string                                                               `path:"state/description" shadow-path:"config/description" module:"openconfig-network-instance"`
	ΛDescription              []ygot.Annotation                                                     `path:"state/@description" ygotAnnotation:"true"`
	HoldPriority              *uint8                                                                `path:"state/hold-priority" shadow-path:"config/hold-priority" module:"openconfig-network-instance"`
	ΛHoldPriority             []ygot.Annotation                                                     `path:"state/@hold-priority" ygotAnnotation:"true"`
	Metric                    *int32                                                                `path:"state/metric" shadow-path:"config/metric" module:"openconfig-network-instance"`
	ΛMetric                   []ygot.Annotation                                                     `path:"state/@metric" ygotAnnotation:"true"`
	MetricType                E_OpenconfigMplsTypes_LSP_METRIC_TYPE                                 `path:"state/metric-type" shadow-path:"config/metric-type" module:"openconfig-network-instance"`
	ΛMetricType               []ygot.Annotation                                                     `path:"state/@metric-type" ygotAnnotation:"true"`
	Name                      *string                                                               `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName                     []ygot.Annotation                                                     `path:"state/@name|@name" ygotAnnotation:"true"`
	OperStatus                E_OpenconfigMplsTypes_LSP_OPER_STATUS                                 `path:"state/oper-status" module:"openconfig-network-instance"`
	ΛOperStatus               []ygot.Annotation                                                     `path:"state/@oper-status" ygotAnnotation:"true"`
	P2PTunnelAttributes       *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes `path:"p2p-tunnel-attributes" module:"openconfig-network-instance"`
	ΛP2PTunnelAttributes      []ygot.Annotation                                                     `path:"@p2p-tunnel-attributes" ygotAnnotation:"true"`
	Preference                *uint8                                                                `path:"state/preference" shadow-path:"config/preference" module:"openconfig-network-instance"`
	ΛPreference               []ygot.Annotation                                                     `path:"state/@preference" ygotAnnotation:"true"`
	ProtectionStyleRequested  E_OpenconfigMplsTypes_PROTECTION_TYPE                                 `path:"state/protection-style-requested" shadow-path:"config/protection-style-requested" module:"openconfig-network-instance"`
	ΛProtectionStyleRequested []ygot.Annotation                                                     `path:"state/@protection-style-requested" ygotAnnotation:"true"`
	ReoptimizeTimer           *uint16                                                               `path:"state/reoptimize-timer" shadow-path:"config/reoptimize-timer" module:"openconfig-network-instance"`
	ΛReoptimizeTimer          []ygot.Annotation                                                     `path:"state/@reoptimize-timer" ygotAnnotation:"true"`
	Role                      E_OpenconfigMplsTypes_LSP_ROLE                                        `path:"state/role" module:"openconfig-network-instance"`
	ΛRole                     []ygot.Annotation                                                     `path:"state/@role" ygotAnnotation:"true"`
	SetupPriority             *uint8                                                                `path:"state/setup-priority" shadow-path:"config/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority            []ygot.Annotation                                                     `path:"state/@setup-priority" ygotAnnotation:"true"`
	ShortcutEligible          *bool                                                                 `path:"state/shortcut-eligible" shadow-path:"config/shortcut-eligible" module:"openconfig-network-instance"`
	ΛShortcutEligible         []ygot.Annotation                                                     `path:"state/@shortcut-eligible" ygotAnnotation:"true"`
	SignalingProtocol         E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL                             `path:"state/signaling-protocol" shadow-path:"config/signaling-protocol" module:"openconfig-network-instance"`
	ΛSignalingProtocol        []ygot.Annotation                                                     `path:"state/@signaling-protocol" ygotAnnotation:"true"`
	SoftPreemption            *bool                                                                 `path:"state/soft-preemption" shadow-path:"config/soft-preemption" module:"openconfig-network-instance"`
	ΛSoftPreemption           []ygot.Annotation                                                     `path:"state/@soft-preemption" ygotAnnotation:"true"`
	Source                    *string                                                               `path:"state/source" shadow-path:"config/source" module:"openconfig-network-instance"`
	ΛSource                   []ygot.Annotation                                                     `path:"state/@source" ygotAnnotation:"true"`
	Type                      E_OpenconfigMplsTypes_TUNNEL_TYPE                                     `path:"state/type" shadow-path:"config/type" module:"openconfig-network-instance"`
	ΛType                     []ygot.Annotation                                                     `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) IsYANGGoStruct() {}

// GetOrCreateBandwidth retrieves the value of the Bandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetOrCreateBandwidth() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth {
	if t.Bandwidth != nil {
		return t.Bandwidth
	}
	t.Bandwidth = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth{}
	return t.Bandwidth
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetOrCreateCounters() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters{}
	return t.Counters
}

// GetOrCreateP2PTunnelAttributes retrieves the value of the P2PTunnelAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetOrCreateP2PTunnelAttributes() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes {
	if t.P2PTunnelAttributes != nil {
		return t.P2PTunnelAttributes
	}
	t.P2PTunnelAttributes = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes{}
	return t.P2PTunnelAttributes
}

// GetBandwidth returns the value of the Bandwidth struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel. If the receiver or the field Bandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetBandwidth() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth {
	if t != nil && t.Bandwidth != nil {
		return t.Bandwidth
	}
	return nil
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetCounters() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetP2PTunnelAttributes returns the value of the P2PTunnelAttributes struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel. If the receiver or the field P2PTunnelAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetP2PTunnelAttributes() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes {
	if t != nil && t.P2PTunnelAttributes != nil {
		return t.P2PTunnelAttributes
	}
	return nil
}

// GetAdminStatus retrieves the value of the leaf AdminStatus from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminStatus is set, it can safely use t.GetAdminStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminStatus == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetAdminStatus() E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS {
	if t == nil || t.AdminStatus == 0 {
		return OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_UP
	}
	return t.AdminStatus
}

// GetAutoGenerated retrieves the value of the leaf AutoGenerated from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AutoGenerated is set, it can safely use t.GetAutoGenerated()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AutoGenerated == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetAutoGenerated() bool {
	if t == nil || t.AutoGenerated == nil {
		return false
	}
	return *t.AutoGenerated
}

// GetDescription retrieves the value of the leaf Description from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetHoldPriority retrieves the value of the leaf HoldPriority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldPriority is set, it can safely use t.GetHoldPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetHoldPriority() uint8 {
	if t == nil || t.HoldPriority == nil {
		return 0
	}
	return *t.HoldPriority
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetMetric() int32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetMetricType retrieves the value of the leaf MetricType from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MetricType is set, it can safely use t.GetMetricType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MetricType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetMetricType() E_OpenconfigMplsTypes_LSP_METRIC_TYPE {
	if t == nil || t.MetricType == 0 {
		return OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_INHERITED
	}
	return t.MetricType
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetOperStatus retrieves the value of the leaf OperStatus from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OperStatus is set, it can safely use t.GetOperStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OperStatus == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetOperStatus() E_OpenconfigMplsTypes_LSP_OPER_STATUS {
	if t == nil || t.OperStatus == 0 {
		return 0
	}
	return t.OperStatus
}

// GetPreference retrieves the value of the leaf Preference from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preference is set, it can safely use t.GetPreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetPreference() uint8 {
	if t == nil || t.Preference == nil {
		return 0
	}
	return *t.Preference
}

// GetProtectionStyleRequested retrieves the value of the leaf ProtectionStyleRequested from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ProtectionStyleRequested is set, it can safely use t.GetProtectionStyleRequested()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ProtectionStyleRequested == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetProtectionStyleRequested() E_OpenconfigMplsTypes_PROTECTION_TYPE {
	if t == nil || t.ProtectionStyleRequested == 0 {
		return OpenconfigMplsTypes_PROTECTION_TYPE_UNPROTECTED
	}
	return t.ProtectionStyleRequested
}

// GetReoptimizeTimer retrieves the value of the leaf ReoptimizeTimer from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReoptimizeTimer is set, it can safely use t.GetReoptimizeTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReoptimizeTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetReoptimizeTimer() uint16 {
	if t == nil || t.ReoptimizeTimer == nil {
		return 0
	}
	return *t.ReoptimizeTimer
}

// GetRole retrieves the value of the leaf Role from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Role is set, it can safely use t.GetRole()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Role == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetRole() E_OpenconfigMplsTypes_LSP_ROLE {
	if t == nil || t.Role == 0 {
		return 0
	}
	return t.Role
}

// GetSetupPriority retrieves the value of the leaf SetupPriority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetupPriority is set, it can safely use t.GetSetupPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetupPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetSetupPriority() uint8 {
	if t == nil || t.SetupPriority == nil {
		return 7
	}
	return *t.SetupPriority
}

// GetShortcutEligible retrieves the value of the leaf ShortcutEligible from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ShortcutEligible is set, it can safely use t.GetShortcutEligible()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ShortcutEligible == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetShortcutEligible() bool {
	if t == nil || t.ShortcutEligible == nil {
		return true
	}
	return *t.ShortcutEligible
}

// GetSignalingProtocol retrieves the value of the leaf SignalingProtocol from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SignalingProtocol is set, it can safely use t.GetSignalingProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SignalingProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetSignalingProtocol() E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL {
	if t == nil || t.SignalingProtocol == 0 {
		return 0
	}
	return t.SignalingProtocol
}

// GetSoftPreemption retrieves the value of the leaf SoftPreemption from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SoftPreemption is set, it can safely use t.GetSoftPreemption()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SoftPreemption == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetSoftPreemption() bool {
	if t == nil || t.SoftPreemption == nil {
		return false
	}
	return *t.SoftPreemption
}

// GetSource retrieves the value of the leaf Source from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Source is set, it can safely use t.GetSource()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Source == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetSource() string {
	if t == nil || t.Source == nil {
		return ""
	}
	return *t.Source
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) GetType() E_OpenconfigMplsTypes_TUNNEL_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth struct {
	ΛMetadata          []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	AutoBandwidth      *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth `path:"auto-bandwidth" module:"openconfig-network-instance"`
	ΛAutoBandwidth     []ygot.Annotation                                                         `path:"@auto-bandwidth" ygotAnnotation:"true"`
	SetBandwidth       *uint64                                                                   `path:"state/set-bandwidth" shadow-path:"config/set-bandwidth" module:"openconfig-network-instance"`
	ΛSetBandwidth      []ygot.Annotation                                                         `path:"state/@set-bandwidth" ygotAnnotation:"true"`
	SignaledBandwidth  *uint64                                                                   `path:"state/signaled-bandwidth" module:"openconfig-network-instance"`
	ΛSignaledBandwidth []ygot.Annotation                                                         `path:"state/@signaled-bandwidth" ygotAnnotation:"true"`
	SpecificationType  E_OpenconfigMpls_TeBandwidthType                                          `path:"state/specification-type" shadow-path:"config/specification-type" module:"openconfig-network-instance"`
	ΛSpecificationType []ygot.Annotation                                                         `path:"state/@specification-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) IsYANGGoStruct() {}

// GetOrCreateAutoBandwidth retrieves the value of the AutoBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) GetOrCreateAutoBandwidth() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth {
	if t.AutoBandwidth != nil {
		return t.AutoBandwidth
	}
	t.AutoBandwidth = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth{}
	return t.AutoBandwidth
}

// GetAutoBandwidth returns the value of the AutoBandwidth struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth. If the receiver or the field AutoBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) GetAutoBandwidth() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth {
	if t != nil && t.AutoBandwidth != nil {
		return t.AutoBandwidth
	}
	return nil
}

// GetSetBandwidth retrieves the value of the leaf SetBandwidth from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetBandwidth is set, it can safely use t.GetSetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) GetSetBandwidth() uint64 {
	if t == nil || t.SetBandwidth == nil {
		return 0
	}
	return *t.SetBandwidth
}

// GetSignaledBandwidth retrieves the value of the leaf SignaledBandwidth from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SignaledBandwidth is set, it can safely use t.GetSignaledBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SignaledBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) GetSignaledBandwidth() uint64 {
	if t == nil || t.SignaledBandwidth == nil {
		return 0
	}
	return *t.SignaledBandwidth
}

// GetSpecificationType retrieves the value of the leaf SpecificationType from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpecificationType is set, it can safely use t.GetSpecificationType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpecificationType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) GetSpecificationType() E_OpenconfigMpls_TeBandwidthType {
	if t == nil || t.SpecificationType == 0 {
		return OpenconfigMpls_TeBandwidthType_SPECIFIED
	}
	return t.SpecificationType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth struct {
	ΛMetadata        []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	AdjustInterval   *uint32                                                                             `path:"state/adjust-interval" shadow-path:"config/adjust-interval" module:"openconfig-network-instance"`
	ΛAdjustInterval  []ygot.Annotation                                                                   `path:"state/@adjust-interval" ygotAnnotation:"true"`
	AdjustThreshold  *uint8                                                                              `path:"state/adjust-threshold" shadow-path:"config/adjust-threshold" module:"openconfig-network-instance"`
	ΛAdjustThreshold []ygot.Annotation                                                                   `path:"state/@adjust-threshold" ygotAnnotation:"true"`
	Enabled          *bool                                                                               `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled         []ygot.Annotation                                                                   `path:"state/@enabled" ygotAnnotation:"true"`
	IntervalHighBw   *uint64                                                                             `path:"state/interval-high-bw" module:"openconfig-network-instance"`
	ΛIntervalHighBw  []ygot.Annotation                                                                   `path:"state/@interval-high-bw" ygotAnnotation:"true"`
	MaxBw            *uint64                                                                             `path:"state/max-bw" shadow-path:"config/max-bw" module:"openconfig-network-instance"`
	ΛMaxBw           []ygot.Annotation                                                                   `path:"state/@max-bw" ygotAnnotation:"true"`
	MinBw            *uint64                                                                             `path:"state/min-bw" shadow-path:"config/min-bw" module:"openconfig-network-instance"`
	ΛMinBw           []ygot.Annotation                                                                   `path:"state/@min-bw" ygotAnnotation:"true"`
	Overflow         *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow  `path:"overflow" module:"openconfig-network-instance"`
	ΛOverflow        []ygot.Annotation                                                                   `path:"@overflow" ygotAnnotation:"true"`
	Underflow        *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow `path:"underflow" module:"openconfig-network-instance"`
	ΛUnderflow       []ygot.Annotation                                                                   `path:"@underflow" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) IsYANGGoStruct() {}

// GetOrCreateOverflow retrieves the value of the Overflow field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetOrCreateOverflow() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow {
	if t.Overflow != nil {
		return t.Overflow
	}
	t.Overflow = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow{}
	return t.Overflow
}

// GetOrCreateUnderflow retrieves the value of the Underflow field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetOrCreateUnderflow() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow {
	if t.Underflow != nil {
		return t.Underflow
	}
	t.Underflow = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow{}
	return t.Underflow
}

// GetOverflow returns the value of the Overflow struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth. If the receiver or the field Overflow is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetOverflow() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow {
	if t != nil && t.Overflow != nil {
		return t.Overflow
	}
	return nil
}

// GetUnderflow returns the value of the Underflow struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth. If the receiver or the field Underflow is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetUnderflow() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow {
	if t != nil && t.Underflow != nil {
		return t.Underflow
	}
	return nil
}

// GetAdjustInterval retrieves the value of the leaf AdjustInterval from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjustInterval is set, it can safely use t.GetAdjustInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjustInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetAdjustInterval() uint32 {
	if t == nil || t.AdjustInterval == nil {
		return 0
	}
	return *t.AdjustInterval
}

// GetAdjustThreshold retrieves the value of the leaf AdjustThreshold from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjustThreshold is set, it can safely use t.GetAdjustThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjustThreshold == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetAdjustThreshold() uint8 {
	if t == nil || t.AdjustThreshold == nil {
		return 0
	}
	return *t.AdjustThreshold
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetIntervalHighBw retrieves the value of the leaf IntervalHighBw from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IntervalHighBw is set, it can safely use t.GetIntervalHighBw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IntervalHighBw == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetIntervalHighBw() uint64 {
	if t == nil || t.IntervalHighBw == nil {
		return 0
	}
	return *t.IntervalHighBw
}

// GetMaxBw retrieves the value of the leaf MaxBw from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxBw is set, it can safely use t.GetMaxBw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxBw == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetMaxBw() uint64 {
	if t == nil || t.MaxBw == nil {
		return 0
	}
	return *t.MaxBw
}

// GetMinBw retrieves the value of the leaf MinBw from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinBw is set, it can safely use t.GetMinBw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinBw == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) GetMinBw() uint64 {
	if t == nil || t.MinBw == nil {
		return 0
	}
	return *t.MinBw
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/overflow YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled            *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled           []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	OverflowThreshold  *uint8            `path:"state/overflow-threshold" shadow-path:"config/overflow-threshold" module:"openconfig-network-instance"`
	ΛOverflowThreshold []ygot.Annotation `path:"state/@overflow-threshold" ygotAnnotation:"true"`
	TriggerEventCount  *uint16           `path:"state/trigger-event-count" shadow-path:"config/trigger-event-count" module:"openconfig-network-instance"`
	ΛTriggerEventCount []ygot.Annotation `path:"state/@trigger-event-count" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow) IsYANGGoStruct() {
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetOverflowThreshold retrieves the value of the leaf OverflowThreshold from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OverflowThreshold is set, it can safely use t.GetOverflowThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OverflowThreshold == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow) GetOverflowThreshold() uint8 {
	if t == nil || t.OverflowThreshold == nil {
		return 0
	}
	return *t.OverflowThreshold
}

// GetTriggerEventCount retrieves the value of the leaf TriggerEventCount from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TriggerEventCount is set, it can safely use t.GetTriggerEventCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TriggerEventCount == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow) GetTriggerEventCount() uint16 {
	if t == nil || t.TriggerEventCount == nil {
		return 0
	}
	return *t.TriggerEventCount
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Overflow) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/underflow YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled             *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	TriggerEventCount   *uint16           `path:"state/trigger-event-count" shadow-path:"config/trigger-event-count" module:"openconfig-network-instance"`
	ΛTriggerEventCount  []ygot.Annotation `path:"state/@trigger-event-count" ygotAnnotation:"true"`
	UnderflowThreshold  *uint8            `path:"state/underflow-threshold" shadow-path:"config/underflow-threshold" module:"openconfig-network-instance"`
	ΛUnderflowThreshold []ygot.Annotation `path:"state/@underflow-threshold" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow) IsYANGGoStruct() {
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetTriggerEventCount retrieves the value of the leaf TriggerEventCount from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TriggerEventCount is set, it can safely use t.GetTriggerEventCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TriggerEventCount == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow) GetTriggerEventCount() uint16 {
	if t == nil || t.TriggerEventCount == nil {
		return 0
	}
	return *t.TriggerEventCount
}

// GetUnderflowThreshold retrieves the value of the leaf UnderflowThreshold from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnderflowThreshold is set, it can safely use t.GetUnderflowThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnderflowThreshold == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow) GetUnderflowThreshold() uint8 {
	if t == nil || t.UnderflowThreshold == nil {
		return 0
	}
	return *t.UnderflowThreshold
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Bandwidth_AutoBandwidth_Underflow) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/counters YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters struct {
	ΛMetadata               []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bytes                   *uint64           `path:"bytes" module:"openconfig-network-instance"`
	ΛBytes                  []ygot.Annotation `path:"@bytes" ygotAnnotation:"true"`
	CurrentPathTime         *uint64           `path:"current-path-time" module:"openconfig-network-instance"`
	ΛCurrentPathTime        []ygot.Annotation `path:"@current-path-time" ygotAnnotation:"true"`
	NextReoptimizationTime  *uint64           `path:"next-reoptimization-time" module:"openconfig-network-instance"`
	ΛNextReoptimizationTime []ygot.Annotation `path:"@next-reoptimization-time" ygotAnnotation:"true"`
	OnlineTime              *uint64           `path:"online-time" module:"openconfig-network-instance"`
	ΛOnlineTime             []ygot.Annotation `path:"@online-time" ygotAnnotation:"true"`
	Packets                 *uint64           `path:"packets" module:"openconfig-network-instance"`
	ΛPackets                []ygot.Annotation `path:"@packets" ygotAnnotation:"true"`
	PathChanges             *uint64           `path:"path-changes" module:"openconfig-network-instance"`
	ΛPathChanges            []ygot.Annotation `path:"@path-changes" ygotAnnotation:"true"`
	StateChanges            *uint64           `path:"state-changes" module:"openconfig-network-instance"`
	ΛStateChanges           []ygot.Annotation `path:"@state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) IsYANGGoStruct() {}

// GetBytes retrieves the value of the leaf Bytes from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bytes is set, it can safely use t.GetBytes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bytes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetBytes() uint64 {
	if t == nil || t.Bytes == nil {
		return 0
	}
	return *t.Bytes
}

// GetCurrentPathTime retrieves the value of the leaf CurrentPathTime from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CurrentPathTime is set, it can safely use t.GetCurrentPathTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CurrentPathTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetCurrentPathTime() uint64 {
	if t == nil || t.CurrentPathTime == nil {
		return 0
	}
	return *t.CurrentPathTime
}

// GetNextReoptimizationTime retrieves the value of the leaf NextReoptimizationTime from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextReoptimizationTime is set, it can safely use t.GetNextReoptimizationTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextReoptimizationTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetNextReoptimizationTime() uint64 {
	if t == nil || t.NextReoptimizationTime == nil {
		return 0
	}
	return *t.NextReoptimizationTime
}

// GetOnlineTime retrieves the value of the leaf OnlineTime from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OnlineTime is set, it can safely use t.GetOnlineTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OnlineTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetOnlineTime() uint64 {
	if t == nil || t.OnlineTime == nil {
		return 0
	}
	return *t.OnlineTime
}

// GetPackets retrieves the value of the leaf Packets from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Packets is set, it can safely use t.GetPackets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Packets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetPackets() uint64 {
	if t == nil || t.Packets == nil {
		return 0
	}
	return *t.Packets
}

// GetPathChanges retrieves the value of the leaf PathChanges from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathChanges is set, it can safely use t.GetPathChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetPathChanges() uint64 {
	if t == nil || t.PathChanges == nil {
		return 0
	}
	return *t.PathChanges
}

// GetStateChanges retrieves the value of the leaf StateChanges from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StateChanges is set, it can safely use t.GetStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StateChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) GetStateChanges() uint64 {
	if t == nil || t.StateChanges == nil {
		return 0
	}
	return *t.StateChanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes struct {
	ΛMetadata         []ygot.Annotation                                                                                 `path:"@" ygotAnnotation:"true"`
	Destination       *string                                                                                           `path:"state/destination" shadow-path:"config/destination" module:"openconfig-network-instance"`
	ΛDestination      []ygot.Annotation                                                                                 `path:"state/@destination" ygotAnnotation:"true"`
	P2PPrimaryPath    map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath   `path:"p2p-primary-path/p2p-primary-path" module:"openconfig-network-instance"`
	ΛP2PPrimaryPath   []ygot.Annotation                                                                                 `path:"p2p-primary-path/@p2p-primary-path" ygotAnnotation:"true"`
	P2PSecondaryPath  map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath `path:"p2p-secondary-paths/p2p-secondary-path" module:"openconfig-network-instance"`
	ΛP2PSecondaryPath []ygot.Annotation                                                                                 `path:"p2p-secondary-paths/@p2p-secondary-path" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) IsYANGGoStruct() {}

// NewP2PPrimaryPath creates a new entry in the P2PPrimaryPath list of the
// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) NewP2PPrimaryPath(Name string) (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.P2PPrimaryPath == nil {
		t.P2PPrimaryPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.P2PPrimaryPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list P2PPrimaryPath", key)
	}

	t.P2PPrimaryPath[key] = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath{
		Name: &Name,
	}

	return t.P2PPrimaryPath[key], nil
}

// RenameP2PPrimaryPath renames an entry in the list P2PPrimaryPath within
// the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) RenameP2PPrimaryPath(oldK, newK string) error {
	if _, ok := t.P2PPrimaryPath[newK]; ok {
		return fmt.Errorf("key %v already exists in P2PPrimaryPath", newK)
	}

	e, ok := t.P2PPrimaryPath[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in P2PPrimaryPath", oldK)
	}
	e.Name = &newK

	t.P2PPrimaryPath[newK] = e
	delete(t.P2PPrimaryPath, oldK)
	return nil
}

// GetOrCreateP2PPrimaryPath retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) GetOrCreateP2PPrimaryPath(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath {

	key := Name

	if v, ok := t.P2PPrimaryPath[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewP2PPrimaryPath(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateP2PPrimaryPath got unexpected error: %v", err))
	}
	return v
}

// GetP2PPrimaryPath retrieves the value with the specified key from
// the P2PPrimaryPath map field of NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) GetP2PPrimaryPath(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.P2PPrimaryPath[key]; ok {
		return lm
	}
	return nil
}

// AppendP2PPrimaryPath appends the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct to the
// list P2PPrimaryPath of NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) AppendP2PPrimaryPath(v *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.P2PPrimaryPath == nil {
		t.P2PPrimaryPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath)
	}

	if _, ok := t.P2PPrimaryPath[key]; ok {
		return fmt.Errorf("duplicate key for list P2PPrimaryPath %v", key)
	}

	t.P2PPrimaryPath[key] = v
	return nil
}

// NewP2PSecondaryPath creates a new entry in the P2PSecondaryPath list of the
// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) NewP2PSecondaryPath(Name string) (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.P2PSecondaryPath == nil {
		t.P2PSecondaryPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.P2PSecondaryPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list P2PSecondaryPath", key)
	}

	t.P2PSecondaryPath[key] = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath{
		Name: &Name,
	}

	return t.P2PSecondaryPath[key], nil
}

// RenameP2PSecondaryPath renames an entry in the list P2PSecondaryPath within
// the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) RenameP2PSecondaryPath(oldK, newK string) error {
	if _, ok := t.P2PSecondaryPath[newK]; ok {
		return fmt.Errorf("key %v already exists in P2PSecondaryPath", newK)
	}

	e, ok := t.P2PSecondaryPath[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in P2PSecondaryPath", oldK)
	}
	e.Name = &newK

	t.P2PSecondaryPath[newK] = e
	delete(t.P2PSecondaryPath, oldK)
	return nil
}

// GetOrCreateP2PSecondaryPath retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) GetOrCreateP2PSecondaryPath(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath {

	key := Name

	if v, ok := t.P2PSecondaryPath[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewP2PSecondaryPath(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateP2PSecondaryPath got unexpected error: %v", err))
	}
	return v
}

// GetP2PSecondaryPath retrieves the value with the specified key from
// the P2PSecondaryPath map field of NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) GetP2PSecondaryPath(Name string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.P2PSecondaryPath[key]; ok {
		return lm
	}
	return nil
}

// AppendP2PSecondaryPath appends the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath struct to the
// list P2PSecondaryPath of NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) AppendP2PSecondaryPath(v *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.P2PSecondaryPath == nil {
		t.P2PSecondaryPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath)
	}

	if _, ok := t.P2PSecondaryPath[key]; ok {
		return fmt.Errorf("duplicate key for list P2PSecondaryPath %v", key)
	}

	t.P2PSecondaryPath[key] = v
	return nil
}

// GetDestination retrieves the value of the leaf Destination from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Destination is set, it can safely use t.GetDestination()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Destination == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) GetDestination() string {
	if t == nil || t.Destination == nil {
		return ""
	}
	return *t.Destination
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct {
	ΛMetadata               []ygot.Annotation                                                                                                      `path:"@" ygotAnnotation:"true"`
	AdminGroups             *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups                       `path:"admin-groups" module:"openconfig-network-instance"`
	ΛAdminGroups            []ygot.Annotation                                                                                                      `path:"@admin-groups" ygotAnnotation:"true"`
	AssociatedRsvpSessions  []uint64                                                                                                               `path:"state/associated-rsvp-sessions" module:"openconfig-network-instance"`
	ΛAssociatedRsvpSessions []ygot.Annotation                                                                                                      `path:"state/@associated-rsvp-sessions" ygotAnnotation:"true"`
	CandidateSecondaryPath  map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath `path:"candidate-secondary-paths/candidate-secondary-path" module:"openconfig-network-instance"`
	ΛCandidateSecondaryPath []ygot.Annotation                                                                                                      `path:"candidate-secondary-paths/@candidate-secondary-path" ygotAnnotation:"true"`
	CspfMetric              *uint64                                                                                                                `path:"state/cspf-metric" module:"openconfig-network-instance"`
	ΛCspfMetric             []ygot.Annotation                                                                                                      `path:"state/@cspf-metric" ygotAnnotation:"true"`
	CspfTiebreaker          E_OpenconfigMpls_CspfTieBreaking                                                                                       `path:"state/cspf-tiebreaker" shadow-path:"config/cspf-tiebreaker" module:"openconfig-network-instance"`
	ΛCspfTiebreaker         []ygot.Annotation                                                                                                      `path:"state/@cspf-tiebreaker" ygotAnnotation:"true"`
	ExplicitPathName        *string                                                                                                                `path:"state/explicit-path-name" shadow-path:"config/explicit-path-name" module:"openconfig-network-instance"`
	ΛExplicitPathName       []ygot.Annotation                                                                                                      `path:"state/@explicit-path-name" ygotAnnotation:"true"`
	HoldPriority            *uint8                                                                                                                 `path:"state/hold-priority" shadow-path:"config/hold-priority" module:"openconfig-network-instance"`
	ΛHoldPriority           []ygot.Annotation                                                                                                      `path:"state/@hold-priority" ygotAnnotation:"true"`
	Name                    *string                                                                                                                `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName                   []ygot.Annotation                                                                                                      `path:"state/@name|@name" ygotAnnotation:"true"`
	PathComputationMethod   E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD                                                                          `path:"state/path-computation-method" shadow-path:"config/path-computation-method" module:"openconfig-network-instance"`
	ΛPathComputationMethod  []ygot.Annotation                                                                                                      `path:"state/@path-computation-method" ygotAnnotation:"true"`
	PathComputationServer   *string                                                                                                                `path:"state/path-computation-server" shadow-path:"config/path-computation-server" module:"openconfig-network-instance"`
	ΛPathComputationServer  []ygot.Annotation                                                                                                      `path:"state/@path-computation-server" ygotAnnotation:"true"`
	Preference              *uint8                                                                                                                 `path:"state/preference" shadow-path:"config/preference" module:"openconfig-network-instance"`
	ΛPreference             []ygot.Annotation                                                                                                      `path:"state/@preference" ygotAnnotation:"true"`
	RetryTimer              *uint16                                                                                                                `path:"state/retry-timer" shadow-path:"config/retry-timer" module:"openconfig-network-instance"`
	ΛRetryTimer             []ygot.Annotation                                                                                                      `path:"state/@retry-timer" ygotAnnotation:"true"`
	SetupPriority           *uint8                                                                                                                 `path:"state/setup-priority" shadow-path:"config/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority          []ygot.Annotation                                                                                                      `path:"state/@setup-priority" ygotAnnotation:"true"`
	SpfMetric               *uint64                                                                                                                `path:"state/spf-metric" module:"openconfig-network-instance"`
	ΛSpfMetric              []ygot.Annotation                                                                                                      `path:"state/@spf-metric" ygotAnnotation:"true"`
	UseCspf                 *bool                                                                                                                  `path:"state/use-cspf" shadow-path:"config/use-cspf" module:"openconfig-network-instance"`
	ΛUseCspf                []ygot.Annotation                                                                                                      `path:"state/@use-cspf" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) IsYANGGoStruct() {
}

// NewCandidateSecondaryPath creates a new entry in the CandidateSecondaryPath list of the
// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) NewCandidateSecondaryPath(SecondaryPath string) (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.CandidateSecondaryPath == nil {
		t.CandidateSecondaryPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath)
	}

	key := SecondaryPath

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.CandidateSecondaryPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list CandidateSecondaryPath", key)
	}

	t.CandidateSecondaryPath[key] = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath{
		SecondaryPath: &SecondaryPath,
	}

	return t.CandidateSecondaryPath[key], nil
}

// RenameCandidateSecondaryPath renames an entry in the list CandidateSecondaryPath within
// the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) RenameCandidateSecondaryPath(oldK, newK string) error {
	if _, ok := t.CandidateSecondaryPath[newK]; ok {
		return fmt.Errorf("key %v already exists in CandidateSecondaryPath", newK)
	}

	e, ok := t.CandidateSecondaryPath[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in CandidateSecondaryPath", oldK)
	}
	e.SecondaryPath = &newK

	t.CandidateSecondaryPath[newK] = e
	delete(t.CandidateSecondaryPath, oldK)
	return nil
}

// GetOrCreateCandidateSecondaryPath retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetOrCreateCandidateSecondaryPath(SecondaryPath string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath {

	key := SecondaryPath

	if v, ok := t.CandidateSecondaryPath[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCandidateSecondaryPath(SecondaryPath)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCandidateSecondaryPath got unexpected error: %v", err))
	}
	return v
}

// GetCandidateSecondaryPath retrieves the value with the specified key from
// the CandidateSecondaryPath map field of NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetCandidateSecondaryPath(SecondaryPath string) *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath {

	if t == nil {
		return nil
	}

	key := SecondaryPath

	if lm, ok := t.CandidateSecondaryPath[key]; ok {
		return lm
	}
	return nil
}

// AppendCandidateSecondaryPath appends the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath struct to the
// list CandidateSecondaryPath of NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) AppendCandidateSecondaryPath(v *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) error {
	if v.SecondaryPath == nil {
		return fmt.Errorf("invalid nil key received for SecondaryPath")
	}

	key := *v.SecondaryPath

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.CandidateSecondaryPath == nil {
		t.CandidateSecondaryPath = make(map[string]*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath)
	}

	if _, ok := t.CandidateSecondaryPath[key]; ok {
		return fmt.Errorf("duplicate key for list CandidateSecondaryPath %v", key)
	}

	t.CandidateSecondaryPath[key] = v
	return nil
}

// GetOrCreateAdminGroups retrieves the value of the AdminGroups field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetOrCreateAdminGroups() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups {
	if t.AdminGroups != nil {
		return t.AdminGroups
	}
	t.AdminGroups = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups{}
	return t.AdminGroups
}

// GetAdminGroups returns the value of the AdminGroups struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath. If the receiver or the field AdminGroups is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetAdminGroups() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups {
	if t != nil && t.AdminGroups != nil {
		return t.AdminGroups
	}
	return nil
}

// GetAssociatedRsvpSessions retrieves the value of the leaf AssociatedRsvpSessions from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AssociatedRsvpSessions is set, it can safely use t.GetAssociatedRsvpSessions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AssociatedRsvpSessions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetAssociatedRsvpSessions() []uint64 {
	if t == nil || t.AssociatedRsvpSessions == nil {
		return nil
	}
	return t.AssociatedRsvpSessions
}

// GetCspfMetric retrieves the value of the leaf CspfMetric from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CspfMetric is set, it can safely use t.GetCspfMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CspfMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetCspfMetric() uint64 {
	if t == nil || t.CspfMetric == nil {
		return 0
	}
	return *t.CspfMetric
}

// GetCspfTiebreaker retrieves the value of the leaf CspfTiebreaker from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CspfTiebreaker is set, it can safely use t.GetCspfTiebreaker()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CspfTiebreaker == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetCspfTiebreaker() E_OpenconfigMpls_CspfTieBreaking {
	if t == nil || t.CspfTiebreaker == 0 {
		return OpenconfigMpls_CspfTieBreaking_RANDOM
	}
	return t.CspfTiebreaker
}

// GetExplicitPathName retrieves the value of the leaf ExplicitPathName from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExplicitPathName is set, it can safely use t.GetExplicitPathName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExplicitPathName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetExplicitPathName() string {
	if t == nil || t.ExplicitPathName == nil {
		return ""
	}
	return *t.ExplicitPathName
}

// GetHoldPriority retrieves the value of the leaf HoldPriority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldPriority is set, it can safely use t.GetHoldPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetHoldPriority() uint8 {
	if t == nil || t.HoldPriority == nil {
		return 0
	}
	return *t.HoldPriority
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPathComputationMethod retrieves the value of the leaf PathComputationMethod from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathComputationMethod is set, it can safely use t.GetPathComputationMethod()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathComputationMethod == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetPathComputationMethod() E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD {
	if t == nil || t.PathComputationMethod == 0 {
		return OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_LOCALLY_COMPUTED
	}
	return t.PathComputationMethod
}

// GetPathComputationServer retrieves the value of the leaf PathComputationServer from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathComputationServer is set, it can safely use t.GetPathComputationServer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathComputationServer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetPathComputationServer() string {
	if t == nil || t.PathComputationServer == nil {
		return ""
	}
	return *t.PathComputationServer
}

// GetPreference retrieves the value of the leaf Preference from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preference is set, it can safely use t.GetPreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetPreference() uint8 {
	if t == nil || t.Preference == nil {
		return 0
	}
	return *t.Preference
}

// GetRetryTimer retrieves the value of the leaf RetryTimer from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetryTimer is set, it can safely use t.GetRetryTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetryTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetRetryTimer() uint16 {
	if t == nil || t.RetryTimer == nil {
		return 0
	}
	return *t.RetryTimer
}

// GetSetupPriority retrieves the value of the leaf SetupPriority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetupPriority is set, it can safely use t.GetSetupPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetupPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetSetupPriority() uint8 {
	if t == nil || t.SetupPriority == nil {
		return 7
	}
	return *t.SetupPriority
}

// GetSpfMetric retrieves the value of the leaf SpfMetric from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpfMetric is set, it can safely use t.GetSpfMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpfMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetSpfMetric() uint64 {
	if t == nil || t.SpfMetric == nil {
		return 0
	}
	return *t.SpfMetric
}

// GetUseCspf retrieves the value of the leaf UseCspf from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UseCspf is set, it can safely use t.GetUseCspf()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UseCspf == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) GetUseCspf() bool {
	if t == nil || t.UseCspf == nil {
		return false
	}
	return *t.UseCspf
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/admin-groups YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExcludeGroup     []string          `path:"state/exclude-group" shadow-path:"config/exclude-group" module:"openconfig-network-instance"`
	ΛExcludeGroup    []ygot.Annotation `path:"state/@exclude-group" ygotAnnotation:"true"`
	IncludeAllGroup  []string          `path:"state/include-all-group" shadow-path:"config/include-all-group" module:"openconfig-network-instance"`
	ΛIncludeAllGroup []ygot.Annotation `path:"state/@include-all-group" ygotAnnotation:"true"`
	IncludeAnyGroup  []string          `path:"state/include-any-group" shadow-path:"config/include-any-group" module:"openconfig-network-instance"`
	ΛIncludeAnyGroup []ygot.Annotation `path:"state/@include-any-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups) IsYANGGoStruct() {
}

// GetExcludeGroup retrieves the value of the leaf ExcludeGroup from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExcludeGroup is set, it can safely use t.GetExcludeGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExcludeGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups) GetExcludeGroup() []string {
	if t == nil || t.ExcludeGroup == nil {
		return nil
	}
	return t.ExcludeGroup
}

// GetIncludeAllGroup retrieves the value of the leaf IncludeAllGroup from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncludeAllGroup is set, it can safely use t.GetIncludeAllGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncludeAllGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups) GetIncludeAllGroup() []string {
	if t == nil || t.IncludeAllGroup == nil {
		return nil
	}
	return t.IncludeAllGroup
}

// GetIncludeAnyGroup retrieves the value of the leaf IncludeAnyGroup from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncludeAnyGroup is set, it can safely use t.GetIncludeAnyGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncludeAnyGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups) GetIncludeAnyGroup() []string {
	if t == nil || t.IncludeAnyGroup == nil {
		return nil
	}
	return t.IncludeAnyGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_AdminGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/candidate-secondary-paths/candidate-secondary-path YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Active         *bool             `path:"state/active" module:"openconfig-network-instance"`
	ΛActive        []ygot.Annotation `path:"state/@active" ygotAnnotation:"true"`
	Priority       *uint16           `path:"state/priority" shadow-path:"config/priority" module:"openconfig-network-instance"`
	ΛPriority      []ygot.Annotation `path:"state/@priority" ygotAnnotation:"true"`
	SecondaryPath  *string           `path:"state/secondary-path|secondary-path" shadow-path:"config/secondary-path" module:"openconfig-network-instance"`
	ΛSecondaryPath []ygot.Annotation `path:"state/@secondary-path|@secondary-path" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) IsYANGGoStruct() {
}

// GetActive retrieves the value of the leaf Active from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) GetPriority() uint16 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetSecondaryPath retrieves the value of the leaf SecondaryPath from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SecondaryPath is set, it can safely use t.GetSecondaryPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SecondaryPath == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) GetSecondaryPath() string {
	if t == nil || t.SecondaryPath == nil {
		return ""
	}
	return *t.SecondaryPath
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SecondaryPath == nil {
		return nil, fmt.Errorf("nil value for key SecondaryPath")
	}

	return map[string]interface{}{
		"secondary-path": *t.SecondaryPath,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_CandidateSecondaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath struct {
	ΛMetadata               []ygot.Annotation                                                                                  `path:"@" ygotAnnotation:"true"`
	AdminGroups             *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups `path:"admin-groups" module:"openconfig-network-instance"`
	ΛAdminGroups            []ygot.Annotation                                                                                  `path:"@admin-groups" ygotAnnotation:"true"`
	AssociatedRsvpSessions  []uint64                                                                                           `path:"state/associated-rsvp-sessions" module:"openconfig-network-instance"`
	ΛAssociatedRsvpSessions []ygot.Annotation                                                                                  `path:"state/@associated-rsvp-sessions" ygotAnnotation:"true"`
	CspfMetric              *uint64                                                                                            `path:"state/cspf-metric" module:"openconfig-network-instance"`
	ΛCspfMetric             []ygot.Annotation                                                                                  `path:"state/@cspf-metric" ygotAnnotation:"true"`
	CspfTiebreaker          E_OpenconfigMpls_CspfTieBreaking                                                                   `path:"state/cspf-tiebreaker" shadow-path:"config/cspf-tiebreaker" module:"openconfig-network-instance"`
	ΛCspfTiebreaker         []ygot.Annotation                                                                                  `path:"state/@cspf-tiebreaker" ygotAnnotation:"true"`
	ExplicitPathName        *string                                                                                            `path:"state/explicit-path-name" shadow-path:"config/explicit-path-name" module:"openconfig-network-instance"`
	ΛExplicitPathName       []ygot.Annotation                                                                                  `path:"state/@explicit-path-name" ygotAnnotation:"true"`
	HoldPriority            *uint8                                                                                             `path:"state/hold-priority" shadow-path:"config/hold-priority" module:"openconfig-network-instance"`
	ΛHoldPriority           []ygot.Annotation                                                                                  `path:"state/@hold-priority" ygotAnnotation:"true"`
	Name                    *string                                                                                            `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName                   []ygot.Annotation                                                                                  `path:"state/@name|@name" ygotAnnotation:"true"`
	PathComputationMethod   E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD                                                      `path:"state/path-computation-method" shadow-path:"config/path-computation-method" module:"openconfig-network-instance"`
	ΛPathComputationMethod  []ygot.Annotation                                                                                  `path:"state/@path-computation-method" ygotAnnotation:"true"`
	PathComputationServer   *string                                                                                            `path:"state/path-computation-server" shadow-path:"config/path-computation-server" module:"openconfig-network-instance"`
	ΛPathComputationServer  []ygot.Annotation                                                                                  `path:"state/@path-computation-server" ygotAnnotation:"true"`
	Preference              *uint8                                                                                             `path:"state/preference" shadow-path:"config/preference" module:"openconfig-network-instance"`
	ΛPreference             []ygot.Annotation                                                                                  `path:"state/@preference" ygotAnnotation:"true"`
	RetryTimer              *uint16                                                                                            `path:"state/retry-timer" shadow-path:"config/retry-timer" module:"openconfig-network-instance"`
	ΛRetryTimer             []ygot.Annotation                                                                                  `path:"state/@retry-timer" ygotAnnotation:"true"`
	SetupPriority           *uint8                                                                                             `path:"state/setup-priority" shadow-path:"config/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority          []ygot.Annotation                                                                                  `path:"state/@setup-priority" ygotAnnotation:"true"`
	SpfMetric               *uint64                                                                                            `path:"state/spf-metric" module:"openconfig-network-instance"`
	ΛSpfMetric              []ygot.Annotation                                                                                  `path:"state/@spf-metric" ygotAnnotation:"true"`
	UseCspf                 *bool                                                                                              `path:"state/use-cspf" shadow-path:"config/use-cspf" module:"openconfig-network-instance"`
	ΛUseCspf                []ygot.Annotation                                                                                  `path:"state/@use-cspf" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) IsYANGGoStruct() {
}

// GetOrCreateAdminGroups retrieves the value of the AdminGroups field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetOrCreateAdminGroups() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups {
	if t.AdminGroups != nil {
		return t.AdminGroups
	}
	t.AdminGroups = &NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups{}
	return t.AdminGroups
}

// GetAdminGroups returns the value of the AdminGroups struct pointer
// from NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath. If the receiver or the field AdminGroups is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetAdminGroups() *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups {
	if t != nil && t.AdminGroups != nil {
		return t.AdminGroups
	}
	return nil
}

// GetAssociatedRsvpSessions retrieves the value of the leaf AssociatedRsvpSessions from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AssociatedRsvpSessions is set, it can safely use t.GetAssociatedRsvpSessions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AssociatedRsvpSessions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetAssociatedRsvpSessions() []uint64 {
	if t == nil || t.AssociatedRsvpSessions == nil {
		return nil
	}
	return t.AssociatedRsvpSessions
}

// GetCspfMetric retrieves the value of the leaf CspfMetric from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CspfMetric is set, it can safely use t.GetCspfMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CspfMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetCspfMetric() uint64 {
	if t == nil || t.CspfMetric == nil {
		return 0
	}
	return *t.CspfMetric
}

// GetCspfTiebreaker retrieves the value of the leaf CspfTiebreaker from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CspfTiebreaker is set, it can safely use t.GetCspfTiebreaker()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CspfTiebreaker == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetCspfTiebreaker() E_OpenconfigMpls_CspfTieBreaking {
	if t == nil || t.CspfTiebreaker == 0 {
		return OpenconfigMpls_CspfTieBreaking_RANDOM
	}
	return t.CspfTiebreaker
}

// GetExplicitPathName retrieves the value of the leaf ExplicitPathName from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExplicitPathName is set, it can safely use t.GetExplicitPathName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExplicitPathName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetExplicitPathName() string {
	if t == nil || t.ExplicitPathName == nil {
		return ""
	}
	return *t.ExplicitPathName
}

// GetHoldPriority retrieves the value of the leaf HoldPriority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldPriority is set, it can safely use t.GetHoldPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetHoldPriority() uint8 {
	if t == nil || t.HoldPriority == nil {
		return 0
	}
	return *t.HoldPriority
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPathComputationMethod retrieves the value of the leaf PathComputationMethod from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathComputationMethod is set, it can safely use t.GetPathComputationMethod()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathComputationMethod == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetPathComputationMethod() E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD {
	if t == nil || t.PathComputationMethod == 0 {
		return OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_LOCALLY_COMPUTED
	}
	return t.PathComputationMethod
}

// GetPathComputationServer retrieves the value of the leaf PathComputationServer from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathComputationServer is set, it can safely use t.GetPathComputationServer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathComputationServer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetPathComputationServer() string {
	if t == nil || t.PathComputationServer == nil {
		return ""
	}
	return *t.PathComputationServer
}

// GetPreference retrieves the value of the leaf Preference from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preference is set, it can safely use t.GetPreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetPreference() uint8 {
	if t == nil || t.Preference == nil {
		return 0
	}
	return *t.Preference
}

// GetRetryTimer retrieves the value of the leaf RetryTimer from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetryTimer is set, it can safely use t.GetRetryTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetryTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetRetryTimer() uint16 {
	if t == nil || t.RetryTimer == nil {
		return 0
	}
	return *t.RetryTimer
}

// GetSetupPriority retrieves the value of the leaf SetupPriority from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetupPriority is set, it can safely use t.GetSetupPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetupPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetSetupPriority() uint8 {
	if t == nil || t.SetupPriority == nil {
		return 7
	}
	return *t.SetupPriority
}

// GetSpfMetric retrieves the value of the leaf SpfMetric from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpfMetric is set, it can safely use t.GetSpfMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpfMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetSpfMetric() uint64 {
	if t == nil || t.SpfMetric == nil {
		return 0
	}
	return *t.SpfMetric
}

// GetUseCspf retrieves the value of the leaf UseCspf from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UseCspf is set, it can safely use t.GetUseCspf()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UseCspf == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) GetUseCspf() bool {
	if t == nil || t.UseCspf == nil {
		return false
	}
	return *t.UseCspf
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/admin-groups YANG schema element.
type NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExcludeGroup     []string          `path:"state/exclude-group" shadow-path:"config/exclude-group" module:"openconfig-network-instance"`
	ΛExcludeGroup    []ygot.Annotation `path:"state/@exclude-group" ygotAnnotation:"true"`
	IncludeAllGroup  []string          `path:"state/include-all-group" shadow-path:"config/include-all-group" module:"openconfig-network-instance"`
	ΛIncludeAllGroup []ygot.Annotation `path:"state/@include-all-group" ygotAnnotation:"true"`
	IncludeAnyGroup  []string          `path:"state/include-any-group" shadow-path:"config/include-any-group" module:"openconfig-network-instance"`
	ΛIncludeAnyGroup []ygot.Annotation `path:"state/@include-any-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups) IsYANGGoStruct() {
}

// GetExcludeGroup retrieves the value of the leaf ExcludeGroup from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExcludeGroup is set, it can safely use t.GetExcludeGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExcludeGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups) GetExcludeGroup() []string {
	if t == nil || t.ExcludeGroup == nil {
		return nil
	}
	return t.ExcludeGroup
}

// GetIncludeAllGroup retrieves the value of the leaf IncludeAllGroup from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncludeAllGroup is set, it can safely use t.GetIncludeAllGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncludeAllGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups) GetIncludeAllGroup() []string {
	if t == nil || t.IncludeAllGroup == nil {
		return nil
	}
	return t.IncludeAllGroup
}

// GetIncludeAnyGroup retrieves the value of the leaf IncludeAnyGroup from the NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncludeAnyGroup is set, it can safely use t.GetIncludeAnyGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncludeAnyGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups) GetIncludeAnyGroup() []string {
	if t == nil || t.IncludeAnyGroup == nil {
		return nil
	}
	return t.IncludeAnyGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnel_P2PTunnelAttributes_P2PSecondaryPath_AdminGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_StaticLsp represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp YANG schema element.
type NetworkInstance_Mpls_Lsps_StaticLsp struct {
	ΛMetadata []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	Egress    *NetworkInstance_Mpls_Lsps_StaticLsp_Egress  `path:"egress" module:"openconfig-network-instance"`
	ΛEgress   []ygot.Annotation                            `path:"@egress" ygotAnnotation:"true"`
	Ingress   *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress `path:"ingress" module:"openconfig-network-instance"`
	ΛIngress  []ygot.Annotation                            `path:"@ingress" ygotAnnotation:"true"`
	Name      *string                                      `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName     []ygot.Annotation                            `path:"state/@name|@name" ygotAnnotation:"true"`
	Transit   *NetworkInstance_Mpls_Lsps_StaticLsp_Transit `path:"transit" module:"openconfig-network-instance"`
	ΛTransit  []ygot.Annotation                            `path:"@transit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_StaticLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_StaticLsp) IsYANGGoStruct() {}

// GetOrCreateEgress retrieves the value of the Egress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetOrCreateEgress() *NetworkInstance_Mpls_Lsps_StaticLsp_Egress {
	if t.Egress != nil {
		return t.Egress
	}
	t.Egress = &NetworkInstance_Mpls_Lsps_StaticLsp_Egress{}
	return t.Egress
}

// GetOrCreateIngress retrieves the value of the Ingress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetOrCreateIngress() *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress {
	if t.Ingress != nil {
		return t.Ingress
	}
	t.Ingress = &NetworkInstance_Mpls_Lsps_StaticLsp_Ingress{}
	return t.Ingress
}

// GetOrCreateTransit retrieves the value of the Transit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetOrCreateTransit() *NetworkInstance_Mpls_Lsps_StaticLsp_Transit {
	if t.Transit != nil {
		return t.Transit
	}
	t.Transit = &NetworkInstance_Mpls_Lsps_StaticLsp_Transit{}
	return t.Transit
}

// GetEgress returns the value of the Egress struct pointer
// from NetworkInstance_Mpls_Lsps_StaticLsp. If the receiver or the field Egress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetEgress() *NetworkInstance_Mpls_Lsps_StaticLsp_Egress {
	if t != nil && t.Egress != nil {
		return t.Egress
	}
	return nil
}

// GetIngress returns the value of the Ingress struct pointer
// from NetworkInstance_Mpls_Lsps_StaticLsp. If the receiver or the field Ingress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetIngress() *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress {
	if t != nil && t.Ingress != nil {
		return t.Ingress
	}
	return nil
}

// GetTransit returns the value of the Transit struct pointer
// from NetworkInstance_Mpls_Lsps_StaticLsp. If the receiver or the field Transit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetTransit() *NetworkInstance_Mpls_Lsps_StaticLsp_Transit {
	if t != nil && t.Transit != nil {
		return t.Transit
	}
	return nil
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Mpls_Lsps_StaticLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_Lsps_StaticLsp struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_StaticLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Egress represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress YANG schema element.
type NetworkInstance_Mpls_Lsps_StaticLsp_Egress struct {
	ΛMetadata      []ygot.Annotation                                              `path:"@" ygotAnnotation:"true"`
	IncomingLabel  NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union `path:"state/incoming-label" shadow-path:"config/incoming-label" module:"openconfig-network-instance"`
	ΛIncomingLabel []ygot.Annotation                                              `path:"state/@incoming-label" ygotAnnotation:"true"`
	NextHop        *string                                                        `path:"state/next-hop" shadow-path:"config/next-hop" module:"openconfig-network-instance"`
	ΛNextHop       []ygot.Annotation                                              `path:"state/@next-hop" ygotAnnotation:"true"`
	PushLabel      NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union     `path:"state/push-label" shadow-path:"config/push-label" module:"openconfig-network-instance"`
	ΛPushLabel     []ygot.Annotation                                              `path:"state/@push-label" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_StaticLsp_Egress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_StaticLsp_Egress) IsYANGGoStruct() {}

// GetIncomingLabel retrieves the value of the leaf IncomingLabel from the NetworkInstance_Mpls_Lsps_StaticLsp_Egress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncomingLabel is set, it can safely use t.GetIncomingLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncomingLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) GetIncomingLabel() NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union {
	if t == nil || t.IncomingLabel == nil {
		return nil
	}
	return t.IncomingLabel
}

// GetNextHop retrieves the value of the leaf NextHop from the NetworkInstance_Mpls_Lsps_StaticLsp_Egress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) GetNextHop() string {
	if t == nil || t.NextHop == nil {
		return ""
	}
	return *t.NextHop
}

// GetPushLabel retrieves the value of the leaf PushLabel from the NetworkInstance_Mpls_Lsps_StaticLsp_Egress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PushLabel is set, it can safely use t.GetPushLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PushLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) GetPushLabel() NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union {
	if t == nil || t.PushLabel == nil {
		return nil
	}
	return t.PushLabel
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_StaticLsp_Egress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/incoming-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union() {
}

// To_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) To_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union(i interface{}) (NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Lsps_StaticLsp_Egress_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/push-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union() {}

// To_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Egress) To_NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union(i interface{}) (NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Lsps_StaticLsp_Egress_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Ingress represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress YANG schema element.
type NetworkInstance_Mpls_Lsps_StaticLsp_Ingress struct {
	ΛMetadata      []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	IncomingLabel  NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union `path:"state/incoming-label" shadow-path:"config/incoming-label" module:"openconfig-network-instance"`
	ΛIncomingLabel []ygot.Annotation                                               `path:"state/@incoming-label" ygotAnnotation:"true"`
	NextHop        *string                                                         `path:"state/next-hop" shadow-path:"config/next-hop" module:"openconfig-network-instance"`
	ΛNextHop       []ygot.Annotation                                               `path:"state/@next-hop" ygotAnnotation:"true"`
	PushLabel      NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union     `path:"state/push-label" shadow-path:"config/push-label" module:"openconfig-network-instance"`
	ΛPushLabel     []ygot.Annotation                                               `path:"state/@push-label" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_StaticLsp_Ingress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) IsYANGGoStruct() {}

// GetIncomingLabel retrieves the value of the leaf IncomingLabel from the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncomingLabel is set, it can safely use t.GetIncomingLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncomingLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) GetIncomingLabel() NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union {
	if t == nil || t.IncomingLabel == nil {
		return nil
	}
	return t.IncomingLabel
}

// GetNextHop retrieves the value of the leaf NextHop from the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) GetNextHop() string {
	if t == nil || t.NextHop == nil {
		return ""
	}
	return *t.NextHop
}

// GetPushLabel retrieves the value of the leaf PushLabel from the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PushLabel is set, it can safely use t.GetPushLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PushLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) GetPushLabel() NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union {
	if t == nil || t.PushLabel == nil {
		return nil
	}
	return t.PushLabel
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_StaticLsp_Ingress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/incoming-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union() {
}

// To_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) To_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union(i interface{}) (NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/push-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union() {}

// To_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Ingress) To_NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union(i interface{}) (NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Lsps_StaticLsp_Ingress_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Transit represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit YANG schema element.
type NetworkInstance_Mpls_Lsps_StaticLsp_Transit struct {
	ΛMetadata      []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	IncomingLabel  NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union `path:"state/incoming-label" shadow-path:"config/incoming-label" module:"openconfig-network-instance"`
	ΛIncomingLabel []ygot.Annotation                                               `path:"state/@incoming-label" ygotAnnotation:"true"`
	NextHop        *string                                                         `path:"state/next-hop" shadow-path:"config/next-hop" module:"openconfig-network-instance"`
	ΛNextHop       []ygot.Annotation                                               `path:"state/@next-hop" ygotAnnotation:"true"`
	PushLabel      NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union     `path:"state/push-label" shadow-path:"config/push-label" module:"openconfig-network-instance"`
	ΛPushLabel     []ygot.Annotation                                               `path:"state/@push-label" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_StaticLsp_Transit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_StaticLsp_Transit) IsYANGGoStruct() {}

// GetIncomingLabel retrieves the value of the leaf IncomingLabel from the NetworkInstance_Mpls_Lsps_StaticLsp_Transit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IncomingLabel is set, it can safely use t.GetIncomingLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IncomingLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) GetIncomingLabel() NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union {
	if t == nil || t.IncomingLabel == nil {
		return nil
	}
	return t.IncomingLabel
}

// GetNextHop retrieves the value of the leaf NextHop from the NetworkInstance_Mpls_Lsps_StaticLsp_Transit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) GetNextHop() string {
	if t == nil || t.NextHop == nil {
		return ""
	}
	return *t.NextHop
}

// GetPushLabel retrieves the value of the leaf PushLabel from the NetworkInstance_Mpls_Lsps_StaticLsp_Transit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PushLabel is set, it can safely use t.GetPushLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PushLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) GetPushLabel() NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union {
	if t == nil || t.PushLabel == nil {
		return nil
	}
	return t.PushLabel
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_StaticLsp_Transit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/incoming-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union() {
}

// To_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) To_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union(i interface{}) (NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Lsps_StaticLsp_Transit_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/push-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union() {}

// To_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_Lsps_StaticLsp_Transit) To_NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union(i interface{}) (NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_Lsps_StaticLsp_Transit_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_Lsps_UnconstrainedPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/unconstrained-path YANG schema element.
type NetworkInstance_Mpls_Lsps_UnconstrainedPath struct {
	ΛMetadata          []ygot.Annotation                                              `path:"@" ygotAnnotation:"true"`
	PathSetupProtocol  *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol `path:"path-setup-protocol" module:"openconfig-network-instance"`
	ΛPathSetupProtocol []ygot.Annotation                                              `path:"@path-setup-protocol" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_UnconstrainedPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_UnconstrainedPath) IsYANGGoStruct() {}

// GetOrCreatePathSetupProtocol retrieves the value of the PathSetupProtocol field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath) GetOrCreatePathSetupProtocol() *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol {
	if t.PathSetupProtocol != nil {
		return t.PathSetupProtocol
	}
	t.PathSetupProtocol = &NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol{}
	return t.PathSetupProtocol
}

// GetPathSetupProtocol returns the value of the PathSetupProtocol struct pointer
// from NetworkInstance_Mpls_Lsps_UnconstrainedPath. If the receiver or the field PathSetupProtocol is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath) GetPathSetupProtocol() *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol {
	if t != nil && t.PathSetupProtocol != nil {
		return t.PathSetupProtocol
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_UnconstrainedPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/unconstrained-path/path-setup-protocol YANG schema element.
type NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol struct {
	ΛMetadata []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	Ldp       *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp `path:"ldp" module:"openconfig-network-instance"`
	ΛLdp      []ygot.Annotation                                                  `path:"@ldp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) IsYANGGoStruct() {}

// GetOrCreateLdp retrieves the value of the Ldp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) GetOrCreateLdp() *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp {
	if t.Ldp != nil {
		return t.Ldp
	}
	t.Ldp = &NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp{}
	return t.Ldp
}

// GetLdp returns the value of the Ldp struct pointer
// from NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol. If the receiver or the field Ldp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) GetLdp() *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp {
	if t != nil && t.Ldp != nil {
		return t.Ldp
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/unconstrained-path/path-setup-protocol/ldp YANG schema element.
type NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols struct {
	ΛMetadata       []ygot.Annotation                                       `path:"@" ygotAnnotation:"true"`
	Ldp             *NetworkInstance_Mpls_SignalingProtocols_Ldp            `path:"ldp" module:"openconfig-network-instance"`
	ΛLdp            []ygot.Annotation                                       `path:"@ldp" ygotAnnotation:"true"`
	RsvpTe          *NetworkInstance_Mpls_SignalingProtocols_RsvpTe         `path:"rsvp-te" module:"openconfig-network-instance"`
	ΛRsvpTe         []ygot.Annotation                                       `path:"@rsvp-te" ygotAnnotation:"true"`
	SegmentRouting  *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting `path:"segment-routing" module:"openconfig-network-instance"`
	ΛSegmentRouting []ygot.Annotation                                       `path:"@segment-routing" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols) IsYANGGoStruct() {}

// GetOrCreateLdp retrieves the value of the Ldp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols) GetOrCreateLdp() *NetworkInstance_Mpls_SignalingProtocols_Ldp {
	if t.Ldp != nil {
		return t.Ldp
	}
	t.Ldp = &NetworkInstance_Mpls_SignalingProtocols_Ldp{}
	return t.Ldp
}

// GetOrCreateRsvpTe retrieves the value of the RsvpTe field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols) GetOrCreateRsvpTe() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe {
	if t.RsvpTe != nil {
		return t.RsvpTe
	}
	t.RsvpTe = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe{}
	return t.RsvpTe
}

// GetOrCreateSegmentRouting retrieves the value of the SegmentRouting field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols) GetOrCreateSegmentRouting() *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting {
	if t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	t.SegmentRouting = &NetworkInstance_Mpls_SignalingProtocols_SegmentRouting{}
	return t.SegmentRouting
}

// GetLdp returns the value of the Ldp struct pointer
// from NetworkInstance_Mpls_SignalingProtocols. If the receiver or the field Ldp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols) GetLdp() *NetworkInstance_Mpls_SignalingProtocols_Ldp {
	if t != nil && t.Ldp != nil {
		return t.Ldp
	}
	return nil
}

// GetRsvpTe returns the value of the RsvpTe struct pointer
// from NetworkInstance_Mpls_SignalingProtocols. If the receiver or the field RsvpTe is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols) GetRsvpTe() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe {
	if t != nil && t.RsvpTe != nil {
		return t.RsvpTe
	}
	return nil
}

// GetSegmentRouting returns the value of the SegmentRouting struct pointer
// from NetworkInstance_Mpls_SignalingProtocols. If the receiver or the field SegmentRouting is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols) GetSegmentRouting() *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting {
	if t != nil && t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp struct {
	ΛMetadata            []ygot.Annotation                                                                                                  `path:"@" ygotAnnotation:"true"`
	Global               *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global                                                                `path:"global" module:"openconfig-network-instance"`
	ΛGlobal              []ygot.Annotation                                                                                                  `path:"@global" ygotAnnotation:"true"`
	InterfaceAttributes  *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes                                                   `path:"interface-attributes" module:"openconfig-network-instance"`
	ΛInterfaceAttributes []ygot.Annotation                                                                                                  `path:"@interface-attributes" ygotAnnotation:"true"`
	Neighbor             map[NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor            []ygot.Annotation                                                                                                  `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	Targeted             *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted                                                              `path:"targeted" module:"openconfig-network-instance"`
	ΛTargeted            []ygot.Annotation                                                                                                  `path:"@targeted" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp) IsYANGGoStruct() {}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key represents the key for list Neighbor of element /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key struct {
	LsrId        string `path:"lsr-id"`
	LabelSpaceId uint16 `path:"label-space-id"`
}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Mpls_SignalingProtocols_Ldp struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) NewNeighbor(LsrId string, LabelSpaceId uint16) (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor)
	}

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key{
		LsrId:        LsrId,
		LabelSpaceId: LabelSpaceId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor{
		LsrId:        &LsrId,
		LabelSpaceId: &LabelSpaceId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Mpls_SignalingProtocols_Ldp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) RenameNeighbor(oldK, newK NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.LsrId = &newK.LsrId
	e.LabelSpaceId = &newK.LabelSpaceId

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_Ldp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetOrCreateNeighbor(LsrId string, LabelSpaceId uint16) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor {

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key{
		LsrId:        LsrId,
		LabelSpaceId: LabelSpaceId,
	}

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(LsrId, LabelSpaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Mpls_SignalingProtocols_Ldp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetNeighbor(LsrId string, LabelSpaceId uint16) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key{
		LsrId:        LsrId,
		LabelSpaceId: LabelSpaceId,
	}

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor struct to the
// list Neighbor of NetworkInstance_Mpls_SignalingProtocols_Ldp. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) AppendNeighbor(v *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) error {
	if v.LsrId == nil {
		return fmt.Errorf("invalid nil key for LsrId")
	}

	if v.LabelSpaceId == nil {
		return fmt.Errorf("invalid nil key for LabelSpaceId")
	}

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key{
		LsrId:        *v.LsrId,
		LabelSpaceId: *v.LabelSpaceId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Key]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetOrCreateGlobal() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Global{}
	return t.Global
}

// GetOrCreateInterfaceAttributes retrieves the value of the InterfaceAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetOrCreateInterfaceAttributes() *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes {
	if t.InterfaceAttributes != nil {
		return t.InterfaceAttributes
	}
	t.InterfaceAttributes = &NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes{}
	return t.InterfaceAttributes
}

// GetOrCreateTargeted retrieves the value of the Targeted field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetOrCreateTargeted() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted {
	if t.Targeted != nil {
		return t.Targeted
	}
	t.Targeted = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted{}
	return t.Targeted
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetGlobal() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// GetInterfaceAttributes returns the value of the InterfaceAttributes struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp. If the receiver or the field InterfaceAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetInterfaceAttributes() *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes {
	if t != nil && t.InterfaceAttributes != nil {
		return t.InterfaceAttributes
	}
	return nil
}

// GetTargeted returns the value of the Targeted struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp. If the receiver or the field Targeted is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) GetTargeted() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted {
	if t != nil && t.Targeted != nil {
		return t.Targeted
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Global represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Global struct {
	ΛMetadata        []ygot.Annotation                                                   `path:"@" ygotAnnotation:"true"`
	Authentication   *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication  `path:"authentication" module:"openconfig-network-instance"`
	ΛAuthentication  []ygot.Annotation                                                   `path:"@authentication" ygotAnnotation:"true"`
	GracefulRestart  *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart []ygot.Annotation                                                   `path:"@graceful-restart" ygotAnnotation:"true"`
	LsrId            *string                                                             `path:"state/lsr-id" shadow-path:"config/lsr-id" module:"openconfig-network-instance"`
	ΛLsrId           []ygot.Annotation                                                   `path:"state/@lsr-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) IsYANGGoStruct() {}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) GetOrCreateAuthentication() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication{}
	return t.Authentication
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) GetOrCreateGracefulRestart() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart{}
	return t.GracefulRestart
}

// GetAuthentication returns the value of the Authentication struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_Global. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) GetAuthentication() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_Global. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) GetGracefulRestart() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetLsrId retrieves the value of the leaf LsrId from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LsrId is set, it can safely use t.GetLsrId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LsrId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) GetLsrId() string {
	if t == nil || t.LsrId == nil {
		return ""
	}
	return *t.LsrId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/authentication YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthenticationKey  *string           `path:"state/authentication-key" shadow-path:"config/authentication-key" module:"openconfig-network-instance"`
	ΛAuthenticationKey []ygot.Annotation `path:"state/@authentication-key" ygotAnnotation:"true"`
	Enable             *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-network-instance"`
	ΛEnable            []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) IsYANGGoStruct() {}

// GetAuthenticationKey retrieves the value of the leaf AuthenticationKey from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationKey is set, it can safely use t.GetAuthenticationKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationKey == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) GetAuthenticationKey() string {
	if t == nil || t.AuthenticationKey == nil {
		return ""
	}
	return *t.AuthenticationKey
}

// GetEnable retrieves the value of the leaf Enable from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/graceful-restart YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled             *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	ForwardingHoldtime  *uint16           `path:"state/forwarding-holdtime" shadow-path:"config/forwarding-holdtime" module:"openconfig-network-instance"`
	ΛForwardingHoldtime []ygot.Annotation `path:"state/@forwarding-holdtime" ygotAnnotation:"true"`
	HelperEnable        *bool             `path:"state/helper-enable" shadow-path:"config/helper-enable" module:"openconfig-network-instance"`
	ΛHelperEnable       []ygot.Annotation `path:"state/@helper-enable" ygotAnnotation:"true"`
	ReconnectTime       *uint16           `path:"state/reconnect-time" shadow-path:"config/reconnect-time" module:"openconfig-network-instance"`
	ΛReconnectTime      []ygot.Annotation `path:"state/@reconnect-time" ygotAnnotation:"true"`
	RecoveryTime        *uint16           `path:"state/recovery-time" shadow-path:"config/recovery-time" module:"openconfig-network-instance"`
	ΛRecoveryTime       []ygot.Annotation `path:"state/@recovery-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetForwardingHoldtime retrieves the value of the leaf ForwardingHoldtime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingHoldtime is set, it can safely use t.GetForwardingHoldtime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingHoldtime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) GetForwardingHoldtime() uint16 {
	if t == nil || t.ForwardingHoldtime == nil {
		return 0
	}
	return *t.ForwardingHoldtime
}

// GetHelperEnable retrieves the value of the leaf HelperEnable from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperEnable is set, it can safely use t.GetHelperEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperEnable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) GetHelperEnable() bool {
	if t == nil || t.HelperEnable == nil {
		return false
	}
	return *t.HelperEnable
}

// GetReconnectTime retrieves the value of the leaf ReconnectTime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReconnectTime is set, it can safely use t.GetReconnectTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReconnectTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) GetReconnectTime() uint16 {
	if t == nil || t.ReconnectTime == nil {
		return 0
	}
	return *t.ReconnectTime
}

// GetRecoveryTime retrieves the value of the leaf RecoveryTime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RecoveryTime is set, it can safely use t.GetRecoveryTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RecoveryTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) GetRecoveryTime() uint16 {
	if t == nil || t.RecoveryTime == nil {
		return 0
	}
	return *t.RecoveryTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes struct {
	ΛMetadata      []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	HelloHoldtime  *uint16                                                                               `path:"state/hello-holdtime" shadow-path:"config/hello-holdtime" module:"openconfig-network-instance"`
	ΛHelloHoldtime []ygot.Annotation                                                                     `path:"state/@hello-holdtime" ygotAnnotation:"true"`
	HelloInterval  *uint16                                                                               `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval []ygot.Annotation                                                                     `path:"state/@hello-interval" ygotAnnotation:"true"`
	Interface      map[string]*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface     []ygot.Annotation                                                                     `path:"interfaces/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) NewInterface(InterfaceId string) (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) GetInterface(InterfaceId string) *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface struct to the
// list Interface of NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) AppendInterface(v *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetHelloHoldtime retrieves the value of the leaf HelloHoldtime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloHoldtime is set, it can safely use t.GetHelloHoldtime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloHoldtime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) GetHelloHoldtime() uint16 {
	if t == nil || t.HelloHoldtime == nil {
		return 0
	}
	return *t.HelloHoldtime
}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) GetHelloInterval() uint16 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface struct {
	ΛMetadata      []ygot.Annotation                                                                                                           `path:"@" ygotAnnotation:"true"`
	AddressFamily  map[E_OpenconfigMplsLdp_MplsLdpAfi]*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily `path:"address-families/address-family" module:"openconfig-network-instance"`
	ΛAddressFamily []ygot.Annotation                                                                                                           `path:"address-families/@address-family" ygotAnnotation:"true"`
	Counters       *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters                                         `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters      []ygot.Annotation                                                                                                           `path:"state/@counters" ygotAnnotation:"true"`
	HelloHoldtime  *uint16                                                                                                                     `path:"state/hello-holdtime" shadow-path:"config/hello-holdtime" module:"openconfig-network-instance"`
	ΛHelloHoldtime []ygot.Annotation                                                                                                           `path:"state/@hello-holdtime" ygotAnnotation:"true"`
	HelloInterval  *uint16                                                                                                                     `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval []ygot.Annotation                                                                                                           `path:"state/@hello-interval" ygotAnnotation:"true"`
	InterfaceId    *string                                                                                                                     `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId   []ygot.Annotation                                                                                                           `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef   *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef                                     `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef  []ygot.Annotation                                                                                                           `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) IsYANGGoStruct() {}

// NewAddressFamily creates a new entry in the AddressFamily list of the
// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) NewAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AddressFamily == nil {
		t.AddressFamily = make(map[E_OpenconfigMplsLdp_MplsLdpAfi]*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily)
	}

	key := AfiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AddressFamily[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AddressFamily", key)
	}

	t.AddressFamily[key] = &NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily{
		AfiName: AfiName,
	}

	return t.AddressFamily[key], nil
}

// RenameAddressFamily renames an entry in the list AddressFamily within
// the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) RenameAddressFamily(oldK, newK E_OpenconfigMplsLdp_MplsLdpAfi) error {
	if _, ok := t.AddressFamily[newK]; ok {
		return fmt.Errorf("key %v already exists in AddressFamily", newK)
	}

	e, ok := t.AddressFamily[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AddressFamily", oldK)
	}
	e.AfiName = newK

	t.AddressFamily[newK] = e
	delete(t.AddressFamily, oldK)
	return nil
}

// GetOrCreateAddressFamily retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetOrCreateAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily {

	key := AfiName

	if v, ok := t.AddressFamily[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAddressFamily(AfiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAddressFamily got unexpected error: %v", err))
	}
	return v
}

// GetAddressFamily retrieves the value with the specified key from
// the AddressFamily map field of NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily {

	if t == nil {
		return nil
	}

	key := AfiName

	if lm, ok := t.AddressFamily[key]; ok {
		return lm
	}
	return nil
}

// AppendAddressFamily appends the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily struct to the
// list AddressFamily of NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) AppendAddressFamily(v *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) error {
	key := v.AfiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AddressFamily == nil {
		t.AddressFamily = make(map[E_OpenconfigMplsLdp_MplsLdpAfi]*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily)
	}

	if _, ok := t.AddressFamily[key]; ok {
		return fmt.Errorf("duplicate key for list AddressFamily %v", key)
	}

	t.AddressFamily[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetOrCreateCounters() *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters{}
	return t.Counters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetCounters() *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetHelloHoldtime retrieves the value of the leaf HelloHoldtime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloHoldtime is set, it can safely use t.GetHelloHoldtime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloHoldtime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetHelloHoldtime() uint16 {
	if t == nil || t.HelloHoldtime == nil {
		return 0
	}
	return *t.HelloHoldtime
}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetHelloInterval() uint16 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily struct {
	ΛMetadata []ygot.Annotation              `path:"@" ygotAnnotation:"true"`
	AfiName   E_OpenconfigMplsLdp_MplsLdpAfi `path:"state/afi-name|afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName  []ygot.Annotation              `path:"state/@afi-name|@afi-name" ygotAnnotation:"true"`
	Enabled   *bool                          `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation              `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) IsYANGGoStruct() {
}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) GetAfiName() E_OpenconfigMplsLdp_MplsLdpAfi {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name": t.AfiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_AddressFamily) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/state/counters YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef) IsYANGGoStruct() {
}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor struct {
	ΛMetadata       []ygot.Annotation                                                                                                                                `path:"@" ygotAnnotation:"true"`
	Authentication  *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication                                                                             `path:"authentication" module:"openconfig-network-instance"`
	ΛAuthentication []ygot.Annotation                                                                                                                                `path:"@authentication" ygotAnnotation:"true"`
	HelloAdjacency  map[NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency `path:"hello-adjacencies/hello-adjacency" module:"openconfig-network-instance"`
	ΛHelloAdjacency []ygot.Annotation                                                                                                                                `path:"hello-adjacencies/@hello-adjacency" ygotAnnotation:"true"`
	LabelSpaceId    *uint16                                                                                                                                          `path:"state/label-space-id|label-space-id" shadow-path:"config/label-space-id" module:"openconfig-network-instance"`
	ΛLabelSpaceId   []ygot.Annotation                                                                                                                                `path:"state/@label-space-id|@label-space-id" ygotAnnotation:"true"`
	LsrId           *string                                                                                                                                          `path:"state/lsr-id|lsr-id" shadow-path:"config/lsr-id" module:"openconfig-network-instance"`
	ΛLsrId          []ygot.Annotation                                                                                                                                `path:"state/@lsr-id|@lsr-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) IsYANGGoStruct() {}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key represents the key for list HelloAdjacency of element /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key struct {
	RemoteAddress string `path:"remote-address"`
	LocalAddress  string `path:"local-address"`
}

// NewHelloAdjacency creates a new entry in the HelloAdjacency list of the
// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) NewHelloAdjacency(RemoteAddress string, LocalAddress string) (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.HelloAdjacency == nil {
		t.HelloAdjacency = make(map[NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency)
	}

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key{
		RemoteAddress: RemoteAddress,
		LocalAddress:  LocalAddress,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.HelloAdjacency[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list HelloAdjacency", key)
	}

	t.HelloAdjacency[key] = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency{
		RemoteAddress: &RemoteAddress,
		LocalAddress:  &LocalAddress,
	}

	return t.HelloAdjacency[key], nil
}

// RenameHelloAdjacency renames an entry in the list HelloAdjacency within
// the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) RenameHelloAdjacency(oldK, newK NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key) error {
	if _, ok := t.HelloAdjacency[newK]; ok {
		return fmt.Errorf("key %v already exists in HelloAdjacency", newK)
	}

	e, ok := t.HelloAdjacency[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in HelloAdjacency", oldK)
	}
	e.RemoteAddress = &newK.RemoteAddress
	e.LocalAddress = &newK.LocalAddress

	t.HelloAdjacency[newK] = e
	delete(t.HelloAdjacency, oldK)
	return nil
}

// GetOrCreateHelloAdjacency retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) GetOrCreateHelloAdjacency(RemoteAddress string, LocalAddress string) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency {

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key{
		RemoteAddress: RemoteAddress,
		LocalAddress:  LocalAddress,
	}

	if v, ok := t.HelloAdjacency[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewHelloAdjacency(RemoteAddress, LocalAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateHelloAdjacency got unexpected error: %v", err))
	}
	return v
}

// GetHelloAdjacency retrieves the value with the specified key from
// the HelloAdjacency map field of NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) GetHelloAdjacency(RemoteAddress string, LocalAddress string) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key{
		RemoteAddress: RemoteAddress,
		LocalAddress:  LocalAddress,
	}

	if lm, ok := t.HelloAdjacency[key]; ok {
		return lm
	}
	return nil
}

// AppendHelloAdjacency appends the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency struct to the
// list HelloAdjacency of NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) AppendHelloAdjacency(v *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) error {
	if v.RemoteAddress == nil {
		return fmt.Errorf("invalid nil key for RemoteAddress")
	}

	if v.LocalAddress == nil {
		return fmt.Errorf("invalid nil key for LocalAddress")
	}

	key := NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key{
		RemoteAddress: *v.RemoteAddress,
		LocalAddress:  *v.LocalAddress,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.HelloAdjacency == nil {
		t.HelloAdjacency = make(map[NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_Key]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency)
	}

	if _, ok := t.HelloAdjacency[key]; ok {
		return fmt.Errorf("duplicate key for list HelloAdjacency %v", key)
	}

	t.HelloAdjacency[key] = v
	return nil
}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) GetOrCreateAuthentication() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication{}
	return t.Authentication
}

// GetAuthentication returns the value of the Authentication struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) GetAuthentication() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetLabelSpaceId retrieves the value of the leaf LabelSpaceId from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LabelSpaceId is set, it can safely use t.GetLabelSpaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LabelSpaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) GetLabelSpaceId() uint16 {
	if t == nil || t.LabelSpaceId == nil {
		return 0
	}
	return *t.LabelSpaceId
}

// GetLsrId retrieves the value of the leaf LsrId from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LsrId is set, it can safely use t.GetLsrId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LsrId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) GetLsrId() string {
	if t == nil || t.LsrId == nil {
		return ""
	}
	return *t.LsrId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LabelSpaceId == nil {
		return nil, fmt.Errorf("nil value for key LabelSpaceId")
	}

	if t.LsrId == nil {
		return nil, fmt.Errorf("nil value for key LsrId")
	}

	return map[string]interface{}{
		"label-space-id": *t.LabelSpaceId,
		"lsr-id":         *t.LsrId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/authentication YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthenticationKey  *string           `path:"state/authentication-key" shadow-path:"config/authentication-key" module:"openconfig-network-instance"`
	ΛAuthenticationKey []ygot.Annotation `path:"state/@authentication-key" ygotAnnotation:"true"`
	Enable             *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-network-instance"`
	ΛEnable            []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication) IsYANGGoStruct() {}

// GetAuthenticationKey retrieves the value of the leaf AuthenticationKey from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationKey is set, it can safely use t.GetAuthenticationKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationKey == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication) GetAuthenticationKey() string {
	if t == nil || t.AuthenticationKey == nil {
		return ""
	}
	return *t.AuthenticationKey
}

// GetEnable retrieves the value of the leaf Enable from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency struct {
	ΛMetadata      []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	AdjacencyType  E_OpenconfigMplsLdp_MplsLdpAdjacencyType                                           `path:"state/adjacency-type" module:"openconfig-network-instance"`
	ΛAdjacencyType []ygot.Annotation                                                                  `path:"state/@adjacency-type" ygotAnnotation:"true"`
	HelloDropped   *uint64                                                                            `path:"state/hello-dropped" module:"openconfig-network-instance"`
	ΛHelloDropped  []ygot.Annotation                                                                  `path:"state/@hello-dropped" ygotAnnotation:"true"`
	HelloHoldtime  *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime `path:"hello-holdtime" module:"openconfig-network-instance"`
	ΛHelloHoldtime []ygot.Annotation                                                                  `path:"@hello-holdtime" ygotAnnotation:"true"`
	HelloReceived  *uint64                                                                            `path:"state/hello-received" module:"openconfig-network-instance"`
	ΛHelloReceived []ygot.Annotation                                                                  `path:"state/@hello-received" ygotAnnotation:"true"`
	InterfaceRef   *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef  `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef  []ygot.Annotation                                                                  `path:"@interface-ref" ygotAnnotation:"true"`
	LastClear      *uint64                                                                            `path:"state/last-clear" module:"openconfig-network-instance"`
	ΛLastClear     []ygot.Annotation                                                                  `path:"state/@last-clear" ygotAnnotation:"true"`
	LocalAddress   *string                                                                            `path:"state/local-address|local-address" module:"openconfig-network-instance"`
	ΛLocalAddress  []ygot.Annotation                                                                  `path:"state/@local-address|@local-address" ygotAnnotation:"true"`
	RemoteAddress  *string                                                                            `path:"state/remote-address|remote-address" module:"openconfig-network-instance"`
	ΛRemoteAddress []ygot.Annotation                                                                  `path:"state/@remote-address|@remote-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) IsYANGGoStruct() {}

// GetOrCreateHelloHoldtime retrieves the value of the HelloHoldtime field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetOrCreateHelloHoldtime() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime {
	if t.HelloHoldtime != nil {
		return t.HelloHoldtime
	}
	t.HelloHoldtime = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime{}
	return t.HelloHoldtime
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetOrCreateInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef{}
	return t.InterfaceRef
}

// GetHelloHoldtime returns the value of the HelloHoldtime struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency. If the receiver or the field HelloHoldtime is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetHelloHoldtime() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime {
	if t != nil && t.HelloHoldtime != nil {
		return t.HelloHoldtime
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetAdjacencyType retrieves the value of the leaf AdjacencyType from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjacencyType is set, it can safely use t.GetAdjacencyType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjacencyType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetAdjacencyType() E_OpenconfigMplsLdp_MplsLdpAdjacencyType {
	if t == nil || t.AdjacencyType == 0 {
		return 0
	}
	return t.AdjacencyType
}

// GetHelloDropped retrieves the value of the leaf HelloDropped from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloDropped is set, it can safely use t.GetHelloDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloDropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetHelloDropped() uint64 {
	if t == nil || t.HelloDropped == nil {
		return 0
	}
	return *t.HelloDropped
}

// GetHelloReceived retrieves the value of the leaf HelloReceived from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloReceived is set, it can safely use t.GetHelloReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloReceived == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetHelloReceived() uint64 {
	if t == nil || t.HelloReceived == nil {
		return 0
	}
	return *t.HelloReceived
}

// GetLastClear retrieves the value of the leaf LastClear from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastClear is set, it can safely use t.GetLastClear()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastClear == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetLastClear() uint64 {
	if t == nil || t.LastClear == nil {
		return 0
	}
	return *t.LastClear
}

// GetLocalAddress retrieves the value of the leaf LocalAddress from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAddress is set, it can safely use t.GetLocalAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetLocalAddress() string {
	if t == nil || t.LocalAddress == nil {
		return ""
	}
	return *t.LocalAddress
}

// GetRemoteAddress retrieves the value of the leaf RemoteAddress from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteAddress is set, it can safely use t.GetRemoteAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) GetRemoteAddress() string {
	if t == nil || t.RemoteAddress == nil {
		return ""
	}
	return *t.RemoteAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalAddress == nil {
		return nil, fmt.Errorf("nil value for key LocalAddress")
	}

	if t.RemoteAddress == nil {
		return nil, fmt.Errorf("nil value for key RemoteAddress")
	}

	return map[string]interface{}{
		"local-address":  *t.LocalAddress,
		"remote-address": *t.RemoteAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/hello-holdtime YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Adjacent         *uint16           `path:"state/adjacent" module:"openconfig-network-instance"`
	ΛAdjacent        []ygot.Annotation `path:"state/@adjacent" ygotAnnotation:"true"`
	HelloExpiration  *uint64           `path:"state/hello-expiration" module:"openconfig-network-instance"`
	ΛHelloExpiration []ygot.Annotation `path:"state/@hello-expiration" ygotAnnotation:"true"`
	Negotiated       *uint16           `path:"state/negotiated" module:"openconfig-network-instance"`
	ΛNegotiated      []ygot.Annotation `path:"state/@negotiated" ygotAnnotation:"true"`
	NextHello        *uint64           `path:"state/next-hello" module:"openconfig-network-instance"`
	ΛNextHello       []ygot.Annotation `path:"state/@next-hello" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) IsYANGGoStruct() {
}

// GetAdjacent retrieves the value of the leaf Adjacent from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Adjacent is set, it can safely use t.GetAdjacent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Adjacent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) GetAdjacent() uint16 {
	if t == nil || t.Adjacent == nil {
		return 0
	}
	return *t.Adjacent
}

// GetHelloExpiration retrieves the value of the leaf HelloExpiration from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloExpiration is set, it can safely use t.GetHelloExpiration()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloExpiration == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) GetHelloExpiration() uint64 {
	if t == nil || t.HelloExpiration == nil {
		return 0
	}
	return *t.HelloExpiration
}

// GetNegotiated retrieves the value of the leaf Negotiated from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Negotiated is set, it can safely use t.GetNegotiated()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Negotiated == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) GetNegotiated() uint16 {
	if t == nil || t.Negotiated == nil {
		return 0
	}
	return *t.Negotiated
}

// GetNextHello retrieves the value of the leaf NextHello from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHello is set, it can safely use t.GetNextHello()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHello == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) GetNextHello() uint64 {
	if t == nil || t.NextHello == nil {
		return 0
	}
	return *t.NextHello
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_HelloHoldtime) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/interface-ref YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef) IsYANGGoStruct() {
}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbor_HelloAdjacency_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted struct {
	ΛMetadata      []ygot.Annotation                                                                                      `path:"@" ygotAnnotation:"true"`
	AddressFamily  map[E_OpenconfigMplsLdp_MplsLdpAfi]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily `path:"address-families/address-family" module:"openconfig-network-instance"`
	ΛAddressFamily []ygot.Annotation                                                                                      `path:"address-families/@address-family" ygotAnnotation:"true"`
	HelloAccept    *bool                                                                                                  `path:"state/hello-accept" shadow-path:"config/hello-accept" module:"openconfig-network-instance"`
	ΛHelloAccept   []ygot.Annotation                                                                                      `path:"state/@hello-accept" ygotAnnotation:"true"`
	HelloHoldtime  *uint16                                                                                                `path:"state/hello-holdtime" shadow-path:"config/hello-holdtime" module:"openconfig-network-instance"`
	ΛHelloHoldtime []ygot.Annotation                                                                                      `path:"state/@hello-holdtime" ygotAnnotation:"true"`
	HelloInterval  *uint16                                                                                                `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval []ygot.Annotation                                                                                      `path:"state/@hello-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) IsYANGGoStruct() {}

// NewAddressFamily creates a new entry in the AddressFamily list of the
// NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) NewAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AddressFamily == nil {
		t.AddressFamily = make(map[E_OpenconfigMplsLdp_MplsLdpAfi]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily)
	}

	key := AfiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AddressFamily[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AddressFamily", key)
	}

	t.AddressFamily[key] = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily{
		AfiName: AfiName,
	}

	return t.AddressFamily[key], nil
}

// RenameAddressFamily renames an entry in the list AddressFamily within
// the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) RenameAddressFamily(oldK, newK E_OpenconfigMplsLdp_MplsLdpAfi) error {
	if _, ok := t.AddressFamily[newK]; ok {
		return fmt.Errorf("key %v already exists in AddressFamily", newK)
	}

	e, ok := t.AddressFamily[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AddressFamily", oldK)
	}
	e.AfiName = newK

	t.AddressFamily[newK] = e
	delete(t.AddressFamily, oldK)
	return nil
}

// GetOrCreateAddressFamily retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) GetOrCreateAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily {

	key := AfiName

	if v, ok := t.AddressFamily[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAddressFamily(AfiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAddressFamily got unexpected error: %v", err))
	}
	return v
}

// GetAddressFamily retrieves the value with the specified key from
// the AddressFamily map field of NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) GetAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily {

	if t == nil {
		return nil
	}

	key := AfiName

	if lm, ok := t.AddressFamily[key]; ok {
		return lm
	}
	return nil
}

// AppendAddressFamily appends the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily struct to the
// list AddressFamily of NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) AppendAddressFamily(v *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) error {
	key := v.AfiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AddressFamily == nil {
		t.AddressFamily = make(map[E_OpenconfigMplsLdp_MplsLdpAfi]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily)
	}

	if _, ok := t.AddressFamily[key]; ok {
		return fmt.Errorf("duplicate key for list AddressFamily %v", key)
	}

	t.AddressFamily[key] = v
	return nil
}

// GetHelloAccept retrieves the value of the leaf HelloAccept from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloAccept is set, it can safely use t.GetHelloAccept()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloAccept == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) GetHelloAccept() bool {
	if t == nil || t.HelloAccept == nil {
		return false
	}
	return *t.HelloAccept
}

// GetHelloHoldtime retrieves the value of the leaf HelloHoldtime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloHoldtime is set, it can safely use t.GetHelloHoldtime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloHoldtime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) GetHelloHoldtime() uint16 {
	if t == nil || t.HelloHoldtime == nil {
		return 0
	}
	return *t.HelloHoldtime
}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) GetHelloInterval() uint16 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily struct {
	ΛMetadata []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	AfiName   E_OpenconfigMplsLdp_MplsLdpAfi                                                        `path:"state/afi-name|afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName  []ygot.Annotation                                                                     `path:"state/@afi-name|@afi-name" ygotAnnotation:"true"`
	Target    map[string]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target `path:"targets/target" module:"openconfig-network-instance"`
	ΛTarget   []ygot.Annotation                                                                     `path:"targets/@target" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) IsYANGGoStruct() {}

// NewTarget creates a new entry in the Target list of the
// NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) NewTarget(RemoteAddress string) (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Target == nil {
		t.Target = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target)
	}

	key := RemoteAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Target[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Target", key)
	}

	t.Target[key] = &NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target{
		RemoteAddress: &RemoteAddress,
	}

	return t.Target[key], nil
}

// RenameTarget renames an entry in the list Target within
// the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) RenameTarget(oldK, newK string) error {
	if _, ok := t.Target[newK]; ok {
		return fmt.Errorf("key %v already exists in Target", newK)
	}

	e, ok := t.Target[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Target", oldK)
	}
	e.RemoteAddress = &newK

	t.Target[newK] = e
	delete(t.Target, oldK)
	return nil
}

// GetOrCreateTarget retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) GetOrCreateTarget(RemoteAddress string) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target {

	key := RemoteAddress

	if v, ok := t.Target[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTarget(RemoteAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTarget got unexpected error: %v", err))
	}
	return v
}

// GetTarget retrieves the value with the specified key from
// the Target map field of NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) GetTarget(RemoteAddress string) *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target {

	if t == nil {
		return nil
	}

	key := RemoteAddress

	if lm, ok := t.Target[key]; ok {
		return lm
	}
	return nil
}

// AppendTarget appends the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target struct to the
// list Target of NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) AppendTarget(v *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) error {
	if v.RemoteAddress == nil {
		return fmt.Errorf("invalid nil key received for RemoteAddress")
	}

	key := *v.RemoteAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Target == nil {
		t.Target = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target)
	}

	if _, ok := t.Target[key]; ok {
		return fmt.Errorf("duplicate key for list Target %v", key)
	}

	t.Target[key] = v
	return nil
}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) GetAfiName() E_OpenconfigMplsLdp_MplsLdpAfi {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name": t.AfiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/targets/target YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled        *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled       []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelloHoldtime  *uint16           `path:"state/hello-holdtime" shadow-path:"config/hello-holdtime" module:"openconfig-network-instance"`
	ΛHelloHoldtime []ygot.Annotation `path:"state/@hello-holdtime" ygotAnnotation:"true"`
	HelloInterval  *uint16           `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval []ygot.Annotation `path:"state/@hello-interval" ygotAnnotation:"true"`
	LocalAddress   *string           `path:"state/local-address" shadow-path:"config/local-address" module:"openconfig-network-instance"`
	ΛLocalAddress  []ygot.Annotation `path:"state/@local-address" ygotAnnotation:"true"`
	RemoteAddress  *string           `path:"state/remote-address|remote-address" shadow-path:"config/remote-address" module:"openconfig-network-instance"`
	ΛRemoteAddress []ygot.Annotation `path:"state/@remote-address|@remote-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelloHoldtime retrieves the value of the leaf HelloHoldtime from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloHoldtime is set, it can safely use t.GetHelloHoldtime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloHoldtime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) GetHelloHoldtime() uint16 {
	if t == nil || t.HelloHoldtime == nil {
		return 0
	}
	return *t.HelloHoldtime
}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) GetHelloInterval() uint16 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// GetLocalAddress retrieves the value of the leaf LocalAddress from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAddress is set, it can safely use t.GetLocalAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) GetLocalAddress() string {
	if t == nil || t.LocalAddress == nil {
		return ""
	}
	return *t.LocalAddress
}

// GetRemoteAddress retrieves the value of the leaf RemoteAddress from the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteAddress is set, it can safely use t.GetRemoteAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) GetRemoteAddress() string {
	if t == nil || t.RemoteAddress == nil {
		return ""
	}
	return *t.RemoteAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RemoteAddress == nil {
		return nil, fmt.Errorf("nil value for key RemoteAddress")
	}

	return map[string]interface{}{
		"remote-address": *t.RemoteAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamily_Target) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct {
	ΛMetadata  []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	Global     *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global               `path:"global" module:"openconfig-network-instance"`
	ΛGlobal    []ygot.Annotation                                                    `path:"@global" ygotAnnotation:"true"`
	Interface  map[string]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface `path:"interface-attributes/interface" module:"openconfig-network-instance"`
	ΛInterface []ygot.Annotation                                                    `path:"interface-attributes/@interface" ygotAnnotation:"true"`
	Neighbor   map[string]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor  `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor  []ygot.Annotation                                                    `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	Session    map[uint64]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session   `path:"sessions/session" module:"openconfig-network-instance"`
	ΛSession   []ygot.Annotation                                                    `path:"sessions/@session" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) NewInterface(InterfaceId string) (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetInterface(InterfaceId string) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface struct to the
// list Interface of NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) AppendInterface(v *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) NewNeighbor(Address string) (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor{
		Address: &Address,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Address = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetOrCreateNeighbor(Address string) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor {

	key := Address

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Address)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetNeighbor(Address string) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor {

	if t == nil {
		return nil
	}

	key := Address

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor struct to the
// list Neighbor of NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) AppendNeighbor(v *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) error {
	if v.Address == nil {
		return fmt.Errorf("invalid nil key received for Address")
	}

	key := *v.Address

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// NewSession creates a new entry in the Session list of the
// NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) NewSession(LocalIndex uint64) (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Session == nil {
		t.Session = make(map[uint64]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session)
	}

	key := LocalIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Session[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Session", key)
	}

	t.Session[key] = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session{
		LocalIndex: &LocalIndex,
	}

	return t.Session[key], nil
}

// RenameSession renames an entry in the list Session within
// the NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) RenameSession(oldK, newK uint64) error {
	if _, ok := t.Session[newK]; ok {
		return fmt.Errorf("key %v already exists in Session", newK)
	}

	e, ok := t.Session[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Session", oldK)
	}
	e.LocalIndex = &newK

	t.Session[newK] = e
	delete(t.Session, oldK)
	return nil
}

// GetOrCreateSession retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetOrCreateSession(LocalIndex uint64) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session {

	key := LocalIndex

	if v, ok := t.Session[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSession(LocalIndex)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSession got unexpected error: %v", err))
	}
	return v
}

// GetSession retrieves the value with the specified key from
// the Session map field of NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetSession(LocalIndex uint64) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session {

	if t == nil {
		return nil
	}

	key := LocalIndex

	if lm, ok := t.Session[key]; ok {
		return lm
	}
	return nil
}

// AppendSession appends the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct to the
// list Session of NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) AppendSession(v *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) error {
	if v.LocalIndex == nil {
		return fmt.Errorf("invalid nil key received for LocalIndex")
	}

	key := *v.LocalIndex

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Session == nil {
		t.Session = make(map[uint64]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session)
	}

	if _, ok := t.Session[key]; ok {
		return fmt.Errorf("duplicate key for list Session %v", key)
	}

	t.Session[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetOrCreateGlobal() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global{}
	return t.Global
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) GetGlobal() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global struct {
	ΛMetadata        []ygot.Annotation                                                      `path:"@" ygotAnnotation:"true"`
	Counters         *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters        `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters        []ygot.Annotation                                                      `path:"state/@counters" ygotAnnotation:"true"`
	GracefulRestart  *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart []ygot.Annotation                                                      `path:"@graceful-restart" ygotAnnotation:"true"`
	Hellos           *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos          `path:"hellos" module:"openconfig-network-instance"`
	ΛHellos          []ygot.Annotation                                                      `path:"@hellos" ygotAnnotation:"true"`
	SoftPreemption   *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption  `path:"soft-preemption" module:"openconfig-network-instance"`
	ΛSoftPreemption  []ygot.Annotation                                                      `path:"@soft-preemption" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetOrCreateCounters() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters{}
	return t.Counters
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetOrCreateGracefulRestart() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateHellos retrieves the value of the Hellos field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetOrCreateHellos() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos {
	if t.Hellos != nil {
		return t.Hellos
	}
	t.Hellos = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos{}
	return t.Hellos
}

// GetOrCreateSoftPreemption retrieves the value of the SoftPreemption field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetOrCreateSoftPreemption() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption {
	if t.SoftPreemption != nil {
		return t.SoftPreemption
	}
	t.SoftPreemption = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption{}
	return t.SoftPreemption
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetCounters() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetGracefulRestart() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetHellos returns the value of the Hellos struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global. If the receiver or the field Hellos is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetHellos() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos {
	if t != nil && t.Hellos != nil {
		return t.Hellos
	}
	return nil
}

// GetSoftPreemption returns the value of the SoftPreemption struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global. If the receiver or the field SoftPreemption is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) GetSoftPreemption() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption {
	if t != nil && t.SoftPreemption != nil {
		return t.SoftPreemption
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/state/counters YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters struct {
	ΛMetadata                    []ygot.Annotation                                                      `path:"@" ygotAnnotation:"true"`
	Errors                       *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors `path:"errors" module:"openconfig-network-instance"`
	ΛErrors                      []ygot.Annotation                                                      `path:"@errors" ygotAnnotation:"true"`
	InAckMessages                *uint64                                                                `path:"in-ack-messages" module:"openconfig-network-instance"`
	ΛInAckMessages               []ygot.Annotation                                                      `path:"@in-ack-messages" ygotAnnotation:"true"`
	InHelloMessages              *uint64                                                                `path:"in-hello-messages" module:"openconfig-network-instance"`
	ΛInHelloMessages             []ygot.Annotation                                                      `path:"@in-hello-messages" ygotAnnotation:"true"`
	InPathErrorMessages          *uint64                                                                `path:"in-path-error-messages" module:"openconfig-network-instance"`
	ΛInPathErrorMessages         []ygot.Annotation                                                      `path:"@in-path-error-messages" ygotAnnotation:"true"`
	InPathMessages               *uint64                                                                `path:"in-path-messages" module:"openconfig-network-instance"`
	ΛInPathMessages              []ygot.Annotation                                                      `path:"@in-path-messages" ygotAnnotation:"true"`
	InPathTearMessages           *uint64                                                                `path:"in-path-tear-messages" module:"openconfig-network-instance"`
	ΛInPathTearMessages          []ygot.Annotation                                                      `path:"@in-path-tear-messages" ygotAnnotation:"true"`
	InReservationErrorMessages   *uint64                                                                `path:"in-reservation-error-messages" module:"openconfig-network-instance"`
	ΛInReservationErrorMessages  []ygot.Annotation                                                      `path:"@in-reservation-error-messages" ygotAnnotation:"true"`
	InReservationMessages        *uint64                                                                `path:"in-reservation-messages" module:"openconfig-network-instance"`
	ΛInReservationMessages       []ygot.Annotation                                                      `path:"@in-reservation-messages" ygotAnnotation:"true"`
	InReservationTearMessages    *uint64                                                                `path:"in-reservation-tear-messages" module:"openconfig-network-instance"`
	ΛInReservationTearMessages   []ygot.Annotation                                                      `path:"@in-reservation-tear-messages" ygotAnnotation:"true"`
	InSrefreshMessages           *uint64                                                                `path:"in-srefresh-messages" module:"openconfig-network-instance"`
	ΛInSrefreshMessages          []ygot.Annotation                                                      `path:"@in-srefresh-messages" ygotAnnotation:"true"`
	OutAckMessages               *uint64                                                                `path:"out-ack-messages" module:"openconfig-network-instance"`
	ΛOutAckMessages              []ygot.Annotation                                                      `path:"@out-ack-messages" ygotAnnotation:"true"`
	OutHelloMessages             *uint64                                                                `path:"out-hello-messages" module:"openconfig-network-instance"`
	ΛOutHelloMessages            []ygot.Annotation                                                      `path:"@out-hello-messages" ygotAnnotation:"true"`
	OutPathErrorMessages         *uint64                                                                `path:"out-path-error-messages" module:"openconfig-network-instance"`
	ΛOutPathErrorMessages        []ygot.Annotation                                                      `path:"@out-path-error-messages" ygotAnnotation:"true"`
	OutPathMessages              *uint64                                                                `path:"out-path-messages" module:"openconfig-network-instance"`
	ΛOutPathMessages             []ygot.Annotation                                                      `path:"@out-path-messages" ygotAnnotation:"true"`
	OutPathTearMessages          *uint64                                                                `path:"out-path-tear-messages" module:"openconfig-network-instance"`
	ΛOutPathTearMessages         []ygot.Annotation                                                      `path:"@out-path-tear-messages" ygotAnnotation:"true"`
	OutReservationErrorMessages  *uint64                                                                `path:"out-reservation-error-messages" module:"openconfig-network-instance"`
	ΛOutReservationErrorMessages []ygot.Annotation                                                      `path:"@out-reservation-error-messages" ygotAnnotation:"true"`
	OutReservationMessages       *uint64                                                                `path:"out-reservation-messages" module:"openconfig-network-instance"`
	ΛOutReservationMessages      []ygot.Annotation                                                      `path:"@out-reservation-messages" ygotAnnotation:"true"`
	OutReservationTearMessages   *uint64                                                                `path:"out-reservation-tear-messages" module:"openconfig-network-instance"`
	ΛOutReservationTearMessages  []ygot.Annotation                                                      `path:"@out-reservation-tear-messages" ygotAnnotation:"true"`
	OutSrefreshMessages          *uint64                                                                `path:"out-srefresh-messages" module:"openconfig-network-instance"`
	ΛOutSrefreshMessages         []ygot.Annotation                                                      `path:"@out-srefresh-messages" ygotAnnotation:"true"`
	PathTimeouts                 *uint64                                                                `path:"path-timeouts" module:"openconfig-network-instance"`
	ΛPathTimeouts                []ygot.Annotation                                                      `path:"@path-timeouts" ygotAnnotation:"true"`
	RateLimitedMessages          *uint64                                                                `path:"rate-limited-messages" module:"openconfig-network-instance"`
	ΛRateLimitedMessages         []ygot.Annotation                                                      `path:"@rate-limited-messages" ygotAnnotation:"true"`
	ReservationTimeouts          *uint64                                                                `path:"reservation-timeouts" module:"openconfig-network-instance"`
	ΛReservationTimeouts         []ygot.Annotation                                                      `path:"@reservation-timeouts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) IsYANGGoStruct() {}

// GetOrCreateErrors retrieves the value of the Errors field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOrCreateErrors() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors {
	if t.Errors != nil {
		return t.Errors
	}
	t.Errors = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors{}
	return t.Errors
}

// GetErrors returns the value of the Errors struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters. If the receiver or the field Errors is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetErrors() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors {
	if t != nil && t.Errors != nil {
		return t.Errors
	}
	return nil
}

// GetInAckMessages retrieves the value of the leaf InAckMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InAckMessages is set, it can safely use t.GetInAckMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InAckMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInAckMessages() uint64 {
	if t == nil || t.InAckMessages == nil {
		return 0
	}
	return *t.InAckMessages
}

// GetInHelloMessages retrieves the value of the leaf InHelloMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InHelloMessages is set, it can safely use t.GetInHelloMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InHelloMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInHelloMessages() uint64 {
	if t == nil || t.InHelloMessages == nil {
		return 0
	}
	return *t.InHelloMessages
}

// GetInPathErrorMessages retrieves the value of the leaf InPathErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPathErrorMessages is set, it can safely use t.GetInPathErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPathErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInPathErrorMessages() uint64 {
	if t == nil || t.InPathErrorMessages == nil {
		return 0
	}
	return *t.InPathErrorMessages
}

// GetInPathMessages retrieves the value of the leaf InPathMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPathMessages is set, it can safely use t.GetInPathMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPathMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInPathMessages() uint64 {
	if t == nil || t.InPathMessages == nil {
		return 0
	}
	return *t.InPathMessages
}

// GetInPathTearMessages retrieves the value of the leaf InPathTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPathTearMessages is set, it can safely use t.GetInPathTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPathTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInPathTearMessages() uint64 {
	if t == nil || t.InPathTearMessages == nil {
		return 0
	}
	return *t.InPathTearMessages
}

// GetInReservationErrorMessages retrieves the value of the leaf InReservationErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InReservationErrorMessages is set, it can safely use t.GetInReservationErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InReservationErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInReservationErrorMessages() uint64 {
	if t == nil || t.InReservationErrorMessages == nil {
		return 0
	}
	return *t.InReservationErrorMessages
}

// GetInReservationMessages retrieves the value of the leaf InReservationMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InReservationMessages is set, it can safely use t.GetInReservationMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InReservationMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInReservationMessages() uint64 {
	if t == nil || t.InReservationMessages == nil {
		return 0
	}
	return *t.InReservationMessages
}

// GetInReservationTearMessages retrieves the value of the leaf InReservationTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InReservationTearMessages is set, it can safely use t.GetInReservationTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InReservationTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInReservationTearMessages() uint64 {
	if t == nil || t.InReservationTearMessages == nil {
		return 0
	}
	return *t.InReservationTearMessages
}

// GetInSrefreshMessages retrieves the value of the leaf InSrefreshMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InSrefreshMessages is set, it can safely use t.GetInSrefreshMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InSrefreshMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetInSrefreshMessages() uint64 {
	if t == nil || t.InSrefreshMessages == nil {
		return 0
	}
	return *t.InSrefreshMessages
}

// GetOutAckMessages retrieves the value of the leaf OutAckMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutAckMessages is set, it can safely use t.GetOutAckMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutAckMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutAckMessages() uint64 {
	if t == nil || t.OutAckMessages == nil {
		return 0
	}
	return *t.OutAckMessages
}

// GetOutHelloMessages retrieves the value of the leaf OutHelloMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutHelloMessages is set, it can safely use t.GetOutHelloMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutHelloMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutHelloMessages() uint64 {
	if t == nil || t.OutHelloMessages == nil {
		return 0
	}
	return *t.OutHelloMessages
}

// GetOutPathErrorMessages retrieves the value of the leaf OutPathErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPathErrorMessages is set, it can safely use t.GetOutPathErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPathErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutPathErrorMessages() uint64 {
	if t == nil || t.OutPathErrorMessages == nil {
		return 0
	}
	return *t.OutPathErrorMessages
}

// GetOutPathMessages retrieves the value of the leaf OutPathMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPathMessages is set, it can safely use t.GetOutPathMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPathMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutPathMessages() uint64 {
	if t == nil || t.OutPathMessages == nil {
		return 0
	}
	return *t.OutPathMessages
}

// GetOutPathTearMessages retrieves the value of the leaf OutPathTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPathTearMessages is set, it can safely use t.GetOutPathTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPathTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutPathTearMessages() uint64 {
	if t == nil || t.OutPathTearMessages == nil {
		return 0
	}
	return *t.OutPathTearMessages
}

// GetOutReservationErrorMessages retrieves the value of the leaf OutReservationErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutReservationErrorMessages is set, it can safely use t.GetOutReservationErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutReservationErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutReservationErrorMessages() uint64 {
	if t == nil || t.OutReservationErrorMessages == nil {
		return 0
	}
	return *t.OutReservationErrorMessages
}

// GetOutReservationMessages retrieves the value of the leaf OutReservationMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutReservationMessages is set, it can safely use t.GetOutReservationMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutReservationMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutReservationMessages() uint64 {
	if t == nil || t.OutReservationMessages == nil {
		return 0
	}
	return *t.OutReservationMessages
}

// GetOutReservationTearMessages retrieves the value of the leaf OutReservationTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutReservationTearMessages is set, it can safely use t.GetOutReservationTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutReservationTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutReservationTearMessages() uint64 {
	if t == nil || t.OutReservationTearMessages == nil {
		return 0
	}
	return *t.OutReservationTearMessages
}

// GetOutSrefreshMessages retrieves the value of the leaf OutSrefreshMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutSrefreshMessages is set, it can safely use t.GetOutSrefreshMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutSrefreshMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetOutSrefreshMessages() uint64 {
	if t == nil || t.OutSrefreshMessages == nil {
		return 0
	}
	return *t.OutSrefreshMessages
}

// GetPathTimeouts retrieves the value of the leaf PathTimeouts from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathTimeouts is set, it can safely use t.GetPathTimeouts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathTimeouts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetPathTimeouts() uint64 {
	if t == nil || t.PathTimeouts == nil {
		return 0
	}
	return *t.PathTimeouts
}

// GetRateLimitedMessages retrieves the value of the leaf RateLimitedMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RateLimitedMessages is set, it can safely use t.GetRateLimitedMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RateLimitedMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetRateLimitedMessages() uint64 {
	if t == nil || t.RateLimitedMessages == nil {
		return 0
	}
	return *t.RateLimitedMessages
}

// GetReservationTimeouts retrieves the value of the leaf ReservationTimeouts from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReservationTimeouts is set, it can safely use t.GetReservationTimeouts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReservationTimeouts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) GetReservationTimeouts() uint64 {
	if t == nil || t.ReservationTimeouts == nil {
		return 0
	}
	return *t.ReservationTimeouts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/state/counters/errors YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthenticationFail  *uint64           `path:"authentication-fail" module:"openconfig-network-instance"`
	ΛAuthenticationFail []ygot.Annotation `path:"@authentication-fail" ygotAnnotation:"true"`
	BadChecksum         *uint64           `path:"bad-checksum" module:"openconfig-network-instance"`
	ΛBadChecksum        []ygot.Annotation `path:"@bad-checksum" ygotAnnotation:"true"`
	BadPacketFormat     *uint64           `path:"bad-packet-format" module:"openconfig-network-instance"`
	ΛBadPacketFormat    []ygot.Annotation `path:"@bad-packet-format" ygotAnnotation:"true"`
	BadPacketLength     *uint64           `path:"bad-packet-length" module:"openconfig-network-instance"`
	ΛBadPacketLength    []ygot.Annotation `path:"@bad-packet-length" ygotAnnotation:"true"`
	OutOfOrder          *uint64           `path:"out-of-order" module:"openconfig-network-instance"`
	ΛOutOfOrder         []ygot.Annotation `path:"@out-of-order" ygotAnnotation:"true"`
	ReceivedNack        *uint64           `path:"received-nack" module:"openconfig-network-instance"`
	ΛReceivedNack       []ygot.Annotation `path:"@received-nack" ygotAnnotation:"true"`
	TransmitFailure     *uint64           `path:"transmit-failure" module:"openconfig-network-instance"`
	ΛTransmitFailure    []ygot.Annotation `path:"@transmit-failure" ygotAnnotation:"true"`
	TransmitQueueFull   *uint64           `path:"transmit-queue-full" module:"openconfig-network-instance"`
	ΛTransmitQueueFull  []ygot.Annotation `path:"@transmit-queue-full" ygotAnnotation:"true"`
	UnknownAck          *uint64           `path:"unknown-ack" module:"openconfig-network-instance"`
	ΛUnknownAck         []ygot.Annotation `path:"@unknown-ack" ygotAnnotation:"true"`
	UnknownNack         *uint64           `path:"unknown-nack" module:"openconfig-network-instance"`
	ΛUnknownNack        []ygot.Annotation `path:"@unknown-nack" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) IsYANGGoStruct() {}

// GetAuthenticationFail retrieves the value of the leaf AuthenticationFail from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationFail is set, it can safely use t.GetAuthenticationFail()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationFail == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetAuthenticationFail() uint64 {
	if t == nil || t.AuthenticationFail == nil {
		return 0
	}
	return *t.AuthenticationFail
}

// GetBadChecksum retrieves the value of the leaf BadChecksum from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BadChecksum is set, it can safely use t.GetBadChecksum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BadChecksum == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetBadChecksum() uint64 {
	if t == nil || t.BadChecksum == nil {
		return 0
	}
	return *t.BadChecksum
}

// GetBadPacketFormat retrieves the value of the leaf BadPacketFormat from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BadPacketFormat is set, it can safely use t.GetBadPacketFormat()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BadPacketFormat == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetBadPacketFormat() uint64 {
	if t == nil || t.BadPacketFormat == nil {
		return 0
	}
	return *t.BadPacketFormat
}

// GetBadPacketLength retrieves the value of the leaf BadPacketLength from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BadPacketLength is set, it can safely use t.GetBadPacketLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BadPacketLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetBadPacketLength() uint64 {
	if t == nil || t.BadPacketLength == nil {
		return 0
	}
	return *t.BadPacketLength
}

// GetOutOfOrder retrieves the value of the leaf OutOfOrder from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOfOrder is set, it can safely use t.GetOutOfOrder()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOfOrder == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetOutOfOrder() uint64 {
	if t == nil || t.OutOfOrder == nil {
		return 0
	}
	return *t.OutOfOrder
}

// GetReceivedNack retrieves the value of the leaf ReceivedNack from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReceivedNack is set, it can safely use t.GetReceivedNack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReceivedNack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetReceivedNack() uint64 {
	if t == nil || t.ReceivedNack == nil {
		return 0
	}
	return *t.ReceivedNack
}

// GetTransmitFailure retrieves the value of the leaf TransmitFailure from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TransmitFailure is set, it can safely use t.GetTransmitFailure()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TransmitFailure == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetTransmitFailure() uint64 {
	if t == nil || t.TransmitFailure == nil {
		return 0
	}
	return *t.TransmitFailure
}

// GetTransmitQueueFull retrieves the value of the leaf TransmitQueueFull from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TransmitQueueFull is set, it can safely use t.GetTransmitQueueFull()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TransmitQueueFull == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetTransmitQueueFull() uint64 {
	if t == nil || t.TransmitQueueFull == nil {
		return 0
	}
	return *t.TransmitQueueFull
}

// GetUnknownAck retrieves the value of the leaf UnknownAck from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnknownAck is set, it can safely use t.GetUnknownAck()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnknownAck == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetUnknownAck() uint64 {
	if t == nil || t.UnknownAck == nil {
		return 0
	}
	return *t.UnknownAck
}

// GetUnknownNack retrieves the value of the leaf UnknownNack from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnknownNack is set, it can safely use t.GetUnknownNack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnknownNack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) GetUnknownNack() uint64 {
	if t == nil || t.UnknownNack == nil {
		return 0
	}
	return *t.UnknownNack
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Counters_Errors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/graceful-restart YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enable        *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-network-instance"`
	ΛEnable       []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
	RecoveryTime  *uint32           `path:"state/recovery-time" shadow-path:"config/recovery-time" module:"openconfig-network-instance"`
	ΛRecoveryTime []ygot.Annotation `path:"state/@recovery-time" ygotAnnotation:"true"`
	RestartTime   *uint32           `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-network-instance"`
	ΛRestartTime  []ygot.Annotation `path:"state/@restart-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) IsYANGGoStruct() {}

// GetEnable retrieves the value of the leaf Enable from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// GetRecoveryTime retrieves the value of the leaf RecoveryTime from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RecoveryTime is set, it can safely use t.GetRecoveryTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RecoveryTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) GetRecoveryTime() uint32 {
	if t == nil || t.RecoveryTime == nil {
		return 0
	}
	return *t.RecoveryTime
}

// GetRestartTime retrieves the value of the leaf RestartTime from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) GetRestartTime() uint32 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/hellos YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	HelloInterval     *uint16           `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval    []ygot.Annotation `path:"state/@hello-interval" ygotAnnotation:"true"`
	RefreshReduction  *bool             `path:"state/refresh-reduction" shadow-path:"config/refresh-reduction" module:"openconfig-network-instance"`
	ΛRefreshReduction []ygot.Annotation `path:"state/@refresh-reduction" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) IsYANGGoStruct() {}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) GetHelloInterval() uint16 {
	if t == nil || t.HelloInterval == nil {
		return 9000
	}
	return *t.HelloInterval
}

// GetRefreshReduction retrieves the value of the leaf RefreshReduction from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RefreshReduction is set, it can safely use t.GetRefreshReduction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RefreshReduction == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) GetRefreshReduction() bool {
	if t == nil || t.RefreshReduction == nil {
		return true
	}
	return *t.RefreshReduction
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/soft-preemption YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption struct {
	ΛMetadata              []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enable                 *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-network-instance"`
	ΛEnable                []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
	SoftPreemptionTimeout  *uint16           `path:"state/soft-preemption-timeout" shadow-path:"config/soft-preemption-timeout" module:"openconfig-network-instance"`
	ΛSoftPreemptionTimeout []ygot.Annotation `path:"state/@soft-preemption-timeout" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) IsYANGGoStruct() {}

// GetEnable retrieves the value of the leaf Enable from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// GetSoftPreemptionTimeout retrieves the value of the leaf SoftPreemptionTimeout from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SoftPreemptionTimeout is set, it can safely use t.GetSoftPreemptionTimeout()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SoftPreemptionTimeout == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) GetSoftPreemptionTimeout() uint16 {
	if t == nil || t.SoftPreemptionTimeout == nil {
		return 30
	}
	return *t.SoftPreemptionTimeout
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface struct {
	ΛMetadata             []ygot.Annotation                                                                                                                                                               `path:"@" ygotAnnotation:"true"`
	Authentication        *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication                                                                                                        `path:"authentication" module:"openconfig-network-instance"`
	ΛAuthentication       []ygot.Annotation                                                                                                                                                               `path:"@authentication" ygotAnnotation:"true"`
	BandwidthReservation  map[NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation `path:"bandwidth-reservations/bandwidth-reservation" module:"openconfig-network-instance"`
	ΛBandwidthReservation []ygot.Annotation                                                                                                                                                               `path:"bandwidth-reservations/@bandwidth-reservation" ygotAnnotation:"true"`
	Counters              *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters                                                                                                              `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters             []ygot.Annotation                                                                                                                                                               `path:"state/@counters" ygotAnnotation:"true"`
	Hellos                *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos                                                                                                                `path:"hellos" module:"openconfig-network-instance"`
	ΛHellos               []ygot.Annotation                                                                                                                                                               `path:"@hellos" ygotAnnotation:"true"`
	InterfaceId           *string                                                                                                                                                                         `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId          []ygot.Annotation                                                                                                                                                               `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef          *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef                                                                                                          `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef         []ygot.Annotation                                                                                                                                                               `path:"@interface-ref" ygotAnnotation:"true"`
	MaxLinkBandwidth      *uint64                                                                                                                                                                         `path:"state/max-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxLinkBandwidth     []ygot.Annotation                                                                                                                                                               `path:"state/@max-link-bandwidth" ygotAnnotation:"true"`
	Protection            *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection                                                                                                            `path:"protection" module:"openconfig-network-instance"`
	ΛProtection           []ygot.Annotation                                                                                                                                                               `path:"@protection" ygotAnnotation:"true"`
	Subscription          *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription                                                                                                          `path:"subscription" module:"openconfig-network-instance"`
	ΛSubscription         []ygot.Annotation                                                                                                                                                               `path:"@subscription" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) IsYANGGoStruct() {}

// NewBandwidthReservation creates a new entry in the BandwidthReservation list of the
// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) NewBandwidthReservation(Priority NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union) (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthReservation == nil {
		t.BandwidthReservation = make(map[NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthReservation[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthReservation", key)
	}

	t.BandwidthReservation[key] = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation{
		Priority: Priority,
	}

	return t.BandwidthReservation[key], nil
}

// RenameBandwidthReservation renames an entry in the list BandwidthReservation within
// the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) RenameBandwidthReservation(oldK, newK NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union) error {
	if _, ok := t.BandwidthReservation[newK]; ok {
		return fmt.Errorf("key %v already exists in BandwidthReservation", newK)
	}

	e, ok := t.BandwidthReservation[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in BandwidthReservation", oldK)
	}
	e.Priority = newK

	t.BandwidthReservation[newK] = e
	delete(t.BandwidthReservation, oldK)
	return nil
}

// GetOrCreateBandwidthReservation retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateBandwidthReservation(Priority NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation {

	key := Priority

	if v, ok := t.BandwidthReservation[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewBandwidthReservation(Priority)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateBandwidthReservation got unexpected error: %v", err))
	}
	return v
}

// GetBandwidthReservation retrieves the value with the specified key from
// the BandwidthReservation map field of NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetBandwidthReservation(Priority NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation {

	if t == nil {
		return nil
	}

	key := Priority

	if lm, ok := t.BandwidthReservation[key]; ok {
		return lm
	}
	return nil
}

// AppendBandwidthReservation appends the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation struct to the
// list BandwidthReservation of NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) AppendBandwidthReservation(v *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) error {
	key := v.Priority

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthReservation == nil {
		t.BandwidthReservation = make(map[NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation)
	}

	if _, ok := t.BandwidthReservation[key]; ok {
		return fmt.Errorf("duplicate key for list BandwidthReservation %v", key)
	}

	t.BandwidthReservation[key] = v
	return nil
}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateAuthentication() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication{}
	return t.Authentication
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateCounters() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters{}
	return t.Counters
}

// GetOrCreateHellos retrieves the value of the Hellos field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateHellos() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos {
	if t.Hellos != nil {
		return t.Hellos
	}
	t.Hellos = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos{}
	return t.Hellos
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetOrCreateProtection retrieves the value of the Protection field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateProtection() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection {
	if t.Protection != nil {
		return t.Protection
	}
	t.Protection = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection{}
	return t.Protection
}

// GetOrCreateSubscription retrieves the value of the Subscription field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetOrCreateSubscription() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription {
	if t.Subscription != nil {
		return t.Subscription
	}
	t.Subscription = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription{}
	return t.Subscription
}

// GetAuthentication returns the value of the Authentication struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetAuthentication() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetCounters() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetHellos returns the value of the Hellos struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver or the field Hellos is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetHellos() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos {
	if t != nil && t.Hellos != nil {
		return t.Hellos
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetProtection returns the value of the Protection struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver or the field Protection is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetProtection() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection {
	if t != nil && t.Protection != nil {
		return t.Protection
	}
	return nil
}

// GetSubscription returns the value of the Subscription struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface. If the receiver or the field Subscription is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetSubscription() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription {
	if t != nil && t.Subscription != nil {
		return t.Subscription
	}
	return nil
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetMaxLinkBandwidth retrieves the value of the leaf MaxLinkBandwidth from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxLinkBandwidth is set, it can safely use t.GetMaxLinkBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxLinkBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) GetMaxLinkBandwidth() uint64 {
	if t == nil || t.MaxLinkBandwidth == nil {
		return 0
	}
	return *t.MaxLinkBandwidth
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/authentication YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthenticationKey  *string           `path:"state/authentication-key" shadow-path:"config/authentication-key" module:"openconfig-network-instance"`
	ΛAuthenticationKey []ygot.Annotation `path:"state/@authentication-key" ygotAnnotation:"true"`
	Enable             *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-network-instance"`
	ΛEnable            []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication) IsYANGGoStruct() {}

// GetAuthenticationKey retrieves the value of the leaf AuthenticationKey from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationKey is set, it can safely use t.GetAuthenticationKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationKey == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication) GetAuthenticationKey() string {
	if t == nil || t.AuthenticationKey == nil {
		return ""
	}
	return *t.AuthenticationKey
}

// GetEnable retrieves the value of the leaf Enable from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation struct {
	ΛMetadata                []ygot.Annotation                                                                            `path:"@" ygotAnnotation:"true"`
	ActiveReservationsCount  *uint64                                                                                      `path:"state/active-reservations-count" module:"openconfig-network-instance"`
	ΛActiveReservationsCount []ygot.Annotation                                                                            `path:"state/@active-reservations-count" ygotAnnotation:"true"`
	AvailableBandwidth       *uint64                                                                                      `path:"state/available-bandwidth" module:"openconfig-network-instance"`
	ΛAvailableBandwidth      []ygot.Annotation                                                                            `path:"state/@available-bandwidth" ygotAnnotation:"true"`
	HighwaterMark            *uint64                                                                                      `path:"state/highwater-mark" module:"openconfig-network-instance"`
	ΛHighwaterMark           []ygot.Annotation                                                                            `path:"state/@highwater-mark" ygotAnnotation:"true"`
	Priority                 NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union `path:"state/priority|priority" module:"openconfig-network-instance"`
	ΛPriority                []ygot.Annotation                                                                            `path:"state/@priority|@priority" ygotAnnotation:"true"`
	ReservedBandwidth        *uint64                                                                                      `path:"state/reserved-bandwidth" module:"openconfig-network-instance"`
	ΛReservedBandwidth       []ygot.Annotation                                                                            `path:"state/@reserved-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) IsYANGGoStruct() {
}

// GetActiveReservationsCount retrieves the value of the leaf ActiveReservationsCount from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ActiveReservationsCount is set, it can safely use t.GetActiveReservationsCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ActiveReservationsCount == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) GetActiveReservationsCount() uint64 {
	if t == nil || t.ActiveReservationsCount == nil {
		return 0
	}
	return *t.ActiveReservationsCount
}

// GetAvailableBandwidth retrieves the value of the leaf AvailableBandwidth from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AvailableBandwidth is set, it can safely use t.GetAvailableBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AvailableBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) GetAvailableBandwidth() uint64 {
	if t == nil || t.AvailableBandwidth == nil {
		return 0
	}
	return *t.AvailableBandwidth
}

// GetHighwaterMark retrieves the value of the leaf HighwaterMark from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HighwaterMark is set, it can safely use t.GetHighwaterMark()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HighwaterMark == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) GetHighwaterMark() uint64 {
	if t == nil || t.HighwaterMark == nil {
		return 0
	}
	return *t.HighwaterMark
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) GetPriority() NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union {
	if t == nil || t.Priority == nil {
		return nil
	}
	return t.Priority
}

// GetReservedBandwidth retrieves the value of the leaf ReservedBandwidth from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReservedBandwidth is set, it can safely use t.GetReservedBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReservedBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) GetReservedBandwidth() uint64 {
	if t == nil || t.ReservedBandwidth == nil {
		return 0
	}
	return *t.ReservedBandwidth
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"priority": t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/state/priority within the YANG schema.
// Union type can be one of [E_BandwidthReservation_Priority_Enum, UnionUint8].
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union interface {
	// Union type can be one of [E_BandwidthReservation_Priority_Enum, UnionUint8]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union ensures that E_BandwidthReservation_Priority_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union interface.
func (E_BandwidthReservation_Priority_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union ensures that UnionUint8
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union interface.
func (UnionUint8) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation) To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint8:
		return UnionUint8(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_BandwidthReservation_Priority_Union, unknown union type, got: %T, want any of [E_BandwidthReservation_Priority_Enum, uint8]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/state/counters YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters struct {
	ΛMetadata                    []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	Errors                       *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors `path:"errors" module:"openconfig-network-instance"`
	ΛErrors                      []ygot.Annotation                                                         `path:"@errors" ygotAnnotation:"true"`
	InAckMessages                *uint64                                                                   `path:"in-ack-messages" module:"openconfig-network-instance"`
	ΛInAckMessages               []ygot.Annotation                                                         `path:"@in-ack-messages" ygotAnnotation:"true"`
	InHelloMessages              *uint64                                                                   `path:"in-hello-messages" module:"openconfig-network-instance"`
	ΛInHelloMessages             []ygot.Annotation                                                         `path:"@in-hello-messages" ygotAnnotation:"true"`
	InPathErrorMessages          *uint64                                                                   `path:"in-path-error-messages" module:"openconfig-network-instance"`
	ΛInPathErrorMessages         []ygot.Annotation                                                         `path:"@in-path-error-messages" ygotAnnotation:"true"`
	InPathMessages               *uint64                                                                   `path:"in-path-messages" module:"openconfig-network-instance"`
	ΛInPathMessages              []ygot.Annotation                                                         `path:"@in-path-messages" ygotAnnotation:"true"`
	InPathTearMessages           *uint64                                                                   `path:"in-path-tear-messages" module:"openconfig-network-instance"`
	ΛInPathTearMessages          []ygot.Annotation                                                         `path:"@in-path-tear-messages" ygotAnnotation:"true"`
	InReservationErrorMessages   *uint64                                                                   `path:"in-reservation-error-messages" module:"openconfig-network-instance"`
	ΛInReservationErrorMessages  []ygot.Annotation                                                         `path:"@in-reservation-error-messages" ygotAnnotation:"true"`
	InReservationMessages        *uint64                                                                   `path:"in-reservation-messages" module:"openconfig-network-instance"`
	ΛInReservationMessages       []ygot.Annotation                                                         `path:"@in-reservation-messages" ygotAnnotation:"true"`
	InReservationTearMessages    *uint64                                                                   `path:"in-reservation-tear-messages" module:"openconfig-network-instance"`
	ΛInReservationTearMessages   []ygot.Annotation                                                         `path:"@in-reservation-tear-messages" ygotAnnotation:"true"`
	InSrefreshMessages           *uint64                                                                   `path:"in-srefresh-messages" module:"openconfig-network-instance"`
	ΛInSrefreshMessages          []ygot.Annotation                                                         `path:"@in-srefresh-messages" ygotAnnotation:"true"`
	OutAckMessages               *uint64                                                                   `path:"out-ack-messages" module:"openconfig-network-instance"`
	ΛOutAckMessages              []ygot.Annotation                                                         `path:"@out-ack-messages" ygotAnnotation:"true"`
	OutHelloMessages             *uint64                                                                   `path:"out-hello-messages" module:"openconfig-network-instance"`
	ΛOutHelloMessages            []ygot.Annotation                                                         `path:"@out-hello-messages" ygotAnnotation:"true"`
	OutPathErrorMessages         *uint64                                                                   `path:"out-path-error-messages" module:"openconfig-network-instance"`
	ΛOutPathErrorMessages        []ygot.Annotation                                                         `path:"@out-path-error-messages" ygotAnnotation:"true"`
	OutPathMessages              *uint64                                                                   `path:"out-path-messages" module:"openconfig-network-instance"`
	ΛOutPathMessages             []ygot.Annotation                                                         `path:"@out-path-messages" ygotAnnotation:"true"`
	OutPathTearMessages          *uint64                                                                   `path:"out-path-tear-messages" module:"openconfig-network-instance"`
	ΛOutPathTearMessages         []ygot.Annotation                                                         `path:"@out-path-tear-messages" ygotAnnotation:"true"`
	OutReservationErrorMessages  *uint64                                                                   `path:"out-reservation-error-messages" module:"openconfig-network-instance"`
	ΛOutReservationErrorMessages []ygot.Annotation                                                         `path:"@out-reservation-error-messages" ygotAnnotation:"true"`
	OutReservationMessages       *uint64                                                                   `path:"out-reservation-messages" module:"openconfig-network-instance"`
	ΛOutReservationMessages      []ygot.Annotation                                                         `path:"@out-reservation-messages" ygotAnnotation:"true"`
	OutReservationTearMessages   *uint64                                                                   `path:"out-reservation-tear-messages" module:"openconfig-network-instance"`
	ΛOutReservationTearMessages  []ygot.Annotation                                                         `path:"@out-reservation-tear-messages" ygotAnnotation:"true"`
	OutSrefreshMessages          *uint64                                                                   `path:"out-srefresh-messages" module:"openconfig-network-instance"`
	ΛOutSrefreshMessages         []ygot.Annotation                                                         `path:"@out-srefresh-messages" ygotAnnotation:"true"`
	RateLimitedMessages          *uint64                                                                   `path:"rate-limited-messages" module:"openconfig-network-instance"`
	ΛRateLimitedMessages         []ygot.Annotation                                                         `path:"@rate-limited-messages" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) IsYANGGoStruct() {}

// GetOrCreateErrors retrieves the value of the Errors field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOrCreateErrors() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors {
	if t.Errors != nil {
		return t.Errors
	}
	t.Errors = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors{}
	return t.Errors
}

// GetErrors returns the value of the Errors struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters. If the receiver or the field Errors is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetErrors() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors {
	if t != nil && t.Errors != nil {
		return t.Errors
	}
	return nil
}

// GetInAckMessages retrieves the value of the leaf InAckMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InAckMessages is set, it can safely use t.GetInAckMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InAckMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInAckMessages() uint64 {
	if t == nil || t.InAckMessages == nil {
		return 0
	}
	return *t.InAckMessages
}

// GetInHelloMessages retrieves the value of the leaf InHelloMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InHelloMessages is set, it can safely use t.GetInHelloMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InHelloMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInHelloMessages() uint64 {
	if t == nil || t.InHelloMessages == nil {
		return 0
	}
	return *t.InHelloMessages
}

// GetInPathErrorMessages retrieves the value of the leaf InPathErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPathErrorMessages is set, it can safely use t.GetInPathErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPathErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInPathErrorMessages() uint64 {
	if t == nil || t.InPathErrorMessages == nil {
		return 0
	}
	return *t.InPathErrorMessages
}

// GetInPathMessages retrieves the value of the leaf InPathMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPathMessages is set, it can safely use t.GetInPathMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPathMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInPathMessages() uint64 {
	if t == nil || t.InPathMessages == nil {
		return 0
	}
	return *t.InPathMessages
}

// GetInPathTearMessages retrieves the value of the leaf InPathTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPathTearMessages is set, it can safely use t.GetInPathTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPathTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInPathTearMessages() uint64 {
	if t == nil || t.InPathTearMessages == nil {
		return 0
	}
	return *t.InPathTearMessages
}

// GetInReservationErrorMessages retrieves the value of the leaf InReservationErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InReservationErrorMessages is set, it can safely use t.GetInReservationErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InReservationErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInReservationErrorMessages() uint64 {
	if t == nil || t.InReservationErrorMessages == nil {
		return 0
	}
	return *t.InReservationErrorMessages
}

// GetInReservationMessages retrieves the value of the leaf InReservationMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InReservationMessages is set, it can safely use t.GetInReservationMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InReservationMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInReservationMessages() uint64 {
	if t == nil || t.InReservationMessages == nil {
		return 0
	}
	return *t.InReservationMessages
}

// GetInReservationTearMessages retrieves the value of the leaf InReservationTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InReservationTearMessages is set, it can safely use t.GetInReservationTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InReservationTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInReservationTearMessages() uint64 {
	if t == nil || t.InReservationTearMessages == nil {
		return 0
	}
	return *t.InReservationTearMessages
}

// GetInSrefreshMessages retrieves the value of the leaf InSrefreshMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InSrefreshMessages is set, it can safely use t.GetInSrefreshMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InSrefreshMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetInSrefreshMessages() uint64 {
	if t == nil || t.InSrefreshMessages == nil {
		return 0
	}
	return *t.InSrefreshMessages
}

// GetOutAckMessages retrieves the value of the leaf OutAckMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutAckMessages is set, it can safely use t.GetOutAckMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutAckMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutAckMessages() uint64 {
	if t == nil || t.OutAckMessages == nil {
		return 0
	}
	return *t.OutAckMessages
}

// GetOutHelloMessages retrieves the value of the leaf OutHelloMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutHelloMessages is set, it can safely use t.GetOutHelloMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutHelloMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutHelloMessages() uint64 {
	if t == nil || t.OutHelloMessages == nil {
		return 0
	}
	return *t.OutHelloMessages
}

// GetOutPathErrorMessages retrieves the value of the leaf OutPathErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPathErrorMessages is set, it can safely use t.GetOutPathErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPathErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutPathErrorMessages() uint64 {
	if t == nil || t.OutPathErrorMessages == nil {
		return 0
	}
	return *t.OutPathErrorMessages
}

// GetOutPathMessages retrieves the value of the leaf OutPathMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPathMessages is set, it can safely use t.GetOutPathMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPathMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutPathMessages() uint64 {
	if t == nil || t.OutPathMessages == nil {
		return 0
	}
	return *t.OutPathMessages
}

// GetOutPathTearMessages retrieves the value of the leaf OutPathTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPathTearMessages is set, it can safely use t.GetOutPathTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPathTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutPathTearMessages() uint64 {
	if t == nil || t.OutPathTearMessages == nil {
		return 0
	}
	return *t.OutPathTearMessages
}

// GetOutReservationErrorMessages retrieves the value of the leaf OutReservationErrorMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutReservationErrorMessages is set, it can safely use t.GetOutReservationErrorMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutReservationErrorMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutReservationErrorMessages() uint64 {
	if t == nil || t.OutReservationErrorMessages == nil {
		return 0
	}
	return *t.OutReservationErrorMessages
}

// GetOutReservationMessages retrieves the value of the leaf OutReservationMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutReservationMessages is set, it can safely use t.GetOutReservationMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutReservationMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutReservationMessages() uint64 {
	if t == nil || t.OutReservationMessages == nil {
		return 0
	}
	return *t.OutReservationMessages
}

// GetOutReservationTearMessages retrieves the value of the leaf OutReservationTearMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutReservationTearMessages is set, it can safely use t.GetOutReservationTearMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutReservationTearMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutReservationTearMessages() uint64 {
	if t == nil || t.OutReservationTearMessages == nil {
		return 0
	}
	return *t.OutReservationTearMessages
}

// GetOutSrefreshMessages retrieves the value of the leaf OutSrefreshMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutSrefreshMessages is set, it can safely use t.GetOutSrefreshMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutSrefreshMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetOutSrefreshMessages() uint64 {
	if t == nil || t.OutSrefreshMessages == nil {
		return 0
	}
	return *t.OutSrefreshMessages
}

// GetRateLimitedMessages retrieves the value of the leaf RateLimitedMessages from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RateLimitedMessages is set, it can safely use t.GetRateLimitedMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RateLimitedMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) GetRateLimitedMessages() uint64 {
	if t == nil || t.RateLimitedMessages == nil {
		return 0
	}
	return *t.RateLimitedMessages
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/state/counters/errors YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthenticationFail  *uint64           `path:"authentication-fail" module:"openconfig-network-instance"`
	ΛAuthenticationFail []ygot.Annotation `path:"@authentication-fail" ygotAnnotation:"true"`
	BadChecksum         *uint64           `path:"bad-checksum" module:"openconfig-network-instance"`
	ΛBadChecksum        []ygot.Annotation `path:"@bad-checksum" ygotAnnotation:"true"`
	BadPacketFormat     *uint64           `path:"bad-packet-format" module:"openconfig-network-instance"`
	ΛBadPacketFormat    []ygot.Annotation `path:"@bad-packet-format" ygotAnnotation:"true"`
	BadPacketLength     *uint64           `path:"bad-packet-length" module:"openconfig-network-instance"`
	ΛBadPacketLength    []ygot.Annotation `path:"@bad-packet-length" ygotAnnotation:"true"`
	OutOfOrder          *uint64           `path:"out-of-order" module:"openconfig-network-instance"`
	ΛOutOfOrder         []ygot.Annotation `path:"@out-of-order" ygotAnnotation:"true"`
	ReceivedNack        *uint64           `path:"received-nack" module:"openconfig-network-instance"`
	ΛReceivedNack       []ygot.Annotation `path:"@received-nack" ygotAnnotation:"true"`
	TransmitFailure     *uint64           `path:"transmit-failure" module:"openconfig-network-instance"`
	ΛTransmitFailure    []ygot.Annotation `path:"@transmit-failure" ygotAnnotation:"true"`
	TransmitQueueFull   *uint64           `path:"transmit-queue-full" module:"openconfig-network-instance"`
	ΛTransmitQueueFull  []ygot.Annotation `path:"@transmit-queue-full" ygotAnnotation:"true"`
	UnknownAck          *uint64           `path:"unknown-ack" module:"openconfig-network-instance"`
	ΛUnknownAck         []ygot.Annotation `path:"@unknown-ack" ygotAnnotation:"true"`
	UnknownNack         *uint64           `path:"unknown-nack" module:"openconfig-network-instance"`
	ΛUnknownNack        []ygot.Annotation `path:"@unknown-nack" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) IsYANGGoStruct() {}

// GetAuthenticationFail retrieves the value of the leaf AuthenticationFail from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationFail is set, it can safely use t.GetAuthenticationFail()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationFail == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetAuthenticationFail() uint64 {
	if t == nil || t.AuthenticationFail == nil {
		return 0
	}
	return *t.AuthenticationFail
}

// GetBadChecksum retrieves the value of the leaf BadChecksum from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BadChecksum is set, it can safely use t.GetBadChecksum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BadChecksum == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetBadChecksum() uint64 {
	if t == nil || t.BadChecksum == nil {
		return 0
	}
	return *t.BadChecksum
}

// GetBadPacketFormat retrieves the value of the leaf BadPacketFormat from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BadPacketFormat is set, it can safely use t.GetBadPacketFormat()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BadPacketFormat == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetBadPacketFormat() uint64 {
	if t == nil || t.BadPacketFormat == nil {
		return 0
	}
	return *t.BadPacketFormat
}

// GetBadPacketLength retrieves the value of the leaf BadPacketLength from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BadPacketLength is set, it can safely use t.GetBadPacketLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BadPacketLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetBadPacketLength() uint64 {
	if t == nil || t.BadPacketLength == nil {
		return 0
	}
	return *t.BadPacketLength
}

// GetOutOfOrder retrieves the value of the leaf OutOfOrder from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOfOrder is set, it can safely use t.GetOutOfOrder()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOfOrder == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetOutOfOrder() uint64 {
	if t == nil || t.OutOfOrder == nil {
		return 0
	}
	return *t.OutOfOrder
}

// GetReceivedNack retrieves the value of the leaf ReceivedNack from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReceivedNack is set, it can safely use t.GetReceivedNack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReceivedNack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetReceivedNack() uint64 {
	if t == nil || t.ReceivedNack == nil {
		return 0
	}
	return *t.ReceivedNack
}

// GetTransmitFailure retrieves the value of the leaf TransmitFailure from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TransmitFailure is set, it can safely use t.GetTransmitFailure()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TransmitFailure == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetTransmitFailure() uint64 {
	if t == nil || t.TransmitFailure == nil {
		return 0
	}
	return *t.TransmitFailure
}

// GetTransmitQueueFull retrieves the value of the leaf TransmitQueueFull from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TransmitQueueFull is set, it can safely use t.GetTransmitQueueFull()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TransmitQueueFull == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetTransmitQueueFull() uint64 {
	if t == nil || t.TransmitQueueFull == nil {
		return 0
	}
	return *t.TransmitQueueFull
}

// GetUnknownAck retrieves the value of the leaf UnknownAck from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnknownAck is set, it can safely use t.GetUnknownAck()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnknownAck == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetUnknownAck() uint64 {
	if t == nil || t.UnknownAck == nil {
		return 0
	}
	return *t.UnknownAck
}

// GetUnknownNack retrieves the value of the leaf UnknownNack from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnknownNack is set, it can safely use t.GetUnknownNack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnknownNack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) GetUnknownNack() uint64 {
	if t == nil || t.UnknownNack == nil {
		return 0
	}
	return *t.UnknownNack
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Counters_Errors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/hellos YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	HelloInterval     *uint16           `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval    []ygot.Annotation `path:"state/@hello-interval" ygotAnnotation:"true"`
	RefreshReduction  *bool             `path:"state/refresh-reduction" shadow-path:"config/refresh-reduction" module:"openconfig-network-instance"`
	ΛRefreshReduction []ygot.Annotation `path:"state/@refresh-reduction" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos) IsYANGGoStruct() {}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos) GetHelloInterval() uint16 {
	if t == nil || t.HelloInterval == nil {
		return 9000
	}
	return *t.HelloInterval
}

// GetRefreshReduction retrieves the value of the leaf RefreshReduction from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RefreshReduction is set, it can safely use t.GetRefreshReduction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RefreshReduction == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos) GetRefreshReduction() bool {
	if t == nil || t.RefreshReduction == nil {
		return true
	}
	return *t.RefreshReduction
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Hellos) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/interface-ref YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection struct {
	ΛMetadata                     []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	BypassOptimizeInterval        *uint16                               `path:"state/bypass-optimize-interval" shadow-path:"config/bypass-optimize-interval" module:"openconfig-network-instance"`
	ΛBypassOptimizeInterval       []ygot.Annotation                     `path:"state/@bypass-optimize-interval" ygotAnnotation:"true"`
	LinkProtectionStyleRequested  E_OpenconfigMplsTypes_PROTECTION_TYPE `path:"state/link-protection-style-requested" shadow-path:"config/link-protection-style-requested" module:"openconfig-network-instance"`
	ΛLinkProtectionStyleRequested []ygot.Annotation                     `path:"state/@link-protection-style-requested" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection) IsYANGGoStruct() {}

// GetBypassOptimizeInterval retrieves the value of the leaf BypassOptimizeInterval from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BypassOptimizeInterval is set, it can safely use t.GetBypassOptimizeInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BypassOptimizeInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection) GetBypassOptimizeInterval() uint16 {
	if t == nil || t.BypassOptimizeInterval == nil {
		return 0
	}
	return *t.BypassOptimizeInterval
}

// GetLinkProtectionStyleRequested retrieves the value of the leaf LinkProtectionStyleRequested from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkProtectionStyleRequested is set, it can safely use t.GetLinkProtectionStyleRequested()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkProtectionStyleRequested == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection) GetLinkProtectionStyleRequested() E_OpenconfigMplsTypes_PROTECTION_TYPE {
	if t == nil || t.LinkProtectionStyleRequested == 0 {
		return OpenconfigMplsTypes_PROTECTION_TYPE_LINK_NODE_PROTECTION_REQUESTED
	}
	return t.LinkProtectionStyleRequested
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Protection) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/subscription YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription struct {
	ΛMetadata                         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CalculatedAbsoluteSubscriptionBw  *uint64           `path:"state/calculated-absolute-subscription-bw" module:"openconfig-network-instance"`
	ΛCalculatedAbsoluteSubscriptionBw []ygot.Annotation `path:"state/@calculated-absolute-subscription-bw" ygotAnnotation:"true"`
	Subscription                      *uint8            `path:"state/subscription" shadow-path:"config/subscription" module:"openconfig-network-instance"`
	ΛSubscription                     []ygot.Annotation `path:"state/@subscription" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription) IsYANGGoStruct() {}

// GetCalculatedAbsoluteSubscriptionBw retrieves the value of the leaf CalculatedAbsoluteSubscriptionBw from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CalculatedAbsoluteSubscriptionBw is set, it can safely use t.GetCalculatedAbsoluteSubscriptionBw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CalculatedAbsoluteSubscriptionBw == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription) GetCalculatedAbsoluteSubscriptionBw() uint64 {
	if t == nil || t.CalculatedAbsoluteSubscriptionBw == nil {
		return 0
	}
	return *t.CalculatedAbsoluteSubscriptionBw
}

// GetSubscription retrieves the value of the leaf Subscription from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subscription is set, it can safely use t.GetSubscription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subscription == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription) GetSubscription() uint8 {
	if t == nil || t.Subscription == nil {
		return 0
	}
	return *t.Subscription
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Interface_Subscription) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/neighbors/neighbor YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor struct {
	ΛMetadata          []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Address            *string                   `path:"state/address|address" module:"openconfig-network-instance"`
	ΛAddress           []ygot.Annotation         `path:"state/@address|@address" ygotAnnotation:"true"`
	DetectedInterface  *string                   `path:"state/detected-interface" module:"openconfig-network-instance"`
	ΛDetectedInterface []ygot.Annotation         `path:"state/@detected-interface" ygotAnnotation:"true"`
	NeighborStatus     E_Neighbor_NeighborStatus `path:"state/neighbor-status" module:"openconfig-network-instance"`
	ΛNeighborStatus    []ygot.Annotation         `path:"state/@neighbor-status" ygotAnnotation:"true"`
	RefreshReduction   *bool                     `path:"state/refresh-reduction" module:"openconfig-network-instance"`
	ΛRefreshReduction  []ygot.Annotation         `path:"state/@refresh-reduction" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetDetectedInterface retrieves the value of the leaf DetectedInterface from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DetectedInterface is set, it can safely use t.GetDetectedInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DetectedInterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) GetDetectedInterface() string {
	if t == nil || t.DetectedInterface == nil {
		return ""
	}
	return *t.DetectedInterface
}

// GetNeighborStatus retrieves the value of the leaf NeighborStatus from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborStatus is set, it can safely use t.GetNeighborStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborStatus == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) GetNeighborStatus() E_Neighbor_NeighborStatus {
	if t == nil || t.NeighborStatus == 0 {
		return 0
	}
	return t.NeighborStatus
}

// GetRefreshReduction retrieves the value of the leaf RefreshReduction from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RefreshReduction is set, it can safely use t.GetRefreshReduction()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RefreshReduction == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) GetRefreshReduction() bool {
	if t == nil || t.RefreshReduction == nil {
		return false
	}
	return *t.RefreshReduction
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct {
	ΛMetadata            []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	DestinationAddress   *string                                                                                `path:"state/destination-address" module:"openconfig-network-instance"`
	ΛDestinationAddress  []ygot.Annotation                                                                      `path:"state/@destination-address" ygotAnnotation:"true"`
	ExplicitRouteObject  map[uint64]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject `path:"explicit-route-objects/explicit-route-object" module:"openconfig-network-instance"`
	ΛExplicitRouteObject []ygot.Annotation                                                                      `path:"explicit-route-objects/@explicit-route-object" ygotAnnotation:"true"`
	LabelIn              NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union                   `path:"state/label-in" module:"openconfig-network-instance"`
	ΛLabelIn             []ygot.Annotation                                                                      `path:"state/@label-in" ygotAnnotation:"true"`
	LabelOut             NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union                  `path:"state/label-out" module:"openconfig-network-instance"`
	ΛLabelOut            []ygot.Annotation                                                                      `path:"state/@label-out" ygotAnnotation:"true"`
	LocalIndex           *uint64                                                                                `path:"state/local-index|local-index" module:"openconfig-network-instance"`
	ΛLocalIndex          []ygot.Annotation                                                                      `path:"state/@local-index|@local-index" ygotAnnotation:"true"`
	LspId                *uint16                                                                                `path:"state/lsp-id" module:"openconfig-network-instance"`
	ΛLspId               []ygot.Annotation                                                                      `path:"state/@lsp-id" ygotAnnotation:"true"`
	ProtectionRequested  E_OpenconfigMplsTypes_PROTECTION_TYPE                                                  `path:"state/protection-requested" module:"openconfig-network-instance"`
	ΛProtectionRequested []ygot.Annotation                                                                      `path:"state/@protection-requested" ygotAnnotation:"true"`
	RecordRouteObject    map[uint8]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject    `path:"record-route-objects/record-route-object" module:"openconfig-network-instance"`
	ΛRecordRouteObject   []ygot.Annotation                                                                      `path:"record-route-objects/@record-route-object" ygotAnnotation:"true"`
	SenderTspec          *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec                    `path:"state/sender-tspec" module:"openconfig-network-instance"`
	ΛSenderTspec         []ygot.Annotation                                                                      `path:"state/@sender-tspec" ygotAnnotation:"true"`
	SessionName          *string                                                                                `path:"state/session-name" module:"openconfig-network-instance"`
	ΛSessionName         []ygot.Annotation                                                                      `path:"state/@session-name" ygotAnnotation:"true"`
	SourceAddress        *string                                                                                `path:"state/source-address" module:"openconfig-network-instance"`
	ΛSourceAddress       []ygot.Annotation                                                                      `path:"state/@source-address" ygotAnnotation:"true"`
	Status               E_Session_Status                                                                       `path:"state/status" module:"openconfig-network-instance"`
	ΛStatus              []ygot.Annotation                                                                      `path:"state/@status" ygotAnnotation:"true"`
	TunnelId             *uint16                                                                                `path:"state/tunnel-id" module:"openconfig-network-instance"`
	ΛTunnelId            []ygot.Annotation                                                                      `path:"state/@tunnel-id" ygotAnnotation:"true"`
	Type                 E_OpenconfigMplsTypes_LSP_ROLE                                                         `path:"state/type" module:"openconfig-network-instance"`
	ΛType                []ygot.Annotation                                                                      `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) IsYANGGoStruct() {}

// NewExplicitRouteObject creates a new entry in the ExplicitRouteObject list of the
// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) NewExplicitRouteObject(Index uint64) (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExplicitRouteObject == nil {
		t.ExplicitRouteObject = make(map[uint64]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExplicitRouteObject[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExplicitRouteObject", key)
	}

	t.ExplicitRouteObject[key] = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject{
		Index: &Index,
	}

	return t.ExplicitRouteObject[key], nil
}

// RenameExplicitRouteObject renames an entry in the list ExplicitRouteObject within
// the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) RenameExplicitRouteObject(oldK, newK uint64) error {
	if _, ok := t.ExplicitRouteObject[newK]; ok {
		return fmt.Errorf("key %v already exists in ExplicitRouteObject", newK)
	}

	e, ok := t.ExplicitRouteObject[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ExplicitRouteObject", oldK)
	}
	e.Index = &newK

	t.ExplicitRouteObject[newK] = e
	delete(t.ExplicitRouteObject, oldK)
	return nil
}

// GetOrCreateExplicitRouteObject retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetOrCreateExplicitRouteObject(Index uint64) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject {

	key := Index

	if v, ok := t.ExplicitRouteObject[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewExplicitRouteObject(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateExplicitRouteObject got unexpected error: %v", err))
	}
	return v
}

// GetExplicitRouteObject retrieves the value with the specified key from
// the ExplicitRouteObject map field of NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetExplicitRouteObject(Index uint64) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.ExplicitRouteObject[key]; ok {
		return lm
	}
	return nil
}

// AppendExplicitRouteObject appends the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject struct to the
// list ExplicitRouteObject of NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) AppendExplicitRouteObject(v *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExplicitRouteObject == nil {
		t.ExplicitRouteObject = make(map[uint64]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject)
	}

	if _, ok := t.ExplicitRouteObject[key]; ok {
		return fmt.Errorf("duplicate key for list ExplicitRouteObject %v", key)
	}

	t.ExplicitRouteObject[key] = v
	return nil
}

// NewRecordRouteObject creates a new entry in the RecordRouteObject list of the
// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) NewRecordRouteObject(Index uint8) (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RecordRouteObject == nil {
		t.RecordRouteObject = make(map[uint8]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RecordRouteObject[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RecordRouteObject", key)
	}

	t.RecordRouteObject[key] = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject{
		Index: &Index,
	}

	return t.RecordRouteObject[key], nil
}

// RenameRecordRouteObject renames an entry in the list RecordRouteObject within
// the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) RenameRecordRouteObject(oldK, newK uint8) error {
	if _, ok := t.RecordRouteObject[newK]; ok {
		return fmt.Errorf("key %v already exists in RecordRouteObject", newK)
	}

	e, ok := t.RecordRouteObject[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in RecordRouteObject", oldK)
	}
	e.Index = &newK

	t.RecordRouteObject[newK] = e
	delete(t.RecordRouteObject, oldK)
	return nil
}

// GetOrCreateRecordRouteObject retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetOrCreateRecordRouteObject(Index uint8) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject {

	key := Index

	if v, ok := t.RecordRouteObject[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRecordRouteObject(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRecordRouteObject got unexpected error: %v", err))
	}
	return v
}

// GetRecordRouteObject retrieves the value with the specified key from
// the RecordRouteObject map field of NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetRecordRouteObject(Index uint8) *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.RecordRouteObject[key]; ok {
		return lm
	}
	return nil
}

// AppendRecordRouteObject appends the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject struct to the
// list RecordRouteObject of NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) AppendRecordRouteObject(v *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RecordRouteObject == nil {
		t.RecordRouteObject = make(map[uint8]*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject)
	}

	if _, ok := t.RecordRouteObject[key]; ok {
		return fmt.Errorf("duplicate key for list RecordRouteObject %v", key)
	}

	t.RecordRouteObject[key] = v
	return nil
}

// GetOrCreateSenderTspec retrieves the value of the SenderTspec field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetOrCreateSenderTspec() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec {
	if t.SenderTspec != nil {
		return t.SenderTspec
	}
	t.SenderTspec = &NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec{}
	return t.SenderTspec
}

// GetSenderTspec returns the value of the SenderTspec struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session. If the receiver or the field SenderTspec is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetSenderTspec() *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec {
	if t != nil && t.SenderTspec != nil {
		return t.SenderTspec
	}
	return nil
}

// GetDestinationAddress retrieves the value of the leaf DestinationAddress from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationAddress is set, it can safely use t.GetDestinationAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetDestinationAddress() string {
	if t == nil || t.DestinationAddress == nil {
		return ""
	}
	return *t.DestinationAddress
}

// GetLabelIn retrieves the value of the leaf LabelIn from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LabelIn is set, it can safely use t.GetLabelIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LabelIn == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetLabelIn() NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union {
	if t == nil || t.LabelIn == nil {
		return nil
	}
	return t.LabelIn
}

// GetLabelOut retrieves the value of the leaf LabelOut from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LabelOut is set, it can safely use t.GetLabelOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LabelOut == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetLabelOut() NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union {
	if t == nil || t.LabelOut == nil {
		return nil
	}
	return t.LabelOut
}

// GetLocalIndex retrieves the value of the leaf LocalIndex from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIndex is set, it can safely use t.GetLocalIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetLocalIndex() uint64 {
	if t == nil || t.LocalIndex == nil {
		return 0
	}
	return *t.LocalIndex
}

// GetLspId retrieves the value of the leaf LspId from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspId is set, it can safely use t.GetLspId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetLspId() uint16 {
	if t == nil || t.LspId == nil {
		return 0
	}
	return *t.LspId
}

// GetProtectionRequested retrieves the value of the leaf ProtectionRequested from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ProtectionRequested is set, it can safely use t.GetProtectionRequested()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ProtectionRequested == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetProtectionRequested() E_OpenconfigMplsTypes_PROTECTION_TYPE {
	if t == nil || t.ProtectionRequested == 0 {
		return 0
	}
	return t.ProtectionRequested
}

// GetSessionName retrieves the value of the leaf SessionName from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SessionName is set, it can safely use t.GetSessionName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SessionName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetSessionName() string {
	if t == nil || t.SessionName == nil {
		return ""
	}
	return *t.SessionName
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// GetStatus retrieves the value of the leaf Status from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Status is set, it can safely use t.GetStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Status == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetStatus() E_Session_Status {
	if t == nil || t.Status == 0 {
		return 0
	}
	return t.Status
}

// GetTunnelId retrieves the value of the leaf TunnelId from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TunnelId is set, it can safely use t.GetTunnelId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TunnelId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetTunnelId() uint16 {
	if t == nil || t.TunnelId == nil {
		return 0
	}
	return *t.TunnelId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) GetType() E_OpenconfigMplsTypes_LSP_ROLE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalIndex == nil {
		return nil, fmt.Errorf("nil value for key LocalIndex")
	}

	return map[string]interface{}{
		"local-index": *t.LocalIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-in within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelIn_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-out within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session) To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_LabelOut_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject struct {
	ΛMetadata    []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	Asn          *uint32                                                                                `path:"state/asn" module:"openconfig-network-instance"`
	ΛAsn         []ygot.Annotation                                                                      `path:"state/@asn" ygotAnnotation:"true"`
	Index        *uint64                                                                                `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex       []ygot.Annotation                                                                      `path:"state/@index|@index" ygotAnnotation:"true"`
	InterfaceId  *uint32                                                                                `path:"state/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId []ygot.Annotation                                                                      `path:"state/@interface-id" ygotAnnotation:"true"`
	IpPrefix     *string                                                                                `path:"state/ip-prefix" module:"openconfig-network-instance"`
	ΛIpPrefix    []ygot.Annotation                                                                      `path:"state/@ip-prefix" ygotAnnotation:"true"`
	Label        NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union `path:"state/label" module:"openconfig-network-instance"`
	ΛLabel       []ygot.Annotation                                                                      `path:"state/@label" ygotAnnotation:"true"`
	Loose        *bool                                                                                  `path:"state/loose" module:"openconfig-network-instance"`
	ΛLoose       []ygot.Annotation                                                                      `path:"state/@loose" ygotAnnotation:"true"`
	Type         E_ExplicitRouteObject_Type                                                             `path:"state/type" module:"openconfig-network-instance"`
	ΛType        []ygot.Annotation                                                                      `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) IsYANGGoStruct() {}

// GetAsn retrieves the value of the leaf Asn from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Asn is set, it can safely use t.GetAsn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Asn == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetAsn() uint32 {
	if t == nil || t.Asn == nil {
		return 0
	}
	return *t.Asn
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetInterfaceId() uint32 {
	if t == nil || t.InterfaceId == nil {
		return 0
	}
	return *t.InterfaceId
}

// GetIpPrefix retrieves the value of the leaf IpPrefix from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpPrefix is set, it can safely use t.GetIpPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpPrefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetIpPrefix() string {
	if t == nil || t.IpPrefix == nil {
		return ""
	}
	return *t.IpPrefix
}

// GetLabel retrieves the value of the leaf Label from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Label is set, it can safely use t.GetLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Label == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetLabel() NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union {
	if t == nil || t.Label == nil {
		return nil
	}
	return t.Label
}

// GetLoose retrieves the value of the leaf Loose from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Loose is set, it can safely use t.GetLoose()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Loose == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetLoose() bool {
	if t == nil || t.Loose == nil {
		return false
	}
	return *t.Loose
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) GetType() E_ExplicitRouteObject_Type {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject) To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_ExplicitRouteObject_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject struct {
	ΛMetadata      []ygot.Annotation                                                                            `path:"@" ygotAnnotation:"true"`
	Address        *string                                                                                      `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress       []ygot.Annotation                                                                            `path:"state/@address" ygotAnnotation:"true"`
	Index          *uint8                                                                                       `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex         []ygot.Annotation                                                                            `path:"state/@index|@index" ygotAnnotation:"true"`
	ReportedFlags  *uint8                                                                                       `path:"state/reported-flags" module:"openconfig-network-instance"`
	ΛReportedFlags []ygot.Annotation                                                                            `path:"state/@reported-flags" ygotAnnotation:"true"`
	ReportedLabel  NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union `path:"state/reported-label" module:"openconfig-network-instance"`
	ΛReportedLabel []ygot.Annotation                                                                            `path:"state/@reported-label" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) GetIndex() uint8 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetReportedFlags retrieves the value of the leaf ReportedFlags from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReportedFlags is set, it can safely use t.GetReportedFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReportedFlags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) GetReportedFlags() uint8 {
	if t == nil || t.ReportedFlags == nil {
		return 0
	}
	return *t.ReportedFlags
}

// GetReportedLabel retrieves the value of the leaf ReportedLabel from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReportedLabel is set, it can safely use t.GetReportedLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReportedLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) GetReportedLabel() NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union {
	if t == nil || t.ReportedLabel == nil {
		return nil
	}
	return t.ReportedLabel
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state/reported-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject) To_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_RecordRouteObject_ReportedLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/sender-tspec YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PeakDataRate  Binary            `path:"peak-data-rate" module:"openconfig-network-instance"`
	ΛPeakDataRate []ygot.Annotation `path:"@peak-data-rate" ygotAnnotation:"true"`
	Rate          Binary            `path:"rate" module:"openconfig-network-instance"`
	ΛRate         []ygot.Annotation `path:"@rate" ygotAnnotation:"true"`
	Size          Binary            `path:"size" module:"openconfig-network-instance"`
	ΛSize         []ygot.Annotation `path:"@size" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec) IsYANGGoStruct() {}

// GetPeakDataRate retrieves the value of the leaf PeakDataRate from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeakDataRate is set, it can safely use t.GetPeakDataRate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeakDataRate == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec) GetPeakDataRate() Binary {
	if t == nil || t.PeakDataRate == nil {
		return nil
	}
	return t.PeakDataRate
}

// GetRate retrieves the value of the leaf Rate from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Rate is set, it can safely use t.GetRate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Rate == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec) GetRate() Binary {
	if t == nil || t.Rate == nil {
		return nil
	}
	return t.Rate
}

// GetSize retrieves the value of the leaf Size from the NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Size is set, it can safely use t.GetSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Size == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec) GetSize() Binary {
	if t == nil || t.Size == nil {
		return nil
	}
	return t.Size
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Session_SenderTspec) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting struct {
	ΛMetadata            []ygot.Annotation                                                                                                                                                          `path:"@" ygotAnnotation:"true"`
	AggregateSidCounter  map[NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter `path:"aggregate-sid-counters/aggregate-sid-counter" module:"openconfig-network-instance"`
	ΛAggregateSidCounter []ygot.Annotation                                                                                                                                                          `path:"aggregate-sid-counters/@aggregate-sid-counter" ygotAnnotation:"true"`
	Interface            map[string]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface                                                                                               `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface           []ygot.Annotation                                                                                                                                                          `path:"interfaces/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) IsYANGGoStruct() {}

// NewAggregateSidCounter creates a new entry in the AggregateSidCounter list of the
// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) NewAggregateSidCounter(MplsLabel NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union) (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AggregateSidCounter == nil {
		t.AggregateSidCounter = make(map[NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter)
	}

	key := MplsLabel

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AggregateSidCounter[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AggregateSidCounter", key)
	}

	t.AggregateSidCounter[key] = &NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter{
		MplsLabel: MplsLabel,
	}

	return t.AggregateSidCounter[key], nil
}

// RenameAggregateSidCounter renames an entry in the list AggregateSidCounter within
// the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) RenameAggregateSidCounter(oldK, newK NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union) error {
	if _, ok := t.AggregateSidCounter[newK]; ok {
		return fmt.Errorf("key %v already exists in AggregateSidCounter", newK)
	}

	e, ok := t.AggregateSidCounter[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AggregateSidCounter", oldK)
	}
	e.MplsLabel = newK

	t.AggregateSidCounter[newK] = e
	delete(t.AggregateSidCounter, oldK)
	return nil
}

// GetOrCreateAggregateSidCounter retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) GetOrCreateAggregateSidCounter(MplsLabel NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter {

	key := MplsLabel

	if v, ok := t.AggregateSidCounter[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAggregateSidCounter(MplsLabel)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAggregateSidCounter got unexpected error: %v", err))
	}
	return v
}

// GetAggregateSidCounter retrieves the value with the specified key from
// the AggregateSidCounter map field of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) GetAggregateSidCounter(MplsLabel NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter {

	if t == nil {
		return nil
	}

	key := MplsLabel

	if lm, ok := t.AggregateSidCounter[key]; ok {
		return lm
	}
	return nil
}

// AppendAggregateSidCounter appends the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter struct to the
// list AggregateSidCounter of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) AppendAggregateSidCounter(v *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) error {
	key := v.MplsLabel

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AggregateSidCounter == nil {
		t.AggregateSidCounter = make(map[NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter)
	}

	if _, ok := t.AggregateSidCounter[key]; ok {
		return fmt.Errorf("duplicate key for list AggregateSidCounter %v", key)
	}

	t.AggregateSidCounter[key] = v
	return nil
}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) NewInterface(InterfaceId string) (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) GetInterface(InterfaceId string) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface struct to the
// list Interface of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) AppendInterface(v *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter struct {
	ΛMetadata  []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	InOctets   *uint64                                                                                    `path:"state/in-octets" module:"openconfig-network-instance"`
	ΛInOctets  []ygot.Annotation                                                                          `path:"state/@in-octets" ygotAnnotation:"true"`
	InPkts     *uint64                                                                                    `path:"state/in-pkts" module:"openconfig-network-instance"`
	ΛInPkts    []ygot.Annotation                                                                          `path:"state/@in-pkts" ygotAnnotation:"true"`
	MplsLabel  NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union `path:"state/mpls-label|mpls-label" module:"openconfig-network-instance"`
	ΛMplsLabel []ygot.Annotation                                                                          `path:"state/@mpls-label|@mpls-label" ygotAnnotation:"true"`
	OutOctets  *uint64                                                                                    `path:"state/out-octets" module:"openconfig-network-instance"`
	ΛOutOctets []ygot.Annotation                                                                          `path:"state/@out-octets" ygotAnnotation:"true"`
	OutPkts    *uint64                                                                                    `path:"state/out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts   []ygot.Annotation                                                                          `path:"state/@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) IsYANGGoStruct() {}

// GetInOctets retrieves the value of the leaf InOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetMplsLabel retrieves the value of the leaf MplsLabel from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsLabel is set, it can safely use t.GetMplsLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) GetMplsLabel() NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union {
	if t == nil || t.MplsLabel == nil {
		return nil
	}
	return t.MplsLabel
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"mpls-label": t.MplsLabel,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/state/mpls-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter) To_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounter_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface struct {
	ΛMetadata     []ygot.Annotation                                                                                                                                                            `path:"@" ygotAnnotation:"true"`
	InOctets      *uint64                                                                                                                                                                      `path:"state/in-octets" module:"openconfig-network-instance"`
	ΛInOctets     []ygot.Annotation                                                                                                                                                            `path:"state/@in-octets" ygotAnnotation:"true"`
	InPkts        *uint64                                                                                                                                                                      `path:"state/in-pkts" module:"openconfig-network-instance"`
	ΛInPkts       []ygot.Annotation                                                                                                                                                            `path:"state/@in-pkts" ygotAnnotation:"true"`
	InterfaceId   *string                                                                                                                                                                      `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId  []ygot.Annotation                                                                                                                                                            `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef  *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef                                                                                               `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef []ygot.Annotation                                                                                                                                                            `path:"@interface-ref" ygotAnnotation:"true"`
	OutOctets     *uint64                                                                                                                                                                      `path:"state/out-octets" module:"openconfig-network-instance"`
	ΛOutOctets    []ygot.Annotation                                                                                                                                                            `path:"state/@out-octets" ygotAnnotation:"true"`
	OutPkts       *uint64                                                                                                                                                                      `path:"state/out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts      []ygot.Annotation                                                                                                                                                            `path:"state/@out-pkts" ygotAnnotation:"true"`
	SidCounter    map[NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter `path:"sid-counters/sid-counter" module:"openconfig-network-instance"`
	ΛSidCounter   []ygot.Annotation                                                                                                                                                            `path:"sid-counters/@sid-counter" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) IsYANGGoStruct() {}

// NewSidCounter creates a new entry in the SidCounter list of the
// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) NewSidCounter(MplsLabel NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union) (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SidCounter == nil {
		t.SidCounter = make(map[NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter)
	}

	key := MplsLabel

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SidCounter[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SidCounter", key)
	}

	t.SidCounter[key] = &NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter{
		MplsLabel: MplsLabel,
	}

	return t.SidCounter[key], nil
}

// RenameSidCounter renames an entry in the list SidCounter within
// the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) RenameSidCounter(oldK, newK NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union) error {
	if _, ok := t.SidCounter[newK]; ok {
		return fmt.Errorf("key %v already exists in SidCounter", newK)
	}

	e, ok := t.SidCounter[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SidCounter", oldK)
	}
	e.MplsLabel = newK

	t.SidCounter[newK] = e
	delete(t.SidCounter, oldK)
	return nil
}

// GetOrCreateSidCounter retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetOrCreateSidCounter(MplsLabel NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter {

	key := MplsLabel

	if v, ok := t.SidCounter[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSidCounter(MplsLabel)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSidCounter got unexpected error: %v", err))
	}
	return v
}

// GetSidCounter retrieves the value with the specified key from
// the SidCounter map field of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetSidCounter(MplsLabel NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter {

	if t == nil {
		return nil
	}

	key := MplsLabel

	if lm, ok := t.SidCounter[key]; ok {
		return lm
	}
	return nil
}

// AppendSidCounter appends the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter struct to the
// list SidCounter of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) AppendSidCounter(v *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) error {
	key := v.MplsLabel

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SidCounter == nil {
		t.SidCounter = make(map[NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter)
	}

	if _, ok := t.SidCounter[key]; ok {
		return fmt.Errorf("duplicate key for list SidCounter %v", key)
	}

	t.SidCounter[key] = v
	return nil
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetInterfaceRef() *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetInOctets retrieves the value of the leaf InOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef) IsYANGGoStruct() {
}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter struct {
	ΛMetadata        []ygot.Annotation                                                                                      `path:"@" ygotAnnotation:"true"`
	ForwardingClass  map[uint8]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass `path:"forwarding-classes/forwarding-class" module:"openconfig-network-instance"`
	ΛForwardingClass []ygot.Annotation                                                                                      `path:"forwarding-classes/@forwarding-class" ygotAnnotation:"true"`
	InOctets         *uint64                                                                                                `path:"state/in-octets" module:"openconfig-network-instance"`
	ΛInOctets        []ygot.Annotation                                                                                      `path:"state/@in-octets" ygotAnnotation:"true"`
	InPkts           *uint64                                                                                                `path:"state/in-pkts" module:"openconfig-network-instance"`
	ΛInPkts          []ygot.Annotation                                                                                      `path:"state/@in-pkts" ygotAnnotation:"true"`
	MplsLabel        NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union            `path:"state/mpls-label|mpls-label" module:"openconfig-network-instance"`
	ΛMplsLabel       []ygot.Annotation                                                                                      `path:"state/@mpls-label|@mpls-label" ygotAnnotation:"true"`
	OutOctets        *uint64                                                                                                `path:"state/out-octets" module:"openconfig-network-instance"`
	ΛOutOctets       []ygot.Annotation                                                                                      `path:"state/@out-octets" ygotAnnotation:"true"`
	OutPkts          *uint64                                                                                                `path:"state/out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts         []ygot.Annotation                                                                                      `path:"state/@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) IsYANGGoStruct() {
}

// NewForwardingClass creates a new entry in the ForwardingClass list of the
// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) NewForwardingClass(Exp uint8) (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ForwardingClass == nil {
		t.ForwardingClass = make(map[uint8]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass)
	}

	key := Exp

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ForwardingClass[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ForwardingClass", key)
	}

	t.ForwardingClass[key] = &NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass{
		Exp: &Exp,
	}

	return t.ForwardingClass[key], nil
}

// RenameForwardingClass renames an entry in the list ForwardingClass within
// the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) RenameForwardingClass(oldK, newK uint8) error {
	if _, ok := t.ForwardingClass[newK]; ok {
		return fmt.Errorf("key %v already exists in ForwardingClass", newK)
	}

	e, ok := t.ForwardingClass[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ForwardingClass", oldK)
	}
	e.Exp = &newK

	t.ForwardingClass[newK] = e
	delete(t.ForwardingClass, oldK)
	return nil
}

// GetOrCreateForwardingClass retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetOrCreateForwardingClass(Exp uint8) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass {

	key := Exp

	if v, ok := t.ForwardingClass[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewForwardingClass(Exp)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateForwardingClass got unexpected error: %v", err))
	}
	return v
}

// GetForwardingClass retrieves the value with the specified key from
// the ForwardingClass map field of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetForwardingClass(Exp uint8) *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass {

	if t == nil {
		return nil
	}

	key := Exp

	if lm, ok := t.ForwardingClass[key]; ok {
		return lm
	}
	return nil
}

// AppendForwardingClass appends the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass struct to the
// list ForwardingClass of NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) AppendForwardingClass(v *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) error {
	if v.Exp == nil {
		return fmt.Errorf("invalid nil key received for Exp")
	}

	key := *v.Exp

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ForwardingClass == nil {
		t.ForwardingClass = make(map[uint8]*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass)
	}

	if _, ok := t.ForwardingClass[key]; ok {
		return fmt.Errorf("duplicate key for list ForwardingClass %v", key)
	}

	t.ForwardingClass[key] = v
	return nil
}

// GetInOctets retrieves the value of the leaf InOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetMplsLabel retrieves the value of the leaf MplsLabel from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsLabel is set, it can safely use t.GetMplsLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetMplsLabel() NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union {
	if t == nil || t.MplsLabel == nil {
		return nil
	}
	return t.MplsLabel
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"mpls-label": t.MplsLabel,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/state/mpls-label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union()
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union() {
}

// Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union ensures that UnionUint32
// implements the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union() {
}

// To_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter) To_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union(i interface{}) (NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union, error) {
	if v, ok := i.(NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/forwarding-classes/forwarding-class YANG schema element.
type NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Exp        *uint8            `path:"state/exp|exp" module:"openconfig-network-instance"`
	ΛExp       []ygot.Annotation `path:"state/@exp|@exp" ygotAnnotation:"true"`
	InOctets   *uint64           `path:"state/in-octets" module:"openconfig-network-instance"`
	ΛInOctets  []ygot.Annotation `path:"state/@in-octets" ygotAnnotation:"true"`
	InPkts     *uint64           `path:"state/in-pkts" module:"openconfig-network-instance"`
	ΛInPkts    []ygot.Annotation `path:"state/@in-pkts" ygotAnnotation:"true"`
	OutOctets  *uint64           `path:"state/out-octets" module:"openconfig-network-instance"`
	ΛOutOctets []ygot.Annotation `path:"state/@out-octets" ygotAnnotation:"true"`
	OutPkts    *uint64           `path:"state/out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts   []ygot.Annotation `path:"state/@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) IsYANGGoStruct() {
}

// GetExp retrieves the value of the leaf Exp from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Exp is set, it can safely use t.GetExp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Exp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) GetExp() uint8 {
	if t == nil || t.Exp == nil {
		return 0
	}
	return *t.Exp
}

// GetInOctets retrieves the value of the leaf InOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Exp == nil {
		return nil, fmt.Errorf("nil value for key Exp")
	}

	return map[string]interface{}{
		"exp": *t.Exp,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interface_SidCounter_ForwardingClass) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_TeGlobalAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes YANG schema element.
type NetworkInstance_Mpls_TeGlobalAttributes struct {
	ΛMetadata    []ygot.Annotation                                              `path:"@" ygotAnnotation:"true"`
	AdminGroup   map[string]*NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup `path:"mpls-admin-groups/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup  []ygot.Annotation                                              `path:"mpls-admin-groups/@admin-group" ygotAnnotation:"true"`
	Srlg         map[string]*NetworkInstance_Mpls_TeGlobalAttributes_Srlg       `path:"srlgs/srlg" module:"openconfig-network-instance"`
	ΛSrlg        []ygot.Annotation                                              `path:"srlgs/@srlg" ygotAnnotation:"true"`
	TeLspTimers  *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers           `path:"te-lsp-timers" module:"openconfig-network-instance"`
	ΛTeLspTimers []ygot.Annotation                                              `path:"@te-lsp-timers" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_TeGlobalAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_TeGlobalAttributes) IsYANGGoStruct() {}

// NewAdminGroup creates a new entry in the AdminGroup list of the
// NetworkInstance_Mpls_TeGlobalAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) NewAdminGroup(AdminGroupName string) (*NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdminGroup == nil {
		t.AdminGroup = make(map[string]*NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup)
	}

	key := AdminGroupName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdminGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdminGroup", key)
	}

	t.AdminGroup[key] = &NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup{
		AdminGroupName: &AdminGroupName,
	}

	return t.AdminGroup[key], nil
}

// RenameAdminGroup renames an entry in the list AdminGroup within
// the NetworkInstance_Mpls_TeGlobalAttributes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) RenameAdminGroup(oldK, newK string) error {
	if _, ok := t.AdminGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in AdminGroup", newK)
	}

	e, ok := t.AdminGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdminGroup", oldK)
	}
	e.AdminGroupName = &newK

	t.AdminGroup[newK] = e
	delete(t.AdminGroup, oldK)
	return nil
}

// GetOrCreateAdminGroup retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_TeGlobalAttributes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) GetOrCreateAdminGroup(AdminGroupName string) *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup {

	key := AdminGroupName

	if v, ok := t.AdminGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdminGroup(AdminGroupName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdminGroup got unexpected error: %v", err))
	}
	return v
}

// GetAdminGroup retrieves the value with the specified key from
// the AdminGroup map field of NetworkInstance_Mpls_TeGlobalAttributes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) GetAdminGroup(AdminGroupName string) *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup {

	if t == nil {
		return nil
	}

	key := AdminGroupName

	if lm, ok := t.AdminGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendAdminGroup appends the supplied NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup struct to the
// list AdminGroup of NetworkInstance_Mpls_TeGlobalAttributes. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) AppendAdminGroup(v *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) error {
	if v.AdminGroupName == nil {
		return fmt.Errorf("invalid nil key received for AdminGroupName")
	}

	key := *v.AdminGroupName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdminGroup == nil {
		t.AdminGroup = make(map[string]*NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup)
	}

	if _, ok := t.AdminGroup[key]; ok {
		return fmt.Errorf("duplicate key for list AdminGroup %v", key)
	}

	t.AdminGroup[key] = v
	return nil
}

// NewSrlg creates a new entry in the Srlg list of the
// NetworkInstance_Mpls_TeGlobalAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) NewSrlg(Name string) (*NetworkInstance_Mpls_TeGlobalAttributes_Srlg, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srlg == nil {
		t.Srlg = make(map[string]*NetworkInstance_Mpls_TeGlobalAttributes_Srlg)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Srlg[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Srlg", key)
	}

	t.Srlg[key] = &NetworkInstance_Mpls_TeGlobalAttributes_Srlg{
		Name: &Name,
	}

	return t.Srlg[key], nil
}

// RenameSrlg renames an entry in the list Srlg within
// the NetworkInstance_Mpls_TeGlobalAttributes struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) RenameSrlg(oldK, newK string) error {
	if _, ok := t.Srlg[newK]; ok {
		return fmt.Errorf("key %v already exists in Srlg", newK)
	}

	e, ok := t.Srlg[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Srlg", oldK)
	}
	e.Name = &newK

	t.Srlg[newK] = e
	delete(t.Srlg, oldK)
	return nil
}

// GetOrCreateSrlg retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_TeGlobalAttributes. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) GetOrCreateSrlg(Name string) *NetworkInstance_Mpls_TeGlobalAttributes_Srlg {

	key := Name

	if v, ok := t.Srlg[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSrlg(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSrlg got unexpected error: %v", err))
	}
	return v
}

// GetSrlg retrieves the value with the specified key from
// the Srlg map field of NetworkInstance_Mpls_TeGlobalAttributes. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) GetSrlg(Name string) *NetworkInstance_Mpls_TeGlobalAttributes_Srlg {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Srlg[key]; ok {
		return lm
	}
	return nil
}

// AppendSrlg appends the supplied NetworkInstance_Mpls_TeGlobalAttributes_Srlg struct to the
// list Srlg of NetworkInstance_Mpls_TeGlobalAttributes. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_TeGlobalAttributes_Srlg already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) AppendSrlg(v *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srlg == nil {
		t.Srlg = make(map[string]*NetworkInstance_Mpls_TeGlobalAttributes_Srlg)
	}

	if _, ok := t.Srlg[key]; ok {
		return fmt.Errorf("duplicate key for list Srlg %v", key)
	}

	t.Srlg[key] = v
	return nil
}

// GetOrCreateTeLspTimers retrieves the value of the TeLspTimers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) GetOrCreateTeLspTimers() *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers {
	if t.TeLspTimers != nil {
		return t.TeLspTimers
	}
	t.TeLspTimers = &NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers{}
	return t.TeLspTimers
}

// GetTeLspTimers returns the value of the TeLspTimers struct pointer
// from NetworkInstance_Mpls_TeGlobalAttributes. If the receiver or the field TeLspTimers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) GetTeLspTimers() *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers {
	if t != nil && t.TeLspTimers != nil {
		return t.TeLspTimers
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_TeGlobalAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_TeGlobalAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/mpls-admin-groups/admin-group YANG schema element.
type NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup struct {
	ΛMetadata       []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdminGroupName  *string           `path:"state/admin-group-name|admin-group-name" shadow-path:"config/admin-group-name" module:"openconfig-network-instance"`
	ΛAdminGroupName []ygot.Annotation `path:"state/@admin-group-name|@admin-group-name" ygotAnnotation:"true"`
	BitPosition     *uint32           `path:"state/bit-position" shadow-path:"config/bit-position" module:"openconfig-network-instance"`
	ΛBitPosition    []ygot.Annotation `path:"state/@bit-position" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) IsYANGGoStruct() {}

// GetAdminGroupName retrieves the value of the leaf AdminGroupName from the NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminGroupName is set, it can safely use t.GetAdminGroupName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminGroupName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) GetAdminGroupName() string {
	if t == nil || t.AdminGroupName == nil {
		return ""
	}
	return *t.AdminGroupName
}

// GetBitPosition retrieves the value of the leaf BitPosition from the NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BitPosition is set, it can safely use t.GetBitPosition()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BitPosition == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) GetBitPosition() uint32 {
	if t == nil || t.BitPosition == nil {
		return 0
	}
	return *t.BitPosition
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AdminGroupName == nil {
		return nil, fmt.Errorf("nil value for key AdminGroupName")
	}

	return map[string]interface{}{
		"admin-group-name": *t.AdminGroupName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_TeGlobalAttributes_Srlg represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg YANG schema element.
type NetworkInstance_Mpls_TeGlobalAttributes_Srlg struct {
	ΛMetadata     []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	Cost          *uint32                                                              `path:"state/cost" shadow-path:"config/cost" module:"openconfig-network-instance"`
	ΛCost         []ygot.Annotation                                                    `path:"state/@cost" ygotAnnotation:"true"`
	FloodingType  E_OpenconfigMpls_MplsSrlgFloodingType                                `path:"state/flooding-type" shadow-path:"config/flooding-type" module:"openconfig-network-instance"`
	ΛFloodingType []ygot.Annotation                                                    `path:"state/@flooding-type" ygotAnnotation:"true"`
	MembersList   map[string]*NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList `path:"static-srlg-members/members-list" module:"openconfig-network-instance"`
	ΛMembersList  []ygot.Annotation                                                    `path:"static-srlg-members/@members-list" ygotAnnotation:"true"`
	Name          *string                                                              `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName         []ygot.Annotation                                                    `path:"state/@name|@name" ygotAnnotation:"true"`
	Value         *uint32                                                              `path:"state/value" shadow-path:"config/value" module:"openconfig-network-instance"`
	ΛValue        []ygot.Annotation                                                    `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_TeGlobalAttributes_Srlg implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_TeGlobalAttributes_Srlg) IsYANGGoStruct() {}

// NewMembersList creates a new entry in the MembersList list of the
// NetworkInstance_Mpls_TeGlobalAttributes_Srlg struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) NewMembersList(FromAddress string) (*NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MembersList == nil {
		t.MembersList = make(map[string]*NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList)
	}

	key := FromAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.MembersList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list MembersList", key)
	}

	t.MembersList[key] = &NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList{
		FromAddress: &FromAddress,
	}

	return t.MembersList[key], nil
}

// RenameMembersList renames an entry in the list MembersList within
// the NetworkInstance_Mpls_TeGlobalAttributes_Srlg struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) RenameMembersList(oldK, newK string) error {
	if _, ok := t.MembersList[newK]; ok {
		return fmt.Errorf("key %v already exists in MembersList", newK)
	}

	e, ok := t.MembersList[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in MembersList", oldK)
	}
	e.FromAddress = &newK

	t.MembersList[newK] = e
	delete(t.MembersList, oldK)
	return nil
}

// GetOrCreateMembersList retrieves the value with the specified keys from
// the receiver NetworkInstance_Mpls_TeGlobalAttributes_Srlg. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) GetOrCreateMembersList(FromAddress string) *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList {

	key := FromAddress

	if v, ok := t.MembersList[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewMembersList(FromAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateMembersList got unexpected error: %v", err))
	}
	return v
}

// GetMembersList retrieves the value with the specified key from
// the MembersList map field of NetworkInstance_Mpls_TeGlobalAttributes_Srlg. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) GetMembersList(FromAddress string) *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList {

	if t == nil {
		return nil
	}

	key := FromAddress

	if lm, ok := t.MembersList[key]; ok {
		return lm
	}
	return nil
}

// AppendMembersList appends the supplied NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList struct to the
// list MembersList of NetworkInstance_Mpls_TeGlobalAttributes_Srlg. If the key value(s) specified in
// the supplied NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList already exist in the list, an error is
// returned.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) AppendMembersList(v *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) error {
	if v.FromAddress == nil {
		return fmt.Errorf("invalid nil key received for FromAddress")
	}

	key := *v.FromAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MembersList == nil {
		t.MembersList = make(map[string]*NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList)
	}

	if _, ok := t.MembersList[key]; ok {
		return fmt.Errorf("duplicate key for list MembersList %v", key)
	}

	t.MembersList[key] = v
	return nil
}

// GetCost retrieves the value of the leaf Cost from the NetworkInstance_Mpls_TeGlobalAttributes_Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Cost is set, it can safely use t.GetCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Cost == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) GetCost() uint32 {
	if t == nil || t.Cost == nil {
		return 0
	}
	return *t.Cost
}

// GetFloodingType retrieves the value of the leaf FloodingType from the NetworkInstance_Mpls_TeGlobalAttributes_Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FloodingType is set, it can safely use t.GetFloodingType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FloodingType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) GetFloodingType() E_OpenconfigMpls_MplsSrlgFloodingType {
	if t == nil || t.FloodingType == 0 {
		return OpenconfigMpls_MplsSrlgFloodingType_FLOODED_SRLG
	}
	return t.FloodingType
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Mpls_TeGlobalAttributes_Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Mpls_TeGlobalAttributes_Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_TeGlobalAttributes_Srlg struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_TeGlobalAttributes_Srlg"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/static-srlg-members/members-list YANG schema element.
type NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	FromAddress  *string           `path:"state/from-address|from-address" shadow-path:"config/from-address" module:"openconfig-network-instance"`
	ΛFromAddress []ygot.Annotation `path:"state/@from-address|@from-address" ygotAnnotation:"true"`
	ToAddress    *string           `path:"state/to-address" shadow-path:"config/to-address" module:"openconfig-network-instance"`
	ΛToAddress   []ygot.Annotation `path:"state/@to-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) IsYANGGoStruct() {}

// GetFromAddress retrieves the value of the leaf FromAddress from the NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FromAddress is set, it can safely use t.GetFromAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FromAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) GetFromAddress() string {
	if t == nil || t.FromAddress == nil {
		return ""
	}
	return *t.FromAddress
}

// GetToAddress retrieves the value of the leaf ToAddress from the NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ToAddress is set, it can safely use t.GetToAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ToAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) GetToAddress() string {
	if t == nil || t.ToAddress == nil {
		return ""
	}
	return *t.ToAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList struct, which is a YANG list entry.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.FromAddress == nil {
		return nil, fmt.Errorf("nil value for key FromAddress")
	}

	return map[string]interface{}{
		"from-address": *t.FromAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_Srlg_MembersList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/te-lsp-timers YANG schema element.
type NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CleanupDelay     *uint16           `path:"state/cleanup-delay" shadow-path:"config/cleanup-delay" module:"openconfig-network-instance"`
	ΛCleanupDelay    []ygot.Annotation `path:"state/@cleanup-delay" ygotAnnotation:"true"`
	InstallDelay     *uint16           `path:"state/install-delay" shadow-path:"config/install-delay" module:"openconfig-network-instance"`
	ΛInstallDelay    []ygot.Annotation `path:"state/@install-delay" ygotAnnotation:"true"`
	ReoptimizeTimer  *uint16           `path:"state/reoptimize-timer" shadow-path:"config/reoptimize-timer" module:"openconfig-network-instance"`
	ΛReoptimizeTimer []ygot.Annotation `path:"state/@reoptimize-timer" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) IsYANGGoStruct() {}

// GetCleanupDelay retrieves the value of the leaf CleanupDelay from the NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CleanupDelay is set, it can safely use t.GetCleanupDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CleanupDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) GetCleanupDelay() uint16 {
	if t == nil || t.CleanupDelay == nil {
		return 0
	}
	return *t.CleanupDelay
}

// GetInstallDelay retrieves the value of the leaf InstallDelay from the NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstallDelay is set, it can safely use t.GetInstallDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstallDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) GetInstallDelay() uint16 {
	if t == nil || t.InstallDelay == nil {
		return 0
	}
	return *t.InstallDelay
}

// GetReoptimizeTimer retrieves the value of the leaf ReoptimizeTimer from the NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReoptimizeTimer is set, it can safely use t.GetReoptimizeTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReoptimizeTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) GetReoptimizeTimer() uint16 {
	if t == nil || t.ReoptimizeTimer == nil {
		return 0
	}
	return *t.ReoptimizeTimer
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding YANG schema element.
type NetworkInstance_PolicyForwarding struct {
	ΛMetadata           []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	Interface           map[string]*NetworkInstance_PolicyForwarding_Interface          `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface          []ygot.Annotation                                               `path:"interfaces/@interface" ygotAnnotation:"true"`
	PathSelectionGroup  map[string]*NetworkInstance_PolicyForwarding_PathSelectionGroup `path:"path-selection-groups/path-selection-group" module:"openconfig-network-instance"`
	ΛPathSelectionGroup []ygot.Annotation                                               `path:"path-selection-groups/@path-selection-group" ygotAnnotation:"true"`
	Policy              map[string]*NetworkInstance_PolicyForwarding_Policy             `path:"policies/policy" module:"openconfig-network-instance"`
	ΛPolicy             []ygot.Annotation                                               `path:"policies/@policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_PolicyForwarding struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_PolicyForwarding) NewInterface(InterfaceId string) (*NetworkInstance_PolicyForwarding_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_PolicyForwarding_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_PolicyForwarding_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_PolicyForwarding struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_PolicyForwarding) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_PolicyForwarding. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_PolicyForwarding) GetOrCreateInterface(InterfaceId string) *NetworkInstance_PolicyForwarding_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_PolicyForwarding. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_PolicyForwarding) GetInterface(InterfaceId string) *NetworkInstance_PolicyForwarding_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_PolicyForwarding_Interface struct to the
// list Interface of NetworkInstance_PolicyForwarding. If the key value(s) specified in
// the supplied NetworkInstance_PolicyForwarding_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_PolicyForwarding) AppendInterface(v *NetworkInstance_PolicyForwarding_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_PolicyForwarding_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewPathSelectionGroup creates a new entry in the PathSelectionGroup list of the
// NetworkInstance_PolicyForwarding struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_PolicyForwarding) NewPathSelectionGroup(GroupId string) (*NetworkInstance_PolicyForwarding_PathSelectionGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PathSelectionGroup == nil {
		t.PathSelectionGroup = make(map[string]*NetworkInstance_PolicyForwarding_PathSelectionGroup)
	}

	key := GroupId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PathSelectionGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PathSelectionGroup", key)
	}

	t.PathSelectionGroup[key] = &NetworkInstance_PolicyForwarding_PathSelectionGroup{
		GroupId: &GroupId,
	}

	return t.PathSelectionGroup[key], nil
}

// RenamePathSelectionGroup renames an entry in the list PathSelectionGroup within
// the NetworkInstance_PolicyForwarding struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_PolicyForwarding) RenamePathSelectionGroup(oldK, newK string) error {
	if _, ok := t.PathSelectionGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in PathSelectionGroup", newK)
	}

	e, ok := t.PathSelectionGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PathSelectionGroup", oldK)
	}
	e.GroupId = &newK

	t.PathSelectionGroup[newK] = e
	delete(t.PathSelectionGroup, oldK)
	return nil
}

// GetOrCreatePathSelectionGroup retrieves the value with the specified keys from
// the receiver NetworkInstance_PolicyForwarding. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_PolicyForwarding) GetOrCreatePathSelectionGroup(GroupId string) *NetworkInstance_PolicyForwarding_PathSelectionGroup {

	key := GroupId

	if v, ok := t.PathSelectionGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPathSelectionGroup(GroupId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePathSelectionGroup got unexpected error: %v", err))
	}
	return v
}

// GetPathSelectionGroup retrieves the value with the specified key from
// the PathSelectionGroup map field of NetworkInstance_PolicyForwarding. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_PolicyForwarding) GetPathSelectionGroup(GroupId string) *NetworkInstance_PolicyForwarding_PathSelectionGroup {

	if t == nil {
		return nil
	}

	key := GroupId

	if lm, ok := t.PathSelectionGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendPathSelectionGroup appends the supplied NetworkInstance_PolicyForwarding_PathSelectionGroup struct to the
// list PathSelectionGroup of NetworkInstance_PolicyForwarding. If the key value(s) specified in
// the supplied NetworkInstance_PolicyForwarding_PathSelectionGroup already exist in the list, an error is
// returned.
func (t *NetworkInstance_PolicyForwarding) AppendPathSelectionGroup(v *NetworkInstance_PolicyForwarding_PathSelectionGroup) error {
	if v.GroupId == nil {
		return fmt.Errorf("invalid nil key received for GroupId")
	}

	key := *v.GroupId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PathSelectionGroup == nil {
		t.PathSelectionGroup = make(map[string]*NetworkInstance_PolicyForwarding_PathSelectionGroup)
	}

	if _, ok := t.PathSelectionGroup[key]; ok {
		return fmt.Errorf("duplicate key for list PathSelectionGroup %v", key)
	}

	t.PathSelectionGroup[key] = v
	return nil
}

// NewPolicy creates a new entry in the Policy list of the
// NetworkInstance_PolicyForwarding struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_PolicyForwarding) NewPolicy(PolicyId string) (*NetworkInstance_PolicyForwarding_Policy, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Policy == nil {
		t.Policy = make(map[string]*NetworkInstance_PolicyForwarding_Policy)
	}

	key := PolicyId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Policy[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Policy", key)
	}

	t.Policy[key] = &NetworkInstance_PolicyForwarding_Policy{
		PolicyId: &PolicyId,
	}

	return t.Policy[key], nil
}

// RenamePolicy renames an entry in the list Policy within
// the NetworkInstance_PolicyForwarding struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_PolicyForwarding) RenamePolicy(oldK, newK string) error {
	if _, ok := t.Policy[newK]; ok {
		return fmt.Errorf("key %v already exists in Policy", newK)
	}

	e, ok := t.Policy[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Policy", oldK)
	}
	e.PolicyId = &newK

	t.Policy[newK] = e
	delete(t.Policy, oldK)
	return nil
}

// GetOrCreatePolicy retrieves the value with the specified keys from
// the receiver NetworkInstance_PolicyForwarding. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_PolicyForwarding) GetOrCreatePolicy(PolicyId string) *NetworkInstance_PolicyForwarding_Policy {

	key := PolicyId

	if v, ok := t.Policy[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPolicy(PolicyId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePolicy got unexpected error: %v", err))
	}
	return v
}

// GetPolicy retrieves the value with the specified key from
// the Policy map field of NetworkInstance_PolicyForwarding. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_PolicyForwarding) GetPolicy(PolicyId string) *NetworkInstance_PolicyForwarding_Policy {

	if t == nil {
		return nil
	}

	key := PolicyId

	if lm, ok := t.Policy[key]; ok {
		return lm
	}
	return nil
}

// AppendPolicy appends the supplied NetworkInstance_PolicyForwarding_Policy struct to the
// list Policy of NetworkInstance_PolicyForwarding. If the key value(s) specified in
// the supplied NetworkInstance_PolicyForwarding_Policy already exist in the list, an error is
// returned.
func (t *NetworkInstance_PolicyForwarding) AppendPolicy(v *NetworkInstance_PolicyForwarding_Policy) error {
	if v.PolicyId == nil {
		return fmt.Errorf("invalid nil key received for PolicyId")
	}

	key := *v.PolicyId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Policy == nil {
		t.Policy = make(map[string]*NetworkInstance_PolicyForwarding_Policy)
	}

	if _, ok := t.Policy[key]; ok {
		return fmt.Errorf("duplicate key for list Policy %v", key)
	}

	t.Policy[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Interface represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface YANG schema element.
type NetworkInstance_PolicyForwarding_Interface struct {
	ΛMetadata              []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	ApplyForwardingPolicy  *string                                                  `path:"state/apply-forwarding-policy" shadow-path:"config/apply-forwarding-policy" module:"openconfig-network-instance"`
	ΛApplyForwardingPolicy []ygot.Annotation                                        `path:"state/@apply-forwarding-policy" ygotAnnotation:"true"`
	InterfaceId            *string                                                  `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId           []ygot.Annotation                                        `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef           *NetworkInstance_PolicyForwarding_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef          []ygot.Annotation                                        `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Interface) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Interface) GetOrCreateInterfaceRef() *NetworkInstance_PolicyForwarding_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_PolicyForwarding_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_PolicyForwarding_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Interface) GetInterfaceRef() *NetworkInstance_PolicyForwarding_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetApplyForwardingPolicy retrieves the value of the leaf ApplyForwardingPolicy from the NetworkInstance_PolicyForwarding_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ApplyForwardingPolicy is set, it can safely use t.GetApplyForwardingPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ApplyForwardingPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Interface) GetApplyForwardingPolicy() string {
	if t == nil || t.ApplyForwardingPolicy == nil {
		return ""
	}
	return *t.ApplyForwardingPolicy
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_PolicyForwarding_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// ΛListKeyMap returns the keys of the NetworkInstance_PolicyForwarding_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_PolicyForwarding_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_PolicyForwarding_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_PolicyForwarding_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_PolicyForwarding_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_PathSelectionGroup represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/path-selection-groups/path-selection-group YANG schema element.
type NetworkInstance_PolicyForwarding_PathSelectionGroup struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	GroupId   *string           `path:"state/group-id|group-id" shadow-path:"config/group-id" module:"openconfig-network-instance"`
	ΛGroupId  []ygot.Annotation `path:"state/@group-id|@group-id" ygotAnnotation:"true"`
	MplsLsp   []string          `path:"state/mpls-lsp" shadow-path:"config/mpls-lsp" module:"openconfig-network-instance"`
	ΛMplsLsp  []ygot.Annotation `path:"state/@mpls-lsp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_PathSelectionGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_PathSelectionGroup) IsYANGGoStruct() {}

// GetGroupId retrieves the value of the leaf GroupId from the NetworkInstance_PolicyForwarding_PathSelectionGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if GroupId is set, it can safely use t.GetGroupId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.GroupId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_PathSelectionGroup) GetGroupId() string {
	if t == nil || t.GroupId == nil {
		return ""
	}
	return *t.GroupId
}

// GetMplsLsp retrieves the value of the leaf MplsLsp from the NetworkInstance_PolicyForwarding_PathSelectionGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsLsp is set, it can safely use t.GetMplsLsp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsLsp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_PathSelectionGroup) GetMplsLsp() []string {
	if t == nil || t.MplsLsp == nil {
		return nil
	}
	return t.MplsLsp
}

// ΛListKeyMap returns the keys of the NetworkInstance_PolicyForwarding_PathSelectionGroup struct, which is a YANG list entry.
func (t *NetworkInstance_PolicyForwarding_PathSelectionGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.GroupId == nil {
		return nil, fmt.Errorf("nil value for key GroupId")
	}

	return map[string]interface{}{
		"group-id": *t.GroupId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_PathSelectionGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_PathSelectionGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_PathSelectionGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy YANG schema element.
type NetworkInstance_PolicyForwarding_Policy struct {
	ΛMetadata []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	PolicyId  *string                                                  `path:"state/policy-id|policy-id" shadow-path:"config/policy-id" module:"openconfig-network-instance"`
	ΛPolicyId []ygot.Annotation                                        `path:"state/@policy-id|@policy-id" ygotAnnotation:"true"`
	Rule      map[uint32]*NetworkInstance_PolicyForwarding_Policy_Rule `path:"rules/rule" module:"openconfig-network-instance"`
	ΛRule     []ygot.Annotation                                        `path:"rules/@rule" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy) IsYANGGoStruct() {}

// NewRule creates a new entry in the Rule list of the
// NetworkInstance_PolicyForwarding_Policy struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_PolicyForwarding_Policy) NewRule(SequenceId uint32) (*NetworkInstance_PolicyForwarding_Policy_Rule, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Rule == nil {
		t.Rule = make(map[uint32]*NetworkInstance_PolicyForwarding_Policy_Rule)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Rule[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Rule", key)
	}

	t.Rule[key] = &NetworkInstance_PolicyForwarding_Policy_Rule{
		SequenceId: &SequenceId,
	}

	return t.Rule[key], nil
}

// RenameRule renames an entry in the list Rule within
// the NetworkInstance_PolicyForwarding_Policy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_PolicyForwarding_Policy) RenameRule(oldK, newK uint32) error {
	if _, ok := t.Rule[newK]; ok {
		return fmt.Errorf("key %v already exists in Rule", newK)
	}

	e, ok := t.Rule[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Rule", oldK)
	}
	e.SequenceId = &newK

	t.Rule[newK] = e
	delete(t.Rule, oldK)
	return nil
}

// GetOrCreateRule retrieves the value with the specified keys from
// the receiver NetworkInstance_PolicyForwarding_Policy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_PolicyForwarding_Policy) GetOrCreateRule(SequenceId uint32) *NetworkInstance_PolicyForwarding_Policy_Rule {

	key := SequenceId

	if v, ok := t.Rule[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRule(SequenceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRule got unexpected error: %v", err))
	}
	return v
}

// GetRule retrieves the value with the specified key from
// the Rule map field of NetworkInstance_PolicyForwarding_Policy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy) GetRule(SequenceId uint32) *NetworkInstance_PolicyForwarding_Policy_Rule {

	if t == nil {
		return nil
	}

	key := SequenceId

	if lm, ok := t.Rule[key]; ok {
		return lm
	}
	return nil
}

// AppendRule appends the supplied NetworkInstance_PolicyForwarding_Policy_Rule struct to the
// list Rule of NetworkInstance_PolicyForwarding_Policy. If the key value(s) specified in
// the supplied NetworkInstance_PolicyForwarding_Policy_Rule already exist in the list, an error is
// returned.
func (t *NetworkInstance_PolicyForwarding_Policy) AppendRule(v *NetworkInstance_PolicyForwarding_Policy_Rule) error {
	if v.SequenceId == nil {
		return fmt.Errorf("invalid nil key received for SequenceId")
	}

	key := *v.SequenceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Rule == nil {
		t.Rule = make(map[uint32]*NetworkInstance_PolicyForwarding_Policy_Rule)
	}

	if _, ok := t.Rule[key]; ok {
		return fmt.Errorf("duplicate key for list Rule %v", key)
	}

	t.Rule[key] = v
	return nil
}

// GetPolicyId retrieves the value of the leaf PolicyId from the NetworkInstance_PolicyForwarding_Policy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PolicyId is set, it can safely use t.GetPolicyId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PolicyId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy) GetPolicyId() string {
	if t == nil || t.PolicyId == nil {
		return ""
	}
	return *t.PolicyId
}

// ΛListKeyMap returns the keys of the NetworkInstance_PolicyForwarding_Policy struct, which is a YANG list entry.
func (t *NetworkInstance_PolicyForwarding_Policy) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PolicyId == nil {
		return nil, fmt.Errorf("nil value for key PolicyId")
	}

	return map[string]interface{}{
		"policy-id": *t.PolicyId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule struct {
	ΛMetadata      []ygot.Annotation                                       `path:"@" ygotAnnotation:"true"`
	Action         *NetworkInstance_PolicyForwarding_Policy_Rule_Action    `path:"action" module:"openconfig-network-instance"`
	ΛAction        []ygot.Annotation                                       `path:"@action" ygotAnnotation:"true"`
	Ipv4           *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4      `path:"ipv4" module:"openconfig-network-instance"`
	ΛIpv4          []ygot.Annotation                                       `path:"@ipv4" ygotAnnotation:"true"`
	Ipv6           *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6      `path:"ipv6" module:"openconfig-network-instance"`
	ΛIpv6          []ygot.Annotation                                       `path:"@ipv6" ygotAnnotation:"true"`
	L2             *NetworkInstance_PolicyForwarding_Policy_Rule_L2        `path:"l2" module:"openconfig-network-instance"`
	ΛL2            []ygot.Annotation                                       `path:"@l2" ygotAnnotation:"true"`
	MatchedOctets  *uint64                                                 `path:"state/matched-octets" module:"openconfig-network-instance"`
	ΛMatchedOctets []ygot.Annotation                                       `path:"state/@matched-octets" ygotAnnotation:"true"`
	MatchedPkts    *uint64                                                 `path:"state/matched-pkts" module:"openconfig-network-instance"`
	ΛMatchedPkts   []ygot.Annotation                                       `path:"state/@matched-pkts" ygotAnnotation:"true"`
	SequenceId     *uint32                                                 `path:"state/sequence-id|sequence-id" shadow-path:"config/sequence-id" module:"openconfig-network-instance"`
	ΛSequenceId    []ygot.Annotation                                       `path:"state/@sequence-id|@sequence-id" ygotAnnotation:"true"`
	Transport      *NetworkInstance_PolicyForwarding_Policy_Rule_Transport `path:"transport" module:"openconfig-network-instance"`
	ΛTransport     []ygot.Annotation                                       `path:"@transport" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule) IsYANGGoStruct() {}

// GetOrCreateAction retrieves the value of the Action field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetOrCreateAction() *NetworkInstance_PolicyForwarding_Policy_Rule_Action {
	if t.Action != nil {
		return t.Action
	}
	t.Action = &NetworkInstance_PolicyForwarding_Policy_Rule_Action{}
	return t.Action
}

// GetOrCreateIpv4 retrieves the value of the Ipv4 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetOrCreateIpv4() *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4 {
	if t.Ipv4 != nil {
		return t.Ipv4
	}
	t.Ipv4 = &NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4{}
	return t.Ipv4
}

// GetOrCreateIpv6 retrieves the value of the Ipv6 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetOrCreateIpv6() *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6 {
	if t.Ipv6 != nil {
		return t.Ipv6
	}
	t.Ipv6 = &NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6{}
	return t.Ipv6
}

// GetOrCreateL2 retrieves the value of the L2 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetOrCreateL2() *NetworkInstance_PolicyForwarding_Policy_Rule_L2 {
	if t.L2 != nil {
		return t.L2
	}
	t.L2 = &NetworkInstance_PolicyForwarding_Policy_Rule_L2{}
	return t.L2
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetOrCreateTransport() *NetworkInstance_PolicyForwarding_Policy_Rule_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &NetworkInstance_PolicyForwarding_Policy_Rule_Transport{}
	return t.Transport
}

// GetAction returns the value of the Action struct pointer
// from NetworkInstance_PolicyForwarding_Policy_Rule. If the receiver or the field Action is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetAction() *NetworkInstance_PolicyForwarding_Policy_Rule_Action {
	if t != nil && t.Action != nil {
		return t.Action
	}
	return nil
}

// GetIpv4 returns the value of the Ipv4 struct pointer
// from NetworkInstance_PolicyForwarding_Policy_Rule. If the receiver or the field Ipv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetIpv4() *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4 {
	if t != nil && t.Ipv4 != nil {
		return t.Ipv4
	}
	return nil
}

// GetIpv6 returns the value of the Ipv6 struct pointer
// from NetworkInstance_PolicyForwarding_Policy_Rule. If the receiver or the field Ipv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetIpv6() *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6 {
	if t != nil && t.Ipv6 != nil {
		return t.Ipv6
	}
	return nil
}

// GetL2 returns the value of the L2 struct pointer
// from NetworkInstance_PolicyForwarding_Policy_Rule. If the receiver or the field L2 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetL2() *NetworkInstance_PolicyForwarding_Policy_Rule_L2 {
	if t != nil && t.L2 != nil {
		return t.L2
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from NetworkInstance_PolicyForwarding_Policy_Rule. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetTransport() *NetworkInstance_PolicyForwarding_Policy_Rule_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetMatchedOctets retrieves the value of the leaf MatchedOctets from the NetworkInstance_PolicyForwarding_Policy_Rule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedOctets is set, it can safely use t.GetMatchedOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetMatchedOctets() uint64 {
	if t == nil || t.MatchedOctets == nil {
		return 0
	}
	return *t.MatchedOctets
}

// GetMatchedPkts retrieves the value of the leaf MatchedPkts from the NetworkInstance_PolicyForwarding_Policy_Rule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchedPkts is set, it can safely use t.GetMatchedPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchedPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetMatchedPkts() uint64 {
	if t == nil || t.MatchedPkts == nil {
		return 0
	}
	return *t.MatchedPkts
}

// GetSequenceId retrieves the value of the leaf SequenceId from the NetworkInstance_PolicyForwarding_Policy_Rule
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SequenceId is set, it can safely use t.GetSequenceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SequenceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) GetSequenceId() uint32 {
	if t == nil || t.SequenceId == nil {
		return 0
	}
	return *t.SequenceId
}

// ΛListKeyMap returns the keys of the NetworkInstance_PolicyForwarding_Policy_Rule struct, which is a YANG list entry.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Action represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_Action struct {
	ΛMetadata           []ygot.Annotation                                                   `path:"@" ygotAnnotation:"true"`
	DecapsulateGre      *bool                                                               `path:"state/decapsulate-gre" shadow-path:"config/decapsulate-gre" module:"openconfig-network-instance"`
	ΛDecapsulateGre     []ygot.Annotation                                                   `path:"state/@decapsulate-gre" ygotAnnotation:"true"`
	Discard             *bool                                                               `path:"state/discard" shadow-path:"config/discard" module:"openconfig-network-instance"`
	ΛDiscard            []ygot.Annotation                                                   `path:"state/@discard" ygotAnnotation:"true"`
	EncapsulateGre      *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre `path:"encapsulate-gre" module:"openconfig-network-instance"`
	ΛEncapsulateGre     []ygot.Annotation                                                   `path:"@encapsulate-gre" ygotAnnotation:"true"`
	NetworkInstance     *string                                                             `path:"state/network-instance" shadow-path:"config/network-instance" module:"openconfig-network-instance"`
	ΛNetworkInstance    []ygot.Annotation                                                   `path:"state/@network-instance" ygotAnnotation:"true"`
	NextHop             *string                                                             `path:"state/next-hop" shadow-path:"config/next-hop" module:"openconfig-network-instance"`
	ΛNextHop            []ygot.Annotation                                                   `path:"state/@next-hop" ygotAnnotation:"true"`
	PathSelectionGroup  *string                                                             `path:"state/path-selection-group" shadow-path:"config/path-selection-group" module:"openconfig-network-instance"`
	ΛPathSelectionGroup []ygot.Annotation                                                   `path:"state/@path-selection-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_Action implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_Action) IsYANGGoStruct() {}

// GetOrCreateEncapsulateGre retrieves the value of the EncapsulateGre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetOrCreateEncapsulateGre() *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre {
	if t.EncapsulateGre != nil {
		return t.EncapsulateGre
	}
	t.EncapsulateGre = &NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre{}
	return t.EncapsulateGre
}

// GetEncapsulateGre returns the value of the EncapsulateGre struct pointer
// from NetworkInstance_PolicyForwarding_Policy_Rule_Action. If the receiver or the field EncapsulateGre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetEncapsulateGre() *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre {
	if t != nil && t.EncapsulateGre != nil {
		return t.EncapsulateGre
	}
	return nil
}

// GetDecapsulateGre retrieves the value of the leaf DecapsulateGre from the NetworkInstance_PolicyForwarding_Policy_Rule_Action
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DecapsulateGre is set, it can safely use t.GetDecapsulateGre()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DecapsulateGre == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetDecapsulateGre() bool {
	if t == nil || t.DecapsulateGre == nil {
		return false
	}
	return *t.DecapsulateGre
}

// GetDiscard retrieves the value of the leaf Discard from the NetworkInstance_PolicyForwarding_Policy_Rule_Action
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Discard is set, it can safely use t.GetDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Discard == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetDiscard() bool {
	if t == nil || t.Discard == nil {
		return false
	}
	return *t.Discard
}

// GetNetworkInstance retrieves the value of the leaf NetworkInstance from the NetworkInstance_PolicyForwarding_Policy_Rule_Action
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NetworkInstance is set, it can safely use t.GetNetworkInstance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NetworkInstance == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetNetworkInstance() string {
	if t == nil || t.NetworkInstance == nil {
		return ""
	}
	return *t.NetworkInstance
}

// GetNextHop retrieves the value of the leaf NextHop from the NetworkInstance_PolicyForwarding_Policy_Rule_Action
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetNextHop() string {
	if t == nil || t.NextHop == nil {
		return ""
	}
	return *t.NextHop
}

// GetPathSelectionGroup retrieves the value of the leaf PathSelectionGroup from the NetworkInstance_PolicyForwarding_Policy_Rule_Action
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathSelectionGroup is set, it can safely use t.GetPathSelectionGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathSelectionGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) GetPathSelectionGroup() string {
	if t == nil || t.PathSelectionGroup == nil {
		return ""
	}
	return *t.PathSelectionGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_Action"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre struct {
	ΛMetadata          []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	IdentifyingPrefix  *string                                                                               `path:"state/identifying-prefix" shadow-path:"config/identifying-prefix" module:"openconfig-network-instance"`
	ΛIdentifyingPrefix []ygot.Annotation                                                                     `path:"state/@identifying-prefix" ygotAnnotation:"true"`
	Target             map[string]*NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target `path:"targets/target" module:"openconfig-network-instance"`
	ΛTarget            []ygot.Annotation                                                                     `path:"targets/@target" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) IsYANGGoStruct() {}

// NewTarget creates a new entry in the Target list of the
// NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) NewTarget(Id string) (*NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Target == nil {
		t.Target = make(map[string]*NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Target[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Target", key)
	}

	t.Target[key] = &NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target{
		Id: &Id,
	}

	return t.Target[key], nil
}

// RenameTarget renames an entry in the list Target within
// the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) RenameTarget(oldK, newK string) error {
	if _, ok := t.Target[newK]; ok {
		return fmt.Errorf("key %v already exists in Target", newK)
	}

	e, ok := t.Target[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Target", oldK)
	}
	e.Id = &newK

	t.Target[newK] = e
	delete(t.Target, oldK)
	return nil
}

// GetOrCreateTarget retrieves the value with the specified keys from
// the receiver NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) GetOrCreateTarget(Id string) *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target {

	key := Id

	if v, ok := t.Target[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTarget(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTarget got unexpected error: %v", err))
	}
	return v
}

// GetTarget retrieves the value with the specified key from
// the Target map field of NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) GetTarget(Id string) *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Target[key]; ok {
		return lm
	}
	return nil
}

// AppendTarget appends the supplied NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target struct to the
// list Target of NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre. If the key value(s) specified in
// the supplied NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target already exist in the list, an error is
// returned.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) AppendTarget(v *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Target == nil {
		t.Target = make(map[string]*NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target)
	}

	if _, ok := t.Target[key]; ok {
		return fmt.Errorf("duplicate key for list Target %v", key)
	}

	t.Target[key] = v
	return nil
}

// GetIdentifyingPrefix retrieves the value of the leaf IdentifyingPrefix from the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IdentifyingPrefix is set, it can safely use t.GetIdentifyingPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IdentifyingPrefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) GetIdentifyingPrefix() string {
	if t == nil || t.IdentifyingPrefix == nil {
		return ""
	}
	return *t.IdentifyingPrefix
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/targets/target YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Destination  *string           `path:"state/destination" shadow-path:"config/destination" module:"openconfig-network-instance"`
	ΛDestination []ygot.Annotation `path:"state/@destination" ygotAnnotation:"true"`
	Id           *string           `path:"state/id|id" shadow-path:"config/id" module:"openconfig-network-instance"`
	ΛId          []ygot.Annotation `path:"state/@id|@id" ygotAnnotation:"true"`
	IpTtl        *uint8            `path:"state/ip-ttl" shadow-path:"config/ip-ttl" module:"openconfig-network-instance"`
	ΛIpTtl       []ygot.Annotation `path:"state/@ip-ttl" ygotAnnotation:"true"`
	Source       *string           `path:"state/source" shadow-path:"config/source" module:"openconfig-network-instance"`
	ΛSource      []ygot.Annotation `path:"state/@source" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) IsYANGGoStruct() {}

// GetDestination retrieves the value of the leaf Destination from the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Destination is set, it can safely use t.GetDestination()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Destination == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) GetDestination() string {
	if t == nil || t.Destination == nil {
		return ""
	}
	return *t.Destination
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetIpTtl retrieves the value of the leaf IpTtl from the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpTtl is set, it can safely use t.GetIpTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpTtl == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) GetIpTtl() uint8 {
	if t == nil || t.IpTtl == nil {
		return 0
	}
	return *t.IpTtl
}

// GetSource retrieves the value of the leaf Source from the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Source is set, it can safely use t.GetSource()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Source == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) GetSource() string {
	if t == nil || t.Source == nil {
		return ""
	}
	return *t.Source
}

// ΛListKeyMap returns the keys of the NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target struct, which is a YANG list entry.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Action_EncapsulateGre_Target) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4 represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4 YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4 struct {
	ΛMetadata           []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	DestinationAddress  *string                                                          `path:"state/destination-address" shadow-path:"config/destination-address" module:"openconfig-network-instance"`
	ΛDestinationAddress []ygot.Annotation                                                `path:"state/@destination-address" ygotAnnotation:"true"`
	Dscp                *uint8                                                           `path:"state/dscp" shadow-path:"config/dscp" module:"openconfig-network-instance"`
	ΛDscp               []ygot.Annotation                                                `path:"state/@dscp" ygotAnnotation:"true"`
	HopLimit            *uint8                                                           `path:"state/hop-limit" shadow-path:"config/hop-limit" module:"openconfig-network-instance"`
	ΛHopLimit           []ygot.Annotation                                                `path:"state/@hop-limit" ygotAnnotation:"true"`
	Protocol            NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union `path:"state/protocol" shadow-path:"config/protocol" module:"openconfig-network-instance"`
	ΛProtocol           []ygot.Annotation                                                `path:"state/@protocol" ygotAnnotation:"true"`
	SourceAddress       *string                                                          `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-network-instance"`
	ΛSourceAddress      []ygot.Annotation                                                `path:"state/@source-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) IsYANGGoStruct() {}

// GetDestinationAddress retrieves the value of the leaf DestinationAddress from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationAddress is set, it can safely use t.GetDestinationAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) GetDestinationAddress() string {
	if t == nil || t.DestinationAddress == nil {
		return ""
	}
	return *t.DestinationAddress
}

// GetDscp retrieves the value of the leaf Dscp from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dscp is set, it can safely use t.GetDscp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dscp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) GetDscp() uint8 {
	if t == nil || t.Dscp == nil {
		return 0
	}
	return *t.Dscp
}

// GetHopLimit retrieves the value of the leaf HopLimit from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HopLimit is set, it can safely use t.GetHopLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HopLimit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) GetHopLimit() uint8 {
	if t == nil || t.HopLimit == nil {
		return 0
	}
	return *t.HopLimit
}

// GetProtocol retrieves the value of the leaf Protocol from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Protocol is set, it can safely use t.GetProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Protocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) GetProtocol() NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union {
	if t == nil || t.Protocol == nil {
		return nil
	}
	return t.Protocol
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state/protocol within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8].
type NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8]
	Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union()
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union ensures that E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union interface.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union ensures that UnionUint8
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union interface.
func (UnionUint8) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union() {
}

// To_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4) To_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union(i interface{}) (NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union, error) {
	if v, ok := i.(NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint8:
		return UnionUint8(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_PolicyForwarding_Policy_Rule_Ipv4_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6 represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6 YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6 struct {
	ΛMetadata             []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	DestinationAddress    *string                                                          `path:"state/destination-address" shadow-path:"config/destination-address" module:"openconfig-network-instance"`
	ΛDestinationAddress   []ygot.Annotation                                                `path:"state/@destination-address" ygotAnnotation:"true"`
	DestinationFlowLabel  *uint32                                                          `path:"state/destination-flow-label" shadow-path:"config/destination-flow-label" module:"openconfig-network-instance"`
	ΛDestinationFlowLabel []ygot.Annotation                                                `path:"state/@destination-flow-label" ygotAnnotation:"true"`
	Dscp                  *uint8                                                           `path:"state/dscp" shadow-path:"config/dscp" module:"openconfig-network-instance"`
	ΛDscp                 []ygot.Annotation                                                `path:"state/@dscp" ygotAnnotation:"true"`
	HopLimit              *uint8                                                           `path:"state/hop-limit" shadow-path:"config/hop-limit" module:"openconfig-network-instance"`
	ΛHopLimit             []ygot.Annotation                                                `path:"state/@hop-limit" ygotAnnotation:"true"`
	Protocol              NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union `path:"state/protocol" shadow-path:"config/protocol" module:"openconfig-network-instance"`
	ΛProtocol             []ygot.Annotation                                                `path:"state/@protocol" ygotAnnotation:"true"`
	SourceAddress         *string                                                          `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-network-instance"`
	ΛSourceAddress        []ygot.Annotation                                                `path:"state/@source-address" ygotAnnotation:"true"`
	SourceFlowLabel       *uint32                                                          `path:"state/source-flow-label" shadow-path:"config/source-flow-label" module:"openconfig-network-instance"`
	ΛSourceFlowLabel      []ygot.Annotation                                                `path:"state/@source-flow-label" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) IsYANGGoStruct() {}

// GetDestinationAddress retrieves the value of the leaf DestinationAddress from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationAddress is set, it can safely use t.GetDestinationAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetDestinationAddress() string {
	if t == nil || t.DestinationAddress == nil {
		return ""
	}
	return *t.DestinationAddress
}

// GetDestinationFlowLabel retrieves the value of the leaf DestinationFlowLabel from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationFlowLabel is set, it can safely use t.GetDestinationFlowLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationFlowLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetDestinationFlowLabel() uint32 {
	if t == nil || t.DestinationFlowLabel == nil {
		return 0
	}
	return *t.DestinationFlowLabel
}

// GetDscp retrieves the value of the leaf Dscp from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dscp is set, it can safely use t.GetDscp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dscp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetDscp() uint8 {
	if t == nil || t.Dscp == nil {
		return 0
	}
	return *t.Dscp
}

// GetHopLimit retrieves the value of the leaf HopLimit from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HopLimit is set, it can safely use t.GetHopLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HopLimit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetHopLimit() uint8 {
	if t == nil || t.HopLimit == nil {
		return 0
	}
	return *t.HopLimit
}

// GetProtocol retrieves the value of the leaf Protocol from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Protocol is set, it can safely use t.GetProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Protocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetProtocol() NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union {
	if t == nil || t.Protocol == nil {
		return nil
	}
	return t.Protocol
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// GetSourceFlowLabel retrieves the value of the leaf SourceFlowLabel from the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceFlowLabel is set, it can safely use t.GetSourceFlowLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceFlowLabel == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) GetSourceFlowLabel() uint32 {
	if t == nil || t.SourceFlowLabel == nil {
		return 0
	}
	return *t.SourceFlowLabel
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state/protocol within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8].
type NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, UnionUint8]
	Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union()
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union ensures that E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union interface.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union ensures that UnionUint8
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union interface.
func (UnionUint8) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union() {
}

// To_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6) To_NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union(i interface{}) (NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union, error) {
	if v, ok := i.(NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint8:
		return UnionUint8(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_PolicyForwarding_Policy_Rule_Ipv6_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
}

// NetworkInstance_PolicyForwarding_Policy_Rule_L2 represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2 YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_L2 struct {
	ΛMetadata           []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	DestinationMac      *string                                                         `path:"state/destination-mac" shadow-path:"config/destination-mac" module:"openconfig-network-instance"`
	ΛDestinationMac     []ygot.Annotation                                               `path:"state/@destination-mac" ygotAnnotation:"true"`
	DestinationMacMask  *string                                                         `path:"state/destination-mac-mask" shadow-path:"config/destination-mac-mask" module:"openconfig-network-instance"`
	ΛDestinationMacMask []ygot.Annotation                                               `path:"state/@destination-mac-mask" ygotAnnotation:"true"`
	Ethertype           NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union `path:"state/ethertype" shadow-path:"config/ethertype" module:"openconfig-network-instance"`
	ΛEthertype          []ygot.Annotation                                               `path:"state/@ethertype" ygotAnnotation:"true"`
	SourceMac           *string                                                         `path:"state/source-mac" shadow-path:"config/source-mac" module:"openconfig-network-instance"`
	ΛSourceMac          []ygot.Annotation                                               `path:"state/@source-mac" ygotAnnotation:"true"`
	SourceMacMask       *string                                                         `path:"state/source-mac-mask" shadow-path:"config/source-mac-mask" module:"openconfig-network-instance"`
	ΛSourceMacMask      []ygot.Annotation                                               `path:"state/@source-mac-mask" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_L2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_L2) IsYANGGoStruct() {}

// GetDestinationMac retrieves the value of the leaf DestinationMac from the NetworkInstance_PolicyForwarding_Policy_Rule_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationMac is set, it can safely use t.GetDestinationMac()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationMac == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) GetDestinationMac() string {
	if t == nil || t.DestinationMac == nil {
		return ""
	}
	return *t.DestinationMac
}

// GetDestinationMacMask retrieves the value of the leaf DestinationMacMask from the NetworkInstance_PolicyForwarding_Policy_Rule_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationMacMask is set, it can safely use t.GetDestinationMacMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationMacMask == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) GetDestinationMacMask() string {
	if t == nil || t.DestinationMacMask == nil {
		return ""
	}
	return *t.DestinationMacMask
}

// GetEthertype retrieves the value of the leaf Ethertype from the NetworkInstance_PolicyForwarding_Policy_Rule_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ethertype is set, it can safely use t.GetEthertype()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ethertype == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) GetEthertype() NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union {
	if t == nil || t.Ethertype == nil {
		return nil
	}
	return t.Ethertype
}

// GetSourceMac retrieves the value of the leaf SourceMac from the NetworkInstance_PolicyForwarding_Policy_Rule_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceMac is set, it can safely use t.GetSourceMac()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceMac == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) GetSourceMac() string {
	if t == nil || t.SourceMac == nil {
		return ""
	}
	return *t.SourceMac
}

// GetSourceMacMask retrieves the value of the leaf SourceMacMask from the NetworkInstance_PolicyForwarding_Policy_Rule_L2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceMacMask is set, it can safely use t.GetSourceMacMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceMacMask == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) GetSourceMacMask() string {
	if t == nil || t.SourceMacMask == nil {
		return ""
	}
	return *t.SourceMacMask
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_L2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state/ethertype within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_ETHERTYPE, UnionUint16].
type NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_ETHERTYPE, UnionUint16]
	Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union()
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union ensures that E_OpenconfigPacketMatchTypes_ETHERTYPE
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union interface.
func (E_OpenconfigPacketMatchTypes_ETHERTYPE) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union ensures that UnionUint16
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union interface.
func (UnionUint16) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union() {
}

// To_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_L2) To_NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union(i interface{}) (NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union, error) {
	if v, ok := i.(NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_PolicyForwarding_Policy_Rule_L2_Ethertype_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_ETHERTYPE, uint16]", i, i)
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Transport represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport YANG schema element.
type NetworkInstance_PolicyForwarding_Policy_Rule_Transport struct {
	ΛMetadata        []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	DestinationPort  NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union `path:"state/destination-port" shadow-path:"config/destination-port" module:"openconfig-network-instance"`
	ΛDestinationPort []ygot.Annotation                                                            `path:"state/@destination-port" ygotAnnotation:"true"`
	SourcePort       NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union      `path:"state/source-port" shadow-path:"config/source-port" module:"openconfig-network-instance"`
	ΛSourcePort      []ygot.Annotation                                                            `path:"state/@source-port" ygotAnnotation:"true"`
	TcpFlags         []E_OpenconfigPacketMatchTypes_TCP_FLAGS                                     `path:"state/tcp-flags" shadow-path:"config/tcp-flags" module:"openconfig-network-instance"`
	ΛTcpFlags        []ygot.Annotation                                                            `path:"state/@tcp-flags" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_PolicyForwarding_Policy_Rule_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_PolicyForwarding_Policy_Rule_Transport) IsYANGGoStruct() {}

// GetDestinationPort retrieves the value of the leaf DestinationPort from the NetworkInstance_PolicyForwarding_Policy_Rule_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DestinationPort is set, it can safely use t.GetDestinationPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DestinationPort == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) GetDestinationPort() NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union {
	if t == nil || t.DestinationPort == nil {
		return nil
	}
	return t.DestinationPort
}

// GetSourcePort retrieves the value of the leaf SourcePort from the NetworkInstance_PolicyForwarding_Policy_Rule_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourcePort is set, it can safely use t.GetSourcePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourcePort == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) GetSourcePort() NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union {
	if t == nil || t.SourcePort == nil {
		return nil
	}
	return t.SourcePort
}

// GetTcpFlags retrieves the value of the leaf TcpFlags from the NetworkInstance_PolicyForwarding_Policy_Rule_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TcpFlags is set, it can safely use t.GetTcpFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TcpFlags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) GetTcpFlags() []E_OpenconfigPacketMatchTypes_TCP_FLAGS {
	if t == nil || t.TcpFlags == nil {
		return nil
	}
	return t.TcpFlags
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_PolicyForwarding_Policy_Rule_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16].
type NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16]
	Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union()
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union ensures that E_OpenconfigPacketMatchTypes_PortNumRange_Enum
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union interface.
func (E_OpenconfigPacketMatchTypes_PortNumRange_Enum) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union ensures that UnionString
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union interface.
func (UnionString) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union ensures that UnionUint16
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union interface.
func (UnionUint16) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union() {
}

// To_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) To_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union(i interface{}) (NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union, error) {
	if v, ok := i.(NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_PolicyForwarding_Policy_Rule_Transport_DestinationPort_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, string, uint16]", i, i)
}

// NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port within the YANG schema.
// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16].
type NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union interface {
	// Union type can be one of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, UnionString, UnionUint16]
	Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union()
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union ensures that E_OpenconfigPacketMatchTypes_PortNumRange_Enum
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union interface.
func (E_OpenconfigPacketMatchTypes_PortNumRange_Enum) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union ensures that UnionString
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union interface.
func (UnionString) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union() {
}

// Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union ensures that UnionUint16
// implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union interface.
func (UnionUint16) Documentation_for_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union() {
}

// To_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_PolicyForwarding_Policy_Rule_Transport) To_NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union(i interface{}) (NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union, error) {
	if v, ok := i.(NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_PolicyForwarding_Policy_Rule_Transport_SourcePort_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_PortNumRange_Enum, string, uint16]", i, i)
}

// NetworkInstance_Protocol represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol YANG schema element.
type NetworkInstance_Protocol struct {
	ΛMetadata      []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	Aggregate      map[string]*NetworkInstance_Protocol_Aggregate `path:"local-aggregates/aggregate" module:"openconfig-network-instance"`
	ΛAggregate     []ygot.Annotation                              `path:"local-aggregates/@aggregate" ygotAnnotation:"true"`
	Bgp            *NetworkInstance_Protocol_Bgp                  `path:"bgp" module:"openconfig-network-instance"`
	ΛBgp           []ygot.Annotation                              `path:"@bgp" ygotAnnotation:"true"`
	DefaultMetric  *uint32                                        `path:"state/default-metric" shadow-path:"config/default-metric" module:"openconfig-network-instance"`
	ΛDefaultMetric []ygot.Annotation                              `path:"state/@default-metric" ygotAnnotation:"true"`
	Enabled        *bool                                          `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled       []ygot.Annotation                              `path:"state/@enabled" ygotAnnotation:"true"`
	Identifier     E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE  `path:"state/identifier|identifier" shadow-path:"config/identifier" module:"openconfig-network-instance"`
	ΛIdentifier    []ygot.Annotation                              `path:"state/@identifier|@identifier" ygotAnnotation:"true"`
	Igmp           *NetworkInstance_Protocol_Igmp                 `path:"igmp" module:"openconfig-network-instance"`
	ΛIgmp          []ygot.Annotation                              `path:"@igmp" ygotAnnotation:"true"`
	Isis           *NetworkInstance_Protocol_Isis                 `path:"isis" module:"openconfig-network-instance"`
	ΛIsis          []ygot.Annotation                              `path:"@isis" ygotAnnotation:"true"`
	Name           *string                                        `path:"state/name|name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName          []ygot.Annotation                              `path:"state/@name|@name" ygotAnnotation:"true"`
	Ospfv2         *NetworkInstance_Protocol_Ospfv2               `path:"ospfv2" module:"openconfig-network-instance"`
	ΛOspfv2        []ygot.Annotation                              `path:"@ospfv2" ygotAnnotation:"true"`
	Pim            *NetworkInstance_Protocol_Pim                  `path:"pim" module:"openconfig-network-instance"`
	ΛPim           []ygot.Annotation                              `path:"@pim" ygotAnnotation:"true"`
	Static         map[string]*NetworkInstance_Protocol_Static    `path:"static-routes/static" module:"openconfig-network-instance"`
	ΛStatic        []ygot.Annotation                              `path:"static-routes/@static" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol) IsYANGGoStruct() {}

// NewAggregate creates a new entry in the Aggregate list of the
// NetworkInstance_Protocol struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol) NewAggregate(Prefix string) (*NetworkInstance_Protocol_Aggregate, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Aggregate == nil {
		t.Aggregate = make(map[string]*NetworkInstance_Protocol_Aggregate)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Aggregate[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Aggregate", key)
	}

	t.Aggregate[key] = &NetworkInstance_Protocol_Aggregate{
		Prefix: &Prefix,
	}

	return t.Aggregate[key], nil
}

// RenameAggregate renames an entry in the list Aggregate within
// the NetworkInstance_Protocol struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol) RenameAggregate(oldK, newK string) error {
	if _, ok := t.Aggregate[newK]; ok {
		return fmt.Errorf("key %v already exists in Aggregate", newK)
	}

	e, ok := t.Aggregate[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Aggregate", oldK)
	}
	e.Prefix = &newK

	t.Aggregate[newK] = e
	delete(t.Aggregate, oldK)
	return nil
}

// GetOrCreateAggregate retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol) GetOrCreateAggregate(Prefix string) *NetworkInstance_Protocol_Aggregate {

	key := Prefix

	if v, ok := t.Aggregate[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAggregate(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAggregate got unexpected error: %v", err))
	}
	return v
}

// GetAggregate retrieves the value with the specified key from
// the Aggregate map field of NetworkInstance_Protocol. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol) GetAggregate(Prefix string) *NetworkInstance_Protocol_Aggregate {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Aggregate[key]; ok {
		return lm
	}
	return nil
}

// AppendAggregate appends the supplied NetworkInstance_Protocol_Aggregate struct to the
// list Aggregate of NetworkInstance_Protocol. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Aggregate already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol) AppendAggregate(v *NetworkInstance_Protocol_Aggregate) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Aggregate == nil {
		t.Aggregate = make(map[string]*NetworkInstance_Protocol_Aggregate)
	}

	if _, ok := t.Aggregate[key]; ok {
		return fmt.Errorf("duplicate key for list Aggregate %v", key)
	}

	t.Aggregate[key] = v
	return nil
}

// NewStatic creates a new entry in the Static list of the
// NetworkInstance_Protocol struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol) NewStatic(Prefix string) (*NetworkInstance_Protocol_Static, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Static == nil {
		t.Static = make(map[string]*NetworkInstance_Protocol_Static)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Static[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Static", key)
	}

	t.Static[key] = &NetworkInstance_Protocol_Static{
		Prefix: &Prefix,
	}

	return t.Static[key], nil
}

// RenameStatic renames an entry in the list Static within
// the NetworkInstance_Protocol struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol) RenameStatic(oldK, newK string) error {
	if _, ok := t.Static[newK]; ok {
		return fmt.Errorf("key %v already exists in Static", newK)
	}

	e, ok := t.Static[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Static", oldK)
	}
	e.Prefix = &newK

	t.Static[newK] = e
	delete(t.Static, oldK)
	return nil
}

// GetOrCreateStatic retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol) GetOrCreateStatic(Prefix string) *NetworkInstance_Protocol_Static {

	key := Prefix

	if v, ok := t.Static[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewStatic(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateStatic got unexpected error: %v", err))
	}
	return v
}

// GetStatic retrieves the value with the specified key from
// the Static map field of NetworkInstance_Protocol. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol) GetStatic(Prefix string) *NetworkInstance_Protocol_Static {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Static[key]; ok {
		return lm
	}
	return nil
}

// AppendStatic appends the supplied NetworkInstance_Protocol_Static struct to the
// list Static of NetworkInstance_Protocol. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Static already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol) AppendStatic(v *NetworkInstance_Protocol_Static) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Static == nil {
		t.Static = make(map[string]*NetworkInstance_Protocol_Static)
	}

	if _, ok := t.Static[key]; ok {
		return fmt.Errorf("duplicate key for list Static %v", key)
	}

	t.Static[key] = v
	return nil
}

// GetOrCreateBgp retrieves the value of the Bgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol) GetOrCreateBgp() *NetworkInstance_Protocol_Bgp {
	if t.Bgp != nil {
		return t.Bgp
	}
	t.Bgp = &NetworkInstance_Protocol_Bgp{}
	return t.Bgp
}

// GetOrCreateIgmp retrieves the value of the Igmp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol) GetOrCreateIgmp() *NetworkInstance_Protocol_Igmp {
	if t.Igmp != nil {
		return t.Igmp
	}
	t.Igmp = &NetworkInstance_Protocol_Igmp{}
	return t.Igmp
}

// GetOrCreateIsis retrieves the value of the Isis field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol) GetOrCreateIsis() *NetworkInstance_Protocol_Isis {
	if t.Isis != nil {
		return t.Isis
	}
	t.Isis = &NetworkInstance_Protocol_Isis{}
	return t.Isis
}

// GetOrCreateOspfv2 retrieves the value of the Ospfv2 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol) GetOrCreateOspfv2() *NetworkInstance_Protocol_Ospfv2 {
	if t.Ospfv2 != nil {
		return t.Ospfv2
	}
	t.Ospfv2 = &NetworkInstance_Protocol_Ospfv2{}
	return t.Ospfv2
}

// GetOrCreatePim retrieves the value of the Pim field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol) GetOrCreatePim() *NetworkInstance_Protocol_Pim {
	if t.Pim != nil {
		return t.Pim
	}
	t.Pim = &NetworkInstance_Protocol_Pim{}
	return t.Pim
}

// GetBgp returns the value of the Bgp struct pointer
// from NetworkInstance_Protocol. If the receiver or the field Bgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol) GetBgp() *NetworkInstance_Protocol_Bgp {
	if t != nil && t.Bgp != nil {
		return t.Bgp
	}
	return nil
}

// GetIgmp returns the value of the Igmp struct pointer
// from NetworkInstance_Protocol. If the receiver or the field Igmp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol) GetIgmp() *NetworkInstance_Protocol_Igmp {
	if t != nil && t.Igmp != nil {
		return t.Igmp
	}
	return nil
}

// GetIsis returns the value of the Isis struct pointer
// from NetworkInstance_Protocol. If the receiver or the field Isis is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol) GetIsis() *NetworkInstance_Protocol_Isis {
	if t != nil && t.Isis != nil {
		return t.Isis
	}
	return nil
}

// GetOspfv2 returns the value of the Ospfv2 struct pointer
// from NetworkInstance_Protocol. If the receiver or the field Ospfv2 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol) GetOspfv2() *NetworkInstance_Protocol_Ospfv2 {
	if t != nil && t.Ospfv2 != nil {
		return t.Ospfv2
	}
	return nil
}

// GetPim returns the value of the Pim struct pointer
// from NetworkInstance_Protocol. If the receiver or the field Pim is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol) GetPim() *NetworkInstance_Protocol_Pim {
	if t != nil && t.Pim != nil {
		return t.Pim
	}
	return nil
}

// GetDefaultMetric retrieves the value of the leaf DefaultMetric from the NetworkInstance_Protocol
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultMetric is set, it can safely use t.GetDefaultMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol) GetDefaultMetric() uint32 {
	if t == nil || t.DefaultMetric == nil {
		return 0
	}
	return *t.DefaultMetric
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetIdentifier retrieves the value of the leaf Identifier from the NetworkInstance_Protocol
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Identifier is set, it can safely use t.GetIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Identifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol) GetIdentifier() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.Identifier == 0 {
		return 0
	}
	return t.Identifier
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Protocol
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol) ΛListKeyMap() (map[string]interface{}, error) {

	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"identifier": t.Identifier,
		"name":       *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Protocol_Aggregate represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate YANG schema element.
type NetworkInstance_Protocol_Aggregate struct {
	ΛMetadata    []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	Description  *string                                         `path:"state/description" shadow-path:"config/description" module:"openconfig-network-instance"`
	ΛDescription []ygot.Annotation                               `path:"state/@description" ygotAnnotation:"true"`
	Discard      *bool                                           `path:"state/discard" shadow-path:"config/discard" module:"openconfig-network-instance"`
	ΛDiscard     []ygot.Annotation                               `path:"state/@discard" ygotAnnotation:"true"`
	Prefix       *string                                         `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-network-instance"`
	ΛPrefix      []ygot.Annotation                               `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SetTag       NetworkInstance_Protocol_Aggregate_SetTag_Union `path:"state/set-tag" shadow-path:"config/set-tag" module:"openconfig-network-instance"`
	ΛSetTag      []ygot.Annotation                               `path:"state/@set-tag" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Aggregate implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Aggregate) IsYANGGoStruct() {}

// GetDescription retrieves the value of the leaf Description from the NetworkInstance_Protocol_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Aggregate) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetDiscard retrieves the value of the leaf Discard from the NetworkInstance_Protocol_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Discard is set, it can safely use t.GetDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Discard == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Aggregate) GetDiscard() bool {
	if t == nil || t.Discard == nil {
		return false
	}
	return *t.Discard
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Aggregate) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSetTag retrieves the value of the leaf SetTag from the NetworkInstance_Protocol_Aggregate
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetTag is set, it can safely use t.GetSetTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetTag == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Aggregate) GetSetTag() NetworkInstance_Protocol_Aggregate_SetTag_Union {
	if t == nil || t.SetTag == nil {
		return nil
	}
	return t.SetTag
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Aggregate struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Aggregate) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Aggregate) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Aggregate"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Aggregate) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Aggregate_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/state/set-tag within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Aggregate_SetTag_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Aggregate_SetTag_Union()
}

// Documentation_for_NetworkInstance_Protocol_Aggregate_SetTag_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Aggregate_SetTag_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Aggregate_SetTag_Union() {}

// Documentation_for_NetworkInstance_Protocol_Aggregate_SetTag_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Aggregate_SetTag_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Aggregate_SetTag_Union() {}

// To_NetworkInstance_Protocol_Aggregate_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Aggregate_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Aggregate) To_NetworkInstance_Protocol_Aggregate_SetTag_Union(i interface{}) (NetworkInstance_Protocol_Aggregate_SetTag_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Aggregate_SetTag_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Aggregate_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Bgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp YANG schema element.
type NetworkInstance_Protocol_Bgp struct {
	ΛMetadata  []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	Global     *NetworkInstance_Protocol_Bgp_Global               `path:"global" module:"openconfig-network-instance"`
	ΛGlobal    []ygot.Annotation                                  `path:"@global" ygotAnnotation:"true"`
	Neighbor   map[string]*NetworkInstance_Protocol_Bgp_Neighbor  `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor  []ygot.Annotation                                  `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	PeerGroup  map[string]*NetworkInstance_Protocol_Bgp_PeerGroup `path:"peer-groups/peer-group" module:"openconfig-network-instance"`
	ΛPeerGroup []ygot.Annotation                                  `path:"peer-groups/@peer-group" ygotAnnotation:"true"`
	Rib        *NetworkInstance_Protocol_Bgp_Rib                  `path:"rib" module:"openconfig-network-instance"`
	ΛRib       []ygot.Annotation                                  `path:"@rib" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Bgp struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp) NewNeighbor(NeighborAddress string) (*NetworkInstance_Protocol_Bgp_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Bgp_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Bgp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp) GetOrCreateNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Bgp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp) GetNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Bgp_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Bgp. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp) AppendNeighbor(v *NetworkInstance_Protocol_Bgp_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// NewPeerGroup creates a new entry in the PeerGroup list of the
// NetworkInstance_Protocol_Bgp struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp) NewPeerGroup(PeerGroupName string) (*NetworkInstance_Protocol_Bgp_PeerGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PeerGroup == nil {
		t.PeerGroup = make(map[string]*NetworkInstance_Protocol_Bgp_PeerGroup)
	}

	key := PeerGroupName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PeerGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PeerGroup", key)
	}

	t.PeerGroup[key] = &NetworkInstance_Protocol_Bgp_PeerGroup{
		PeerGroupName: &PeerGroupName,
	}

	return t.PeerGroup[key], nil
}

// RenamePeerGroup renames an entry in the list PeerGroup within
// the NetworkInstance_Protocol_Bgp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp) RenamePeerGroup(oldK, newK string) error {
	if _, ok := t.PeerGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in PeerGroup", newK)
	}

	e, ok := t.PeerGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PeerGroup", oldK)
	}
	e.PeerGroupName = &newK

	t.PeerGroup[newK] = e
	delete(t.PeerGroup, oldK)
	return nil
}

// GetOrCreatePeerGroup retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp) GetOrCreatePeerGroup(PeerGroupName string) *NetworkInstance_Protocol_Bgp_PeerGroup {

	key := PeerGroupName

	if v, ok := t.PeerGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPeerGroup(PeerGroupName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePeerGroup got unexpected error: %v", err))
	}
	return v
}

// GetPeerGroup retrieves the value with the specified key from
// the PeerGroup map field of NetworkInstance_Protocol_Bgp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp) GetPeerGroup(PeerGroupName string) *NetworkInstance_Protocol_Bgp_PeerGroup {

	if t == nil {
		return nil
	}

	key := PeerGroupName

	if lm, ok := t.PeerGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendPeerGroup appends the supplied NetworkInstance_Protocol_Bgp_PeerGroup struct to the
// list PeerGroup of NetworkInstance_Protocol_Bgp. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_PeerGroup already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp) AppendPeerGroup(v *NetworkInstance_Protocol_Bgp_PeerGroup) error {
	if v.PeerGroupName == nil {
		return fmt.Errorf("invalid nil key received for PeerGroupName")
	}

	key := *v.PeerGroupName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PeerGroup == nil {
		t.PeerGroup = make(map[string]*NetworkInstance_Protocol_Bgp_PeerGroup)
	}

	if _, ok := t.PeerGroup[key]; ok {
		return fmt.Errorf("duplicate key for list PeerGroup %v", key)
	}

	t.PeerGroup[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp) GetOrCreateGlobal() *NetworkInstance_Protocol_Bgp_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Protocol_Bgp_Global{}
	return t.Global
}

// GetOrCreateRib retrieves the value of the Rib field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp) GetOrCreateRib() *NetworkInstance_Protocol_Bgp_Rib {
	if t.Rib != nil {
		return t.Rib
	}
	t.Rib = &NetworkInstance_Protocol_Bgp_Rib{}
	return t.Rib
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Protocol_Bgp. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp) GetGlobal() *NetworkInstance_Protocol_Bgp_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// GetRib returns the value of the Rib struct pointer
// from NetworkInstance_Protocol_Bgp. If the receiver or the field Rib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp) GetRib() *NetworkInstance_Protocol_Bgp_Rib {
	if t != nil && t.Rib != nil {
		return t.Rib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Protocol_Bgp_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global YANG schema element.
type NetworkInstance_Protocol_Bgp_Global struct {
	ΛMetadata              []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	AfiSafi                map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Global_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-network-instance"`
	ΛAfiSafi               []ygot.Annotation                                                                   `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	As                     *uint32                                                                             `path:"state/as" shadow-path:"config/as" module:"openconfig-network-instance"`
	ΛAs                    []ygot.Annotation                                                                   `path:"state/@as" ygotAnnotation:"true"`
	Confederation          *NetworkInstance_Protocol_Bgp_Global_Confederation                                  `path:"confederation" module:"openconfig-network-instance"`
	ΛConfederation         []ygot.Annotation                                                                   `path:"@confederation" ygotAnnotation:"true"`
	DefaultRouteDistance   *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance                           `path:"default-route-distance" module:"openconfig-network-instance"`
	ΛDefaultRouteDistance  []ygot.Annotation                                                                   `path:"@default-route-distance" ygotAnnotation:"true"`
	DynamicNeighborPrefix  map[string]*NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix               `path:"dynamic-neighbor-prefixes/dynamic-neighbor-prefix" module:"openconfig-network-instance"`
	ΛDynamicNeighborPrefix []ygot.Annotation                                                                   `path:"dynamic-neighbor-prefixes/@dynamic-neighbor-prefix" ygotAnnotation:"true"`
	GracefulRestart        *NetworkInstance_Protocol_Bgp_Global_GracefulRestart                                `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart       []ygot.Annotation                                                                   `path:"@graceful-restart" ygotAnnotation:"true"`
	RouteSelectionOptions  *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions                          `path:"route-selection-options" module:"openconfig-network-instance"`
	ΛRouteSelectionOptions []ygot.Annotation                                                                   `path:"@route-selection-options" ygotAnnotation:"true"`
	RouterId               *string                                                                             `path:"state/router-id" shadow-path:"config/router-id" module:"openconfig-network-instance"`
	ΛRouterId              []ygot.Annotation                                                                   `path:"state/@router-id" ygotAnnotation:"true"`
	TotalPaths             *uint32                                                                             `path:"state/total-paths" module:"openconfig-network-instance"`
	ΛTotalPaths            []ygot.Annotation                                                                   `path:"state/@total-paths" ygotAnnotation:"true"`
	TotalPrefixes          *uint32                                                                             `path:"state/total-prefixes" module:"openconfig-network-instance"`
	ΛTotalPrefixes         []ygot.Annotation                                                                   `path:"state/@total-prefixes" ygotAnnotation:"true"`
	UseMultiplePaths       *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths                               `path:"use-multiple-paths" module:"openconfig-network-instance"`
	ΛUseMultiplePaths      []ygot.Annotation                                                                   `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// NetworkInstance_Protocol_Bgp_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Global) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*NetworkInstance_Protocol_Bgp_Global_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Global_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &NetworkInstance_Protocol_Bgp_Global_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the NetworkInstance_Protocol_Bgp_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Global) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_Global_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of NetworkInstance_Protocol_Bgp_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_Global_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied NetworkInstance_Protocol_Bgp_Global_AfiSafi struct to the
// list AfiSafi of NetworkInstance_Protocol_Bgp_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Global_AfiSafi already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Global) AppendAfiSafi(v *NetworkInstance_Protocol_Bgp_Global_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Global_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// NewDynamicNeighborPrefix creates a new entry in the DynamicNeighborPrefix list of the
// NetworkInstance_Protocol_Bgp_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Global) NewDynamicNeighborPrefix(Prefix string) (*NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DynamicNeighborPrefix == nil {
		t.DynamicNeighborPrefix = make(map[string]*NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DynamicNeighborPrefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DynamicNeighborPrefix", key)
	}

	t.DynamicNeighborPrefix[key] = &NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix{
		Prefix: &Prefix,
	}

	return t.DynamicNeighborPrefix[key], nil
}

// RenameDynamicNeighborPrefix renames an entry in the list DynamicNeighborPrefix within
// the NetworkInstance_Protocol_Bgp_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Global) RenameDynamicNeighborPrefix(oldK, newK string) error {
	if _, ok := t.DynamicNeighborPrefix[newK]; ok {
		return fmt.Errorf("key %v already exists in DynamicNeighborPrefix", newK)
	}

	e, ok := t.DynamicNeighborPrefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in DynamicNeighborPrefix", oldK)
	}
	e.Prefix = &newK

	t.DynamicNeighborPrefix[newK] = e
	delete(t.DynamicNeighborPrefix, oldK)
	return nil
}

// GetOrCreateDynamicNeighborPrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateDynamicNeighborPrefix(Prefix string) *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix {

	key := Prefix

	if v, ok := t.DynamicNeighborPrefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewDynamicNeighborPrefix(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateDynamicNeighborPrefix got unexpected error: %v", err))
	}
	return v
}

// GetDynamicNeighborPrefix retrieves the value with the specified key from
// the DynamicNeighborPrefix map field of NetworkInstance_Protocol_Bgp_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetDynamicNeighborPrefix(Prefix string) *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.DynamicNeighborPrefix[key]; ok {
		return lm
	}
	return nil
}

// AppendDynamicNeighborPrefix appends the supplied NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix struct to the
// list DynamicNeighborPrefix of NetworkInstance_Protocol_Bgp_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Global) AppendDynamicNeighborPrefix(v *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DynamicNeighborPrefix == nil {
		t.DynamicNeighborPrefix = make(map[string]*NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix)
	}

	if _, ok := t.DynamicNeighborPrefix[key]; ok {
		return fmt.Errorf("duplicate key for list DynamicNeighborPrefix %v", key)
	}

	t.DynamicNeighborPrefix[key] = v
	return nil
}

// GetOrCreateConfederation retrieves the value of the Confederation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateConfederation() *NetworkInstance_Protocol_Bgp_Global_Confederation {
	if t.Confederation != nil {
		return t.Confederation
	}
	t.Confederation = &NetworkInstance_Protocol_Bgp_Global_Confederation{}
	return t.Confederation
}

// GetOrCreateDefaultRouteDistance retrieves the value of the DefaultRouteDistance field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateDefaultRouteDistance() *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance {
	if t.DefaultRouteDistance != nil {
		return t.DefaultRouteDistance
	}
	t.DefaultRouteDistance = &NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance{}
	return t.DefaultRouteDistance
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Bgp_Global_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Bgp_Global_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateRouteSelectionOptions retrieves the value of the RouteSelectionOptions field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateRouteSelectionOptions() *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions {
	if t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	t.RouteSelectionOptions = &NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions{}
	return t.RouteSelectionOptions
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global) GetOrCreateUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetConfederation returns the value of the Confederation struct pointer
// from NetworkInstance_Protocol_Bgp_Global. If the receiver or the field Confederation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetConfederation() *NetworkInstance_Protocol_Bgp_Global_Confederation {
	if t != nil && t.Confederation != nil {
		return t.Confederation
	}
	return nil
}

// GetDefaultRouteDistance returns the value of the DefaultRouteDistance struct pointer
// from NetworkInstance_Protocol_Bgp_Global. If the receiver or the field DefaultRouteDistance is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetDefaultRouteDistance() *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance {
	if t != nil && t.DefaultRouteDistance != nil {
		return t.DefaultRouteDistance
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Bgp_Global. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetGracefulRestart() *NetworkInstance_Protocol_Bgp_Global_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetRouteSelectionOptions returns the value of the RouteSelectionOptions struct pointer
// from NetworkInstance_Protocol_Bgp_Global. If the receiver or the field RouteSelectionOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetRouteSelectionOptions() *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions {
	if t != nil && t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from NetworkInstance_Protocol_Bgp_Global. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global) GetUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAs retrieves the value of the leaf As from the NetworkInstance_Protocol_Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As is set, it can safely use t.GetAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global) GetAs() uint32 {
	if t == nil || t.As == nil {
		return 0
	}
	return *t.As
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetTotalPaths retrieves the value of the leaf TotalPaths from the NetworkInstance_Protocol_Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPaths is set, it can safely use t.GetTotalPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global) GetTotalPaths() uint32 {
	if t == nil || t.TotalPaths == nil {
		return 0
	}
	return *t.TotalPaths
}

// GetTotalPrefixes retrieves the value of the leaf TotalPrefixes from the NetworkInstance_Protocol_Bgp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPrefixes is set, it can safely use t.GetTotalPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global) GetTotalPrefixes() uint32 {
	if t == nil || t.TotalPrefixes == nil {
		return 0
	}
	return *t.TotalPrefixes
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi struct {
	ΛMetadata              []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	AddPaths               *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths              `path:"add-paths" module:"openconfig-network-instance"`
	ΛAddPaths              []ygot.Annotation                                                  `path:"@add-paths" ygotAnnotation:"true"`
	AfiSafiName            E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                 `path:"state/afi-safi-name|afi-safi-name" shadow-path:"config/afi-safi-name" module:"openconfig-network-instance"`
	ΛAfiSafiName           []ygot.Annotation                                                  `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	Enabled                *bool                                                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled               []ygot.Annotation                                                  `path:"state/@enabled" ygotAnnotation:"true"`
	GracefulRestart        *NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart       `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart       []ygot.Annotation                                                  `path:"@graceful-restart" ygotAnnotation:"true"`
	Ipv4LabeledUnicast     *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast    `path:"ipv4-labeled-unicast" module:"openconfig-network-instance"`
	ΛIpv4LabeledUnicast    []ygot.Annotation                                                  `path:"@ipv4-labeled-unicast" ygotAnnotation:"true"`
	Ipv4Unicast            *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast           `path:"ipv4-unicast" module:"openconfig-network-instance"`
	ΛIpv4Unicast           []ygot.Annotation                                                  `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6LabeledUnicast     *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast    `path:"ipv6-labeled-unicast" module:"openconfig-network-instance"`
	ΛIpv6LabeledUnicast    []ygot.Annotation                                                  `path:"@ipv6-labeled-unicast" ygotAnnotation:"true"`
	Ipv6Unicast            *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast           `path:"ipv6-unicast" module:"openconfig-network-instance"`
	ΛIpv6Unicast           []ygot.Annotation                                                  `path:"@ipv6-unicast" ygotAnnotation:"true"`
	L2VpnEvpn              *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn             `path:"l2vpn-evpn" module:"openconfig-network-instance"`
	ΛL2VpnEvpn             []ygot.Annotation                                                  `path:"@l2vpn-evpn" ygotAnnotation:"true"`
	L2VpnVpls              *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls             `path:"l2vpn-vpls" module:"openconfig-network-instance"`
	ΛL2VpnVpls             []ygot.Annotation                                                  `path:"@l2vpn-vpls" ygotAnnotation:"true"`
	L3VpnIpv4Multicast     *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast    `path:"l3vpn-ipv4-multicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv4Multicast    []ygot.Annotation                                                  `path:"@l3vpn-ipv4-multicast" ygotAnnotation:"true"`
	L3VpnIpv4Unicast       *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast      `path:"l3vpn-ipv4-unicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv4Unicast      []ygot.Annotation                                                  `path:"@l3vpn-ipv4-unicast" ygotAnnotation:"true"`
	L3VpnIpv6Multicast     *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast    `path:"l3vpn-ipv6-multicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv6Multicast    []ygot.Annotation                                                  `path:"@l3vpn-ipv6-multicast" ygotAnnotation:"true"`
	L3VpnIpv6Unicast       *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast      `path:"l3vpn-ipv6-unicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv6Unicast      []ygot.Annotation                                                  `path:"@l3vpn-ipv6-unicast" ygotAnnotation:"true"`
	RouteSelectionOptions  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions `path:"route-selection-options" module:"openconfig-network-instance"`
	ΛRouteSelectionOptions []ygot.Annotation                                                  `path:"@route-selection-options" ygotAnnotation:"true"`
	SrtePolicyIpv4         *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4        `path:"srte-policy-ipv4" module:"openconfig-network-instance"`
	ΛSrtePolicyIpv4        []ygot.Annotation                                                  `path:"@srte-policy-ipv4" ygotAnnotation:"true"`
	SrtePolicyIpv6         *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6        `path:"srte-policy-ipv6" module:"openconfig-network-instance"`
	ΛSrtePolicyIpv6        []ygot.Annotation                                                  `path:"@srte-policy-ipv6" ygotAnnotation:"true"`
	TotalPaths             *uint32                                                            `path:"state/total-paths" module:"openconfig-network-instance"`
	ΛTotalPaths            []ygot.Annotation                                                  `path:"state/@total-paths" ygotAnnotation:"true"`
	TotalPrefixes          *uint32                                                            `path:"state/total-prefixes" module:"openconfig-network-instance"`
	ΛTotalPrefixes         []ygot.Annotation                                                  `path:"state/@total-prefixes" ygotAnnotation:"true"`
	UseMultiplePaths       *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths      `path:"use-multiple-paths" module:"openconfig-network-instance"`
	ΛUseMultiplePaths      []ygot.Annotation                                                  `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateAddPaths retrieves the value of the AddPaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateAddPaths() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths {
	if t.AddPaths != nil {
		return t.AddPaths
	}
	t.AddPaths = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths{}
	return t.AddPaths
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateIpv4LabeledUnicast retrieves the value of the Ipv4LabeledUnicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateIpv4LabeledUnicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast {
	if t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	t.Ipv4LabeledUnicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast{}
	return t.Ipv4LabeledUnicast
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateIpv4Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6LabeledUnicast retrieves the value of the Ipv6LabeledUnicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateIpv6LabeledUnicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast {
	if t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	t.Ipv6LabeledUnicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast{}
	return t.Ipv6LabeledUnicast
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateIpv6Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetOrCreateL2VpnEvpn retrieves the value of the L2VpnEvpn field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateL2VpnEvpn() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn {
	if t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	t.L2VpnEvpn = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn{}
	return t.L2VpnEvpn
}

// GetOrCreateL2VpnVpls retrieves the value of the L2VpnVpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateL2VpnVpls() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls {
	if t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	t.L2VpnVpls = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls{}
	return t.L2VpnVpls
}

// GetOrCreateL3VpnIpv4Multicast retrieves the value of the L3VpnIpv4Multicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv4Multicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast {
	if t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	t.L3VpnIpv4Multicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast{}
	return t.L3VpnIpv4Multicast
}

// GetOrCreateL3VpnIpv4Unicast retrieves the value of the L3VpnIpv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv4Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast {
	if t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	t.L3VpnIpv4Unicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast{}
	return t.L3VpnIpv4Unicast
}

// GetOrCreateL3VpnIpv6Multicast retrieves the value of the L3VpnIpv6Multicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv6Multicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast {
	if t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	t.L3VpnIpv6Multicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast{}
	return t.L3VpnIpv6Multicast
}

// GetOrCreateL3VpnIpv6Unicast retrieves the value of the L3VpnIpv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateL3VpnIpv6Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast {
	if t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	t.L3VpnIpv6Unicast = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast{}
	return t.L3VpnIpv6Unicast
}

// GetOrCreateRouteSelectionOptions retrieves the value of the RouteSelectionOptions field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateRouteSelectionOptions() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions {
	if t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	t.RouteSelectionOptions = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions{}
	return t.RouteSelectionOptions
}

// GetOrCreateSrtePolicyIpv4 retrieves the value of the SrtePolicyIpv4 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateSrtePolicyIpv4() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4 {
	if t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	t.SrtePolicyIpv4 = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4{}
	return t.SrtePolicyIpv4
}

// GetOrCreateSrtePolicyIpv6 retrieves the value of the SrtePolicyIpv6 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateSrtePolicyIpv6() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6 {
	if t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	t.SrtePolicyIpv6 = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6{}
	return t.SrtePolicyIpv6
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetOrCreateUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetAddPaths returns the value of the AddPaths struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field AddPaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetAddPaths() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths {
	if t != nil && t.AddPaths != nil {
		return t.AddPaths
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetGracefulRestart() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetIpv4LabeledUnicast returns the value of the Ipv4LabeledUnicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field Ipv4LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetIpv4LabeledUnicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast {
	if t != nil && t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetIpv4Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6LabeledUnicast returns the value of the Ipv6LabeledUnicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field Ipv6LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetIpv6LabeledUnicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast {
	if t != nil && t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetIpv6Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetL2VpnEvpn returns the value of the L2VpnEvpn struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field L2VpnEvpn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetL2VpnEvpn() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn {
	if t != nil && t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	return nil
}

// GetL2VpnVpls returns the value of the L2VpnVpls struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field L2VpnVpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetL2VpnVpls() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls {
	if t != nil && t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	return nil
}

// GetL3VpnIpv4Multicast returns the value of the L3VpnIpv4Multicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv4Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetL3VpnIpv4Multicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast {
	if t != nil && t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	return nil
}

// GetL3VpnIpv4Unicast returns the value of the L3VpnIpv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetL3VpnIpv4Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast {
	if t != nil && t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	return nil
}

// GetL3VpnIpv6Multicast returns the value of the L3VpnIpv6Multicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv6Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetL3VpnIpv6Multicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast {
	if t != nil && t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	return nil
}

// GetL3VpnIpv6Unicast returns the value of the L3VpnIpv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field L3VpnIpv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetL3VpnIpv6Unicast() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast {
	if t != nil && t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	return nil
}

// GetRouteSelectionOptions returns the value of the RouteSelectionOptions struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field RouteSelectionOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetRouteSelectionOptions() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions {
	if t != nil && t.RouteSelectionOptions != nil {
		return t.RouteSelectionOptions
	}
	return nil
}

// GetSrtePolicyIpv4 returns the value of the SrtePolicyIpv4 struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field SrtePolicyIpv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetSrtePolicyIpv4() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4 {
	if t != nil && t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	return nil
}

// GetSrtePolicyIpv6 returns the value of the SrtePolicyIpv6 struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field SrtePolicyIpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetSrtePolicyIpv6() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6 {
	if t != nil && t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the NetworkInstance_Protocol_Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetTotalPaths retrieves the value of the leaf TotalPaths from the NetworkInstance_Protocol_Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPaths is set, it can safely use t.GetTotalPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetTotalPaths() uint32 {
	if t == nil || t.TotalPaths == nil {
		return 0
	}
	return *t.TotalPaths
}

// GetTotalPrefixes retrieves the value of the leaf TotalPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPrefixes is set, it can safely use t.GetTotalPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) GetTotalPrefixes() uint32 {
	if t == nil || t.TotalPrefixes == nil {
		return 0
	}
	return *t.TotalPrefixes
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Global_AfiSafi struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/add-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EligiblePrefixPolicy  *string           `path:"state/eligible-prefix-policy" shadow-path:"config/eligible-prefix-policy" module:"openconfig-network-instance"`
	ΛEligiblePrefixPolicy []ygot.Annotation `path:"state/@eligible-prefix-policy" ygotAnnotation:"true"`
	Receive               *bool             `path:"state/receive" shadow-path:"config/receive" module:"openconfig-network-instance"`
	ΛReceive              []ygot.Annotation `path:"state/@receive" ygotAnnotation:"true"`
	Send                  *bool             `path:"state/send" shadow-path:"config/send" module:"openconfig-network-instance"`
	ΛSend                 []ygot.Annotation `path:"state/@send" ygotAnnotation:"true"`
	SendMax               *uint8            `path:"state/send-max" shadow-path:"config/send-max" module:"openconfig-network-instance"`
	ΛSendMax              []ygot.Annotation `path:"state/@send-max" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) IsYANGGoStruct() {}

// GetEligiblePrefixPolicy retrieves the value of the leaf EligiblePrefixPolicy from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EligiblePrefixPolicy is set, it can safely use t.GetEligiblePrefixPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EligiblePrefixPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) GetEligiblePrefixPolicy() string {
	if t == nil || t.EligiblePrefixPolicy == nil {
		return ""
	}
	return *t.EligiblePrefixPolicy
}

// GetReceive retrieves the value of the leaf Receive from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Receive is set, it can safely use t.GetReceive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Receive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) GetReceive() bool {
	if t == nil || t.Receive == nil {
		return false
	}
	return *t.Receive
}

// GetSend retrieves the value of the leaf Send from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Send is set, it can safely use t.GetSend()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Send == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) GetSend() bool {
	if t == nil || t.Send == nil {
		return false
	}
	return *t.Send
}

// GetSendMax retrieves the value of the leaf SendMax from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendMax is set, it can safely use t.GetSendMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendMax == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) GetSendMax() uint8 {
	if t == nil || t.SendMax == nil {
		return 0
	}
	return *t.SendMax
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled   *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast struct {
	ΛMetadata         []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit      []ygot.Annotation                                                    `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                                                `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-network-instance"`
	ΛSendDefaultRoute []ygot.Annotation                                                    `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast struct {
	ΛMetadata         []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit      []ygot.Annotation                                                    `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                                                `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-network-instance"`
	ΛSendDefaultRoute []ygot.Annotation                                                    `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn struct {
	ΛMetadata    []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls struct {
	ΛMetadata    []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                  `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast struct {
	ΛMetadata    []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast struct {
	ΛMetadata    []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                         `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast struct {
	ΛMetadata    []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast struct {
	ΛMetadata    []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                         `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/route-selection-options YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdvertiseInactiveRoutes  *bool             `path:"state/advertise-inactive-routes" shadow-path:"config/advertise-inactive-routes" module:"openconfig-network-instance"`
	ΛAdvertiseInactiveRoutes []ygot.Annotation `path:"state/@advertise-inactive-routes" ygotAnnotation:"true"`
	AlwaysCompareMed         *bool             `path:"state/always-compare-med" shadow-path:"config/always-compare-med" module:"openconfig-network-instance"`
	ΛAlwaysCompareMed        []ygot.Annotation `path:"state/@always-compare-med" ygotAnnotation:"true"`
	EnableAigp               *bool             `path:"state/enable-aigp" shadow-path:"config/enable-aigp" module:"openconfig-network-instance"`
	ΛEnableAigp              []ygot.Annotation `path:"state/@enable-aigp" ygotAnnotation:"true"`
	ExternalCompareRouterId  *bool             `path:"state/external-compare-router-id" shadow-path:"config/external-compare-router-id" module:"openconfig-network-instance"`
	ΛExternalCompareRouterId []ygot.Annotation `path:"state/@external-compare-router-id" ygotAnnotation:"true"`
	IgnoreAsPathLength       *bool             `path:"state/ignore-as-path-length" shadow-path:"config/ignore-as-path-length" module:"openconfig-network-instance"`
	ΛIgnoreAsPathLength      []ygot.Annotation `path:"state/@ignore-as-path-length" ygotAnnotation:"true"`
	IgnoreNextHopIgpMetric   *bool             `path:"state/ignore-next-hop-igp-metric" shadow-path:"config/ignore-next-hop-igp-metric" module:"openconfig-network-instance"`
	ΛIgnoreNextHopIgpMetric  []ygot.Annotation `path:"state/@ignore-next-hop-igp-metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) IsYANGGoStruct() {}

// GetAdvertiseInactiveRoutes retrieves the value of the leaf AdvertiseInactiveRoutes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertiseInactiveRoutes is set, it can safely use t.GetAdvertiseInactiveRoutes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertiseInactiveRoutes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) GetAdvertiseInactiveRoutes() bool {
	if t == nil || t.AdvertiseInactiveRoutes == nil {
		return false
	}
	return *t.AdvertiseInactiveRoutes
}

// GetAlwaysCompareMed retrieves the value of the leaf AlwaysCompareMed from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlwaysCompareMed is set, it can safely use t.GetAlwaysCompareMed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlwaysCompareMed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) GetAlwaysCompareMed() bool {
	if t == nil || t.AlwaysCompareMed == nil {
		return false
	}
	return *t.AlwaysCompareMed
}

// GetEnableAigp retrieves the value of the leaf EnableAigp from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableAigp is set, it can safely use t.GetEnableAigp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableAigp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) GetEnableAigp() bool {
	if t == nil || t.EnableAigp == nil {
		return false
	}
	return *t.EnableAigp
}

// GetExternalCompareRouterId retrieves the value of the leaf ExternalCompareRouterId from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalCompareRouterId is set, it can safely use t.GetExternalCompareRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalCompareRouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) GetExternalCompareRouterId() bool {
	if t == nil || t.ExternalCompareRouterId == nil {
		return true
	}
	return *t.ExternalCompareRouterId
}

// GetIgnoreAsPathLength retrieves the value of the leaf IgnoreAsPathLength from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreAsPathLength is set, it can safely use t.GetIgnoreAsPathLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreAsPathLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) GetIgnoreAsPathLength() bool {
	if t == nil || t.IgnoreAsPathLength == nil {
		return false
	}
	return *t.IgnoreAsPathLength
}

// GetIgnoreNextHopIgpMetric retrieves the value of the leaf IgnoreNextHopIgpMetric from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreNextHopIgpMetric is set, it can safely use t.GetIgnoreNextHopIgpMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreNextHopIgpMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) GetIgnoreNextHopIgpMetric() bool {
	if t == nil || t.IgnoreNextHopIgpMetric == nil {
		return false
	}
	return *t.IgnoreNextHopIgpMetric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4 struct {
	ΛMetadata    []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                       `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6 struct {
	ΛMetadata    []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                       `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	Ebgp      *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-network-instance"`
	ΛEbgp     []ygot.Annotation                                                  `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation                                                  `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-network-instance"`
	ΛIbgp     []ygot.Annotation                                                  `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) GetOrCreateEbgp() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) GetOrCreateIbgp() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) GetEbgp() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) GetIbgp() *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-network-instance"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_Confederation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/confederation YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_Confederation struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Identifier  *uint32           `path:"state/identifier" shadow-path:"config/identifier" module:"openconfig-network-instance"`
	ΛIdentifier []ygot.Annotation `path:"state/@identifier" ygotAnnotation:"true"`
	MemberAs    []uint32          `path:"state/member-as" shadow-path:"config/member-as" module:"openconfig-network-instance"`
	ΛMemberAs   []ygot.Annotation `path:"state/@member-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_Confederation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_Confederation) IsYANGGoStruct() {}

// GetIdentifier retrieves the value of the leaf Identifier from the NetworkInstance_Protocol_Bgp_Global_Confederation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Identifier is set, it can safely use t.GetIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Identifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_Confederation) GetIdentifier() uint32 {
	if t == nil || t.Identifier == nil {
		return 0
	}
	return *t.Identifier
}

// GetMemberAs retrieves the value of the leaf MemberAs from the NetworkInstance_Protocol_Bgp_Global_Confederation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MemberAs is set, it can safely use t.GetMemberAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MemberAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_Confederation) GetMemberAs() []uint32 {
	if t == nil || t.MemberAs == nil {
		return nil
	}
	return t.MemberAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_Confederation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_Confederation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_Confederation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/default-route-distance YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance struct {
	ΛMetadata              []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExternalRouteDistance  *uint8            `path:"state/external-route-distance" shadow-path:"config/external-route-distance" module:"openconfig-network-instance"`
	ΛExternalRouteDistance []ygot.Annotation `path:"state/@external-route-distance" ygotAnnotation:"true"`
	InternalRouteDistance  *uint8            `path:"state/internal-route-distance" shadow-path:"config/internal-route-distance" module:"openconfig-network-instance"`
	ΛInternalRouteDistance []ygot.Annotation `path:"state/@internal-route-distance" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance) IsYANGGoStruct() {}

// GetExternalRouteDistance retrieves the value of the leaf ExternalRouteDistance from the NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRouteDistance is set, it can safely use t.GetExternalRouteDistance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRouteDistance == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance) GetExternalRouteDistance() uint8 {
	if t == nil || t.ExternalRouteDistance == nil {
		return 0
	}
	return *t.ExternalRouteDistance
}

// GetInternalRouteDistance retrieves the value of the leaf InternalRouteDistance from the NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InternalRouteDistance is set, it can safely use t.GetInternalRouteDistance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InternalRouteDistance == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance) GetInternalRouteDistance() uint8 {
	if t == nil || t.InternalRouteDistance == nil {
		return 0
	}
	return *t.InternalRouteDistance
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_DefaultRouteDistance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PeerGroup  *string           `path:"state/peer-group" shadow-path:"config/peer-group" module:"openconfig-network-instance"`
	ΛPeerGroup []ygot.Annotation `path:"state/@peer-group" ygotAnnotation:"true"`
	Prefix     *string           `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-network-instance"`
	ΛPrefix    []ygot.Annotation `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) IsYANGGoStruct() {}

// GetPeerGroup retrieves the value of the leaf PeerGroup from the NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerGroup is set, it can safely use t.GetPeerGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) GetPeerGroup() string {
	if t == nil || t.PeerGroup == nil {
		return ""
	}
	return *t.PeerGroup
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_DynamicNeighborPrefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_GracefulRestart struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled          *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled         []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly       *bool             `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-network-instance"`
	ΛHelperOnly      []ygot.Annotation `path:"state/@helper-only" ygotAnnotation:"true"`
	RestartTime      *uint16           `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-network-instance"`
	ΛRestartTime     []ygot.Annotation `path:"state/@restart-time" ygotAnnotation:"true"`
	StaleRoutesTime  *float64          `path:"state/stale-routes-time" shadow-path:"config/stale-routes-time" module:"openconfig-network-instance"`
	ΛStaleRoutesTime []ygot.Annotation `path:"state/@stale-routes-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the NetworkInstance_Protocol_Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// GetRestartTime retrieves the value of the leaf RestartTime from the NetworkInstance_Protocol_Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_GracefulRestart) GetRestartTime() uint16 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// GetStaleRoutesTime retrieves the value of the leaf StaleRoutesTime from the NetworkInstance_Protocol_Bgp_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StaleRoutesTime is set, it can safely use t.GetStaleRoutesTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StaleRoutesTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_GracefulRestart) GetStaleRoutesTime() float64 {
	if t == nil || t.StaleRoutesTime == nil {
		return 0.0
	}
	return *t.StaleRoutesTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/route-selection-options YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdvertiseInactiveRoutes  *bool             `path:"state/advertise-inactive-routes" shadow-path:"config/advertise-inactive-routes" module:"openconfig-network-instance"`
	ΛAdvertiseInactiveRoutes []ygot.Annotation `path:"state/@advertise-inactive-routes" ygotAnnotation:"true"`
	AlwaysCompareMed         *bool             `path:"state/always-compare-med" shadow-path:"config/always-compare-med" module:"openconfig-network-instance"`
	ΛAlwaysCompareMed        []ygot.Annotation `path:"state/@always-compare-med" ygotAnnotation:"true"`
	EnableAigp               *bool             `path:"state/enable-aigp" shadow-path:"config/enable-aigp" module:"openconfig-network-instance"`
	ΛEnableAigp              []ygot.Annotation `path:"state/@enable-aigp" ygotAnnotation:"true"`
	ExternalCompareRouterId  *bool             `path:"state/external-compare-router-id" shadow-path:"config/external-compare-router-id" module:"openconfig-network-instance"`
	ΛExternalCompareRouterId []ygot.Annotation `path:"state/@external-compare-router-id" ygotAnnotation:"true"`
	IgnoreAsPathLength       *bool             `path:"state/ignore-as-path-length" shadow-path:"config/ignore-as-path-length" module:"openconfig-network-instance"`
	ΛIgnoreAsPathLength      []ygot.Annotation `path:"state/@ignore-as-path-length" ygotAnnotation:"true"`
	IgnoreNextHopIgpMetric   *bool             `path:"state/ignore-next-hop-igp-metric" shadow-path:"config/ignore-next-hop-igp-metric" module:"openconfig-network-instance"`
	ΛIgnoreNextHopIgpMetric  []ygot.Annotation `path:"state/@ignore-next-hop-igp-metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) IsYANGGoStruct() {}

// GetAdvertiseInactiveRoutes retrieves the value of the leaf AdvertiseInactiveRoutes from the NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertiseInactiveRoutes is set, it can safely use t.GetAdvertiseInactiveRoutes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertiseInactiveRoutes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) GetAdvertiseInactiveRoutes() bool {
	if t == nil || t.AdvertiseInactiveRoutes == nil {
		return false
	}
	return *t.AdvertiseInactiveRoutes
}

// GetAlwaysCompareMed retrieves the value of the leaf AlwaysCompareMed from the NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlwaysCompareMed is set, it can safely use t.GetAlwaysCompareMed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlwaysCompareMed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) GetAlwaysCompareMed() bool {
	if t == nil || t.AlwaysCompareMed == nil {
		return false
	}
	return *t.AlwaysCompareMed
}

// GetEnableAigp retrieves the value of the leaf EnableAigp from the NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableAigp is set, it can safely use t.GetEnableAigp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableAigp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) GetEnableAigp() bool {
	if t == nil || t.EnableAigp == nil {
		return false
	}
	return *t.EnableAigp
}

// GetExternalCompareRouterId retrieves the value of the leaf ExternalCompareRouterId from the NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalCompareRouterId is set, it can safely use t.GetExternalCompareRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalCompareRouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) GetExternalCompareRouterId() bool {
	if t == nil || t.ExternalCompareRouterId == nil {
		return true
	}
	return *t.ExternalCompareRouterId
}

// GetIgnoreAsPathLength retrieves the value of the leaf IgnoreAsPathLength from the NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreAsPathLength is set, it can safely use t.GetIgnoreAsPathLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreAsPathLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) GetIgnoreAsPathLength() bool {
	if t == nil || t.IgnoreAsPathLength == nil {
		return false
	}
	return *t.IgnoreAsPathLength
}

// GetIgnoreNextHopIgpMetric retrieves the value of the leaf IgnoreNextHopIgpMetric from the NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreNextHopIgpMetric is set, it can safely use t.GetIgnoreNextHopIgpMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreNextHopIgpMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) GetIgnoreNextHopIgpMetric() bool {
	if t == nil || t.IgnoreNextHopIgpMetric == nil {
		return false
	}
	return *t.IgnoreNextHopIgpMetric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                                          `path:"@" ygotAnnotation:"true"`
	Ebgp      *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-network-instance"`
	ΛEbgp     []ygot.Annotation                                          `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                                      `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation                                          `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-network-instance"`
	ΛIbgp     []ygot.Annotation                                          `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) GetOrCreateEbgp() *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) GetOrCreateIbgp() *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) GetEbgp() *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) GetIbgp() *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ebgp YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-network-instance"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ibgp YANG schema element.
type NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor struct {
	ΛMetadata               []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	AfiSafi                 map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-network-instance"`
	ΛAfiSafi                []ygot.Annotation                                                                     `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	ApplyPolicy             *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy                                    `path:"apply-policy" module:"openconfig-network-instance"`
	ΛApplyPolicy            []ygot.Annotation                                                                     `path:"@apply-policy" ygotAnnotation:"true"`
	AsPathOptions           *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions                                  `path:"as-path-options" module:"openconfig-network-instance"`
	ΛAsPathOptions          []ygot.Annotation                                                                     `path:"@as-path-options" ygotAnnotation:"true"`
	AuthPassword            *string                                                                               `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-network-instance"`
	ΛAuthPassword           []ygot.Annotation                                                                     `path:"state/@auth-password" ygotAnnotation:"true"`
	Description             *string                                                                               `path:"state/description" shadow-path:"config/description" module:"openconfig-network-instance"`
	ΛDescription            []ygot.Annotation                                                                     `path:"state/@description" ygotAnnotation:"true"`
	DynamicallyConfigured   *bool                                                                                 `path:"state/dynamically-configured" module:"openconfig-network-instance"`
	ΛDynamicallyConfigured  []ygot.Annotation                                                                     `path:"state/@dynamically-configured" ygotAnnotation:"true"`
	EbgpMultihop            *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop                                   `path:"ebgp-multihop" module:"openconfig-network-instance"`
	ΛEbgpMultihop           []ygot.Annotation                                                                     `path:"@ebgp-multihop" ygotAnnotation:"true"`
	Enabled                 *bool                                                                                 `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled                []ygot.Annotation                                                                     `path:"state/@enabled" ygotAnnotation:"true"`
	ErrorHandling           *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling                                  `path:"error-handling" module:"openconfig-network-instance"`
	ΛErrorHandling          []ygot.Annotation                                                                     `path:"@error-handling" ygotAnnotation:"true"`
	EstablishedTransitions  *uint64                                                                               `path:"state/established-transitions" module:"openconfig-network-instance"`
	ΛEstablishedTransitions []ygot.Annotation                                                                     `path:"state/@established-transitions" ygotAnnotation:"true"`
	GracefulRestart         *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart                                `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart        []ygot.Annotation                                                                     `path:"@graceful-restart" ygotAnnotation:"true"`
	LastEstablished         *uint64                                                                               `path:"state/last-established" module:"openconfig-network-instance"`
	ΛLastEstablished        []ygot.Annotation                                                                     `path:"state/@last-established" ygotAnnotation:"true"`
	LocalAs                 *uint32                                                                               `path:"state/local-as" shadow-path:"config/local-as" module:"openconfig-network-instance"`
	ΛLocalAs                []ygot.Annotation                                                                     `path:"state/@local-as" ygotAnnotation:"true"`
	LoggingOptions          *NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions                                 `path:"logging-options" module:"openconfig-network-instance"`
	ΛLoggingOptions         []ygot.Annotation                                                                     `path:"@logging-options" ygotAnnotation:"true"`
	Messages                *NetworkInstance_Protocol_Bgp_Neighbor_Messages                                       `path:"state/messages" module:"openconfig-network-instance"`
	ΛMessages               []ygot.Annotation                                                                     `path:"state/@messages" ygotAnnotation:"true"`
	NeighborAddress         *string                                                                               `path:"state/neighbor-address|neighbor-address" shadow-path:"config/neighbor-address" module:"openconfig-network-instance"`
	ΛNeighborAddress        []ygot.Annotation                                                                     `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
	PeerAs                  *uint32                                                                               `path:"state/peer-as" shadow-path:"config/peer-as" module:"openconfig-network-instance"`
	ΛPeerAs                 []ygot.Annotation                                                                     `path:"state/@peer-as" ygotAnnotation:"true"`
	PeerGroup               *string                                                                               `path:"state/peer-group" shadow-path:"config/peer-group" module:"openconfig-network-instance"`
	ΛPeerGroup              []ygot.Annotation                                                                     `path:"state/@peer-group" ygotAnnotation:"true"`
	PeerType                E_OpenconfigBgpTypes_PeerType                                                         `path:"state/peer-type" shadow-path:"config/peer-type" module:"openconfig-network-instance"`
	ΛPeerType               []ygot.Annotation                                                                     `path:"state/@peer-type" ygotAnnotation:"true"`
	Queues                  *NetworkInstance_Protocol_Bgp_Neighbor_Queues                                         `path:"state/queues" module:"openconfig-network-instance"`
	ΛQueues                 []ygot.Annotation                                                                     `path:"state/@queues" ygotAnnotation:"true"`
	RemovePrivateAs         E_OpenconfigBgpTypes_RemovePrivateAsOption                                            `path:"state/remove-private-as" shadow-path:"config/remove-private-as" module:"openconfig-network-instance"`
	ΛRemovePrivateAs        []ygot.Annotation                                                                     `path:"state/@remove-private-as" ygotAnnotation:"true"`
	RouteFlapDamping        *bool                                                                                 `path:"state/route-flap-damping" shadow-path:"config/route-flap-damping" module:"openconfig-network-instance"`
	ΛRouteFlapDamping       []ygot.Annotation                                                                     `path:"state/@route-flap-damping" ygotAnnotation:"true"`
	RouteReflector          *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector                                 `path:"route-reflector" module:"openconfig-network-instance"`
	ΛRouteReflector         []ygot.Annotation                                                                     `path:"@route-reflector" ygotAnnotation:"true"`
	SendCommunity           E_OpenconfigBgpTypes_CommunityType                                                    `path:"state/send-community" shadow-path:"config/send-community" module:"openconfig-network-instance"`
	ΛSendCommunity          []ygot.Annotation                                                                     `path:"state/@send-community" ygotAnnotation:"true"`
	SessionState            E_Neighbor_SessionState                                                               `path:"state/session-state" module:"openconfig-network-instance"`
	ΛSessionState           []ygot.Annotation                                                                     `path:"state/@session-state" ygotAnnotation:"true"`
	SupportedCapabilities   []E_OpenconfigBgpTypes_BGP_CAPABILITY                                                 `path:"state/supported-capabilities" module:"openconfig-network-instance"`
	ΛSupportedCapabilities  []ygot.Annotation                                                                     `path:"state/@supported-capabilities" ygotAnnotation:"true"`
	Timers                  *NetworkInstance_Protocol_Bgp_Neighbor_Timers                                         `path:"timers" module:"openconfig-network-instance"`
	ΛTimers                 []ygot.Annotation                                                                     `path:"@timers" ygotAnnotation:"true"`
	Transport               *NetworkInstance_Protocol_Bgp_Neighbor_Transport                                      `path:"transport" module:"openconfig-network-instance"`
	ΛTransport              []ygot.Annotation                                                                     `path:"@transport" ygotAnnotation:"true"`
	UseMultiplePaths        *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths                               `path:"use-multiple-paths" module:"openconfig-network-instance"`
	ΛUseMultiplePaths       []ygot.Annotation                                                                     `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// NetworkInstance_Protocol_Bgp_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the NetworkInstance_Protocol_Bgp_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of NetworkInstance_Protocol_Bgp_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi struct to the
// list AfiSafi of NetworkInstance_Protocol_Bgp_Neighbor. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) AppendAfiSafi(v *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateApplyPolicy() *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateAsPathOptions retrieves the value of the AsPathOptions field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateAsPathOptions() *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions {
	if t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	t.AsPathOptions = &NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions{}
	return t.AsPathOptions
}

// GetOrCreateEbgpMultihop retrieves the value of the EbgpMultihop field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateEbgpMultihop() *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop {
	if t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	t.EbgpMultihop = &NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop{}
	return t.EbgpMultihop
}

// GetOrCreateErrorHandling retrieves the value of the ErrorHandling field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateErrorHandling() *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling {
	if t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	t.ErrorHandling = &NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling{}
	return t.ErrorHandling
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateLoggingOptions retrieves the value of the LoggingOptions field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateLoggingOptions() *NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions {
	if t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	t.LoggingOptions = &NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions{}
	return t.LoggingOptions
}

// GetOrCreateMessages retrieves the value of the Messages field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateMessages() *NetworkInstance_Protocol_Bgp_Neighbor_Messages {
	if t.Messages != nil {
		return t.Messages
	}
	t.Messages = &NetworkInstance_Protocol_Bgp_Neighbor_Messages{}
	return t.Messages
}

// GetOrCreateQueues retrieves the value of the Queues field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateQueues() *NetworkInstance_Protocol_Bgp_Neighbor_Queues {
	if t.Queues != nil {
		return t.Queues
	}
	t.Queues = &NetworkInstance_Protocol_Bgp_Neighbor_Queues{}
	return t.Queues
}

// GetOrCreateRouteReflector retrieves the value of the RouteReflector field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateRouteReflector() *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector {
	if t.RouteReflector != nil {
		return t.RouteReflector
	}
	t.RouteReflector = &NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector{}
	return t.RouteReflector
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateTimers() *NetworkInstance_Protocol_Bgp_Neighbor_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Bgp_Neighbor_Timers{}
	return t.Timers
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateTransport() *NetworkInstance_Protocol_Bgp_Neighbor_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &NetworkInstance_Protocol_Bgp_Neighbor_Transport{}
	return t.Transport
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetOrCreateUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetApplyPolicy() *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetAsPathOptions returns the value of the AsPathOptions struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field AsPathOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetAsPathOptions() *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions {
	if t != nil && t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	return nil
}

// GetEbgpMultihop returns the value of the EbgpMultihop struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field EbgpMultihop is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetEbgpMultihop() *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop {
	if t != nil && t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	return nil
}

// GetErrorHandling returns the value of the ErrorHandling struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field ErrorHandling is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetErrorHandling() *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling {
	if t != nil && t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetGracefulRestart() *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetLoggingOptions returns the value of the LoggingOptions struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field LoggingOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetLoggingOptions() *NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions {
	if t != nil && t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	return nil
}

// GetMessages returns the value of the Messages struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field Messages is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetMessages() *NetworkInstance_Protocol_Bgp_Neighbor_Messages {
	if t != nil && t.Messages != nil {
		return t.Messages
	}
	return nil
}

// GetQueues returns the value of the Queues struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field Queues is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetQueues() *NetworkInstance_Protocol_Bgp_Neighbor_Queues {
	if t != nil && t.Queues != nil {
		return t.Queues
	}
	return nil
}

// GetRouteReflector returns the value of the RouteReflector struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field RouteReflector is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetRouteReflector() *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector {
	if t != nil && t.RouteReflector != nil {
		return t.RouteReflector
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetTimers() *NetworkInstance_Protocol_Bgp_Neighbor_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetTransport() *NetworkInstance_Protocol_Bgp_Neighbor_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// GetDescription retrieves the value of the leaf Description from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetDynamicallyConfigured retrieves the value of the leaf DynamicallyConfigured from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DynamicallyConfigured is set, it can safely use t.GetDynamicallyConfigured()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DynamicallyConfigured == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetDynamicallyConfigured() bool {
	if t == nil || t.DynamicallyConfigured == nil {
		return false
	}
	return *t.DynamicallyConfigured
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetEstablishedTransitions retrieves the value of the leaf EstablishedTransitions from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EstablishedTransitions is set, it can safely use t.GetEstablishedTransitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EstablishedTransitions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetEstablishedTransitions() uint64 {
	if t == nil || t.EstablishedTransitions == nil {
		return 0
	}
	return *t.EstablishedTransitions
}

// GetLastEstablished retrieves the value of the leaf LastEstablished from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastEstablished is set, it can safely use t.GetLastEstablished()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastEstablished == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetLastEstablished() uint64 {
	if t == nil || t.LastEstablished == nil {
		return 0
	}
	return *t.LastEstablished
}

// GetLocalAs retrieves the value of the leaf LocalAs from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAs is set, it can safely use t.GetLocalAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetLocalAs() uint32 {
	if t == nil || t.LocalAs == nil {
		return 0
	}
	return *t.LocalAs
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// GetPeerAs retrieves the value of the leaf PeerAs from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerAs is set, it can safely use t.GetPeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetPeerAs() uint32 {
	if t == nil || t.PeerAs == nil {
		return 0
	}
	return *t.PeerAs
}

// GetPeerGroup retrieves the value of the leaf PeerGroup from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerGroup is set, it can safely use t.GetPeerGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetPeerGroup() string {
	if t == nil || t.PeerGroup == nil {
		return ""
	}
	return *t.PeerGroup
}

// GetPeerType retrieves the value of the leaf PeerType from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerType is set, it can safely use t.GetPeerType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetPeerType() E_OpenconfigBgpTypes_PeerType {
	if t == nil || t.PeerType == 0 {
		return 0
	}
	return t.PeerType
}

// GetRemovePrivateAs retrieves the value of the leaf RemovePrivateAs from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemovePrivateAs is set, it can safely use t.GetRemovePrivateAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemovePrivateAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetRemovePrivateAs() E_OpenconfigBgpTypes_RemovePrivateAsOption {
	if t == nil || t.RemovePrivateAs == 0 {
		return 0
	}
	return t.RemovePrivateAs
}

// GetRouteFlapDamping retrieves the value of the leaf RouteFlapDamping from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteFlapDamping is set, it can safely use t.GetRouteFlapDamping()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteFlapDamping == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetRouteFlapDamping() bool {
	if t == nil || t.RouteFlapDamping == nil {
		return false
	}
	return *t.RouteFlapDamping
}

// GetSendCommunity retrieves the value of the leaf SendCommunity from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendCommunity is set, it can safely use t.GetSendCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendCommunity == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetSendCommunity() E_OpenconfigBgpTypes_CommunityType {
	if t == nil || t.SendCommunity == 0 {
		return OpenconfigBgpTypes_CommunityType_NONE
	}
	return t.SendCommunity
}

// GetSessionState retrieves the value of the leaf SessionState from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SessionState is set, it can safely use t.GetSessionState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SessionState == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetSessionState() E_Neighbor_SessionState {
	if t == nil || t.SessionState == 0 {
		return 0
	}
	return t.SessionState
}

// GetSupportedCapabilities retrieves the value of the leaf SupportedCapabilities from the NetworkInstance_Protocol_Bgp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SupportedCapabilities is set, it can safely use t.GetSupportedCapabilities()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SupportedCapabilities == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) GetSupportedCapabilities() []E_OpenconfigBgpTypes_BGP_CAPABILITY {
	if t == nil || t.SupportedCapabilities == nil {
		return nil
	}
	return t.SupportedCapabilities
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi struct {
	ΛMetadata           []ygot.Annotation                                                 `path:"@" ygotAnnotation:"true"`
	Active              *bool                                                             `path:"state/active" module:"openconfig-network-instance"`
	ΛActive             []ygot.Annotation                                                 `path:"state/@active" ygotAnnotation:"true"`
	AddPaths            *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-network-instance"`
	ΛAddPaths           []ygot.Annotation                                                 `path:"@add-paths" ygotAnnotation:"true"`
	AfiSafiName         E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                `path:"state/afi-safi-name|afi-safi-name" shadow-path:"config/afi-safi-name" module:"openconfig-network-instance"`
	ΛAfiSafiName        []ygot.Annotation                                                 `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	ApplyPolicy         *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-network-instance"`
	ΛApplyPolicy        []ygot.Annotation                                                 `path:"@apply-policy" ygotAnnotation:"true"`
	Enabled             *bool                                                             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation                                                 `path:"state/@enabled" ygotAnnotation:"true"`
	GracefulRestart     *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart    []ygot.Annotation                                                 `path:"@graceful-restart" ygotAnnotation:"true"`
	Ipv4LabeledUnicast  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-network-instance"`
	ΛIpv4LabeledUnicast []ygot.Annotation                                                 `path:"@ipv4-labeled-unicast" ygotAnnotation:"true"`
	Ipv4Unicast         *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-network-instance"`
	ΛIpv4Unicast        []ygot.Annotation                                                 `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6LabeledUnicast  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-network-instance"`
	ΛIpv6LabeledUnicast []ygot.Annotation                                                 `path:"@ipv6-labeled-unicast" ygotAnnotation:"true"`
	Ipv6Unicast         *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-network-instance"`
	ΛIpv6Unicast        []ygot.Annotation                                                 `path:"@ipv6-unicast" ygotAnnotation:"true"`
	L2VpnEvpn           *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-network-instance"`
	ΛL2VpnEvpn          []ygot.Annotation                                                 `path:"@l2vpn-evpn" ygotAnnotation:"true"`
	L2VpnVpls           *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-network-instance"`
	ΛL2VpnVpls          []ygot.Annotation                                                 `path:"@l2vpn-vpls" ygotAnnotation:"true"`
	L3VpnIpv4Multicast  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv4Multicast []ygot.Annotation                                                 `path:"@l3vpn-ipv4-multicast" ygotAnnotation:"true"`
	L3VpnIpv4Unicast    *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv4Unicast   []ygot.Annotation                                                 `path:"@l3vpn-ipv4-unicast" ygotAnnotation:"true"`
	L3VpnIpv6Multicast  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv6Multicast []ygot.Annotation                                                 `path:"@l3vpn-ipv6-multicast" ygotAnnotation:"true"`
	L3VpnIpv6Unicast    *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv6Unicast   []ygot.Annotation                                                 `path:"@l3vpn-ipv6-unicast" ygotAnnotation:"true"`
	Prefixes            *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes           `path:"state/prefixes" module:"openconfig-network-instance"`
	ΛPrefixes           []ygot.Annotation                                                 `path:"state/@prefixes" ygotAnnotation:"true"`
	SrtePolicyIpv4      *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-network-instance"`
	ΛSrtePolicyIpv4     []ygot.Annotation                                                 `path:"@srte-policy-ipv4" ygotAnnotation:"true"`
	SrtePolicyIpv6      *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-network-instance"`
	ΛSrtePolicyIpv6     []ygot.Annotation                                                 `path:"@srte-policy-ipv6" ygotAnnotation:"true"`
	UseMultiplePaths    *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-network-instance"`
	ΛUseMultiplePaths   []ygot.Annotation                                                 `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateAddPaths retrieves the value of the AddPaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateAddPaths() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths {
	if t.AddPaths != nil {
		return t.AddPaths
	}
	t.AddPaths = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths{}
	return t.AddPaths
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateApplyPolicy() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateIpv4LabeledUnicast retrieves the value of the Ipv4LabeledUnicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateIpv4LabeledUnicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast {
	if t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	t.Ipv4LabeledUnicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast{}
	return t.Ipv4LabeledUnicast
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateIpv4Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6LabeledUnicast retrieves the value of the Ipv6LabeledUnicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateIpv6LabeledUnicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast {
	if t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	t.Ipv6LabeledUnicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast{}
	return t.Ipv6LabeledUnicast
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateIpv6Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetOrCreateL2VpnEvpn retrieves the value of the L2VpnEvpn field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateL2VpnEvpn() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn {
	if t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	t.L2VpnEvpn = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn{}
	return t.L2VpnEvpn
}

// GetOrCreateL2VpnVpls retrieves the value of the L2VpnVpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateL2VpnVpls() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls {
	if t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	t.L2VpnVpls = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls{}
	return t.L2VpnVpls
}

// GetOrCreateL3VpnIpv4Multicast retrieves the value of the L3VpnIpv4Multicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv4Multicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast {
	if t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	t.L3VpnIpv4Multicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast{}
	return t.L3VpnIpv4Multicast
}

// GetOrCreateL3VpnIpv4Unicast retrieves the value of the L3VpnIpv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv4Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast {
	if t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	t.L3VpnIpv4Unicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast{}
	return t.L3VpnIpv4Unicast
}

// GetOrCreateL3VpnIpv6Multicast retrieves the value of the L3VpnIpv6Multicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv6Multicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast {
	if t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	t.L3VpnIpv6Multicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast{}
	return t.L3VpnIpv6Multicast
}

// GetOrCreateL3VpnIpv6Unicast retrieves the value of the L3VpnIpv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateL3VpnIpv6Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast {
	if t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	t.L3VpnIpv6Unicast = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast{}
	return t.L3VpnIpv6Unicast
}

// GetOrCreatePrefixes retrieves the value of the Prefixes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreatePrefixes() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes {
	if t.Prefixes != nil {
		return t.Prefixes
	}
	t.Prefixes = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes{}
	return t.Prefixes
}

// GetOrCreateSrtePolicyIpv4 retrieves the value of the SrtePolicyIpv4 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateSrtePolicyIpv4() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 {
	if t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	t.SrtePolicyIpv4 = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4{}
	return t.SrtePolicyIpv4
}

// GetOrCreateSrtePolicyIpv6 retrieves the value of the SrtePolicyIpv6 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateSrtePolicyIpv6() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 {
	if t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	t.SrtePolicyIpv6 = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6{}
	return t.SrtePolicyIpv6
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetOrCreateUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetAddPaths returns the value of the AddPaths struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field AddPaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetAddPaths() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths {
	if t != nil && t.AddPaths != nil {
		return t.AddPaths
	}
	return nil
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetApplyPolicy() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetGracefulRestart() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetIpv4LabeledUnicast returns the value of the Ipv4LabeledUnicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv4LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetIpv4LabeledUnicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast {
	if t != nil && t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetIpv4Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6LabeledUnicast returns the value of the Ipv6LabeledUnicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv6LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetIpv6LabeledUnicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast {
	if t != nil && t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetIpv6Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetL2VpnEvpn returns the value of the L2VpnEvpn struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field L2VpnEvpn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetL2VpnEvpn() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn {
	if t != nil && t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	return nil
}

// GetL2VpnVpls returns the value of the L2VpnVpls struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field L2VpnVpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetL2VpnVpls() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls {
	if t != nil && t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	return nil
}

// GetL3VpnIpv4Multicast returns the value of the L3VpnIpv4Multicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv4Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetL3VpnIpv4Multicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast {
	if t != nil && t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	return nil
}

// GetL3VpnIpv4Unicast returns the value of the L3VpnIpv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetL3VpnIpv4Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast {
	if t != nil && t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	return nil
}

// GetL3VpnIpv6Multicast returns the value of the L3VpnIpv6Multicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv6Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetL3VpnIpv6Multicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast {
	if t != nil && t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	return nil
}

// GetL3VpnIpv6Unicast returns the value of the L3VpnIpv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field L3VpnIpv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetL3VpnIpv6Unicast() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast {
	if t != nil && t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	return nil
}

// GetPrefixes returns the value of the Prefixes struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field Prefixes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetPrefixes() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes {
	if t != nil && t.Prefixes != nil {
		return t.Prefixes
	}
	return nil
}

// GetSrtePolicyIpv4 returns the value of the SrtePolicyIpv4 struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field SrtePolicyIpv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetSrtePolicyIpv4() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 {
	if t != nil && t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	return nil
}

// GetSrtePolicyIpv6 returns the value of the SrtePolicyIpv6 struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field SrtePolicyIpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetSrtePolicyIpv6() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 {
	if t != nil && t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetUseMultiplePaths() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetActive retrieves the value of the leaf Active from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EligiblePrefixPolicy  *string           `path:"state/eligible-prefix-policy" shadow-path:"config/eligible-prefix-policy" module:"openconfig-network-instance"`
	ΛEligiblePrefixPolicy []ygot.Annotation `path:"state/@eligible-prefix-policy" ygotAnnotation:"true"`
	Receive               *bool             `path:"state/receive" shadow-path:"config/receive" module:"openconfig-network-instance"`
	ΛReceive              []ygot.Annotation `path:"state/@receive" ygotAnnotation:"true"`
	Send                  *bool             `path:"state/send" shadow-path:"config/send" module:"openconfig-network-instance"`
	ΛSend                 []ygot.Annotation `path:"state/@send" ygotAnnotation:"true"`
	SendMax               *uint8            `path:"state/send-max" shadow-path:"config/send-max" module:"openconfig-network-instance"`
	ΛSendMax              []ygot.Annotation `path:"state/@send-max" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) IsYANGGoStruct() {}

// GetEligiblePrefixPolicy retrieves the value of the leaf EligiblePrefixPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EligiblePrefixPolicy is set, it can safely use t.GetEligiblePrefixPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EligiblePrefixPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) GetEligiblePrefixPolicy() string {
	if t == nil || t.EligiblePrefixPolicy == nil {
		return ""
	}
	return *t.EligiblePrefixPolicy
}

// GetReceive retrieves the value of the leaf Receive from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Receive is set, it can safely use t.GetReceive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Receive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) GetReceive() bool {
	if t == nil || t.Receive == nil {
		return false
	}
	return *t.Receive
}

// GetSend retrieves the value of the leaf Send from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Send is set, it can safely use t.GetSend()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Send == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) GetSend() bool {
	if t == nil || t.Send == nil {
		return false
	}
	return *t.Send
}

// GetSendMax retrieves the value of the leaf SendMax from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendMax is set, it can safely use t.GetSendMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendMax == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) GetSendMax() uint8 {
	if t == nil || t.SendMax == nil {
		return 0
	}
	return *t.SendMax
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-network-instance"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-network-instance"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Advertised  *bool             `path:"state/advertised" module:"openconfig-network-instance"`
	ΛAdvertised []ygot.Annotation `path:"state/@advertised" ygotAnnotation:"true"`
	Enabled     *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled    []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	Received    *bool             `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// GetAdvertised retrieves the value of the leaf Advertised from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Advertised is set, it can safely use t.GetAdvertised()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Advertised == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart) GetAdvertised() bool {
	if t == nil || t.Advertised == nil {
		return false
	}
	return *t.Advertised
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart) GetReceived() bool {
	if t == nil || t.Received == nil {
		return false
	}
	return *t.Received
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                                             `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                             `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast struct {
	ΛMetadata         []ygot.Annotation                                                      `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit      []ygot.Annotation                                                      `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                                                  `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-network-instance"`
	ΛSendDefaultRoute []ygot.Annotation                                                      `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                                             `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                             `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast struct {
	ΛMetadata         []ygot.Annotation                                                      `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit      []ygot.Annotation                                                      `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                                                  `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-network-instance"`
	ΛSendDefaultRoute []ygot.Annotation                                                      `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn struct {
	ΛMetadata    []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                    `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls struct {
	ΛMetadata    []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                    `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast struct {
	ΛMetadata    []ygot.Annotation                                                             `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                             `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast struct {
	ΛMetadata    []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast struct {
	ΛMetadata    []ygot.Annotation                                                             `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                             `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast struct {
	ΛMetadata    []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                           `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/state/prefixes YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Installed          *uint32           `path:"installed" module:"openconfig-network-instance"`
	ΛInstalled         []ygot.Annotation `path:"@installed" ygotAnnotation:"true"`
	Received           *uint32           `path:"received" module:"openconfig-network-instance"`
	ΛReceived          []ygot.Annotation `path:"@received" ygotAnnotation:"true"`
	ReceivedPrePolicy  *uint32           `path:"received-pre-policy" module:"openconfig-network-instance"`
	ΛReceivedPrePolicy []ygot.Annotation `path:"@received-pre-policy" ygotAnnotation:"true"`
	Sent               *uint32           `path:"sent" module:"openconfig-network-instance"`
	ΛSent              []ygot.Annotation `path:"@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) IsYANGGoStruct() {}

// GetInstalled retrieves the value of the leaf Installed from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Installed is set, it can safely use t.GetInstalled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Installed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) GetInstalled() uint32 {
	if t == nil || t.Installed == nil {
		return 0
	}
	return *t.Installed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetReceivedPrePolicy retrieves the value of the leaf ReceivedPrePolicy from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReceivedPrePolicy is set, it can safely use t.GetReceivedPrePolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReceivedPrePolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) GetReceivedPrePolicy() uint32 {
	if t == nil || t.ReceivedPrePolicy == nil {
		return 0
	}
	return *t.ReceivedPrePolicy
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 struct {
	ΛMetadata    []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                         `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 struct {
	ΛMetadata    []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                         `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	Ebgp      *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-network-instance"`
	ΛEbgp     []ygot.Annotation                                                    `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                                                `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation                                                    `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths) GetOrCreateEbgp() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths) GetEbgp() *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-network-instance"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-network-instance"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-network-instance"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/as-path-options YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowOwnAs           *uint8            `path:"state/allow-own-as" shadow-path:"config/allow-own-as" module:"openconfig-network-instance"`
	ΛAllowOwnAs          []ygot.Annotation `path:"state/@allow-own-as" ygotAnnotation:"true"`
	DisablePeerAsFilter  *bool             `path:"state/disable-peer-as-filter" shadow-path:"config/disable-peer-as-filter" module:"openconfig-network-instance"`
	ΛDisablePeerAsFilter []ygot.Annotation `path:"state/@disable-peer-as-filter" ygotAnnotation:"true"`
	ReplacePeerAs        *bool             `path:"state/replace-peer-as" shadow-path:"config/replace-peer-as" module:"openconfig-network-instance"`
	ΛReplacePeerAs       []ygot.Annotation `path:"state/@replace-peer-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions) IsYANGGoStruct() {}

// GetAllowOwnAs retrieves the value of the leaf AllowOwnAs from the NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowOwnAs is set, it can safely use t.GetAllowOwnAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowOwnAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions) GetAllowOwnAs() uint8 {
	if t == nil || t.AllowOwnAs == nil {
		return 0
	}
	return *t.AllowOwnAs
}

// GetDisablePeerAsFilter retrieves the value of the leaf DisablePeerAsFilter from the NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DisablePeerAsFilter is set, it can safely use t.GetDisablePeerAsFilter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DisablePeerAsFilter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions) GetDisablePeerAsFilter() bool {
	if t == nil || t.DisablePeerAsFilter == nil {
		return false
	}
	return *t.DisablePeerAsFilter
}

// GetReplacePeerAs retrieves the value of the leaf ReplacePeerAs from the NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReplacePeerAs is set, it can safely use t.GetReplacePeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReplacePeerAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions) GetReplacePeerAs() bool {
	if t == nil || t.ReplacePeerAs == nil {
		return false
	}
	return *t.ReplacePeerAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/ebgp-multihop YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled      *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled     []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	MultihopTtl  *uint8            `path:"state/multihop-ttl" shadow-path:"config/multihop-ttl" module:"openconfig-network-instance"`
	ΛMultihopTtl []ygot.Annotation `path:"state/@multihop-ttl" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetMultihopTtl retrieves the value of the leaf MultihopTtl from the NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultihopTtl is set, it can safely use t.GetMultihopTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultihopTtl == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop) GetMultihopTtl() uint8 {
	if t == nil || t.MultihopTtl == nil {
		return 0
	}
	return *t.MultihopTtl
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/error-handling YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ErroneousUpdateMessages  *uint32           `path:"state/erroneous-update-messages" module:"openconfig-network-instance"`
	ΛErroneousUpdateMessages []ygot.Annotation `path:"state/@erroneous-update-messages" ygotAnnotation:"true"`
	TreatAsWithdraw          *bool             `path:"state/treat-as-withdraw" shadow-path:"config/treat-as-withdraw" module:"openconfig-network-instance"`
	ΛTreatAsWithdraw         []ygot.Annotation `path:"state/@treat-as-withdraw" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling) IsYANGGoStruct() {}

// GetErroneousUpdateMessages retrieves the value of the leaf ErroneousUpdateMessages from the NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ErroneousUpdateMessages is set, it can safely use t.GetErroneousUpdateMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ErroneousUpdateMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling) GetErroneousUpdateMessages() uint32 {
	if t == nil || t.ErroneousUpdateMessages == nil {
		return 0
	}
	return *t.ErroneousUpdateMessages
}

// GetTreatAsWithdraw retrieves the value of the leaf TreatAsWithdraw from the NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TreatAsWithdraw is set, it can safely use t.GetTreatAsWithdraw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TreatAsWithdraw == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling) GetTreatAsWithdraw() bool {
	if t == nil || t.TreatAsWithdraw == nil {
		return false
	}
	return *t.TreatAsWithdraw
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart struct {
	ΛMetadata        []ygot.Annotation      `path:"@" ygotAnnotation:"true"`
	Enabled          *bool                  `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled         []ygot.Annotation      `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly       *bool                  `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-network-instance"`
	ΛHelperOnly      []ygot.Annotation      `path:"state/@helper-only" ygotAnnotation:"true"`
	LocalRestarting  *bool                  `path:"state/local-restarting" module:"openconfig-network-instance"`
	ΛLocalRestarting []ygot.Annotation      `path:"state/@local-restarting" ygotAnnotation:"true"`
	Mode             E_GracefulRestart_Mode `path:"state/mode" module:"openconfig-network-instance"`
	ΛMode            []ygot.Annotation      `path:"state/@mode" ygotAnnotation:"true"`
	PeerRestartTime  *uint16                `path:"state/peer-restart-time" module:"openconfig-network-instance"`
	ΛPeerRestartTime []ygot.Annotation      `path:"state/@peer-restart-time" ygotAnnotation:"true"`
	PeerRestarting   *bool                  `path:"state/peer-restarting" module:"openconfig-network-instance"`
	ΛPeerRestarting  []ygot.Annotation      `path:"state/@peer-restarting" ygotAnnotation:"true"`
	RestartTime      *uint16                `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-network-instance"`
	ΛRestartTime     []ygot.Annotation      `path:"state/@restart-time" ygotAnnotation:"true"`
	StaleRoutesTime  *float64               `path:"state/stale-routes-time" shadow-path:"config/stale-routes-time" module:"openconfig-network-instance"`
	ΛStaleRoutesTime []ygot.Annotation      `path:"state/@stale-routes-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// GetLocalRestarting retrieves the value of the leaf LocalRestarting from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalRestarting is set, it can safely use t.GetLocalRestarting()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalRestarting == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetLocalRestarting() bool {
	if t == nil || t.LocalRestarting == nil {
		return false
	}
	return *t.LocalRestarting
}

// GetMode retrieves the value of the leaf Mode from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetMode() E_GracefulRestart_Mode {
	if t == nil || t.Mode == 0 {
		return 0
	}
	return t.Mode
}

// GetPeerRestartTime retrieves the value of the leaf PeerRestartTime from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerRestartTime is set, it can safely use t.GetPeerRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerRestartTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetPeerRestartTime() uint16 {
	if t == nil || t.PeerRestartTime == nil {
		return 0
	}
	return *t.PeerRestartTime
}

// GetPeerRestarting retrieves the value of the leaf PeerRestarting from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerRestarting is set, it can safely use t.GetPeerRestarting()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerRestarting == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetPeerRestarting() bool {
	if t == nil || t.PeerRestarting == nil {
		return false
	}
	return *t.PeerRestarting
}

// GetRestartTime retrieves the value of the leaf RestartTime from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetRestartTime() uint16 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// GetStaleRoutesTime retrieves the value of the leaf StaleRoutesTime from the NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StaleRoutesTime is set, it can safely use t.GetStaleRoutesTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StaleRoutesTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) GetStaleRoutesTime() float64 {
	if t == nil || t.StaleRoutesTime == nil {
		return 0.0
	}
	return *t.StaleRoutesTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/logging-options YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LogNeighborStateChanges  *bool             `path:"state/log-neighbor-state-changes" shadow-path:"config/log-neighbor-state-changes" module:"openconfig-network-instance"`
	ΛLogNeighborStateChanges []ygot.Annotation `path:"state/@log-neighbor-state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions) IsYANGGoStruct() {}

// GetLogNeighborStateChanges retrieves the value of the leaf LogNeighborStateChanges from the NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogNeighborStateChanges is set, it can safely use t.GetLogNeighborStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogNeighborStateChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions) GetLogNeighborStateChanges() bool {
	if t == nil || t.LogNeighborStateChanges == nil {
		return true
	}
	return *t.LogNeighborStateChanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_Messages represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_Messages struct {
	ΛMetadata []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	Received  *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received `path:"received" module:"openconfig-network-instance"`
	ΛReceived []ygot.Annotation                                        `path:"@received" ygotAnnotation:"true"`
	Sent      *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent     `path:"sent" module:"openconfig-network-instance"`
	ΛSent     []ygot.Annotation                                        `path:"@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_Messages) IsYANGGoStruct() {}

// GetOrCreateReceived retrieves the value of the Received field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages) GetOrCreateReceived() *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received {
	if t.Received != nil {
		return t.Received
	}
	t.Received = &NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received{}
	return t.Received
}

// GetOrCreateSent retrieves the value of the Sent field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages) GetOrCreateSent() *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent {
	if t.Sent != nil {
		return t.Sent
	}
	t.Sent = &NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent{}
	return t.Sent
}

// GetReceived returns the value of the Received struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_Messages. If the receiver or the field Received is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages) GetReceived() *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received {
	if t != nil && t.Received != nil {
		return t.Received
	}
	return nil
}

// GetSent returns the value of the Sent struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_Messages. If the receiver or the field Sent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages) GetSent() *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent {
	if t != nil && t.Sent != nil {
		return t.Sent
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/received YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received struct {
	ΛMetadata                     []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	NOTIFICATION                  *uint64                                `path:"NOTIFICATION" module:"openconfig-network-instance"`
	ΛNOTIFICATION                 []ygot.Annotation                      `path:"@NOTIFICATION" ygotAnnotation:"true"`
	UPDATE                        *uint64                                `path:"UPDATE" module:"openconfig-network-instance"`
	ΛUPDATE                       []ygot.Annotation                      `path:"@UPDATE" ygotAnnotation:"true"`
	LastNotificationErrorCode     E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-network-instance"`
	ΛLastNotificationErrorCode    []ygot.Annotation                      `path:"@last-notification-error-code" ygotAnnotation:"true"`
	LastNotificationErrorSubcode  E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-network-instance"`
	ΛLastNotificationErrorSubcode []ygot.Annotation                      `path:"@last-notification-error-subcode" ygotAnnotation:"true"`
	LastNotificationTime          *uint64                                `path:"last-notification-time" module:"openconfig-network-instance"`
	ΛLastNotificationTime         []ygot.Annotation                      `path:"@last-notification-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) IsYANGGoStruct() {}

// GetNOTIFICATION retrieves the value of the leaf NOTIFICATION from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NOTIFICATION is set, it can safely use t.GetNOTIFICATION()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NOTIFICATION == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) GetNOTIFICATION() uint64 {
	if t == nil || t.NOTIFICATION == nil {
		return 0
	}
	return *t.NOTIFICATION
}

// GetUPDATE retrieves the value of the leaf UPDATE from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UPDATE is set, it can safely use t.GetUPDATE()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UPDATE == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) GetUPDATE() uint64 {
	if t == nil || t.UPDATE == nil {
		return 0
	}
	return *t.UPDATE
}

// GetLastNotificationErrorCode retrieves the value of the leaf LastNotificationErrorCode from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorCode is set, it can safely use t.GetLastNotificationErrorCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorCode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) GetLastNotificationErrorCode() E_OpenconfigBgpTypes_BGP_ERROR_CODE {
	if t == nil || t.LastNotificationErrorCode == 0 {
		return 0
	}
	return t.LastNotificationErrorCode
}

// GetLastNotificationErrorSubcode retrieves the value of the leaf LastNotificationErrorSubcode from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorSubcode is set, it can safely use t.GetLastNotificationErrorSubcode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorSubcode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) GetLastNotificationErrorSubcode() E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE {
	if t == nil || t.LastNotificationErrorSubcode == 0 {
		return 0
	}
	return t.LastNotificationErrorSubcode
}

// GetLastNotificationTime retrieves the value of the leaf LastNotificationTime from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationTime is set, it can safely use t.GetLastNotificationTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) GetLastNotificationTime() uint64 {
	if t == nil || t.LastNotificationTime == nil {
		return 0
	}
	return *t.LastNotificationTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Received) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/sent YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent struct {
	ΛMetadata                     []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	NOTIFICATION                  *uint64                                `path:"NOTIFICATION" module:"openconfig-network-instance"`
	ΛNOTIFICATION                 []ygot.Annotation                      `path:"@NOTIFICATION" ygotAnnotation:"true"`
	UPDATE                        *uint64                                `path:"UPDATE" module:"openconfig-network-instance"`
	ΛUPDATE                       []ygot.Annotation                      `path:"@UPDATE" ygotAnnotation:"true"`
	LastNotificationErrorCode     E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-network-instance"`
	ΛLastNotificationErrorCode    []ygot.Annotation                      `path:"@last-notification-error-code" ygotAnnotation:"true"`
	LastNotificationErrorSubcode  E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-network-instance"`
	ΛLastNotificationErrorSubcode []ygot.Annotation                      `path:"@last-notification-error-subcode" ygotAnnotation:"true"`
	LastNotificationTime          *uint64                                `path:"last-notification-time" module:"openconfig-network-instance"`
	ΛLastNotificationTime         []ygot.Annotation                      `path:"@last-notification-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) IsYANGGoStruct() {}

// GetNOTIFICATION retrieves the value of the leaf NOTIFICATION from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NOTIFICATION is set, it can safely use t.GetNOTIFICATION()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NOTIFICATION == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) GetNOTIFICATION() uint64 {
	if t == nil || t.NOTIFICATION == nil {
		return 0
	}
	return *t.NOTIFICATION
}

// GetUPDATE retrieves the value of the leaf UPDATE from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UPDATE is set, it can safely use t.GetUPDATE()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UPDATE == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) GetUPDATE() uint64 {
	if t == nil || t.UPDATE == nil {
		return 0
	}
	return *t.UPDATE
}

// GetLastNotificationErrorCode retrieves the value of the leaf LastNotificationErrorCode from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorCode is set, it can safely use t.GetLastNotificationErrorCode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorCode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) GetLastNotificationErrorCode() E_OpenconfigBgpTypes_BGP_ERROR_CODE {
	if t == nil || t.LastNotificationErrorCode == 0 {
		return 0
	}
	return t.LastNotificationErrorCode
}

// GetLastNotificationErrorSubcode retrieves the value of the leaf LastNotificationErrorSubcode from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationErrorSubcode is set, it can safely use t.GetLastNotificationErrorSubcode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationErrorSubcode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) GetLastNotificationErrorSubcode() E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE {
	if t == nil || t.LastNotificationErrorSubcode == 0 {
		return 0
	}
	return t.LastNotificationErrorSubcode
}

// GetLastNotificationTime retrieves the value of the leaf LastNotificationTime from the NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastNotificationTime is set, it can safely use t.GetLastNotificationTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastNotificationTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) GetLastNotificationTime() uint64 {
	if t == nil || t.LastNotificationTime == nil {
		return 0
	}
	return *t.LastNotificationTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Messages_Sent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_Queues represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/queues YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_Queues struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Input     *uint32           `path:"input" module:"openconfig-network-instance"`
	ΛInput    []ygot.Annotation `path:"@input" ygotAnnotation:"true"`
	Output    *uint32           `path:"output" module:"openconfig-network-instance"`
	ΛOutput   []ygot.Annotation `path:"@output" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_Queues implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_Queues) IsYANGGoStruct() {}

// GetInput retrieves the value of the leaf Input from the NetworkInstance_Protocol_Bgp_Neighbor_Queues
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Input is set, it can safely use t.GetInput()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Input == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Queues) GetInput() uint32 {
	if t == nil || t.Input == nil {
		return 0
	}
	return *t.Input
}

// GetOutput retrieves the value of the leaf Output from the NetworkInstance_Protocol_Bgp_Neighbor_Queues
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Output is set, it can safely use t.GetOutput()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Output == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Queues) GetOutput() uint32 {
	if t == nil || t.Output == nil {
		return 0
	}
	return *t.Output
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Queues) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_Queues"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Queues) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector struct {
	ΛMetadata                []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	RouteReflectorClient     *bool                                                                              `path:"state/route-reflector-client" shadow-path:"config/route-reflector-client" module:"openconfig-network-instance"`
	ΛRouteReflectorClient    []ygot.Annotation                                                                  `path:"state/@route-reflector-client" ygotAnnotation:"true"`
	RouteReflectorClusterId  NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union `path:"state/route-reflector-cluster-id" shadow-path:"config/route-reflector-cluster-id" module:"openconfig-network-instance"`
	ΛRouteReflectorClusterId []ygot.Annotation                                                                  `path:"state/@route-reflector-cluster-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector) IsYANGGoStruct() {}

// GetRouteReflectorClient retrieves the value of the leaf RouteReflectorClient from the NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClient is set, it can safely use t.GetRouteReflectorClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClient == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector) GetRouteReflectorClient() bool {
	if t == nil || t.RouteReflectorClient == nil {
		return false
	}
	return *t.RouteReflectorClient
}

// GetRouteReflectorClusterId retrieves the value of the leaf RouteReflectorClusterId from the NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClusterId is set, it can safely use t.GetRouteReflectorClusterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClusterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector) GetRouteReflectorClusterId() NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union {
	if t == nil || t.RouteReflectorClusterId == nil {
		return nil
	}
	return t.RouteReflectorClusterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union() {
}

// To_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector) To_NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Neighbor_RouteReflector_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Bgp_Neighbor_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/timers YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_Timers struct {
	ΛMetadata                     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ConnectRetry                  *float64          `path:"state/connect-retry" shadow-path:"config/connect-retry" module:"openconfig-network-instance"`
	ΛConnectRetry                 []ygot.Annotation `path:"state/@connect-retry" ygotAnnotation:"true"`
	HoldTime                      *float64          `path:"state/hold-time" shadow-path:"config/hold-time" module:"openconfig-network-instance"`
	ΛHoldTime                     []ygot.Annotation `path:"state/@hold-time" ygotAnnotation:"true"`
	KeepaliveInterval             *float64          `path:"state/keepalive-interval" shadow-path:"config/keepalive-interval" module:"openconfig-network-instance"`
	ΛKeepaliveInterval            []ygot.Annotation `path:"state/@keepalive-interval" ygotAnnotation:"true"`
	MinimumAdvertisementInterval  *float64          `path:"state/minimum-advertisement-interval" shadow-path:"config/minimum-advertisement-interval" module:"openconfig-network-instance"`
	ΛMinimumAdvertisementInterval []ygot.Annotation `path:"state/@minimum-advertisement-interval" ygotAnnotation:"true"`
	NegotiatedHoldTime            *float64          `path:"state/negotiated-hold-time" module:"openconfig-network-instance"`
	ΛNegotiatedHoldTime           []ygot.Annotation `path:"state/@negotiated-hold-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_Timers) IsYANGGoStruct() {}

// GetConnectRetry retrieves the value of the leaf ConnectRetry from the NetworkInstance_Protocol_Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectRetry is set, it can safely use t.GetConnectRetry()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectRetry == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) GetConnectRetry() float64 {
	if t == nil || t.ConnectRetry == nil {
		return 30
	}
	return *t.ConnectRetry
}

// GetHoldTime retrieves the value of the leaf HoldTime from the NetworkInstance_Protocol_Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) GetHoldTime() float64 {
	if t == nil || t.HoldTime == nil {
		return 90
	}
	return *t.HoldTime
}

// GetKeepaliveInterval retrieves the value of the leaf KeepaliveInterval from the NetworkInstance_Protocol_Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeepaliveInterval is set, it can safely use t.GetKeepaliveInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeepaliveInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) GetKeepaliveInterval() float64 {
	if t == nil || t.KeepaliveInterval == nil {
		return 30
	}
	return *t.KeepaliveInterval
}

// GetMinimumAdvertisementInterval retrieves the value of the leaf MinimumAdvertisementInterval from the NetworkInstance_Protocol_Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinimumAdvertisementInterval is set, it can safely use t.GetMinimumAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinimumAdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) GetMinimumAdvertisementInterval() float64 {
	if t == nil || t.MinimumAdvertisementInterval == nil {
		return 30
	}
	return *t.MinimumAdvertisementInterval
}

// GetNegotiatedHoldTime retrieves the value of the leaf NegotiatedHoldTime from the NetworkInstance_Protocol_Bgp_Neighbor_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NegotiatedHoldTime is set, it can safely use t.GetNegotiatedHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NegotiatedHoldTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) GetNegotiatedHoldTime() float64 {
	if t == nil || t.NegotiatedHoldTime == nil {
		return 0.0
	}
	return *t.NegotiatedHoldTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_Transport represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/transport YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_Transport struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LocalAddress   *string           `path:"state/local-address" shadow-path:"config/local-address" module:"openconfig-network-instance"`
	ΛLocalAddress  []ygot.Annotation `path:"state/@local-address" ygotAnnotation:"true"`
	LocalPort      *uint16           `path:"state/local-port" module:"openconfig-network-instance"`
	ΛLocalPort     []ygot.Annotation `path:"state/@local-port" ygotAnnotation:"true"`
	MtuDiscovery   *bool             `path:"state/mtu-discovery" shadow-path:"config/mtu-discovery" module:"openconfig-network-instance"`
	ΛMtuDiscovery  []ygot.Annotation `path:"state/@mtu-discovery" ygotAnnotation:"true"`
	PassiveMode    *bool             `path:"state/passive-mode" shadow-path:"config/passive-mode" module:"openconfig-network-instance"`
	ΛPassiveMode   []ygot.Annotation `path:"state/@passive-mode" ygotAnnotation:"true"`
	RemoteAddress  *string           `path:"state/remote-address" module:"openconfig-network-instance"`
	ΛRemoteAddress []ygot.Annotation `path:"state/@remote-address" ygotAnnotation:"true"`
	RemotePort     *uint16           `path:"state/remote-port" module:"openconfig-network-instance"`
	ΛRemotePort    []ygot.Annotation `path:"state/@remote-port" ygotAnnotation:"true"`
	TcpMss         *uint16           `path:"state/tcp-mss" shadow-path:"config/tcp-mss" module:"openconfig-network-instance"`
	ΛTcpMss        []ygot.Annotation `path:"state/@tcp-mss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_Transport) IsYANGGoStruct() {}

// GetLocalAddress retrieves the value of the leaf LocalAddress from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAddress is set, it can safely use t.GetLocalAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetLocalAddress() string {
	if t == nil || t.LocalAddress == nil {
		return ""
	}
	return *t.LocalAddress
}

// GetLocalPort retrieves the value of the leaf LocalPort from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalPort is set, it can safely use t.GetLocalPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalPort == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetLocalPort() uint16 {
	if t == nil || t.LocalPort == nil {
		return 0
	}
	return *t.LocalPort
}

// GetMtuDiscovery retrieves the value of the leaf MtuDiscovery from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtuDiscovery is set, it can safely use t.GetMtuDiscovery()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtuDiscovery == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetMtuDiscovery() bool {
	if t == nil || t.MtuDiscovery == nil {
		return false
	}
	return *t.MtuDiscovery
}

// GetPassiveMode retrieves the value of the leaf PassiveMode from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PassiveMode is set, it can safely use t.GetPassiveMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PassiveMode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetPassiveMode() bool {
	if t == nil || t.PassiveMode == nil {
		return false
	}
	return *t.PassiveMode
}

// GetRemoteAddress retrieves the value of the leaf RemoteAddress from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteAddress is set, it can safely use t.GetRemoteAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetRemoteAddress() string {
	if t == nil || t.RemoteAddress == nil {
		return ""
	}
	return *t.RemoteAddress
}

// GetRemotePort retrieves the value of the leaf RemotePort from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemotePort is set, it can safely use t.GetRemotePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemotePort == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetRemotePort() uint16 {
	if t == nil || t.RemotePort == nil {
		return 0
	}
	return *t.RemotePort
}

// GetTcpMss retrieves the value of the leaf TcpMss from the NetworkInstance_Protocol_Bgp_Neighbor_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TcpMss is set, it can safely use t.GetTcpMss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TcpMss == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) GetTcpMss() uint16 {
	if t == nil || t.TcpMss == nil {
		return 0
	}
	return *t.TcpMss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	Ebgp      *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-network-instance"`
	ΛEbgp     []ygot.Annotation                                            `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                                        `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation                                            `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths) GetOrCreateEbgp() *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths) GetEbgp() *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths/ebgp YANG schema element.
type NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-network-instance"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Neighbor_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup struct {
	ΛMetadata         []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	AfiSafi           map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-network-instance"`
	ΛAfiSafi          []ygot.Annotation                                                                      `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	ApplyPolicy       *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy                                    `path:"apply-policy" module:"openconfig-network-instance"`
	ΛApplyPolicy      []ygot.Annotation                                                                      `path:"@apply-policy" ygotAnnotation:"true"`
	AsPathOptions     *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions                                  `path:"as-path-options" module:"openconfig-network-instance"`
	ΛAsPathOptions    []ygot.Annotation                                                                      `path:"@as-path-options" ygotAnnotation:"true"`
	AuthPassword      *string                                                                                `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-network-instance"`
	ΛAuthPassword     []ygot.Annotation                                                                      `path:"state/@auth-password" ygotAnnotation:"true"`
	Description       *string                                                                                `path:"state/description" shadow-path:"config/description" module:"openconfig-network-instance"`
	ΛDescription      []ygot.Annotation                                                                      `path:"state/@description" ygotAnnotation:"true"`
	EbgpMultihop      *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop                                   `path:"ebgp-multihop" module:"openconfig-network-instance"`
	ΛEbgpMultihop     []ygot.Annotation                                                                      `path:"@ebgp-multihop" ygotAnnotation:"true"`
	ErrorHandling     *NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling                                  `path:"error-handling" module:"openconfig-network-instance"`
	ΛErrorHandling    []ygot.Annotation                                                                      `path:"@error-handling" ygotAnnotation:"true"`
	GracefulRestart   *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart                                `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart  []ygot.Annotation                                                                      `path:"@graceful-restart" ygotAnnotation:"true"`
	LocalAs           *uint32                                                                                `path:"state/local-as" shadow-path:"config/local-as" module:"openconfig-network-instance"`
	ΛLocalAs          []ygot.Annotation                                                                      `path:"state/@local-as" ygotAnnotation:"true"`
	LoggingOptions    *NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions                                 `path:"logging-options" module:"openconfig-network-instance"`
	ΛLoggingOptions   []ygot.Annotation                                                                      `path:"@logging-options" ygotAnnotation:"true"`
	PeerAs            *uint32                                                                                `path:"state/peer-as" shadow-path:"config/peer-as" module:"openconfig-network-instance"`
	ΛPeerAs           []ygot.Annotation                                                                      `path:"state/@peer-as" ygotAnnotation:"true"`
	PeerGroupName     *string                                                                                `path:"state/peer-group-name|peer-group-name" shadow-path:"config/peer-group-name" module:"openconfig-network-instance"`
	ΛPeerGroupName    []ygot.Annotation                                                                      `path:"state/@peer-group-name|@peer-group-name" ygotAnnotation:"true"`
	PeerType          E_OpenconfigBgpTypes_PeerType                                                          `path:"state/peer-type" shadow-path:"config/peer-type" module:"openconfig-network-instance"`
	ΛPeerType         []ygot.Annotation                                                                      `path:"state/@peer-type" ygotAnnotation:"true"`
	RemovePrivateAs   E_OpenconfigBgpTypes_RemovePrivateAsOption                                             `path:"state/remove-private-as" shadow-path:"config/remove-private-as" module:"openconfig-network-instance"`
	ΛRemovePrivateAs  []ygot.Annotation                                                                      `path:"state/@remove-private-as" ygotAnnotation:"true"`
	RouteFlapDamping  *bool                                                                                  `path:"state/route-flap-damping" shadow-path:"config/route-flap-damping" module:"openconfig-network-instance"`
	ΛRouteFlapDamping []ygot.Annotation                                                                      `path:"state/@route-flap-damping" ygotAnnotation:"true"`
	RouteReflector    *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector                                 `path:"route-reflector" module:"openconfig-network-instance"`
	ΛRouteReflector   []ygot.Annotation                                                                      `path:"@route-reflector" ygotAnnotation:"true"`
	SendCommunity     E_OpenconfigBgpTypes_CommunityType                                                     `path:"state/send-community" shadow-path:"config/send-community" module:"openconfig-network-instance"`
	ΛSendCommunity    []ygot.Annotation                                                                      `path:"state/@send-community" ygotAnnotation:"true"`
	Timers            *NetworkInstance_Protocol_Bgp_PeerGroup_Timers                                         `path:"timers" module:"openconfig-network-instance"`
	ΛTimers           []ygot.Annotation                                                                      `path:"@timers" ygotAnnotation:"true"`
	TotalPaths        *uint32                                                                                `path:"state/total-paths" module:"openconfig-network-instance"`
	ΛTotalPaths       []ygot.Annotation                                                                      `path:"state/@total-paths" ygotAnnotation:"true"`
	TotalPrefixes     *uint32                                                                                `path:"state/total-prefixes" module:"openconfig-network-instance"`
	ΛTotalPrefixes    []ygot.Annotation                                                                      `path:"state/@total-prefixes" ygotAnnotation:"true"`
	Transport         *NetworkInstance_Protocol_Bgp_PeerGroup_Transport                                      `path:"transport" module:"openconfig-network-instance"`
	ΛTransport        []ygot.Annotation                                                                      `path:"@transport" ygotAnnotation:"true"`
	UseMultiplePaths  *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths                               `path:"use-multiple-paths" module:"openconfig-network-instance"`
	ΛUseMultiplePaths []ygot.Annotation                                                                      `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// NetworkInstance_Protocol_Bgp_PeerGroup struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the NetworkInstance_Protocol_Bgp_PeerGroup struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_PeerGroup. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi struct to the
// list AfiSafi of NetworkInstance_Protocol_Bgp_PeerGroup. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) AppendAfiSafi(v *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateApplyPolicy() *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateAsPathOptions retrieves the value of the AsPathOptions field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateAsPathOptions() *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions {
	if t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	t.AsPathOptions = &NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions{}
	return t.AsPathOptions
}

// GetOrCreateEbgpMultihop retrieves the value of the EbgpMultihop field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateEbgpMultihop() *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop {
	if t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	t.EbgpMultihop = &NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop{}
	return t.EbgpMultihop
}

// GetOrCreateErrorHandling retrieves the value of the ErrorHandling field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateErrorHandling() *NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling {
	if t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	t.ErrorHandling = &NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling{}
	return t.ErrorHandling
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateLoggingOptions retrieves the value of the LoggingOptions field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateLoggingOptions() *NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions {
	if t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	t.LoggingOptions = &NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions{}
	return t.LoggingOptions
}

// GetOrCreateRouteReflector retrieves the value of the RouteReflector field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateRouteReflector() *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector {
	if t.RouteReflector != nil {
		return t.RouteReflector
	}
	t.RouteReflector = &NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector{}
	return t.RouteReflector
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateTimers() *NetworkInstance_Protocol_Bgp_PeerGroup_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Bgp_PeerGroup_Timers{}
	return t.Timers
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateTransport() *NetworkInstance_Protocol_Bgp_PeerGroup_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &NetworkInstance_Protocol_Bgp_PeerGroup_Transport{}
	return t.Transport
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetOrCreateUseMultiplePaths() *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetApplyPolicy() *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetAsPathOptions returns the value of the AsPathOptions struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field AsPathOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetAsPathOptions() *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions {
	if t != nil && t.AsPathOptions != nil {
		return t.AsPathOptions
	}
	return nil
}

// GetEbgpMultihop returns the value of the EbgpMultihop struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field EbgpMultihop is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetEbgpMultihop() *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop {
	if t != nil && t.EbgpMultihop != nil {
		return t.EbgpMultihop
	}
	return nil
}

// GetErrorHandling returns the value of the ErrorHandling struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field ErrorHandling is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetErrorHandling() *NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling {
	if t != nil && t.ErrorHandling != nil {
		return t.ErrorHandling
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetGracefulRestart() *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetLoggingOptions returns the value of the LoggingOptions struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field LoggingOptions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetLoggingOptions() *NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions {
	if t != nil && t.LoggingOptions != nil {
		return t.LoggingOptions
	}
	return nil
}

// GetRouteReflector returns the value of the RouteReflector struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field RouteReflector is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetRouteReflector() *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector {
	if t != nil && t.RouteReflector != nil {
		return t.RouteReflector
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetTimers() *NetworkInstance_Protocol_Bgp_PeerGroup_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetTransport() *NetworkInstance_Protocol_Bgp_PeerGroup_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetUseMultiplePaths() *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// GetDescription retrieves the value of the leaf Description from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetLocalAs retrieves the value of the leaf LocalAs from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAs is set, it can safely use t.GetLocalAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetLocalAs() uint32 {
	if t == nil || t.LocalAs == nil {
		return 0
	}
	return *t.LocalAs
}

// GetPeerAs retrieves the value of the leaf PeerAs from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerAs is set, it can safely use t.GetPeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetPeerAs() uint32 {
	if t == nil || t.PeerAs == nil {
		return 0
	}
	return *t.PeerAs
}

// GetPeerGroupName retrieves the value of the leaf PeerGroupName from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerGroupName is set, it can safely use t.GetPeerGroupName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerGroupName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetPeerGroupName() string {
	if t == nil || t.PeerGroupName == nil {
		return ""
	}
	return *t.PeerGroupName
}

// GetPeerType retrieves the value of the leaf PeerType from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PeerType is set, it can safely use t.GetPeerType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PeerType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetPeerType() E_OpenconfigBgpTypes_PeerType {
	if t == nil || t.PeerType == 0 {
		return 0
	}
	return t.PeerType
}

// GetRemovePrivateAs retrieves the value of the leaf RemovePrivateAs from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemovePrivateAs is set, it can safely use t.GetRemovePrivateAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemovePrivateAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetRemovePrivateAs() E_OpenconfigBgpTypes_RemovePrivateAsOption {
	if t == nil || t.RemovePrivateAs == 0 {
		return 0
	}
	return t.RemovePrivateAs
}

// GetRouteFlapDamping retrieves the value of the leaf RouteFlapDamping from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteFlapDamping is set, it can safely use t.GetRouteFlapDamping()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteFlapDamping == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetRouteFlapDamping() bool {
	if t == nil || t.RouteFlapDamping == nil {
		return false
	}
	return *t.RouteFlapDamping
}

// GetSendCommunity retrieves the value of the leaf SendCommunity from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendCommunity is set, it can safely use t.GetSendCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendCommunity == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetSendCommunity() E_OpenconfigBgpTypes_CommunityType {
	if t == nil || t.SendCommunity == 0 {
		return OpenconfigBgpTypes_CommunityType_NONE
	}
	return t.SendCommunity
}

// GetTotalPaths retrieves the value of the leaf TotalPaths from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPaths is set, it can safely use t.GetTotalPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetTotalPaths() uint32 {
	if t == nil || t.TotalPaths == nil {
		return 0
	}
	return *t.TotalPaths
}

// GetTotalPrefixes retrieves the value of the leaf TotalPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalPrefixes is set, it can safely use t.GetTotalPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) GetTotalPrefixes() uint32 {
	if t == nil || t.TotalPrefixes == nil {
		return 0
	}
	return *t.TotalPrefixes
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_PeerGroup struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PeerGroupName == nil {
		return nil, fmt.Errorf("nil value for key PeerGroupName")
	}

	return map[string]interface{}{
		"peer-group-name": *t.PeerGroupName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi struct {
	ΛMetadata           []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	AddPaths            *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-network-instance"`
	ΛAddPaths           []ygot.Annotation                                                  `path:"@add-paths" ygotAnnotation:"true"`
	AfiSafiName         E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                 `path:"state/afi-safi-name|afi-safi-name" shadow-path:"config/afi-safi-name" module:"openconfig-network-instance"`
	ΛAfiSafiName        []ygot.Annotation                                                  `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	ApplyPolicy         *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-network-instance"`
	ΛApplyPolicy        []ygot.Annotation                                                  `path:"@apply-policy" ygotAnnotation:"true"`
	Enabled             *bool                                                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation                                                  `path:"state/@enabled" ygotAnnotation:"true"`
	GracefulRestart     *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart    []ygot.Annotation                                                  `path:"@graceful-restart" ygotAnnotation:"true"`
	Ipv4LabeledUnicast  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-network-instance"`
	ΛIpv4LabeledUnicast []ygot.Annotation                                                  `path:"@ipv4-labeled-unicast" ygotAnnotation:"true"`
	Ipv4Unicast         *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-network-instance"`
	ΛIpv4Unicast        []ygot.Annotation                                                  `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6LabeledUnicast  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-network-instance"`
	ΛIpv6LabeledUnicast []ygot.Annotation                                                  `path:"@ipv6-labeled-unicast" ygotAnnotation:"true"`
	Ipv6Unicast         *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-network-instance"`
	ΛIpv6Unicast        []ygot.Annotation                                                  `path:"@ipv6-unicast" ygotAnnotation:"true"`
	L2VpnEvpn           *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-network-instance"`
	ΛL2VpnEvpn          []ygot.Annotation                                                  `path:"@l2vpn-evpn" ygotAnnotation:"true"`
	L2VpnVpls           *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-network-instance"`
	ΛL2VpnVpls          []ygot.Annotation                                                  `path:"@l2vpn-vpls" ygotAnnotation:"true"`
	L3VpnIpv4Multicast  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv4Multicast []ygot.Annotation                                                  `path:"@l3vpn-ipv4-multicast" ygotAnnotation:"true"`
	L3VpnIpv4Unicast    *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv4Unicast   []ygot.Annotation                                                  `path:"@l3vpn-ipv4-unicast" ygotAnnotation:"true"`
	L3VpnIpv6Multicast  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv6Multicast []ygot.Annotation                                                  `path:"@l3vpn-ipv6-multicast" ygotAnnotation:"true"`
	L3VpnIpv6Unicast    *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-network-instance"`
	ΛL3VpnIpv6Unicast   []ygot.Annotation                                                  `path:"@l3vpn-ipv6-unicast" ygotAnnotation:"true"`
	SrtePolicyIpv4      *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-network-instance"`
	ΛSrtePolicyIpv4     []ygot.Annotation                                                  `path:"@srte-policy-ipv4" ygotAnnotation:"true"`
	SrtePolicyIpv6      *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-network-instance"`
	ΛSrtePolicyIpv6     []ygot.Annotation                                                  `path:"@srte-policy-ipv6" ygotAnnotation:"true"`
	UseMultiplePaths    *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-network-instance"`
	ΛUseMultiplePaths   []ygot.Annotation                                                  `path:"@use-multiple-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateAddPaths retrieves the value of the AddPaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateAddPaths() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths {
	if t.AddPaths != nil {
		return t.AddPaths
	}
	t.AddPaths = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths{}
	return t.AddPaths
}

// GetOrCreateApplyPolicy retrieves the value of the ApplyPolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateApplyPolicy() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy {
	if t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	t.ApplyPolicy = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy{}
	return t.ApplyPolicy
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateIpv4LabeledUnicast retrieves the value of the Ipv4LabeledUnicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateIpv4LabeledUnicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast {
	if t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	t.Ipv4LabeledUnicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast{}
	return t.Ipv4LabeledUnicast
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateIpv4Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6LabeledUnicast retrieves the value of the Ipv6LabeledUnicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateIpv6LabeledUnicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast {
	if t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	t.Ipv6LabeledUnicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast{}
	return t.Ipv6LabeledUnicast
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateIpv6Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetOrCreateL2VpnEvpn retrieves the value of the L2VpnEvpn field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateL2VpnEvpn() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn {
	if t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	t.L2VpnEvpn = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn{}
	return t.L2VpnEvpn
}

// GetOrCreateL2VpnVpls retrieves the value of the L2VpnVpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateL2VpnVpls() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls {
	if t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	t.L2VpnVpls = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls{}
	return t.L2VpnVpls
}

// GetOrCreateL3VpnIpv4Multicast retrieves the value of the L3VpnIpv4Multicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv4Multicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast {
	if t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	t.L3VpnIpv4Multicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast{}
	return t.L3VpnIpv4Multicast
}

// GetOrCreateL3VpnIpv4Unicast retrieves the value of the L3VpnIpv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv4Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast {
	if t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	t.L3VpnIpv4Unicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast{}
	return t.L3VpnIpv4Unicast
}

// GetOrCreateL3VpnIpv6Multicast retrieves the value of the L3VpnIpv6Multicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv6Multicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast {
	if t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	t.L3VpnIpv6Multicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast{}
	return t.L3VpnIpv6Multicast
}

// GetOrCreateL3VpnIpv6Unicast retrieves the value of the L3VpnIpv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateL3VpnIpv6Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast {
	if t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	t.L3VpnIpv6Unicast = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast{}
	return t.L3VpnIpv6Unicast
}

// GetOrCreateSrtePolicyIpv4 retrieves the value of the SrtePolicyIpv4 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateSrtePolicyIpv4() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 {
	if t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	t.SrtePolicyIpv4 = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4{}
	return t.SrtePolicyIpv4
}

// GetOrCreateSrtePolicyIpv6 retrieves the value of the SrtePolicyIpv6 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateSrtePolicyIpv6() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 {
	if t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	t.SrtePolicyIpv6 = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6{}
	return t.SrtePolicyIpv6
}

// GetOrCreateUseMultiplePaths retrieves the value of the UseMultiplePaths field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetOrCreateUseMultiplePaths() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths {
	if t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	t.UseMultiplePaths = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths{}
	return t.UseMultiplePaths
}

// GetAddPaths returns the value of the AddPaths struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field AddPaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetAddPaths() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths {
	if t != nil && t.AddPaths != nil {
		return t.AddPaths
	}
	return nil
}

// GetApplyPolicy returns the value of the ApplyPolicy struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field ApplyPolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetApplyPolicy() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy {
	if t != nil && t.ApplyPolicy != nil {
		return t.ApplyPolicy
	}
	return nil
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetGracefulRestart() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetIpv4LabeledUnicast returns the value of the Ipv4LabeledUnicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv4LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetIpv4LabeledUnicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast {
	if t != nil && t.Ipv4LabeledUnicast != nil {
		return t.Ipv4LabeledUnicast
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetIpv4Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6LabeledUnicast returns the value of the Ipv6LabeledUnicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv6LabeledUnicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetIpv6LabeledUnicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast {
	if t != nil && t.Ipv6LabeledUnicast != nil {
		return t.Ipv6LabeledUnicast
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetIpv6Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetL2VpnEvpn returns the value of the L2VpnEvpn struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field L2VpnEvpn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetL2VpnEvpn() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn {
	if t != nil && t.L2VpnEvpn != nil {
		return t.L2VpnEvpn
	}
	return nil
}

// GetL2VpnVpls returns the value of the L2VpnVpls struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field L2VpnVpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetL2VpnVpls() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls {
	if t != nil && t.L2VpnVpls != nil {
		return t.L2VpnVpls
	}
	return nil
}

// GetL3VpnIpv4Multicast returns the value of the L3VpnIpv4Multicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv4Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetL3VpnIpv4Multicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast {
	if t != nil && t.L3VpnIpv4Multicast != nil {
		return t.L3VpnIpv4Multicast
	}
	return nil
}

// GetL3VpnIpv4Unicast returns the value of the L3VpnIpv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetL3VpnIpv4Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast {
	if t != nil && t.L3VpnIpv4Unicast != nil {
		return t.L3VpnIpv4Unicast
	}
	return nil
}

// GetL3VpnIpv6Multicast returns the value of the L3VpnIpv6Multicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv6Multicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetL3VpnIpv6Multicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast {
	if t != nil && t.L3VpnIpv6Multicast != nil {
		return t.L3VpnIpv6Multicast
	}
	return nil
}

// GetL3VpnIpv6Unicast returns the value of the L3VpnIpv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field L3VpnIpv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetL3VpnIpv6Unicast() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast {
	if t != nil && t.L3VpnIpv6Unicast != nil {
		return t.L3VpnIpv6Unicast
	}
	return nil
}

// GetSrtePolicyIpv4 returns the value of the SrtePolicyIpv4 struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field SrtePolicyIpv4 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetSrtePolicyIpv4() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 {
	if t != nil && t.SrtePolicyIpv4 != nil {
		return t.SrtePolicyIpv4
	}
	return nil
}

// GetSrtePolicyIpv6 returns the value of the SrtePolicyIpv6 struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field SrtePolicyIpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetSrtePolicyIpv6() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 {
	if t != nil && t.SrtePolicyIpv6 != nil {
		return t.SrtePolicyIpv6
	}
	return nil
}

// GetUseMultiplePaths returns the value of the UseMultiplePaths struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi. If the receiver or the field UseMultiplePaths is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetUseMultiplePaths() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths {
	if t != nil && t.UseMultiplePaths != nil {
		return t.UseMultiplePaths
	}
	return nil
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EligiblePrefixPolicy  *string           `path:"state/eligible-prefix-policy" shadow-path:"config/eligible-prefix-policy" module:"openconfig-network-instance"`
	ΛEligiblePrefixPolicy []ygot.Annotation `path:"state/@eligible-prefix-policy" ygotAnnotation:"true"`
	Receive               *bool             `path:"state/receive" shadow-path:"config/receive" module:"openconfig-network-instance"`
	ΛReceive              []ygot.Annotation `path:"state/@receive" ygotAnnotation:"true"`
	Send                  *bool             `path:"state/send" shadow-path:"config/send" module:"openconfig-network-instance"`
	ΛSend                 []ygot.Annotation `path:"state/@send" ygotAnnotation:"true"`
	SendMax               *uint8            `path:"state/send-max" shadow-path:"config/send-max" module:"openconfig-network-instance"`
	ΛSendMax              []ygot.Annotation `path:"state/@send-max" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) IsYANGGoStruct() {}

// GetEligiblePrefixPolicy retrieves the value of the leaf EligiblePrefixPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EligiblePrefixPolicy is set, it can safely use t.GetEligiblePrefixPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EligiblePrefixPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) GetEligiblePrefixPolicy() string {
	if t == nil || t.EligiblePrefixPolicy == nil {
		return ""
	}
	return *t.EligiblePrefixPolicy
}

// GetReceive retrieves the value of the leaf Receive from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Receive is set, it can safely use t.GetReceive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Receive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) GetReceive() bool {
	if t == nil || t.Receive == nil {
		return false
	}
	return *t.Receive
}

// GetSend retrieves the value of the leaf Send from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Send is set, it can safely use t.GetSend()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Send == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) GetSend() bool {
	if t == nil || t.Send == nil {
		return false
	}
	return *t.Send
}

// GetSendMax retrieves the value of the leaf SendMax from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendMax is set, it can safely use t.GetSendMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendMax == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) GetSendMax() uint8 {
	if t == nil || t.SendMax == nil {
		return 0
	}
	return *t.SendMax
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-network-instance"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-network-instance"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled   *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                              `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast struct {
	ΛMetadata         []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit      []ygot.Annotation                                                       `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                                                   `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-network-instance"`
	ΛSendDefaultRoute []ygot.Annotation                                                       `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast struct {
	ΛMetadata    []ygot.Annotation                                                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                              `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast struct {
	ΛMetadata         []ygot.Annotation                                                       `path:"@" ygotAnnotation:"true"`
	PrefixLimit       *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit      []ygot.Annotation                                                       `path:"@prefix-limit" ygotAnnotation:"true"`
	SendDefaultRoute  *bool                                                                   `path:"state/send-default-route" shadow-path:"config/send-default-route" module:"openconfig-network-instance"`
	ΛSendDefaultRoute []ygot.Annotation                                                       `path:"state/@send-default-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// GetSendDefaultRoute retrieves the value of the leaf SendDefaultRoute from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SendDefaultRoute is set, it can safely use t.GetSendDefaultRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SendDefaultRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast) GetSendDefaultRoute() bool {
	if t == nil || t.SendDefaultRoute == nil {
		return false
	}
	return *t.SendDefaultRoute
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn struct {
	ΛMetadata    []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                     `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls struct {
	ΛMetadata    []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                     `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast struct {
	ΛMetadata    []ygot.Annotation                                                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                              `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast struct {
	ΛMetadata    []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                            `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast struct {
	ΛMetadata    []ygot.Annotation                                                              `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                              `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast struct {
	ΛMetadata    []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                            `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 struct {
	ΛMetadata    []ygot.Annotation                                                          `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                          `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 struct {
	ΛMetadata    []ygot.Annotation                                                          `path:"@" ygotAnnotation:"true"`
	PrefixLimit  *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	ΛPrefixLimit []ygot.Annotation                                                          `path:"@prefix-limit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// GetOrCreatePrefixLimit retrieves the value of the PrefixLimit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) GetOrCreatePrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	t.PrefixLimit = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit{}
	return t.PrefixLimit
}

// GetPrefixLimit returns the value of the PrefixLimit struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6. If the receiver or the field PrefixLimit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) GetPrefixLimit() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit {
	if t != nil && t.PrefixLimit != nil {
		return t.PrefixLimit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaxPrefixes          *uint32           `path:"state/max-prefixes" shadow-path:"config/max-prefixes" module:"openconfig-network-instance"`
	ΛMaxPrefixes         []ygot.Annotation `path:"state/@max-prefixes" ygotAnnotation:"true"`
	PreventTeardown      *bool             `path:"state/prevent-teardown" shadow-path:"config/prevent-teardown" module:"openconfig-network-instance"`
	ΛPreventTeardown     []ygot.Annotation `path:"state/@prevent-teardown" ygotAnnotation:"true"`
	RestartTimer         *float64          `path:"state/restart-timer" shadow-path:"config/restart-timer" module:"openconfig-network-instance"`
	ΛRestartTimer        []ygot.Annotation `path:"state/@restart-timer" ygotAnnotation:"true"`
	WarningThresholdPct  *uint8            `path:"state/warning-threshold-pct" shadow-path:"config/warning-threshold-pct" module:"openconfig-network-instance"`
	ΛWarningThresholdPct []ygot.Annotation `path:"state/@warning-threshold-pct" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// GetMaxPrefixes retrieves the value of the leaf MaxPrefixes from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxPrefixes is set, it can safely use t.GetMaxPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetMaxPrefixes() uint32 {
	if t == nil || t.MaxPrefixes == nil {
		return 0
	}
	return *t.MaxPrefixes
}

// GetPreventTeardown retrieves the value of the leaf PreventTeardown from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PreventTeardown is set, it can safely use t.GetPreventTeardown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PreventTeardown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetPreventTeardown() bool {
	if t == nil || t.PreventTeardown == nil {
		return false
	}
	return *t.PreventTeardown
}

// GetRestartTimer retrieves the value of the leaf RestartTimer from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTimer is set, it can safely use t.GetRestartTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetRestartTimer() float64 {
	if t == nil || t.RestartTimer == nil {
		return 0.0
	}
	return *t.RestartTimer
}

// GetWarningThresholdPct retrieves the value of the leaf WarningThresholdPct from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningThresholdPct is set, it can safely use t.GetWarningThresholdPct()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningThresholdPct == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) GetWarningThresholdPct() uint8 {
	if t == nil || t.WarningThresholdPct == nil {
		return 0
	}
	return *t.WarningThresholdPct
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	Ebgp      *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-network-instance"`
	ΛEbgp     []ygot.Annotation                                                     `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                                                 `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation                                                     `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-network-instance"`
	ΛIbgp     []ygot.Annotation                                                     `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetOrCreateEbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetOrCreateIbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetEbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetIbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-network-instance"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultExportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-export-policy" shadow-path:"config/default-export-policy" module:"openconfig-network-instance"`
	ΛDefaultExportPolicy []ygot.Annotation                           `path:"state/@default-export-policy" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ExportPolicy         []string                                    `path:"state/export-policy" shadow-path:"config/export-policy" module:"openconfig-network-instance"`
	ΛExportPolicy        []ygot.Annotation                           `path:"state/@export-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) IsYANGGoStruct() {}

// GetDefaultExportPolicy retrieves the value of the leaf DefaultExportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultExportPolicy is set, it can safely use t.GetDefaultExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) GetDefaultExportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultExportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultExportPolicy
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetExportPolicy retrieves the value of the leaf ExportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExportPolicy is set, it can safely use t.GetExportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) GetExportPolicy() []string {
	if t == nil || t.ExportPolicy == nil {
		return nil
	}
	return t.ExportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/as-path-options YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowOwnAs           *uint8            `path:"state/allow-own-as" shadow-path:"config/allow-own-as" module:"openconfig-network-instance"`
	ΛAllowOwnAs          []ygot.Annotation `path:"state/@allow-own-as" ygotAnnotation:"true"`
	DisablePeerAsFilter  *bool             `path:"state/disable-peer-as-filter" shadow-path:"config/disable-peer-as-filter" module:"openconfig-network-instance"`
	ΛDisablePeerAsFilter []ygot.Annotation `path:"state/@disable-peer-as-filter" ygotAnnotation:"true"`
	ReplacePeerAs        *bool             `path:"state/replace-peer-as" shadow-path:"config/replace-peer-as" module:"openconfig-network-instance"`
	ΛReplacePeerAs       []ygot.Annotation `path:"state/@replace-peer-as" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions) IsYANGGoStruct() {}

// GetAllowOwnAs retrieves the value of the leaf AllowOwnAs from the NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowOwnAs is set, it can safely use t.GetAllowOwnAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowOwnAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions) GetAllowOwnAs() uint8 {
	if t == nil || t.AllowOwnAs == nil {
		return 0
	}
	return *t.AllowOwnAs
}

// GetDisablePeerAsFilter retrieves the value of the leaf DisablePeerAsFilter from the NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DisablePeerAsFilter is set, it can safely use t.GetDisablePeerAsFilter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DisablePeerAsFilter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions) GetDisablePeerAsFilter() bool {
	if t == nil || t.DisablePeerAsFilter == nil {
		return false
	}
	return *t.DisablePeerAsFilter
}

// GetReplacePeerAs retrieves the value of the leaf ReplacePeerAs from the NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReplacePeerAs is set, it can safely use t.GetReplacePeerAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReplacePeerAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions) GetReplacePeerAs() bool {
	if t == nil || t.ReplacePeerAs == nil {
		return false
	}
	return *t.ReplacePeerAs
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/ebgp-multihop YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled      *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled     []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	MultihopTtl  *uint8            `path:"state/multihop-ttl" shadow-path:"config/multihop-ttl" module:"openconfig-network-instance"`
	ΛMultihopTtl []ygot.Annotation `path:"state/@multihop-ttl" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetMultihopTtl retrieves the value of the leaf MultihopTtl from the NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultihopTtl is set, it can safely use t.GetMultihopTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultihopTtl == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop) GetMultihopTtl() uint8 {
	if t == nil || t.MultihopTtl == nil {
		return 0
	}
	return *t.MultihopTtl
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/error-handling YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	TreatAsWithdraw  *bool             `path:"state/treat-as-withdraw" shadow-path:"config/treat-as-withdraw" module:"openconfig-network-instance"`
	ΛTreatAsWithdraw []ygot.Annotation `path:"state/@treat-as-withdraw" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling) IsYANGGoStruct() {}

// GetTreatAsWithdraw retrieves the value of the leaf TreatAsWithdraw from the NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TreatAsWithdraw is set, it can safely use t.GetTreatAsWithdraw()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TreatAsWithdraw == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling) GetTreatAsWithdraw() bool {
	if t == nil || t.TreatAsWithdraw == nil {
		return false
	}
	return *t.TreatAsWithdraw
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled          *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled         []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly       *bool             `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-network-instance"`
	ΛHelperOnly      []ygot.Annotation `path:"state/@helper-only" ygotAnnotation:"true"`
	RestartTime      *uint16           `path:"state/restart-time" shadow-path:"config/restart-time" module:"openconfig-network-instance"`
	ΛRestartTime     []ygot.Annotation `path:"state/@restart-time" ygotAnnotation:"true"`
	StaleRoutesTime  *float64          `path:"state/stale-routes-time" shadow-path:"config/stale-routes-time" module:"openconfig-network-instance"`
	ΛStaleRoutesTime []ygot.Annotation `path:"state/@stale-routes-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// GetRestartTime retrieves the value of the leaf RestartTime from the NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartTime is set, it can safely use t.GetRestartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) GetRestartTime() uint16 {
	if t == nil || t.RestartTime == nil {
		return 0
	}
	return *t.RestartTime
}

// GetStaleRoutesTime retrieves the value of the leaf StaleRoutesTime from the NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StaleRoutesTime is set, it can safely use t.GetStaleRoutesTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StaleRoutesTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) GetStaleRoutesTime() float64 {
	if t == nil || t.StaleRoutesTime == nil {
		return 0.0
	}
	return *t.StaleRoutesTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/logging-options YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LogNeighborStateChanges  *bool             `path:"state/log-neighbor-state-changes" shadow-path:"config/log-neighbor-state-changes" module:"openconfig-network-instance"`
	ΛLogNeighborStateChanges []ygot.Annotation `path:"state/@log-neighbor-state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions) IsYANGGoStruct() {}

// GetLogNeighborStateChanges retrieves the value of the leaf LogNeighborStateChanges from the NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogNeighborStateChanges is set, it can safely use t.GetLogNeighborStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogNeighborStateChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions) GetLogNeighborStateChanges() bool {
	if t == nil || t.LogNeighborStateChanges == nil {
		return true
	}
	return *t.LogNeighborStateChanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector struct {
	ΛMetadata                []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	RouteReflectorClient     *bool                                                                               `path:"state/route-reflector-client" shadow-path:"config/route-reflector-client" module:"openconfig-network-instance"`
	ΛRouteReflectorClient    []ygot.Annotation                                                                   `path:"state/@route-reflector-client" ygotAnnotation:"true"`
	RouteReflectorClusterId  NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union `path:"state/route-reflector-cluster-id" shadow-path:"config/route-reflector-cluster-id" module:"openconfig-network-instance"`
	ΛRouteReflectorClusterId []ygot.Annotation                                                                   `path:"state/@route-reflector-cluster-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector) IsYANGGoStruct() {}

// GetRouteReflectorClient retrieves the value of the leaf RouteReflectorClient from the NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClient is set, it can safely use t.GetRouteReflectorClient()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClient == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector) GetRouteReflectorClient() bool {
	if t == nil || t.RouteReflectorClient == nil {
		return false
	}
	return *t.RouteReflectorClient
}

// GetRouteReflectorClusterId retrieves the value of the leaf RouteReflectorClusterId from the NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteReflectorClusterId is set, it can safely use t.GetRouteReflectorClusterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteReflectorClusterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector) GetRouteReflectorClusterId() NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union {
	if t == nil || t.RouteReflectorClusterId == nil {
		return nil
	}
	return t.RouteReflectorClusterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union() {
}

// To_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector) To_NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union(i interface{}) (NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_PeerGroup_RouteReflector_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Bgp_PeerGroup_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/timers YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_Timers struct {
	ΛMetadata                     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ConnectRetry                  *float64          `path:"state/connect-retry" shadow-path:"config/connect-retry" module:"openconfig-network-instance"`
	ΛConnectRetry                 []ygot.Annotation `path:"state/@connect-retry" ygotAnnotation:"true"`
	HoldTime                      *float64          `path:"state/hold-time" shadow-path:"config/hold-time" module:"openconfig-network-instance"`
	ΛHoldTime                     []ygot.Annotation `path:"state/@hold-time" ygotAnnotation:"true"`
	KeepaliveInterval             *float64          `path:"state/keepalive-interval" shadow-path:"config/keepalive-interval" module:"openconfig-network-instance"`
	ΛKeepaliveInterval            []ygot.Annotation `path:"state/@keepalive-interval" ygotAnnotation:"true"`
	MinimumAdvertisementInterval  *float64          `path:"state/minimum-advertisement-interval" shadow-path:"config/minimum-advertisement-interval" module:"openconfig-network-instance"`
	ΛMinimumAdvertisementInterval []ygot.Annotation `path:"state/@minimum-advertisement-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_Timers) IsYANGGoStruct() {}

// GetConnectRetry retrieves the value of the leaf ConnectRetry from the NetworkInstance_Protocol_Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectRetry is set, it can safely use t.GetConnectRetry()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectRetry == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Timers) GetConnectRetry() float64 {
	if t == nil || t.ConnectRetry == nil {
		return 30
	}
	return *t.ConnectRetry
}

// GetHoldTime retrieves the value of the leaf HoldTime from the NetworkInstance_Protocol_Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Timers) GetHoldTime() float64 {
	if t == nil || t.HoldTime == nil {
		return 90
	}
	return *t.HoldTime
}

// GetKeepaliveInterval retrieves the value of the leaf KeepaliveInterval from the NetworkInstance_Protocol_Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeepaliveInterval is set, it can safely use t.GetKeepaliveInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeepaliveInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Timers) GetKeepaliveInterval() float64 {
	if t == nil || t.KeepaliveInterval == nil {
		return 30
	}
	return *t.KeepaliveInterval
}

// GetMinimumAdvertisementInterval retrieves the value of the leaf MinimumAdvertisementInterval from the NetworkInstance_Protocol_Bgp_PeerGroup_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinimumAdvertisementInterval is set, it can safely use t.GetMinimumAdvertisementInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinimumAdvertisementInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Timers) GetMinimumAdvertisementInterval() float64 {
	if t == nil || t.MinimumAdvertisementInterval == nil {
		return 30
	}
	return *t.MinimumAdvertisementInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_Transport represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/transport YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_Transport struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LocalAddress  *string           `path:"state/local-address" shadow-path:"config/local-address" module:"openconfig-network-instance"`
	ΛLocalAddress []ygot.Annotation `path:"state/@local-address" ygotAnnotation:"true"`
	MtuDiscovery  *bool             `path:"state/mtu-discovery" shadow-path:"config/mtu-discovery" module:"openconfig-network-instance"`
	ΛMtuDiscovery []ygot.Annotation `path:"state/@mtu-discovery" ygotAnnotation:"true"`
	PassiveMode   *bool             `path:"state/passive-mode" shadow-path:"config/passive-mode" module:"openconfig-network-instance"`
	ΛPassiveMode  []ygot.Annotation `path:"state/@passive-mode" ygotAnnotation:"true"`
	TcpMss        *uint16           `path:"state/tcp-mss" shadow-path:"config/tcp-mss" module:"openconfig-network-instance"`
	ΛTcpMss       []ygot.Annotation `path:"state/@tcp-mss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_Transport) IsYANGGoStruct() {}

// GetLocalAddress retrieves the value of the leaf LocalAddress from the NetworkInstance_Protocol_Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalAddress is set, it can safely use t.GetLocalAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Transport) GetLocalAddress() string {
	if t == nil || t.LocalAddress == nil {
		return ""
	}
	return *t.LocalAddress
}

// GetMtuDiscovery retrieves the value of the leaf MtuDiscovery from the NetworkInstance_Protocol_Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtuDiscovery is set, it can safely use t.GetMtuDiscovery()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtuDiscovery == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Transport) GetMtuDiscovery() bool {
	if t == nil || t.MtuDiscovery == nil {
		return false
	}
	return *t.MtuDiscovery
}

// GetPassiveMode retrieves the value of the leaf PassiveMode from the NetworkInstance_Protocol_Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PassiveMode is set, it can safely use t.GetPassiveMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PassiveMode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Transport) GetPassiveMode() bool {
	if t == nil || t.PassiveMode == nil {
		return false
	}
	return *t.PassiveMode
}

// GetTcpMss retrieves the value of the leaf TcpMss from the NetworkInstance_Protocol_Bgp_PeerGroup_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TcpMss is set, it can safely use t.GetTcpMss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TcpMss == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Transport) GetTcpMss() uint16 {
	if t == nil || t.TcpMss == nil {
		return 0
	}
	return *t.TcpMss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths struct {
	ΛMetadata []ygot.Annotation                                             `path:"@" ygotAnnotation:"true"`
	Ebgp      *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp `path:"ebgp" module:"openconfig-network-instance"`
	ΛEbgp     []ygot.Annotation                                             `path:"@ebgp" ygotAnnotation:"true"`
	Enabled   *bool                                                         `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation                                             `path:"state/@enabled" ygotAnnotation:"true"`
	Ibgp      *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp `path:"ibgp" module:"openconfig-network-instance"`
	ΛIbgp     []ygot.Annotation                                             `path:"@ibgp" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) IsYANGGoStruct() {}

// GetOrCreateEbgp retrieves the value of the Ebgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) GetOrCreateEbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp {
	if t.Ebgp != nil {
		return t.Ebgp
	}
	t.Ebgp = &NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp{}
	return t.Ebgp
}

// GetOrCreateIbgp retrieves the value of the Ibgp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) GetOrCreateIbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp {
	if t.Ibgp != nil {
		return t.Ibgp
	}
	t.Ibgp = &NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp{}
	return t.Ibgp
}

// GetEbgp returns the value of the Ebgp struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths. If the receiver or the field Ebgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) GetEbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp {
	if t != nil && t.Ebgp != nil {
		return t.Ebgp
	}
	return nil
}

// GetIbgp returns the value of the Ibgp struct pointer
// from NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths. If the receiver or the field Ibgp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) GetIbgp() *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp {
	if t != nil && t.Ibgp != nil {
		return t.Ibgp
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ebgp YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AllowMultipleAs  *bool             `path:"state/allow-multiple-as" shadow-path:"config/allow-multiple-as" module:"openconfig-network-instance"`
	ΛAllowMultipleAs []ygot.Annotation `path:"state/@allow-multiple-as" ygotAnnotation:"true"`
	MaximumPaths     *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths    []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// GetAllowMultipleAs retrieves the value of the leaf AllowMultipleAs from the NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllowMultipleAs is set, it can safely use t.GetAllowMultipleAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllowMultipleAs == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp) GetAllowMultipleAs() bool {
	if t == nil || t.AllowMultipleAs == nil {
		return false
	}
	return *t.AllowMultipleAs
}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ibgp YANG schema element.
type NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	MaximumPaths  *uint32           `path:"state/maximum-paths" shadow-path:"config/maximum-paths" module:"openconfig-network-instance"`
	ΛMaximumPaths []ygot.Annotation `path:"state/@maximum-paths" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// GetMaximumPaths retrieves the value of the leaf MaximumPaths from the NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumPaths is set, it can safely use t.GetMaximumPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp) GetMaximumPaths() uint32 {
	if t == nil || t.MaximumPaths == nil {
		return 1
	}
	return *t.MaximumPaths
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_PeerGroup_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib struct {
	ΛMetadata     []ygot.Annotation                                                                `path:"@" ygotAnnotation:"true"`
	AfiSafi       map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi `path:"afi-safis/afi-safi" module:"openconfig-network-instance"`
	ΛAfiSafi      []ygot.Annotation                                                                `path:"afi-safis/@afi-safi" ygotAnnotation:"true"`
	AttrSet       map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet                             `path:"attr-sets/attr-set" module:"openconfig-network-instance"`
	ΛAttrSet      []ygot.Annotation                                                                `path:"attr-sets/@attr-set" ygotAnnotation:"true"`
	Community     map[uint64]*NetworkInstance_Protocol_Bgp_Rib_Community                           `path:"communities/community" module:"openconfig-network-instance"`
	ΛCommunity    []ygot.Annotation                                                                `path:"communities/@community" ygotAnnotation:"true"`
	ExtCommunity  map[uint64]*NetworkInstance_Protocol_Bgp_Rib_ExtCommunity                        `path:"ext-communities/ext-community" module:"openconfig-network-instance"`
	ΛExtCommunity []ygot.Annotation                                                                `path:"ext-communities/@ext-community" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// NetworkInstance_Protocol_Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// RenameAfiSafi renames an entry in the list AfiSafi within
// the NetworkInstance_Protocol_Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib) RenameAfiSafi(oldK, newK E_OpenconfigBgpTypes_AFI_SAFI_TYPE) error {
	if _, ok := t.AfiSafi[newK]; ok {
		return fmt.Errorf("key %v already exists in AfiSafi", newK)
	}

	e, ok := t.AfiSafi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AfiSafi", oldK)
	}
	e.AfiSafiName = newK

	t.AfiSafi[newK] = e
	delete(t.AfiSafi, oldK)
	return nil
}

// GetOrCreateAfiSafi retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetOrCreateAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi {

	key := AfiSafiName

	if v, ok := t.AfiSafi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfiSafi(AfiSafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfiSafi got unexpected error: %v", err))
	}
	return v
}

// GetAfiSafi retrieves the value with the specified key from
// the AfiSafi map field of NetworkInstance_Protocol_Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi {

	if t == nil {
		return nil
	}

	key := AfiSafiName

	if lm, ok := t.AfiSafi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfiSafi appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi struct to the
// list AfiSafi of NetworkInstance_Protocol_Bgp_Rib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib) AppendAfiSafi(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) error {
	key := v.AfiSafiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi)
	}

	if _, ok := t.AfiSafi[key]; ok {
		return fmt.Errorf("duplicate key for list AfiSafi %v", key)
	}

	t.AfiSafi[key] = v
	return nil
}

// NewAttrSet creates a new entry in the AttrSet list of the
// NetworkInstance_Protocol_Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib) NewAttrSet(Index uint64) (*NetworkInstance_Protocol_Bgp_Rib_AttrSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AttrSet == nil {
		t.AttrSet = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AttrSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AttrSet", key)
	}

	t.AttrSet[key] = &NetworkInstance_Protocol_Bgp_Rib_AttrSet{
		Index: &Index,
	}

	return t.AttrSet[key], nil
}

// RenameAttrSet renames an entry in the list AttrSet within
// the NetworkInstance_Protocol_Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib) RenameAttrSet(oldK, newK uint64) error {
	if _, ok := t.AttrSet[newK]; ok {
		return fmt.Errorf("key %v already exists in AttrSet", newK)
	}

	e, ok := t.AttrSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AttrSet", oldK)
	}
	e.Index = &newK

	t.AttrSet[newK] = e
	delete(t.AttrSet, oldK)
	return nil
}

// GetOrCreateAttrSet retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetOrCreateAttrSet(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_AttrSet {

	key := Index

	if v, ok := t.AttrSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAttrSet(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAttrSet got unexpected error: %v", err))
	}
	return v
}

// GetAttrSet retrieves the value with the specified key from
// the AttrSet map field of NetworkInstance_Protocol_Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetAttrSet(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_AttrSet {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.AttrSet[key]; ok {
		return lm
	}
	return nil
}

// AppendAttrSet appends the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet struct to the
// list AttrSet of NetworkInstance_Protocol_Bgp_Rib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib) AppendAttrSet(v *NetworkInstance_Protocol_Bgp_Rib_AttrSet) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AttrSet == nil {
		t.AttrSet = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet)
	}

	if _, ok := t.AttrSet[key]; ok {
		return fmt.Errorf("duplicate key for list AttrSet %v", key)
	}

	t.AttrSet[key] = v
	return nil
}

// NewCommunity creates a new entry in the Community list of the
// NetworkInstance_Protocol_Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib) NewCommunity(Index uint64) (*NetworkInstance_Protocol_Bgp_Rib_Community, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Community == nil {
		t.Community = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_Community)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Community[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Community", key)
	}

	t.Community[key] = &NetworkInstance_Protocol_Bgp_Rib_Community{
		Index: &Index,
	}

	return t.Community[key], nil
}

// RenameCommunity renames an entry in the list Community within
// the NetworkInstance_Protocol_Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib) RenameCommunity(oldK, newK uint64) error {
	if _, ok := t.Community[newK]; ok {
		return fmt.Errorf("key %v already exists in Community", newK)
	}

	e, ok := t.Community[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Community", oldK)
	}
	e.Index = &newK

	t.Community[newK] = e
	delete(t.Community, oldK)
	return nil
}

// GetOrCreateCommunity retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetOrCreateCommunity(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_Community {

	key := Index

	if v, ok := t.Community[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCommunity(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCommunity got unexpected error: %v", err))
	}
	return v
}

// GetCommunity retrieves the value with the specified key from
// the Community map field of NetworkInstance_Protocol_Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetCommunity(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_Community {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Community[key]; ok {
		return lm
	}
	return nil
}

// AppendCommunity appends the supplied NetworkInstance_Protocol_Bgp_Rib_Community struct to the
// list Community of NetworkInstance_Protocol_Bgp_Rib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_Community already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib) AppendCommunity(v *NetworkInstance_Protocol_Bgp_Rib_Community) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Community == nil {
		t.Community = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_Community)
	}

	if _, ok := t.Community[key]; ok {
		return fmt.Errorf("duplicate key for list Community %v", key)
	}

	t.Community[key] = v
	return nil
}

// NewExtCommunity creates a new entry in the ExtCommunity list of the
// NetworkInstance_Protocol_Bgp_Rib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib) NewExtCommunity(Index uint64) (*NetworkInstance_Protocol_Bgp_Rib_ExtCommunity, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExtCommunity == nil {
		t.ExtCommunity = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_ExtCommunity)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExtCommunity[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExtCommunity", key)
	}

	t.ExtCommunity[key] = &NetworkInstance_Protocol_Bgp_Rib_ExtCommunity{
		Index: &Index,
	}

	return t.ExtCommunity[key], nil
}

// RenameExtCommunity renames an entry in the list ExtCommunity within
// the NetworkInstance_Protocol_Bgp_Rib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib) RenameExtCommunity(oldK, newK uint64) error {
	if _, ok := t.ExtCommunity[newK]; ok {
		return fmt.Errorf("key %v already exists in ExtCommunity", newK)
	}

	e, ok := t.ExtCommunity[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ExtCommunity", oldK)
	}
	e.Index = &newK

	t.ExtCommunity[newK] = e
	delete(t.ExtCommunity, oldK)
	return nil
}

// GetOrCreateExtCommunity retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetOrCreateExtCommunity(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity {

	key := Index

	if v, ok := t.ExtCommunity[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewExtCommunity(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateExtCommunity got unexpected error: %v", err))
	}
	return v
}

// GetExtCommunity retrieves the value with the specified key from
// the ExtCommunity map field of NetworkInstance_Protocol_Bgp_Rib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib) GetExtCommunity(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.ExtCommunity[key]; ok {
		return lm
	}
	return nil
}

// AppendExtCommunity appends the supplied NetworkInstance_Protocol_Bgp_Rib_ExtCommunity struct to the
// list ExtCommunity of NetworkInstance_Protocol_Bgp_Rib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_ExtCommunity already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib) AppendExtCommunity(v *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExtCommunity == nil {
		t.ExtCommunity = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_ExtCommunity)
	}

	if _, ok := t.ExtCommunity[key]; ok {
		return fmt.Errorf("duplicate key for list ExtCommunity %v", key)
	}

	t.ExtCommunity[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi struct {
	ΛMetadata       []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	AfiSafiName     E_OpenconfigBgpTypes_AFI_SAFI_TYPE                       `path:"state/afi-safi-name|afi-safi-name" module:"openconfig-network-instance"`
	ΛAfiSafiName    []ygot.Annotation                                        `path:"state/@afi-safi-name|@afi-safi-name" ygotAnnotation:"true"`
	Ipv4SrtePolicy  *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy `path:"ipv4-srte-policy" module:"openconfig-network-instance"`
	ΛIpv4SrtePolicy []ygot.Annotation                                        `path:"@ipv4-srte-policy" ygotAnnotation:"true"`
	Ipv4Unicast     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast    `path:"ipv4-unicast" module:"openconfig-network-instance"`
	ΛIpv4Unicast    []ygot.Annotation                                        `path:"@ipv4-unicast" ygotAnnotation:"true"`
	Ipv6SrtePolicy  *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy `path:"ipv6-srte-policy" module:"openconfig-network-instance"`
	ΛIpv6SrtePolicy []ygot.Annotation                                        `path:"@ipv6-srte-policy" ygotAnnotation:"true"`
	Ipv6Unicast     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast    `path:"ipv6-unicast" module:"openconfig-network-instance"`
	ΛIpv6Unicast    []ygot.Annotation                                        `path:"@ipv6-unicast" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi) IsYANGGoStruct() {}

// GetOrCreateIpv4SrtePolicy retrieves the value of the Ipv4SrtePolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetOrCreateIpv4SrtePolicy() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy {
	if t.Ipv4SrtePolicy != nil {
		return t.Ipv4SrtePolicy
	}
	t.Ipv4SrtePolicy = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy{}
	return t.Ipv4SrtePolicy
}

// GetOrCreateIpv4Unicast retrieves the value of the Ipv4Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetOrCreateIpv4Unicast() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast {
	if t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	t.Ipv4Unicast = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast{}
	return t.Ipv4Unicast
}

// GetOrCreateIpv6SrtePolicy retrieves the value of the Ipv6SrtePolicy field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetOrCreateIpv6SrtePolicy() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy {
	if t.Ipv6SrtePolicy != nil {
		return t.Ipv6SrtePolicy
	}
	t.Ipv6SrtePolicy = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy{}
	return t.Ipv6SrtePolicy
}

// GetOrCreateIpv6Unicast retrieves the value of the Ipv6Unicast field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetOrCreateIpv6Unicast() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast {
	if t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	t.Ipv6Unicast = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast{}
	return t.Ipv6Unicast
}

// GetIpv4SrtePolicy returns the value of the Ipv4SrtePolicy struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi. If the receiver or the field Ipv4SrtePolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetIpv4SrtePolicy() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy {
	if t != nil && t.Ipv4SrtePolicy != nil {
		return t.Ipv4SrtePolicy
	}
	return nil
}

// GetIpv4Unicast returns the value of the Ipv4Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi. If the receiver or the field Ipv4Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetIpv4Unicast() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast {
	if t != nil && t.Ipv4Unicast != nil {
		return t.Ipv4Unicast
	}
	return nil
}

// GetIpv6SrtePolicy returns the value of the Ipv6SrtePolicy struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi. If the receiver or the field Ipv6SrtePolicy is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetIpv6SrtePolicy() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy {
	if t != nil && t.Ipv6SrtePolicy != nil {
		return t.Ipv6SrtePolicy
	}
	return nil
}

// GetIpv6Unicast returns the value of the Ipv6Unicast struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi. If the receiver or the field Ipv6Unicast is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetIpv6Unicast() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast {
	if t != nil && t.Ipv6Unicast != nil {
		return t.Ipv6Unicast
	}
	return nil
}

// GetAfiSafiName retrieves the value of the leaf AfiSafiName from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiSafiName is set, it can safely use t.GetAfiSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiSafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) GetAfiSafiName() E_OpenconfigBgpTypes_AFI_SAFI_TYPE {
	if t == nil || t.AfiSafiName == 0 {
		return 0
	}
	return t.AfiSafiName
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy struct {
	ΛMetadata []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	LocRib    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib              `path:"loc-rib" module:"openconfig-network-instance"`
	ΛLocRib   []ygot.Annotation                                                            `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                            `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) NewNeighbor(NeighborAddress string) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetOrCreateNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) AppendNeighbor(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetOrCreateLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) GetLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                                                                                  `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                  `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                          `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                          `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                          `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                          `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                          `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                     `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                          `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                          `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                            `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	ΛAdjRibInPost    []ygot.Annotation                                                               `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	ΛAdjRibInPre     []ygot.Annotation                                                               `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	ΛAdjRibOutPost   []ygot.Annotation                                                               `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	ΛAdjRibOutPre    []ygot.Annotation                                                               `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                                                         `path:"state/neighbor-address|neighbor-address" module:"openconfig-network-instance"`
	ΛNeighborAddress []ygot.Annotation                                                               `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetOrCreateAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                               `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                         `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                               `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                                                           `path:"state/best-path" module:"openconfig-network-instance"`
	ΛBestPath          []ygot.Annotation                                                                                               `path:"state/@best-path" ygotAnnotation:"true"`
	Color              *uint32                                                                                                         `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                               `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                         `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                               `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                         `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                               `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                         `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                               `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                    `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                               `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                         `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                               `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                         `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                               `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                               `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                           `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                               `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                              `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                              `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                              `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                        `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                              `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                                        `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                              `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                        `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                              `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                        `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                              `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                        `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                              `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                   `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                              `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                        `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                              `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                        `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                              `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                              `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                          `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                              `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                                  `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                                  `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                                `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                          `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                                `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                                          `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                                `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                          `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                                `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                          `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                                `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                          `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                                `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                     `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                                `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                          `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                                `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                          `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                                `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                                `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                            `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                                `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                               `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                         `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                               `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                                         `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                               `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                         `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                               `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                         `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                               `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                         `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                               `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                    `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                               `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                         `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                               `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                         `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                               `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                               `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                           `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                               `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast struct {
	ΛMetadata []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	LocRib    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib              `path:"loc-rib" module:"openconfig-network-instance"`
	ΛLocRib   []ygot.Annotation                                                         `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                         `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) NewNeighbor(NeighborAddress string) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) GetOrCreateNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) GetNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) AppendNeighbor(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) GetOrCreateLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) GetLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                                                                            `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                            `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key struct {
	Prefix string                                                                         `path:"prefix"`
	Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union `path:"origin"`
	PathId uint32                                                                         `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) NewRoute(Prefix string, Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.Origin = newK.Origin
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) GetOrCreateRoute(Prefix string, Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, Origin, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) GetRoute(Prefix string, Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key{
		Prefix: *v.Prefix,
		Origin: v.Origin,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                                             `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                       `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                             `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                       `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                             `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                       `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                             `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                  `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                             `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                       `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                             `path:"state/@last-modified" ygotAnnotation:"true"`
	Origin             NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union                `path:"state/origin|origin" module:"openconfig-network-instance"`
	ΛOrigin            []ygot.Annotation                                                                             `path:"state/@origin|@origin" ygotAnnotation:"true"`
	PathId             *uint32                                                                                       `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                             `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                       `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                             `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                             `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                         `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                             `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetOrigin retrieves the value of the leaf Origin from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetOrigin() NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union {
	if t == nil || t.Origin == nil {
		return nil
	}
	return t.Origin
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/origin within the YANG schema.
// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString].
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union interface {
	// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString]
	Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union ensures that E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union interface.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union() {
}

// To_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route) To_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	ΛAdjRibInPost    []ygot.Annotation                                                            `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	ΛAdjRibInPre     []ygot.Annotation                                                            `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	ΛAdjRibOutPost   []ygot.Annotation                                                            `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	ΛAdjRibOutPre    []ygot.Annotation                                                            `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                                                      `path:"state/neighbor-address|neighbor-address" module:"openconfig-network-instance"`
	ΛNeighborAddress []ygot.Annotation                                                            `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetOrCreateAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                            `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                      `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                            `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                                                        `path:"state/best-path" module:"openconfig-network-instance"`
	ΛBestPath          []ygot.Annotation                                                                                            `path:"state/@best-path" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                      `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                            `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                      `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                            `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                 `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                            `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                      `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                            `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                      `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                            `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                      `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                            `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                            `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                        `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                            `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                        `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                        `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                           `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                     `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                           `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                     `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                           `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                     `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                           `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                           `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                     `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                           `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                     `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                           `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                     `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                           `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                           `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                       `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                           `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                            `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                            `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                             `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                       `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                             `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                       `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                             `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                       `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                             `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                  `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                             `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                       `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                             `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                       `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                             `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                       `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                             `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                             `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                         `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                             `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                            `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                      `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                            `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                      `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                            `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                      `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                            `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                 `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                            `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                      `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                            `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                      `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                            `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                      `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                            `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                            `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                        `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                            `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv4Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy struct {
	ΛMetadata []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	LocRib    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib              `path:"loc-rib" module:"openconfig-network-instance"`
	ΛLocRib   []ygot.Annotation                                                            `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                            `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) NewNeighbor(NeighborAddress string) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetOrCreateNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) AppendNeighbor(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetOrCreateLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) GetLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                                                                                  `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                  `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                          `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                          `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                          `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                          `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                          `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                     `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                          `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                          `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                            `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	ΛAdjRibInPost    []ygot.Annotation                                                               `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	ΛAdjRibInPre     []ygot.Annotation                                                               `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	ΛAdjRibOutPost   []ygot.Annotation                                                               `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	ΛAdjRibOutPre    []ygot.Annotation                                                               `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                                                         `path:"state/neighbor-address|neighbor-address" module:"openconfig-network-instance"`
	ΛNeighborAddress []ygot.Annotation                                                               `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetOrCreateAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                               `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                         `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                               `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                                                           `path:"state/best-path" module:"openconfig-network-instance"`
	ΛBestPath          []ygot.Annotation                                                                                               `path:"state/@best-path" ygotAnnotation:"true"`
	Color              *uint32                                                                                                         `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                               `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                         `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                               `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                         `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                               `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                         `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                               `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                    `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                               `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                         `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                               `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                         `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                               `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                               `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                           `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                               `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                              `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                              `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                              `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                        `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                              `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                                        `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                              `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                        `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                              `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                        `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                              `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                        `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                              `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                   `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                              `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                        `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                              `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                        `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                              `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                              `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                          `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                              `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                                  `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                                  `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                                `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                          `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                                `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                                          `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                                `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                          `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                                `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                          `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                                `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                          `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                                `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                     `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                                `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                          `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                                `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                          `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                                `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                                `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                            `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                                `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                                `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                                `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) NewRoute(PathId uint32, Endpoint string, Color uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.PathId = &newK.PathId
	e.Endpoint = &newK.Endpoint
	e.Color = &newK.Color

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) GetOrCreateRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(PathId, Endpoint, Color)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) GetRoute(PathId uint32, Endpoint string, Color uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) error {
	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key{
		PathId:   *v.PathId,
		Endpoint: *v.Endpoint,
		Color:    *v.Color,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                               `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                         `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                               `path:"state/@attr-index" ygotAnnotation:"true"`
	Color              *uint32                                                                                                         `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                               `path:"state/@color|@color" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                         `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                               `path:"state/@community-index" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                         `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                               `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                         `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                               `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                    `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                               `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                         `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                               `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                         `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                               `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                               `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                           `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                               `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6SrtePolicy_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast struct {
	ΛMetadata []ygot.Annotation                                                         `path:"@" ygotAnnotation:"true"`
	LocRib    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib              `path:"loc-rib" module:"openconfig-network-instance"`
	ΛLocRib   []ygot.Annotation                                                         `path:"@loc-rib" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                         `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) NewNeighbor(NeighborAddress string) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) GetOrCreateNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) GetNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) AppendNeighbor(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateLocRib retrieves the value of the LocRib field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) GetOrCreateLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib {
	if t.LocRib != nil {
		return t.LocRib
	}
	t.LocRib = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib{}
	return t.LocRib
}

// GetLocRib returns the value of the LocRib struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast. If the receiver or the field LocRib is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) GetLocRib() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib {
	if t != nil && t.LocRib != nil {
		return t.LocRib
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib struct {
	ΛMetadata []ygot.Annotation                                                                                                                            `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                            `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key struct {
	Prefix string                                                                         `path:"prefix"`
	Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union `path:"origin"`
	PathId uint32                                                                         `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) NewRoute(Prefix string, Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.Origin = newK.Origin
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) GetOrCreateRoute(Prefix string, Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, Origin, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) GetRoute(Prefix string, Origin NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key{
		Prefix: *v.Prefix,
		Origin: v.Origin,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct {
	ΛMetadata          []ygot.Annotation                                                                             `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                       `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                             `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                       `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                             `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                       `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                             `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                  `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                             `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                       `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                             `path:"state/@last-modified" ygotAnnotation:"true"`
	Origin             NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union                `path:"state/origin|origin" module:"openconfig-network-instance"`
	ΛOrigin            []ygot.Annotation                                                                             `path:"state/@origin|@origin" ygotAnnotation:"true"`
	PathId             *uint32                                                                                       `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                             `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                       `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                             `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                             `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                         `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                             `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) IsYANGGoStruct() {}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetOrigin retrieves the value of the leaf Origin from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetOrigin() NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union {
	if t == nil || t.Origin == nil {
		return nil
	}
	return t.Origin
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/origin within the YANG schema.
// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString].
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union interface {
	// Union type can be one of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, UnionString]
	Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union ensures that E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union interface.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union() {
}

// To_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route) To_NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_LocRib_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor struct {
	ΛMetadata        []ygot.Annotation                                                            `path:"@" ygotAnnotation:"true"`
	AdjRibInPost     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	ΛAdjRibInPost    []ygot.Annotation                                                            `path:"@adj-rib-in-post" ygotAnnotation:"true"`
	AdjRibInPre      *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	ΛAdjRibInPre     []ygot.Annotation                                                            `path:"@adj-rib-in-pre" ygotAnnotation:"true"`
	AdjRibOutPost    *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	ΛAdjRibOutPost   []ygot.Annotation                                                            `path:"@adj-rib-out-post" ygotAnnotation:"true"`
	AdjRibOutPre     *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	ΛAdjRibOutPre    []ygot.Annotation                                                            `path:"@adj-rib-out-pre" ygotAnnotation:"true"`
	NeighborAddress  *string                                                                      `path:"state/neighbor-address|neighbor-address" module:"openconfig-network-instance"`
	ΛNeighborAddress []ygot.Annotation                                                            `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) IsYANGGoStruct() {}

// GetOrCreateAdjRibInPost retrieves the value of the AdjRibInPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost {
	if t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	t.AdjRibInPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost{}
	return t.AdjRibInPost
}

// GetOrCreateAdjRibInPre retrieves the value of the AdjRibInPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre {
	if t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	t.AdjRibInPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre{}
	return t.AdjRibInPre
}

// GetOrCreateAdjRibOutPost retrieves the value of the AdjRibOutPost field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost {
	if t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	t.AdjRibOutPost = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost{}
	return t.AdjRibOutPost
}

// GetOrCreateAdjRibOutPre retrieves the value of the AdjRibOutPre field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetOrCreateAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre {
	if t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	t.AdjRibOutPre = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre{}
	return t.AdjRibOutPre
}

// GetAdjRibInPost returns the value of the AdjRibInPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibInPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibInPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost {
	if t != nil && t.AdjRibInPost != nil {
		return t.AdjRibInPost
	}
	return nil
}

// GetAdjRibInPre returns the value of the AdjRibInPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibInPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibInPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre {
	if t != nil && t.AdjRibInPre != nil {
		return t.AdjRibInPre
	}
	return nil
}

// GetAdjRibOutPost returns the value of the AdjRibOutPost struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibOutPost is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibOutPost() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost {
	if t != nil && t.AdjRibOutPost != nil {
		return t.AdjRibOutPost
	}
	return nil
}

// GetAdjRibOutPre returns the value of the AdjRibOutPre struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor. If the receiver or the field AdjRibOutPre is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetAdjRibOutPre() *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre {
	if t != nil && t.AdjRibOutPre != nil {
		return t.AdjRibOutPre
	}
	return nil
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                            `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                      `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                            `path:"state/@attr-index" ygotAnnotation:"true"`
	BestPath           *bool                                                                                                        `path:"state/best-path" module:"openconfig-network-instance"`
	ΛBestPath          []ygot.Annotation                                                                                            `path:"state/@best-path" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                      `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                            `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                      `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                            `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                 `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                            `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                      `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                            `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                      `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                            `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                      `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                            `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                            `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                        `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                            `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetBestPath retrieves the value of the leaf BestPath from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BestPath is set, it can safely use t.GetBestPath()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BestPath == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetBestPath() bool {
	if t == nil || t.BestPath == nil {
		return false
	}
	return *t.BestPath
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                        `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                        `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                           `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                     `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                           `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                     `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                           `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                     `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                           `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                           `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                     `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                           `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                     `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                           `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                     `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                           `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                           `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                       `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                           `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibInPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                            `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                            `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                             `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                       `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                             `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                       `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                             `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                       `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                             `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                  `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                             `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                       `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                             `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                       `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                             `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                       `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                             `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                             `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                         `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                             `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPost_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                          `path:"@" ygotAnnotation:"true"`
	Route     map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route `path:"routes/route" module:"openconfig-network-instance"`
	ΛRoute    []ygot.Annotation                                                                                                                                                          `path:"routes/@route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) NewRoute(Prefix string, PathId uint32) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route)
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// RenameRoute renames an entry in the list Route within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) RenameRoute(oldK, newK NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key) error {
	if _, ok := t.Route[newK]; ok {
		return fmt.Errorf("key %v already exists in Route", newK)
	}

	e, ok := t.Route[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Route", oldK)
	}
	e.Prefix = &newK.Prefix
	e.PathId = &newK.PathId

	t.Route[newK] = e
	delete(t.Route, oldK)
	return nil
}

// GetOrCreateRoute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) GetOrCreateRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route {

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if v, ok := t.Route[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRoute(Prefix, PathId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRoute got unexpected error: %v", err))
	}
	return v
}

// GetRoute retrieves the value with the specified key from
// the Route map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) GetRoute(Prefix string, PathId uint32) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	if lm, ok := t.Route[key]; ok {
		return lm
	}
	return nil
}

// AppendRoute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct to the
// list Route of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) AppendRoute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.PathId == nil {
		return fmt.Errorf("invalid nil key for PathId")
	}

	key := NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key{
		Prefix: *v.Prefix,
		PathId: *v.PathId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_Key]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route)
	}

	if _, ok := t.Route[key]; ok {
		return fmt.Errorf("duplicate key for list Route %v", key)
	}

	t.Route[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct {
	ΛMetadata          []ygot.Annotation                                                                                            `path:"@" ygotAnnotation:"true"`
	AttrIndex          *uint64                                                                                                      `path:"state/attr-index" module:"openconfig-network-instance"`
	ΛAttrIndex         []ygot.Annotation                                                                                            `path:"state/@attr-index" ygotAnnotation:"true"`
	CommunityIndex     *uint64                                                                                                      `path:"state/community-index" module:"openconfig-network-instance"`
	ΛCommunityIndex    []ygot.Annotation                                                                                            `path:"state/@community-index" ygotAnnotation:"true"`
	ExtCommunityIndex  *uint64                                                                                                      `path:"state/ext-community-index" module:"openconfig-network-instance"`
	ΛExtCommunityIndex []ygot.Annotation                                                                                            `path:"state/@ext-community-index" ygotAnnotation:"true"`
	InvalidReason      E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                 `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason     []ygot.Annotation                                                                                            `path:"state/@invalid-reason" ygotAnnotation:"true"`
	LastModified       *uint64                                                                                                      `path:"state/last-modified" module:"openconfig-network-instance"`
	ΛLastModified      []ygot.Annotation                                                                                            `path:"state/@last-modified" ygotAnnotation:"true"`
	PathId             *uint32                                                                                                      `path:"state/path-id|path-id" module:"openconfig-network-instance"`
	ΛPathId            []ygot.Annotation                                                                                            `path:"state/@path-id|@path-id" ygotAnnotation:"true"`
	Prefix             *string                                                                                                      `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix            []ygot.Annotation                                                                                            `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UnknownAttribute   map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute `path:"unknown-attributes/unknown-attribute" module:"openconfig-network-instance"`
	ΛUnknownAttribute  []ygot.Annotation                                                                                            `path:"unknown-attributes/@unknown-attribute" ygotAnnotation:"true"`
	ValidRoute         *bool                                                                                                        `path:"state/valid-route" module:"openconfig-network-instance"`
	ΛValidRoute        []ygot.Annotation                                                                                            `path:"state/@valid-route" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) NewUnknownAttribute(AttrType uint8) (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// RenameUnknownAttribute renames an entry in the list UnknownAttribute within
// the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) RenameUnknownAttribute(oldK, newK uint8) error {
	if _, ok := t.UnknownAttribute[newK]; ok {
		return fmt.Errorf("key %v already exists in UnknownAttribute", newK)
	}

	e, ok := t.UnknownAttribute[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnknownAttribute", oldK)
	}
	e.AttrType = &newK

	t.UnknownAttribute[newK] = e
	delete(t.UnknownAttribute, oldK)
	return nil
}

// GetOrCreateUnknownAttribute retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetOrCreateUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	key := AttrType

	if v, ok := t.UnknownAttribute[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnknownAttribute(AttrType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnknownAttribute got unexpected error: %v", err))
	}
	return v
}

// GetUnknownAttribute retrieves the value with the specified key from
// the UnknownAttribute map field of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetUnknownAttribute(AttrType uint8) *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute {

	if t == nil {
		return nil
	}

	key := AttrType

	if lm, ok := t.UnknownAttribute[key]; ok {
		return lm
	}
	return nil
}

// AppendUnknownAttribute appends the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct to the
// list UnknownAttribute of NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) AppendUnknownAttribute(v *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) error {
	if v.AttrType == nil {
		return fmt.Errorf("invalid nil key received for AttrType")
	}

	key := *v.AttrType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute)
	}

	if _, ok := t.UnknownAttribute[key]; ok {
		return fmt.Errorf("duplicate key for list UnknownAttribute %v", key)
	}

	t.UnknownAttribute[key] = v
	return nil
}

// GetAttrIndex retrieves the value of the leaf AttrIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrIndex is set, it can safely use t.GetAttrIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetAttrIndex() uint64 {
	if t == nil || t.AttrIndex == nil {
		return 0
	}
	return *t.AttrIndex
}

// GetCommunityIndex retrieves the value of the leaf CommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CommunityIndex is set, it can safely use t.GetCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetCommunityIndex() uint64 {
	if t == nil || t.CommunityIndex == nil {
		return 0
	}
	return *t.CommunityIndex
}

// GetExtCommunityIndex retrieves the value of the leaf ExtCommunityIndex from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunityIndex is set, it can safely use t.GetExtCommunityIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunityIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetExtCommunityIndex() uint64 {
	if t == nil || t.ExtCommunityIndex == nil {
		return 0
	}
	return *t.ExtCommunityIndex
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetInvalidReason() E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetLastModified retrieves the value of the leaf LastModified from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastModified is set, it can safely use t.GetLastModified()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastModified == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetLastModified() uint64 {
	if t == nil || t.LastModified == nil {
		return 0
	}
	return *t.LastModified
}

// GetPathId retrieves the value of the leaf PathId from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PathId is set, it can safely use t.GetPathId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PathId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetPathId() uint32 {
	if t == nil || t.PathId == nil {
		return 0
	}
	return *t.PathId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetValidRoute retrieves the value of the leaf ValidRoute from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ValidRoute is set, it can safely use t.GetValidRoute()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ValidRoute == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) GetValidRoute() bool {
	if t == nil || t.ValidRoute == nil {
		return false
	}
	return *t.ValidRoute
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttrLen     *uint16           `path:"state/attr-len" module:"openconfig-network-instance"`
	ΛAttrLen    []ygot.Annotation `path:"state/@attr-len" ygotAnnotation:"true"`
	AttrType    *uint8            `path:"state/attr-type|attr-type" module:"openconfig-network-instance"`
	ΛAttrType   []ygot.Annotation `path:"state/@attr-type|@attr-type" ygotAnnotation:"true"`
	AttrValue   Binary            `path:"state/attr-value" module:"openconfig-network-instance"`
	ΛAttrValue  []ygot.Annotation `path:"state/@attr-value" ygotAnnotation:"true"`
	Extended    *bool             `path:"state/extended" module:"openconfig-network-instance"`
	ΛExtended   []ygot.Annotation `path:"state/@extended" ygotAnnotation:"true"`
	Optional    *bool             `path:"state/optional" module:"openconfig-network-instance"`
	ΛOptional   []ygot.Annotation `path:"state/@optional" ygotAnnotation:"true"`
	Partial     *bool             `path:"state/partial" module:"openconfig-network-instance"`
	ΛPartial    []ygot.Annotation `path:"state/@partial" ygotAnnotation:"true"`
	Transitive  *bool             `path:"state/transitive" module:"openconfig-network-instance"`
	ΛTransitive []ygot.Annotation `path:"state/@transitive" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) IsYANGGoStruct() {
}

// GetAttrLen retrieves the value of the leaf AttrLen from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrLen is set, it can safely use t.GetAttrLen()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrLen == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrLen() uint16 {
	if t == nil || t.AttrLen == nil {
		return 0
	}
	return *t.AttrLen
}

// GetAttrType retrieves the value of the leaf AttrType from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrType is set, it can safely use t.GetAttrType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrType() uint8 {
	if t == nil || t.AttrType == nil {
		return 0
	}
	return *t.AttrType
}

// GetAttrValue retrieves the value of the leaf AttrValue from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttrValue is set, it can safely use t.GetAttrValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttrValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetAttrValue() Binary {
	if t == nil || t.AttrValue == nil {
		return nil
	}
	return t.AttrValue
}

// GetExtended retrieves the value of the leaf Extended from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Extended is set, it can safely use t.GetExtended()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Extended == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetExtended() bool {
	if t == nil || t.Extended == nil {
		return false
	}
	return *t.Extended
}

// GetOptional retrieves the value of the leaf Optional from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Optional is set, it can safely use t.GetOptional()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Optional == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetOptional() bool {
	if t == nil || t.Optional == nil {
		return false
	}
	return *t.Optional
}

// GetPartial retrieves the value of the leaf Partial from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Partial is set, it can safely use t.GetPartial()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Partial == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetPartial() bool {
	if t == nil || t.Partial == nil {
		return false
	}
	return *t.Partial
}

// GetTransitive retrieves the value of the leaf Transitive from the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transitive is set, it can safely use t.GetTransitive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transitive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) GetTransitive() bool {
	if t == nil || t.Transitive == nil {
		return false
	}
	return *t.Transitive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AfiSafi_Ipv6Unicast_Neighbor_AdjRibOutPre_Route_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet struct {
	ΛMetadata            []ygot.Annotation                                             `path:"@" ygotAnnotation:"true"`
	Aggregator           *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator          `path:"aggregator" module:"openconfig-network-instance"`
	ΛAggregator          []ygot.Annotation                                             `path:"@aggregator" ygotAnnotation:"true"`
	Aigp                 *uint64                                                       `path:"state/aigp" module:"openconfig-network-instance"`
	ΛAigp                []ygot.Annotation                                             `path:"state/@aigp" ygotAnnotation:"true"`
	AsSegment            []*NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment         `path:"as-path/as-segment" module:"openconfig-network-instance"`
	ΛAsSegment           []ygot.Annotation                                             `path:"as-path/@as-segment" ygotAnnotation:"true"`
	As4Segment           []*NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment        `path:"as4-path/as4-segment" module:"openconfig-network-instance"`
	ΛAs4Segment          []ygot.Annotation                                             `path:"as4-path/@as4-segment" ygotAnnotation:"true"`
	AtomicAggregate      *bool                                                         `path:"state/atomic-aggregate" module:"openconfig-network-instance"`
	ΛAtomicAggregate     []ygot.Annotation                                             `path:"state/@atomic-aggregate" ygotAnnotation:"true"`
	ClusterList          []string                                                      `path:"state/cluster-list" module:"openconfig-network-instance"`
	ΛClusterList         []ygot.Annotation                                             `path:"state/@cluster-list" ygotAnnotation:"true"`
	Index                *uint64                                                       `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex               []ygot.Annotation                                             `path:"state/@index|@index" ygotAnnotation:"true"`
	LocalPref            *uint32                                                       `path:"state/local-pref" module:"openconfig-network-instance"`
	ΛLocalPref           []ygot.Annotation                                             `path:"state/@local-pref" ygotAnnotation:"true"`
	Med                  *uint32                                                       `path:"state/med" module:"openconfig-network-instance"`
	ΛMed                 []ygot.Annotation                                             `path:"state/@med" ygotAnnotation:"true"`
	NextHop              *string                                                       `path:"state/next-hop" module:"openconfig-network-instance"`
	ΛNextHop             []ygot.Annotation                                             `path:"state/@next-hop" ygotAnnotation:"true"`
	Origin               E_OpenconfigBgpTypes_BgpOriginAttrType                        `path:"state/origin" module:"openconfig-network-instance"`
	ΛOrigin              []ygot.Annotation                                             `path:"state/@origin" ygotAnnotation:"true"`
	OriginatorId         *string                                                       `path:"state/originator-id" module:"openconfig-network-instance"`
	ΛOriginatorId        []ygot.Annotation                                             `path:"state/@originator-id" ygotAnnotation:"true"`
	TunnelEncapsulation  *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation `path:"tunnel-encapsulation" module:"openconfig-network-instance"`
	ΛTunnelEncapsulation []ygot.Annotation                                             `path:"@tunnel-encapsulation" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet) IsYANGGoStruct() {}

// GetOrCreateAggregator retrieves the value of the Aggregator field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetOrCreateAggregator() *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator {
	if t.Aggregator != nil {
		return t.Aggregator
	}
	t.Aggregator = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator{}
	return t.Aggregator
}

// GetOrCreateTunnelEncapsulation retrieves the value of the TunnelEncapsulation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetOrCreateTunnelEncapsulation() *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation {
	if t.TunnelEncapsulation != nil {
		return t.TunnelEncapsulation
	}
	t.TunnelEncapsulation = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation{}
	return t.TunnelEncapsulation
}

// GetAggregator returns the value of the Aggregator struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AttrSet. If the receiver or the field Aggregator is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetAggregator() *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator {
	if t != nil && t.Aggregator != nil {
		return t.Aggregator
	}
	return nil
}

// GetTunnelEncapsulation returns the value of the TunnelEncapsulation struct pointer
// from NetworkInstance_Protocol_Bgp_Rib_AttrSet. If the receiver or the field TunnelEncapsulation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetTunnelEncapsulation() *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation {
	if t != nil && t.TunnelEncapsulation != nil {
		return t.TunnelEncapsulation
	}
	return nil
}

// GetAigp retrieves the value of the leaf Aigp from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Aigp is set, it can safely use t.GetAigp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Aigp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetAigp() uint64 {
	if t == nil || t.Aigp == nil {
		return 0
	}
	return *t.Aigp
}

// GetAtomicAggregate retrieves the value of the leaf AtomicAggregate from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AtomicAggregate is set, it can safely use t.GetAtomicAggregate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AtomicAggregate == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetAtomicAggregate() bool {
	if t == nil || t.AtomicAggregate == nil {
		return false
	}
	return *t.AtomicAggregate
}

// GetClusterList retrieves the value of the leaf ClusterList from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ClusterList is set, it can safely use t.GetClusterList()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ClusterList == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetClusterList() []string {
	if t == nil || t.ClusterList == nil {
		return nil
	}
	return t.ClusterList
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLocalPref retrieves the value of the leaf LocalPref from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalPref is set, it can safely use t.GetLocalPref()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalPref == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetLocalPref() uint32 {
	if t == nil || t.LocalPref == nil {
		return 0
	}
	return *t.LocalPref
}

// GetMed retrieves the value of the leaf Med from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Med is set, it can safely use t.GetMed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Med == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetMed() uint32 {
	if t == nil || t.Med == nil {
		return 0
	}
	return *t.Med
}

// GetNextHop retrieves the value of the leaf NextHop from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetNextHop() string {
	if t == nil || t.NextHop == nil {
		return ""
	}
	return *t.NextHop
}

// GetOrigin retrieves the value of the leaf Origin from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Origin is set, it can safely use t.GetOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Origin == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetOrigin() E_OpenconfigBgpTypes_BgpOriginAttrType {
	if t == nil || t.Origin == 0 {
		return 0
	}
	return t.Origin
}

// GetOriginatorId retrieves the value of the leaf OriginatorId from the NetworkInstance_Protocol_Bgp_Rib_AttrSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginatorId is set, it can safely use t.GetOriginatorId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginatorId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) GetOriginatorId() string {
	if t == nil || t.OriginatorId == nil {
		return ""
	}
	return *t.OriginatorId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AttrSet struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/aggregator YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   *string           `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
	As        *uint32           `path:"state/as" module:"openconfig-network-instance"`
	ΛAs       []ygot.Annotation `path:"state/@as" ygotAnnotation:"true"`
	As4       *uint32           `path:"state/as4" module:"openconfig-network-instance"`
	ΛAs4      []ygot.Annotation `path:"state/@as4" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetAs retrieves the value of the leaf As from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As is set, it can safely use t.GetAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator) GetAs() uint32 {
	if t == nil || t.As == nil {
		return 0
	}
	return *t.As
}

// GetAs4 retrieves the value of the leaf As4 from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As4 is set, it can safely use t.GetAs4()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As4 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator) GetAs4() uint32 {
	if t == nil || t.As4 == nil {
		return 0
	}
	return *t.As4
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_Aggregator) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as4-path/as4-segment YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment struct {
	ΛMetadata []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Member    []uint32                               `path:"state/member" module:"openconfig-network-instance"`
	ΛMember   []ygot.Annotation                      `path:"state/@member" ygotAnnotation:"true"`
	Type      E_OpenconfigBgpTypes_AsPathSegmentType `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                      `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment) IsYANGGoStruct() {}

// GetMember retrieves the value of the leaf Member from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Member is set, it can safely use t.GetMember()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Member == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment) GetMember() []uint32 {
	if t == nil || t.Member == nil {
		return nil
	}
	return t.Member
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment) GetType() E_OpenconfigBgpTypes_AsPathSegmentType {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_As4Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as-path/as-segment YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment struct {
	ΛMetadata []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Member    []uint32                               `path:"state/member" module:"openconfig-network-instance"`
	ΛMember   []ygot.Annotation                      `path:"state/@member" ygotAnnotation:"true"`
	Type      E_OpenconfigBgpTypes_AsPathSegmentType `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                      `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment) IsYANGGoStruct() {}

// GetMember retrieves the value of the leaf Member from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Member is set, it can safely use t.GetMember()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Member == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment) GetMember() []uint32 {
	if t == nil || t.Member == nil {
		return nil
	}
	return t.Member
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment) GetType() E_OpenconfigBgpTypes_AsPathSegmentType {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_AsSegment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation struct {
	ΛMetadata []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	Tunnel    map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel `path:"tunnels/tunnel" module:"openconfig-network-instance"`
	ΛTunnel   []ygot.Annotation                                                                                                          `path:"tunnels/@tunnel" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) IsYANGGoStruct() {}

// NewTunnel creates a new entry in the Tunnel list of the
// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) NewTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tunnel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tunnel", key)
	}

	t.Tunnel[key] = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel{
		Type: Type,
	}

	return t.Tunnel[key], nil
}

// RenameTunnel renames an entry in the list Tunnel within
// the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) RenameTunnel(oldK, newK E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) error {
	if _, ok := t.Tunnel[newK]; ok {
		return fmt.Errorf("key %v already exists in Tunnel", newK)
	}

	e, ok := t.Tunnel[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Tunnel", oldK)
	}
	e.Type = newK

	t.Tunnel[newK] = e
	delete(t.Tunnel, oldK)
	return nil
}

// GetOrCreateTunnel retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) GetOrCreateTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel {

	key := Type

	if v, ok := t.Tunnel[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTunnel(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTunnel got unexpected error: %v", err))
	}
	return v
}

// GetTunnel retrieves the value with the specified key from
// the Tunnel map field of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) GetTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Tunnel[key]; ok {
		return lm
	}
	return nil
}

// AppendTunnel appends the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct to the
// list Tunnel of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) AppendTunnel(v *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel)
	}

	if _, ok := t.Tunnel[key]; ok {
		return fmt.Errorf("duplicate key for list Tunnel %v", key)
	}

	t.Tunnel[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct {
	ΛMetadata []ygot.Annotation                                                                                                                        `path:"@" ygotAnnotation:"true"`
	Subtlv    map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv   []ygot.Annotation                                                                                                                        `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	Type      E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE                                                                                        `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                                                                                                                        `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) NewSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) RenameSubtlv(oldK, newK E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) GetOrCreateSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) GetSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) AppendSubtlv(v *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) GetType() E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct {
	ΛMetadata       []ygot.Annotation                                                                                     `path:"@" ygotAnnotation:"true"`
	BindingSid      NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union           `path:"state/binding-sid" module:"openconfig-network-instance"`
	ΛBindingSid     []ygot.Annotation                                                                                     `path:"state/@binding-sid" ygotAnnotation:"true"`
	Colors          []uint32                                                                                              `path:"state/colors" module:"openconfig-network-instance"`
	ΛColors         []ygot.Annotation                                                                                     `path:"state/@colors" ygotAnnotation:"true"`
	Preference      *uint32                                                                                               `path:"state/preference" module:"openconfig-network-instance"`
	ΛPreference     []ygot.Annotation                                                                                     `path:"state/@preference" ygotAnnotation:"true"`
	RemoteEndpoint  map[string]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint `path:"remote-endpoints/remote-endpoint" module:"openconfig-network-instance"`
	ΛRemoteEndpoint []ygot.Annotation                                                                                     `path:"remote-endpoints/@remote-endpoint" ygotAnnotation:"true"`
	SegmentList     map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList    `path:"segment-lists/segment-list" module:"openconfig-network-instance"`
	ΛSegmentList    []ygot.Annotation                                                                                     `path:"segment-lists/@segment-list" ygotAnnotation:"true"`
	Type            E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE                                              `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType           []ygot.Annotation                                                                                     `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) IsYANGGoStruct() {}

// NewRemoteEndpoint creates a new entry in the RemoteEndpoint list of the
// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) NewRemoteEndpoint(Endpoint string) (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteEndpoint == nil {
		t.RemoteEndpoint = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint)
	}

	key := Endpoint

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RemoteEndpoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RemoteEndpoint", key)
	}

	t.RemoteEndpoint[key] = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint{
		Endpoint: &Endpoint,
	}

	return t.RemoteEndpoint[key], nil
}

// RenameRemoteEndpoint renames an entry in the list RemoteEndpoint within
// the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) RenameRemoteEndpoint(oldK, newK string) error {
	if _, ok := t.RemoteEndpoint[newK]; ok {
		return fmt.Errorf("key %v already exists in RemoteEndpoint", newK)
	}

	e, ok := t.RemoteEndpoint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in RemoteEndpoint", oldK)
	}
	e.Endpoint = &newK

	t.RemoteEndpoint[newK] = e
	delete(t.RemoteEndpoint, oldK)
	return nil
}

// GetOrCreateRemoteEndpoint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetOrCreateRemoteEndpoint(Endpoint string) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint {

	key := Endpoint

	if v, ok := t.RemoteEndpoint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRemoteEndpoint(Endpoint)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRemoteEndpoint got unexpected error: %v", err))
	}
	return v
}

// GetRemoteEndpoint retrieves the value with the specified key from
// the RemoteEndpoint map field of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetRemoteEndpoint(Endpoint string) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint {

	if t == nil {
		return nil
	}

	key := Endpoint

	if lm, ok := t.RemoteEndpoint[key]; ok {
		return lm
	}
	return nil
}

// AppendRemoteEndpoint appends the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint struct to the
// list RemoteEndpoint of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) AppendRemoteEndpoint(v *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) error {
	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key received for Endpoint")
	}

	key := *v.Endpoint

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteEndpoint == nil {
		t.RemoteEndpoint = make(map[string]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint)
	}

	if _, ok := t.RemoteEndpoint[key]; ok {
		return fmt.Errorf("duplicate key for list RemoteEndpoint %v", key)
	}

	t.RemoteEndpoint[key] = v
	return nil
}

// NewSegmentList creates a new entry in the SegmentList list of the
// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) NewSegmentList(InstanceId uint64) (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList)
	}

	key := InstanceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SegmentList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SegmentList", key)
	}

	t.SegmentList[key] = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList{
		InstanceId: &InstanceId,
	}

	return t.SegmentList[key], nil
}

// RenameSegmentList renames an entry in the list SegmentList within
// the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) RenameSegmentList(oldK, newK uint64) error {
	if _, ok := t.SegmentList[newK]; ok {
		return fmt.Errorf("key %v already exists in SegmentList", newK)
	}

	e, ok := t.SegmentList[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SegmentList", oldK)
	}
	e.InstanceId = &newK

	t.SegmentList[newK] = e
	delete(t.SegmentList, oldK)
	return nil
}

// GetOrCreateSegmentList retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetOrCreateSegmentList(InstanceId uint64) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList {

	key := InstanceId

	if v, ok := t.SegmentList[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSegmentList(InstanceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSegmentList got unexpected error: %v", err))
	}
	return v
}

// GetSegmentList retrieves the value with the specified key from
// the SegmentList map field of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetSegmentList(InstanceId uint64) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList {

	if t == nil {
		return nil
	}

	key := InstanceId

	if lm, ok := t.SegmentList[key]; ok {
		return lm
	}
	return nil
}

// AppendSegmentList appends the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct to the
// list SegmentList of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) AppendSegmentList(v *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) error {
	if v.InstanceId == nil {
		return fmt.Errorf("invalid nil key received for InstanceId")
	}

	key := *v.InstanceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList)
	}

	if _, ok := t.SegmentList[key]; ok {
		return fmt.Errorf("duplicate key for list SegmentList %v", key)
	}

	t.SegmentList[key] = v
	return nil
}

// GetBindingSid retrieves the value of the leaf BindingSid from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BindingSid is set, it can safely use t.GetBindingSid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BindingSid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetBindingSid() NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union {
	if t == nil || t.BindingSid == nil {
		return nil
	}
	return t.BindingSid
}

// GetColors retrieves the value of the leaf Colors from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Colors is set, it can safely use t.GetColors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Colors == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetColors() []uint32 {
	if t == nil || t.Colors == nil {
		return nil
	}
	return t.Colors
}

// GetPreference retrieves the value of the leaf Preference from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preference is set, it can safely use t.GetPreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetPreference() uint32 {
	if t == nil || t.Preference == nil {
		return 100
	}
	return *t.Preference
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) GetType() E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union() {
}

// To_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv) To_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_BindingSid_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints/remote-endpoint YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	As        *uint32           `path:"state/as" module:"openconfig-network-instance"`
	ΛAs       []ygot.Annotation `path:"state/@as" ygotAnnotation:"true"`
	Endpoint  *string           `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint []ygot.Annotation `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) IsYANGGoStruct() {
}

// GetAs retrieves the value of the leaf As from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if As is set, it can safely use t.GetAs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.As == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) GetAs() uint32 {
	if t == nil || t.As == nil {
		return 0
	}
	return *t.As
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	return map[string]interface{}{
		"endpoint": *t.Endpoint,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_RemoteEndpoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct {
	ΛMetadata   []ygot.Annotation                                                                                          `path:"@" ygotAnnotation:"true"`
	InstanceId  *uint64                                                                                                    `path:"state/instance-id|instance-id" module:"openconfig-network-instance"`
	ΛInstanceId []ygot.Annotation                                                                                          `path:"state/@instance-id|@instance-id" ygotAnnotation:"true"`
	Segment     map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment `path:"segments/segment" module:"openconfig-network-instance"`
	ΛSegment    []ygot.Annotation                                                                                          `path:"segments/@segment" ygotAnnotation:"true"`
	Weight      *uint32                                                                                                    `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight     []ygot.Annotation                                                                                          `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) IsYANGGoStruct() {
}

// NewSegment creates a new entry in the Segment list of the
// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) NewSegment(Index uint64) (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Segment == nil {
		t.Segment = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Segment[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Segment", key)
	}

	t.Segment[key] = &NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment{
		Index: &Index,
	}

	return t.Segment[key], nil
}

// RenameSegment renames an entry in the list Segment within
// the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) RenameSegment(oldK, newK uint64) error {
	if _, ok := t.Segment[newK]; ok {
		return fmt.Errorf("key %v already exists in Segment", newK)
	}

	e, ok := t.Segment[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Segment", oldK)
	}
	e.Index = &newK

	t.Segment[newK] = e
	delete(t.Segment, oldK)
	return nil
}

// GetOrCreateSegment retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetOrCreateSegment(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment {

	key := Index

	if v, ok := t.Segment[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSegment(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSegment got unexpected error: %v", err))
	}
	return v
}

// GetSegment retrieves the value with the specified key from
// the Segment map field of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetSegment(Index uint64) *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Segment[key]; ok {
		return lm
	}
	return nil
}

// AppendSegment appends the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment struct to the
// list Segment of NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) AppendSegment(v *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Segment == nil {
		t.Segment = make(map[uint64]*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment)
	}

	if _, ok := t.Segment[key]; ok {
		return fmt.Errorf("duplicate key for list Segment %v", key)
	}

	t.Segment[key] = v
	return nil
}

// GetInstanceId retrieves the value of the leaf InstanceId from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstanceId is set, it can safely use t.GetInstanceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstanceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetInstanceId() uint64 {
	if t == nil || t.InstanceId == nil {
		return 0
	}
	return *t.InstanceId
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) GetWeight() uint32 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceId == nil {
		return nil, fmt.Errorf("nil value for key InstanceId")
	}

	return map[string]interface{}{
		"instance-id": *t.InstanceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment struct {
	ΛMetadata          []ygot.Annotation                                                                                        `path:"@" ygotAnnotation:"true"`
	Index              *uint64                                                                                                  `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex             []ygot.Annotation                                                                                        `path:"state/@index|@index" ygotAnnotation:"true"`
	LocalInterfaceId   *uint32                                                                                                  `path:"state/local-interface-id" module:"openconfig-network-instance"`
	ΛLocalInterfaceId  []ygot.Annotation                                                                                        `path:"state/@local-interface-id" ygotAnnotation:"true"`
	LocalIpv4Address   *string                                                                                                  `path:"state/local-ipv4-address" module:"openconfig-network-instance"`
	ΛLocalIpv4Address  []ygot.Annotation                                                                                        `path:"state/@local-ipv4-address" ygotAnnotation:"true"`
	LocalIpv6Address   *string                                                                                                  `path:"state/local-ipv6-address" module:"openconfig-network-instance"`
	ΛLocalIpv6Address  []ygot.Annotation                                                                                        `path:"state/@local-ipv6-address" ygotAnnotation:"true"`
	MplsBos            *bool                                                                                                    `path:"state/mpls-bos" module:"openconfig-network-instance"`
	ΛMplsBos           []ygot.Annotation                                                                                        `path:"state/@mpls-bos" ygotAnnotation:"true"`
	MplsTc             *uint8                                                                                                   `path:"state/mpls-tc" module:"openconfig-network-instance"`
	ΛMplsTc            []ygot.Annotation                                                                                        `path:"state/@mpls-tc" ygotAnnotation:"true"`
	MplsTtl            *uint8                                                                                                   `path:"state/mpls-ttl" module:"openconfig-network-instance"`
	ΛMplsTtl           []ygot.Annotation                                                                                        `path:"state/@mpls-ttl" ygotAnnotation:"true"`
	RemoteIpv4Address  *string                                                                                                  `path:"state/remote-ipv4-address" module:"openconfig-network-instance"`
	ΛRemoteIpv4Address []ygot.Annotation                                                                                        `path:"state/@remote-ipv4-address" ygotAnnotation:"true"`
	RemoteIpv6Address  *string                                                                                                  `path:"state/remote-ipv6-address" module:"openconfig-network-instance"`
	ΛRemoteIpv6Address []ygot.Annotation                                                                                        `path:"state/@remote-ipv6-address" ygotAnnotation:"true"`
	Sid                NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union `path:"state/sid" module:"openconfig-network-instance"`
	ΛSid               []ygot.Annotation                                                                                        `path:"state/@sid" ygotAnnotation:"true"`
	Type               E_Segment_Type                                                                                           `path:"state/type" module:"openconfig-network-instance"`
	ΛType              []ygot.Annotation                                                                                        `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) IsYANGGoStruct() {
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLocalInterfaceId retrieves the value of the leaf LocalInterfaceId from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalInterfaceId is set, it can safely use t.GetLocalInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalInterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetLocalInterfaceId() uint32 {
	if t == nil || t.LocalInterfaceId == nil {
		return 0
	}
	return *t.LocalInterfaceId
}

// GetLocalIpv4Address retrieves the value of the leaf LocalIpv4Address from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpv4Address is set, it can safely use t.GetLocalIpv4Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpv4Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetLocalIpv4Address() string {
	if t == nil || t.LocalIpv4Address == nil {
		return ""
	}
	return *t.LocalIpv4Address
}

// GetLocalIpv6Address retrieves the value of the leaf LocalIpv6Address from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpv6Address is set, it can safely use t.GetLocalIpv6Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpv6Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetLocalIpv6Address() string {
	if t == nil || t.LocalIpv6Address == nil {
		return ""
	}
	return *t.LocalIpv6Address
}

// GetMplsBos retrieves the value of the leaf MplsBos from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsBos is set, it can safely use t.GetMplsBos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsBos == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetMplsBos() bool {
	if t == nil || t.MplsBos == nil {
		return false
	}
	return *t.MplsBos
}

// GetMplsTc retrieves the value of the leaf MplsTc from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTc is set, it can safely use t.GetMplsTc()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTc == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetMplsTc() uint8 {
	if t == nil || t.MplsTc == nil {
		return 0
	}
	return *t.MplsTc
}

// GetMplsTtl retrieves the value of the leaf MplsTtl from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTtl is set, it can safely use t.GetMplsTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTtl == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetMplsTtl() uint8 {
	if t == nil || t.MplsTtl == nil {
		return 0
	}
	return *t.MplsTtl
}

// GetRemoteIpv4Address retrieves the value of the leaf RemoteIpv4Address from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteIpv4Address is set, it can safely use t.GetRemoteIpv4Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteIpv4Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetRemoteIpv4Address() string {
	if t == nil || t.RemoteIpv4Address == nil {
		return ""
	}
	return *t.RemoteIpv4Address
}

// GetRemoteIpv6Address retrieves the value of the leaf RemoteIpv6Address from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteIpv6Address is set, it can safely use t.GetRemoteIpv6Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteIpv6Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetRemoteIpv6Address() string {
	if t == nil || t.RemoteIpv6Address == nil {
		return ""
	}
	return *t.RemoteIpv6Address
}

// GetSid retrieves the value of the leaf Sid from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sid is set, it can safely use t.GetSid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetSid() NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union {
	if t == nil || t.Sid == nil {
		return nil
	}
	return t.Sid
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) GetType() E_Segment_Type {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union() {
}

// To_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment) To_NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Rib_AttrSet_TunnelEncapsulation_Tunnel_Subtlv_SegmentList_Segment_Sid_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_Protocol_Bgp_Rib_Community represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_Community struct {
	ΛMetadata  []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	Community  []NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union `path:"state/community" module:"openconfig-network-instance"`
	ΛCommunity []ygot.Annotation                                            `path:"state/@community" ygotAnnotation:"true"`
	Index      *uint64                                                      `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex     []ygot.Annotation                                            `path:"state/@index|@index" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_Community implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_Community) IsYANGGoStruct() {}

// GetCommunity retrieves the value of the leaf Community from the NetworkInstance_Protocol_Bgp_Rib_Community
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Community is set, it can safely use t.GetCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Community == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_Community) GetCommunity() []NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union {
	if t == nil || t.Community == nil {
		return nil
	}
	return t.Community
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Protocol_Bgp_Rib_Community
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_Community) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_Community struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_Community) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_Community) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_Community"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_Community) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community within the YANG schema.
// Union type can be one of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, UnionString, UnionUint32].
type NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union interface {
	// Union type can be one of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union ensures that E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
// implements the NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union interface.
func (E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union() {}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union() {}

// To_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Rib_Community) To_NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Rib_Community_Community_Union, unknown union type, got: %T, want any of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, string, uint32]", i, i)
}

// NetworkInstance_Protocol_Bgp_Rib_ExtCommunity represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community YANG schema element.
type NetworkInstance_Protocol_Bgp_Rib_ExtCommunity struct {
	ΛMetadata     []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	ExtCommunity  []NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union `path:"state/ext-community" module:"openconfig-network-instance"`
	ΛExtCommunity []ygot.Annotation                                                  `path:"state/@ext-community" ygotAnnotation:"true"`
	Index         *uint64                                                            `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex        []ygot.Annotation                                                  `path:"state/@index|@index" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Bgp_Rib_ExtCommunity implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) IsYANGGoStruct() {}

// GetExtCommunity retrieves the value of the leaf ExtCommunity from the NetworkInstance_Protocol_Bgp_Rib_ExtCommunity
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtCommunity is set, it can safely use t.GetExtCommunity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtCommunity == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) GetExtCommunity() []NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union {
	if t == nil || t.ExtCommunity == nil {
		return nil
	}
	return t.ExtCommunity
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Protocol_Bgp_Rib_ExtCommunity
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Bgp_Rib_ExtCommunity struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Bgp_Rib_ExtCommunity"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community/state/ext-community within the YANG schema.
// Union type can be one of [Binary, UnionString].
type NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union interface {
	// Union type can be one of [Binary, UnionString]
	Documentation_for_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union()
}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union ensures that Binary
// implements the NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union interface.
func (Binary) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union() {}

// Documentation_for_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union() {
}

// To_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Bgp_Rib_ExtCommunity) To_NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union(i interface{}) (NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case []byte:
		return Binary(v), nil
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Bgp_Rib_ExtCommunity_ExtCommunity_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
}

// NetworkInstance_Protocol_Igmp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp YANG schema element.
type NetworkInstance_Protocol_Igmp struct {
	ΛMetadata  []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	Global     *NetworkInstance_Protocol_Igmp_Global               `path:"global" module:"openconfig-network-instance"`
	ΛGlobal    []ygot.Annotation                                   `path:"@global" ygotAnnotation:"true"`
	Interface  map[string]*NetworkInstance_Protocol_Igmp_Interface `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface []ygot.Annotation                                   `path:"interfaces/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Protocol_Igmp struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Igmp) NewInterface(InterfaceId string) (*NetworkInstance_Protocol_Igmp_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Igmp_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Protocol_Igmp_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Protocol_Igmp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Igmp) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Igmp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Igmp) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Protocol_Igmp_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Protocol_Igmp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Igmp) GetInterface(InterfaceId string) *NetworkInstance_Protocol_Igmp_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Protocol_Igmp_Interface struct to the
// list Interface of NetworkInstance_Protocol_Igmp. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Igmp_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Igmp) AppendInterface(v *NetworkInstance_Protocol_Igmp_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Igmp_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp) GetOrCreateGlobal() *NetworkInstance_Protocol_Igmp_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Protocol_Igmp_Global{}
	return t.Global
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Protocol_Igmp. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp) GetGlobal() *NetworkInstance_Protocol_Igmp_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Protocol_Igmp_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global YANG schema element.
type NetworkInstance_Protocol_Igmp_Global struct {
	ΛMetadata []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Ssm       *NetworkInstance_Protocol_Igmp_Global_Ssm `path:"ssm" module:"openconfig-network-instance"`
	ΛSsm      []ygot.Annotation                         `path:"@ssm" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Global) IsYANGGoStruct() {}

// GetOrCreateSsm retrieves the value of the Ssm field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Global) GetOrCreateSsm() *NetworkInstance_Protocol_Igmp_Global_Ssm {
	if t.Ssm != nil {
		return t.Ssm
	}
	t.Ssm = &NetworkInstance_Protocol_Igmp_Global_Ssm{}
	return t.Ssm
}

// GetSsm returns the value of the Ssm struct pointer
// from NetworkInstance_Protocol_Igmp_Global. If the receiver or the field Ssm is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Global) GetSsm() *NetworkInstance_Protocol_Igmp_Global_Ssm {
	if t != nil && t.Ssm != nil {
		return t.Ssm
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Global_Ssm represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm YANG schema element.
type NetworkInstance_Protocol_Igmp_Global_Ssm struct {
	ΛMetadata []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	Mapping   map[string]*NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping `path:"mappings/mapping" module:"openconfig-network-instance"`
	ΛMapping  []ygot.Annotation                                            `path:"mappings/@mapping" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Global_Ssm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Global_Ssm) IsYANGGoStruct() {}

// NewMapping creates a new entry in the Mapping list of the
// NetworkInstance_Protocol_Igmp_Global_Ssm struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) NewMapping(Source string) (*NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Mapping == nil {
		t.Mapping = make(map[string]*NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping)
	}

	key := Source

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Mapping[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Mapping", key)
	}

	t.Mapping[key] = &NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping{
		Source: &Source,
	}

	return t.Mapping[key], nil
}

// RenameMapping renames an entry in the list Mapping within
// the NetworkInstance_Protocol_Igmp_Global_Ssm struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) RenameMapping(oldK, newK string) error {
	if _, ok := t.Mapping[newK]; ok {
		return fmt.Errorf("key %v already exists in Mapping", newK)
	}

	e, ok := t.Mapping[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Mapping", oldK)
	}
	e.Source = &newK

	t.Mapping[newK] = e
	delete(t.Mapping, oldK)
	return nil
}

// GetOrCreateMapping retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Igmp_Global_Ssm. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) GetOrCreateMapping(Source string) *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping {

	key := Source

	if v, ok := t.Mapping[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewMapping(Source)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateMapping got unexpected error: %v", err))
	}
	return v
}

// GetMapping retrieves the value with the specified key from
// the Mapping map field of NetworkInstance_Protocol_Igmp_Global_Ssm. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) GetMapping(Source string) *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping {

	if t == nil {
		return nil
	}

	key := Source

	if lm, ok := t.Mapping[key]; ok {
		return lm
	}
	return nil
}

// AppendMapping appends the supplied NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping struct to the
// list Mapping of NetworkInstance_Protocol_Igmp_Global_Ssm. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) AppendMapping(v *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) error {
	if v.Source == nil {
		return fmt.Errorf("invalid nil key received for Source")
	}

	key := *v.Source

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Mapping == nil {
		t.Mapping = make(map[string]*NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping)
	}

	if _, ok := t.Mapping[key]; ok {
		return fmt.Errorf("duplicate key for list Mapping %v", key)
	}

	t.Mapping[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Global_Ssm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm/mappings/mapping YANG schema element.
type NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Source     *string           `path:"state/source|source" shadow-path:"config/source" module:"openconfig-network-instance"`
	ΛSource    []ygot.Annotation `path:"state/@source|@source" ygotAnnotation:"true"`
	SsmRanges  *string           `path:"state/ssm-ranges" shadow-path:"config/ssm-ranges" module:"openconfig-network-instance"`
	ΛSsmRanges []ygot.Annotation `path:"state/@ssm-ranges" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) IsYANGGoStruct() {}

// GetSource retrieves the value of the leaf Source from the NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Source is set, it can safely use t.GetSource()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Source == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) GetSource() string {
	if t == nil || t.Source == nil {
		return ""
	}
	return *t.Source
}

// GetSsmRanges retrieves the value of the leaf SsmRanges from the NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SsmRanges is set, it can safely use t.GetSsmRanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SsmRanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) GetSsmRanges() string {
	if t == nil || t.SsmRanges == nil {
		return ""
	}
	return *t.SsmRanges
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Source == nil {
		return nil, fmt.Errorf("nil value for key Source")
	}

	return map[string]interface{}{
		"source": *t.Source,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Global_Ssm_Mapping) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface struct {
	ΛMetadata       []ygot.Annotation                                         `path:"@" ygotAnnotation:"true"`
	Counters        *NetworkInstance_Protocol_Igmp_Interface_Counters         `path:"counters" module:"openconfig-network-instance"`
	ΛCounters       []ygot.Annotation                                         `path:"@counters" ygotAnnotation:"true"`
	Enabled         *bool                                                     `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled        []ygot.Annotation                                         `path:"state/@enabled" ygotAnnotation:"true"`
	FilterPrefixes  *string                                                   `path:"state/filter-prefixes" shadow-path:"config/filter-prefixes" module:"openconfig-network-instance"`
	ΛFilterPrefixes []ygot.Annotation                                         `path:"state/@filter-prefixes" ygotAnnotation:"true"`
	Group           map[string]*NetworkInstance_Protocol_Igmp_Interface_Group `path:"membership-groups/group" module:"openconfig-network-instance"`
	ΛGroup          []ygot.Annotation                                         `path:"membership-groups/@group" ygotAnnotation:"true"`
	InterfaceId     *string                                                   `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId    []ygot.Annotation                                         `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef    *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef     `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef   []ygot.Annotation                                         `path:"@interface-ref" ygotAnnotation:"true"`
	QueryExpires    *uint64                                                   `path:"state/query-expires" module:"openconfig-network-instance"`
	ΛQueryExpires   []ygot.Annotation                                         `path:"state/@query-expires" ygotAnnotation:"true"`
	QueryInterval   *uint16                                                   `path:"state/query-interval" shadow-path:"config/query-interval" module:"openconfig-network-instance"`
	ΛQueryInterval  []ygot.Annotation                                         `path:"state/@query-interval" ygotAnnotation:"true"`
	Version         *uint8                                                    `path:"state/version" shadow-path:"config/version" module:"openconfig-network-instance"`
	ΛVersion        []ygot.Annotation                                         `path:"state/@version" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface) IsYANGGoStruct() {}

// NewGroup creates a new entry in the Group list of the
// NetworkInstance_Protocol_Igmp_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Igmp_Interface) NewGroup(Group string) (*NetworkInstance_Protocol_Igmp_Interface_Group, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Group == nil {
		t.Group = make(map[string]*NetworkInstance_Protocol_Igmp_Interface_Group)
	}

	key := Group

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Group[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Group", key)
	}

	t.Group[key] = &NetworkInstance_Protocol_Igmp_Interface_Group{
		Group: &Group,
	}

	return t.Group[key], nil
}

// RenameGroup renames an entry in the list Group within
// the NetworkInstance_Protocol_Igmp_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Igmp_Interface) RenameGroup(oldK, newK string) error {
	if _, ok := t.Group[newK]; ok {
		return fmt.Errorf("key %v already exists in Group", newK)
	}

	e, ok := t.Group[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Group", oldK)
	}
	e.Group = &newK

	t.Group[newK] = e
	delete(t.Group, oldK)
	return nil
}

// GetOrCreateGroup retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Igmp_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetOrCreateGroup(Group string) *NetworkInstance_Protocol_Igmp_Interface_Group {

	key := Group

	if v, ok := t.Group[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewGroup(Group)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateGroup got unexpected error: %v", err))
	}
	return v
}

// GetGroup retrieves the value with the specified key from
// the Group map field of NetworkInstance_Protocol_Igmp_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetGroup(Group string) *NetworkInstance_Protocol_Igmp_Interface_Group {

	if t == nil {
		return nil
	}

	key := Group

	if lm, ok := t.Group[key]; ok {
		return lm
	}
	return nil
}

// AppendGroup appends the supplied NetworkInstance_Protocol_Igmp_Interface_Group struct to the
// list Group of NetworkInstance_Protocol_Igmp_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Igmp_Interface_Group already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Igmp_Interface) AppendGroup(v *NetworkInstance_Protocol_Igmp_Interface_Group) error {
	if v.Group == nil {
		return fmt.Errorf("invalid nil key received for Group")
	}

	key := *v.Group

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Group == nil {
		t.Group = make(map[string]*NetworkInstance_Protocol_Igmp_Interface_Group)
	}

	if _, ok := t.Group[key]; ok {
		return fmt.Errorf("duplicate key for list Group %v", key)
	}

	t.Group[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetOrCreateCounters() *NetworkInstance_Protocol_Igmp_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Protocol_Igmp_Interface_Counters{}
	return t.Counters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Protocol_Igmp_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Protocol_Igmp_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetCounters() *NetworkInstance_Protocol_Igmp_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Protocol_Igmp_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetInterfaceRef() *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Igmp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetFilterPrefixes retrieves the value of the leaf FilterPrefixes from the NetworkInstance_Protocol_Igmp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FilterPrefixes is set, it can safely use t.GetFilterPrefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FilterPrefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetFilterPrefixes() string {
	if t == nil || t.FilterPrefixes == nil {
		return ""
	}
	return *t.FilterPrefixes
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Protocol_Igmp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetQueryExpires retrieves the value of the leaf QueryExpires from the NetworkInstance_Protocol_Igmp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if QueryExpires is set, it can safely use t.GetQueryExpires()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.QueryExpires == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetQueryExpires() uint64 {
	if t == nil || t.QueryExpires == nil {
		return 0
	}
	return *t.QueryExpires
}

// GetQueryInterval retrieves the value of the leaf QueryInterval from the NetworkInstance_Protocol_Igmp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if QueryInterval is set, it can safely use t.GetQueryInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.QueryInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetQueryInterval() uint16 {
	if t == nil || t.QueryInterval == nil {
		return 0
	}
	return *t.QueryInterval
}

// GetVersion retrieves the value of the leaf Version from the NetworkInstance_Protocol_Igmp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Version is set, it can safely use t.GetVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Version == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface) GetVersion() uint8 {
	if t == nil || t.Version == nil {
		return 0
	}
	return *t.Version
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Igmp_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Igmp_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_Counters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_Counters struct {
	ΛMetadata []ygot.Annotation                                         `path:"@" ygotAnnotation:"true"`
	Queries   *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries `path:"queries" module:"openconfig-network-instance"`
	ΛQueries  []ygot.Annotation                                         `path:"@queries" ygotAnnotation:"true"`
	Reports   *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports `path:"reports" module:"openconfig-network-instance"`
	ΛReports  []ygot.Annotation                                         `path:"@reports" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_Counters) IsYANGGoStruct() {}

// GetOrCreateQueries retrieves the value of the Queries field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters) GetOrCreateQueries() *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries {
	if t.Queries != nil {
		return t.Queries
	}
	t.Queries = &NetworkInstance_Protocol_Igmp_Interface_Counters_Queries{}
	return t.Queries
}

// GetOrCreateReports retrieves the value of the Reports field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters) GetOrCreateReports() *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports {
	if t.Reports != nil {
		return t.Reports
	}
	t.Reports = &NetworkInstance_Protocol_Igmp_Interface_Counters_Reports{}
	return t.Reports
}

// GetQueries returns the value of the Queries struct pointer
// from NetworkInstance_Protocol_Igmp_Interface_Counters. If the receiver or the field Queries is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters) GetQueries() *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries {
	if t != nil && t.Queries != nil {
		return t.Queries
	}
	return nil
}

// GetReports returns the value of the Reports struct pointer
// from NetworkInstance_Protocol_Igmp_Interface_Counters. If the receiver or the field Reports is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters) GetReports() *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports {
	if t != nil && t.Reports != nil {
		return t.Reports
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_Counters_Queries represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_Counters_Queries struct {
	ΛMetadata []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	Received  *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received `path:"received" module:"openconfig-network-instance"`
	ΛReceived []ygot.Annotation                                                  `path:"@received" ygotAnnotation:"true"`
	Sent      *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent     `path:"sent" module:"openconfig-network-instance"`
	ΛSent     []ygot.Annotation                                                  `path:"@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_Counters_Queries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) IsYANGGoStruct() {}

// GetOrCreateReceived retrieves the value of the Received field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) GetOrCreateReceived() *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received {
	if t.Received != nil {
		return t.Received
	}
	t.Received = &NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received{}
	return t.Received
}

// GetOrCreateSent retrieves the value of the Sent field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) GetOrCreateSent() *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent {
	if t.Sent != nil {
		return t.Sent
	}
	t.Sent = &NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent{}
	return t.Sent
}

// GetReceived returns the value of the Received struct pointer
// from NetworkInstance_Protocol_Igmp_Interface_Counters_Queries. If the receiver or the field Received is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) GetReceived() *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received {
	if t != nil && t.Received != nil {
		return t.Received
	}
	return nil
}

// GetSent returns the value of the Sent struct pointer
// from NetworkInstance_Protocol_Igmp_Interface_Counters_Queries. If the receiver or the field Sent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) GetSent() *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent {
	if t != nil && t.Sent != nil {
		return t.Sent
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_Counters_Queries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries/received YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	V1        *uint32           `path:"state/v1" module:"openconfig-network-instance"`
	ΛV1       []ygot.Annotation `path:"state/@v1" ygotAnnotation:"true"`
	V2        *uint32           `path:"state/v2" module:"openconfig-network-instance"`
	ΛV2       []ygot.Annotation `path:"state/@v2" ygotAnnotation:"true"`
	V3        *uint32           `path:"state/v3" module:"openconfig-network-instance"`
	ΛV3       []ygot.Annotation `path:"state/@v3" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received) IsYANGGoStruct() {}

// GetV1 retrieves the value of the leaf V1 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V1 is set, it can safely use t.GetV1()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V1 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received) GetV1() uint32 {
	if t == nil || t.V1 == nil {
		return 0
	}
	return *t.V1
}

// GetV2 retrieves the value of the leaf V2 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V2 is set, it can safely use t.GetV2()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V2 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received) GetV2() uint32 {
	if t == nil || t.V2 == nil {
		return 0
	}
	return *t.V2
}

// GetV3 retrieves the value of the leaf V3 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V3 is set, it can safely use t.GetV3()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V3 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received) GetV3() uint32 {
	if t == nil || t.V3 == nil {
		return 0
	}
	return *t.V3
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Received) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries/sent YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	V1        *uint32           `path:"state/v1" module:"openconfig-network-instance"`
	ΛV1       []ygot.Annotation `path:"state/@v1" ygotAnnotation:"true"`
	V2        *uint32           `path:"state/v2" module:"openconfig-network-instance"`
	ΛV2       []ygot.Annotation `path:"state/@v2" ygotAnnotation:"true"`
	V3        *uint32           `path:"state/v3" module:"openconfig-network-instance"`
	ΛV3       []ygot.Annotation `path:"state/@v3" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent) IsYANGGoStruct() {}

// GetV1 retrieves the value of the leaf V1 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V1 is set, it can safely use t.GetV1()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V1 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent) GetV1() uint32 {
	if t == nil || t.V1 == nil {
		return 0
	}
	return *t.V1
}

// GetV2 retrieves the value of the leaf V2 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V2 is set, it can safely use t.GetV2()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V2 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent) GetV2() uint32 {
	if t == nil || t.V2 == nil {
		return 0
	}
	return *t.V2
}

// GetV3 retrieves the value of the leaf V3 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V3 is set, it can safely use t.GetV3()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V3 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent) GetV3() uint32 {
	if t == nil || t.V3 == nil {
		return 0
	}
	return *t.V3
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Queries_Sent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_Counters_Reports represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/reports YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_Counters_Reports struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	V1        *uint32           `path:"state/v1" module:"openconfig-network-instance"`
	ΛV1       []ygot.Annotation `path:"state/@v1" ygotAnnotation:"true"`
	V2        *uint32           `path:"state/v2" module:"openconfig-network-instance"`
	ΛV2       []ygot.Annotation `path:"state/@v2" ygotAnnotation:"true"`
	V3        *uint32           `path:"state/v3" module:"openconfig-network-instance"`
	ΛV3       []ygot.Annotation `path:"state/@v3" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_Counters_Reports implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_Counters_Reports) IsYANGGoStruct() {}

// GetV1 retrieves the value of the leaf V1 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Reports
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V1 is set, it can safely use t.GetV1()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V1 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports) GetV1() uint32 {
	if t == nil || t.V1 == nil {
		return 0
	}
	return *t.V1
}

// GetV2 retrieves the value of the leaf V2 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Reports
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V2 is set, it can safely use t.GetV2()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V2 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports) GetV2() uint32 {
	if t == nil || t.V2 == nil {
		return 0
	}
	return *t.V2
}

// GetV3 retrieves the value of the leaf V3 from the NetworkInstance_Protocol_Igmp_Interface_Counters_Reports
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if V3 is set, it can safely use t.GetV3()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.V3 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports) GetV3() uint32 {
	if t == nil || t.V3 == nil {
		return 0
	}
	return *t.V3
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_Counters_Reports"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_Counters_Reports) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_Group represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/membership-groups/group YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_Group struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Group     *string           `path:"state/group|group" module:"openconfig-network-instance"`
	ΛGroup    []ygot.Annotation `path:"state/@group|@group" ygotAnnotation:"true"`
	Reporter  *string           `path:"state/reporter" module:"openconfig-network-instance"`
	ΛReporter []ygot.Annotation `path:"state/@reporter" ygotAnnotation:"true"`
	Source    *string           `path:"state/source" module:"openconfig-network-instance"`
	ΛSource   []ygot.Annotation `path:"state/@source" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_Group implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_Group) IsYANGGoStruct() {}

// GetGroup retrieves the value of the leaf Group from the NetworkInstance_Protocol_Igmp_Interface_Group
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Group is set, it can safely use t.GetGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Group == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Group) GetGroup() string {
	if t == nil || t.Group == nil {
		return ""
	}
	return *t.Group
}

// GetReporter retrieves the value of the leaf Reporter from the NetworkInstance_Protocol_Igmp_Interface_Group
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Reporter is set, it can safely use t.GetReporter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Reporter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Group) GetReporter() string {
	if t == nil || t.Reporter == nil {
		return ""
	}
	return *t.Reporter
}

// GetSource retrieves the value of the leaf Source from the NetworkInstance_Protocol_Igmp_Interface_Group
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Source is set, it can safely use t.GetSource()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Source == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_Group) GetSource() string {
	if t == nil || t.Source == nil {
		return ""
	}
	return *t.Source
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Igmp_Interface_Group struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Igmp_Interface_Group) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Group == nil {
		return nil, fmt.Errorf("nil value for key Group")
	}

	return map[string]interface{}{
		"group": *t.Group,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_Group) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_Group"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_Group) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Igmp_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_Protocol_Igmp_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Igmp_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Igmp_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Protocol_Igmp_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Protocol_Igmp_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Igmp_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Igmp_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis YANG schema element.
type NetworkInstance_Protocol_Isis struct {
	ΛMetadata  []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	Global     *NetworkInstance_Protocol_Isis_Global               `path:"global" module:"openconfig-network-instance"`
	ΛGlobal    []ygot.Annotation                                   `path:"@global" ygotAnnotation:"true"`
	Interface  map[string]*NetworkInstance_Protocol_Isis_Interface `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface []ygot.Annotation                                   `path:"interfaces/@interface" ygotAnnotation:"true"`
	Level      map[uint8]*NetworkInstance_Protocol_Isis_Level      `path:"levels/level" module:"openconfig-network-instance"`
	ΛLevel     []ygot.Annotation                                   `path:"levels/@level" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Protocol_Isis struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis) NewInterface(InterfaceId string) (*NetworkInstance_Protocol_Isis_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Isis_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Protocol_Isis_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Protocol_Isis struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Protocol_Isis_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Protocol_Isis. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis) GetInterface(InterfaceId string) *NetworkInstance_Protocol_Isis_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Protocol_Isis_Interface struct to the
// list Interface of NetworkInstance_Protocol_Isis. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis) AppendInterface(v *NetworkInstance_Protocol_Isis_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Isis_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewLevel creates a new entry in the Level list of the
// NetworkInstance_Protocol_Isis struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis) NewLevel(LevelNumber uint8) (*NetworkInstance_Protocol_Isis_Level, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Level == nil {
		t.Level = make(map[uint8]*NetworkInstance_Protocol_Isis_Level)
	}

	key := LevelNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Level[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Level", key)
	}

	t.Level[key] = &NetworkInstance_Protocol_Isis_Level{
		LevelNumber: &LevelNumber,
	}

	return t.Level[key], nil
}

// RenameLevel renames an entry in the list Level within
// the NetworkInstance_Protocol_Isis struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis) RenameLevel(oldK, newK uint8) error {
	if _, ok := t.Level[newK]; ok {
		return fmt.Errorf("key %v already exists in Level", newK)
	}

	e, ok := t.Level[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Level", oldK)
	}
	e.LevelNumber = &newK

	t.Level[newK] = e
	delete(t.Level, oldK)
	return nil
}

// GetOrCreateLevel retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis) GetOrCreateLevel(LevelNumber uint8) *NetworkInstance_Protocol_Isis_Level {

	key := LevelNumber

	if v, ok := t.Level[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLevel(LevelNumber)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLevel got unexpected error: %v", err))
	}
	return v
}

// GetLevel retrieves the value with the specified key from
// the Level map field of NetworkInstance_Protocol_Isis. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis) GetLevel(LevelNumber uint8) *NetworkInstance_Protocol_Isis_Level {

	if t == nil {
		return nil
	}

	key := LevelNumber

	if lm, ok := t.Level[key]; ok {
		return lm
	}
	return nil
}

// AppendLevel appends the supplied NetworkInstance_Protocol_Isis_Level struct to the
// list Level of NetworkInstance_Protocol_Isis. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis) AppendLevel(v *NetworkInstance_Protocol_Isis_Level) error {
	if v.LevelNumber == nil {
		return fmt.Errorf("invalid nil key received for LevelNumber")
	}

	key := *v.LevelNumber

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Level == nil {
		t.Level = make(map[uint8]*NetworkInstance_Protocol_Isis_Level)
	}

	if _, ok := t.Level[key]; ok {
		return fmt.Errorf("duplicate key for list Level %v", key)
	}

	t.Level[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis) GetOrCreateGlobal() *NetworkInstance_Protocol_Isis_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Protocol_Isis_Global{}
	return t.Global
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Protocol_Isis. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis) GetGlobal() *NetworkInstance_Protocol_Isis_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Protocol_Isis_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global YANG schema element.
type NetworkInstance_Protocol_Isis_Global struct {
	ΛMetadata                      []ygot.Annotation                                                                        `path:"@" ygotAnnotation:"true"`
	Af                             map[NetworkInstance_Protocol_Isis_Global_Af_Key]*NetworkInstance_Protocol_Isis_Global_Af `path:"afi-safi/af" module:"openconfig-network-instance"`
	ΛAf                            []ygot.Annotation                                                                        `path:"afi-safi/@af" ygotAnnotation:"true"`
	Afi                            map[E_OpenconfigIsisTypes_AFI_TYPE]*NetworkInstance_Protocol_Isis_Global_Afi             `path:"igp-shortcuts/afi" module:"openconfig-network-instance"`
	ΛAfi                           []ygot.Annotation                                                                        `path:"igp-shortcuts/@afi" ygotAnnotation:"true"`
	AuthenticationCheck            *bool                                                                                    `path:"state/authentication-check" shadow-path:"config/authentication-check" module:"openconfig-network-instance"`
	ΛAuthenticationCheck           []ygot.Annotation                                                                        `path:"state/@authentication-check" ygotAnnotation:"true"`
	FastFlooding                   *bool                                                                                    `path:"state/fast-flooding" shadow-path:"config/fast-flooding" module:"openconfig-network-instance"`
	ΛFastFlooding                  []ygot.Annotation                                                                        `path:"state/@fast-flooding" ygotAnnotation:"true"`
	GracefulRestart                *NetworkInstance_Protocol_Isis_Global_GracefulRestart                                    `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart               []ygot.Annotation                                                                        `path:"@graceful-restart" ygotAnnotation:"true"`
	IidTlv                         *bool                                                                                    `path:"state/iid-tlv" shadow-path:"config/iid-tlv" module:"openconfig-network-instance"`
	ΛIidTlv                        []ygot.Annotation                                                                        `path:"state/@iid-tlv" ygotAnnotation:"true"`
	Instance                       *string                                                                                  `path:"state/instance" shadow-path:"config/instance" module:"openconfig-network-instance"`
	ΛInstance                      []ygot.Annotation                                                                        `path:"state/@instance" ygotAnnotation:"true"`
	InterLevelPropagationPolicies  *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies                      `path:"inter-level-propagation-policies" module:"openconfig-network-instance"`
	ΛInterLevelPropagationPolicies []ygot.Annotation                                                                        `path:"@inter-level-propagation-policies" ygotAnnotation:"true"`
	LevelCapability                E_OpenconfigIsisTypes_LevelType                                                          `path:"state/level-capability" shadow-path:"config/level-capability" module:"openconfig-network-instance"`
	ΛLevelCapability               []ygot.Annotation                                                                        `path:"state/@level-capability" ygotAnnotation:"true"`
	LspBit                         *NetworkInstance_Protocol_Isis_Global_LspBit                                             `path:"lsp-bit" module:"openconfig-network-instance"`
	ΛLspBit                        []ygot.Annotation                                                                        `path:"@lsp-bit" ygotAnnotation:"true"`
	MaxEcmpPaths                   *uint8                                                                                   `path:"state/max-ecmp-paths" shadow-path:"config/max-ecmp-paths" module:"openconfig-network-instance"`
	ΛMaxEcmpPaths                  []ygot.Annotation                                                                        `path:"state/@max-ecmp-paths" ygotAnnotation:"true"`
	MaximumAreaAddresses           *uint8                                                                                   `path:"state/maximum-area-addresses" shadow-path:"config/maximum-area-addresses" module:"openconfig-network-instance"`
	ΛMaximumAreaAddresses          []ygot.Annotation                                                                        `path:"state/@maximum-area-addresses" ygotAnnotation:"true"`
	Mpls                           *NetworkInstance_Protocol_Isis_Global_Mpls                                               `path:"mpls" module:"openconfig-network-instance"`
	ΛMpls                          []ygot.Annotation                                                                        `path:"@mpls" ygotAnnotation:"true"`
	Net                            []string                                                                                 `path:"state/net" shadow-path:"config/net" module:"openconfig-network-instance"`
	ΛNet                           []ygot.Annotation                                                                        `path:"state/@net" ygotAnnotation:"true"`
	Nsr                            *NetworkInstance_Protocol_Isis_Global_Nsr                                                `path:"nsr" module:"openconfig-network-instance"`
	ΛNsr                           []ygot.Annotation                                                                        `path:"@nsr" ygotAnnotation:"true"`
	PoiTlv                         *bool                                                                                    `path:"state/poi-tlv" shadow-path:"config/poi-tlv" module:"openconfig-network-instance"`
	ΛPoiTlv                        []ygot.Annotation                                                                        `path:"state/@poi-tlv" ygotAnnotation:"true"`
	ReferenceBandwidth             *NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth                                 `path:"reference-bandwidth" module:"openconfig-network-instance"`
	ΛReferenceBandwidth            []ygot.Annotation                                                                        `path:"@reference-bandwidth" ygotAnnotation:"true"`
	SegmentRouting                 *NetworkInstance_Protocol_Isis_Global_SegmentRouting                                     `path:"segment-routing" module:"openconfig-network-instance"`
	ΛSegmentRouting                []ygot.Annotation                                                                        `path:"@segment-routing" ygotAnnotation:"true"`
	Timers                         *NetworkInstance_Protocol_Isis_Global_Timers                                             `path:"timers" module:"openconfig-network-instance"`
	ΛTimers                        []ygot.Annotation                                                                        `path:"@timers" ygotAnnotation:"true"`
	Transport                      *NetworkInstance_Protocol_Isis_Global_Transport                                          `path:"transport" module:"openconfig-network-instance"`
	ΛTransport                     []ygot.Annotation                                                                        `path:"@transport" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Global_Af_Key represents the key for list Af of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global.
type NetworkInstance_Protocol_Isis_Global_Af_Key struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name"`
}

// NewAf creates a new entry in the Af list of the
// NetworkInstance_Protocol_Isis_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Global) NewAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) (*NetworkInstance_Protocol_Isis_Global_Af, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[NetworkInstance_Protocol_Isis_Global_Af_Key]*NetworkInstance_Protocol_Isis_Global_Af)
	}

	key := NetworkInstance_Protocol_Isis_Global_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Af[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Af", key)
	}

	t.Af[key] = &NetworkInstance_Protocol_Isis_Global_Af{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	return t.Af[key], nil
}

// RenameAf renames an entry in the list Af within
// the NetworkInstance_Protocol_Isis_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Global) RenameAf(oldK, newK NetworkInstance_Protocol_Isis_Global_Af_Key) error {
	if _, ok := t.Af[newK]; ok {
		return fmt.Errorf("key %v already exists in Af", newK)
	}

	e, ok := t.Af[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Af", oldK)
	}
	e.AfiName = newK.AfiName
	e.SafiName = newK.SafiName

	t.Af[newK] = e
	delete(t.Af, oldK)
	return nil
}

// GetOrCreateAf retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) *NetworkInstance_Protocol_Isis_Global_Af {

	key := NetworkInstance_Protocol_Isis_Global_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	if v, ok := t.Af[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAf(AfiName, SafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAf got unexpected error: %v", err))
	}
	return v
}

// GetAf retrieves the value with the specified key from
// the Af map field of NetworkInstance_Protocol_Isis_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) *NetworkInstance_Protocol_Isis_Global_Af {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Global_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	if lm, ok := t.Af[key]; ok {
		return lm
	}
	return nil
}

// AppendAf appends the supplied NetworkInstance_Protocol_Isis_Global_Af struct to the
// list Af of NetworkInstance_Protocol_Isis_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Global_Af already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Global) AppendAf(v *NetworkInstance_Protocol_Isis_Global_Af) error {
	key := NetworkInstance_Protocol_Isis_Global_Af_Key{
		AfiName:  v.AfiName,
		SafiName: v.SafiName,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[NetworkInstance_Protocol_Isis_Global_Af_Key]*NetworkInstance_Protocol_Isis_Global_Af)
	}

	if _, ok := t.Af[key]; ok {
		return fmt.Errorf("duplicate key for list Af %v", key)
	}

	t.Af[key] = v
	return nil
}

// NewAfi creates a new entry in the Afi list of the
// NetworkInstance_Protocol_Isis_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Global) NewAfi(AfiName E_OpenconfigIsisTypes_AFI_TYPE) (*NetworkInstance_Protocol_Isis_Global_Afi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Afi == nil {
		t.Afi = make(map[E_OpenconfigIsisTypes_AFI_TYPE]*NetworkInstance_Protocol_Isis_Global_Afi)
	}

	key := AfiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Afi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Afi", key)
	}

	t.Afi[key] = &NetworkInstance_Protocol_Isis_Global_Afi{
		AfiName: AfiName,
	}

	return t.Afi[key], nil
}

// RenameAfi renames an entry in the list Afi within
// the NetworkInstance_Protocol_Isis_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Global) RenameAfi(oldK, newK E_OpenconfigIsisTypes_AFI_TYPE) error {
	if _, ok := t.Afi[newK]; ok {
		return fmt.Errorf("key %v already exists in Afi", newK)
	}

	e, ok := t.Afi[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Afi", oldK)
	}
	e.AfiName = newK

	t.Afi[newK] = e
	delete(t.Afi, oldK)
	return nil
}

// GetOrCreateAfi retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateAfi(AfiName E_OpenconfigIsisTypes_AFI_TYPE) *NetworkInstance_Protocol_Isis_Global_Afi {

	key := AfiName

	if v, ok := t.Afi[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAfi(AfiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAfi got unexpected error: %v", err))
	}
	return v
}

// GetAfi retrieves the value with the specified key from
// the Afi map field of NetworkInstance_Protocol_Isis_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetAfi(AfiName E_OpenconfigIsisTypes_AFI_TYPE) *NetworkInstance_Protocol_Isis_Global_Afi {

	if t == nil {
		return nil
	}

	key := AfiName

	if lm, ok := t.Afi[key]; ok {
		return lm
	}
	return nil
}

// AppendAfi appends the supplied NetworkInstance_Protocol_Isis_Global_Afi struct to the
// list Afi of NetworkInstance_Protocol_Isis_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Global_Afi already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Global) AppendAfi(v *NetworkInstance_Protocol_Isis_Global_Afi) error {
	key := v.AfiName

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Afi == nil {
		t.Afi = make(map[E_OpenconfigIsisTypes_AFI_TYPE]*NetworkInstance_Protocol_Isis_Global_Afi)
	}

	if _, ok := t.Afi[key]; ok {
		return fmt.Errorf("duplicate key for list Afi %v", key)
	}

	t.Afi[key] = v
	return nil
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Isis_Global_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Isis_Global_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateInterLevelPropagationPolicies retrieves the value of the InterLevelPropagationPolicies field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateInterLevelPropagationPolicies() *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies {
	if t.InterLevelPropagationPolicies != nil {
		return t.InterLevelPropagationPolicies
	}
	t.InterLevelPropagationPolicies = &NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies{}
	return t.InterLevelPropagationPolicies
}

// GetOrCreateLspBit retrieves the value of the LspBit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateLspBit() *NetworkInstance_Protocol_Isis_Global_LspBit {
	if t.LspBit != nil {
		return t.LspBit
	}
	t.LspBit = &NetworkInstance_Protocol_Isis_Global_LspBit{}
	return t.LspBit
}

// GetOrCreateMpls retrieves the value of the Mpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateMpls() *NetworkInstance_Protocol_Isis_Global_Mpls {
	if t.Mpls != nil {
		return t.Mpls
	}
	t.Mpls = &NetworkInstance_Protocol_Isis_Global_Mpls{}
	return t.Mpls
}

// GetOrCreateNsr retrieves the value of the Nsr field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateNsr() *NetworkInstance_Protocol_Isis_Global_Nsr {
	if t.Nsr != nil {
		return t.Nsr
	}
	t.Nsr = &NetworkInstance_Protocol_Isis_Global_Nsr{}
	return t.Nsr
}

// GetOrCreateReferenceBandwidth retrieves the value of the ReferenceBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateReferenceBandwidth() *NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth {
	if t.ReferenceBandwidth != nil {
		return t.ReferenceBandwidth
	}
	t.ReferenceBandwidth = &NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth{}
	return t.ReferenceBandwidth
}

// GetOrCreateSegmentRouting retrieves the value of the SegmentRouting field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateSegmentRouting() *NetworkInstance_Protocol_Isis_Global_SegmentRouting {
	if t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	t.SegmentRouting = &NetworkInstance_Protocol_Isis_Global_SegmentRouting{}
	return t.SegmentRouting
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateTimers() *NetworkInstance_Protocol_Isis_Global_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Isis_Global_Timers{}
	return t.Timers
}

// GetOrCreateTransport retrieves the value of the Transport field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global) GetOrCreateTransport() *NetworkInstance_Protocol_Isis_Global_Transport {
	if t.Transport != nil {
		return t.Transport
	}
	t.Transport = &NetworkInstance_Protocol_Isis_Global_Transport{}
	return t.Transport
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetGracefulRestart() *NetworkInstance_Protocol_Isis_Global_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetInterLevelPropagationPolicies returns the value of the InterLevelPropagationPolicies struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field InterLevelPropagationPolicies is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetInterLevelPropagationPolicies() *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies {
	if t != nil && t.InterLevelPropagationPolicies != nil {
		return t.InterLevelPropagationPolicies
	}
	return nil
}

// GetLspBit returns the value of the LspBit struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field LspBit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetLspBit() *NetworkInstance_Protocol_Isis_Global_LspBit {
	if t != nil && t.LspBit != nil {
		return t.LspBit
	}
	return nil
}

// GetMpls returns the value of the Mpls struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field Mpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetMpls() *NetworkInstance_Protocol_Isis_Global_Mpls {
	if t != nil && t.Mpls != nil {
		return t.Mpls
	}
	return nil
}

// GetNsr returns the value of the Nsr struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field Nsr is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetNsr() *NetworkInstance_Protocol_Isis_Global_Nsr {
	if t != nil && t.Nsr != nil {
		return t.Nsr
	}
	return nil
}

// GetReferenceBandwidth returns the value of the ReferenceBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field ReferenceBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetReferenceBandwidth() *NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth {
	if t != nil && t.ReferenceBandwidth != nil {
		return t.ReferenceBandwidth
	}
	return nil
}

// GetSegmentRouting returns the value of the SegmentRouting struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field SegmentRouting is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetSegmentRouting() *NetworkInstance_Protocol_Isis_Global_SegmentRouting {
	if t != nil && t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetTimers() *NetworkInstance_Protocol_Isis_Global_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetTransport returns the value of the Transport struct pointer
// from NetworkInstance_Protocol_Isis_Global. If the receiver or the field Transport is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global) GetTransport() *NetworkInstance_Protocol_Isis_Global_Transport {
	if t != nil && t.Transport != nil {
		return t.Transport
	}
	return nil
}

// GetAuthenticationCheck retrieves the value of the leaf AuthenticationCheck from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationCheck is set, it can safely use t.GetAuthenticationCheck()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationCheck == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetAuthenticationCheck() bool {
	if t == nil || t.AuthenticationCheck == nil {
		return true
	}
	return *t.AuthenticationCheck
}

// GetFastFlooding retrieves the value of the leaf FastFlooding from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FastFlooding is set, it can safely use t.GetFastFlooding()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FastFlooding == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetFastFlooding() bool {
	if t == nil || t.FastFlooding == nil {
		return true
	}
	return *t.FastFlooding
}

// GetIidTlv retrieves the value of the leaf IidTlv from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IidTlv is set, it can safely use t.GetIidTlv()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IidTlv == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetIidTlv() bool {
	if t == nil || t.IidTlv == nil {
		return false
	}
	return *t.IidTlv
}

// GetInstance retrieves the value of the leaf Instance from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instance is set, it can safely use t.GetInstance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instance == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetInstance() string {
	if t == nil || t.Instance == nil {
		return "0"
	}
	return *t.Instance
}

// GetLevelCapability retrieves the value of the leaf LevelCapability from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LevelCapability is set, it can safely use t.GetLevelCapability()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LevelCapability == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetLevelCapability() E_OpenconfigIsisTypes_LevelType {
	if t == nil || t.LevelCapability == 0 {
		return OpenconfigIsisTypes_LevelType_LEVEL_1_2
	}
	return t.LevelCapability
}

// GetMaxEcmpPaths retrieves the value of the leaf MaxEcmpPaths from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxEcmpPaths is set, it can safely use t.GetMaxEcmpPaths()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxEcmpPaths == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetMaxEcmpPaths() uint8 {
	if t == nil || t.MaxEcmpPaths == nil {
		return 0
	}
	return *t.MaxEcmpPaths
}

// GetMaximumAreaAddresses retrieves the value of the leaf MaximumAreaAddresses from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumAreaAddresses is set, it can safely use t.GetMaximumAreaAddresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumAreaAddresses == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetMaximumAreaAddresses() uint8 {
	if t == nil || t.MaximumAreaAddresses == nil {
		return 3
	}
	return *t.MaximumAreaAddresses
}

// GetNet retrieves the value of the leaf Net from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Net is set, it can safely use t.GetNet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Net == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetNet() []string {
	if t == nil || t.Net == nil {
		return nil
	}
	return t.Net
}

// GetPoiTlv retrieves the value of the leaf PoiTlv from the NetworkInstance_Protocol_Isis_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PoiTlv is set, it can safely use t.GetPoiTlv()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PoiTlv == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global) GetPoiTlv() bool {
	if t == nil || t.PoiTlv == nil {
		return false
	}
	return *t.PoiTlv
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Af represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Af struct {
	ΛMetadata      []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	AfiName        E_OpenconfigIsisTypes_AFI_TYPE                         `path:"state/afi-name|afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName       []ygot.Annotation                                      `path:"state/@afi-name|@afi-name" ygotAnnotation:"true"`
	Enabled        *bool                                                  `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled       []ygot.Annotation                                      `path:"state/@enabled" ygotAnnotation:"true"`
	Metric         *uint32                                                `path:"state/metric" shadow-path:"config/metric" module:"openconfig-network-instance"`
	ΛMetric        []ygot.Annotation                                      `path:"state/@metric" ygotAnnotation:"true"`
	MultiTopology  *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology `path:"multi-topology" module:"openconfig-network-instance"`
	ΛMultiTopology []ygot.Annotation                                      `path:"@multi-topology" ygotAnnotation:"true"`
	SafiName       E_OpenconfigIsisTypes_SAFI_TYPE                        `path:"state/safi-name|safi-name" shadow-path:"config/safi-name" module:"openconfig-network-instance"`
	ΛSafiName      []ygot.Annotation                                      `path:"state/@safi-name|@safi-name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Af implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Af) IsYANGGoStruct() {}

// GetOrCreateMultiTopology retrieves the value of the MultiTopology field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_Af) GetOrCreateMultiTopology() *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology {
	if t.MultiTopology != nil {
		return t.MultiTopology
	}
	t.MultiTopology = &NetworkInstance_Protocol_Isis_Global_Af_MultiTopology{}
	return t.MultiTopology
}

// GetMultiTopology returns the value of the MultiTopology struct pointer
// from NetworkInstance_Protocol_Isis_Global_Af. If the receiver or the field MultiTopology is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_Af) GetMultiTopology() *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology {
	if t != nil && t.MultiTopology != nil {
		return t.MultiTopology
	}
	return nil
}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Protocol_Isis_Global_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af) GetAfiName() E_OpenconfigIsisTypes_AFI_TYPE {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Global_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Global_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 10
	}
	return *t.Metric
}

// GetSafiName retrieves the value of the leaf SafiName from the NetworkInstance_Protocol_Isis_Global_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SafiName is set, it can safely use t.GetSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af) GetSafiName() E_OpenconfigIsisTypes_SAFI_TYPE {
	if t == nil || t.SafiName == 0 {
		return 0
	}
	return t.SafiName
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Global_Af struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Global_Af) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name":  t.AfiName,
		"safi-name": t.SafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Af) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Af"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Af) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Af_MultiTopology represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Af_MultiTopology struct {
	ΛMetadata []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	AfiName   E_OpenconfigIsisTypes_AFI_TYPE  `path:"state/afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName  []ygot.Annotation               `path:"state/@afi-name" ygotAnnotation:"true"`
	Enabled   *bool                           `path:"state/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation               `path:"state/@enabled" ygotAnnotation:"true"`
	SafiName  E_OpenconfigIsisTypes_SAFI_TYPE `path:"state/safi-name" shadow-path:"config/safi-name" module:"openconfig-network-instance"`
	ΛSafiName []ygot.Annotation               `path:"state/@safi-name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Af_MultiTopology implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Af_MultiTopology) IsYANGGoStruct() {}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Protocol_Isis_Global_Af_MultiTopology
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology) GetAfiName() E_OpenconfigIsisTypes_AFI_TYPE {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Global_Af_MultiTopology
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetSafiName retrieves the value of the leaf SafiName from the NetworkInstance_Protocol_Isis_Global_Af_MultiTopology
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SafiName is set, it can safely use t.GetSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology) GetSafiName() E_OpenconfigIsisTypes_SAFI_TYPE {
	if t == nil || t.SafiName == 0 {
		return 0
	}
	return t.SafiName
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Af_MultiTopology"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Af_MultiTopology) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Afi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Afi struct {
	ΛMetadata []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	AfiName   E_OpenconfigIsisTypes_AFI_TYPE              `path:"state/afi-name|afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName  []ygot.Annotation                           `path:"state/@afi-name|@afi-name" ygotAnnotation:"true"`
	NhType    []E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL `path:"state/nh-type" shadow-path:"config/nh-type" module:"openconfig-network-instance"`
	ΛNhType   []ygot.Annotation                           `path:"state/@nh-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Afi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Afi) IsYANGGoStruct() {}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Protocol_Isis_Global_Afi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Afi) GetAfiName() E_OpenconfigIsisTypes_AFI_TYPE {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// GetNhType retrieves the value of the leaf NhType from the NetworkInstance_Protocol_Isis_Global_Afi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NhType is set, it can safely use t.GetNhType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NhType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Afi) GetNhType() []E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL {
	if t == nil || t.NhType == nil {
		return nil
	}
	return t.NhType
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Global_Afi struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Global_Afi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name": t.AfiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Afi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Afi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Afi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Isis_Global_GracefulRestart struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled     *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled    []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly  *bool             `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-network-instance"`
	ΛHelperOnly []ygot.Annotation `path:"state/@helper-only" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the NetworkInstance_Protocol_Isis_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies YANG schema element.
type NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies struct {
	ΛMetadata       []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	Level1ToLevel2  *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 `path:"level1-to-level2" module:"openconfig-network-instance"`
	ΛLevel1ToLevel2 []ygot.Annotation                                                                  `path:"@level1-to-level2" ygotAnnotation:"true"`
	Level2ToLevel1  *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 `path:"level2-to-level1" module:"openconfig-network-instance"`
	ΛLevel2ToLevel1 []ygot.Annotation                                                                  `path:"@level2-to-level1" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) IsYANGGoStruct() {}

// GetOrCreateLevel1ToLevel2 retrieves the value of the Level1ToLevel2 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) GetOrCreateLevel1ToLevel2() *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 {
	if t.Level1ToLevel2 != nil {
		return t.Level1ToLevel2
	}
	t.Level1ToLevel2 = &NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2{}
	return t.Level1ToLevel2
}

// GetOrCreateLevel2ToLevel1 retrieves the value of the Level2ToLevel1 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) GetOrCreateLevel2ToLevel1() *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 {
	if t.Level2ToLevel1 != nil {
		return t.Level2ToLevel1
	}
	t.Level2ToLevel1 = &NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1{}
	return t.Level2ToLevel1
}

// GetLevel1ToLevel2 returns the value of the Level1ToLevel2 struct pointer
// from NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies. If the receiver or the field Level1ToLevel2 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) GetLevel1ToLevel2() *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 {
	if t != nil && t.Level1ToLevel2 != nil {
		return t.Level1ToLevel2
	}
	return nil
}

// GetLevel2ToLevel1 returns the value of the Level2ToLevel1 struct pointer
// from NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies. If the receiver or the field Level2ToLevel1 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) GetLevel2ToLevel1() *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 {
	if t != nil && t.Level2ToLevel1 != nil {
		return t.Level2ToLevel1
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2 YANG schema element.
type NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) IsYANGGoStruct() {
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1 YANG schema element.
type NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 struct {
	ΛMetadata            []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                           `path:"state/@default-import-policy" ygotAnnotation:"true"`
	ImportPolicy         []string                                    `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                           `path:"state/@import-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) IsYANGGoStruct() {
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_LspBit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit YANG schema element.
type NetworkInstance_Protocol_Isis_Global_LspBit struct {
	ΛMetadata    []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	AttachedBit  *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit `path:"attached-bit" module:"openconfig-network-instance"`
	ΛAttachedBit []ygot.Annotation                                        `path:"@attached-bit" ygotAnnotation:"true"`
	OverloadBit  *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit `path:"overload-bit" module:"openconfig-network-instance"`
	ΛOverloadBit []ygot.Annotation                                        `path:"@overload-bit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_LspBit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_LspBit) IsYANGGoStruct() {}

// GetOrCreateAttachedBit retrieves the value of the AttachedBit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit) GetOrCreateAttachedBit() *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit {
	if t.AttachedBit != nil {
		return t.AttachedBit
	}
	t.AttachedBit = &NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit{}
	return t.AttachedBit
}

// GetOrCreateOverloadBit retrieves the value of the OverloadBit field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit) GetOrCreateOverloadBit() *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit {
	if t.OverloadBit != nil {
		return t.OverloadBit
	}
	t.OverloadBit = &NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit{}
	return t.OverloadBit
}

// GetAttachedBit returns the value of the AttachedBit struct pointer
// from NetworkInstance_Protocol_Isis_Global_LspBit. If the receiver or the field AttachedBit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit) GetAttachedBit() *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit {
	if t != nil && t.AttachedBit != nil {
		return t.AttachedBit
	}
	return nil
}

// GetOverloadBit returns the value of the OverloadBit struct pointer
// from NetworkInstance_Protocol_Isis_Global_LspBit. If the receiver or the field OverloadBit is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit) GetOverloadBit() *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit {
	if t != nil && t.OverloadBit != nil {
		return t.OverloadBit
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_LspBit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/attached-bit YANG schema element.
type NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	IgnoreBit    *bool             `path:"state/ignore-bit" shadow-path:"config/ignore-bit" module:"openconfig-network-instance"`
	ΛIgnoreBit   []ygot.Annotation `path:"state/@ignore-bit" ygotAnnotation:"true"`
	SuppressBit  *bool             `path:"state/suppress-bit" shadow-path:"config/suppress-bit" module:"openconfig-network-instance"`
	ΛSuppressBit []ygot.Annotation `path:"state/@suppress-bit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit) IsYANGGoStruct() {}

// GetIgnoreBit retrieves the value of the leaf IgnoreBit from the NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgnoreBit is set, it can safely use t.GetIgnoreBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgnoreBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit) GetIgnoreBit() bool {
	if t == nil || t.IgnoreBit == nil {
		return false
	}
	return *t.IgnoreBit
}

// GetSuppressBit retrieves the value of the leaf SuppressBit from the NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SuppressBit is set, it can safely use t.GetSuppressBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SuppressBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit) GetSuppressBit() bool {
	if t == nil || t.SuppressBit == nil {
		return false
	}
	return *t.SuppressBit
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_AttachedBit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit YANG schema element.
type NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit struct {
	ΛMetadata            []ygot.Annotation                                                                                                           `path:"@" ygotAnnotation:"true"`
	AdvertiseHighMetric  *bool                                                                                                                       `path:"state/advertise-high-metric" shadow-path:"config/advertise-high-metric" module:"openconfig-network-instance"`
	ΛAdvertiseHighMetric []ygot.Annotation                                                                                                           `path:"state/@advertise-high-metric" ygotAnnotation:"true"`
	ResetTrigger         map[E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE]*NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger `path:"reset-triggers/reset-trigger" module:"openconfig-network-instance"`
	ΛResetTrigger        []ygot.Annotation                                                                                                           `path:"reset-triggers/@reset-trigger" ygotAnnotation:"true"`
	SetBit               *bool                                                                                                                       `path:"state/set-bit" shadow-path:"config/set-bit" module:"openconfig-network-instance"`
	ΛSetBit              []ygot.Annotation                                                                                                           `path:"state/@set-bit" ygotAnnotation:"true"`
	SetBitOnBoot         *bool                                                                                                                       `path:"state/set-bit-on-boot" shadow-path:"config/set-bit-on-boot" module:"openconfig-network-instance"`
	ΛSetBitOnBoot        []ygot.Annotation                                                                                                           `path:"state/@set-bit-on-boot" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) IsYANGGoStruct() {}

// NewResetTrigger creates a new entry in the ResetTrigger list of the
// NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) NewResetTrigger(ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) (*NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ResetTrigger == nil {
		t.ResetTrigger = make(map[E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE]*NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger)
	}

	key := ResetTrigger

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ResetTrigger[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ResetTrigger", key)
	}

	t.ResetTrigger[key] = &NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger{
		ResetTrigger: ResetTrigger,
	}

	return t.ResetTrigger[key], nil
}

// RenameResetTrigger renames an entry in the list ResetTrigger within
// the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) RenameResetTrigger(oldK, newK E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) error {
	if _, ok := t.ResetTrigger[newK]; ok {
		return fmt.Errorf("key %v already exists in ResetTrigger", newK)
	}

	e, ok := t.ResetTrigger[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ResetTrigger", oldK)
	}
	e.ResetTrigger = newK

	t.ResetTrigger[newK] = e
	delete(t.ResetTrigger, oldK)
	return nil
}

// GetOrCreateResetTrigger retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) GetOrCreateResetTrigger(ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger {

	key := ResetTrigger

	if v, ok := t.ResetTrigger[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewResetTrigger(ResetTrigger)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateResetTrigger got unexpected error: %v", err))
	}
	return v
}

// GetResetTrigger retrieves the value with the specified key from
// the ResetTrigger map field of NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) GetResetTrigger(ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger {

	if t == nil {
		return nil
	}

	key := ResetTrigger

	if lm, ok := t.ResetTrigger[key]; ok {
		return lm
	}
	return nil
}

// AppendResetTrigger appends the supplied NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger struct to the
// list ResetTrigger of NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) AppendResetTrigger(v *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) error {
	key := v.ResetTrigger

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ResetTrigger == nil {
		t.ResetTrigger = make(map[E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE]*NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger)
	}

	if _, ok := t.ResetTrigger[key]; ok {
		return fmt.Errorf("duplicate key for list ResetTrigger %v", key)
	}

	t.ResetTrigger[key] = v
	return nil
}

// GetAdvertiseHighMetric retrieves the value of the leaf AdvertiseHighMetric from the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertiseHighMetric is set, it can safely use t.GetAdvertiseHighMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertiseHighMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) GetAdvertiseHighMetric() bool {
	if t == nil || t.AdvertiseHighMetric == nil {
		return false
	}
	return *t.AdvertiseHighMetric
}

// GetSetBit retrieves the value of the leaf SetBit from the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetBit is set, it can safely use t.GetSetBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) GetSetBit() bool {
	if t == nil || t.SetBit == nil {
		return false
	}
	return *t.SetBit
}

// GetSetBitOnBoot retrieves the value of the leaf SetBitOnBoot from the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetBitOnBoot is set, it can safely use t.GetSetBitOnBoot()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetBitOnBoot == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) GetSetBitOnBoot() bool {
	if t == nil || t.SetBitOnBoot == nil {
		return false
	}
	return *t.SetBitOnBoot
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger YANG schema element.
type NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger struct {
	ΛMetadata     []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	Delay         *uint16                                           `path:"state/delay" shadow-path:"config/delay" module:"openconfig-network-instance"`
	ΛDelay        []ygot.Annotation                                 `path:"state/@delay" ygotAnnotation:"true"`
	ResetTrigger  E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE `path:"state/reset-trigger|reset-trigger" shadow-path:"config/reset-trigger" module:"openconfig-network-instance"`
	ΛResetTrigger []ygot.Annotation                                 `path:"state/@reset-trigger|@reset-trigger" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) IsYANGGoStruct() {}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) GetDelay() uint16 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// GetResetTrigger retrieves the value of the leaf ResetTrigger from the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ResetTrigger is set, it can safely use t.GetResetTrigger()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ResetTrigger == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) GetResetTrigger() E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE {
	if t == nil || t.ResetTrigger == 0 {
		return 0
	}
	return t.ResetTrigger
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"reset-trigger": t.ResetTrigger,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_LspBit_OverloadBit_ResetTrigger) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/mpls YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Mpls struct {
	ΛMetadata   []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	IgpLdpSync  *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
	ΛIgpLdpSync []ygot.Annotation                                     `path:"@igp-ldp-sync" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Mpls) IsYANGGoStruct() {}

// GetOrCreateIgpLdpSync retrieves the value of the IgpLdpSync field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls) GetOrCreateIgpLdpSync() *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync {
	if t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	t.IgpLdpSync = &NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync{}
	return t.IgpLdpSync
}

// GetIgpLdpSync returns the value of the IgpLdpSync struct pointer
// from NetworkInstance_Protocol_Isis_Global_Mpls. If the receiver or the field IgpLdpSync is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls) GetIgpLdpSync() *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync {
	if t != nil && t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/mpls/igp-ldp-sync YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled             *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	PostSessionUpDelay  *uint16           `path:"state/post-session-up-delay" shadow-path:"config/post-session-up-delay" module:"openconfig-network-instance"`
	ΛPostSessionUpDelay []ygot.Annotation `path:"state/@post-session-up-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetPostSessionUpDelay retrieves the value of the leaf PostSessionUpDelay from the NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PostSessionUpDelay is set, it can safely use t.GetPostSessionUpDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PostSessionUpDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync) GetPostSessionUpDelay() uint16 {
	if t == nil || t.PostSessionUpDelay == nil {
		return 0
	}
	return *t.PostSessionUpDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Nsr represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/nsr YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Nsr struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled   *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Nsr implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Nsr) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Global_Nsr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Nsr) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Nsr) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Nsr"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Nsr) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/reference-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ReferenceBandwidth  *uint32           `path:"state/reference-bandwidth" shadow-path:"config/reference-bandwidth" module:"openconfig-network-instance"`
	ΛReferenceBandwidth []ygot.Annotation `path:"state/@reference-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth) IsYANGGoStruct() {}

// GetReferenceBandwidth retrieves the value of the leaf ReferenceBandwidth from the NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReferenceBandwidth is set, it can safely use t.GetReferenceBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReferenceBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth) GetReferenceBandwidth() uint32 {
	if t == nil || t.ReferenceBandwidth == nil {
		return 0
	}
	return *t.ReferenceBandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_ReferenceBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/segment-routing YANG schema element.
type NetworkInstance_Protocol_Isis_Global_SegmentRouting struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled   *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	Srgb      *string           `path:"state/srgb" shadow-path:"config/srgb" module:"openconfig-network-instance"`
	ΛSrgb     []ygot.Annotation `path:"state/@srgb" ygotAnnotation:"true"`
	Srlb      *string           `path:"state/srlb" shadow-path:"config/srlb" module:"openconfig-network-instance"`
	ΛSrlb     []ygot.Annotation `path:"state/@srlb" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_SegmentRouting) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Global_SegmentRouting
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_SegmentRouting) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetSrgb retrieves the value of the leaf Srgb from the NetworkInstance_Protocol_Isis_Global_SegmentRouting
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Srgb is set, it can safely use t.GetSrgb()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Srgb == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_SegmentRouting) GetSrgb() string {
	if t == nil || t.Srgb == nil {
		return ""
	}
	return *t.Srgb
}

// GetSrlb retrieves the value of the leaf Srlb from the NetworkInstance_Protocol_Isis_Global_SegmentRouting
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Srlb is set, it can safely use t.GetSrlb()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Srlb == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_SegmentRouting) GetSrlb() string {
	if t == nil || t.Srlb == nil {
		return ""
	}
	return *t.Srlb
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Timers struct {
	ΛMetadata            []ygot.Annotation                                          `path:"@" ygotAnnotation:"true"`
	LspGeneration        *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration `path:"lsp-generation" module:"openconfig-network-instance"`
	ΛLspGeneration       []ygot.Annotation                                          `path:"@lsp-generation" ygotAnnotation:"true"`
	LspLifetimeInterval  *uint16                                                    `path:"state/lsp-lifetime-interval" shadow-path:"config/lsp-lifetime-interval" module:"openconfig-network-instance"`
	ΛLspLifetimeInterval []ygot.Annotation                                          `path:"state/@lsp-lifetime-interval" ygotAnnotation:"true"`
	LspRefreshInterval   *uint16                                                    `path:"state/lsp-refresh-interval" shadow-path:"config/lsp-refresh-interval" module:"openconfig-network-instance"`
	ΛLspRefreshInterval  []ygot.Annotation                                          `path:"state/@lsp-refresh-interval" ygotAnnotation:"true"`
	Spf                  *NetworkInstance_Protocol_Isis_Global_Timers_Spf           `path:"spf" module:"openconfig-network-instance"`
	ΛSpf                 []ygot.Annotation                                          `path:"@spf" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Timers) IsYANGGoStruct() {}

// GetOrCreateLspGeneration retrieves the value of the LspGeneration field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) GetOrCreateLspGeneration() *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration {
	if t.LspGeneration != nil {
		return t.LspGeneration
	}
	t.LspGeneration = &NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration{}
	return t.LspGeneration
}

// GetOrCreateSpf retrieves the value of the Spf field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) GetOrCreateSpf() *NetworkInstance_Protocol_Isis_Global_Timers_Spf {
	if t.Spf != nil {
		return t.Spf
	}
	t.Spf = &NetworkInstance_Protocol_Isis_Global_Timers_Spf{}
	return t.Spf
}

// GetLspGeneration returns the value of the LspGeneration struct pointer
// from NetworkInstance_Protocol_Isis_Global_Timers. If the receiver or the field LspGeneration is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) GetLspGeneration() *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration {
	if t != nil && t.LspGeneration != nil {
		return t.LspGeneration
	}
	return nil
}

// GetSpf returns the value of the Spf struct pointer
// from NetworkInstance_Protocol_Isis_Global_Timers. If the receiver or the field Spf is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) GetSpf() *NetworkInstance_Protocol_Isis_Global_Timers_Spf {
	if t != nil && t.Spf != nil {
		return t.Spf
	}
	return nil
}

// GetLspLifetimeInterval retrieves the value of the leaf LspLifetimeInterval from the NetworkInstance_Protocol_Isis_Global_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspLifetimeInterval is set, it can safely use t.GetLspLifetimeInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspLifetimeInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) GetLspLifetimeInterval() uint16 {
	if t == nil || t.LspLifetimeInterval == nil {
		return 1200
	}
	return *t.LspLifetimeInterval
}

// GetLspRefreshInterval retrieves the value of the leaf LspRefreshInterval from the NetworkInstance_Protocol_Isis_Global_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspRefreshInterval is set, it can safely use t.GetLspRefreshInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspRefreshInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) GetLspRefreshInterval() uint16 {
	if t == nil || t.LspRefreshInterval == nil {
		return 0
	}
	return *t.LspRefreshInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/lsp-generation YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration struct {
	ΛMetadata              []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	AdaptiveTimer          E_OpenconfigIsisTypes_AdaptiveTimerType `path:"state/adaptive-timer" module:"openconfig-network-instance"`
	ΛAdaptiveTimer         []ygot.Annotation                       `path:"state/@adaptive-timer" ygotAnnotation:"true"`
	LspFirstWaitInterval   *uint64                                 `path:"state/lsp-first-wait-interval" shadow-path:"config/lsp-first-wait-interval" module:"openconfig-network-instance"`
	ΛLspFirstWaitInterval  []ygot.Annotation                       `path:"state/@lsp-first-wait-interval" ygotAnnotation:"true"`
	LspMaxWaitInterval     *uint64                                 `path:"state/lsp-max-wait-interval" shadow-path:"config/lsp-max-wait-interval" module:"openconfig-network-instance"`
	ΛLspMaxWaitInterval    []ygot.Annotation                       `path:"state/@lsp-max-wait-interval" ygotAnnotation:"true"`
	LspSecondWaitInterval  *uint64                                 `path:"state/lsp-second-wait-interval" shadow-path:"config/lsp-second-wait-interval" module:"openconfig-network-instance"`
	ΛLspSecondWaitInterval []ygot.Annotation                       `path:"state/@lsp-second-wait-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) IsYANGGoStruct() {}

// GetAdaptiveTimer retrieves the value of the leaf AdaptiveTimer from the NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdaptiveTimer is set, it can safely use t.GetAdaptiveTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdaptiveTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) GetAdaptiveTimer() E_OpenconfigIsisTypes_AdaptiveTimerType {
	if t == nil || t.AdaptiveTimer == 0 {
		return 0
	}
	return t.AdaptiveTimer
}

// GetLspFirstWaitInterval retrieves the value of the leaf LspFirstWaitInterval from the NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspFirstWaitInterval is set, it can safely use t.GetLspFirstWaitInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspFirstWaitInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) GetLspFirstWaitInterval() uint64 {
	if t == nil || t.LspFirstWaitInterval == nil {
		return 0
	}
	return *t.LspFirstWaitInterval
}

// GetLspMaxWaitInterval retrieves the value of the leaf LspMaxWaitInterval from the NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspMaxWaitInterval is set, it can safely use t.GetLspMaxWaitInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspMaxWaitInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) GetLspMaxWaitInterval() uint64 {
	if t == nil || t.LspMaxWaitInterval == nil {
		return 0
	}
	return *t.LspMaxWaitInterval
}

// GetLspSecondWaitInterval retrieves the value of the leaf LspSecondWaitInterval from the NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspSecondWaitInterval is set, it can safely use t.GetLspSecondWaitInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspSecondWaitInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) GetLspSecondWaitInterval() uint64 {
	if t == nil || t.LspSecondWaitInterval == nil {
		return 0
	}
	return *t.LspSecondWaitInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_LspGeneration) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Timers_Spf represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/spf YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Timers_Spf struct {
	ΛMetadata          []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	AdaptiveTimer      E_OpenconfigIsisTypes_AdaptiveTimerType `path:"state/adaptive-timer" module:"openconfig-network-instance"`
	ΛAdaptiveTimer     []ygot.Annotation                       `path:"state/@adaptive-timer" ygotAnnotation:"true"`
	SpfFirstInterval   *uint64                                 `path:"state/spf-first-interval" shadow-path:"config/spf-first-interval" module:"openconfig-network-instance"`
	ΛSpfFirstInterval  []ygot.Annotation                       `path:"state/@spf-first-interval" ygotAnnotation:"true"`
	SpfHoldInterval    *uint64                                 `path:"state/spf-hold-interval" shadow-path:"config/spf-hold-interval" module:"openconfig-network-instance"`
	ΛSpfHoldInterval   []ygot.Annotation                       `path:"state/@spf-hold-interval" ygotAnnotation:"true"`
	SpfSecondInterval  *uint64                                 `path:"state/spf-second-interval" shadow-path:"config/spf-second-interval" module:"openconfig-network-instance"`
	ΛSpfSecondInterval []ygot.Annotation                       `path:"state/@spf-second-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Timers_Spf implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Timers_Spf) IsYANGGoStruct() {}

// GetAdaptiveTimer retrieves the value of the leaf AdaptiveTimer from the NetworkInstance_Protocol_Isis_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdaptiveTimer is set, it can safely use t.GetAdaptiveTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdaptiveTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_Spf) GetAdaptiveTimer() E_OpenconfigIsisTypes_AdaptiveTimerType {
	if t == nil || t.AdaptiveTimer == 0 {
		return 0
	}
	return t.AdaptiveTimer
}

// GetSpfFirstInterval retrieves the value of the leaf SpfFirstInterval from the NetworkInstance_Protocol_Isis_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpfFirstInterval is set, it can safely use t.GetSpfFirstInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpfFirstInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_Spf) GetSpfFirstInterval() uint64 {
	if t == nil || t.SpfFirstInterval == nil {
		return 0
	}
	return *t.SpfFirstInterval
}

// GetSpfHoldInterval retrieves the value of the leaf SpfHoldInterval from the NetworkInstance_Protocol_Isis_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpfHoldInterval is set, it can safely use t.GetSpfHoldInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpfHoldInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_Spf) GetSpfHoldInterval() uint64 {
	if t == nil || t.SpfHoldInterval == nil {
		return 5000
	}
	return *t.SpfHoldInterval
}

// GetSpfSecondInterval retrieves the value of the leaf SpfSecondInterval from the NetworkInstance_Protocol_Isis_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpfSecondInterval is set, it can safely use t.GetSpfSecondInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpfSecondInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_Spf) GetSpfSecondInterval() uint64 {
	if t == nil || t.SpfSecondInterval == nil {
		return 0
	}
	return *t.SpfSecondInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_Spf) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Timers_Spf"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Timers_Spf) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Global_Transport represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/transport YANG schema element.
type NetworkInstance_Protocol_Isis_Global_Transport struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	LspMtuSize  *uint16           `path:"state/lsp-mtu-size" shadow-path:"config/lsp-mtu-size" module:"openconfig-network-instance"`
	ΛLspMtuSize []ygot.Annotation `path:"state/@lsp-mtu-size" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Global_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Global_Transport) IsYANGGoStruct() {}

// GetLspMtuSize retrieves the value of the leaf LspMtuSize from the NetworkInstance_Protocol_Isis_Global_Transport
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspMtuSize is set, it can safely use t.GetLspMtuSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspMtuSize == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Global_Transport) GetLspMtuSize() uint16 {
	if t == nil || t.LspMtuSize == nil {
		return 0
	}
	return *t.LspMtuSize
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Global_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Global_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Global_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface YANG schema element.
type NetworkInstance_Protocol_Isis_Interface struct {
	ΛMetadata        []ygot.Annotation                                                                              `path:"@" ygotAnnotation:"true"`
	Af               map[NetworkInstance_Protocol_Isis_Interface_Af_Key]*NetworkInstance_Protocol_Isis_Interface_Af `path:"afi-safi/af" module:"openconfig-network-instance"`
	ΛAf              []ygot.Annotation                                                                              `path:"afi-safi/@af" ygotAnnotation:"true"`
	Authentication   *NetworkInstance_Protocol_Isis_Interface_Authentication                                        `path:"authentication" module:"openconfig-network-instance"`
	ΛAuthentication  []ygot.Annotation                                                                              `path:"@authentication" ygotAnnotation:"true"`
	Bfd              *NetworkInstance_Protocol_Isis_Interface_Bfd                                                   `path:"bfd" module:"openconfig-network-instance"`
	ΛBfd             []ygot.Annotation                                                                              `path:"@bfd" ygotAnnotation:"true"`
	CircuitCounters  *NetworkInstance_Protocol_Isis_Interface_CircuitCounters                                       `path:"circuit-counters" module:"openconfig-network-instance"`
	ΛCircuitCounters []ygot.Annotation                                                                              `path:"@circuit-counters" ygotAnnotation:"true"`
	CircuitType      E_OpenconfigIsisTypes_CircuitType                                                              `path:"state/circuit-type" shadow-path:"config/circuit-type" module:"openconfig-network-instance"`
	ΛCircuitType     []ygot.Annotation                                                                              `path:"state/@circuit-type" ygotAnnotation:"true"`
	Enabled          *bool                                                                                          `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled         []ygot.Annotation                                                                              `path:"state/@enabled" ygotAnnotation:"true"`
	HelloPadding     E_OpenconfigIsisTypes_HelloPaddingType                                                         `path:"state/hello-padding" shadow-path:"config/hello-padding" module:"openconfig-network-instance"`
	ΛHelloPadding    []ygot.Annotation                                                                              `path:"state/@hello-padding" ygotAnnotation:"true"`
	InterfaceId      *string                                                                                        `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId     []ygot.Annotation                                                                              `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef     *NetworkInstance_Protocol_Isis_Interface_InterfaceRef                                          `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef    []ygot.Annotation                                                                              `path:"@interface-ref" ygotAnnotation:"true"`
	Level            map[uint8]*NetworkInstance_Protocol_Isis_Interface_Level                                       `path:"levels/level" module:"openconfig-network-instance"`
	ΛLevel           []ygot.Annotation                                                                              `path:"levels/@level" ygotAnnotation:"true"`
	Mpls             *NetworkInstance_Protocol_Isis_Interface_Mpls                                                  `path:"mpls" module:"openconfig-network-instance"`
	ΛMpls            []ygot.Annotation                                                                              `path:"@mpls" ygotAnnotation:"true"`
	Passive          *bool                                                                                          `path:"state/passive" shadow-path:"config/passive" module:"openconfig-network-instance"`
	ΛPassive         []ygot.Annotation                                                                              `path:"state/@passive" ygotAnnotation:"true"`
	Timers           *NetworkInstance_Protocol_Isis_Interface_Timers                                                `path:"timers" module:"openconfig-network-instance"`
	ΛTimers          []ygot.Annotation                                                                              `path:"@timers" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Interface_Af_Key represents the key for list Af of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface.
type NetworkInstance_Protocol_Isis_Interface_Af_Key struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name"`
}

// NewAf creates a new entry in the Af list of the
// NetworkInstance_Protocol_Isis_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Interface) NewAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) (*NetworkInstance_Protocol_Isis_Interface_Af, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[NetworkInstance_Protocol_Isis_Interface_Af_Key]*NetworkInstance_Protocol_Isis_Interface_Af)
	}

	key := NetworkInstance_Protocol_Isis_Interface_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Af[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Af", key)
	}

	t.Af[key] = &NetworkInstance_Protocol_Isis_Interface_Af{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	return t.Af[key], nil
}

// RenameAf renames an entry in the list Af within
// the NetworkInstance_Protocol_Isis_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Interface) RenameAf(oldK, newK NetworkInstance_Protocol_Isis_Interface_Af_Key) error {
	if _, ok := t.Af[newK]; ok {
		return fmt.Errorf("key %v already exists in Af", newK)
	}

	e, ok := t.Af[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Af", oldK)
	}
	e.AfiName = newK.AfiName
	e.SafiName = newK.SafiName

	t.Af[newK] = e
	delete(t.Af, oldK)
	return nil
}

// GetOrCreateAf retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) *NetworkInstance_Protocol_Isis_Interface_Af {

	key := NetworkInstance_Protocol_Isis_Interface_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	if v, ok := t.Af[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAf(AfiName, SafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAf got unexpected error: %v", err))
	}
	return v
}

// GetAf retrieves the value with the specified key from
// the Af map field of NetworkInstance_Protocol_Isis_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) *NetworkInstance_Protocol_Isis_Interface_Af {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Interface_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	if lm, ok := t.Af[key]; ok {
		return lm
	}
	return nil
}

// AppendAf appends the supplied NetworkInstance_Protocol_Isis_Interface_Af struct to the
// list Af of NetworkInstance_Protocol_Isis_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface_Af already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Interface) AppendAf(v *NetworkInstance_Protocol_Isis_Interface_Af) error {
	key := NetworkInstance_Protocol_Isis_Interface_Af_Key{
		AfiName:  v.AfiName,
		SafiName: v.SafiName,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[NetworkInstance_Protocol_Isis_Interface_Af_Key]*NetworkInstance_Protocol_Isis_Interface_Af)
	}

	if _, ok := t.Af[key]; ok {
		return fmt.Errorf("duplicate key for list Af %v", key)
	}

	t.Af[key] = v
	return nil
}

// NewLevel creates a new entry in the Level list of the
// NetworkInstance_Protocol_Isis_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Interface) NewLevel(LevelNumber uint8) (*NetworkInstance_Protocol_Isis_Interface_Level, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Level == nil {
		t.Level = make(map[uint8]*NetworkInstance_Protocol_Isis_Interface_Level)
	}

	key := LevelNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Level[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Level", key)
	}

	t.Level[key] = &NetworkInstance_Protocol_Isis_Interface_Level{
		LevelNumber: &LevelNumber,
	}

	return t.Level[key], nil
}

// RenameLevel renames an entry in the list Level within
// the NetworkInstance_Protocol_Isis_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Interface) RenameLevel(oldK, newK uint8) error {
	if _, ok := t.Level[newK]; ok {
		return fmt.Errorf("key %v already exists in Level", newK)
	}

	e, ok := t.Level[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Level", oldK)
	}
	e.LevelNumber = &newK

	t.Level[newK] = e
	delete(t.Level, oldK)
	return nil
}

// GetOrCreateLevel retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateLevel(LevelNumber uint8) *NetworkInstance_Protocol_Isis_Interface_Level {

	key := LevelNumber

	if v, ok := t.Level[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLevel(LevelNumber)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLevel got unexpected error: %v", err))
	}
	return v
}

// GetLevel retrieves the value with the specified key from
// the Level map field of NetworkInstance_Protocol_Isis_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetLevel(LevelNumber uint8) *NetworkInstance_Protocol_Isis_Interface_Level {

	if t == nil {
		return nil
	}

	key := LevelNumber

	if lm, ok := t.Level[key]; ok {
		return lm
	}
	return nil
}

// AppendLevel appends the supplied NetworkInstance_Protocol_Isis_Interface_Level struct to the
// list Level of NetworkInstance_Protocol_Isis_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface_Level already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Interface) AppendLevel(v *NetworkInstance_Protocol_Isis_Interface_Level) error {
	if v.LevelNumber == nil {
		return fmt.Errorf("invalid nil key received for LevelNumber")
	}

	key := *v.LevelNumber

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Level == nil {
		t.Level = make(map[uint8]*NetworkInstance_Protocol_Isis_Interface_Level)
	}

	if _, ok := t.Level[key]; ok {
		return fmt.Errorf("duplicate key for list Level %v", key)
	}

	t.Level[key] = v
	return nil
}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateAuthentication() *NetworkInstance_Protocol_Isis_Interface_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &NetworkInstance_Protocol_Isis_Interface_Authentication{}
	return t.Authentication
}

// GetOrCreateBfd retrieves the value of the Bfd field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateBfd() *NetworkInstance_Protocol_Isis_Interface_Bfd {
	if t.Bfd != nil {
		return t.Bfd
	}
	t.Bfd = &NetworkInstance_Protocol_Isis_Interface_Bfd{}
	return t.Bfd
}

// GetOrCreateCircuitCounters retrieves the value of the CircuitCounters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateCircuitCounters() *NetworkInstance_Protocol_Isis_Interface_CircuitCounters {
	if t.CircuitCounters != nil {
		return t.CircuitCounters
	}
	t.CircuitCounters = &NetworkInstance_Protocol_Isis_Interface_CircuitCounters{}
	return t.CircuitCounters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Protocol_Isis_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Protocol_Isis_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetOrCreateMpls retrieves the value of the Mpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateMpls() *NetworkInstance_Protocol_Isis_Interface_Mpls {
	if t.Mpls != nil {
		return t.Mpls
	}
	t.Mpls = &NetworkInstance_Protocol_Isis_Interface_Mpls{}
	return t.Mpls
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface) GetOrCreateTimers() *NetworkInstance_Protocol_Isis_Interface_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Isis_Interface_Timers{}
	return t.Timers
}

// GetAuthentication returns the value of the Authentication struct pointer
// from NetworkInstance_Protocol_Isis_Interface. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetAuthentication() *NetworkInstance_Protocol_Isis_Interface_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetBfd returns the value of the Bfd struct pointer
// from NetworkInstance_Protocol_Isis_Interface. If the receiver or the field Bfd is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetBfd() *NetworkInstance_Protocol_Isis_Interface_Bfd {
	if t != nil && t.Bfd != nil {
		return t.Bfd
	}
	return nil
}

// GetCircuitCounters returns the value of the CircuitCounters struct pointer
// from NetworkInstance_Protocol_Isis_Interface. If the receiver or the field CircuitCounters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetCircuitCounters() *NetworkInstance_Protocol_Isis_Interface_CircuitCounters {
	if t != nil && t.CircuitCounters != nil {
		return t.CircuitCounters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Protocol_Isis_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetInterfaceRef() *NetworkInstance_Protocol_Isis_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetMpls returns the value of the Mpls struct pointer
// from NetworkInstance_Protocol_Isis_Interface. If the receiver or the field Mpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetMpls() *NetworkInstance_Protocol_Isis_Interface_Mpls {
	if t != nil && t.Mpls != nil {
		return t.Mpls
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Isis_Interface. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface) GetTimers() *NetworkInstance_Protocol_Isis_Interface_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetCircuitType retrieves the value of the leaf CircuitType from the NetworkInstance_Protocol_Isis_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CircuitType is set, it can safely use t.GetCircuitType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CircuitType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface) GetCircuitType() E_OpenconfigIsisTypes_CircuitType {
	if t == nil || t.CircuitType == 0 {
		return 0
	}
	return t.CircuitType
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelloPadding retrieves the value of the leaf HelloPadding from the NetworkInstance_Protocol_Isis_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloPadding is set, it can safely use t.GetHelloPadding()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloPadding == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface) GetHelloPadding() E_OpenconfigIsisTypes_HelloPaddingType {
	if t == nil || t.HelloPadding == 0 {
		return 0
	}
	return t.HelloPadding
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Protocol_Isis_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetPassive retrieves the value of the leaf Passive from the NetworkInstance_Protocol_Isis_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Passive is set, it can safely use t.GetPassive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Passive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface) GetPassive() bool {
	if t == nil || t.Passive == nil {
		return false
	}
	return *t.Passive
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Af represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Af struct {
	ΛMetadata []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	AfiName   E_OpenconfigIsisTypes_AFI_TYPE  `path:"state/afi-name|afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName  []ygot.Annotation               `path:"state/@afi-name|@afi-name" ygotAnnotation:"true"`
	Enabled   *bool                           `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled  []ygot.Annotation               `path:"state/@enabled" ygotAnnotation:"true"`
	SafiName  E_OpenconfigIsisTypes_SAFI_TYPE `path:"state/safi-name|safi-name" shadow-path:"config/safi-name" module:"openconfig-network-instance"`
	ΛSafiName []ygot.Annotation               `path:"state/@safi-name|@safi-name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Af implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Af) IsYANGGoStruct() {}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Protocol_Isis_Interface_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Af) GetAfiName() E_OpenconfigIsisTypes_AFI_TYPE {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Interface_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Af) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetSafiName retrieves the value of the leaf SafiName from the NetworkInstance_Protocol_Isis_Interface_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SafiName is set, it can safely use t.GetSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Af) GetSafiName() E_OpenconfigIsisTypes_SAFI_TYPE {
	if t == nil || t.SafiName == 0 {
		return 0
	}
	return t.SafiName
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface_Af struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface_Af) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name":  t.AfiName,
		"safi-name": t.SafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Af) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Af"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Af) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Authentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Authentication struct {
	ΛMetadata            []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	HelloAuthentication  *bool                                                            `path:"state/hello-authentication" shadow-path:"config/hello-authentication" module:"openconfig-network-instance"`
	ΛHelloAuthentication []ygot.Annotation                                                `path:"state/@hello-authentication" ygotAnnotation:"true"`
	Key                  *NetworkInstance_Protocol_Isis_Interface_Authentication_Key      `path:"key" module:"openconfig-network-instance"`
	ΛKey                 []ygot.Annotation                                                `path:"@key" ygotAnnotation:"true"`
	Keychain             *NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain `path:"keychain" module:"openconfig-network-instance"`
	ΛKeychain            []ygot.Annotation                                                `path:"@keychain" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Authentication) IsYANGGoStruct() {}

// GetOrCreateKey retrieves the value of the Key field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) GetOrCreateKey() *NetworkInstance_Protocol_Isis_Interface_Authentication_Key {
	if t.Key != nil {
		return t.Key
	}
	t.Key = &NetworkInstance_Protocol_Isis_Interface_Authentication_Key{}
	return t.Key
}

// GetOrCreateKeychain retrieves the value of the Keychain field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) GetOrCreateKeychain() *NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain {
	if t.Keychain != nil {
		return t.Keychain
	}
	t.Keychain = &NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain{}
	return t.Keychain
}

// GetKey returns the value of the Key struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Authentication. If the receiver or the field Key is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) GetKey() *NetworkInstance_Protocol_Isis_Interface_Authentication_Key {
	if t != nil && t.Key != nil {
		return t.Key
	}
	return nil
}

// GetKeychain returns the value of the Keychain struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Authentication. If the receiver or the field Keychain is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) GetKeychain() *NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain {
	if t != nil && t.Keychain != nil {
		return t.Keychain
	}
	return nil
}

// GetHelloAuthentication retrieves the value of the leaf HelloAuthentication from the NetworkInstance_Protocol_Isis_Interface_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloAuthentication is set, it can safely use t.GetHelloAuthentication()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloAuthentication == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) GetHelloAuthentication() bool {
	if t == nil || t.HelloAuthentication == nil {
		return false
	}
	return *t.HelloAuthentication
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Authentication_Key represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/key YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Authentication_Key struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthPassword  *string           `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-network-instance"`
	ΛAuthPassword []ygot.Annotation `path:"state/@auth-password" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Authentication_Key implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Authentication_Key) IsYANGGoStruct() {}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the NetworkInstance_Protocol_Isis_Interface_Authentication_Key
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication_Key) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication_Key) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Authentication_Key"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication_Key) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/keychain YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Authentication_Keychain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Bfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/bfd YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Bfd struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BfdTlv    *bool             `path:"state/bfd-tlv" shadow-path:"config/bfd-tlv" module:"openconfig-network-instance"`
	ΛBfdTlv   []ygot.Annotation `path:"state/@bfd-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Bfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Bfd) IsYANGGoStruct() {}

// GetBfdTlv retrieves the value of the leaf BfdTlv from the NetworkInstance_Protocol_Isis_Interface_Bfd
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BfdTlv is set, it can safely use t.GetBfdTlv()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BfdTlv == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Bfd) GetBfdTlv() bool {
	if t == nil || t.BfdTlv == nil {
		return false
	}
	return *t.BfdTlv
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Bfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Bfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Bfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_CircuitCounters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/circuit-counters YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_CircuitCounters struct {
	ΛMetadata                 []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdjChanges                *uint32           `path:"state/adj-changes" module:"openconfig-network-instance"`
	ΛAdjChanges               []ygot.Annotation `path:"state/@adj-changes" ygotAnnotation:"true"`
	AdjNumber                 *uint32           `path:"state/adj-number" module:"openconfig-network-instance"`
	ΛAdjNumber                []ygot.Annotation `path:"state/@adj-number" ygotAnnotation:"true"`
	AuthFails                 *uint32           `path:"state/auth-fails" module:"openconfig-network-instance"`
	ΛAuthFails                []ygot.Annotation `path:"state/@auth-fails" ygotAnnotation:"true"`
	AuthTypeFails             *uint32           `path:"state/auth-type-fails" module:"openconfig-network-instance"`
	ΛAuthTypeFails            []ygot.Annotation `path:"state/@auth-type-fails" ygotAnnotation:"true"`
	IdFieldLenMismatches      *uint32           `path:"state/id-field-len-mismatches" module:"openconfig-network-instance"`
	ΛIdFieldLenMismatches     []ygot.Annotation `path:"state/@id-field-len-mismatches" ygotAnnotation:"true"`
	InitFails                 *uint32           `path:"state/init-fails" module:"openconfig-network-instance"`
	ΛInitFails                []ygot.Annotation `path:"state/@init-fails" ygotAnnotation:"true"`
	LanDisChanges             *uint32           `path:"state/lan-dis-changes" module:"openconfig-network-instance"`
	ΛLanDisChanges            []ygot.Annotation `path:"state/@lan-dis-changes" ygotAnnotation:"true"`
	MaxAreaAddressMismatches  *uint32           `path:"state/max-area-address-mismatches" module:"openconfig-network-instance"`
	ΛMaxAreaAddressMismatches []ygot.Annotation `path:"state/@max-area-address-mismatches" ygotAnnotation:"true"`
	RejectedAdj               *uint32           `path:"state/rejected-adj" module:"openconfig-network-instance"`
	ΛRejectedAdj              []ygot.Annotation `path:"state/@rejected-adj" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_CircuitCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_CircuitCounters) IsYANGGoStruct() {}

// GetAdjChanges retrieves the value of the leaf AdjChanges from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjChanges is set, it can safely use t.GetAdjChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetAdjChanges() uint32 {
	if t == nil || t.AdjChanges == nil {
		return 0
	}
	return *t.AdjChanges
}

// GetAdjNumber retrieves the value of the leaf AdjNumber from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjNumber is set, it can safely use t.GetAdjNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetAdjNumber() uint32 {
	if t == nil || t.AdjNumber == nil {
		return 0
	}
	return *t.AdjNumber
}

// GetAuthFails retrieves the value of the leaf AuthFails from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthFails is set, it can safely use t.GetAuthFails()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthFails == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetAuthFails() uint32 {
	if t == nil || t.AuthFails == nil {
		return 0
	}
	return *t.AuthFails
}

// GetAuthTypeFails retrieves the value of the leaf AuthTypeFails from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthTypeFails is set, it can safely use t.GetAuthTypeFails()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthTypeFails == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetAuthTypeFails() uint32 {
	if t == nil || t.AuthTypeFails == nil {
		return 0
	}
	return *t.AuthTypeFails
}

// GetIdFieldLenMismatches retrieves the value of the leaf IdFieldLenMismatches from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IdFieldLenMismatches is set, it can safely use t.GetIdFieldLenMismatches()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IdFieldLenMismatches == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetIdFieldLenMismatches() uint32 {
	if t == nil || t.IdFieldLenMismatches == nil {
		return 0
	}
	return *t.IdFieldLenMismatches
}

// GetInitFails retrieves the value of the leaf InitFails from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InitFails is set, it can safely use t.GetInitFails()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InitFails == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetInitFails() uint32 {
	if t == nil || t.InitFails == nil {
		return 0
	}
	return *t.InitFails
}

// GetLanDisChanges retrieves the value of the leaf LanDisChanges from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LanDisChanges is set, it can safely use t.GetLanDisChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LanDisChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetLanDisChanges() uint32 {
	if t == nil || t.LanDisChanges == nil {
		return 0
	}
	return *t.LanDisChanges
}

// GetMaxAreaAddressMismatches retrieves the value of the leaf MaxAreaAddressMismatches from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxAreaAddressMismatches is set, it can safely use t.GetMaxAreaAddressMismatches()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxAreaAddressMismatches == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetMaxAreaAddressMismatches() uint32 {
	if t == nil || t.MaxAreaAddressMismatches == nil {
		return 0
	}
	return *t.MaxAreaAddressMismatches
}

// GetRejectedAdj retrieves the value of the leaf RejectedAdj from the NetworkInstance_Protocol_Isis_Interface_CircuitCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RejectedAdj is set, it can safely use t.GetRejectedAdj()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RejectedAdj == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) GetRejectedAdj() uint32 {
	if t == nil || t.RejectedAdj == nil {
		return 0
	}
	return *t.RejectedAdj
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_CircuitCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_CircuitCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Protocol_Isis_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Protocol_Isis_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level struct {
	ΛMetadata            []ygot.Annotation                                                                                          `path:"@" ygotAnnotation:"true"`
	Adjacency            map[string]*NetworkInstance_Protocol_Isis_Interface_Level_Adjacency                                        `path:"adjacencies/adjacency" module:"openconfig-network-instance"`
	ΛAdjacency           []ygot.Annotation                                                                                          `path:"adjacencies/@adjacency" ygotAnnotation:"true"`
	Af                   map[NetworkInstance_Protocol_Isis_Interface_Level_Af_Key]*NetworkInstance_Protocol_Isis_Interface_Level_Af `path:"afi-safi/af" module:"openconfig-network-instance"`
	ΛAf                  []ygot.Annotation                                                                                          `path:"afi-safi/@af" ygotAnnotation:"true"`
	Enabled              *bool                                                                                                      `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled             []ygot.Annotation                                                                                          `path:"state/@enabled" ygotAnnotation:"true"`
	HelloAuthentication  *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication                                         `path:"hello-authentication" module:"openconfig-network-instance"`
	ΛHelloAuthentication []ygot.Annotation                                                                                          `path:"@hello-authentication" ygotAnnotation:"true"`
	LevelNumber          *uint8                                                                                                     `path:"state/level-number|level-number" shadow-path:"config/level-number" module:"openconfig-network-instance"`
	ΛLevelNumber         []ygot.Annotation                                                                                          `path:"state/@level-number|@level-number" ygotAnnotation:"true"`
	PacketCounters       *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters                                              `path:"packet-counters" module:"openconfig-network-instance"`
	ΛPacketCounters      []ygot.Annotation                                                                                          `path:"@packet-counters" ygotAnnotation:"true"`
	Passive              *bool                                                                                                      `path:"state/passive" shadow-path:"config/passive" module:"openconfig-network-instance"`
	ΛPassive             []ygot.Annotation                                                                                          `path:"state/@passive" ygotAnnotation:"true"`
	Priority             *uint8                                                                                                     `path:"state/priority" shadow-path:"config/priority" module:"openconfig-network-instance"`
	ΛPriority            []ygot.Annotation                                                                                          `path:"state/@priority" ygotAnnotation:"true"`
	Timers               *NetworkInstance_Protocol_Isis_Interface_Level_Timers                                                      `path:"timers" module:"openconfig-network-instance"`
	ΛTimers              []ygot.Annotation                                                                                          `path:"@timers" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_Key represents the key for list Af of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level.
type NetworkInstance_Protocol_Isis_Interface_Level_Af_Key struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name"`
}

// NewAdjacency creates a new entry in the Adjacency list of the
// NetworkInstance_Protocol_Isis_Interface_Level struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) NewAdjacency(SystemId string) (*NetworkInstance_Protocol_Isis_Interface_Level_Adjacency, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Adjacency == nil {
		t.Adjacency = make(map[string]*NetworkInstance_Protocol_Isis_Interface_Level_Adjacency)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Adjacency[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Adjacency", key)
	}

	t.Adjacency[key] = &NetworkInstance_Protocol_Isis_Interface_Level_Adjacency{
		SystemId: &SystemId,
	}

	return t.Adjacency[key], nil
}

// RenameAdjacency renames an entry in the list Adjacency within
// the NetworkInstance_Protocol_Isis_Interface_Level struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) RenameAdjacency(oldK, newK string) error {
	if _, ok := t.Adjacency[newK]; ok {
		return fmt.Errorf("key %v already exists in Adjacency", newK)
	}

	e, ok := t.Adjacency[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Adjacency", oldK)
	}
	e.SystemId = &newK

	t.Adjacency[newK] = e
	delete(t.Adjacency, oldK)
	return nil
}

// GetOrCreateAdjacency retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Interface_Level. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetOrCreateAdjacency(SystemId string) *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency {

	key := SystemId

	if v, ok := t.Adjacency[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdjacency(SystemId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdjacency got unexpected error: %v", err))
	}
	return v
}

// GetAdjacency retrieves the value with the specified key from
// the Adjacency map field of NetworkInstance_Protocol_Isis_Interface_Level. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetAdjacency(SystemId string) *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency {

	if t == nil {
		return nil
	}

	key := SystemId

	if lm, ok := t.Adjacency[key]; ok {
		return lm
	}
	return nil
}

// AppendAdjacency appends the supplied NetworkInstance_Protocol_Isis_Interface_Level_Adjacency struct to the
// list Adjacency of NetworkInstance_Protocol_Isis_Interface_Level. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface_Level_Adjacency already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) AppendAdjacency(v *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) error {
	if v.SystemId == nil {
		return fmt.Errorf("invalid nil key received for SystemId")
	}

	key := *v.SystemId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Adjacency == nil {
		t.Adjacency = make(map[string]*NetworkInstance_Protocol_Isis_Interface_Level_Adjacency)
	}

	if _, ok := t.Adjacency[key]; ok {
		return fmt.Errorf("duplicate key for list Adjacency %v", key)
	}

	t.Adjacency[key] = v
	return nil
}

// NewAf creates a new entry in the Af list of the
// NetworkInstance_Protocol_Isis_Interface_Level struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) NewAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) (*NetworkInstance_Protocol_Isis_Interface_Level_Af, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[NetworkInstance_Protocol_Isis_Interface_Level_Af_Key]*NetworkInstance_Protocol_Isis_Interface_Level_Af)
	}

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Af[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Af", key)
	}

	t.Af[key] = &NetworkInstance_Protocol_Isis_Interface_Level_Af{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	return t.Af[key], nil
}

// RenameAf renames an entry in the list Af within
// the NetworkInstance_Protocol_Isis_Interface_Level struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) RenameAf(oldK, newK NetworkInstance_Protocol_Isis_Interface_Level_Af_Key) error {
	if _, ok := t.Af[newK]; ok {
		return fmt.Errorf("key %v already exists in Af", newK)
	}

	e, ok := t.Af[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Af", oldK)
	}
	e.AfiName = newK.AfiName
	e.SafiName = newK.SafiName

	t.Af[newK] = e
	delete(t.Af, oldK)
	return nil
}

// GetOrCreateAf retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Interface_Level. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetOrCreateAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) *NetworkInstance_Protocol_Isis_Interface_Level_Af {

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	if v, ok := t.Af[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAf(AfiName, SafiName)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAf got unexpected error: %v", err))
	}
	return v
}

// GetAf retrieves the value with the specified key from
// the Af map field of NetworkInstance_Protocol_Isis_Interface_Level. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) *NetworkInstance_Protocol_Isis_Interface_Level_Af {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	if lm, ok := t.Af[key]; ok {
		return lm
	}
	return nil
}

// AppendAf appends the supplied NetworkInstance_Protocol_Isis_Interface_Level_Af struct to the
// list Af of NetworkInstance_Protocol_Isis_Interface_Level. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface_Level_Af already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) AppendAf(v *NetworkInstance_Protocol_Isis_Interface_Level_Af) error {
	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_Key{
		AfiName:  v.AfiName,
		SafiName: v.SafiName,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[NetworkInstance_Protocol_Isis_Interface_Level_Af_Key]*NetworkInstance_Protocol_Isis_Interface_Level_Af)
	}

	if _, ok := t.Af[key]; ok {
		return fmt.Errorf("duplicate key for list Af %v", key)
	}

	t.Af[key] = v
	return nil
}

// GetOrCreateHelloAuthentication retrieves the value of the HelloAuthentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetOrCreateHelloAuthentication() *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication {
	if t.HelloAuthentication != nil {
		return t.HelloAuthentication
	}
	t.HelloAuthentication = &NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication{}
	return t.HelloAuthentication
}

// GetOrCreatePacketCounters retrieves the value of the PacketCounters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetOrCreatePacketCounters() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters {
	if t.PacketCounters != nil {
		return t.PacketCounters
	}
	t.PacketCounters = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters{}
	return t.PacketCounters
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetOrCreateTimers() *NetworkInstance_Protocol_Isis_Interface_Level_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Isis_Interface_Level_Timers{}
	return t.Timers
}

// GetHelloAuthentication returns the value of the HelloAuthentication struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level. If the receiver or the field HelloAuthentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetHelloAuthentication() *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication {
	if t != nil && t.HelloAuthentication != nil {
		return t.HelloAuthentication
	}
	return nil
}

// GetPacketCounters returns the value of the PacketCounters struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level. If the receiver or the field PacketCounters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetPacketCounters() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters {
	if t != nil && t.PacketCounters != nil {
		return t.PacketCounters
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetTimers() *NetworkInstance_Protocol_Isis_Interface_Level_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Interface_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetLevelNumber retrieves the value of the leaf LevelNumber from the NetworkInstance_Protocol_Isis_Interface_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LevelNumber is set, it can safely use t.GetLevelNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LevelNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetLevelNumber() uint8 {
	if t == nil || t.LevelNumber == nil {
		return 0
	}
	return *t.LevelNumber
}

// GetPassive retrieves the value of the leaf Passive from the NetworkInstance_Protocol_Isis_Interface_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Passive is set, it can safely use t.GetPassive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Passive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetPassive() bool {
	if t == nil || t.Passive == nil {
		return false
	}
	return *t.Passive
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Isis_Interface_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface_Level struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LevelNumber == nil {
		return nil, fmt.Errorf("nil value for key LevelNumber")
	}

	return map[string]interface{}{
		"level-number": *t.LevelNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Adjacency represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_Adjacency struct {
	ΛMetadata                  []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	AdjacencyState             E_OpenconfigIsisTypes_IsisInterfaceAdjState `path:"state/adjacency-state" module:"openconfig-network-instance"`
	ΛAdjacencyState            []ygot.Annotation                           `path:"state/@adjacency-state" ygotAnnotation:"true"`
	AdjacencyType              E_OpenconfigIsisTypes_LevelType             `path:"state/adjacency-type" module:"openconfig-network-instance"`
	ΛAdjacencyType             []ygot.Annotation                           `path:"state/@adjacency-type" ygotAnnotation:"true"`
	AreaAddress                []string                                    `path:"state/area-address" module:"openconfig-network-instance"`
	ΛAreaAddress               []ygot.Annotation                           `path:"state/@area-address" ygotAnnotation:"true"`
	DisSystemId                *string                                     `path:"state/dis-system-id" module:"openconfig-network-instance"`
	ΛDisSystemId               []ygot.Annotation                           `path:"state/@dis-system-id" ygotAnnotation:"true"`
	LocalExtendedCircuitId     *uint32                                     `path:"state/local-extended-circuit-id" module:"openconfig-network-instance"`
	ΛLocalExtendedCircuitId    []ygot.Annotation                           `path:"state/@local-extended-circuit-id" ygotAnnotation:"true"`
	MultiTopology              *bool                                       `path:"state/multi-topology" module:"openconfig-network-instance"`
	ΛMultiTopology             []ygot.Annotation                           `path:"state/@multi-topology" ygotAnnotation:"true"`
	NeighborCircuitType        E_OpenconfigIsisTypes_LevelType             `path:"state/neighbor-circuit-type" module:"openconfig-network-instance"`
	ΛNeighborCircuitType       []ygot.Annotation                           `path:"state/@neighbor-circuit-type" ygotAnnotation:"true"`
	NeighborExtendedCircuitId  *uint32                                     `path:"state/neighbor-extended-circuit-id" module:"openconfig-network-instance"`
	ΛNeighborExtendedCircuitId []ygot.Annotation                           `path:"state/@neighbor-extended-circuit-id" ygotAnnotation:"true"`
	NeighborIpv4Address        *string                                     `path:"state/neighbor-ipv4-address" module:"openconfig-network-instance"`
	ΛNeighborIpv4Address       []ygot.Annotation                           `path:"state/@neighbor-ipv4-address" ygotAnnotation:"true"`
	NeighborIpv6Address        *string                                     `path:"state/neighbor-ipv6-address" module:"openconfig-network-instance"`
	ΛNeighborIpv6Address       []ygot.Annotation                           `path:"state/@neighbor-ipv6-address" ygotAnnotation:"true"`
	NeighborSnpa               *string                                     `path:"state/neighbor-snpa" module:"openconfig-network-instance"`
	ΛNeighborSnpa              []ygot.Annotation                           `path:"state/@neighbor-snpa" ygotAnnotation:"true"`
	Nlpid                      []E_Adjacency_Nlpid                         `path:"state/nlpid" module:"openconfig-network-instance"`
	ΛNlpid                     []ygot.Annotation                           `path:"state/@nlpid" ygotAnnotation:"true"`
	Priority                   *uint8                                      `path:"state/priority" module:"openconfig-network-instance"`
	ΛPriority                  []ygot.Annotation                           `path:"state/@priority" ygotAnnotation:"true"`
	RemainingHoldTime          *uint16                                     `path:"state/remaining-hold-time" module:"openconfig-network-instance"`
	ΛRemainingHoldTime         []ygot.Annotation                           `path:"state/@remaining-hold-time" ygotAnnotation:"true"`
	RestartStatus              *bool                                       `path:"state/restart-status" module:"openconfig-network-instance"`
	ΛRestartStatus             []ygot.Annotation                           `path:"state/@restart-status" ygotAnnotation:"true"`
	RestartSupport             *bool                                       `path:"state/restart-support" module:"openconfig-network-instance"`
	ΛRestartSupport            []ygot.Annotation                           `path:"state/@restart-support" ygotAnnotation:"true"`
	RestartSuppress            *bool                                       `path:"state/restart-suppress" module:"openconfig-network-instance"`
	ΛRestartSuppress           []ygot.Annotation                           `path:"state/@restart-suppress" ygotAnnotation:"true"`
	SystemId                   *string                                     `path:"state/system-id|system-id" module:"openconfig-network-instance"`
	ΛSystemId                  []ygot.Annotation                           `path:"state/@system-id|@system-id" ygotAnnotation:"true"`
	Topology                   []E_OpenconfigIsisTypes_AFI_SAFI_TYPE       `path:"state/topology" module:"openconfig-network-instance"`
	ΛTopology                  []ygot.Annotation                           `path:"state/@topology" ygotAnnotation:"true"`
	UpTime                     *uint32                                     `path:"state/up-time" module:"openconfig-network-instance"`
	ΛUpTime                    []ygot.Annotation                           `path:"state/@up-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_Adjacency implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) IsYANGGoStruct() {}

// GetAdjacencyState retrieves the value of the leaf AdjacencyState from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjacencyState is set, it can safely use t.GetAdjacencyState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjacencyState == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetAdjacencyState() E_OpenconfigIsisTypes_IsisInterfaceAdjState {
	if t == nil || t.AdjacencyState == 0 {
		return 0
	}
	return t.AdjacencyState
}

// GetAdjacencyType retrieves the value of the leaf AdjacencyType from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjacencyType is set, it can safely use t.GetAdjacencyType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjacencyType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetAdjacencyType() E_OpenconfigIsisTypes_LevelType {
	if t == nil || t.AdjacencyType == 0 {
		return 0
	}
	return t.AdjacencyType
}

// GetAreaAddress retrieves the value of the leaf AreaAddress from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AreaAddress is set, it can safely use t.GetAreaAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AreaAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetAreaAddress() []string {
	if t == nil || t.AreaAddress == nil {
		return nil
	}
	return t.AreaAddress
}

// GetDisSystemId retrieves the value of the leaf DisSystemId from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DisSystemId is set, it can safely use t.GetDisSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DisSystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetDisSystemId() string {
	if t == nil || t.DisSystemId == nil {
		return ""
	}
	return *t.DisSystemId
}

// GetLocalExtendedCircuitId retrieves the value of the leaf LocalExtendedCircuitId from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalExtendedCircuitId is set, it can safely use t.GetLocalExtendedCircuitId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalExtendedCircuitId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetLocalExtendedCircuitId() uint32 {
	if t == nil || t.LocalExtendedCircuitId == nil {
		return 0
	}
	return *t.LocalExtendedCircuitId
}

// GetMultiTopology retrieves the value of the leaf MultiTopology from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultiTopology is set, it can safely use t.GetMultiTopology()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultiTopology == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetMultiTopology() bool {
	if t == nil || t.MultiTopology == nil {
		return false
	}
	return *t.MultiTopology
}

// GetNeighborCircuitType retrieves the value of the leaf NeighborCircuitType from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborCircuitType is set, it can safely use t.GetNeighborCircuitType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborCircuitType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetNeighborCircuitType() E_OpenconfigIsisTypes_LevelType {
	if t == nil || t.NeighborCircuitType == 0 {
		return 0
	}
	return t.NeighborCircuitType
}

// GetNeighborExtendedCircuitId retrieves the value of the leaf NeighborExtendedCircuitId from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborExtendedCircuitId is set, it can safely use t.GetNeighborExtendedCircuitId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborExtendedCircuitId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetNeighborExtendedCircuitId() uint32 {
	if t == nil || t.NeighborExtendedCircuitId == nil {
		return 0
	}
	return *t.NeighborExtendedCircuitId
}

// GetNeighborIpv4Address retrieves the value of the leaf NeighborIpv4Address from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborIpv4Address is set, it can safely use t.GetNeighborIpv4Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborIpv4Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetNeighborIpv4Address() string {
	if t == nil || t.NeighborIpv4Address == nil {
		return ""
	}
	return *t.NeighborIpv4Address
}

// GetNeighborIpv6Address retrieves the value of the leaf NeighborIpv6Address from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborIpv6Address is set, it can safely use t.GetNeighborIpv6Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborIpv6Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetNeighborIpv6Address() string {
	if t == nil || t.NeighborIpv6Address == nil {
		return ""
	}
	return *t.NeighborIpv6Address
}

// GetNeighborSnpa retrieves the value of the leaf NeighborSnpa from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborSnpa is set, it can safely use t.GetNeighborSnpa()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborSnpa == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetNeighborSnpa() string {
	if t == nil || t.NeighborSnpa == nil {
		return ""
	}
	return *t.NeighborSnpa
}

// GetNlpid retrieves the value of the leaf Nlpid from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Nlpid is set, it can safely use t.GetNlpid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Nlpid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetNlpid() []E_Adjacency_Nlpid {
	if t == nil || t.Nlpid == nil {
		return nil
	}
	return t.Nlpid
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetRemainingHoldTime retrieves the value of the leaf RemainingHoldTime from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemainingHoldTime is set, it can safely use t.GetRemainingHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemainingHoldTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetRemainingHoldTime() uint16 {
	if t == nil || t.RemainingHoldTime == nil {
		return 0
	}
	return *t.RemainingHoldTime
}

// GetRestartStatus retrieves the value of the leaf RestartStatus from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartStatus is set, it can safely use t.GetRestartStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartStatus == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetRestartStatus() bool {
	if t == nil || t.RestartStatus == nil {
		return false
	}
	return *t.RestartStatus
}

// GetRestartSupport retrieves the value of the leaf RestartSupport from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartSupport is set, it can safely use t.GetRestartSupport()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartSupport == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetRestartSupport() bool {
	if t == nil || t.RestartSupport == nil {
		return false
	}
	return *t.RestartSupport
}

// GetRestartSuppress retrieves the value of the leaf RestartSuppress from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RestartSuppress is set, it can safely use t.GetRestartSuppress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RestartSuppress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetRestartSuppress() bool {
	if t == nil || t.RestartSuppress == nil {
		return false
	}
	return *t.RestartSuppress
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// GetTopology retrieves the value of the leaf Topology from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Topology is set, it can safely use t.GetTopology()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Topology == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetTopology() []E_OpenconfigIsisTypes_AFI_SAFI_TYPE {
	if t == nil || t.Topology == nil {
		return nil
	}
	return t.Topology
}

// GetUpTime retrieves the value of the leaf UpTime from the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpTime is set, it can safely use t.GetUpTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) GetUpTime() uint32 {
	if t == nil || t.UpTime == nil {
		return 0
	}
	return *t.UpTime
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface_Level_Adjacency struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_Adjacency"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Adjacency) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_Af struct {
	ΛMetadata       []ygot.Annotation                                                `path:"@" ygotAnnotation:"true"`
	AfiName         E_OpenconfigIsisTypes_AFI_TYPE                                   `path:"state/afi-name|afi-name" shadow-path:"config/afi-name" module:"openconfig-network-instance"`
	ΛAfiName        []ygot.Annotation                                                `path:"state/@afi-name|@afi-name" ygotAnnotation:"true"`
	Enabled         *bool                                                            `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled        []ygot.Annotation                                                `path:"state/@enabled" ygotAnnotation:"true"`
	Metric          *uint32                                                          `path:"state/metric" shadow-path:"config/metric" module:"openconfig-network-instance"`
	ΛMetric         []ygot.Annotation                                                `path:"state/@metric" ygotAnnotation:"true"`
	SafiName        E_OpenconfigIsisTypes_SAFI_TYPE                                  `path:"state/safi-name|safi-name" shadow-path:"config/safi-name" module:"openconfig-network-instance"`
	ΛSafiName       []ygot.Annotation                                                `path:"state/@safi-name|@safi-name" ygotAnnotation:"true"`
	SegmentRouting  *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting `path:"segment-routing" module:"openconfig-network-instance"`
	ΛSegmentRouting []ygot.Annotation                                                `path:"@segment-routing" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_Af implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_Af) IsYANGGoStruct() {}

// GetOrCreateSegmentRouting retrieves the value of the SegmentRouting field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) GetOrCreateSegmentRouting() *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting {
	if t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	t.SegmentRouting = &NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting{}
	return t.SegmentRouting
}

// GetSegmentRouting returns the value of the SegmentRouting struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_Af. If the receiver or the field SegmentRouting is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) GetSegmentRouting() *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting {
	if t != nil && t.SegmentRouting != nil {
		return t.SegmentRouting
	}
	return nil
}

// GetAfiName retrieves the value of the leaf AfiName from the NetworkInstance_Protocol_Isis_Interface_Level_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AfiName is set, it can safely use t.GetAfiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AfiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) GetAfiName() E_OpenconfigIsisTypes_AFI_TYPE {
	if t == nil || t.AfiName == 0 {
		return 0
	}
	return t.AfiName
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Interface_Level_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Interface_Level_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 10
	}
	return *t.Metric
}

// GetSafiName retrieves the value of the leaf SafiName from the NetworkInstance_Protocol_Isis_Interface_Level_Af
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SafiName is set, it can safely use t.GetSafiName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SafiName == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) GetSafiName() E_OpenconfigIsisTypes_SAFI_TYPE {
	if t == nil || t.SafiName == 0 {
		return 0
	}
	return t.SafiName
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface_Level_Af struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name":  t.AfiName,
		"safi-name": t.SafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_Af"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting struct {
	ΛMetadata     []ygot.Annotation                                                                                                                                                  `path:"@" ygotAnnotation:"true"`
	AdjacencySid  map[NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key]*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid `path:"adjacency-sids/adjacency-sid" module:"openconfig-network-instance"`
	ΛAdjacencySid []ygot.Annotation                                                                                                                                                  `path:"adjacency-sids/@adjacency-sid" ygotAnnotation:"true"`
	PrefixSid     map[string]*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid                                                                              `path:"prefix-sids/prefix-sid" module:"openconfig-network-instance"`
	ΛPrefixSid    []ygot.Annotation                                                                                                                                                  `path:"prefix-sids/@prefix-sid" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key represents the key for list AdjacencySid of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing.
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key struct {
	Neighbor string                                                                                   `path:"neighbor"`
	SidId    NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union `path:"sid-id"`
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) NewAdjacencySid(Neighbor string, SidId NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union) (*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key]*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid)
	}

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key{
		Neighbor: Neighbor,
		SidId:    SidId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid{
		Neighbor: &Neighbor,
		SidId:    SidId,
	}

	return t.AdjacencySid[key], nil
}

// RenameAdjacencySid renames an entry in the list AdjacencySid within
// the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) RenameAdjacencySid(oldK, newK NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key) error {
	if _, ok := t.AdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in AdjacencySid", newK)
	}

	e, ok := t.AdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdjacencySid", oldK)
	}
	e.Neighbor = &newK.Neighbor
	e.SidId = newK.SidId

	t.AdjacencySid[newK] = e
	delete(t.AdjacencySid, oldK)
	return nil
}

// GetOrCreateAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) GetOrCreateAdjacencySid(Neighbor string, SidId NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union) *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid {

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key{
		Neighbor: Neighbor,
		SidId:    SidId,
	}

	if v, ok := t.AdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdjacencySid(Neighbor, SidId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetAdjacencySid retrieves the value with the specified key from
// the AdjacencySid map field of NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) GetAdjacencySid(Neighbor string, SidId NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union) *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key{
		Neighbor: Neighbor,
		SidId:    SidId,
	}

	if lm, ok := t.AdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid struct to the
// list AdjacencySid of NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) AppendAdjacencySid(v *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) error {
	if v.Neighbor == nil {
		return fmt.Errorf("invalid nil key for Neighbor")
	}

	key := NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key{
		Neighbor: *v.Neighbor,
		SidId:    v.SidId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_Key]*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid)
	}

	if _, ok := t.AdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list AdjacencySid %v", key)
	}

	t.AdjacencySid[key] = v
	return nil
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) NewPrefixSid(Prefix string) (*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[string]*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid{
		Prefix: &Prefix,
	}

	return t.PrefixSid[key], nil
}

// RenamePrefixSid renames an entry in the list PrefixSid within
// the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) RenamePrefixSid(oldK, newK string) error {
	if _, ok := t.PrefixSid[newK]; ok {
		return fmt.Errorf("key %v already exists in PrefixSid", newK)
	}

	e, ok := t.PrefixSid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PrefixSid", oldK)
	}
	e.Prefix = &newK

	t.PrefixSid[newK] = e
	delete(t.PrefixSid, oldK)
	return nil
}

// GetOrCreatePrefixSid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) GetOrCreatePrefixSid(Prefix string) *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid {

	key := Prefix

	if v, ok := t.PrefixSid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefixSid(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefixSid got unexpected error: %v", err))
	}
	return v
}

// GetPrefixSid retrieves the value with the specified key from
// the PrefixSid map field of NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) GetPrefixSid(Prefix string) *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.PrefixSid[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefixSid appends the supplied NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid struct to the
// list PrefixSid of NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) AppendPrefixSid(v *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[string]*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid)
	}

	if _, ok := t.PrefixSid[key]; ok {
		return fmt.Errorf("duplicate key for list PrefixSid %v", key)
	}

	t.PrefixSid[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid struct {
	ΛMetadata              []ygot.Annotation                                                                                        `path:"@" ygotAnnotation:"true"`
	AllocatedDynamicLocal  NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union `path:"state/allocated-dynamic-local" module:"openconfig-network-instance"`
	ΛAllocatedDynamicLocal []ygot.Annotation                                                                                        `path:"state/@allocated-dynamic-local" ygotAnnotation:"true"`
	Group                  *bool                                                                                                    `path:"state/group" shadow-path:"config/group" module:"openconfig-network-instance"`
	ΛGroup                 []ygot.Annotation                                                                                        `path:"state/@group" ygotAnnotation:"true"`
	Neighbor               *string                                                                                                  `path:"state/neighbor|neighbor" shadow-path:"config/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor              []ygot.Annotation                                                                                        `path:"state/@neighbor|@neighbor" ygotAnnotation:"true"`
	ProtectionEligible     *bool                                                                                                    `path:"state/protection-eligible" shadow-path:"config/protection-eligible" module:"openconfig-network-instance"`
	ΛProtectionEligible    []ygot.Annotation                                                                                        `path:"state/@protection-eligible" ygotAnnotation:"true"`
	SidId                  NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union                 `path:"state/sid-id|sid-id" shadow-path:"config/sid-id" module:"openconfig-network-instance"`
	ΛSidId                 []ygot.Annotation                                                                                        `path:"state/@sid-id|@sid-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) IsYANGGoStruct() {
}

// GetAllocatedDynamicLocal retrieves the value of the leaf AllocatedDynamicLocal from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AllocatedDynamicLocal is set, it can safely use t.GetAllocatedDynamicLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AllocatedDynamicLocal == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) GetAllocatedDynamicLocal() NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union {
	if t == nil || t.AllocatedDynamicLocal == nil {
		return nil
	}
	return t.AllocatedDynamicLocal
}

// GetGroup retrieves the value of the leaf Group from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Group is set, it can safely use t.GetGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Group == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) GetGroup() bool {
	if t == nil || t.Group == nil {
		return false
	}
	return *t.Group
}

// GetNeighbor retrieves the value of the leaf Neighbor from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Neighbor is set, it can safely use t.GetNeighbor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Neighbor == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) GetNeighbor() string {
	if t == nil || t.Neighbor == nil {
		return ""
	}
	return *t.Neighbor
}

// GetProtectionEligible retrieves the value of the leaf ProtectionEligible from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ProtectionEligible is set, it can safely use t.GetProtectionEligible()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ProtectionEligible == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) GetProtectionEligible() bool {
	if t == nil || t.ProtectionEligible == nil {
		return true
	}
	return *t.ProtectionEligible
}

// GetSidId retrieves the value of the leaf SidId from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidId is set, it can safely use t.GetSidId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) GetSidId() NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union {
	if t == nil || t.SidId == nil {
		return nil
	}
	return t.SidId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Neighbor == nil {
		return nil, fmt.Errorf("nil value for key Neighbor")
	}

	return map[string]interface{}{
		"neighbor": *t.Neighbor,
		"sid-id":   t.SidId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union()
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union() {
}

// To_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) To_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union(i interface{}) (NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_AllocatedDynamicLocal_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id within the YANG schema.
// Union type can be one of [E_AdjacencySid_SidId_Enum, E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union interface {
	// Union type can be one of [E_AdjacencySid_SidId_Enum, E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union()
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union ensures that E_AdjacencySid_SidId_Enum
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union interface.
func (E_AdjacencySid_SidId_Enum) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union() {
}

// To_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid) To_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union(i interface{}) (NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_AdjacencySid_SidId_Union, unknown union type, got: %T, want any of [E_AdjacencySid_SidId_Enum, E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid struct {
	ΛMetadata     []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	LabelOptions  E_PrefixSid_LabelOptions                                                              `path:"state/label-options" shadow-path:"config/label-options" module:"openconfig-network-instance"`
	ΛLabelOptions []ygot.Annotation                                                                     `path:"state/@label-options" ygotAnnotation:"true"`
	Prefix        *string                                                                               `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-network-instance"`
	ΛPrefix       []ygot.Annotation                                                                     `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SidId         NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union `path:"state/sid-id" shadow-path:"config/sid-id" module:"openconfig-network-instance"`
	ΛSidId        []ygot.Annotation                                                                     `path:"state/@sid-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) IsYANGGoStruct() {}

// GetLabelOptions retrieves the value of the leaf LabelOptions from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LabelOptions is set, it can safely use t.GetLabelOptions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LabelOptions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) GetLabelOptions() E_PrefixSid_LabelOptions {
	if t == nil || t.LabelOptions == 0 {
		return 0
	}
	return t.LabelOptions
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSidId retrieves the value of the leaf SidId from the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidId is set, it can safely use t.GetSidId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) GetSidId() NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union {
	if t == nil || t.SidId == nil {
		return nil
	}
	return t.SidId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union()
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union() {
}

// To_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid) To_NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union(i interface{}) (NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Isis_Interface_Level_Af_SegmentRouting_PrefixSid_SidId_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication struct {
	ΛMetadata            []ygot.Annotation                                                           `path:"@" ygotAnnotation:"true"`
	HelloAuthentication  *bool                                                                       `path:"state/hello-authentication" shadow-path:"config/hello-authentication" module:"openconfig-network-instance"`
	ΛHelloAuthentication []ygot.Annotation                                                           `path:"state/@hello-authentication" ygotAnnotation:"true"`
	Key                  *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key      `path:"key" module:"openconfig-network-instance"`
	ΛKey                 []ygot.Annotation                                                           `path:"@key" ygotAnnotation:"true"`
	Keychain             *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain `path:"keychain" module:"openconfig-network-instance"`
	ΛKeychain            []ygot.Annotation                                                           `path:"@keychain" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) IsYANGGoStruct() {}

// GetOrCreateKey retrieves the value of the Key field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) GetOrCreateKey() *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key {
	if t.Key != nil {
		return t.Key
	}
	t.Key = &NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key{}
	return t.Key
}

// GetOrCreateKeychain retrieves the value of the Keychain field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) GetOrCreateKeychain() *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain {
	if t.Keychain != nil {
		return t.Keychain
	}
	t.Keychain = &NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain{}
	return t.Keychain
}

// GetKey returns the value of the Key struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication. If the receiver or the field Key is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) GetKey() *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key {
	if t != nil && t.Key != nil {
		return t.Key
	}
	return nil
}

// GetKeychain returns the value of the Keychain struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication. If the receiver or the field Keychain is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) GetKeychain() *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain {
	if t != nil && t.Keychain != nil {
		return t.Keychain
	}
	return nil
}

// GetHelloAuthentication retrieves the value of the leaf HelloAuthentication from the NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloAuthentication is set, it can safely use t.GetHelloAuthentication()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloAuthentication == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) GetHelloAuthentication() bool {
	if t == nil || t.HelloAuthentication == nil {
		return false
	}
	return *t.HelloAuthentication
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/key YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthPassword  *string           `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-network-instance"`
	ΛAuthPassword []ygot.Annotation `path:"state/@auth-password" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key) IsYANGGoStruct() {}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Key) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/keychain YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_HelloAuthentication_Keychain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters struct {
	ΛMetadata []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	Csnp      *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp    `path:"csnp" module:"openconfig-network-instance"`
	ΛCsnp     []ygot.Annotation                                                     `path:"@csnp" ygotAnnotation:"true"`
	Esh       *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh     `path:"esh" module:"openconfig-network-instance"`
	ΛEsh      []ygot.Annotation                                                     `path:"@esh" ygotAnnotation:"true"`
	Iih       *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih     `path:"iih" module:"openconfig-network-instance"`
	ΛIih      []ygot.Annotation                                                     `path:"@iih" ygotAnnotation:"true"`
	Ish       *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish     `path:"ish" module:"openconfig-network-instance"`
	ΛIsh      []ygot.Annotation                                                     `path:"@ish" ygotAnnotation:"true"`
	Lsp       *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp     `path:"lsp" module:"openconfig-network-instance"`
	ΛLsp      []ygot.Annotation                                                     `path:"@lsp" ygotAnnotation:"true"`
	Psnp      *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp    `path:"psnp" module:"openconfig-network-instance"`
	ΛPsnp     []ygot.Annotation                                                     `path:"@psnp" ygotAnnotation:"true"`
	Unknown   *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown `path:"unknown" module:"openconfig-network-instance"`
	ΛUnknown  []ygot.Annotation                                                     `path:"@unknown" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) IsYANGGoStruct() {}

// GetOrCreateCsnp retrieves the value of the Csnp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreateCsnp() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp {
	if t.Csnp != nil {
		return t.Csnp
	}
	t.Csnp = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp{}
	return t.Csnp
}

// GetOrCreateEsh retrieves the value of the Esh field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreateEsh() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh {
	if t.Esh != nil {
		return t.Esh
	}
	t.Esh = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh{}
	return t.Esh
}

// GetOrCreateIih retrieves the value of the Iih field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreateIih() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih {
	if t.Iih != nil {
		return t.Iih
	}
	t.Iih = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih{}
	return t.Iih
}

// GetOrCreateIsh retrieves the value of the Ish field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreateIsh() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish {
	if t.Ish != nil {
		return t.Ish
	}
	t.Ish = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish{}
	return t.Ish
}

// GetOrCreateLsp retrieves the value of the Lsp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreateLsp() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp {
	if t.Lsp != nil {
		return t.Lsp
	}
	t.Lsp = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp{}
	return t.Lsp
}

// GetOrCreatePsnp retrieves the value of the Psnp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreatePsnp() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp {
	if t.Psnp != nil {
		return t.Psnp
	}
	t.Psnp = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp{}
	return t.Psnp
}

// GetOrCreateUnknown retrieves the value of the Unknown field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetOrCreateUnknown() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown {
	if t.Unknown != nil {
		return t.Unknown
	}
	t.Unknown = &NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown{}
	return t.Unknown
}

// GetCsnp returns the value of the Csnp struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Csnp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetCsnp() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp {
	if t != nil && t.Csnp != nil {
		return t.Csnp
	}
	return nil
}

// GetEsh returns the value of the Esh struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Esh is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetEsh() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh {
	if t != nil && t.Esh != nil {
		return t.Esh
	}
	return nil
}

// GetIih returns the value of the Iih struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Iih is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetIih() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih {
	if t != nil && t.Iih != nil {
		return t.Iih
	}
	return nil
}

// GetIsh returns the value of the Ish struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Ish is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetIsh() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish {
	if t != nil && t.Ish != nil {
		return t.Ish
	}
	return nil
}

// GetLsp returns the value of the Lsp struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Lsp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetLsp() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp {
	if t != nil && t.Lsp != nil {
		return t.Lsp
	}
	return nil
}

// GetPsnp returns the value of the Psnp struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Psnp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetPsnp() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp {
	if t != nil && t.Psnp != nil {
		return t.Psnp
	}
	return nil
}

// GetUnknown returns the value of the Unknown struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters. If the receiver or the field Unknown is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) GetUnknown() *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown {
	if t != nil && t.Unknown != nil {
		return t.Unknown
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/csnp YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Csnp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/esh YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Esh) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/iih YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Iih) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/ish YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Ish) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/lsp YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Lsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/psnp YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Psnp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/unknown YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dropped     *uint32           `path:"state/dropped" module:"openconfig-network-instance"`
	ΛDropped    []ygot.Annotation `path:"state/@dropped" ygotAnnotation:"true"`
	Processed   *uint32           `path:"state/processed" module:"openconfig-network-instance"`
	ΛProcessed  []ygot.Annotation `path:"state/@processed" ygotAnnotation:"true"`
	Received    *uint32           `path:"state/received" module:"openconfig-network-instance"`
	ΛReceived   []ygot.Annotation `path:"state/@received" ygotAnnotation:"true"`
	Retransmit  *uint32           `path:"state/retransmit" module:"openconfig-network-instance"`
	ΛRetransmit []ygot.Annotation `path:"state/@retransmit" ygotAnnotation:"true"`
	Sent        *uint32           `path:"state/sent" module:"openconfig-network-instance"`
	ΛSent       []ygot.Annotation `path:"state/@sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) IsYANGGoStruct() {}

// GetDropped retrieves the value of the leaf Dropped from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dropped is set, it can safely use t.GetDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dropped == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) GetDropped() uint32 {
	if t == nil || t.Dropped == nil {
		return 0
	}
	return *t.Dropped
}

// GetProcessed retrieves the value of the leaf Processed from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Processed is set, it can safely use t.GetProcessed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Processed == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) GetProcessed() uint32 {
	if t == nil || t.Processed == nil {
		return 0
	}
	return *t.Processed
}

// GetReceived retrieves the value of the leaf Received from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Received is set, it can safely use t.GetReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Received == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) GetReceived() uint32 {
	if t == nil || t.Received == nil {
		return 0
	}
	return *t.Received
}

// GetRetransmit retrieves the value of the leaf Retransmit from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Retransmit is set, it can safely use t.GetRetransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Retransmit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) GetRetransmit() uint32 {
	if t == nil || t.Retransmit == nil {
		return 0
	}
	return *t.Retransmit
}

// GetSent retrieves the value of the leaf Sent from the NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Sent is set, it can safely use t.GetSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Sent == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) GetSent() uint32 {
	if t == nil || t.Sent == nil {
		return 0
	}
	return *t.Sent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_PacketCounters_Unknown) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Level_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/timers YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Level_Timers struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	HelloInterval    *uint32           `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval   []ygot.Annotation `path:"state/@hello-interval" ygotAnnotation:"true"`
	HelloMultiplier  *uint8            `path:"state/hello-multiplier" shadow-path:"config/hello-multiplier" module:"openconfig-network-instance"`
	ΛHelloMultiplier []ygot.Annotation `path:"state/@hello-multiplier" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Level_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Level_Timers) IsYANGGoStruct() {}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Protocol_Isis_Interface_Level_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Timers) GetHelloInterval() uint32 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// GetHelloMultiplier retrieves the value of the leaf HelloMultiplier from the NetworkInstance_Protocol_Isis_Interface_Level_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloMultiplier is set, it can safely use t.GetHelloMultiplier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloMultiplier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Timers) GetHelloMultiplier() uint8 {
	if t == nil || t.HelloMultiplier == nil {
		return 0
	}
	return *t.HelloMultiplier
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Level_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Level_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/mpls YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Mpls struct {
	ΛMetadata   []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	IgpLdpSync  *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
	ΛIgpLdpSync []ygot.Annotation                                        `path:"@igp-ldp-sync" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Mpls) IsYANGGoStruct() {}

// GetOrCreateIgpLdpSync retrieves the value of the IgpLdpSync field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls) GetOrCreateIgpLdpSync() *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync {
	if t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	t.IgpLdpSync = &NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync{}
	return t.IgpLdpSync
}

// GetIgpLdpSync returns the value of the IgpLdpSync struct pointer
// from NetworkInstance_Protocol_Isis_Interface_Mpls. If the receiver or the field IgpLdpSync is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls) GetIgpLdpSync() *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync {
	if t != nil && t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/mpls/igp-ldp-sync YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled             *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	PostSessionUpDelay  *uint16           `path:"state/post-session-up-delay" shadow-path:"config/post-session-up-delay" module:"openconfig-network-instance"`
	ΛPostSessionUpDelay []ygot.Annotation `path:"state/@post-session-up-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return true
	}
	return *t.Enabled
}

// GetPostSessionUpDelay retrieves the value of the leaf PostSessionUpDelay from the NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PostSessionUpDelay is set, it can safely use t.GetPostSessionUpDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PostSessionUpDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync) GetPostSessionUpDelay() uint16 {
	if t == nil || t.PostSessionUpDelay == nil {
		return 0
	}
	return *t.PostSessionUpDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Interface_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/timers YANG schema element.
type NetworkInstance_Protocol_Isis_Interface_Timers struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CsnpInterval       *uint16           `path:"state/csnp-interval" shadow-path:"config/csnp-interval" module:"openconfig-network-instance"`
	ΛCsnpInterval      []ygot.Annotation `path:"state/@csnp-interval" ygotAnnotation:"true"`
	LspPacingInterval  *uint64           `path:"state/lsp-pacing-interval" shadow-path:"config/lsp-pacing-interval" module:"openconfig-network-instance"`
	ΛLspPacingInterval []ygot.Annotation `path:"state/@lsp-pacing-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Interface_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Interface_Timers) IsYANGGoStruct() {}

// GetCsnpInterval retrieves the value of the leaf CsnpInterval from the NetworkInstance_Protocol_Isis_Interface_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CsnpInterval is set, it can safely use t.GetCsnpInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CsnpInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Timers) GetCsnpInterval() uint16 {
	if t == nil || t.CsnpInterval == nil {
		return 0
	}
	return *t.CsnpInterval
}

// GetLspPacingInterval retrieves the value of the leaf LspPacingInterval from the NetworkInstance_Protocol_Isis_Interface_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspPacingInterval is set, it can safely use t.GetLspPacingInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspPacingInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Interface_Timers) GetLspPacingInterval() uint64 {
	if t == nil || t.LspPacingInterval == nil {
		return 0
	}
	return *t.LspPacingInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Interface_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Interface_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Interface_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level YANG schema element.
type NetworkInstance_Protocol_Isis_Level struct {
	ΛMetadata            []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	Authentication       *NetworkInstance_Protocol_Isis_Level_Authentication      `path:"authentication" module:"openconfig-network-instance"`
	ΛAuthentication      []ygot.Annotation                                        `path:"@authentication" ygotAnnotation:"true"`
	AuthenticationCheck  *bool                                                    `path:"state/authentication-check" shadow-path:"config/authentication-check" module:"openconfig-network-instance"`
	ΛAuthenticationCheck []ygot.Annotation                                        `path:"state/@authentication-check" ygotAnnotation:"true"`
	Enabled              *bool                                                    `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled             []ygot.Annotation                                        `path:"state/@enabled" ygotAnnotation:"true"`
	LevelNumber          *uint8                                                   `path:"state/level-number|level-number" shadow-path:"config/level-number" module:"openconfig-network-instance"`
	ΛLevelNumber         []ygot.Annotation                                        `path:"state/@level-number|@level-number" ygotAnnotation:"true"`
	Lsp                  map[string]*NetworkInstance_Protocol_Isis_Level_Lsp      `path:"link-state-database/lsp" module:"openconfig-network-instance"`
	ΛLsp                 []ygot.Annotation                                        `path:"link-state-database/@lsp" ygotAnnotation:"true"`
	MetricStyle          E_OpenconfigIsisTypes_MetricStyle                        `path:"state/metric-style" shadow-path:"config/metric-style" module:"openconfig-network-instance"`
	ΛMetricStyle         []ygot.Annotation                                        `path:"state/@metric-style" ygotAnnotation:"true"`
	RoutePreference      *NetworkInstance_Protocol_Isis_Level_RoutePreference     `path:"route-preference" module:"openconfig-network-instance"`
	ΛRoutePreference     []ygot.Annotation                                        `path:"@route-preference" ygotAnnotation:"true"`
	SystemLevelCounters  *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters `path:"system-level-counters" module:"openconfig-network-instance"`
	ΛSystemLevelCounters []ygot.Annotation                                        `path:"@system-level-counters" ygotAnnotation:"true"`
	TrafficEngineering   *NetworkInstance_Protocol_Isis_Level_TrafficEngineering  `path:"traffic-engineering" module:"openconfig-network-instance"`
	ΛTrafficEngineering  []ygot.Annotation                                        `path:"@traffic-engineering" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level) IsYANGGoStruct() {}

// NewLsp creates a new entry in the Lsp list of the
// NetworkInstance_Protocol_Isis_Level struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level) NewLsp(LspId string) (*NetworkInstance_Protocol_Isis_Level_Lsp, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Lsp == nil {
		t.Lsp = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp)
	}

	key := LspId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Lsp[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Lsp", key)
	}

	t.Lsp[key] = &NetworkInstance_Protocol_Isis_Level_Lsp{
		LspId: &LspId,
	}

	return t.Lsp[key], nil
}

// RenameLsp renames an entry in the list Lsp within
// the NetworkInstance_Protocol_Isis_Level struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level) RenameLsp(oldK, newK string) error {
	if _, ok := t.Lsp[newK]; ok {
		return fmt.Errorf("key %v already exists in Lsp", newK)
	}

	e, ok := t.Lsp[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Lsp", oldK)
	}
	e.LspId = &newK

	t.Lsp[newK] = e
	delete(t.Lsp, oldK)
	return nil
}

// GetOrCreateLsp retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level) GetOrCreateLsp(LspId string) *NetworkInstance_Protocol_Isis_Level_Lsp {

	key := LspId

	if v, ok := t.Lsp[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLsp(LspId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLsp got unexpected error: %v", err))
	}
	return v
}

// GetLsp retrieves the value with the specified key from
// the Lsp map field of NetworkInstance_Protocol_Isis_Level. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level) GetLsp(LspId string) *NetworkInstance_Protocol_Isis_Level_Lsp {

	if t == nil {
		return nil
	}

	key := LspId

	if lm, ok := t.Lsp[key]; ok {
		return lm
	}
	return nil
}

// AppendLsp appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp struct to the
// list Lsp of NetworkInstance_Protocol_Isis_Level. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level) AppendLsp(v *NetworkInstance_Protocol_Isis_Level_Lsp) error {
	if v.LspId == nil {
		return fmt.Errorf("invalid nil key received for LspId")
	}

	key := *v.LspId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Lsp == nil {
		t.Lsp = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp)
	}

	if _, ok := t.Lsp[key]; ok {
		return fmt.Errorf("duplicate key for list Lsp %v", key)
	}

	t.Lsp[key] = v
	return nil
}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level) GetOrCreateAuthentication() *NetworkInstance_Protocol_Isis_Level_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &NetworkInstance_Protocol_Isis_Level_Authentication{}
	return t.Authentication
}

// GetOrCreateRoutePreference retrieves the value of the RoutePreference field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level) GetOrCreateRoutePreference() *NetworkInstance_Protocol_Isis_Level_RoutePreference {
	if t.RoutePreference != nil {
		return t.RoutePreference
	}
	t.RoutePreference = &NetworkInstance_Protocol_Isis_Level_RoutePreference{}
	return t.RoutePreference
}

// GetOrCreateSystemLevelCounters retrieves the value of the SystemLevelCounters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level) GetOrCreateSystemLevelCounters() *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters {
	if t.SystemLevelCounters != nil {
		return t.SystemLevelCounters
	}
	t.SystemLevelCounters = &NetworkInstance_Protocol_Isis_Level_SystemLevelCounters{}
	return t.SystemLevelCounters
}

// GetOrCreateTrafficEngineering retrieves the value of the TrafficEngineering field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level) GetOrCreateTrafficEngineering() *NetworkInstance_Protocol_Isis_Level_TrafficEngineering {
	if t.TrafficEngineering != nil {
		return t.TrafficEngineering
	}
	t.TrafficEngineering = &NetworkInstance_Protocol_Isis_Level_TrafficEngineering{}
	return t.TrafficEngineering
}

// GetAuthentication returns the value of the Authentication struct pointer
// from NetworkInstance_Protocol_Isis_Level. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level) GetAuthentication() *NetworkInstance_Protocol_Isis_Level_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetRoutePreference returns the value of the RoutePreference struct pointer
// from NetworkInstance_Protocol_Isis_Level. If the receiver or the field RoutePreference is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level) GetRoutePreference() *NetworkInstance_Protocol_Isis_Level_RoutePreference {
	if t != nil && t.RoutePreference != nil {
		return t.RoutePreference
	}
	return nil
}

// GetSystemLevelCounters returns the value of the SystemLevelCounters struct pointer
// from NetworkInstance_Protocol_Isis_Level. If the receiver or the field SystemLevelCounters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level) GetSystemLevelCounters() *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters {
	if t != nil && t.SystemLevelCounters != nil {
		return t.SystemLevelCounters
	}
	return nil
}

// GetTrafficEngineering returns the value of the TrafficEngineering struct pointer
// from NetworkInstance_Protocol_Isis_Level. If the receiver or the field TrafficEngineering is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level) GetTrafficEngineering() *NetworkInstance_Protocol_Isis_Level_TrafficEngineering {
	if t != nil && t.TrafficEngineering != nil {
		return t.TrafficEngineering
	}
	return nil
}

// GetAuthenticationCheck retrieves the value of the leaf AuthenticationCheck from the NetworkInstance_Protocol_Isis_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationCheck is set, it can safely use t.GetAuthenticationCheck()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationCheck == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level) GetAuthenticationCheck() bool {
	if t == nil || t.AuthenticationCheck == nil {
		return true
	}
	return *t.AuthenticationCheck
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetLevelNumber retrieves the value of the leaf LevelNumber from the NetworkInstance_Protocol_Isis_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LevelNumber is set, it can safely use t.GetLevelNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LevelNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level) GetLevelNumber() uint8 {
	if t == nil || t.LevelNumber == nil {
		return 0
	}
	return *t.LevelNumber
}

// GetMetricStyle retrieves the value of the leaf MetricStyle from the NetworkInstance_Protocol_Isis_Level
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MetricStyle is set, it can safely use t.GetMetricStyle()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MetricStyle == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level) GetMetricStyle() E_OpenconfigIsisTypes_MetricStyle {
	if t == nil || t.MetricStyle == 0 {
		return 0
	}
	return t.MetricStyle
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LevelNumber == nil {
		return nil, fmt.Errorf("nil value for key LevelNumber")
	}

	return map[string]interface{}{
		"level-number": *t.LevelNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Authentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Authentication struct {
	ΛMetadata           []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	CsnpAuthentication  *bool                                                        `path:"state/csnp-authentication" shadow-path:"config/csnp-authentication" module:"openconfig-network-instance"`
	ΛCsnpAuthentication []ygot.Annotation                                            `path:"state/@csnp-authentication" ygotAnnotation:"true"`
	Key                 *NetworkInstance_Protocol_Isis_Level_Authentication_Key      `path:"key" module:"openconfig-network-instance"`
	ΛKey                []ygot.Annotation                                            `path:"@key" ygotAnnotation:"true"`
	Keychain            *NetworkInstance_Protocol_Isis_Level_Authentication_Keychain `path:"keychain" module:"openconfig-network-instance"`
	ΛKeychain           []ygot.Annotation                                            `path:"@keychain" ygotAnnotation:"true"`
	LspAuthentication   *bool                                                        `path:"state/lsp-authentication" shadow-path:"config/lsp-authentication" module:"openconfig-network-instance"`
	ΛLspAuthentication  []ygot.Annotation                                            `path:"state/@lsp-authentication" ygotAnnotation:"true"`
	PsnpAuthentication  *bool                                                        `path:"state/psnp-authentication" shadow-path:"config/psnp-authentication" module:"openconfig-network-instance"`
	ΛPsnpAuthentication []ygot.Annotation                                            `path:"state/@psnp-authentication" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Authentication) IsYANGGoStruct() {}

// GetOrCreateKey retrieves the value of the Key field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetOrCreateKey() *NetworkInstance_Protocol_Isis_Level_Authentication_Key {
	if t.Key != nil {
		return t.Key
	}
	t.Key = &NetworkInstance_Protocol_Isis_Level_Authentication_Key{}
	return t.Key
}

// GetOrCreateKeychain retrieves the value of the Keychain field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetOrCreateKeychain() *NetworkInstance_Protocol_Isis_Level_Authentication_Keychain {
	if t.Keychain != nil {
		return t.Keychain
	}
	t.Keychain = &NetworkInstance_Protocol_Isis_Level_Authentication_Keychain{}
	return t.Keychain
}

// GetKey returns the value of the Key struct pointer
// from NetworkInstance_Protocol_Isis_Level_Authentication. If the receiver or the field Key is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetKey() *NetworkInstance_Protocol_Isis_Level_Authentication_Key {
	if t != nil && t.Key != nil {
		return t.Key
	}
	return nil
}

// GetKeychain returns the value of the Keychain struct pointer
// from NetworkInstance_Protocol_Isis_Level_Authentication. If the receiver or the field Keychain is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetKeychain() *NetworkInstance_Protocol_Isis_Level_Authentication_Keychain {
	if t != nil && t.Keychain != nil {
		return t.Keychain
	}
	return nil
}

// GetCsnpAuthentication retrieves the value of the leaf CsnpAuthentication from the NetworkInstance_Protocol_Isis_Level_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CsnpAuthentication is set, it can safely use t.GetCsnpAuthentication()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CsnpAuthentication == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetCsnpAuthentication() bool {
	if t == nil || t.CsnpAuthentication == nil {
		return false
	}
	return *t.CsnpAuthentication
}

// GetLspAuthentication retrieves the value of the leaf LspAuthentication from the NetworkInstance_Protocol_Isis_Level_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspAuthentication is set, it can safely use t.GetLspAuthentication()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspAuthentication == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetLspAuthentication() bool {
	if t == nil || t.LspAuthentication == nil {
		return false
	}
	return *t.LspAuthentication
}

// GetPsnpAuthentication retrieves the value of the leaf PsnpAuthentication from the NetworkInstance_Protocol_Isis_Level_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PsnpAuthentication is set, it can safely use t.GetPsnpAuthentication()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PsnpAuthentication == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) GetPsnpAuthentication() bool {
	if t == nil || t.PsnpAuthentication == nil {
		return false
	}
	return *t.PsnpAuthentication
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Authentication_Key represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/key YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Authentication_Key struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthPassword  *string           `path:"state/auth-password" shadow-path:"config/auth-password" module:"openconfig-network-instance"`
	ΛAuthPassword []ygot.Annotation `path:"state/@auth-password" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Authentication_Key implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Authentication_Key) IsYANGGoStruct() {}

// GetAuthPassword retrieves the value of the leaf AuthPassword from the NetworkInstance_Protocol_Isis_Level_Authentication_Key
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPassword is set, it can safely use t.GetAuthPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPassword == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication_Key) GetAuthPassword() string {
	if t == nil || t.AuthPassword == nil {
		return ""
	}
	return *t.AuthPassword
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication_Key) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Authentication_Key"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication_Key) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Authentication_Keychain represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/keychain YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Authentication_Keychain struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Authentication_Keychain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Authentication_Keychain) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication_Keychain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Authentication_Keychain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Authentication_Keychain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp struct {
	ΛMetadata             []ygot.Annotation                                                                        `path:"@" ygotAnnotation:"true"`
	Checksum              *uint16                                                                                  `path:"state/checksum" module:"openconfig-network-instance"`
	ΛChecksum             []ygot.Annotation                                                                        `path:"state/@checksum" ygotAnnotation:"true"`
	Flags                 []E_Lsp_Flags                                                                            `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags                []ygot.Annotation                                                                        `path:"state/@flags" ygotAnnotation:"true"`
	IdLength              *uint8                                                                                   `path:"state/id-length" module:"openconfig-network-instance"`
	ΛIdLength             []ygot.Annotation                                                                        `path:"state/@id-length" ygotAnnotation:"true"`
	IsType                *uint8                                                                                   `path:"state/is-type" module:"openconfig-network-instance"`
	ΛIsType               []ygot.Annotation                                                                        `path:"state/@is-type" ygotAnnotation:"true"`
	LspId                 *string                                                                                  `path:"state/lsp-id|lsp-id" module:"openconfig-network-instance"`
	ΛLspId                []ygot.Annotation                                                                        `path:"state/@lsp-id|@lsp-id" ygotAnnotation:"true"`
	MaximumAreaAddresses  *uint8                                                                                   `path:"state/maximum-area-addresses" module:"openconfig-network-instance"`
	ΛMaximumAreaAddresses []ygot.Annotation                                                                        `path:"state/@maximum-area-addresses" ygotAnnotation:"true"`
	PduLength             *uint16                                                                                  `path:"state/pdu-length" module:"openconfig-network-instance"`
	ΛPduLength            []ygot.Annotation                                                                        `path:"state/@pdu-length" ygotAnnotation:"true"`
	PduType               E_Lsp_PduType                                                                            `path:"state/pdu-type" module:"openconfig-network-instance"`
	ΛPduType              []ygot.Annotation                                                                        `path:"state/@pdu-type" ygotAnnotation:"true"`
	RemainingLifetime     *uint16                                                                                  `path:"state/remaining-lifetime" module:"openconfig-network-instance"`
	ΛRemainingLifetime    []ygot.Annotation                                                                        `path:"state/@remaining-lifetime" ygotAnnotation:"true"`
	SequenceNumber        *uint32                                                                                  `path:"state/sequence-number" module:"openconfig-network-instance"`
	ΛSequenceNumber       []ygot.Annotation                                                                        `path:"state/@sequence-number" ygotAnnotation:"true"`
	Tlv                   map[E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv                  []ygot.Annotation                                                                        `path:"tlvs/@tlv" ygotAnnotation:"true"`
	UndefinedTlv          map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv                          `path:"undefined-tlvs/undefined-tlv" module:"openconfig-network-instance"`
	ΛUndefinedTlv         []ygot.Annotation                                                                        `path:"undefined-tlvs/@undefined-tlv" ygotAnnotation:"true"`
	Version               *uint8                                                                                   `path:"state/version" module:"openconfig-network-instance"`
	ΛVersion              []ygot.Annotation                                                                        `path:"state/@version" ygotAnnotation:"true"`
	Version2              *uint8                                                                                   `path:"state/version2" module:"openconfig-network-instance"`
	ΛVersion2             []ygot.Annotation                                                                        `path:"state/@version2" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp) IsYANGGoStruct() {}

// NewTlv creates a new entry in the Tlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) NewTlv(Type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tlv", key)
	}

	t.Tlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv{
		Type: Type,
	}

	return t.Tlv[key], nil
}

// RenameTlv renames an entry in the list Tlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) RenameTlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) error {
	if _, ok := t.Tlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Tlv", newK)
	}

	e, ok := t.Tlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Tlv", oldK)
	}
	e.Type = newK

	t.Tlv[newK] = e
	delete(t.Tlv, oldK)
	return nil
}

// GetOrCreateTlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetOrCreateTlv(Type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv {

	key := Type

	if v, ok := t.Tlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTlv got unexpected error: %v", err))
	}
	return v
}

// GetTlv retrieves the value with the specified key from
// the Tlv map field of NetworkInstance_Protocol_Isis_Level_Lsp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetTlv(Type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Tlv[key]; ok {
		return lm
	}
	return nil
}

// AppendTlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct to the
// list Tlv of NetworkInstance_Protocol_Isis_Level_Lsp. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) AppendTlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv)
	}

	if _, ok := t.Tlv[key]; ok {
		return fmt.Errorf("duplicate key for list Tlv %v", key)
	}

	t.Tlv[key] = v
	return nil
}

// NewUndefinedTlv creates a new entry in the UndefinedTlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) NewUndefinedTlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedTlv == nil {
		t.UndefinedTlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedTlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedTlv", key)
	}

	t.UndefinedTlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv{
		Type: &Type,
	}

	return t.UndefinedTlv[key], nil
}

// RenameUndefinedTlv renames an entry in the list UndefinedTlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) RenameUndefinedTlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedTlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedTlv", newK)
	}

	e, ok := t.UndefinedTlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedTlv", oldK)
	}
	e.Type = &newK

	t.UndefinedTlv[newK] = e
	delete(t.UndefinedTlv, oldK)
	return nil
}

// GetOrCreateUndefinedTlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetOrCreateUndefinedTlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv {

	key := Type

	if v, ok := t.UndefinedTlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedTlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedTlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedTlv retrieves the value with the specified key from
// the UndefinedTlv map field of NetworkInstance_Protocol_Isis_Level_Lsp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetUndefinedTlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedTlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedTlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv struct to the
// list UndefinedTlv of NetworkInstance_Protocol_Isis_Level_Lsp. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) AppendUndefinedTlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedTlv == nil {
		t.UndefinedTlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv)
	}

	if _, ok := t.UndefinedTlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedTlv %v", key)
	}

	t.UndefinedTlv[key] = v
	return nil
}

// GetChecksum retrieves the value of the leaf Checksum from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Checksum is set, it can safely use t.GetChecksum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Checksum == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetChecksum() uint16 {
	if t == nil || t.Checksum == nil {
		return 0
	}
	return *t.Checksum
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetFlags() []E_Lsp_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetIdLength retrieves the value of the leaf IdLength from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IdLength is set, it can safely use t.GetIdLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IdLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetIdLength() uint8 {
	if t == nil || t.IdLength == nil {
		return 0
	}
	return *t.IdLength
}

// GetIsType retrieves the value of the leaf IsType from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IsType is set, it can safely use t.GetIsType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IsType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetIsType() uint8 {
	if t == nil || t.IsType == nil {
		return 0
	}
	return *t.IsType
}

// GetLspId retrieves the value of the leaf LspId from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspId is set, it can safely use t.GetLspId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetLspId() string {
	if t == nil || t.LspId == nil {
		return ""
	}
	return *t.LspId
}

// GetMaximumAreaAddresses retrieves the value of the leaf MaximumAreaAddresses from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumAreaAddresses is set, it can safely use t.GetMaximumAreaAddresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumAreaAddresses == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetMaximumAreaAddresses() uint8 {
	if t == nil || t.MaximumAreaAddresses == nil {
		return 0
	}
	return *t.MaximumAreaAddresses
}

// GetPduLength retrieves the value of the leaf PduLength from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PduLength is set, it can safely use t.GetPduLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PduLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetPduLength() uint16 {
	if t == nil || t.PduLength == nil {
		return 0
	}
	return *t.PduLength
}

// GetPduType retrieves the value of the leaf PduType from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PduType is set, it can safely use t.GetPduType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PduType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetPduType() E_Lsp_PduType {
	if t == nil || t.PduType == 0 {
		return 0
	}
	return t.PduType
}

// GetRemainingLifetime retrieves the value of the leaf RemainingLifetime from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemainingLifetime is set, it can safely use t.GetRemainingLifetime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemainingLifetime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetRemainingLifetime() uint16 {
	if t == nil || t.RemainingLifetime == nil {
		return 0
	}
	return *t.RemainingLifetime
}

// GetSequenceNumber retrieves the value of the leaf SequenceNumber from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SequenceNumber is set, it can safely use t.GetSequenceNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SequenceNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetSequenceNumber() uint32 {
	if t == nil || t.SequenceNumber == nil {
		return 0
	}
	return *t.SequenceNumber
}

// GetVersion retrieves the value of the leaf Version from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Version is set, it can safely use t.GetVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Version == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetVersion() uint8 {
	if t == nil || t.Version == nil {
		return 1
	}
	return *t.Version
}

// GetVersion2 retrieves the value of the leaf Version2 from the NetworkInstance_Protocol_Isis_Level_Lsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Version2 is set, it can safely use t.GetVersion2()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Version2 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) GetVersion2() uint8 {
	if t == nil || t.Version2 == nil {
		return 1
	}
	return *t.Version2
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LspId == nil {
		return nil, fmt.Errorf("nil value for key LspId")
	}

	return map[string]interface{}{
		"lsp-id": *t.LspId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct {
	ΛMetadata                 []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	AreaAddress               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress              `path:"area-address" module:"openconfig-network-instance"`
	ΛAreaAddress              []ygot.Annotation                                                     `path:"@area-address" ygotAnnotation:"true"`
	Authentication            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication           `path:"authentication" module:"openconfig-network-instance"`
	ΛAuthentication           []ygot.Annotation                                                     `path:"@authentication" ygotAnnotation:"true"`
	Capability                map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability    `path:"router-capabilities/capability" module:"openconfig-network-instance"`
	ΛCapability               []ygot.Annotation                                                     `path:"router-capabilities/@capability" ygotAnnotation:"true"`
	ExtendedIpv4Reachability  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability `path:"extended-ipv4-reachability" module:"openconfig-network-instance"`
	ΛExtendedIpv4Reachability []ygot.Annotation                                                     `path:"@extended-ipv4-reachability" ygotAnnotation:"true"`
	ExtendedIsReachability    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability   `path:"extended-is-reachability" module:"openconfig-network-instance"`
	ΛExtendedIsReachability   []ygot.Annotation                                                     `path:"@extended-is-reachability" ygotAnnotation:"true"`
	Hostname                  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname                 `path:"hostname" module:"openconfig-network-instance"`
	ΛHostname                 []ygot.Annotation                                                     `path:"@hostname" ygotAnnotation:"true"`
	InstanceId                map[uint16]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId    `path:"instance-ids/instance-id" module:"openconfig-network-instance"`
	ΛInstanceId               []ygot.Annotation                                                     `path:"instance-ids/@instance-id" ygotAnnotation:"true"`
	Ipv4ExternalReachability  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability `path:"ipv4-external-reachability" module:"openconfig-network-instance"`
	ΛIpv4ExternalReachability []ygot.Annotation                                                     `path:"@ipv4-external-reachability" ygotAnnotation:"true"`
	Ipv4InterfaceAddresses    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses   `path:"ipv4-interface-addresses" module:"openconfig-network-instance"`
	ΛIpv4InterfaceAddresses   []ygot.Annotation                                                     `path:"@ipv4-interface-addresses" ygotAnnotation:"true"`
	Ipv4InternalReachability  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability `path:"ipv4-internal-reachability" module:"openconfig-network-instance"`
	ΛIpv4InternalReachability []ygot.Annotation                                                     `path:"@ipv4-internal-reachability" ygotAnnotation:"true"`
	Ipv4Srlg                  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg      `path:"ipv4-srlgs/ipv4-srlg" module:"openconfig-network-instance"`
	ΛIpv4Srlg                 []ygot.Annotation                                                     `path:"ipv4-srlgs/@ipv4-srlg" ygotAnnotation:"true"`
	Ipv4TeRouterId            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId           `path:"ipv4-te-router-id" module:"openconfig-network-instance"`
	ΛIpv4TeRouterId           []ygot.Annotation                                                     `path:"@ipv4-te-router-id" ygotAnnotation:"true"`
	Ipv6InterfaceAddresses    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses   `path:"ipv6-interface-addresses" module:"openconfig-network-instance"`
	ΛIpv6InterfaceAddresses   []ygot.Annotation                                                     `path:"@ipv6-interface-addresses" ygotAnnotation:"true"`
	Ipv6Reachability          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability         `path:"ipv6-reachability" module:"openconfig-network-instance"`
	ΛIpv6Reachability         []ygot.Annotation                                                     `path:"@ipv6-reachability" ygotAnnotation:"true"`
	Ipv6Srlg                  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg      `path:"ipv6-srlgs/ipv6-srlg" module:"openconfig-network-instance"`
	ΛIpv6Srlg                 []ygot.Annotation                                                     `path:"ipv6-srlgs/@ipv6-srlg" ygotAnnotation:"true"`
	Ipv6TeRouterId            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId           `path:"ipv6-te-router-id" module:"openconfig-network-instance"`
	ΛIpv6TeRouterId           []ygot.Annotation                                                     `path:"@ipv6-te-router-id" ygotAnnotation:"true"`
	IsAliasId                 *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId                `path:"is-alias-id" module:"openconfig-network-instance"`
	ΛIsAliasId                []ygot.Annotation                                                     `path:"@is-alias-id" ygotAnnotation:"true"`
	IsReachability            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability           `path:"is-reachability" module:"openconfig-network-instance"`
	ΛIsReachability           []ygot.Annotation                                                     `path:"@is-reachability" ygotAnnotation:"true"`
	IsisNeighborAttribute     *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute    `path:"isis-neighbor-attribute" module:"openconfig-network-instance"`
	ΛIsisNeighborAttribute    []ygot.Annotation                                                     `path:"@isis-neighbor-attribute" ygotAnnotation:"true"`
	LspBufferSize             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize            `path:"lsp-buffer-size" module:"openconfig-network-instance"`
	ΛLspBufferSize            []ygot.Annotation                                                     `path:"@lsp-buffer-size" ygotAnnotation:"true"`
	MtIpv4Reachability        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability       `path:"mt-ipv4-reachability" module:"openconfig-network-instance"`
	ΛMtIpv4Reachability       []ygot.Annotation                                                     `path:"@mt-ipv4-reachability" ygotAnnotation:"true"`
	MtIpv6Reachability        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability       `path:"mt-ipv6-reachability" module:"openconfig-network-instance"`
	ΛMtIpv6Reachability       []ygot.Annotation                                                     `path:"@mt-ipv6-reachability" ygotAnnotation:"true"`
	MtIsisNeighborAttribute   *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute  `path:"mt-isis-neighbor-attribute" module:"openconfig-network-instance"`
	ΛMtIsisNeighborAttribute  []ygot.Annotation                                                     `path:"@mt-isis-neighbor-attribute" ygotAnnotation:"true"`
	MtIsn                     *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn                    `path:"mt-isn" module:"openconfig-network-instance"`
	ΛMtIsn                    []ygot.Annotation                                                     `path:"@mt-isn" ygotAnnotation:"true"`
	MultiTopology             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology            `path:"multi-topology" module:"openconfig-network-instance"`
	ΛMultiTopology            []ygot.Annotation                                                     `path:"@multi-topology" ygotAnnotation:"true"`
	Nlpid                     *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid                    `path:"nlpid" module:"openconfig-network-instance"`
	ΛNlpid                    []ygot.Annotation                                                     `path:"@nlpid" ygotAnnotation:"true"`
	PurgeOi                   *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi                  `path:"purge-oi" module:"openconfig-network-instance"`
	ΛPurgeOi                  []ygot.Annotation                                                     `path:"@purge-oi" ygotAnnotation:"true"`
	Type                      E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE                               `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType                     []ygot.Annotation                                                     `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) IsYANGGoStruct() {}

// NewCapability creates a new entry in the Capability list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) NewCapability(InstanceNumber uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Capability == nil {
		t.Capability = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability)
	}

	key := InstanceNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Capability[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Capability", key)
	}

	t.Capability[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability{
		InstanceNumber: &InstanceNumber,
	}

	return t.Capability[key], nil
}

// RenameCapability renames an entry in the list Capability within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) RenameCapability(oldK, newK uint32) error {
	if _, ok := t.Capability[newK]; ok {
		return fmt.Errorf("key %v already exists in Capability", newK)
	}

	e, ok := t.Capability[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Capability", oldK)
	}
	e.InstanceNumber = &newK

	t.Capability[newK] = e
	delete(t.Capability, oldK)
	return nil
}

// GetOrCreateCapability retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateCapability(InstanceNumber uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability {

	key := InstanceNumber

	if v, ok := t.Capability[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCapability(InstanceNumber)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCapability got unexpected error: %v", err))
	}
	return v
}

// GetCapability retrieves the value with the specified key from
// the Capability map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetCapability(InstanceNumber uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability {

	if t == nil {
		return nil
	}

	key := InstanceNumber

	if lm, ok := t.Capability[key]; ok {
		return lm
	}
	return nil
}

// AppendCapability appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct to the
// list Capability of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) AppendCapability(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) error {
	if v.InstanceNumber == nil {
		return fmt.Errorf("invalid nil key received for InstanceNumber")
	}

	key := *v.InstanceNumber

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Capability == nil {
		t.Capability = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability)
	}

	if _, ok := t.Capability[key]; ok {
		return fmt.Errorf("duplicate key for list Capability %v", key)
	}

	t.Capability[key] = v
	return nil
}

// NewInstanceId creates a new entry in the InstanceId list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) NewInstanceId(InstanceId uint16) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InstanceId == nil {
		t.InstanceId = make(map[uint16]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId)
	}

	key := InstanceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.InstanceId[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list InstanceId", key)
	}

	t.InstanceId[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId{
		InstanceId: &InstanceId,
	}

	return t.InstanceId[key], nil
}

// RenameInstanceId renames an entry in the list InstanceId within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) RenameInstanceId(oldK, newK uint16) error {
	if _, ok := t.InstanceId[newK]; ok {
		return fmt.Errorf("key %v already exists in InstanceId", newK)
	}

	e, ok := t.InstanceId[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in InstanceId", oldK)
	}
	e.InstanceId = &newK

	t.InstanceId[newK] = e
	delete(t.InstanceId, oldK)
	return nil
}

// GetOrCreateInstanceId retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateInstanceId(InstanceId uint16) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId {

	key := InstanceId

	if v, ok := t.InstanceId[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInstanceId(InstanceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInstanceId got unexpected error: %v", err))
	}
	return v
}

// GetInstanceId retrieves the value with the specified key from
// the InstanceId map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetInstanceId(InstanceId uint16) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId {

	if t == nil {
		return nil
	}

	key := InstanceId

	if lm, ok := t.InstanceId[key]; ok {
		return lm
	}
	return nil
}

// AppendInstanceId appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId struct to the
// list InstanceId of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) AppendInstanceId(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) error {
	if v.InstanceId == nil {
		return fmt.Errorf("invalid nil key received for InstanceId")
	}

	key := *v.InstanceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InstanceId == nil {
		t.InstanceId = make(map[uint16]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId)
	}

	if _, ok := t.InstanceId[key]; ok {
		return fmt.Errorf("duplicate key for list InstanceId %v", key)
	}

	t.InstanceId[key] = v
	return nil
}

// NewIpv4Srlg creates a new entry in the Ipv4Srlg list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) NewIpv4Srlg(InstanceNumber uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4Srlg == nil {
		t.Ipv4Srlg = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg)
	}

	key := InstanceNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4Srlg[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4Srlg", key)
	}

	t.Ipv4Srlg[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg{
		InstanceNumber: &InstanceNumber,
	}

	return t.Ipv4Srlg[key], nil
}

// RenameIpv4Srlg renames an entry in the list Ipv4Srlg within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) RenameIpv4Srlg(oldK, newK uint32) error {
	if _, ok := t.Ipv4Srlg[newK]; ok {
		return fmt.Errorf("key %v already exists in Ipv4Srlg", newK)
	}

	e, ok := t.Ipv4Srlg[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Ipv4Srlg", oldK)
	}
	e.InstanceNumber = &newK

	t.Ipv4Srlg[newK] = e
	delete(t.Ipv4Srlg, oldK)
	return nil
}

// GetOrCreateIpv4Srlg retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv4Srlg(InstanceNumber uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg {

	key := InstanceNumber

	if v, ok := t.Ipv4Srlg[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewIpv4Srlg(InstanceNumber)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateIpv4Srlg got unexpected error: %v", err))
	}
	return v
}

// GetIpv4Srlg retrieves the value with the specified key from
// the Ipv4Srlg map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv4Srlg(InstanceNumber uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg {

	if t == nil {
		return nil
	}

	key := InstanceNumber

	if lm, ok := t.Ipv4Srlg[key]; ok {
		return lm
	}
	return nil
}

// AppendIpv4Srlg appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg struct to the
// list Ipv4Srlg of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) AppendIpv4Srlg(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) error {
	if v.InstanceNumber == nil {
		return fmt.Errorf("invalid nil key received for InstanceNumber")
	}

	key := *v.InstanceNumber

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4Srlg == nil {
		t.Ipv4Srlg = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg)
	}

	if _, ok := t.Ipv4Srlg[key]; ok {
		return fmt.Errorf("duplicate key for list Ipv4Srlg %v", key)
	}

	t.Ipv4Srlg[key] = v
	return nil
}

// NewIpv6Srlg creates a new entry in the Ipv6Srlg list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) NewIpv6Srlg(InstanceNumber uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6Srlg == nil {
		t.Ipv6Srlg = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg)
	}

	key := InstanceNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6Srlg[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6Srlg", key)
	}

	t.Ipv6Srlg[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg{
		InstanceNumber: &InstanceNumber,
	}

	return t.Ipv6Srlg[key], nil
}

// RenameIpv6Srlg renames an entry in the list Ipv6Srlg within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) RenameIpv6Srlg(oldK, newK uint32) error {
	if _, ok := t.Ipv6Srlg[newK]; ok {
		return fmt.Errorf("key %v already exists in Ipv6Srlg", newK)
	}

	e, ok := t.Ipv6Srlg[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Ipv6Srlg", oldK)
	}
	e.InstanceNumber = &newK

	t.Ipv6Srlg[newK] = e
	delete(t.Ipv6Srlg, oldK)
	return nil
}

// GetOrCreateIpv6Srlg retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv6Srlg(InstanceNumber uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg {

	key := InstanceNumber

	if v, ok := t.Ipv6Srlg[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewIpv6Srlg(InstanceNumber)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateIpv6Srlg got unexpected error: %v", err))
	}
	return v
}

// GetIpv6Srlg retrieves the value with the specified key from
// the Ipv6Srlg map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv6Srlg(InstanceNumber uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg {

	if t == nil {
		return nil
	}

	key := InstanceNumber

	if lm, ok := t.Ipv6Srlg[key]; ok {
		return lm
	}
	return nil
}

// AppendIpv6Srlg appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg struct to the
// list Ipv6Srlg of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) AppendIpv6Srlg(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) error {
	if v.InstanceNumber == nil {
		return fmt.Errorf("invalid nil key received for InstanceNumber")
	}

	key := *v.InstanceNumber

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6Srlg == nil {
		t.Ipv6Srlg = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg)
	}

	if _, ok := t.Ipv6Srlg[key]; ok {
		return fmt.Errorf("duplicate key for list Ipv6Srlg %v", key)
	}

	t.Ipv6Srlg[key] = v
	return nil
}

// GetOrCreateAreaAddress retrieves the value of the AreaAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateAreaAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress {
	if t.AreaAddress != nil {
		return t.AreaAddress
	}
	t.AreaAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress{}
	return t.AreaAddress
}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateAuthentication() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication{}
	return t.Authentication
}

// GetOrCreateExtendedIpv4Reachability retrieves the value of the ExtendedIpv4Reachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateExtendedIpv4Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability {
	if t.ExtendedIpv4Reachability != nil {
		return t.ExtendedIpv4Reachability
	}
	t.ExtendedIpv4Reachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability{}
	return t.ExtendedIpv4Reachability
}

// GetOrCreateExtendedIsReachability retrieves the value of the ExtendedIsReachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateExtendedIsReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability {
	if t.ExtendedIsReachability != nil {
		return t.ExtendedIsReachability
	}
	t.ExtendedIsReachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability{}
	return t.ExtendedIsReachability
}

// GetOrCreateHostname retrieves the value of the Hostname field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateHostname() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname {
	if t.Hostname != nil {
		return t.Hostname
	}
	t.Hostname = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname{}
	return t.Hostname
}

// GetOrCreateIpv4ExternalReachability retrieves the value of the Ipv4ExternalReachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv4ExternalReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability {
	if t.Ipv4ExternalReachability != nil {
		return t.Ipv4ExternalReachability
	}
	t.Ipv4ExternalReachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability{}
	return t.Ipv4ExternalReachability
}

// GetOrCreateIpv4InterfaceAddresses retrieves the value of the Ipv4InterfaceAddresses field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv4InterfaceAddresses() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses {
	if t.Ipv4InterfaceAddresses != nil {
		return t.Ipv4InterfaceAddresses
	}
	t.Ipv4InterfaceAddresses = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses{}
	return t.Ipv4InterfaceAddresses
}

// GetOrCreateIpv4InternalReachability retrieves the value of the Ipv4InternalReachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv4InternalReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability {
	if t.Ipv4InternalReachability != nil {
		return t.Ipv4InternalReachability
	}
	t.Ipv4InternalReachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability{}
	return t.Ipv4InternalReachability
}

// GetOrCreateIpv4TeRouterId retrieves the value of the Ipv4TeRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv4TeRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId {
	if t.Ipv4TeRouterId != nil {
		return t.Ipv4TeRouterId
	}
	t.Ipv4TeRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId{}
	return t.Ipv4TeRouterId
}

// GetOrCreateIpv6InterfaceAddresses retrieves the value of the Ipv6InterfaceAddresses field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv6InterfaceAddresses() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses {
	if t.Ipv6InterfaceAddresses != nil {
		return t.Ipv6InterfaceAddresses
	}
	t.Ipv6InterfaceAddresses = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses{}
	return t.Ipv6InterfaceAddresses
}

// GetOrCreateIpv6Reachability retrieves the value of the Ipv6Reachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv6Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability {
	if t.Ipv6Reachability != nil {
		return t.Ipv6Reachability
	}
	t.Ipv6Reachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability{}
	return t.Ipv6Reachability
}

// GetOrCreateIpv6TeRouterId retrieves the value of the Ipv6TeRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIpv6TeRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId {
	if t.Ipv6TeRouterId != nil {
		return t.Ipv6TeRouterId
	}
	t.Ipv6TeRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId{}
	return t.Ipv6TeRouterId
}

// GetOrCreateIsAliasId retrieves the value of the IsAliasId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIsAliasId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId {
	if t.IsAliasId != nil {
		return t.IsAliasId
	}
	t.IsAliasId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId{}
	return t.IsAliasId
}

// GetOrCreateIsReachability retrieves the value of the IsReachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIsReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability {
	if t.IsReachability != nil {
		return t.IsReachability
	}
	t.IsReachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability{}
	return t.IsReachability
}

// GetOrCreateIsisNeighborAttribute retrieves the value of the IsisNeighborAttribute field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateIsisNeighborAttribute() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute {
	if t.IsisNeighborAttribute != nil {
		return t.IsisNeighborAttribute
	}
	t.IsisNeighborAttribute = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute{}
	return t.IsisNeighborAttribute
}

// GetOrCreateLspBufferSize retrieves the value of the LspBufferSize field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateLspBufferSize() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize {
	if t.LspBufferSize != nil {
		return t.LspBufferSize
	}
	t.LspBufferSize = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize{}
	return t.LspBufferSize
}

// GetOrCreateMtIpv4Reachability retrieves the value of the MtIpv4Reachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateMtIpv4Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability {
	if t.MtIpv4Reachability != nil {
		return t.MtIpv4Reachability
	}
	t.MtIpv4Reachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability{}
	return t.MtIpv4Reachability
}

// GetOrCreateMtIpv6Reachability retrieves the value of the MtIpv6Reachability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateMtIpv6Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability {
	if t.MtIpv6Reachability != nil {
		return t.MtIpv6Reachability
	}
	t.MtIpv6Reachability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability{}
	return t.MtIpv6Reachability
}

// GetOrCreateMtIsisNeighborAttribute retrieves the value of the MtIsisNeighborAttribute field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateMtIsisNeighborAttribute() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute {
	if t.MtIsisNeighborAttribute != nil {
		return t.MtIsisNeighborAttribute
	}
	t.MtIsisNeighborAttribute = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute{}
	return t.MtIsisNeighborAttribute
}

// GetOrCreateMtIsn retrieves the value of the MtIsn field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateMtIsn() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn {
	if t.MtIsn != nil {
		return t.MtIsn
	}
	t.MtIsn = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn{}
	return t.MtIsn
}

// GetOrCreateMultiTopology retrieves the value of the MultiTopology field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateMultiTopology() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology {
	if t.MultiTopology != nil {
		return t.MultiTopology
	}
	t.MultiTopology = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology{}
	return t.MultiTopology
}

// GetOrCreateNlpid retrieves the value of the Nlpid field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreateNlpid() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid {
	if t.Nlpid != nil {
		return t.Nlpid
	}
	t.Nlpid = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid{}
	return t.Nlpid
}

// GetOrCreatePurgeOi retrieves the value of the PurgeOi field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetOrCreatePurgeOi() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi {
	if t.PurgeOi != nil {
		return t.PurgeOi
	}
	t.PurgeOi = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi{}
	return t.PurgeOi
}

// GetAreaAddress returns the value of the AreaAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field AreaAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetAreaAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress {
	if t != nil && t.AreaAddress != nil {
		return t.AreaAddress
	}
	return nil
}

// GetAuthentication returns the value of the Authentication struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetAuthentication() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetExtendedIpv4Reachability returns the value of the ExtendedIpv4Reachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field ExtendedIpv4Reachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetExtendedIpv4Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability {
	if t != nil && t.ExtendedIpv4Reachability != nil {
		return t.ExtendedIpv4Reachability
	}
	return nil
}

// GetExtendedIsReachability returns the value of the ExtendedIsReachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field ExtendedIsReachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetExtendedIsReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability {
	if t != nil && t.ExtendedIsReachability != nil {
		return t.ExtendedIsReachability
	}
	return nil
}

// GetHostname returns the value of the Hostname struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Hostname is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetHostname() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname {
	if t != nil && t.Hostname != nil {
		return t.Hostname
	}
	return nil
}

// GetIpv4ExternalReachability returns the value of the Ipv4ExternalReachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv4ExternalReachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv4ExternalReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability {
	if t != nil && t.Ipv4ExternalReachability != nil {
		return t.Ipv4ExternalReachability
	}
	return nil
}

// GetIpv4InterfaceAddresses returns the value of the Ipv4InterfaceAddresses struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv4InterfaceAddresses is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv4InterfaceAddresses() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses {
	if t != nil && t.Ipv4InterfaceAddresses != nil {
		return t.Ipv4InterfaceAddresses
	}
	return nil
}

// GetIpv4InternalReachability returns the value of the Ipv4InternalReachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv4InternalReachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv4InternalReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability {
	if t != nil && t.Ipv4InternalReachability != nil {
		return t.Ipv4InternalReachability
	}
	return nil
}

// GetIpv4TeRouterId returns the value of the Ipv4TeRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv4TeRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv4TeRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId {
	if t != nil && t.Ipv4TeRouterId != nil {
		return t.Ipv4TeRouterId
	}
	return nil
}

// GetIpv6InterfaceAddresses returns the value of the Ipv6InterfaceAddresses struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv6InterfaceAddresses is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv6InterfaceAddresses() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses {
	if t != nil && t.Ipv6InterfaceAddresses != nil {
		return t.Ipv6InterfaceAddresses
	}
	return nil
}

// GetIpv6Reachability returns the value of the Ipv6Reachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv6Reachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv6Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability {
	if t != nil && t.Ipv6Reachability != nil {
		return t.Ipv6Reachability
	}
	return nil
}

// GetIpv6TeRouterId returns the value of the Ipv6TeRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Ipv6TeRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIpv6TeRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId {
	if t != nil && t.Ipv6TeRouterId != nil {
		return t.Ipv6TeRouterId
	}
	return nil
}

// GetIsAliasId returns the value of the IsAliasId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field IsAliasId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIsAliasId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId {
	if t != nil && t.IsAliasId != nil {
		return t.IsAliasId
	}
	return nil
}

// GetIsReachability returns the value of the IsReachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field IsReachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIsReachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability {
	if t != nil && t.IsReachability != nil {
		return t.IsReachability
	}
	return nil
}

// GetIsisNeighborAttribute returns the value of the IsisNeighborAttribute struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field IsisNeighborAttribute is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetIsisNeighborAttribute() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute {
	if t != nil && t.IsisNeighborAttribute != nil {
		return t.IsisNeighborAttribute
	}
	return nil
}

// GetLspBufferSize returns the value of the LspBufferSize struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field LspBufferSize is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetLspBufferSize() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize {
	if t != nil && t.LspBufferSize != nil {
		return t.LspBufferSize
	}
	return nil
}

// GetMtIpv4Reachability returns the value of the MtIpv4Reachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field MtIpv4Reachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetMtIpv4Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability {
	if t != nil && t.MtIpv4Reachability != nil {
		return t.MtIpv4Reachability
	}
	return nil
}

// GetMtIpv6Reachability returns the value of the MtIpv6Reachability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field MtIpv6Reachability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetMtIpv6Reachability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability {
	if t != nil && t.MtIpv6Reachability != nil {
		return t.MtIpv6Reachability
	}
	return nil
}

// GetMtIsisNeighborAttribute returns the value of the MtIsisNeighborAttribute struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field MtIsisNeighborAttribute is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetMtIsisNeighborAttribute() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute {
	if t != nil && t.MtIsisNeighborAttribute != nil {
		return t.MtIsisNeighborAttribute
	}
	return nil
}

// GetMtIsn returns the value of the MtIsn struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field MtIsn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetMtIsn() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn {
	if t != nil && t.MtIsn != nil {
		return t.MtIsn
	}
	return nil
}

// GetMultiTopology returns the value of the MultiTopology struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field MultiTopology is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetMultiTopology() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology {
	if t != nil && t.MultiTopology != nil {
		return t.MultiTopology
	}
	return nil
}

// GetNlpid returns the value of the Nlpid struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field Nlpid is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetNlpid() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid {
	if t != nil && t.Nlpid != nil {
		return t.Nlpid
	}
	return nil
}

// GetPurgeOi returns the value of the PurgeOi struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv. If the receiver or the field PurgeOi is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetPurgeOi() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi {
	if t != nil && t.PurgeOi != nil {
		return t.PurgeOi
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/area-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_AreaAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/authentication YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication struct {
	ΛMetadata          []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	AuthenticationKey  *string                     `path:"state/authentication-key" module:"openconfig-network-instance"`
	ΛAuthenticationKey []ygot.Annotation           `path:"state/@authentication-key" ygotAnnotation:"true"`
	CryptoType         E_Authentication_CryptoType `path:"state/crypto-type" module:"openconfig-network-instance"`
	ΛCryptoType        []ygot.Annotation           `path:"state/@crypto-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication) IsYANGGoStruct() {}

// GetAuthenticationKey retrieves the value of the leaf AuthenticationKey from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationKey is set, it can safely use t.GetAuthenticationKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationKey == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication) GetAuthenticationKey() string {
	if t == nil || t.AuthenticationKey == nil {
		return ""
	}
	return *t.AuthenticationKey
}

// GetCryptoType retrieves the value of the leaf CryptoType from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CryptoType is set, it can safely use t.GetCryptoType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CryptoType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication) GetCryptoType() E_Authentication_CryptoType {
	if t == nil || t.CryptoType == 0 {
		return 0
	}
	return t.CryptoType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct {
	ΛMetadata        []ygot.Annotation                                                                                             `path:"@" ygotAnnotation:"true"`
	Flags            []E_Capability_Flags                                                                                          `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags           []ygot.Annotation                                                                                             `path:"state/@flags" ygotAnnotation:"true"`
	InstanceNumber   *uint32                                                                                                       `path:"state/instance-number|instance-number" module:"openconfig-network-instance"`
	ΛInstanceNumber  []ygot.Annotation                                                                                             `path:"state/@instance-number|@instance-number" ygotAnnotation:"true"`
	RouterId         *string                                                                                                       `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId        []ygot.Annotation                                                                                             `path:"state/@router-id" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                             `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                             `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetFlags() []E_Capability_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetInstanceNumber retrieves the value of the leaf InstanceNumber from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstanceNumber is set, it can safely use t.GetInstanceNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstanceNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetInstanceNumber() uint32 {
	if t == nil || t.InstanceNumber == nil {
		return 0
	}
	return *t.InstanceNumber
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceNumber == nil {
		return nil, fmt.Errorf("nil value for key InstanceNumber")
	}

	return map[string]interface{}{
		"instance-number": *t.InstanceNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv struct {
	ΛMetadata                 []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	SegmentRoutingAlgorithms  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms `path:"segment-routing-algorithms" module:"openconfig-network-instance"`
	ΛSegmentRoutingAlgorithms []ygot.Annotation                                                                       `path:"@segment-routing-algorithms" ygotAnnotation:"true"`
	SegmentRoutingCapability  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability `path:"segment-routing-capability" module:"openconfig-network-instance"`
	ΛSegmentRoutingCapability []ygot.Annotation                                                                       `path:"@segment-routing-capability" ygotAnnotation:"true"`
	Type                      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                              `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType                     []ygot.Annotation                                                                       `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) IsYANGGoStruct() {}

// GetOrCreateSegmentRoutingAlgorithms retrieves the value of the SegmentRoutingAlgorithms field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) GetOrCreateSegmentRoutingAlgorithms() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms {
	if t.SegmentRoutingAlgorithms != nil {
		return t.SegmentRoutingAlgorithms
	}
	t.SegmentRoutingAlgorithms = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms{}
	return t.SegmentRoutingAlgorithms
}

// GetOrCreateSegmentRoutingCapability retrieves the value of the SegmentRoutingCapability field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) GetOrCreateSegmentRoutingCapability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability {
	if t.SegmentRoutingCapability != nil {
		return t.SegmentRoutingCapability
	}
	t.SegmentRoutingCapability = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability{}
	return t.SegmentRoutingCapability
}

// GetSegmentRoutingAlgorithms returns the value of the SegmentRoutingAlgorithms struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv. If the receiver or the field SegmentRoutingAlgorithms is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) GetSegmentRoutingAlgorithms() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms {
	if t != nil && t.SegmentRoutingAlgorithms != nil {
		return t.SegmentRoutingAlgorithms
	}
	return nil
}

// GetSegmentRoutingCapability returns the value of the SegmentRoutingCapability struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv. If the receiver or the field SegmentRoutingCapability is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) GetSegmentRoutingCapability() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability {
	if t != nil && t.SegmentRoutingCapability != nil {
		return t.SegmentRoutingCapability
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-algorithms YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms struct {
	ΛMetadata  []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Algorithm  []E_SegmentRoutingAlgorithms_Algorithm `path:"state/algorithm" module:"openconfig-network-instance"`
	ΛAlgorithm []ygot.Annotation                      `path:"state/@algorithm" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms) IsYANGGoStruct() {
}

// GetAlgorithm retrieves the value of the leaf Algorithm from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Algorithm is set, it can safely use t.GetAlgorithm()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Algorithm == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms) GetAlgorithm() []E_SegmentRoutingAlgorithms_Algorithm {
	if t == nil || t.Algorithm == nil {
		return nil
	}
	return t.Algorithm
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingAlgorithms) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability struct {
	ΛMetadata       []ygot.Annotation                                                                                                 `path:"@" ygotAnnotation:"true"`
	Flags           []E_SegmentRoutingCapability_Flags                                                                                `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags          []ygot.Annotation                                                                                                 `path:"state/@flags" ygotAnnotation:"true"`
	SrgbDescriptor  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor `path:"srgb-descriptors/srgb-descriptor" module:"openconfig-network-instance"`
	ΛSrgbDescriptor []ygot.Annotation                                                                                                 `path:"srgb-descriptors/@srgb-descriptor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) IsYANGGoStruct() {
}

// NewSrgbDescriptor creates a new entry in the SrgbDescriptor list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) NewSrgbDescriptor(Range uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SrgbDescriptor == nil {
		t.SrgbDescriptor = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor)
	}

	key := Range

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SrgbDescriptor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SrgbDescriptor", key)
	}

	t.SrgbDescriptor[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor{
		Range: &Range,
	}

	return t.SrgbDescriptor[key], nil
}

// RenameSrgbDescriptor renames an entry in the list SrgbDescriptor within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) RenameSrgbDescriptor(oldK, newK uint32) error {
	if _, ok := t.SrgbDescriptor[newK]; ok {
		return fmt.Errorf("key %v already exists in SrgbDescriptor", newK)
	}

	e, ok := t.SrgbDescriptor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SrgbDescriptor", oldK)
	}
	e.Range = &newK

	t.SrgbDescriptor[newK] = e
	delete(t.SrgbDescriptor, oldK)
	return nil
}

// GetOrCreateSrgbDescriptor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) GetOrCreateSrgbDescriptor(Range uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor {

	key := Range

	if v, ok := t.SrgbDescriptor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSrgbDescriptor(Range)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSrgbDescriptor got unexpected error: %v", err))
	}
	return v
}

// GetSrgbDescriptor retrieves the value with the specified key from
// the SrgbDescriptor map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) GetSrgbDescriptor(Range uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor {

	if t == nil {
		return nil
	}

	key := Range

	if lm, ok := t.SrgbDescriptor[key]; ok {
		return lm
	}
	return nil
}

// AppendSrgbDescriptor appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor struct to the
// list SrgbDescriptor of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) AppendSrgbDescriptor(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) error {
	if v.Range == nil {
		return fmt.Errorf("invalid nil key received for Range")
	}

	key := *v.Range

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SrgbDescriptor == nil {
		t.SrgbDescriptor = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor)
	}

	if _, ok := t.SrgbDescriptor[key]; ok {
		return fmt.Errorf("duplicate key for list SrgbDescriptor %v", key)
	}

	t.SrgbDescriptor[key] = v
	return nil
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) GetFlags() []E_SegmentRoutingCapability_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor struct {
	ΛMetadata []ygot.Annotation                                                                                                 `path:"@" ygotAnnotation:"true"`
	Label     NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union `path:"state/label" module:"openconfig-network-instance"`
	ΛLabel    []ygot.Annotation                                                                                                 `path:"state/@label" ygotAnnotation:"true"`
	Range     *uint32                                                                                                           `path:"state/range|range" module:"openconfig-network-instance"`
	ΛRange    []ygot.Annotation                                                                                                 `path:"state/@range|@range" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) IsYANGGoStruct() {
}

// GetLabel retrieves the value of the leaf Label from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Label is set, it can safely use t.GetLabel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Label == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) GetLabel() NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union {
	if t == nil || t.Label == nil {
		return nil
	}
	return t.Label
}

// GetRange retrieves the value of the leaf Range from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Range is set, it can safely use t.GetRange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Range == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) GetRange() uint32 {
	if t == nil || t.Range == nil {
		return 0
	}
	return *t.Range
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Range == nil {
		return nil, fmt.Errorf("nil value for key Range")
	}

	return map[string]interface{}{
		"range": *t.Range,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state/label within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union()
}

// Documentation_for_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union() {
}

// To_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor) To_NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union(i interface{}) (NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_Subtlv_SegmentRoutingCapability_SrgbDescriptor_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) IsYANGGoStruct() {}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Capability_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability struct {
	ΛMetadata []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	Prefix    map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix `path:"prefixes/prefix" module:"openconfig-network-instance"`
	ΛPrefix   []ygot.Annotation                                                                       `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) IsYANGGoStruct() {}

// NewPrefix creates a new entry in the Prefix list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) NewPrefix(Prefix string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) RenamePrefix(oldK, newK string) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.Prefix = &newK

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) GetOrCreatePrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix {

	key := Prefix

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) GetPrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct to the
// list Prefix of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) AppendPrefix(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct {
	ΛMetadata        []ygot.Annotation                                                                                                                  `path:"@" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                            `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                                  `path:"state/@metric" ygotAnnotation:"true"`
	Prefix           *string                                                                                                                            `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix          []ygot.Annotation                                                                                                                  `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SBit             *bool                                                                                                                              `path:"state/s-bit" module:"openconfig-network-instance"`
	ΛSBit            []ygot.Annotation                                                                                                                  `path:"state/@s-bit" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                                  `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                                  `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
	UpDown           *bool                                                                                                                              `path:"state/up-down" module:"openconfig-network-instance"`
	ΛUpDown          []ygot.Annotation                                                                                                                  `path:"state/@up-down" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSBit retrieves the value of the leaf SBit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SBit is set, it can safely use t.GetSBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetSBit() bool {
	if t == nil || t.SBit == nil {
		return false
	}
	return *t.SBit
}

// GetUpDown retrieves the value of the leaf UpDown from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDown is set, it can safely use t.GetUpDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) GetUpDown() bool {
	if t == nil || t.UpDown == nil {
		return false
	}
	return *t.UpDown
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv struct {
	ΛMetadata           []ygot.Annotation                                                                                        `path:"@" ygotAnnotation:"true"`
	Flags               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags                `path:"flags" module:"openconfig-network-instance"`
	ΛFlags              []ygot.Annotation                                                                                        `path:"@flags" ygotAnnotation:"true"`
	Ipv4SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId   `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	ΛIpv4SourceRouterId []ygot.Annotation                                                                                        `path:"@ipv4-source-router-id" ygotAnnotation:"true"`
	Ipv6SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId   `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	ΛIpv6SourceRouterId []ygot.Annotation                                                                                        `path:"@ipv6-source-router-id" ygotAnnotation:"true"`
	PrefixSid           map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid `path:"prefix-sids/prefix-sid" module:"openconfig-network-instance"`
	ΛPrefixSid          []ygot.Annotation                                                                                        `path:"prefix-sids/@prefix-sid" ygotAnnotation:"true"`
	Tag                 *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag                  `path:"tag" module:"openconfig-network-instance"`
	ΛTag                []ygot.Annotation                                                                                        `path:"@tag" ygotAnnotation:"true"`
	Tag64               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64                `path:"tag64" module:"openconfig-network-instance"`
	ΛTag64              []ygot.Annotation                                                                                        `path:"@tag64" ygotAnnotation:"true"`
	Type                E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                               `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                                        `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) NewPrefixSid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// RenamePrefixSid renames an entry in the list PrefixSid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) RenamePrefixSid(oldK, newK uint32) error {
	if _, ok := t.PrefixSid[newK]; ok {
		return fmt.Errorf("key %v already exists in PrefixSid", newK)
	}

	e, ok := t.PrefixSid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PrefixSid", oldK)
	}
	e.Value = &newK

	t.PrefixSid[newK] = e
	delete(t.PrefixSid, oldK)
	return nil
}

// GetOrCreatePrefixSid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetOrCreatePrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid {

	key := Value

	if v, ok := t.PrefixSid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefixSid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefixSid got unexpected error: %v", err))
	}
	return v
}

// GetPrefixSid retrieves the value with the specified key from
// the PrefixSid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetPrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.PrefixSid[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefixSid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid struct to the
// list PrefixSid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) AppendPrefixSid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid)
	}

	if _, ok := t.PrefixSid[key]; ok {
		return fmt.Errorf("duplicate key for list PrefixSid %v", key)
	}

	t.PrefixSid[key] = v
	return nil
}

// GetOrCreateFlags retrieves the value of the Flags field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetOrCreateFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags {
	if t.Flags != nil {
		return t.Flags
	}
	t.Flags = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags{}
	return t.Flags
}

// GetOrCreateIpv4SourceRouterId retrieves the value of the Ipv4SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetOrCreateIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	t.Ipv4SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId{}
	return t.Ipv4SourceRouterId
}

// GetOrCreateIpv6SourceRouterId retrieves the value of the Ipv6SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetOrCreateIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	t.Ipv6SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId{}
	return t.Ipv6SourceRouterId
}

// GetOrCreateTag retrieves the value of the Tag field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetOrCreateTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag {
	if t.Tag != nil {
		return t.Tag
	}
	t.Tag = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag{}
	return t.Tag
}

// GetOrCreateTag64 retrieves the value of the Tag64 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetOrCreateTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64 {
	if t.Tag64 != nil {
		return t.Tag64
	}
	t.Tag64 = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64{}
	return t.Tag64
}

// GetFlags returns the value of the Flags struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the receiver or the field Flags is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags {
	if t != nil && t.Flags != nil {
		return t.Flags
	}
	return nil
}

// GetIpv4SourceRouterId returns the value of the Ipv4SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the receiver or the field Ipv4SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t != nil && t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	return nil
}

// GetIpv6SourceRouterId returns the value of the Ipv6SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the receiver or the field Ipv6SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t != nil && t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	return nil
}

// GetTag returns the value of the Tag struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the receiver or the field Tag is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag {
	if t != nil && t.Tag != nil {
		return t.Tag
	}
	return nil
}

// GetTag64 returns the value of the Tag64 struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv. If the receiver or the field Tag64 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64 {
	if t != nil && t.Tag64 != nil {
		return t.Tag64
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Flags     []E_Flags_Flags                            `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                          `path:"state/@flags" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags) GetFlags() []E_Flags_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid struct {
	ΛMetadata  []ygot.Annotation   `path:"@" ygotAnnotation:"true"`
	Algorithm  *uint8              `path:"state/algorithm" module:"openconfig-network-instance"`
	ΛAlgorithm []ygot.Annotation   `path:"state/@algorithm" ygotAnnotation:"true"`
	Flags      []E_PrefixSid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags     []ygot.Annotation   `path:"state/@flags" ygotAnnotation:"true"`
	Value      *uint32             `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue     []ygot.Annotation   `path:"state/@value|@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) IsYANGGoStruct() {
}

// GetAlgorithm retrieves the value of the leaf Algorithm from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Algorithm is set, it can safely use t.GetAlgorithm()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Algorithm == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) GetAlgorithm() uint8 {
	if t == nil || t.Algorithm == nil {
		return 0
	}
	return *t.Algorithm
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) GetFlags() []E_PrefixSid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag32     []uint32          `path:"state/tag32" module:"openconfig-network-instance"`
	ΛTag32    []ygot.Annotation `path:"state/@tag32" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag) IsYANGGoStruct() {
}

// GetTag32 retrieves the value of the leaf Tag32 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag32 is set, it can safely use t.GetTag32()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag32 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag) GetTag32() []uint32 {
	if t == nil || t.Tag32 == nil {
		return nil
	}
	return t.Tag32
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64 struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag64     []uint64          `path:"state/tag64" module:"openconfig-network-instance"`
	ΛTag64    []ygot.Annotation `path:"state/@tag64" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64) IsYANGGoStruct() {
}

// GetTag64 retrieves the value of the leaf Tag64 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag64 is set, it can safely use t.GetTag64()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag64 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64) GetTag64() []uint64 {
	if t == nil || t.Tag64 == nil {
		return nil
	}
	return t.Tag64
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIpv4Reachability_Prefix_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability struct {
	ΛMetadata []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                                       `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) NewNeighbor(SystemId string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor{
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.SystemId = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) GetOrCreateNeighbor(SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor {

	key := SystemId

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(SystemId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) GetNeighbor(SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor {

	if t == nil {
		return nil
	}

	key := SystemId

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) AppendNeighbor(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) error {
	if v.SystemId == nil {
		return fmt.Errorf("invalid nil key received for SystemId")
	}

	key := *v.SystemId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor struct {
	ΛMetadata []ygot.Annotation                                                                                `path:"@" ygotAnnotation:"true"`
	Instance  map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance `path:"instances/instance" module:"openconfig-network-instance"`
	ΛInstance []ygot.Annotation                                                                                `path:"instances/@instance" ygotAnnotation:"true"`
	SystemId  *string                                                                                          `path:"state/system-id|system-id" module:"openconfig-network-instance"`
	ΛSystemId []ygot.Annotation                                                                                `path:"state/@system-id|@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) IsYANGGoStruct() {
}

// NewInstance creates a new entry in the Instance list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) NewInstance(Id uint64) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// RenameInstance renames an entry in the list Instance within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) RenameInstance(oldK, newK uint64) error {
	if _, ok := t.Instance[newK]; ok {
		return fmt.Errorf("key %v already exists in Instance", newK)
	}

	e, ok := t.Instance[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Instance", oldK)
	}
	e.Id = &newK

	t.Instance[newK] = e
	delete(t.Instance, oldK)
	return nil
}

// GetOrCreateInstance retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) GetOrCreateInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance {

	key := Id

	if v, ok := t.Instance[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInstance(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInstance got unexpected error: %v", err))
	}
	return v
}

// GetInstance retrieves the value with the specified key from
// the Instance map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) GetInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Instance[key]; ok {
		return lm
	}
	return nil
}

// AppendInstance appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct to the
// list Instance of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) AppendInstance(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance)
	}

	if _, ok := t.Instance[key]; ok {
		return fmt.Errorf("duplicate key for list Instance %v", key)
	}

	t.Instance[key] = v
	return nil
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct {
	ΛMetadata        []ygot.Annotation                                                                                                                           `path:"@" ygotAnnotation:"true"`
	Id               *uint64                                                                                                                                     `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId              []ygot.Annotation                                                                                                                           `path:"state/@id|@id" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                                     `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                                           `path:"state/@metric" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                                           `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                                           `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) GetId() uint64 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct {
	ΛMetadata                   []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	AdjacencySid                map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid       `path:"adjacency-sids/adjacency-sid" module:"openconfig-network-instance"`
	ΛAdjacencySid               []ygot.Annotation                                                                                                          `path:"adjacency-sids/@adjacency-sid" ygotAnnotation:"true"`
	AdminGroup                  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup                    `path:"admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup                 []ygot.Annotation                                                                                                          `path:"@admin-group" ygotAnnotation:"true"`
	AvailableBandwidth          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth            `path:"available-bandwidth" module:"openconfig-network-instance"`
	ΛAvailableBandwidth         []ygot.Annotation                                                                                                          `path:"@available-bandwidth" ygotAnnotation:"true"`
	BandwidthConstraint         map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint `path:"bandwidth-constraints/bandwidth-constraint" module:"openconfig-network-instance"`
	ΛBandwidthConstraint        []ygot.Annotation                                                                                                          `path:"bandwidth-constraints/@bandwidth-constraint" ygotAnnotation:"true"`
	ExtendedAdminGroup          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup            `path:"extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup         []ygot.Annotation                                                                                                          `path:"@extended-admin-group" ygotAnnotation:"true"`
	Ipv4InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress          `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	ΛIpv4InterfaceAddress       []ygot.Annotation                                                                                                          `path:"@ipv4-interface-address" ygotAnnotation:"true"`
	Ipv4NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress           `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv4NeighborAddress        []ygot.Annotation                                                                                                          `path:"@ipv4-neighbor-address" ygotAnnotation:"true"`
	Ipv6InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress          `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	ΛIpv6InterfaceAddress       []ygot.Annotation                                                                                                          `path:"@ipv6-interface-address" ygotAnnotation:"true"`
	Ipv6NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress           `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv6NeighborAddress        []ygot.Annotation                                                                                                          `path:"@ipv6-neighbor-address" ygotAnnotation:"true"`
	LanAdjacencySid             map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid    `path:"lan-adjacency-sids/lan-adjacency-sid" module:"openconfig-network-instance"`
	ΛLanAdjacencySid            []ygot.Annotation                                                                                                          `path:"lan-adjacency-sids/@lan-adjacency-sid" ygotAnnotation:"true"`
	LinkAttributes              *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes                `path:"link-attributes" module:"openconfig-network-instance"`
	ΛLinkAttributes             []ygot.Annotation                                                                                                          `path:"@link-attributes" ygotAnnotation:"true"`
	LinkDelay                   *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay                     `path:"link-delay" module:"openconfig-network-instance"`
	ΛLinkDelay                  []ygot.Annotation                                                                                                          `path:"@link-delay" ygotAnnotation:"true"`
	LinkDelayVariation          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation            `path:"link-delay-variation" module:"openconfig-network-instance"`
	ΛLinkDelayVariation         []ygot.Annotation                                                                                                          `path:"@link-delay-variation" ygotAnnotation:"true"`
	LinkId                      *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId                        `path:"link-id" module:"openconfig-network-instance"`
	ΛLinkId                     []ygot.Annotation                                                                                                          `path:"@link-id" ygotAnnotation:"true"`
	LinkLoss                    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss                      `path:"link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss                   []ygot.Annotation                                                                                                          `path:"@link-loss" ygotAnnotation:"true"`
	LinkProtectionType          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType            `path:"link-protection-type" module:"openconfig-network-instance"`
	ΛLinkProtectionType         []ygot.Annotation                                                                                                          `path:"@link-protection-type" ygotAnnotation:"true"`
	MaxLinkBandwidth            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth              `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxLinkBandwidth           []ygot.Annotation                                                                                                          `path:"@max-link-bandwidth" ygotAnnotation:"true"`
	MaxReservableLinkBandwidth  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth    `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxReservableLinkBandwidth []ygot.Annotation                                                                                                          `path:"@max-reservable-link-bandwidth" ygotAnnotation:"true"`
	MinMaxLinkDelay             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay               `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ΛMinMaxLinkDelay            []ygot.Annotation                                                                                                          `path:"@min-max-link-delay" ygotAnnotation:"true"`
	ResidualBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth             `path:"residual-bandwidth" module:"openconfig-network-instance"`
	ΛResidualBandwidth          []ygot.Annotation                                                                                                          `path:"@residual-bandwidth" ygotAnnotation:"true"`
	SetupPriority               map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority       `path:"unreserved-bandwidth/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority              []ygot.Annotation                                                                                                          `path:"unreserved-bandwidth/@setup-priority" ygotAnnotation:"true"`
	TeDefaultMetric             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric               `path:"te-default-metric" module:"openconfig-network-instance"`
	ΛTeDefaultMetric            []ygot.Annotation                                                                                                          `path:"@te-default-metric" ygotAnnotation:"true"`
	Type                        E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                 `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType                       []ygot.Annotation                                                                                                          `path:"state/@type|@type" ygotAnnotation:"true"`
	UnconstrainedLsp            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp              `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	ΛUnconstrainedLsp           []ygot.Annotation                                                                                                          `path:"@unconstrained-lsp" ygotAnnotation:"true"`
	UtilizedBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth             `path:"utilized-bandwidth" module:"openconfig-network-instance"`
	ΛUtilizedBandwidth          []ygot.Annotation                                                                                                          `path:"@utilized-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) NewAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// RenameAdjacencySid renames an entry in the list AdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) RenameAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.AdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in AdjacencySid", newK)
	}

	e, ok := t.AdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdjacencySid", oldK)
	}
	e.Value = &newK

	t.AdjacencySid[newK] = e
	delete(t.AdjacencySid, oldK)
	return nil
}

// GetOrCreateAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid {

	key := Value

	if v, ok := t.AdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetAdjacencySid retrieves the value with the specified key from
// the AdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.AdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid struct to the
// list AdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) AppendAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	if _, ok := t.AdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list AdjacencySid %v", key)
	}

	t.AdjacencySid[key] = v
	return nil
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) NewBandwidthConstraint(ModelId uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// RenameBandwidthConstraint renames an entry in the list BandwidthConstraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) RenameBandwidthConstraint(oldK, newK uint8) error {
	if _, ok := t.BandwidthConstraint[newK]; ok {
		return fmt.Errorf("key %v already exists in BandwidthConstraint", newK)
	}

	e, ok := t.BandwidthConstraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in BandwidthConstraint", oldK)
	}
	e.ModelId = &newK

	t.BandwidthConstraint[newK] = e
	delete(t.BandwidthConstraint, oldK)
	return nil
}

// GetOrCreateBandwidthConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint {

	key := ModelId

	if v, ok := t.BandwidthConstraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewBandwidthConstraint(ModelId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateBandwidthConstraint got unexpected error: %v", err))
	}
	return v
}

// GetBandwidthConstraint retrieves the value with the specified key from
// the BandwidthConstraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint {

	if t == nil {
		return nil
	}

	key := ModelId

	if lm, ok := t.BandwidthConstraint[key]; ok {
		return lm
	}
	return nil
}

// AppendBandwidthConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint struct to the
// list BandwidthConstraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) AppendBandwidthConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) error {
	if v.ModelId == nil {
		return fmt.Errorf("invalid nil key received for ModelId")
	}

	key := *v.ModelId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	if _, ok := t.BandwidthConstraint[key]; ok {
		return fmt.Errorf("duplicate key for list BandwidthConstraint %v", key)
	}

	t.BandwidthConstraint[key] = v
	return nil
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) NewLanAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// RenameLanAdjacencySid renames an entry in the list LanAdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) RenameLanAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.LanAdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in LanAdjacencySid", newK)
	}

	e, ok := t.LanAdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in LanAdjacencySid", oldK)
	}
	e.Value = &newK

	t.LanAdjacencySid[newK] = e
	delete(t.LanAdjacencySid, oldK)
	return nil
}

// GetOrCreateLanAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid {

	key := Value

	if v, ok := t.LanAdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLanAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLanAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetLanAdjacencySid retrieves the value with the specified key from
// the LanAdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.LanAdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendLanAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid struct to the
// list LanAdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) AppendLanAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	if _, ok := t.LanAdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list LanAdjacencySid %v", key)
	}

	t.LanAdjacencySid[key] = v
	return nil
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) NewSetupPriority(Priority uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// RenameSetupPriority renames an entry in the list SetupPriority within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) RenameSetupPriority(oldK, newK uint8) error {
	if _, ok := t.SetupPriority[newK]; ok {
		return fmt.Errorf("key %v already exists in SetupPriority", newK)
	}

	e, ok := t.SetupPriority[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SetupPriority", oldK)
	}
	e.Priority = &newK

	t.SetupPriority[newK] = e
	delete(t.SetupPriority, oldK)
	return nil
}

// GetOrCreateSetupPriority retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority {

	key := Priority

	if v, ok := t.SetupPriority[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSetupPriority(Priority)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSetupPriority got unexpected error: %v", err))
	}
	return v
}

// GetSetupPriority retrieves the value with the specified key from
// the SetupPriority map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority {

	if t == nil {
		return nil
	}

	key := Priority

	if lm, ok := t.SetupPriority[key]; ok {
		return lm
	}
	return nil
}

// AppendSetupPriority appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority struct to the
// list SetupPriority of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) AppendSetupPriority(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) error {
	if v.Priority == nil {
		return fmt.Errorf("invalid nil key received for Priority")
	}

	key := *v.Priority

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority)
	}

	if _, ok := t.SetupPriority[key]; ok {
		return fmt.Errorf("duplicate key for list SetupPriority %v", key)
	}

	t.SetupPriority[key] = v
	return nil
}

// GetOrCreateAdminGroup retrieves the value of the AdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup {
	if t.AdminGroup != nil {
		return t.AdminGroup
	}
	t.AdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup{}
	return t.AdminGroup
}

// GetOrCreateAvailableBandwidth retrieves the value of the AvailableBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	t.AvailableBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth{}
	return t.AvailableBandwidth
}

// GetOrCreateExtendedAdminGroup retrieves the value of the ExtendedAdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	t.ExtendedAdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup{}
	return t.ExtendedAdminGroup
}

// GetOrCreateIpv4InterfaceAddress retrieves the value of the Ipv4InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	t.Ipv4InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress{}
	return t.Ipv4InterfaceAddress
}

// GetOrCreateIpv4NeighborAddress retrieves the value of the Ipv4NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	t.Ipv4NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress{}
	return t.Ipv4NeighborAddress
}

// GetOrCreateIpv6InterfaceAddress retrieves the value of the Ipv6InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	t.Ipv6InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress{}
	return t.Ipv6InterfaceAddress
}

// GetOrCreateIpv6NeighborAddress retrieves the value of the Ipv6NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	t.Ipv6NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress{}
	return t.Ipv6NeighborAddress
}

// GetOrCreateLinkAttributes retrieves the value of the LinkAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes {
	if t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	t.LinkAttributes = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes{}
	return t.LinkAttributes
}

// GetOrCreateLinkDelay retrieves the value of the LinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay {
	if t.LinkDelay != nil {
		return t.LinkDelay
	}
	t.LinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay{}
	return t.LinkDelay
}

// GetOrCreateLinkDelayVariation retrieves the value of the LinkDelayVariation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	t.LinkDelayVariation = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation{}
	return t.LinkDelayVariation
}

// GetOrCreateLinkId retrieves the value of the LinkId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId {
	if t.LinkId != nil {
		return t.LinkId
	}
	t.LinkId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId{}
	return t.LinkId
}

// GetOrCreateLinkLoss retrieves the value of the LinkLoss field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss {
	if t.LinkLoss != nil {
		return t.LinkLoss
	}
	t.LinkLoss = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss{}
	return t.LinkLoss
}

// GetOrCreateLinkProtectionType retrieves the value of the LinkProtectionType field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	t.LinkProtectionType = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType{}
	return t.LinkProtectionType
}

// GetOrCreateMaxLinkBandwidth retrieves the value of the MaxLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	t.MaxLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth{}
	return t.MaxLinkBandwidth
}

// GetOrCreateMaxReservableLinkBandwidth retrieves the value of the MaxReservableLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	t.MaxReservableLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth{}
	return t.MaxReservableLinkBandwidth
}

// GetOrCreateMinMaxLinkDelay retrieves the value of the MinMaxLinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	t.MinMaxLinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay{}
	return t.MinMaxLinkDelay
}

// GetOrCreateResidualBandwidth retrieves the value of the ResidualBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	t.ResidualBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth{}
	return t.ResidualBandwidth
}

// GetOrCreateTeDefaultMetric retrieves the value of the TeDefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	t.TeDefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric{}
	return t.TeDefaultMetric
}

// GetOrCreateUnconstrainedLsp retrieves the value of the UnconstrainedLsp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	t.UnconstrainedLsp = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp{}
	return t.UnconstrainedLsp
}

// GetOrCreateUtilizedBandwidth retrieves the value of the UtilizedBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetOrCreateUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	t.UtilizedBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth{}
	return t.UtilizedBandwidth
}

// GetAdminGroup returns the value of the AdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field AdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup {
	if t != nil && t.AdminGroup != nil {
		return t.AdminGroup
	}
	return nil
}

// GetAvailableBandwidth returns the value of the AvailableBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field AvailableBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t != nil && t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	return nil
}

// GetExtendedAdminGroup returns the value of the ExtendedAdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field ExtendedAdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t != nil && t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	return nil
}

// GetIpv4InterfaceAddress returns the value of the Ipv4InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t != nil && t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	return nil
}

// GetIpv4NeighborAddress returns the value of the Ipv4NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t != nil && t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	return nil
}

// GetIpv6InterfaceAddress returns the value of the Ipv6InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t != nil && t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	return nil
}

// GetIpv6NeighborAddress returns the value of the Ipv6NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t != nil && t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	return nil
}

// GetLinkAttributes returns the value of the LinkAttributes struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field LinkAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes {
	if t != nil && t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	return nil
}

// GetLinkDelay returns the value of the LinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay {
	if t != nil && t.LinkDelay != nil {
		return t.LinkDelay
	}
	return nil
}

// GetLinkDelayVariation returns the value of the LinkDelayVariation struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelayVariation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t != nil && t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	return nil
}

// GetLinkId returns the value of the LinkId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field LinkId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId {
	if t != nil && t.LinkId != nil {
		return t.LinkId
	}
	return nil
}

// GetLinkLoss returns the value of the LinkLoss struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field LinkLoss is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss {
	if t != nil && t.LinkLoss != nil {
		return t.LinkLoss
	}
	return nil
}

// GetLinkProtectionType returns the value of the LinkProtectionType struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field LinkProtectionType is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t != nil && t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	return nil
}

// GetMaxLinkBandwidth returns the value of the MaxLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field MaxLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t != nil && t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	return nil
}

// GetMaxReservableLinkBandwidth returns the value of the MaxReservableLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field MaxReservableLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t != nil && t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	return nil
}

// GetMinMaxLinkDelay returns the value of the MinMaxLinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field MinMaxLinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t != nil && t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	return nil
}

// GetResidualBandwidth returns the value of the ResidualBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field ResidualBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t != nil && t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	return nil
}

// GetTeDefaultMetric returns the value of the TeDefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field TeDefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t != nil && t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	return nil
}

// GetUnconstrainedLsp returns the value of the UnconstrainedLsp struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field UnconstrainedLsp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t != nil && t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	return nil
}

// GetUtilizedBandwidth returns the value of the UtilizedBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv. If the receiver or the field UtilizedBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t != nil && t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid struct {
	ΛMetadata []ygot.Annotation      `path:"@" ygotAnnotation:"true"`
	Flags     []E_AdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation      `path:"state/@flags" ygotAnnotation:"true"`
	Value     *uint32                `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation      `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight    *uint8                 `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight   []ygot.Annotation      `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) GetFlags() []E_AdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdminGroup  []uint32          `path:"state/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup []ygot.Annotation `path:"state/@admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// GetAdminGroup retrieves the value of the leaf AdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminGroup is set, it can safely use t.GetAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup) GetAdminGroup() []uint32 {
	if t == nil || t.AdminGroup == nil {
		return nil
	}
	return t.AdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint struct {
	ΛMetadata   []ygot.Annotation                                                                                                                      `path:"@" ygotAnnotation:"true"`
	Constraint  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint `path:"constraints/constraint" module:"openconfig-network-instance"`
	ΛConstraint []ygot.Annotation                                                                                                                      `path:"constraints/@constraint" ygotAnnotation:"true"`
	ModelId     *uint8                                                                                                                                 `path:"state/model-id|model-id" module:"openconfig-network-instance"`
	ΛModelId    []ygot.Annotation                                                                                                                      `path:"state/@model-id|@model-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) NewConstraint(ConstraintId uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// RenameConstraint renames an entry in the list Constraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) RenameConstraint(oldK, newK uint32) error {
	if _, ok := t.Constraint[newK]; ok {
		return fmt.Errorf("key %v already exists in Constraint", newK)
	}

	e, ok := t.Constraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Constraint", oldK)
	}
	e.ConstraintId = &newK

	t.Constraint[newK] = e
	delete(t.Constraint, oldK)
	return nil
}

// GetOrCreateConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) GetOrCreateConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	key := ConstraintId

	if v, ok := t.Constraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewConstraint(ConstraintId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateConstraint got unexpected error: %v", err))
	}
	return v
}

// GetConstraint retrieves the value with the specified key from
// the Constraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) GetConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	if t == nil {
		return nil
	}

	key := ConstraintId

	if lm, ok := t.Constraint[key]; ok {
		return lm
	}
	return nil
}

// AppendConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct to the
// list Constraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) AppendConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) error {
	if v.ConstraintId == nil {
		return fmt.Errorf("invalid nil key received for ConstraintId")
	}

	key := *v.ConstraintId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	if _, ok := t.Constraint[key]; ok {
		return fmt.Errorf("duplicate key for list Constraint %v", key)
	}

	t.Constraint[key] = v
	return nil
}

// GetModelId retrieves the value of the leaf ModelId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ModelId is set, it can safely use t.GetModelId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ModelId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) GetModelId() uint8 {
	if t == nil || t.ModelId == nil {
		return 0
	}
	return *t.ModelId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth     Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth    []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	ConstraintId  *uint32           `path:"state/constraint-id|constraint-id" module:"openconfig-network-instance"`
	ΛConstraintId []ygot.Annotation `path:"state/@constraint-id|@constraint-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetConstraintId retrieves the value of the leaf ConstraintId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConstraintId is set, it can safely use t.GetConstraintId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConstraintId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetConstraintId() uint32 {
	if t == nil || t.ConstraintId == nil {
		return 0
	}
	return *t.ConstraintId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExtendedAdminGroup  []uint32          `path:"state/extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup []ygot.Annotation `path:"state/@extended-admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// GetExtendedAdminGroup retrieves the value of the leaf ExtendedAdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtendedAdminGroup is set, it can safely use t.GetExtendedAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtendedAdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup) GetExtendedAdminGroup() []uint32 {
	if t == nil || t.ExtendedAdminGroup == nil {
		return nil
	}
	return t.ExtendedAdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid struct {
	ΛMetadata   []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Flags       []E_LanAdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags      []ygot.Annotation         `path:"state/@flags" ygotAnnotation:"true"`
	NeighborId  *string                   `path:"state/neighbor-id" module:"openconfig-network-instance"`
	ΛNeighborId []ygot.Annotation         `path:"state/@neighbor-id" ygotAnnotation:"true"`
	Value       *uint32                   `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue      []ygot.Annotation         `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight      *uint8                    `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight     []ygot.Annotation         `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) GetFlags() []E_LanAdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetNeighborId retrieves the value of the leaf NeighborId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborId is set, it can safely use t.GetNeighborId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) GetNeighborId() string {
	if t == nil || t.NeighborId == nil {
		return ""
	}
	return *t.NeighborId
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes struct {
	ΛMetadata        []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	LocalProtection  []E_LinkAttributes_LocalProtection `path:"state/local-protection" module:"openconfig-network-instance"`
	ΛLocalProtection []ygot.Annotation                  `path:"state/@local-protection" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// GetLocalProtection retrieves the value of the leaf LocalProtection from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalProtection is set, it can safely use t.GetLocalProtection()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalProtection == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes) GetLocalProtection() []E_LinkAttributes_LocalProtection {
	if t == nil || t.LocalProtection == nil {
		return nil
	}
	return t.LocalProtection
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Local     *uint32           `path:"state/local" module:"openconfig-network-instance"`
	ΛLocal    []ygot.Annotation `path:"state/@local" ygotAnnotation:"true"`
	Remote    *uint32           `path:"state/remote" module:"openconfig-network-instance"`
	ΛRemote   []ygot.Annotation `path:"state/@remote" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId) IsYANGGoStruct() {
}

// GetLocal retrieves the value of the leaf Local from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Local is set, it can safely use t.GetLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Local == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId) GetLocal() uint32 {
	if t == nil || t.Local == nil {
		return 0
	}
	return *t.Local
}

// GetRemote retrieves the value of the leaf Remote from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Remote is set, it can safely use t.GetRemote()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Remote == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId) GetRemote() uint32 {
	if t == nil || t.Remote == nil {
		return 0
	}
	return *t.Remote
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	LinkLoss  *uint32           `path:"state/link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss []ygot.Annotation `path:"state/@link-loss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetLinkLoss retrieves the value of the leaf LinkLoss from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLoss is set, it can safely use t.GetLinkLoss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLoss == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss) GetLinkLoss() uint32 {
	if t == nil || t.LinkLoss == nil {
		return 0
	}
	return *t.LinkLoss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType struct {
	ΛMetadata []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	Type      []E_LinkProtectionType_Type `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation           `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType) GetType() []E_LinkProtectionType_Type {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	MaxDelay  *uint32           `path:"state/max-delay" module:"openconfig-network-instance"`
	ΛMaxDelay []ygot.Annotation `path:"state/@max-delay" ygotAnnotation:"true"`
	MinDelay  *uint32           `path:"state/min-delay" module:"openconfig-network-instance"`
	ΛMinDelay []ygot.Annotation `path:"state/@min-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetMaxDelay retrieves the value of the leaf MaxDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxDelay is set, it can safely use t.GetMaxDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMaxDelay() uint32 {
	if t == nil || t.MaxDelay == nil {
		return 0
	}
	return *t.MaxDelay
}

// GetMinDelay retrieves the value of the leaf MinDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinDelay is set, it can safely use t.GetMinDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMinDelay() uint32 {
	if t == nil || t.MinDelay == nil {
		return 0
	}
	return *t.MinDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	Priority   *uint8            `path:"state/priority|priority" module:"openconfig-network-instance"`
	ΛPriority  []ygot.Annotation `path:"state/@priority|@priority" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint32           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Count     *uint16                                    `path:"state/count" module:"openconfig-network-instance"`
	ΛCount    []ygot.Annotation                          `path:"state/@count" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// GetCount retrieves the value of the leaf Count from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Count is set, it can safely use t.GetCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Count == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetCount() uint16 {
	if t == nil || t.Count == nil {
		return 0
	}
	return *t.Count
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_ExtendedIsReachability_Neighbor_Instance_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/hostname YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Hostname  []string          `path:"state/hostname" module:"openconfig-network-instance"`
	ΛHostname []ygot.Annotation `path:"state/@hostname" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname) IsYANGGoStruct() {}

// GetHostname retrieves the value of the leaf Hostname from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Hostname is set, it can safely use t.GetHostname()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Hostname == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname) GetHostname() []string {
	if t == nil || t.Hostname == nil {
		return nil
	}
	return t.Hostname
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Hostname) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/instance-ids/instance-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InstanceId  *uint16           `path:"state/instance-id|instance-id" module:"openconfig-network-instance"`
	ΛInstanceId []ygot.Annotation `path:"state/@instance-id|@instance-id" ygotAnnotation:"true"`
	TopologyId  []uint16          `path:"state/topology-id" module:"openconfig-network-instance"`
	ΛTopologyId []ygot.Annotation `path:"state/@topology-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) IsYANGGoStruct() {}

// GetInstanceId retrieves the value of the leaf InstanceId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstanceId is set, it can safely use t.GetInstanceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstanceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) GetInstanceId() uint16 {
	if t == nil || t.InstanceId == nil {
		return 0
	}
	return *t.InstanceId
}

// GetTopologyId retrieves the value of the leaf TopologyId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TopologyId is set, it can safely use t.GetTopologyId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TopologyId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) GetTopologyId() []uint16 {
	if t == nil || t.TopologyId == nil {
		return nil
	}
	return t.TopologyId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceId == nil {
		return nil, fmt.Errorf("nil value for key InstanceId")
	}

	return map[string]interface{}{
		"instance-id": *t.InstanceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_InstanceId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability struct {
	ΛMetadata []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	Prefix    map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix `path:"prefixes/prefix" module:"openconfig-network-instance"`
	ΛPrefix   []ygot.Annotation                                                                       `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) IsYANGGoStruct() {}

// NewPrefix creates a new entry in the Prefix list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) NewPrefix(Prefix string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) RenamePrefix(oldK, newK string) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.Prefix = &newK

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) GetOrCreatePrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix {

	key := Prefix

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) GetPrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix struct to the
// list Prefix of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) AppendPrefix(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix struct {
	ΛMetadata      []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	DefaultMetric  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric `path:"default-metric" module:"openconfig-network-instance"`
	ΛDefaultMetric []ygot.Annotation                                                                          `path:"@default-metric" ygotAnnotation:"true"`
	DelayMetric    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric   `path:"delay-metric" module:"openconfig-network-instance"`
	ΛDelayMetric   []ygot.Annotation                                                                          `path:"@delay-metric" ygotAnnotation:"true"`
	ErrorMetric    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric   `path:"error-metric" module:"openconfig-network-instance"`
	ΛErrorMetric   []ygot.Annotation                                                                          `path:"@error-metric" ygotAnnotation:"true"`
	ExpenseMetric  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric `path:"expense-metric" module:"openconfig-network-instance"`
	ΛExpenseMetric []ygot.Annotation                                                                          `path:"@expense-metric" ygotAnnotation:"true"`
	Prefix         *string                                                                                    `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix        []ygot.Annotation                                                                          `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UpDown         *bool                                                                                      `path:"state/up-down" module:"openconfig-network-instance"`
	ΛUpDown        []ygot.Annotation                                                                          `path:"state/@up-down" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) IsYANGGoStruct() {
}

// GetOrCreateDefaultMetric retrieves the value of the DefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetOrCreateDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric {
	if t.DefaultMetric != nil {
		return t.DefaultMetric
	}
	t.DefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric{}
	return t.DefaultMetric
}

// GetOrCreateDelayMetric retrieves the value of the DelayMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetOrCreateDelayMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric {
	if t.DelayMetric != nil {
		return t.DelayMetric
	}
	t.DelayMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric{}
	return t.DelayMetric
}

// GetOrCreateErrorMetric retrieves the value of the ErrorMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetOrCreateErrorMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric {
	if t.ErrorMetric != nil {
		return t.ErrorMetric
	}
	t.ErrorMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric{}
	return t.ErrorMetric
}

// GetOrCreateExpenseMetric retrieves the value of the ExpenseMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetOrCreateExpenseMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric {
	if t.ExpenseMetric != nil {
		return t.ExpenseMetric
	}
	t.ExpenseMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric{}
	return t.ExpenseMetric
}

// GetDefaultMetric returns the value of the DefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix. If the receiver or the field DefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric {
	if t != nil && t.DefaultMetric != nil {
		return t.DefaultMetric
	}
	return nil
}

// GetDelayMetric returns the value of the DelayMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix. If the receiver or the field DelayMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetDelayMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric {
	if t != nil && t.DelayMetric != nil {
		return t.DelayMetric
	}
	return nil
}

// GetErrorMetric returns the value of the ErrorMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix. If the receiver or the field ErrorMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetErrorMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric {
	if t != nil && t.ErrorMetric != nil {
		return t.ErrorMetric
	}
	return nil
}

// GetExpenseMetric returns the value of the ExpenseMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix. If the receiver or the field ExpenseMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetExpenseMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric {
	if t != nil && t.ExpenseMetric != nil {
		return t.ExpenseMetric
	}
	return nil
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetUpDown retrieves the value of the leaf UpDown from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDown is set, it can safely use t.GetUpDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) GetUpDown() bool {
	if t == nil || t.UpDown == nil {
		return false
	}
	return *t.UpDown
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric struct {
	ΛMetadata []ygot.Annotation     `path:"@" ygotAnnotation:"true"`
	Flags     E_DefaultMetric_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation     `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation     `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric) GetFlags() E_DefaultMetric_Flags {
	if t == nil || t.Flags == 0 {
		return 0
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/delay-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_DelayMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/error-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ErrorMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/expense-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4ExternalReachability_Prefix_ExpenseMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-interface-addresses YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InterfaceAddresses) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability struct {
	ΛMetadata []ygot.Annotation                                                                       `path:"@" ygotAnnotation:"true"`
	Prefix    map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix `path:"prefixes/prefix" module:"openconfig-network-instance"`
	ΛPrefix   []ygot.Annotation                                                                       `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) IsYANGGoStruct() {}

// NewPrefix creates a new entry in the Prefix list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) NewPrefix(Prefix string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) RenamePrefix(oldK, newK string) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.Prefix = &newK

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) GetOrCreatePrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix {

	key := Prefix

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) GetPrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix struct to the
// list Prefix of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) AppendPrefix(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix struct {
	ΛMetadata      []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	DefaultMetric  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric `path:"default-metric" module:"openconfig-network-instance"`
	ΛDefaultMetric []ygot.Annotation                                                                          `path:"@default-metric" ygotAnnotation:"true"`
	DelayMetric    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric   `path:"delay-metric" module:"openconfig-network-instance"`
	ΛDelayMetric   []ygot.Annotation                                                                          `path:"@delay-metric" ygotAnnotation:"true"`
	ErrorMetric    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric   `path:"error-metric" module:"openconfig-network-instance"`
	ΛErrorMetric   []ygot.Annotation                                                                          `path:"@error-metric" ygotAnnotation:"true"`
	ExpenseMetric  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric `path:"expense-metric" module:"openconfig-network-instance"`
	ΛExpenseMetric []ygot.Annotation                                                                          `path:"@expense-metric" ygotAnnotation:"true"`
	Prefix         *string                                                                                    `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix        []ygot.Annotation                                                                          `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	UpDown         *bool                                                                                      `path:"state/up-down" module:"openconfig-network-instance"`
	ΛUpDown        []ygot.Annotation                                                                          `path:"state/@up-down" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) IsYANGGoStruct() {
}

// GetOrCreateDefaultMetric retrieves the value of the DefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetOrCreateDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric {
	if t.DefaultMetric != nil {
		return t.DefaultMetric
	}
	t.DefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric{}
	return t.DefaultMetric
}

// GetOrCreateDelayMetric retrieves the value of the DelayMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetOrCreateDelayMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric {
	if t.DelayMetric != nil {
		return t.DelayMetric
	}
	t.DelayMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric{}
	return t.DelayMetric
}

// GetOrCreateErrorMetric retrieves the value of the ErrorMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetOrCreateErrorMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric {
	if t.ErrorMetric != nil {
		return t.ErrorMetric
	}
	t.ErrorMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric{}
	return t.ErrorMetric
}

// GetOrCreateExpenseMetric retrieves the value of the ExpenseMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetOrCreateExpenseMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric {
	if t.ExpenseMetric != nil {
		return t.ExpenseMetric
	}
	t.ExpenseMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric{}
	return t.ExpenseMetric
}

// GetDefaultMetric returns the value of the DefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix. If the receiver or the field DefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric {
	if t != nil && t.DefaultMetric != nil {
		return t.DefaultMetric
	}
	return nil
}

// GetDelayMetric returns the value of the DelayMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix. If the receiver or the field DelayMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetDelayMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric {
	if t != nil && t.DelayMetric != nil {
		return t.DelayMetric
	}
	return nil
}

// GetErrorMetric returns the value of the ErrorMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix. If the receiver or the field ErrorMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetErrorMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric {
	if t != nil && t.ErrorMetric != nil {
		return t.ErrorMetric
	}
	return nil
}

// GetExpenseMetric returns the value of the ExpenseMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix. If the receiver or the field ExpenseMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetExpenseMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric {
	if t != nil && t.ExpenseMetric != nil {
		return t.ExpenseMetric
	}
	return nil
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetUpDown retrieves the value of the leaf UpDown from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDown is set, it can safely use t.GetUpDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) GetUpDown() bool {
	if t == nil || t.UpDown == nil {
		return false
	}
	return *t.UpDown
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric struct {
	ΛMetadata []ygot.Annotation     `path:"@" ygotAnnotation:"true"`
	Flags     E_DefaultMetric_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation     `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation     `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric) GetFlags() E_DefaultMetric_Flags {
	if t == nil || t.Flags == 0 {
		return 0
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/delay-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_DelayMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/error-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ErrorMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/expense-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4InternalReachability_Prefix_ExpenseMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-srlgs/ipv4-srlg YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg struct {
	ΛMetadata             []ygot.Annotation  `path:"@" ygotAnnotation:"true"`
	Flags                 []E_Ipv4Srlg_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags                []ygot.Annotation  `path:"state/@flags" ygotAnnotation:"true"`
	InstanceNumber        *uint32            `path:"state/instance-number|instance-number" module:"openconfig-network-instance"`
	ΛInstanceNumber       []ygot.Annotation  `path:"state/@instance-number|@instance-number" ygotAnnotation:"true"`
	Ipv4InterfaceAddress  *string            `path:"state/ipv4-interface-address" module:"openconfig-network-instance"`
	ΛIpv4InterfaceAddress []ygot.Annotation  `path:"state/@ipv4-interface-address" ygotAnnotation:"true"`
	Ipv4NeighborAddress   *string            `path:"state/ipv4-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv4NeighborAddress  []ygot.Annotation  `path:"state/@ipv4-neighbor-address" ygotAnnotation:"true"`
	PsnNumber             *uint8             `path:"state/psn-number" module:"openconfig-network-instance"`
	ΛPsnNumber            []ygot.Annotation  `path:"state/@psn-number" ygotAnnotation:"true"`
	SrlgValue             []uint32           `path:"state/srlg-value" module:"openconfig-network-instance"`
	ΛSrlgValue            []ygot.Annotation  `path:"state/@srlg-value" ygotAnnotation:"true"`
	SystemId              *string            `path:"state/system-id" module:"openconfig-network-instance"`
	ΛSystemId             []ygot.Annotation  `path:"state/@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) IsYANGGoStruct() {}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetFlags() []E_Ipv4Srlg_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetInstanceNumber retrieves the value of the leaf InstanceNumber from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstanceNumber is set, it can safely use t.GetInstanceNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstanceNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetInstanceNumber() uint32 {
	if t == nil || t.InstanceNumber == nil {
		return 0
	}
	return *t.InstanceNumber
}

// GetIpv4InterfaceAddress retrieves the value of the leaf Ipv4InterfaceAddress from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv4InterfaceAddress is set, it can safely use t.GetIpv4InterfaceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv4InterfaceAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetIpv4InterfaceAddress() string {
	if t == nil || t.Ipv4InterfaceAddress == nil {
		return ""
	}
	return *t.Ipv4InterfaceAddress
}

// GetIpv4NeighborAddress retrieves the value of the leaf Ipv4NeighborAddress from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv4NeighborAddress is set, it can safely use t.GetIpv4NeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv4NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetIpv4NeighborAddress() string {
	if t == nil || t.Ipv4NeighborAddress == nil {
		return ""
	}
	return *t.Ipv4NeighborAddress
}

// GetPsnNumber retrieves the value of the leaf PsnNumber from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PsnNumber is set, it can safely use t.GetPsnNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PsnNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetPsnNumber() uint8 {
	if t == nil || t.PsnNumber == nil {
		return 0
	}
	return *t.PsnNumber
}

// GetSrlgValue retrieves the value of the leaf SrlgValue from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SrlgValue is set, it can safely use t.GetSrlgValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SrlgValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetSrlgValue() []uint32 {
	if t == nil || t.SrlgValue == nil {
		return nil
	}
	return t.SrlgValue
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceNumber == nil {
		return nil, fmt.Errorf("nil value for key InstanceNumber")
	}

	return map[string]interface{}{
		"instance-number": *t.InstanceNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4Srlg) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-te-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	RouterId  []string          `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation `path:"state/@router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId) IsYANGGoStruct() {}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId) GetRouterId() []string {
	if t == nil || t.RouterId == nil {
		return nil
	}
	return t.RouterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv4TeRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-interface-addresses YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6InterfaceAddresses) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability struct {
	ΛMetadata []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	Prefix    map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix `path:"prefixes/prefix" module:"openconfig-network-instance"`
	ΛPrefix   []ygot.Annotation                                                               `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) IsYANGGoStruct() {}

// NewPrefix creates a new entry in the Prefix list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) NewPrefix(Prefix string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) RenamePrefix(oldK, newK string) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.Prefix = &newK

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) GetOrCreatePrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix {

	key := Prefix

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) GetPrefix(Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix {

	if t == nil {
		return nil
	}

	key := Prefix

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct to the
// list Prefix of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) AppendPrefix(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key received for Prefix")
	}

	key := *v.Prefix

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct {
	ΛMetadata        []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                    `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                          `path:"state/@metric" ygotAnnotation:"true"`
	Prefix           *string                                                                                                                    `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix          []ygot.Annotation                                                                                                          `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SBit             *bool                                                                                                                      `path:"state/s-bit" module:"openconfig-network-instance"`
	ΛSBit            []ygot.Annotation                                                                                                          `path:"state/@s-bit" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                          `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                          `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
	UpDown           *bool                                                                                                                      `path:"state/up-down" module:"openconfig-network-instance"`
	ΛUpDown          []ygot.Annotation                                                                                                          `path:"state/@up-down" ygotAnnotation:"true"`
	XBit             *bool                                                                                                                      `path:"state/x-bit" module:"openconfig-network-instance"`
	ΛXBit            []ygot.Annotation                                                                                                          `path:"state/@x-bit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSBit retrieves the value of the leaf SBit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SBit is set, it can safely use t.GetSBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetSBit() bool {
	if t == nil || t.SBit == nil {
		return false
	}
	return *t.SBit
}

// GetUpDown retrieves the value of the leaf UpDown from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDown is set, it can safely use t.GetUpDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetUpDown() bool {
	if t == nil || t.UpDown == nil {
		return false
	}
	return *t.UpDown
}

// GetXBit retrieves the value of the leaf XBit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if XBit is set, it can safely use t.GetXBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.XBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) GetXBit() bool {
	if t == nil || t.XBit == nil {
		return false
	}
	return *t.XBit
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv struct {
	ΛMetadata           []ygot.Annotation                                                                                `path:"@" ygotAnnotation:"true"`
	Flags               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags                `path:"flags" module:"openconfig-network-instance"`
	ΛFlags              []ygot.Annotation                                                                                `path:"@flags" ygotAnnotation:"true"`
	Ipv4SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId   `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	ΛIpv4SourceRouterId []ygot.Annotation                                                                                `path:"@ipv4-source-router-id" ygotAnnotation:"true"`
	Ipv6SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId   `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	ΛIpv6SourceRouterId []ygot.Annotation                                                                                `path:"@ipv6-source-router-id" ygotAnnotation:"true"`
	PrefixSid           map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid `path:"prefix-sids/prefix-sid" module:"openconfig-network-instance"`
	ΛPrefixSid          []ygot.Annotation                                                                                `path:"prefix-sids/@prefix-sid" ygotAnnotation:"true"`
	Tag                 *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag                  `path:"tag" module:"openconfig-network-instance"`
	ΛTag                []ygot.Annotation                                                                                `path:"@tag" ygotAnnotation:"true"`
	Tag64               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64                `path:"tag64" module:"openconfig-network-instance"`
	ΛTag64              []ygot.Annotation                                                                                `path:"@tag64" ygotAnnotation:"true"`
	Type                E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                       `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                                `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) IsYANGGoStruct() {}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) NewPrefixSid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// RenamePrefixSid renames an entry in the list PrefixSid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) RenamePrefixSid(oldK, newK uint32) error {
	if _, ok := t.PrefixSid[newK]; ok {
		return fmt.Errorf("key %v already exists in PrefixSid", newK)
	}

	e, ok := t.PrefixSid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PrefixSid", oldK)
	}
	e.Value = &newK

	t.PrefixSid[newK] = e
	delete(t.PrefixSid, oldK)
	return nil
}

// GetOrCreatePrefixSid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetOrCreatePrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid {

	key := Value

	if v, ok := t.PrefixSid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefixSid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefixSid got unexpected error: %v", err))
	}
	return v
}

// GetPrefixSid retrieves the value with the specified key from
// the PrefixSid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetPrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.PrefixSid[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefixSid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid struct to the
// list PrefixSid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) AppendPrefixSid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid)
	}

	if _, ok := t.PrefixSid[key]; ok {
		return fmt.Errorf("duplicate key for list PrefixSid %v", key)
	}

	t.PrefixSid[key] = v
	return nil
}

// GetOrCreateFlags retrieves the value of the Flags field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetOrCreateFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags {
	if t.Flags != nil {
		return t.Flags
	}
	t.Flags = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags{}
	return t.Flags
}

// GetOrCreateIpv4SourceRouterId retrieves the value of the Ipv4SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetOrCreateIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	t.Ipv4SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId{}
	return t.Ipv4SourceRouterId
}

// GetOrCreateIpv6SourceRouterId retrieves the value of the Ipv6SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetOrCreateIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	t.Ipv6SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId{}
	return t.Ipv6SourceRouterId
}

// GetOrCreateTag retrieves the value of the Tag field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetOrCreateTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag {
	if t.Tag != nil {
		return t.Tag
	}
	t.Tag = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag{}
	return t.Tag
}

// GetOrCreateTag64 retrieves the value of the Tag64 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetOrCreateTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64 {
	if t.Tag64 != nil {
		return t.Tag64
	}
	t.Tag64 = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64{}
	return t.Tag64
}

// GetFlags returns the value of the Flags struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the receiver or the field Flags is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags {
	if t != nil && t.Flags != nil {
		return t.Flags
	}
	return nil
}

// GetIpv4SourceRouterId returns the value of the Ipv4SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the receiver or the field Ipv4SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t != nil && t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	return nil
}

// GetIpv6SourceRouterId returns the value of the Ipv6SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the receiver or the field Ipv6SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t != nil && t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	return nil
}

// GetTag returns the value of the Tag struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the receiver or the field Tag is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag {
	if t != nil && t.Tag != nil {
		return t.Tag
	}
	return nil
}

// GetTag64 returns the value of the Tag64 struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv. If the receiver or the field Tag64 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64 {
	if t != nil && t.Tag64 != nil {
		return t.Tag64
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Flags     []E_Flags_Flags                            `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                          `path:"state/@flags" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags) GetFlags() []E_Flags_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid struct {
	ΛMetadata  []ygot.Annotation   `path:"@" ygotAnnotation:"true"`
	Algorithm  *uint8              `path:"state/algorithm" module:"openconfig-network-instance"`
	ΛAlgorithm []ygot.Annotation   `path:"state/@algorithm" ygotAnnotation:"true"`
	Flags      []E_PrefixSid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags     []ygot.Annotation   `path:"state/@flags" ygotAnnotation:"true"`
	Value      *uint32             `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue     []ygot.Annotation   `path:"state/@value|@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) IsYANGGoStruct() {
}

// GetAlgorithm retrieves the value of the leaf Algorithm from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Algorithm is set, it can safely use t.GetAlgorithm()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Algorithm == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) GetAlgorithm() uint8 {
	if t == nil || t.Algorithm == nil {
		return 0
	}
	return *t.Algorithm
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) GetFlags() []E_PrefixSid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag32     []uint32          `path:"state/tag32" module:"openconfig-network-instance"`
	ΛTag32    []ygot.Annotation `path:"state/@tag32" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag) IsYANGGoStruct() {
}

// GetTag32 retrieves the value of the leaf Tag32 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag32 is set, it can safely use t.GetTag32()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag32 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag) GetTag32() []uint32 {
	if t == nil || t.Tag32 == nil {
		return nil
	}
	return t.Tag32
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64 struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag64     []uint64          `path:"state/tag64" module:"openconfig-network-instance"`
	ΛTag64    []ygot.Annotation `path:"state/@tag64" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64) IsYANGGoStruct() {
}

// GetTag64 retrieves the value of the leaf Tag64 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag64 is set, it can safely use t.GetTag64()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag64 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64) GetTag64() []uint64 {
	if t == nil || t.Tag64 == nil {
		return nil
	}
	return t.Tag64
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Reachability_Prefix_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-srlgs/ipv6-srlg YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg struct {
	ΛMetadata             []ygot.Annotation  `path:"@" ygotAnnotation:"true"`
	Flags                 []E_Ipv6Srlg_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags                []ygot.Annotation  `path:"state/@flags" ygotAnnotation:"true"`
	InstanceNumber        *uint32            `path:"state/instance-number|instance-number" module:"openconfig-network-instance"`
	ΛInstanceNumber       []ygot.Annotation  `path:"state/@instance-number|@instance-number" ygotAnnotation:"true"`
	Ipv6InterfaceAddress  *string            `path:"state/ipv6-interface-address" module:"openconfig-network-instance"`
	ΛIpv6InterfaceAddress []ygot.Annotation  `path:"state/@ipv6-interface-address" ygotAnnotation:"true"`
	Ipv6NeighborAddress   *string            `path:"state/ipv6-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv6NeighborAddress  []ygot.Annotation  `path:"state/@ipv6-neighbor-address" ygotAnnotation:"true"`
	PsnNumber             *uint8             `path:"state/psn-number" module:"openconfig-network-instance"`
	ΛPsnNumber            []ygot.Annotation  `path:"state/@psn-number" ygotAnnotation:"true"`
	SrlgValue             []uint32           `path:"state/srlg-value" module:"openconfig-network-instance"`
	ΛSrlgValue            []ygot.Annotation  `path:"state/@srlg-value" ygotAnnotation:"true"`
	SystemId              *string            `path:"state/system-id" module:"openconfig-network-instance"`
	ΛSystemId             []ygot.Annotation  `path:"state/@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) IsYANGGoStruct() {}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetFlags() []E_Ipv6Srlg_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetInstanceNumber retrieves the value of the leaf InstanceNumber from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstanceNumber is set, it can safely use t.GetInstanceNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstanceNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetInstanceNumber() uint32 {
	if t == nil || t.InstanceNumber == nil {
		return 0
	}
	return *t.InstanceNumber
}

// GetIpv6InterfaceAddress retrieves the value of the leaf Ipv6InterfaceAddress from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv6InterfaceAddress is set, it can safely use t.GetIpv6InterfaceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv6InterfaceAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetIpv6InterfaceAddress() string {
	if t == nil || t.Ipv6InterfaceAddress == nil {
		return ""
	}
	return *t.Ipv6InterfaceAddress
}

// GetIpv6NeighborAddress retrieves the value of the leaf Ipv6NeighborAddress from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv6NeighborAddress is set, it can safely use t.GetIpv6NeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv6NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetIpv6NeighborAddress() string {
	if t == nil || t.Ipv6NeighborAddress == nil {
		return ""
	}
	return *t.Ipv6NeighborAddress
}

// GetPsnNumber retrieves the value of the leaf PsnNumber from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PsnNumber is set, it can safely use t.GetPsnNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PsnNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetPsnNumber() uint8 {
	if t == nil || t.PsnNumber == nil {
		return 0
	}
	return *t.PsnNumber
}

// GetSrlgValue retrieves the value of the leaf SrlgValue from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SrlgValue is set, it can safely use t.GetSrlgValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SrlgValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetSrlgValue() []uint32 {
	if t == nil || t.SrlgValue == nil {
		return nil
	}
	return t.SrlgValue
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceNumber == nil {
		return nil, fmt.Errorf("nil value for key InstanceNumber")
	}

	return map[string]interface{}{
		"instance-number": *t.InstanceNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6Srlg) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-te-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	RouterId  []string          `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation `path:"state/@router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId) IsYANGGoStruct() {}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId) GetRouterId() []string {
	if t == nil || t.RouterId == nil {
		return nil
	}
	return t.RouterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Ipv6TeRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-alias-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AliasId   *string           `path:"state/alias-id" module:"openconfig-network-instance"`
	ΛAliasId  []ygot.Annotation `path:"state/@alias-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId) IsYANGGoStruct() {}

// GetAliasId retrieves the value of the leaf AliasId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AliasId is set, it can safely use t.GetAliasId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AliasId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId) GetAliasId() string {
	if t == nil || t.AliasId == nil {
		return ""
	}
	return *t.AliasId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsAliasId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability struct {
	ΛMetadata []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                               `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) NewNeighbor(SystemId string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor{
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.SystemId = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) GetOrCreateNeighbor(SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor {

	key := SystemId

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(SystemId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) GetNeighbor(SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor {

	if t == nil {
		return nil
	}

	key := SystemId

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) AppendNeighbor(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) error {
	if v.SystemId == nil {
		return fmt.Errorf("invalid nil key received for SystemId")
	}

	key := *v.SystemId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor struct {
	ΛMetadata      []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	DefaultMetric  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric `path:"default-metric" module:"openconfig-network-instance"`
	ΛDefaultMetric []ygot.Annotation                                                                  `path:"@default-metric" ygotAnnotation:"true"`
	DelayMetric    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric   `path:"delay-metric" module:"openconfig-network-instance"`
	ΛDelayMetric   []ygot.Annotation                                                                  `path:"@delay-metric" ygotAnnotation:"true"`
	ErrorMetric    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric   `path:"error-metric" module:"openconfig-network-instance"`
	ΛErrorMetric   []ygot.Annotation                                                                  `path:"@error-metric" ygotAnnotation:"true"`
	ExpenseMetric  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric `path:"expense-metric" module:"openconfig-network-instance"`
	ΛExpenseMetric []ygot.Annotation                                                                  `path:"@expense-metric" ygotAnnotation:"true"`
	SystemId       *string                                                                            `path:"state/system-id|system-id" module:"openconfig-network-instance"`
	ΛSystemId      []ygot.Annotation                                                                  `path:"state/@system-id|@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) IsYANGGoStruct() {}

// GetOrCreateDefaultMetric retrieves the value of the DefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetOrCreateDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric {
	if t.DefaultMetric != nil {
		return t.DefaultMetric
	}
	t.DefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric{}
	return t.DefaultMetric
}

// GetOrCreateDelayMetric retrieves the value of the DelayMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetOrCreateDelayMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric {
	if t.DelayMetric != nil {
		return t.DelayMetric
	}
	t.DelayMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric{}
	return t.DelayMetric
}

// GetOrCreateErrorMetric retrieves the value of the ErrorMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetOrCreateErrorMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric {
	if t.ErrorMetric != nil {
		return t.ErrorMetric
	}
	t.ErrorMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric{}
	return t.ErrorMetric
}

// GetOrCreateExpenseMetric retrieves the value of the ExpenseMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetOrCreateExpenseMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric {
	if t.ExpenseMetric != nil {
		return t.ExpenseMetric
	}
	t.ExpenseMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric{}
	return t.ExpenseMetric
}

// GetDefaultMetric returns the value of the DefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor. If the receiver or the field DefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric {
	if t != nil && t.DefaultMetric != nil {
		return t.DefaultMetric
	}
	return nil
}

// GetDelayMetric returns the value of the DelayMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor. If the receiver or the field DelayMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetDelayMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric {
	if t != nil && t.DelayMetric != nil {
		return t.DelayMetric
	}
	return nil
}

// GetErrorMetric returns the value of the ErrorMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor. If the receiver or the field ErrorMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetErrorMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric {
	if t != nil && t.ErrorMetric != nil {
		return t.ErrorMetric
	}
	return nil
}

// GetExpenseMetric returns the value of the ExpenseMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor. If the receiver or the field ExpenseMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetExpenseMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric {
	if t != nil && t.ExpenseMetric != nil {
		return t.ExpenseMetric
	}
	return nil
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric struct {
	ΛMetadata []ygot.Annotation     `path:"@" ygotAnnotation:"true"`
	Flags     E_DefaultMetric_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation     `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation     `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric) GetFlags() E_DefaultMetric_Flags {
	if t == nil || t.Flags == 0 {
		return 0
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/delay-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_DelayMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/error-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ErrorMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/expense-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Flags     []E_OpenconfigIsis_IsisMetricFlags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                  `path:"state/@flags" ygotAnnotation:"true"`
	Metric    *uint8                             `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation                  `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric) GetFlags() []E_OpenconfigIsis_IsisMetricFlags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric) GetMetric() uint8 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsReachability_Neighbor_ExpenseMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute struct {
	ΛMetadata []ygot.Annotation                                                                      `path:"@" ygotAnnotation:"true"`
	Neighbor  map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                                      `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) NewNeighbor(SystemId string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor{
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.SystemId = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) GetOrCreateNeighbor(SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor {

	key := SystemId

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(SystemId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) GetNeighbor(SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor {

	if t == nil {
		return nil
	}

	key := SystemId

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) AppendNeighbor(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) error {
	if v.SystemId == nil {
		return fmt.Errorf("invalid nil key received for SystemId")
	}

	key := *v.SystemId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor struct {
	ΛMetadata []ygot.Annotation                                                                               `path:"@" ygotAnnotation:"true"`
	Instance  map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance `path:"instances/instance" module:"openconfig-network-instance"`
	ΛInstance []ygot.Annotation                                                                               `path:"instances/@instance" ygotAnnotation:"true"`
	SystemId  *string                                                                                         `path:"state/system-id|system-id" module:"openconfig-network-instance"`
	ΛSystemId []ygot.Annotation                                                                               `path:"state/@system-id|@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) IsYANGGoStruct() {}

// NewInstance creates a new entry in the Instance list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) NewInstance(Id uint64) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// RenameInstance renames an entry in the list Instance within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) RenameInstance(oldK, newK uint64) error {
	if _, ok := t.Instance[newK]; ok {
		return fmt.Errorf("key %v already exists in Instance", newK)
	}

	e, ok := t.Instance[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Instance", oldK)
	}
	e.Id = &newK

	t.Instance[newK] = e
	delete(t.Instance, oldK)
	return nil
}

// GetOrCreateInstance retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) GetOrCreateInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance {

	key := Id

	if v, ok := t.Instance[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInstance(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInstance got unexpected error: %v", err))
	}
	return v
}

// GetInstance retrieves the value with the specified key from
// the Instance map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) GetInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Instance[key]; ok {
		return lm
	}
	return nil
}

// AppendInstance appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct to the
// list Instance of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) AppendInstance(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance)
	}

	if _, ok := t.Instance[key]; ok {
		return fmt.Errorf("duplicate key for list Instance %v", key)
	}

	t.Instance[key] = v
	return nil
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct {
	ΛMetadata        []ygot.Annotation                                                                                                                          `path:"@" ygotAnnotation:"true"`
	Id               *uint64                                                                                                                                    `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId              []ygot.Annotation                                                                                                                          `path:"state/@id|@id" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                                    `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                                          `path:"state/@metric" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                                          `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                                          `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) GetId() uint64 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct {
	ΛMetadata                   []ygot.Annotation                                                                                                         `path:"@" ygotAnnotation:"true"`
	AdjacencySid                map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid       `path:"adjacency-sids/adjacency-sid" module:"openconfig-network-instance"`
	ΛAdjacencySid               []ygot.Annotation                                                                                                         `path:"adjacency-sids/@adjacency-sid" ygotAnnotation:"true"`
	AdminGroup                  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup                    `path:"admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup                 []ygot.Annotation                                                                                                         `path:"@admin-group" ygotAnnotation:"true"`
	AvailableBandwidth          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth            `path:"available-bandwidth" module:"openconfig-network-instance"`
	ΛAvailableBandwidth         []ygot.Annotation                                                                                                         `path:"@available-bandwidth" ygotAnnotation:"true"`
	BandwidthConstraint         map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint `path:"bandwidth-constraints/bandwidth-constraint" module:"openconfig-network-instance"`
	ΛBandwidthConstraint        []ygot.Annotation                                                                                                         `path:"bandwidth-constraints/@bandwidth-constraint" ygotAnnotation:"true"`
	ExtendedAdminGroup          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup            `path:"extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup         []ygot.Annotation                                                                                                         `path:"@extended-admin-group" ygotAnnotation:"true"`
	Ipv4InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress          `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	ΛIpv4InterfaceAddress       []ygot.Annotation                                                                                                         `path:"@ipv4-interface-address" ygotAnnotation:"true"`
	Ipv4NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress           `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv4NeighborAddress        []ygot.Annotation                                                                                                         `path:"@ipv4-neighbor-address" ygotAnnotation:"true"`
	Ipv6InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress          `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	ΛIpv6InterfaceAddress       []ygot.Annotation                                                                                                         `path:"@ipv6-interface-address" ygotAnnotation:"true"`
	Ipv6NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress           `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv6NeighborAddress        []ygot.Annotation                                                                                                         `path:"@ipv6-neighbor-address" ygotAnnotation:"true"`
	LanAdjacencySid             map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid    `path:"lan-adjacency-sids/lan-adjacency-sid" module:"openconfig-network-instance"`
	ΛLanAdjacencySid            []ygot.Annotation                                                                                                         `path:"lan-adjacency-sids/@lan-adjacency-sid" ygotAnnotation:"true"`
	LinkAttributes              *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes                `path:"link-attributes" module:"openconfig-network-instance"`
	ΛLinkAttributes             []ygot.Annotation                                                                                                         `path:"@link-attributes" ygotAnnotation:"true"`
	LinkDelay                   *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay                     `path:"link-delay" module:"openconfig-network-instance"`
	ΛLinkDelay                  []ygot.Annotation                                                                                                         `path:"@link-delay" ygotAnnotation:"true"`
	LinkDelayVariation          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation            `path:"link-delay-variation" module:"openconfig-network-instance"`
	ΛLinkDelayVariation         []ygot.Annotation                                                                                                         `path:"@link-delay-variation" ygotAnnotation:"true"`
	LinkId                      *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId                        `path:"link-id" module:"openconfig-network-instance"`
	ΛLinkId                     []ygot.Annotation                                                                                                         `path:"@link-id" ygotAnnotation:"true"`
	LinkLoss                    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss                      `path:"link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss                   []ygot.Annotation                                                                                                         `path:"@link-loss" ygotAnnotation:"true"`
	LinkProtectionType          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType            `path:"link-protection-type" module:"openconfig-network-instance"`
	ΛLinkProtectionType         []ygot.Annotation                                                                                                         `path:"@link-protection-type" ygotAnnotation:"true"`
	MaxLinkBandwidth            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth              `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxLinkBandwidth           []ygot.Annotation                                                                                                         `path:"@max-link-bandwidth" ygotAnnotation:"true"`
	MaxReservableLinkBandwidth  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth    `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxReservableLinkBandwidth []ygot.Annotation                                                                                                         `path:"@max-reservable-link-bandwidth" ygotAnnotation:"true"`
	MinMaxLinkDelay             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay               `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ΛMinMaxLinkDelay            []ygot.Annotation                                                                                                         `path:"@min-max-link-delay" ygotAnnotation:"true"`
	ResidualBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth             `path:"residual-bandwidth" module:"openconfig-network-instance"`
	ΛResidualBandwidth          []ygot.Annotation                                                                                                         `path:"@residual-bandwidth" ygotAnnotation:"true"`
	SetupPriority               map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority       `path:"unreserved-bandwidth/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority              []ygot.Annotation                                                                                                         `path:"unreserved-bandwidth/@setup-priority" ygotAnnotation:"true"`
	TeDefaultMetric             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric               `path:"te-default-metric" module:"openconfig-network-instance"`
	ΛTeDefaultMetric            []ygot.Annotation                                                                                                         `path:"@te-default-metric" ygotAnnotation:"true"`
	Type                        E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType                       []ygot.Annotation                                                                                                         `path:"state/@type|@type" ygotAnnotation:"true"`
	UnconstrainedLsp            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp              `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	ΛUnconstrainedLsp           []ygot.Annotation                                                                                                         `path:"@unconstrained-lsp" ygotAnnotation:"true"`
	UtilizedBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth             `path:"utilized-bandwidth" module:"openconfig-network-instance"`
	ΛUtilizedBandwidth          []ygot.Annotation                                                                                                         `path:"@utilized-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) NewAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// RenameAdjacencySid renames an entry in the list AdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.AdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in AdjacencySid", newK)
	}

	e, ok := t.AdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdjacencySid", oldK)
	}
	e.Value = &newK

	t.AdjacencySid[newK] = e
	delete(t.AdjacencySid, oldK)
	return nil
}

// GetOrCreateAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid {

	key := Value

	if v, ok := t.AdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetAdjacencySid retrieves the value with the specified key from
// the AdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.AdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid struct to the
// list AdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	if _, ok := t.AdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list AdjacencySid %v", key)
	}

	t.AdjacencySid[key] = v
	return nil
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) NewBandwidthConstraint(ModelId uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// RenameBandwidthConstraint renames an entry in the list BandwidthConstraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameBandwidthConstraint(oldK, newK uint8) error {
	if _, ok := t.BandwidthConstraint[newK]; ok {
		return fmt.Errorf("key %v already exists in BandwidthConstraint", newK)
	}

	e, ok := t.BandwidthConstraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in BandwidthConstraint", oldK)
	}
	e.ModelId = &newK

	t.BandwidthConstraint[newK] = e
	delete(t.BandwidthConstraint, oldK)
	return nil
}

// GetOrCreateBandwidthConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint {

	key := ModelId

	if v, ok := t.BandwidthConstraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewBandwidthConstraint(ModelId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateBandwidthConstraint got unexpected error: %v", err))
	}
	return v
}

// GetBandwidthConstraint retrieves the value with the specified key from
// the BandwidthConstraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint {

	if t == nil {
		return nil
	}

	key := ModelId

	if lm, ok := t.BandwidthConstraint[key]; ok {
		return lm
	}
	return nil
}

// AppendBandwidthConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct to the
// list BandwidthConstraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendBandwidthConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) error {
	if v.ModelId == nil {
		return fmt.Errorf("invalid nil key received for ModelId")
	}

	key := *v.ModelId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	if _, ok := t.BandwidthConstraint[key]; ok {
		return fmt.Errorf("duplicate key for list BandwidthConstraint %v", key)
	}

	t.BandwidthConstraint[key] = v
	return nil
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) NewLanAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// RenameLanAdjacencySid renames an entry in the list LanAdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameLanAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.LanAdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in LanAdjacencySid", newK)
	}

	e, ok := t.LanAdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in LanAdjacencySid", oldK)
	}
	e.Value = &newK

	t.LanAdjacencySid[newK] = e
	delete(t.LanAdjacencySid, oldK)
	return nil
}

// GetOrCreateLanAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid {

	key := Value

	if v, ok := t.LanAdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLanAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLanAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetLanAdjacencySid retrieves the value with the specified key from
// the LanAdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.LanAdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendLanAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid struct to the
// list LanAdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendLanAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	if _, ok := t.LanAdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list LanAdjacencySid %v", key)
	}

	t.LanAdjacencySid[key] = v
	return nil
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) NewSetupPriority(Priority uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// RenameSetupPriority renames an entry in the list SetupPriority within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameSetupPriority(oldK, newK uint8) error {
	if _, ok := t.SetupPriority[newK]; ok {
		return fmt.Errorf("key %v already exists in SetupPriority", newK)
	}

	e, ok := t.SetupPriority[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SetupPriority", oldK)
	}
	e.Priority = &newK

	t.SetupPriority[newK] = e
	delete(t.SetupPriority, oldK)
	return nil
}

// GetOrCreateSetupPriority retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority {

	key := Priority

	if v, ok := t.SetupPriority[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSetupPriority(Priority)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSetupPriority got unexpected error: %v", err))
	}
	return v
}

// GetSetupPriority retrieves the value with the specified key from
// the SetupPriority map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority {

	if t == nil {
		return nil
	}

	key := Priority

	if lm, ok := t.SetupPriority[key]; ok {
		return lm
	}
	return nil
}

// AppendSetupPriority appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority struct to the
// list SetupPriority of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendSetupPriority(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) error {
	if v.Priority == nil {
		return fmt.Errorf("invalid nil key received for Priority")
	}

	key := *v.Priority

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority)
	}

	if _, ok := t.SetupPriority[key]; ok {
		return fmt.Errorf("duplicate key for list SetupPriority %v", key)
	}

	t.SetupPriority[key] = v
	return nil
}

// GetOrCreateAdminGroup retrieves the value of the AdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup {
	if t.AdminGroup != nil {
		return t.AdminGroup
	}
	t.AdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup{}
	return t.AdminGroup
}

// GetOrCreateAvailableBandwidth retrieves the value of the AvailableBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	t.AvailableBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth{}
	return t.AvailableBandwidth
}

// GetOrCreateExtendedAdminGroup retrieves the value of the ExtendedAdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	t.ExtendedAdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup{}
	return t.ExtendedAdminGroup
}

// GetOrCreateIpv4InterfaceAddress retrieves the value of the Ipv4InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	t.Ipv4InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress{}
	return t.Ipv4InterfaceAddress
}

// GetOrCreateIpv4NeighborAddress retrieves the value of the Ipv4NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	t.Ipv4NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress{}
	return t.Ipv4NeighborAddress
}

// GetOrCreateIpv6InterfaceAddress retrieves the value of the Ipv6InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	t.Ipv6InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress{}
	return t.Ipv6InterfaceAddress
}

// GetOrCreateIpv6NeighborAddress retrieves the value of the Ipv6NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	t.Ipv6NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress{}
	return t.Ipv6NeighborAddress
}

// GetOrCreateLinkAttributes retrieves the value of the LinkAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes {
	if t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	t.LinkAttributes = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes{}
	return t.LinkAttributes
}

// GetOrCreateLinkDelay retrieves the value of the LinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay {
	if t.LinkDelay != nil {
		return t.LinkDelay
	}
	t.LinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay{}
	return t.LinkDelay
}

// GetOrCreateLinkDelayVariation retrieves the value of the LinkDelayVariation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	t.LinkDelayVariation = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation{}
	return t.LinkDelayVariation
}

// GetOrCreateLinkId retrieves the value of the LinkId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId {
	if t.LinkId != nil {
		return t.LinkId
	}
	t.LinkId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId{}
	return t.LinkId
}

// GetOrCreateLinkLoss retrieves the value of the LinkLoss field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss {
	if t.LinkLoss != nil {
		return t.LinkLoss
	}
	t.LinkLoss = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss{}
	return t.LinkLoss
}

// GetOrCreateLinkProtectionType retrieves the value of the LinkProtectionType field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	t.LinkProtectionType = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType{}
	return t.LinkProtectionType
}

// GetOrCreateMaxLinkBandwidth retrieves the value of the MaxLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	t.MaxLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth{}
	return t.MaxLinkBandwidth
}

// GetOrCreateMaxReservableLinkBandwidth retrieves the value of the MaxReservableLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	t.MaxReservableLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth{}
	return t.MaxReservableLinkBandwidth
}

// GetOrCreateMinMaxLinkDelay retrieves the value of the MinMaxLinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	t.MinMaxLinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay{}
	return t.MinMaxLinkDelay
}

// GetOrCreateResidualBandwidth retrieves the value of the ResidualBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	t.ResidualBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth{}
	return t.ResidualBandwidth
}

// GetOrCreateTeDefaultMetric retrieves the value of the TeDefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	t.TeDefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric{}
	return t.TeDefaultMetric
}

// GetOrCreateUnconstrainedLsp retrieves the value of the UnconstrainedLsp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	t.UnconstrainedLsp = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp{}
	return t.UnconstrainedLsp
}

// GetOrCreateUtilizedBandwidth retrieves the value of the UtilizedBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	t.UtilizedBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth{}
	return t.UtilizedBandwidth
}

// GetAdminGroup returns the value of the AdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field AdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup {
	if t != nil && t.AdminGroup != nil {
		return t.AdminGroup
	}
	return nil
}

// GetAvailableBandwidth returns the value of the AvailableBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field AvailableBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t != nil && t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	return nil
}

// GetExtendedAdminGroup returns the value of the ExtendedAdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field ExtendedAdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t != nil && t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	return nil
}

// GetIpv4InterfaceAddress returns the value of the Ipv4InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t != nil && t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	return nil
}

// GetIpv4NeighborAddress returns the value of the Ipv4NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t != nil && t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	return nil
}

// GetIpv6InterfaceAddress returns the value of the Ipv6InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t != nil && t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	return nil
}

// GetIpv6NeighborAddress returns the value of the Ipv6NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t != nil && t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	return nil
}

// GetLinkAttributes returns the value of the LinkAttributes struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes {
	if t != nil && t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	return nil
}

// GetLinkDelay returns the value of the LinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay {
	if t != nil && t.LinkDelay != nil {
		return t.LinkDelay
	}
	return nil
}

// GetLinkDelayVariation returns the value of the LinkDelayVariation struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelayVariation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t != nil && t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	return nil
}

// GetLinkId returns the value of the LinkId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId {
	if t != nil && t.LinkId != nil {
		return t.LinkId
	}
	return nil
}

// GetLinkLoss returns the value of the LinkLoss struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkLoss is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss {
	if t != nil && t.LinkLoss != nil {
		return t.LinkLoss
	}
	return nil
}

// GetLinkProtectionType returns the value of the LinkProtectionType struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkProtectionType is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t != nil && t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	return nil
}

// GetMaxLinkBandwidth returns the value of the MaxLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field MaxLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t != nil && t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	return nil
}

// GetMaxReservableLinkBandwidth returns the value of the MaxReservableLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field MaxReservableLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t != nil && t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	return nil
}

// GetMinMaxLinkDelay returns the value of the MinMaxLinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field MinMaxLinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t != nil && t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	return nil
}

// GetResidualBandwidth returns the value of the ResidualBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field ResidualBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t != nil && t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	return nil
}

// GetTeDefaultMetric returns the value of the TeDefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field TeDefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t != nil && t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	return nil
}

// GetUnconstrainedLsp returns the value of the UnconstrainedLsp struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field UnconstrainedLsp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t != nil && t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	return nil
}

// GetUtilizedBandwidth returns the value of the UtilizedBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field UtilizedBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t != nil && t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid struct {
	ΛMetadata []ygot.Annotation      `path:"@" ygotAnnotation:"true"`
	Flags     []E_AdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation      `path:"state/@flags" ygotAnnotation:"true"`
	Value     *uint32                `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation      `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight    *uint8                 `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight   []ygot.Annotation      `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) GetFlags() []E_AdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdminGroup  []uint32          `path:"state/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup []ygot.Annotation `path:"state/@admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// GetAdminGroup retrieves the value of the leaf AdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminGroup is set, it can safely use t.GetAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) GetAdminGroup() []uint32 {
	if t == nil || t.AdminGroup == nil {
		return nil
	}
	return t.AdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct {
	ΛMetadata   []ygot.Annotation                                                                                                                     `path:"@" ygotAnnotation:"true"`
	Constraint  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint `path:"constraints/constraint" module:"openconfig-network-instance"`
	ΛConstraint []ygot.Annotation                                                                                                                     `path:"constraints/@constraint" ygotAnnotation:"true"`
	ModelId     *uint8                                                                                                                                `path:"state/model-id|model-id" module:"openconfig-network-instance"`
	ΛModelId    []ygot.Annotation                                                                                                                     `path:"state/@model-id|@model-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) NewConstraint(ConstraintId uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// RenameConstraint renames an entry in the list Constraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) RenameConstraint(oldK, newK uint32) error {
	if _, ok := t.Constraint[newK]; ok {
		return fmt.Errorf("key %v already exists in Constraint", newK)
	}

	e, ok := t.Constraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Constraint", oldK)
	}
	e.ConstraintId = &newK

	t.Constraint[newK] = e
	delete(t.Constraint, oldK)
	return nil
}

// GetOrCreateConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) GetOrCreateConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	key := ConstraintId

	if v, ok := t.Constraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewConstraint(ConstraintId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateConstraint got unexpected error: %v", err))
	}
	return v
}

// GetConstraint retrieves the value with the specified key from
// the Constraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) GetConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	if t == nil {
		return nil
	}

	key := ConstraintId

	if lm, ok := t.Constraint[key]; ok {
		return lm
	}
	return nil
}

// AppendConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct to the
// list Constraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) AppendConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) error {
	if v.ConstraintId == nil {
		return fmt.Errorf("invalid nil key received for ConstraintId")
	}

	key := *v.ConstraintId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	if _, ok := t.Constraint[key]; ok {
		return fmt.Errorf("duplicate key for list Constraint %v", key)
	}

	t.Constraint[key] = v
	return nil
}

// GetModelId retrieves the value of the leaf ModelId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ModelId is set, it can safely use t.GetModelId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ModelId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) GetModelId() uint8 {
	if t == nil || t.ModelId == nil {
		return 0
	}
	return *t.ModelId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth     Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth    []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	ConstraintId  *uint32           `path:"state/constraint-id|constraint-id" module:"openconfig-network-instance"`
	ΛConstraintId []ygot.Annotation `path:"state/@constraint-id|@constraint-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetConstraintId retrieves the value of the leaf ConstraintId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConstraintId is set, it can safely use t.GetConstraintId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConstraintId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetConstraintId() uint32 {
	if t == nil || t.ConstraintId == nil {
		return 0
	}
	return *t.ConstraintId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExtendedAdminGroup  []uint32          `path:"state/extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup []ygot.Annotation `path:"state/@extended-admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// GetExtendedAdminGroup retrieves the value of the leaf ExtendedAdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtendedAdminGroup is set, it can safely use t.GetExtendedAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtendedAdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) GetExtendedAdminGroup() []uint32 {
	if t == nil || t.ExtendedAdminGroup == nil {
		return nil
	}
	return t.ExtendedAdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid struct {
	ΛMetadata   []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Flags       []E_LanAdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags      []ygot.Annotation         `path:"state/@flags" ygotAnnotation:"true"`
	NeighborId  *string                   `path:"state/neighbor-id" module:"openconfig-network-instance"`
	ΛNeighborId []ygot.Annotation         `path:"state/@neighbor-id" ygotAnnotation:"true"`
	Value       *uint32                   `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue      []ygot.Annotation         `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight      *uint8                    `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight     []ygot.Annotation         `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetFlags() []E_LanAdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetNeighborId retrieves the value of the leaf NeighborId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborId is set, it can safely use t.GetNeighborId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetNeighborId() string {
	if t == nil || t.NeighborId == nil {
		return ""
	}
	return *t.NeighborId
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes struct {
	ΛMetadata        []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	LocalProtection  []E_LinkAttributes_LocalProtection `path:"state/local-protection" module:"openconfig-network-instance"`
	ΛLocalProtection []ygot.Annotation                  `path:"state/@local-protection" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// GetLocalProtection retrieves the value of the leaf LocalProtection from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalProtection is set, it can safely use t.GetLocalProtection()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalProtection == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) GetLocalProtection() []E_LinkAttributes_LocalProtection {
	if t == nil || t.LocalProtection == nil {
		return nil
	}
	return t.LocalProtection
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Local     *uint32           `path:"state/local" module:"openconfig-network-instance"`
	ΛLocal    []ygot.Annotation `path:"state/@local" ygotAnnotation:"true"`
	Remote    *uint32           `path:"state/remote" module:"openconfig-network-instance"`
	ΛRemote   []ygot.Annotation `path:"state/@remote" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) IsYANGGoStruct() {
}

// GetLocal retrieves the value of the leaf Local from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Local is set, it can safely use t.GetLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Local == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) GetLocal() uint32 {
	if t == nil || t.Local == nil {
		return 0
	}
	return *t.Local
}

// GetRemote retrieves the value of the leaf Remote from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Remote is set, it can safely use t.GetRemote()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Remote == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) GetRemote() uint32 {
	if t == nil || t.Remote == nil {
		return 0
	}
	return *t.Remote
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	LinkLoss  *uint32           `path:"state/link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss []ygot.Annotation `path:"state/@link-loss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetLinkLoss retrieves the value of the leaf LinkLoss from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLoss is set, it can safely use t.GetLinkLoss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLoss == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) GetLinkLoss() uint32 {
	if t == nil || t.LinkLoss == nil {
		return 0
	}
	return *t.LinkLoss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType struct {
	ΛMetadata []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	Type      []E_LinkProtectionType_Type `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation           `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) GetType() []E_LinkProtectionType_Type {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	MaxDelay  *uint32           `path:"state/max-delay" module:"openconfig-network-instance"`
	ΛMaxDelay []ygot.Annotation `path:"state/@max-delay" ygotAnnotation:"true"`
	MinDelay  *uint32           `path:"state/min-delay" module:"openconfig-network-instance"`
	ΛMinDelay []ygot.Annotation `path:"state/@min-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetMaxDelay retrieves the value of the leaf MaxDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxDelay is set, it can safely use t.GetMaxDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMaxDelay() uint32 {
	if t == nil || t.MaxDelay == nil {
		return 0
	}
	return *t.MaxDelay
}

// GetMinDelay retrieves the value of the leaf MinDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinDelay is set, it can safely use t.GetMinDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMinDelay() uint32 {
	if t == nil || t.MinDelay == nil {
		return 0
	}
	return *t.MinDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	Priority   *uint8            `path:"state/priority|priority" module:"openconfig-network-instance"`
	ΛPriority  []ygot.Annotation `path:"state/@priority|@priority" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint32           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Count     *uint16                                    `path:"state/count" module:"openconfig-network-instance"`
	ΛCount    []ygot.Annotation                          `path:"state/@count" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// GetCount retrieves the value of the leaf Count from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Count is set, it can safely use t.GetCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Count == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetCount() uint16 {
	if t == nil || t.Count == nil {
		return 0
	}
	return *t.Count
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_IsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/lsp-buffer-size YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Size      *uint16           `path:"state/size" module:"openconfig-network-instance"`
	ΛSize     []ygot.Annotation `path:"state/@size" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize) IsYANGGoStruct() {}

// GetSize retrieves the value of the leaf Size from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Size is set, it can safely use t.GetSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Size == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize) GetSize() uint16 {
	if t == nil || t.Size == nil {
		return 0
	}
	return *t.Size
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_LspBufferSize) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability struct {
	ΛMetadata []ygot.Annotation                                                                                                                                    `path:"@" ygotAnnotation:"true"`
	Prefix    map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix `path:"prefixes/prefix" module:"openconfig-network-instance"`
	ΛPrefix   []ygot.Annotation                                                                                                                                    `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key represents the key for list Prefix of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key struct {
	MtId   uint16 `path:"mt-id"`
	Prefix string `path:"prefix"`
}

// NewPrefix creates a new entry in the Prefix list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) NewPrefix(MtId uint16, Prefix string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix)
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key{
		MtId:   MtId,
		Prefix: Prefix,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix{
		MtId:   &MtId,
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) RenamePrefix(oldK, newK NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.MtId = &newK.MtId
	e.Prefix = &newK.Prefix

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) GetOrCreatePrefix(MtId uint16, Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix {

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key{
		MtId:   MtId,
		Prefix: Prefix,
	}

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(MtId, Prefix)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) GetPrefix(MtId uint16, Prefix string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key{
		MtId:   MtId,
		Prefix: Prefix,
	}

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct to the
// list Prefix of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) AppendPrefix(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) error {
	if v.MtId == nil {
		return fmt.Errorf("invalid nil key for MtId")
	}

	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key{
		MtId:   *v.MtId,
		Prefix: *v.Prefix,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct {
	ΛMetadata        []ygot.Annotation                                                                                                            `path:"@" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                      `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                            `path:"state/@metric" ygotAnnotation:"true"`
	MtId             *uint16                                                                                                                      `path:"state/mt-id|mt-id" module:"openconfig-network-instance"`
	ΛMtId            []ygot.Annotation                                                                                                            `path:"state/@mt-id|@mt-id" ygotAnnotation:"true"`
	Prefix           *string                                                                                                                      `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix          []ygot.Annotation                                                                                                            `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SBit             *bool                                                                                                                        `path:"state/s-bit" module:"openconfig-network-instance"`
	ΛSBit            []ygot.Annotation                                                                                                            `path:"state/@s-bit" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                            `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                            `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
	UpDown           *bool                                                                                                                        `path:"state/up-down" module:"openconfig-network-instance"`
	ΛUpDown          []ygot.Annotation                                                                                                            `path:"state/@up-down" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetMtId retrieves the value of the leaf MtId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtId is set, it can safely use t.GetMtId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetMtId() uint16 {
	if t == nil || t.MtId == nil {
		return 0
	}
	return *t.MtId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSBit retrieves the value of the leaf SBit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SBit is set, it can safely use t.GetSBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetSBit() bool {
	if t == nil || t.SBit == nil {
		return false
	}
	return *t.SBit
}

// GetUpDown retrieves the value of the leaf UpDown from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDown is set, it can safely use t.GetUpDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) GetUpDown() bool {
	if t == nil || t.UpDown == nil {
		return false
	}
	return *t.UpDown
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"mt-id":  *t.MtId,
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv struct {
	ΛMetadata           []ygot.Annotation                                                                                  `path:"@" ygotAnnotation:"true"`
	Flags               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags                `path:"flags" module:"openconfig-network-instance"`
	ΛFlags              []ygot.Annotation                                                                                  `path:"@flags" ygotAnnotation:"true"`
	Ipv4SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId   `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	ΛIpv4SourceRouterId []ygot.Annotation                                                                                  `path:"@ipv4-source-router-id" ygotAnnotation:"true"`
	Ipv6SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId   `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	ΛIpv6SourceRouterId []ygot.Annotation                                                                                  `path:"@ipv6-source-router-id" ygotAnnotation:"true"`
	PrefixSid           map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid `path:"prefix-sids/prefix-sid" module:"openconfig-network-instance"`
	ΛPrefixSid          []ygot.Annotation                                                                                  `path:"prefix-sids/@prefix-sid" ygotAnnotation:"true"`
	Tag                 *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag                  `path:"tag" module:"openconfig-network-instance"`
	ΛTag                []ygot.Annotation                                                                                  `path:"@tag" ygotAnnotation:"true"`
	Tag64               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64                `path:"tag64" module:"openconfig-network-instance"`
	ΛTag64              []ygot.Annotation                                                                                  `path:"@tag64" ygotAnnotation:"true"`
	Type                E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                         `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                                  `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) NewPrefixSid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// RenamePrefixSid renames an entry in the list PrefixSid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) RenamePrefixSid(oldK, newK uint32) error {
	if _, ok := t.PrefixSid[newK]; ok {
		return fmt.Errorf("key %v already exists in PrefixSid", newK)
	}

	e, ok := t.PrefixSid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PrefixSid", oldK)
	}
	e.Value = &newK

	t.PrefixSid[newK] = e
	delete(t.PrefixSid, oldK)
	return nil
}

// GetOrCreatePrefixSid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetOrCreatePrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid {

	key := Value

	if v, ok := t.PrefixSid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefixSid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefixSid got unexpected error: %v", err))
	}
	return v
}

// GetPrefixSid retrieves the value with the specified key from
// the PrefixSid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetPrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.PrefixSid[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefixSid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid struct to the
// list PrefixSid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) AppendPrefixSid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid)
	}

	if _, ok := t.PrefixSid[key]; ok {
		return fmt.Errorf("duplicate key for list PrefixSid %v", key)
	}

	t.PrefixSid[key] = v
	return nil
}

// GetOrCreateFlags retrieves the value of the Flags field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetOrCreateFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags {
	if t.Flags != nil {
		return t.Flags
	}
	t.Flags = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags{}
	return t.Flags
}

// GetOrCreateIpv4SourceRouterId retrieves the value of the Ipv4SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetOrCreateIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	t.Ipv4SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId{}
	return t.Ipv4SourceRouterId
}

// GetOrCreateIpv6SourceRouterId retrieves the value of the Ipv6SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetOrCreateIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	t.Ipv6SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId{}
	return t.Ipv6SourceRouterId
}

// GetOrCreateTag retrieves the value of the Tag field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetOrCreateTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag {
	if t.Tag != nil {
		return t.Tag
	}
	t.Tag = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag{}
	return t.Tag
}

// GetOrCreateTag64 retrieves the value of the Tag64 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetOrCreateTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64 {
	if t.Tag64 != nil {
		return t.Tag64
	}
	t.Tag64 = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64{}
	return t.Tag64
}

// GetFlags returns the value of the Flags struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the receiver or the field Flags is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags {
	if t != nil && t.Flags != nil {
		return t.Flags
	}
	return nil
}

// GetIpv4SourceRouterId returns the value of the Ipv4SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the receiver or the field Ipv4SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t != nil && t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	return nil
}

// GetIpv6SourceRouterId returns the value of the Ipv6SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the receiver or the field Ipv6SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t != nil && t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	return nil
}

// GetTag returns the value of the Tag struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the receiver or the field Tag is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag {
	if t != nil && t.Tag != nil {
		return t.Tag
	}
	return nil
}

// GetTag64 returns the value of the Tag64 struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv. If the receiver or the field Tag64 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64 {
	if t != nil && t.Tag64 != nil {
		return t.Tag64
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Flags     []E_Flags_Flags                            `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                          `path:"state/@flags" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags) GetFlags() []E_Flags_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid struct {
	ΛMetadata  []ygot.Annotation   `path:"@" ygotAnnotation:"true"`
	Algorithm  *uint8              `path:"state/algorithm" module:"openconfig-network-instance"`
	ΛAlgorithm []ygot.Annotation   `path:"state/@algorithm" ygotAnnotation:"true"`
	Flags      []E_PrefixSid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags     []ygot.Annotation   `path:"state/@flags" ygotAnnotation:"true"`
	Value      *uint32             `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue     []ygot.Annotation   `path:"state/@value|@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) IsYANGGoStruct() {
}

// GetAlgorithm retrieves the value of the leaf Algorithm from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Algorithm is set, it can safely use t.GetAlgorithm()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Algorithm == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) GetAlgorithm() uint8 {
	if t == nil || t.Algorithm == nil {
		return 0
	}
	return *t.Algorithm
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) GetFlags() []E_PrefixSid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag32     []uint32          `path:"state/tag32" module:"openconfig-network-instance"`
	ΛTag32    []ygot.Annotation `path:"state/@tag32" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag) IsYANGGoStruct() {
}

// GetTag32 retrieves the value of the leaf Tag32 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag32 is set, it can safely use t.GetTag32()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag32 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag) GetTag32() []uint32 {
	if t == nil || t.Tag32 == nil {
		return nil
	}
	return t.Tag32
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64 struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag64     []uint64          `path:"state/tag64" module:"openconfig-network-instance"`
	ΛTag64    []ygot.Annotation `path:"state/@tag64" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64) IsYANGGoStruct() {
}

// GetTag64 retrieves the value of the leaf Tag64 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag64 is set, it can safely use t.GetTag64()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag64 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64) GetTag64() []uint64 {
	if t == nil || t.Tag64 == nil {
		return nil
	}
	return t.Tag64
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv4Reachability_Prefix_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability struct {
	ΛMetadata []ygot.Annotation                                                                                                                                    `path:"@" ygotAnnotation:"true"`
	Prefix    map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix `path:"prefixes/prefix" module:"openconfig-network-instance"`
	ΛPrefix   []ygot.Annotation                                                                                                                                    `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key represents the key for list Prefix of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key struct {
	Prefix string `path:"prefix"`
	MtId   uint16 `path:"mt-id"`
}

// NewPrefix creates a new entry in the Prefix list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) NewPrefix(Prefix string, MtId uint16) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix)
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key{
		Prefix: Prefix,
		MtId:   MtId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix{
		Prefix: &Prefix,
		MtId:   &MtId,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) RenamePrefix(oldK, newK NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.Prefix = &newK.Prefix
	e.MtId = &newK.MtId

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) GetOrCreatePrefix(Prefix string, MtId uint16) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix {

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key{
		Prefix: Prefix,
		MtId:   MtId,
	}

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(Prefix, MtId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) GetPrefix(Prefix string, MtId uint16) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key{
		Prefix: Prefix,
		MtId:   MtId,
	}

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct to the
// list Prefix of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) AppendPrefix(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) error {
	if v.Prefix == nil {
		return fmt.Errorf("invalid nil key for Prefix")
	}

	if v.MtId == nil {
		return fmt.Errorf("invalid nil key for MtId")
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key{
		Prefix: *v.Prefix,
		MtId:   *v.MtId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct {
	ΛMetadata        []ygot.Annotation                                                                                                            `path:"@" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                      `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                            `path:"state/@metric" ygotAnnotation:"true"`
	MtId             *uint16                                                                                                                      `path:"state/mt-id|mt-id" module:"openconfig-network-instance"`
	ΛMtId            []ygot.Annotation                                                                                                            `path:"state/@mt-id|@mt-id" ygotAnnotation:"true"`
	Prefix           *string                                                                                                                      `path:"state/prefix|prefix" module:"openconfig-network-instance"`
	ΛPrefix          []ygot.Annotation                                                                                                            `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SBit             *bool                                                                                                                        `path:"state/s-bit" module:"openconfig-network-instance"`
	ΛSBit            []ygot.Annotation                                                                                                            `path:"state/@s-bit" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                            `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                            `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
	UpDown           *bool                                                                                                                        `path:"state/up-down" module:"openconfig-network-instance"`
	ΛUpDown          []ygot.Annotation                                                                                                            `path:"state/@up-down" ygotAnnotation:"true"`
	XBit             *bool                                                                                                                        `path:"state/x-bit" module:"openconfig-network-instance"`
	ΛXBit            []ygot.Annotation                                                                                                            `path:"state/@x-bit" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetMtId retrieves the value of the leaf MtId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtId is set, it can safely use t.GetMtId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetMtId() uint16 {
	if t == nil || t.MtId == nil {
		return 0
	}
	return *t.MtId
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSBit retrieves the value of the leaf SBit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SBit is set, it can safely use t.GetSBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetSBit() bool {
	if t == nil || t.SBit == nil {
		return false
	}
	return *t.SBit
}

// GetUpDown retrieves the value of the leaf UpDown from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpDown is set, it can safely use t.GetUpDown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpDown == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetUpDown() bool {
	if t == nil || t.UpDown == nil {
		return false
	}
	return *t.UpDown
}

// GetXBit retrieves the value of the leaf XBit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if XBit is set, it can safely use t.GetXBit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.XBit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) GetXBit() bool {
	if t == nil || t.XBit == nil {
		return false
	}
	return *t.XBit
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"mt-id":  *t.MtId,
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv struct {
	ΛMetadata           []ygot.Annotation                                                                                  `path:"@" ygotAnnotation:"true"`
	Flags               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags                `path:"flags" module:"openconfig-network-instance"`
	ΛFlags              []ygot.Annotation                                                                                  `path:"@flags" ygotAnnotation:"true"`
	Ipv4SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId   `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	ΛIpv4SourceRouterId []ygot.Annotation                                                                                  `path:"@ipv4-source-router-id" ygotAnnotation:"true"`
	Ipv6SourceRouterId  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId   `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	ΛIpv6SourceRouterId []ygot.Annotation                                                                                  `path:"@ipv6-source-router-id" ygotAnnotation:"true"`
	PrefixSid           map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid `path:"prefix-sids/prefix-sid" module:"openconfig-network-instance"`
	ΛPrefixSid          []ygot.Annotation                                                                                  `path:"prefix-sids/@prefix-sid" ygotAnnotation:"true"`
	Tag                 *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag                  `path:"tag" module:"openconfig-network-instance"`
	ΛTag                []ygot.Annotation                                                                                  `path:"@tag" ygotAnnotation:"true"`
	Tag64               *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64                `path:"tag64" module:"openconfig-network-instance"`
	ΛTag64              []ygot.Annotation                                                                                  `path:"@tag64" ygotAnnotation:"true"`
	Type                E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                         `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                                  `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) NewPrefixSid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// RenamePrefixSid renames an entry in the list PrefixSid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) RenamePrefixSid(oldK, newK uint32) error {
	if _, ok := t.PrefixSid[newK]; ok {
		return fmt.Errorf("key %v already exists in PrefixSid", newK)
	}

	e, ok := t.PrefixSid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PrefixSid", oldK)
	}
	e.Value = &newK

	t.PrefixSid[newK] = e
	delete(t.PrefixSid, oldK)
	return nil
}

// GetOrCreatePrefixSid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetOrCreatePrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid {

	key := Value

	if v, ok := t.PrefixSid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefixSid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefixSid got unexpected error: %v", err))
	}
	return v
}

// GetPrefixSid retrieves the value with the specified key from
// the PrefixSid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetPrefixSid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.PrefixSid[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefixSid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid struct to the
// list PrefixSid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) AppendPrefixSid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid)
	}

	if _, ok := t.PrefixSid[key]; ok {
		return fmt.Errorf("duplicate key for list PrefixSid %v", key)
	}

	t.PrefixSid[key] = v
	return nil
}

// GetOrCreateFlags retrieves the value of the Flags field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetOrCreateFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags {
	if t.Flags != nil {
		return t.Flags
	}
	t.Flags = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags{}
	return t.Flags
}

// GetOrCreateIpv4SourceRouterId retrieves the value of the Ipv4SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetOrCreateIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	t.Ipv4SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId{}
	return t.Ipv4SourceRouterId
}

// GetOrCreateIpv6SourceRouterId retrieves the value of the Ipv6SourceRouterId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetOrCreateIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	t.Ipv6SourceRouterId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId{}
	return t.Ipv6SourceRouterId
}

// GetOrCreateTag retrieves the value of the Tag field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetOrCreateTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag {
	if t.Tag != nil {
		return t.Tag
	}
	t.Tag = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag{}
	return t.Tag
}

// GetOrCreateTag64 retrieves the value of the Tag64 field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetOrCreateTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64 {
	if t.Tag64 != nil {
		return t.Tag64
	}
	t.Tag64 = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64{}
	return t.Tag64
}

// GetFlags returns the value of the Flags struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the receiver or the field Flags is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetFlags() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags {
	if t != nil && t.Flags != nil {
		return t.Flags
	}
	return nil
}

// GetIpv4SourceRouterId returns the value of the Ipv4SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the receiver or the field Ipv4SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetIpv4SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId {
	if t != nil && t.Ipv4SourceRouterId != nil {
		return t.Ipv4SourceRouterId
	}
	return nil
}

// GetIpv6SourceRouterId returns the value of the Ipv6SourceRouterId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the receiver or the field Ipv6SourceRouterId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetIpv6SourceRouterId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId {
	if t != nil && t.Ipv6SourceRouterId != nil {
		return t.Ipv6SourceRouterId
	}
	return nil
}

// GetTag returns the value of the Tag struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the receiver or the field Tag is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetTag() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag {
	if t != nil && t.Tag != nil {
		return t.Tag
	}
	return nil
}

// GetTag64 returns the value of the Tag64 struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv. If the receiver or the field Tag64 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetTag64() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64 {
	if t != nil && t.Tag64 != nil {
		return t.Tag64
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Flags     []E_Flags_Flags                            `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation                          `path:"state/@flags" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags) GetFlags() []E_Flags_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	RouterId  *string                                    `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId []ygot.Annotation                          `path:"state/@router-id" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid struct {
	ΛMetadata  []ygot.Annotation   `path:"@" ygotAnnotation:"true"`
	Algorithm  *uint8              `path:"state/algorithm" module:"openconfig-network-instance"`
	ΛAlgorithm []ygot.Annotation   `path:"state/@algorithm" ygotAnnotation:"true"`
	Flags      []E_PrefixSid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags     []ygot.Annotation   `path:"state/@flags" ygotAnnotation:"true"`
	Value      *uint32             `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue     []ygot.Annotation   `path:"state/@value|@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) IsYANGGoStruct() {
}

// GetAlgorithm retrieves the value of the leaf Algorithm from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Algorithm is set, it can safely use t.GetAlgorithm()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Algorithm == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) GetAlgorithm() uint8 {
	if t == nil || t.Algorithm == nil {
		return 0
	}
	return *t.Algorithm
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) GetFlags() []E_PrefixSid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag32     []uint32          `path:"state/tag32" module:"openconfig-network-instance"`
	ΛTag32    []ygot.Annotation `path:"state/@tag32" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag) IsYANGGoStruct() {
}

// GetTag32 retrieves the value of the leaf Tag32 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag32 is set, it can safely use t.GetTag32()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag32 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag) GetTag32() []uint32 {
	if t == nil || t.Tag32 == nil {
		return nil
	}
	return t.Tag32
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64 struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Tag64     []uint64          `path:"state/tag64" module:"openconfig-network-instance"`
	ΛTag64    []ygot.Annotation `path:"state/@tag64" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64) IsYANGGoStruct() {
}

// GetTag64 retrieves the value of the leaf Tag64 from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag64 is set, it can safely use t.GetTag64()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag64 == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64) GetTag64() []uint64 {
	if t == nil || t.Tag64 == nil {
		return nil
	}
	return t.Tag64
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIpv6Reachability_Prefix_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute struct {
	ΛMetadata []ygot.Annotation                                                                                                                                                  `path:"@" ygotAnnotation:"true"`
	Neighbor  map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                                                                                                                  `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key represents the key for list Neighbor of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key struct {
	MtId     uint16 `path:"mt-id"`
	SystemId string `path:"system-id"`
}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) NewNeighbor(MtId uint16, SystemId string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor)
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor{
		MtId:     &MtId,
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) RenameNeighbor(oldK, newK NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.MtId = &newK.MtId
	e.SystemId = &newK.SystemId

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) GetOrCreateNeighbor(MtId uint16, SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor {

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(MtId, SystemId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) GetNeighbor(MtId uint16, SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) AppendNeighbor(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) error {
	if v.MtId == nil {
		return fmt.Errorf("invalid nil key for MtId")
	}

	if v.SystemId == nil {
		return fmt.Errorf("invalid nil key for SystemId")
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key{
		MtId:     *v.MtId,
		SystemId: *v.SystemId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor struct {
	ΛMetadata []ygot.Annotation                                                                                 `path:"@" ygotAnnotation:"true"`
	Instance  map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance `path:"instances/instance" module:"openconfig-network-instance"`
	ΛInstance []ygot.Annotation                                                                                 `path:"instances/@instance" ygotAnnotation:"true"`
	MtId      *uint16                                                                                           `path:"state/mt-id|mt-id" module:"openconfig-network-instance"`
	ΛMtId     []ygot.Annotation                                                                                 `path:"state/@mt-id|@mt-id" ygotAnnotation:"true"`
	SystemId  *string                                                                                           `path:"state/system-id|system-id" module:"openconfig-network-instance"`
	ΛSystemId []ygot.Annotation                                                                                 `path:"state/@system-id|@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) IsYANGGoStruct() {
}

// NewInstance creates a new entry in the Instance list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) NewInstance(Id uint64) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// RenameInstance renames an entry in the list Instance within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) RenameInstance(oldK, newK uint64) error {
	if _, ok := t.Instance[newK]; ok {
		return fmt.Errorf("key %v already exists in Instance", newK)
	}

	e, ok := t.Instance[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Instance", oldK)
	}
	e.Id = &newK

	t.Instance[newK] = e
	delete(t.Instance, oldK)
	return nil
}

// GetOrCreateInstance retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) GetOrCreateInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance {

	key := Id

	if v, ok := t.Instance[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInstance(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInstance got unexpected error: %v", err))
	}
	return v
}

// GetInstance retrieves the value with the specified key from
// the Instance map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) GetInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Instance[key]; ok {
		return lm
	}
	return nil
}

// AppendInstance appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct to the
// list Instance of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) AppendInstance(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance)
	}

	if _, ok := t.Instance[key]; ok {
		return fmt.Errorf("duplicate key for list Instance %v", key)
	}

	t.Instance[key] = v
	return nil
}

// GetMtId retrieves the value of the leaf MtId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtId is set, it can safely use t.GetMtId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) GetMtId() uint16 {
	if t == nil || t.MtId == nil {
		return 0
	}
	return *t.MtId
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"mt-id":     *t.MtId,
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct {
	ΛMetadata        []ygot.Annotation                                                                                                                            `path:"@" ygotAnnotation:"true"`
	Id               *uint64                                                                                                                                      `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId              []ygot.Annotation                                                                                                                            `path:"state/@id|@id" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                                      `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                                            `path:"state/@metric" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                                            `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                                            `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) GetId() uint64 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct {
	ΛMetadata                   []ygot.Annotation                                                                                                           `path:"@" ygotAnnotation:"true"`
	AdjacencySid                map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid       `path:"adjacency-sids/adjacency-sid" module:"openconfig-network-instance"`
	ΛAdjacencySid               []ygot.Annotation                                                                                                           `path:"adjacency-sids/@adjacency-sid" ygotAnnotation:"true"`
	AdminGroup                  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup                    `path:"admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup                 []ygot.Annotation                                                                                                           `path:"@admin-group" ygotAnnotation:"true"`
	AvailableBandwidth          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth            `path:"available-bandwidth" module:"openconfig-network-instance"`
	ΛAvailableBandwidth         []ygot.Annotation                                                                                                           `path:"@available-bandwidth" ygotAnnotation:"true"`
	BandwidthConstraint         map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint `path:"bandwidth-constraints/bandwidth-constraint" module:"openconfig-network-instance"`
	ΛBandwidthConstraint        []ygot.Annotation                                                                                                           `path:"bandwidth-constraints/@bandwidth-constraint" ygotAnnotation:"true"`
	ExtendedAdminGroup          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup            `path:"extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup         []ygot.Annotation                                                                                                           `path:"@extended-admin-group" ygotAnnotation:"true"`
	Ipv4InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress          `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	ΛIpv4InterfaceAddress       []ygot.Annotation                                                                                                           `path:"@ipv4-interface-address" ygotAnnotation:"true"`
	Ipv4NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress           `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv4NeighborAddress        []ygot.Annotation                                                                                                           `path:"@ipv4-neighbor-address" ygotAnnotation:"true"`
	Ipv6InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress          `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	ΛIpv6InterfaceAddress       []ygot.Annotation                                                                                                           `path:"@ipv6-interface-address" ygotAnnotation:"true"`
	Ipv6NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress           `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv6NeighborAddress        []ygot.Annotation                                                                                                           `path:"@ipv6-neighbor-address" ygotAnnotation:"true"`
	LanAdjacencySid             map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid    `path:"lan-adjacency-sids/lan-adjacency-sid" module:"openconfig-network-instance"`
	ΛLanAdjacencySid            []ygot.Annotation                                                                                                           `path:"lan-adjacency-sids/@lan-adjacency-sid" ygotAnnotation:"true"`
	LinkAttributes              *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes                `path:"link-attributes" module:"openconfig-network-instance"`
	ΛLinkAttributes             []ygot.Annotation                                                                                                           `path:"@link-attributes" ygotAnnotation:"true"`
	LinkDelay                   *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay                     `path:"link-delay" module:"openconfig-network-instance"`
	ΛLinkDelay                  []ygot.Annotation                                                                                                           `path:"@link-delay" ygotAnnotation:"true"`
	LinkDelayVariation          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation            `path:"link-delay-variation" module:"openconfig-network-instance"`
	ΛLinkDelayVariation         []ygot.Annotation                                                                                                           `path:"@link-delay-variation" ygotAnnotation:"true"`
	LinkId                      *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId                        `path:"link-id" module:"openconfig-network-instance"`
	ΛLinkId                     []ygot.Annotation                                                                                                           `path:"@link-id" ygotAnnotation:"true"`
	LinkLoss                    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss                      `path:"link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss                   []ygot.Annotation                                                                                                           `path:"@link-loss" ygotAnnotation:"true"`
	LinkProtectionType          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType            `path:"link-protection-type" module:"openconfig-network-instance"`
	ΛLinkProtectionType         []ygot.Annotation                                                                                                           `path:"@link-protection-type" ygotAnnotation:"true"`
	MaxLinkBandwidth            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth              `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxLinkBandwidth           []ygot.Annotation                                                                                                           `path:"@max-link-bandwidth" ygotAnnotation:"true"`
	MaxReservableLinkBandwidth  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth    `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxReservableLinkBandwidth []ygot.Annotation                                                                                                           `path:"@max-reservable-link-bandwidth" ygotAnnotation:"true"`
	MinMaxLinkDelay             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay               `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ΛMinMaxLinkDelay            []ygot.Annotation                                                                                                           `path:"@min-max-link-delay" ygotAnnotation:"true"`
	ResidualBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth             `path:"residual-bandwidth" module:"openconfig-network-instance"`
	ΛResidualBandwidth          []ygot.Annotation                                                                                                           `path:"@residual-bandwidth" ygotAnnotation:"true"`
	SetupPriority               map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority       `path:"unreserved-bandwidth/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority              []ygot.Annotation                                                                                                           `path:"unreserved-bandwidth/@setup-priority" ygotAnnotation:"true"`
	TeDefaultMetric             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric               `path:"te-default-metric" module:"openconfig-network-instance"`
	ΛTeDefaultMetric            []ygot.Annotation                                                                                                           `path:"@te-default-metric" ygotAnnotation:"true"`
	Type                        E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                  `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType                       []ygot.Annotation                                                                                                           `path:"state/@type|@type" ygotAnnotation:"true"`
	UnconstrainedLsp            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp              `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	ΛUnconstrainedLsp           []ygot.Annotation                                                                                                           `path:"@unconstrained-lsp" ygotAnnotation:"true"`
	UtilizedBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth             `path:"utilized-bandwidth" module:"openconfig-network-instance"`
	ΛUtilizedBandwidth          []ygot.Annotation                                                                                                           `path:"@utilized-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) NewAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// RenameAdjacencySid renames an entry in the list AdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.AdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in AdjacencySid", newK)
	}

	e, ok := t.AdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdjacencySid", oldK)
	}
	e.Value = &newK

	t.AdjacencySid[newK] = e
	delete(t.AdjacencySid, oldK)
	return nil
}

// GetOrCreateAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid {

	key := Value

	if v, ok := t.AdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetAdjacencySid retrieves the value with the specified key from
// the AdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.AdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid struct to the
// list AdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	if _, ok := t.AdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list AdjacencySid %v", key)
	}

	t.AdjacencySid[key] = v
	return nil
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) NewBandwidthConstraint(ModelId uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// RenameBandwidthConstraint renames an entry in the list BandwidthConstraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameBandwidthConstraint(oldK, newK uint8) error {
	if _, ok := t.BandwidthConstraint[newK]; ok {
		return fmt.Errorf("key %v already exists in BandwidthConstraint", newK)
	}

	e, ok := t.BandwidthConstraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in BandwidthConstraint", oldK)
	}
	e.ModelId = &newK

	t.BandwidthConstraint[newK] = e
	delete(t.BandwidthConstraint, oldK)
	return nil
}

// GetOrCreateBandwidthConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint {

	key := ModelId

	if v, ok := t.BandwidthConstraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewBandwidthConstraint(ModelId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateBandwidthConstraint got unexpected error: %v", err))
	}
	return v
}

// GetBandwidthConstraint retrieves the value with the specified key from
// the BandwidthConstraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint {

	if t == nil {
		return nil
	}

	key := ModelId

	if lm, ok := t.BandwidthConstraint[key]; ok {
		return lm
	}
	return nil
}

// AppendBandwidthConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct to the
// list BandwidthConstraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendBandwidthConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) error {
	if v.ModelId == nil {
		return fmt.Errorf("invalid nil key received for ModelId")
	}

	key := *v.ModelId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	if _, ok := t.BandwidthConstraint[key]; ok {
		return fmt.Errorf("duplicate key for list BandwidthConstraint %v", key)
	}

	t.BandwidthConstraint[key] = v
	return nil
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) NewLanAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// RenameLanAdjacencySid renames an entry in the list LanAdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameLanAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.LanAdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in LanAdjacencySid", newK)
	}

	e, ok := t.LanAdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in LanAdjacencySid", oldK)
	}
	e.Value = &newK

	t.LanAdjacencySid[newK] = e
	delete(t.LanAdjacencySid, oldK)
	return nil
}

// GetOrCreateLanAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid {

	key := Value

	if v, ok := t.LanAdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLanAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLanAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetLanAdjacencySid retrieves the value with the specified key from
// the LanAdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.LanAdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendLanAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid struct to the
// list LanAdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendLanAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	if _, ok := t.LanAdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list LanAdjacencySid %v", key)
	}

	t.LanAdjacencySid[key] = v
	return nil
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) NewSetupPriority(Priority uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// RenameSetupPriority renames an entry in the list SetupPriority within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) RenameSetupPriority(oldK, newK uint8) error {
	if _, ok := t.SetupPriority[newK]; ok {
		return fmt.Errorf("key %v already exists in SetupPriority", newK)
	}

	e, ok := t.SetupPriority[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SetupPriority", oldK)
	}
	e.Priority = &newK

	t.SetupPriority[newK] = e
	delete(t.SetupPriority, oldK)
	return nil
}

// GetOrCreateSetupPriority retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority {

	key := Priority

	if v, ok := t.SetupPriority[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSetupPriority(Priority)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSetupPriority got unexpected error: %v", err))
	}
	return v
}

// GetSetupPriority retrieves the value with the specified key from
// the SetupPriority map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority {

	if t == nil {
		return nil
	}

	key := Priority

	if lm, ok := t.SetupPriority[key]; ok {
		return lm
	}
	return nil
}

// AppendSetupPriority appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority struct to the
// list SetupPriority of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) AppendSetupPriority(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) error {
	if v.Priority == nil {
		return fmt.Errorf("invalid nil key received for Priority")
	}

	key := *v.Priority

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority)
	}

	if _, ok := t.SetupPriority[key]; ok {
		return fmt.Errorf("duplicate key for list SetupPriority %v", key)
	}

	t.SetupPriority[key] = v
	return nil
}

// GetOrCreateAdminGroup retrieves the value of the AdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup {
	if t.AdminGroup != nil {
		return t.AdminGroup
	}
	t.AdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup{}
	return t.AdminGroup
}

// GetOrCreateAvailableBandwidth retrieves the value of the AvailableBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	t.AvailableBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth{}
	return t.AvailableBandwidth
}

// GetOrCreateExtendedAdminGroup retrieves the value of the ExtendedAdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	t.ExtendedAdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup{}
	return t.ExtendedAdminGroup
}

// GetOrCreateIpv4InterfaceAddress retrieves the value of the Ipv4InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	t.Ipv4InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress{}
	return t.Ipv4InterfaceAddress
}

// GetOrCreateIpv4NeighborAddress retrieves the value of the Ipv4NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	t.Ipv4NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress{}
	return t.Ipv4NeighborAddress
}

// GetOrCreateIpv6InterfaceAddress retrieves the value of the Ipv6InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	t.Ipv6InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress{}
	return t.Ipv6InterfaceAddress
}

// GetOrCreateIpv6NeighborAddress retrieves the value of the Ipv6NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	t.Ipv6NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress{}
	return t.Ipv6NeighborAddress
}

// GetOrCreateLinkAttributes retrieves the value of the LinkAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes {
	if t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	t.LinkAttributes = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes{}
	return t.LinkAttributes
}

// GetOrCreateLinkDelay retrieves the value of the LinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay {
	if t.LinkDelay != nil {
		return t.LinkDelay
	}
	t.LinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay{}
	return t.LinkDelay
}

// GetOrCreateLinkDelayVariation retrieves the value of the LinkDelayVariation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	t.LinkDelayVariation = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation{}
	return t.LinkDelayVariation
}

// GetOrCreateLinkId retrieves the value of the LinkId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId {
	if t.LinkId != nil {
		return t.LinkId
	}
	t.LinkId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId{}
	return t.LinkId
}

// GetOrCreateLinkLoss retrieves the value of the LinkLoss field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss {
	if t.LinkLoss != nil {
		return t.LinkLoss
	}
	t.LinkLoss = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss{}
	return t.LinkLoss
}

// GetOrCreateLinkProtectionType retrieves the value of the LinkProtectionType field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	t.LinkProtectionType = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType{}
	return t.LinkProtectionType
}

// GetOrCreateMaxLinkBandwidth retrieves the value of the MaxLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	t.MaxLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth{}
	return t.MaxLinkBandwidth
}

// GetOrCreateMaxReservableLinkBandwidth retrieves the value of the MaxReservableLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	t.MaxReservableLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth{}
	return t.MaxReservableLinkBandwidth
}

// GetOrCreateMinMaxLinkDelay retrieves the value of the MinMaxLinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	t.MinMaxLinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay{}
	return t.MinMaxLinkDelay
}

// GetOrCreateResidualBandwidth retrieves the value of the ResidualBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	t.ResidualBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth{}
	return t.ResidualBandwidth
}

// GetOrCreateTeDefaultMetric retrieves the value of the TeDefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	t.TeDefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric{}
	return t.TeDefaultMetric
}

// GetOrCreateUnconstrainedLsp retrieves the value of the UnconstrainedLsp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	t.UnconstrainedLsp = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp{}
	return t.UnconstrainedLsp
}

// GetOrCreateUtilizedBandwidth retrieves the value of the UtilizedBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetOrCreateUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	t.UtilizedBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth{}
	return t.UtilizedBandwidth
}

// GetAdminGroup returns the value of the AdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field AdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup {
	if t != nil && t.AdminGroup != nil {
		return t.AdminGroup
	}
	return nil
}

// GetAvailableBandwidth returns the value of the AvailableBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field AvailableBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t != nil && t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	return nil
}

// GetExtendedAdminGroup returns the value of the ExtendedAdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field ExtendedAdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t != nil && t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	return nil
}

// GetIpv4InterfaceAddress returns the value of the Ipv4InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t != nil && t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	return nil
}

// GetIpv4NeighborAddress returns the value of the Ipv4NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t != nil && t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	return nil
}

// GetIpv6InterfaceAddress returns the value of the Ipv6InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t != nil && t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	return nil
}

// GetIpv6NeighborAddress returns the value of the Ipv6NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t != nil && t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	return nil
}

// GetLinkAttributes returns the value of the LinkAttributes struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes {
	if t != nil && t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	return nil
}

// GetLinkDelay returns the value of the LinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay {
	if t != nil && t.LinkDelay != nil {
		return t.LinkDelay
	}
	return nil
}

// GetLinkDelayVariation returns the value of the LinkDelayVariation struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelayVariation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t != nil && t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	return nil
}

// GetLinkId returns the value of the LinkId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId {
	if t != nil && t.LinkId != nil {
		return t.LinkId
	}
	return nil
}

// GetLinkLoss returns the value of the LinkLoss struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkLoss is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss {
	if t != nil && t.LinkLoss != nil {
		return t.LinkLoss
	}
	return nil
}

// GetLinkProtectionType returns the value of the LinkProtectionType struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field LinkProtectionType is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t != nil && t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	return nil
}

// GetMaxLinkBandwidth returns the value of the MaxLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field MaxLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t != nil && t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	return nil
}

// GetMaxReservableLinkBandwidth returns the value of the MaxReservableLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field MaxReservableLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t != nil && t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	return nil
}

// GetMinMaxLinkDelay returns the value of the MinMaxLinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field MinMaxLinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t != nil && t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	return nil
}

// GetResidualBandwidth returns the value of the ResidualBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field ResidualBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t != nil && t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	return nil
}

// GetTeDefaultMetric returns the value of the TeDefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field TeDefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t != nil && t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	return nil
}

// GetUnconstrainedLsp returns the value of the UnconstrainedLsp struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field UnconstrainedLsp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t != nil && t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	return nil
}

// GetUtilizedBandwidth returns the value of the UtilizedBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv. If the receiver or the field UtilizedBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t != nil && t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid struct {
	ΛMetadata []ygot.Annotation      `path:"@" ygotAnnotation:"true"`
	Flags     []E_AdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation      `path:"state/@flags" ygotAnnotation:"true"`
	Value     *uint32                `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation      `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight    *uint8                 `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight   []ygot.Annotation      `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) GetFlags() []E_AdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdminGroup  []uint32          `path:"state/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup []ygot.Annotation `path:"state/@admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// GetAdminGroup retrieves the value of the leaf AdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminGroup is set, it can safely use t.GetAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) GetAdminGroup() []uint32 {
	if t == nil || t.AdminGroup == nil {
		return nil
	}
	return t.AdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct {
	ΛMetadata   []ygot.Annotation                                                                                                                       `path:"@" ygotAnnotation:"true"`
	Constraint  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint `path:"constraints/constraint" module:"openconfig-network-instance"`
	ΛConstraint []ygot.Annotation                                                                                                                       `path:"constraints/@constraint" ygotAnnotation:"true"`
	ModelId     *uint8                                                                                                                                  `path:"state/model-id|model-id" module:"openconfig-network-instance"`
	ΛModelId    []ygot.Annotation                                                                                                                       `path:"state/@model-id|@model-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) NewConstraint(ConstraintId uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// RenameConstraint renames an entry in the list Constraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) RenameConstraint(oldK, newK uint32) error {
	if _, ok := t.Constraint[newK]; ok {
		return fmt.Errorf("key %v already exists in Constraint", newK)
	}

	e, ok := t.Constraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Constraint", oldK)
	}
	e.ConstraintId = &newK

	t.Constraint[newK] = e
	delete(t.Constraint, oldK)
	return nil
}

// GetOrCreateConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) GetOrCreateConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	key := ConstraintId

	if v, ok := t.Constraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewConstraint(ConstraintId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateConstraint got unexpected error: %v", err))
	}
	return v
}

// GetConstraint retrieves the value with the specified key from
// the Constraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) GetConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	if t == nil {
		return nil
	}

	key := ConstraintId

	if lm, ok := t.Constraint[key]; ok {
		return lm
	}
	return nil
}

// AppendConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct to the
// list Constraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) AppendConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) error {
	if v.ConstraintId == nil {
		return fmt.Errorf("invalid nil key received for ConstraintId")
	}

	key := *v.ConstraintId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	if _, ok := t.Constraint[key]; ok {
		return fmt.Errorf("duplicate key for list Constraint %v", key)
	}

	t.Constraint[key] = v
	return nil
}

// GetModelId retrieves the value of the leaf ModelId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ModelId is set, it can safely use t.GetModelId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ModelId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) GetModelId() uint8 {
	if t == nil || t.ModelId == nil {
		return 0
	}
	return *t.ModelId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth     Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth    []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	ConstraintId  *uint32           `path:"state/constraint-id|constraint-id" module:"openconfig-network-instance"`
	ΛConstraintId []ygot.Annotation `path:"state/@constraint-id|@constraint-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetConstraintId retrieves the value of the leaf ConstraintId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConstraintId is set, it can safely use t.GetConstraintId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConstraintId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetConstraintId() uint32 {
	if t == nil || t.ConstraintId == nil {
		return 0
	}
	return *t.ConstraintId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExtendedAdminGroup  []uint32          `path:"state/extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup []ygot.Annotation `path:"state/@extended-admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// GetExtendedAdminGroup retrieves the value of the leaf ExtendedAdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtendedAdminGroup is set, it can safely use t.GetExtendedAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtendedAdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) GetExtendedAdminGroup() []uint32 {
	if t == nil || t.ExtendedAdminGroup == nil {
		return nil
	}
	return t.ExtendedAdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid struct {
	ΛMetadata   []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Flags       []E_LanAdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags      []ygot.Annotation         `path:"state/@flags" ygotAnnotation:"true"`
	NeighborId  *string                   `path:"state/neighbor-id" module:"openconfig-network-instance"`
	ΛNeighborId []ygot.Annotation         `path:"state/@neighbor-id" ygotAnnotation:"true"`
	Value       *uint32                   `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue      []ygot.Annotation         `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight      *uint8                    `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight     []ygot.Annotation         `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetFlags() []E_LanAdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetNeighborId retrieves the value of the leaf NeighborId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborId is set, it can safely use t.GetNeighborId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetNeighborId() string {
	if t == nil || t.NeighborId == nil {
		return ""
	}
	return *t.NeighborId
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes struct {
	ΛMetadata        []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	LocalProtection  []E_LinkAttributes_LocalProtection `path:"state/local-protection" module:"openconfig-network-instance"`
	ΛLocalProtection []ygot.Annotation                  `path:"state/@local-protection" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// GetLocalProtection retrieves the value of the leaf LocalProtection from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalProtection is set, it can safely use t.GetLocalProtection()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalProtection == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) GetLocalProtection() []E_LinkAttributes_LocalProtection {
	if t == nil || t.LocalProtection == nil {
		return nil
	}
	return t.LocalProtection
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Local     *uint32           `path:"state/local" module:"openconfig-network-instance"`
	ΛLocal    []ygot.Annotation `path:"state/@local" ygotAnnotation:"true"`
	Remote    *uint32           `path:"state/remote" module:"openconfig-network-instance"`
	ΛRemote   []ygot.Annotation `path:"state/@remote" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) IsYANGGoStruct() {
}

// GetLocal retrieves the value of the leaf Local from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Local is set, it can safely use t.GetLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Local == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) GetLocal() uint32 {
	if t == nil || t.Local == nil {
		return 0
	}
	return *t.Local
}

// GetRemote retrieves the value of the leaf Remote from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Remote is set, it can safely use t.GetRemote()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Remote == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) GetRemote() uint32 {
	if t == nil || t.Remote == nil {
		return 0
	}
	return *t.Remote
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	LinkLoss  *uint32           `path:"state/link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss []ygot.Annotation `path:"state/@link-loss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetLinkLoss retrieves the value of the leaf LinkLoss from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLoss is set, it can safely use t.GetLinkLoss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLoss == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) GetLinkLoss() uint32 {
	if t == nil || t.LinkLoss == nil {
		return 0
	}
	return *t.LinkLoss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType struct {
	ΛMetadata []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	Type      []E_LinkProtectionType_Type `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation           `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) GetType() []E_LinkProtectionType_Type {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	MaxDelay  *uint32           `path:"state/max-delay" module:"openconfig-network-instance"`
	ΛMaxDelay []ygot.Annotation `path:"state/@max-delay" ygotAnnotation:"true"`
	MinDelay  *uint32           `path:"state/min-delay" module:"openconfig-network-instance"`
	ΛMinDelay []ygot.Annotation `path:"state/@min-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetMaxDelay retrieves the value of the leaf MaxDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxDelay is set, it can safely use t.GetMaxDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMaxDelay() uint32 {
	if t == nil || t.MaxDelay == nil {
		return 0
	}
	return *t.MaxDelay
}

// GetMinDelay retrieves the value of the leaf MinDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinDelay is set, it can safely use t.GetMinDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMinDelay() uint32 {
	if t == nil || t.MinDelay == nil {
		return 0
	}
	return *t.MinDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	Priority   *uint8            `path:"state/priority|priority" module:"openconfig-network-instance"`
	ΛPriority  []ygot.Annotation `path:"state/@priority|@priority" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint32           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Count     *uint16                                    `path:"state/count" module:"openconfig-network-instance"`
	ΛCount    []ygot.Annotation                          `path:"state/@count" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// GetCount retrieves the value of the leaf Count from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Count is set, it can safely use t.GetCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Count == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetCount() uint16 {
	if t == nil || t.Count == nil {
		return 0
	}
	return *t.Count
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsisNeighborAttribute_Neighbor_Instance_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn struct {
	ΛMetadata []ygot.Annotation                                                                                                              `path:"@" ygotAnnotation:"true"`
	Neighbor  map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor []ygot.Annotation                                                                                                              `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key represents the key for list Neighbor of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key struct {
	MtId     uint16 `path:"mt-id"`
	SystemId string `path:"system-id"`
}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) NewNeighbor(MtId uint16, SystemId string) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor)
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor{
		MtId:     &MtId,
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) RenameNeighbor(oldK, newK NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.MtId = &newK.MtId
	e.SystemId = &newK.SystemId

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) GetOrCreateNeighbor(MtId uint16, SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor {

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(MtId, SystemId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) GetNeighbor(MtId uint16, SystemId string) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) AppendNeighbor(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) error {
	if v.MtId == nil {
		return fmt.Errorf("invalid nil key for MtId")
	}

	if v.SystemId == nil {
		return fmt.Errorf("invalid nil key for SystemId")
	}

	key := NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key{
		MtId:     *v.MtId,
		SystemId: *v.SystemId,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Key]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor struct {
	ΛMetadata []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	Instance  map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance `path:"instances/instance" module:"openconfig-network-instance"`
	ΛInstance []ygot.Annotation                                                               `path:"instances/@instance" ygotAnnotation:"true"`
	MtId      *uint16                                                                         `path:"state/mt-id|mt-id" module:"openconfig-network-instance"`
	ΛMtId     []ygot.Annotation                                                               `path:"state/@mt-id|@mt-id" ygotAnnotation:"true"`
	SystemId  *string                                                                         `path:"state/system-id|system-id" module:"openconfig-network-instance"`
	ΛSystemId []ygot.Annotation                                                               `path:"state/@system-id|@system-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) IsYANGGoStruct() {}

// NewInstance creates a new entry in the Instance list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) NewInstance(Id uint64) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// RenameInstance renames an entry in the list Instance within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) RenameInstance(oldK, newK uint64) error {
	if _, ok := t.Instance[newK]; ok {
		return fmt.Errorf("key %v already exists in Instance", newK)
	}

	e, ok := t.Instance[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Instance", oldK)
	}
	e.Id = &newK

	t.Instance[newK] = e
	delete(t.Instance, oldK)
	return nil
}

// GetOrCreateInstance retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) GetOrCreateInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance {

	key := Id

	if v, ok := t.Instance[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInstance(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInstance got unexpected error: %v", err))
	}
	return v
}

// GetInstance retrieves the value with the specified key from
// the Instance map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) GetInstance(Id uint64) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Instance[key]; ok {
		return lm
	}
	return nil
}

// AppendInstance appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct to the
// list Instance of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) AppendInstance(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance)
	}

	if _, ok := t.Instance[key]; ok {
		return fmt.Errorf("duplicate key for list Instance %v", key)
	}

	t.Instance[key] = v
	return nil
}

// GetMtId retrieves the value of the leaf MtId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtId is set, it can safely use t.GetMtId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) GetMtId() uint16 {
	if t == nil || t.MtId == nil {
		return 0
	}
	return *t.MtId
}

// GetSystemId retrieves the value of the leaf SystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemId is set, it can safely use t.GetSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) GetSystemId() string {
	if t == nil || t.SystemId == nil {
		return ""
	}
	return *t.SystemId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"mt-id":     *t.MtId,
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct {
	ΛMetadata        []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	Id               *uint64                                                                                                                    `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId              []ygot.Annotation                                                                                                          `path:"state/@id|@id" ygotAnnotation:"true"`
	Metric           *uint32                                                                                                                    `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric          []ygot.Annotation                                                                                                          `path:"state/@metric" ygotAnnotation:"true"`
	Subtlv           map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv `path:"subtlvs/subtlv" module:"openconfig-network-instance"`
	ΛSubtlv          []ygot.Annotation                                                                                                          `path:"subtlvs/@subtlv" ygotAnnotation:"true"`
	UndefinedSubtlv  map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv                             `path:"undefined-subtlvs/undefined-subtlv" module:"openconfig-network-instance"`
	ΛUndefinedSubtlv []ygot.Annotation                                                                                                          `path:"undefined-subtlvs/@undefined-subtlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) IsYANGGoStruct() {}

// NewSubtlv creates a new entry in the Subtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// RenameSubtlv renames an entry in the list Subtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) RenameSubtlv(oldK, newK E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) error {
	if _, ok := t.Subtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Subtlv", newK)
	}

	e, ok := t.Subtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Subtlv", oldK)
	}
	e.Type = newK

	t.Subtlv[newK] = e
	delete(t.Subtlv, oldK)
	return nil
}

// GetOrCreateSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) GetOrCreateSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv {

	key := Type

	if v, ok := t.Subtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetSubtlv retrieves the value with the specified key from
// the Subtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) GetSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.Subtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct to the
// list Subtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) AppendSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv)
	}

	if _, ok := t.Subtlv[key]; ok {
		return fmt.Errorf("duplicate key for list Subtlv %v", key)
	}

	t.Subtlv[key] = v
	return nil
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) NewUndefinedSubtlv(Type uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// RenameUndefinedSubtlv renames an entry in the list UndefinedSubtlv within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) RenameUndefinedSubtlv(oldK, newK uint8) error {
	if _, ok := t.UndefinedSubtlv[newK]; ok {
		return fmt.Errorf("key %v already exists in UndefinedSubtlv", newK)
	}

	e, ok := t.UndefinedSubtlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UndefinedSubtlv", oldK)
	}
	e.Type = &newK

	t.UndefinedSubtlv[newK] = e
	delete(t.UndefinedSubtlv, oldK)
	return nil
}

// GetOrCreateUndefinedSubtlv retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) GetOrCreateUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv {

	key := Type

	if v, ok := t.UndefinedSubtlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUndefinedSubtlv(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUndefinedSubtlv got unexpected error: %v", err))
	}
	return v
}

// GetUndefinedSubtlv retrieves the value with the specified key from
// the UndefinedSubtlv map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) GetUndefinedSubtlv(Type uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.UndefinedSubtlv[key]; ok {
		return lm
	}
	return nil
}

// AppendUndefinedSubtlv appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv struct to the
// list UndefinedSubtlv of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) AppendUndefinedSubtlv(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key received for Type")
	}

	key := *v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv)
	}

	if _, ok := t.UndefinedSubtlv[key]; ok {
		return fmt.Errorf("duplicate key for list UndefinedSubtlv %v", key)
	}

	t.UndefinedSubtlv[key] = v
	return nil
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) GetId() uint64 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct {
	ΛMetadata                   []ygot.Annotation                                                                                         `path:"@" ygotAnnotation:"true"`
	AdjacencySid                map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid       `path:"adjacency-sids/adjacency-sid" module:"openconfig-network-instance"`
	ΛAdjacencySid               []ygot.Annotation                                                                                         `path:"adjacency-sids/@adjacency-sid" ygotAnnotation:"true"`
	AdminGroup                  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup                    `path:"admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup                 []ygot.Annotation                                                                                         `path:"@admin-group" ygotAnnotation:"true"`
	AvailableBandwidth          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth            `path:"available-bandwidth" module:"openconfig-network-instance"`
	ΛAvailableBandwidth         []ygot.Annotation                                                                                         `path:"@available-bandwidth" ygotAnnotation:"true"`
	BandwidthConstraint         map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint `path:"bandwidth-constraints/bandwidth-constraint" module:"openconfig-network-instance"`
	ΛBandwidthConstraint        []ygot.Annotation                                                                                         `path:"bandwidth-constraints/@bandwidth-constraint" ygotAnnotation:"true"`
	ExtendedAdminGroup          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup            `path:"extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup         []ygot.Annotation                                                                                         `path:"@extended-admin-group" ygotAnnotation:"true"`
	Ipv4InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress          `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	ΛIpv4InterfaceAddress       []ygot.Annotation                                                                                         `path:"@ipv4-interface-address" ygotAnnotation:"true"`
	Ipv4NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress           `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv4NeighborAddress        []ygot.Annotation                                                                                         `path:"@ipv4-neighbor-address" ygotAnnotation:"true"`
	Ipv6InterfaceAddress        *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress          `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	ΛIpv6InterfaceAddress       []ygot.Annotation                                                                                         `path:"@ipv6-interface-address" ygotAnnotation:"true"`
	Ipv6NeighborAddress         *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress           `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	ΛIpv6NeighborAddress        []ygot.Annotation                                                                                         `path:"@ipv6-neighbor-address" ygotAnnotation:"true"`
	LanAdjacencySid             map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid    `path:"lan-adjacency-sids/lan-adjacency-sid" module:"openconfig-network-instance"`
	ΛLanAdjacencySid            []ygot.Annotation                                                                                         `path:"lan-adjacency-sids/@lan-adjacency-sid" ygotAnnotation:"true"`
	LinkAttributes              *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes                `path:"link-attributes" module:"openconfig-network-instance"`
	ΛLinkAttributes             []ygot.Annotation                                                                                         `path:"@link-attributes" ygotAnnotation:"true"`
	LinkDelay                   *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay                     `path:"link-delay" module:"openconfig-network-instance"`
	ΛLinkDelay                  []ygot.Annotation                                                                                         `path:"@link-delay" ygotAnnotation:"true"`
	LinkDelayVariation          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation            `path:"link-delay-variation" module:"openconfig-network-instance"`
	ΛLinkDelayVariation         []ygot.Annotation                                                                                         `path:"@link-delay-variation" ygotAnnotation:"true"`
	LinkId                      *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId                        `path:"link-id" module:"openconfig-network-instance"`
	ΛLinkId                     []ygot.Annotation                                                                                         `path:"@link-id" ygotAnnotation:"true"`
	LinkLoss                    *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss                      `path:"link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss                   []ygot.Annotation                                                                                         `path:"@link-loss" ygotAnnotation:"true"`
	LinkProtectionType          *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType            `path:"link-protection-type" module:"openconfig-network-instance"`
	ΛLinkProtectionType         []ygot.Annotation                                                                                         `path:"@link-protection-type" ygotAnnotation:"true"`
	MaxLinkBandwidth            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth              `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxLinkBandwidth           []ygot.Annotation                                                                                         `path:"@max-link-bandwidth" ygotAnnotation:"true"`
	MaxReservableLinkBandwidth  *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth    `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	ΛMaxReservableLinkBandwidth []ygot.Annotation                                                                                         `path:"@max-reservable-link-bandwidth" ygotAnnotation:"true"`
	MinMaxLinkDelay             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay               `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ΛMinMaxLinkDelay            []ygot.Annotation                                                                                         `path:"@min-max-link-delay" ygotAnnotation:"true"`
	ResidualBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth             `path:"residual-bandwidth" module:"openconfig-network-instance"`
	ΛResidualBandwidth          []ygot.Annotation                                                                                         `path:"@residual-bandwidth" ygotAnnotation:"true"`
	SetupPriority               map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority       `path:"unreserved-bandwidth/setup-priority" module:"openconfig-network-instance"`
	ΛSetupPriority              []ygot.Annotation                                                                                         `path:"unreserved-bandwidth/@setup-priority" ygotAnnotation:"true"`
	TeDefaultMetric             *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric               `path:"te-default-metric" module:"openconfig-network-instance"`
	ΛTeDefaultMetric            []ygot.Annotation                                                                                         `path:"@te-default-metric" ygotAnnotation:"true"`
	Type                        E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType                       []ygot.Annotation                                                                                         `path:"state/@type|@type" ygotAnnotation:"true"`
	UnconstrainedLsp            *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp              `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	ΛUnconstrainedLsp           []ygot.Annotation                                                                                         `path:"@unconstrained-lsp" ygotAnnotation:"true"`
	UtilizedBandwidth           *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth             `path:"utilized-bandwidth" module:"openconfig-network-instance"`
	ΛUtilizedBandwidth          []ygot.Annotation                                                                                         `path:"@utilized-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) IsYANGGoStruct() {}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) NewAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// RenameAdjacencySid renames an entry in the list AdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) RenameAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.AdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in AdjacencySid", newK)
	}

	e, ok := t.AdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdjacencySid", oldK)
	}
	e.Value = &newK

	t.AdjacencySid[newK] = e
	delete(t.AdjacencySid, oldK)
	return nil
}

// GetOrCreateAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid {

	key := Value

	if v, ok := t.AdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetAdjacencySid retrieves the value with the specified key from
// the AdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.AdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid struct to the
// list AdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) AppendAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid)
	}

	if _, ok := t.AdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list AdjacencySid %v", key)
	}

	t.AdjacencySid[key] = v
	return nil
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) NewBandwidthConstraint(ModelId uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// RenameBandwidthConstraint renames an entry in the list BandwidthConstraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) RenameBandwidthConstraint(oldK, newK uint8) error {
	if _, ok := t.BandwidthConstraint[newK]; ok {
		return fmt.Errorf("key %v already exists in BandwidthConstraint", newK)
	}

	e, ok := t.BandwidthConstraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in BandwidthConstraint", oldK)
	}
	e.ModelId = &newK

	t.BandwidthConstraint[newK] = e
	delete(t.BandwidthConstraint, oldK)
	return nil
}

// GetOrCreateBandwidthConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint {

	key := ModelId

	if v, ok := t.BandwidthConstraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewBandwidthConstraint(ModelId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateBandwidthConstraint got unexpected error: %v", err))
	}
	return v
}

// GetBandwidthConstraint retrieves the value with the specified key from
// the BandwidthConstraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetBandwidthConstraint(ModelId uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint {

	if t == nil {
		return nil
	}

	key := ModelId

	if lm, ok := t.BandwidthConstraint[key]; ok {
		return lm
	}
	return nil
}

// AppendBandwidthConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint struct to the
// list BandwidthConstraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) AppendBandwidthConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) error {
	if v.ModelId == nil {
		return fmt.Errorf("invalid nil key received for ModelId")
	}

	key := *v.ModelId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint)
	}

	if _, ok := t.BandwidthConstraint[key]; ok {
		return fmt.Errorf("duplicate key for list BandwidthConstraint %v", key)
	}

	t.BandwidthConstraint[key] = v
	return nil
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) NewLanAdjacencySid(Value uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// RenameLanAdjacencySid renames an entry in the list LanAdjacencySid within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) RenameLanAdjacencySid(oldK, newK uint32) error {
	if _, ok := t.LanAdjacencySid[newK]; ok {
		return fmt.Errorf("key %v already exists in LanAdjacencySid", newK)
	}

	e, ok := t.LanAdjacencySid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in LanAdjacencySid", oldK)
	}
	e.Value = &newK

	t.LanAdjacencySid[newK] = e
	delete(t.LanAdjacencySid, oldK)
	return nil
}

// GetOrCreateLanAdjacencySid retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid {

	key := Value

	if v, ok := t.LanAdjacencySid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLanAdjacencySid(Value)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLanAdjacencySid got unexpected error: %v", err))
	}
	return v
}

// GetLanAdjacencySid retrieves the value with the specified key from
// the LanAdjacencySid map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLanAdjacencySid(Value uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid {

	if t == nil {
		return nil
	}

	key := Value

	if lm, ok := t.LanAdjacencySid[key]; ok {
		return lm
	}
	return nil
}

// AppendLanAdjacencySid appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid struct to the
// list LanAdjacencySid of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) AppendLanAdjacencySid(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) error {
	if v.Value == nil {
		return fmt.Errorf("invalid nil key received for Value")
	}

	key := *v.Value

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid)
	}

	if _, ok := t.LanAdjacencySid[key]; ok {
		return fmt.Errorf("duplicate key for list LanAdjacencySid %v", key)
	}

	t.LanAdjacencySid[key] = v
	return nil
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) NewSetupPriority(Priority uint8) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// RenameSetupPriority renames an entry in the list SetupPriority within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) RenameSetupPriority(oldK, newK uint8) error {
	if _, ok := t.SetupPriority[newK]; ok {
		return fmt.Errorf("key %v already exists in SetupPriority", newK)
	}

	e, ok := t.SetupPriority[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SetupPriority", oldK)
	}
	e.Priority = &newK

	t.SetupPriority[newK] = e
	delete(t.SetupPriority, oldK)
	return nil
}

// GetOrCreateSetupPriority retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority {

	key := Priority

	if v, ok := t.SetupPriority[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSetupPriority(Priority)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSetupPriority got unexpected error: %v", err))
	}
	return v
}

// GetSetupPriority retrieves the value with the specified key from
// the SetupPriority map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetSetupPriority(Priority uint8) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority {

	if t == nil {
		return nil
	}

	key := Priority

	if lm, ok := t.SetupPriority[key]; ok {
		return lm
	}
	return nil
}

// AppendSetupPriority appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority struct to the
// list SetupPriority of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) AppendSetupPriority(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) error {
	if v.Priority == nil {
		return fmt.Errorf("invalid nil key received for Priority")
	}

	key := *v.Priority

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority)
	}

	if _, ok := t.SetupPriority[key]; ok {
		return fmt.Errorf("duplicate key for list SetupPriority %v", key)
	}

	t.SetupPriority[key] = v
	return nil
}

// GetOrCreateAdminGroup retrieves the value of the AdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup {
	if t.AdminGroup != nil {
		return t.AdminGroup
	}
	t.AdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup{}
	return t.AdminGroup
}

// GetOrCreateAvailableBandwidth retrieves the value of the AvailableBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	t.AvailableBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth{}
	return t.AvailableBandwidth
}

// GetOrCreateExtendedAdminGroup retrieves the value of the ExtendedAdminGroup field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	t.ExtendedAdminGroup = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup{}
	return t.ExtendedAdminGroup
}

// GetOrCreateIpv4InterfaceAddress retrieves the value of the Ipv4InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	t.Ipv4InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress{}
	return t.Ipv4InterfaceAddress
}

// GetOrCreateIpv4NeighborAddress retrieves the value of the Ipv4NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	t.Ipv4NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress{}
	return t.Ipv4NeighborAddress
}

// GetOrCreateIpv6InterfaceAddress retrieves the value of the Ipv6InterfaceAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	t.Ipv6InterfaceAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress{}
	return t.Ipv6InterfaceAddress
}

// GetOrCreateIpv6NeighborAddress retrieves the value of the Ipv6NeighborAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	t.Ipv6NeighborAddress = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress{}
	return t.Ipv6NeighborAddress
}

// GetOrCreateLinkAttributes retrieves the value of the LinkAttributes field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes {
	if t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	t.LinkAttributes = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes{}
	return t.LinkAttributes
}

// GetOrCreateLinkDelay retrieves the value of the LinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay {
	if t.LinkDelay != nil {
		return t.LinkDelay
	}
	t.LinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay{}
	return t.LinkDelay
}

// GetOrCreateLinkDelayVariation retrieves the value of the LinkDelayVariation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	t.LinkDelayVariation = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation{}
	return t.LinkDelayVariation
}

// GetOrCreateLinkId retrieves the value of the LinkId field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId {
	if t.LinkId != nil {
		return t.LinkId
	}
	t.LinkId = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId{}
	return t.LinkId
}

// GetOrCreateLinkLoss retrieves the value of the LinkLoss field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss {
	if t.LinkLoss != nil {
		return t.LinkLoss
	}
	t.LinkLoss = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss{}
	return t.LinkLoss
}

// GetOrCreateLinkProtectionType retrieves the value of the LinkProtectionType field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	t.LinkProtectionType = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType{}
	return t.LinkProtectionType
}

// GetOrCreateMaxLinkBandwidth retrieves the value of the MaxLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	t.MaxLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth{}
	return t.MaxLinkBandwidth
}

// GetOrCreateMaxReservableLinkBandwidth retrieves the value of the MaxReservableLinkBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	t.MaxReservableLinkBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth{}
	return t.MaxReservableLinkBandwidth
}

// GetOrCreateMinMaxLinkDelay retrieves the value of the MinMaxLinkDelay field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	t.MinMaxLinkDelay = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay{}
	return t.MinMaxLinkDelay
}

// GetOrCreateResidualBandwidth retrieves the value of the ResidualBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	t.ResidualBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth{}
	return t.ResidualBandwidth
}

// GetOrCreateTeDefaultMetric retrieves the value of the TeDefaultMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	t.TeDefaultMetric = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric{}
	return t.TeDefaultMetric
}

// GetOrCreateUnconstrainedLsp retrieves the value of the UnconstrainedLsp field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	t.UnconstrainedLsp = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp{}
	return t.UnconstrainedLsp
}

// GetOrCreateUtilizedBandwidth retrieves the value of the UtilizedBandwidth field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetOrCreateUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	t.UtilizedBandwidth = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth{}
	return t.UtilizedBandwidth
}

// GetAdminGroup returns the value of the AdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field AdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup {
	if t != nil && t.AdminGroup != nil {
		return t.AdminGroup
	}
	return nil
}

// GetAvailableBandwidth returns the value of the AvailableBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field AvailableBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetAvailableBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth {
	if t != nil && t.AvailableBandwidth != nil {
		return t.AvailableBandwidth
	}
	return nil
}

// GetExtendedAdminGroup returns the value of the ExtendedAdminGroup struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field ExtendedAdminGroup is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetExtendedAdminGroup() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup {
	if t != nil && t.ExtendedAdminGroup != nil {
		return t.ExtendedAdminGroup
	}
	return nil
}

// GetIpv4InterfaceAddress returns the value of the Ipv4InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetIpv4InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress {
	if t != nil && t.Ipv4InterfaceAddress != nil {
		return t.Ipv4InterfaceAddress
	}
	return nil
}

// GetIpv4NeighborAddress returns the value of the Ipv4NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field Ipv4NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetIpv4NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress {
	if t != nil && t.Ipv4NeighborAddress != nil {
		return t.Ipv4NeighborAddress
	}
	return nil
}

// GetIpv6InterfaceAddress returns the value of the Ipv6InterfaceAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6InterfaceAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetIpv6InterfaceAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress {
	if t != nil && t.Ipv6InterfaceAddress != nil {
		return t.Ipv6InterfaceAddress
	}
	return nil
}

// GetIpv6NeighborAddress returns the value of the Ipv6NeighborAddress struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field Ipv6NeighborAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetIpv6NeighborAddress() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress {
	if t != nil && t.Ipv6NeighborAddress != nil {
		return t.Ipv6NeighborAddress
	}
	return nil
}

// GetLinkAttributes returns the value of the LinkAttributes struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field LinkAttributes is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLinkAttributes() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes {
	if t != nil && t.LinkAttributes != nil {
		return t.LinkAttributes
	}
	return nil
}

// GetLinkDelay returns the value of the LinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay {
	if t != nil && t.LinkDelay != nil {
		return t.LinkDelay
	}
	return nil
}

// GetLinkDelayVariation returns the value of the LinkDelayVariation struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field LinkDelayVariation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLinkDelayVariation() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation {
	if t != nil && t.LinkDelayVariation != nil {
		return t.LinkDelayVariation
	}
	return nil
}

// GetLinkId returns the value of the LinkId struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field LinkId is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLinkId() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId {
	if t != nil && t.LinkId != nil {
		return t.LinkId
	}
	return nil
}

// GetLinkLoss returns the value of the LinkLoss struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field LinkLoss is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLinkLoss() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss {
	if t != nil && t.LinkLoss != nil {
		return t.LinkLoss
	}
	return nil
}

// GetLinkProtectionType returns the value of the LinkProtectionType struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field LinkProtectionType is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetLinkProtectionType() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType {
	if t != nil && t.LinkProtectionType != nil {
		return t.LinkProtectionType
	}
	return nil
}

// GetMaxLinkBandwidth returns the value of the MaxLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field MaxLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetMaxLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth {
	if t != nil && t.MaxLinkBandwidth != nil {
		return t.MaxLinkBandwidth
	}
	return nil
}

// GetMaxReservableLinkBandwidth returns the value of the MaxReservableLinkBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field MaxReservableLinkBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetMaxReservableLinkBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth {
	if t != nil && t.MaxReservableLinkBandwidth != nil {
		return t.MaxReservableLinkBandwidth
	}
	return nil
}

// GetMinMaxLinkDelay returns the value of the MinMaxLinkDelay struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field MinMaxLinkDelay is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetMinMaxLinkDelay() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay {
	if t != nil && t.MinMaxLinkDelay != nil {
		return t.MinMaxLinkDelay
	}
	return nil
}

// GetResidualBandwidth returns the value of the ResidualBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field ResidualBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetResidualBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth {
	if t != nil && t.ResidualBandwidth != nil {
		return t.ResidualBandwidth
	}
	return nil
}

// GetTeDefaultMetric returns the value of the TeDefaultMetric struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field TeDefaultMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetTeDefaultMetric() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric {
	if t != nil && t.TeDefaultMetric != nil {
		return t.TeDefaultMetric
	}
	return nil
}

// GetUnconstrainedLsp returns the value of the UnconstrainedLsp struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field UnconstrainedLsp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetUnconstrainedLsp() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp {
	if t != nil && t.UnconstrainedLsp != nil {
		return t.UnconstrainedLsp
	}
	return nil
}

// GetUtilizedBandwidth returns the value of the UtilizedBandwidth struct pointer
// from NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv. If the receiver or the field UtilizedBandwidth is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetUtilizedBandwidth() *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth {
	if t != nil && t.UtilizedBandwidth != nil {
		return t.UtilizedBandwidth
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid struct {
	ΛMetadata []ygot.Annotation      `path:"@" ygotAnnotation:"true"`
	Flags     []E_AdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags    []ygot.Annotation      `path:"state/@flags" ygotAnnotation:"true"`
	Value     *uint32                `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation      `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight    *uint8                 `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight   []ygot.Annotation      `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) GetFlags() []E_AdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdminGroup  []uint32          `path:"state/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup []ygot.Annotation `path:"state/@admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// GetAdminGroup retrieves the value of the leaf AdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminGroup is set, it can safely use t.GetAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup) GetAdminGroup() []uint32 {
	if t == nil || t.AdminGroup == nil {
		return nil
	}
	return t.AdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint struct {
	ΛMetadata   []ygot.Annotation                                                                                                     `path:"@" ygotAnnotation:"true"`
	Constraint  map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint `path:"constraints/constraint" module:"openconfig-network-instance"`
	ΛConstraint []ygot.Annotation                                                                                                     `path:"constraints/@constraint" ygotAnnotation:"true"`
	ModelId     *uint8                                                                                                                `path:"state/model-id|model-id" module:"openconfig-network-instance"`
	ΛModelId    []ygot.Annotation                                                                                                     `path:"state/@model-id|@model-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) NewConstraint(ConstraintId uint32) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// RenameConstraint renames an entry in the list Constraint within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) RenameConstraint(oldK, newK uint32) error {
	if _, ok := t.Constraint[newK]; ok {
		return fmt.Errorf("key %v already exists in Constraint", newK)
	}

	e, ok := t.Constraint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Constraint", oldK)
	}
	e.ConstraintId = &newK

	t.Constraint[newK] = e
	delete(t.Constraint, oldK)
	return nil
}

// GetOrCreateConstraint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) GetOrCreateConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	key := ConstraintId

	if v, ok := t.Constraint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewConstraint(ConstraintId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateConstraint got unexpected error: %v", err))
	}
	return v
}

// GetConstraint retrieves the value with the specified key from
// the Constraint map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) GetConstraint(ConstraintId uint32) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint {

	if t == nil {
		return nil
	}

	key := ConstraintId

	if lm, ok := t.Constraint[key]; ok {
		return lm
	}
	return nil
}

// AppendConstraint appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct to the
// list Constraint of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) AppendConstraint(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) error {
	if v.ConstraintId == nil {
		return fmt.Errorf("invalid nil key received for ConstraintId")
	}

	key := *v.ConstraintId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint)
	}

	if _, ok := t.Constraint[key]; ok {
		return fmt.Errorf("duplicate key for list Constraint %v", key)
	}

	t.Constraint[key] = v
	return nil
}

// GetModelId retrieves the value of the leaf ModelId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ModelId is set, it can safely use t.GetModelId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ModelId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) GetModelId() uint8 {
	if t == nil || t.ModelId == nil {
		return 0
	}
	return *t.ModelId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth     Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth    []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	ConstraintId  *uint32           `path:"state/constraint-id|constraint-id" module:"openconfig-network-instance"`
	ΛConstraintId []ygot.Annotation `path:"state/@constraint-id|@constraint-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetConstraintId retrieves the value of the leaf ConstraintId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConstraintId is set, it can safely use t.GetConstraintId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConstraintId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) GetConstraintId() uint32 {
	if t == nil || t.ConstraintId == nil {
		return 0
	}
	return *t.ConstraintId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_BandwidthConstraint_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExtendedAdminGroup  []uint32          `path:"state/extended-admin-group" module:"openconfig-network-instance"`
	ΛExtendedAdminGroup []ygot.Annotation `path:"state/@extended-admin-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// GetExtendedAdminGroup retrieves the value of the leaf ExtendedAdminGroup from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExtendedAdminGroup is set, it can safely use t.GetExtendedAdminGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExtendedAdminGroup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup) GetExtendedAdminGroup() []uint32 {
	if t == nil || t.ExtendedAdminGroup == nil {
		return nil
	}
	return t.ExtendedAdminGroup
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid struct {
	ΛMetadata   []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Flags       []E_LanAdjacencySid_Flags `path:"state/flags" module:"openconfig-network-instance"`
	ΛFlags      []ygot.Annotation         `path:"state/@flags" ygotAnnotation:"true"`
	NeighborId  *string                   `path:"state/neighbor-id" module:"openconfig-network-instance"`
	ΛNeighborId []ygot.Annotation         `path:"state/@neighbor-id" ygotAnnotation:"true"`
	Value       *uint32                   `path:"state/value|value" module:"openconfig-network-instance"`
	ΛValue      []ygot.Annotation         `path:"state/@value|@value" ygotAnnotation:"true"`
	Weight      *uint8                    `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight     []ygot.Annotation         `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) IsYANGGoStruct() {
}

// GetFlags retrieves the value of the leaf Flags from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Flags is set, it can safely use t.GetFlags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Flags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) GetFlags() []E_LanAdjacencySid_Flags {
	if t == nil || t.Flags == nil {
		return nil
	}
	return t.Flags
}

// GetNeighborId retrieves the value of the leaf NeighborId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborId is set, it can safely use t.GetNeighborId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) GetNeighborId() string {
	if t == nil || t.NeighborId == nil {
		return ""
	}
	return *t.NeighborId
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) GetValue() uint32 {
	if t == nil || t.Value == nil {
		return 0
	}
	return *t.Value
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes struct {
	ΛMetadata        []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	LocalProtection  []E_LinkAttributes_LocalProtection `path:"state/local-protection" module:"openconfig-network-instance"`
	ΛLocalProtection []ygot.Annotation                  `path:"state/@local-protection" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// GetLocalProtection retrieves the value of the leaf LocalProtection from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalProtection is set, it can safely use t.GetLocalProtection()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalProtection == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes) GetLocalProtection() []E_LinkAttributes_LocalProtection {
	if t == nil || t.LocalProtection == nil {
		return nil
	}
	return t.LocalProtection
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Delay     *uint32           `path:"state/delay" module:"openconfig-network-instance"`
	ΛDelay    []ygot.Annotation `path:"state/@delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// GetDelay retrieves the value of the leaf Delay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Delay is set, it can safely use t.GetDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Delay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation) GetDelay() uint32 {
	if t == nil || t.Delay == nil {
		return 0
	}
	return *t.Delay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Local     *uint32           `path:"state/local" module:"openconfig-network-instance"`
	ΛLocal    []ygot.Annotation `path:"state/@local" ygotAnnotation:"true"`
	Remote    *uint32           `path:"state/remote" module:"openconfig-network-instance"`
	ΛRemote   []ygot.Annotation `path:"state/@remote" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId) IsYANGGoStruct() {
}

// GetLocal retrieves the value of the leaf Local from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Local is set, it can safely use t.GetLocal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Local == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId) GetLocal() uint32 {
	if t == nil || t.Local == nil {
		return 0
	}
	return *t.Local
}

// GetRemote retrieves the value of the leaf Remote from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Remote is set, it can safely use t.GetRemote()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Remote == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId) GetRemote() uint32 {
	if t == nil || t.Remote == nil {
		return 0
	}
	return *t.Remote
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	LinkLoss  *uint32           `path:"state/link-loss" module:"openconfig-network-instance"`
	ΛLinkLoss []ygot.Annotation `path:"state/@link-loss" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetLinkLoss retrieves the value of the leaf LinkLoss from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkLoss is set, it can safely use t.GetLinkLoss()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkLoss == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss) GetLinkLoss() uint32 {
	if t == nil || t.LinkLoss == nil {
		return 0
	}
	return *t.LinkLoss
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType struct {
	ΛMetadata []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	Type      []E_LinkProtectionType_Type `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation           `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType) GetType() []E_LinkProtectionType_Type {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ABit      *bool             `path:"state/a-bit" module:"openconfig-network-instance"`
	ΛABit     []ygot.Annotation `path:"state/@a-bit" ygotAnnotation:"true"`
	MaxDelay  *uint32           `path:"state/max-delay" module:"openconfig-network-instance"`
	ΛMaxDelay []ygot.Annotation `path:"state/@max-delay" ygotAnnotation:"true"`
	MinDelay  *uint32           `path:"state/min-delay" module:"openconfig-network-instance"`
	ΛMinDelay []ygot.Annotation `path:"state/@min-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// GetABit retrieves the value of the leaf ABit from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ABit is set, it can safely use t.GetABit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ABit == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetABit() bool {
	if t == nil || t.ABit == nil {
		return false
	}
	return *t.ABit
}

// GetMaxDelay retrieves the value of the leaf MaxDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxDelay is set, it can safely use t.GetMaxDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMaxDelay() uint32 {
	if t == nil || t.MaxDelay == nil {
		return 0
	}
	return *t.MaxDelay
}

// GetMinDelay retrieves the value of the leaf MinDelay from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinDelay is set, it can safely use t.GetMinDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay) GetMinDelay() uint32 {
	if t == nil || t.MinDelay == nil {
		return 0
	}
	return *t.MinDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary            `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation `path:"state/@bandwidth" ygotAnnotation:"true"`
	Priority   *uint8            `path:"state/priority|priority" module:"openconfig-network-instance"`
	ΛPriority  []ygot.Annotation `path:"state/@priority|@priority" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint32           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Count     *uint16                                    `path:"state/count" module:"openconfig-network-instance"`
	ΛCount    []ygot.Annotation                          `path:"state/@count" ygotAnnotation:"true"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// GetCount retrieves the value of the leaf Count from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Count is set, it can safely use t.GetCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Count == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetCount() uint16 {
	if t == nil || t.Count == nil {
		return 0
	}
	return *t.Count
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth struct {
	ΛMetadata  []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Bandwidth  Binary                                     `path:"state/bandwidth" module:"openconfig-network-instance"`
	ΛBandwidth []ygot.Annotation                          `path:"state/@bandwidth" ygotAnnotation:"true"`
	Type       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"state/type" module:"openconfig-network-instance"`
	ΛType      []ygot.Annotation                          `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// GetBandwidth retrieves the value of the leaf Bandwidth from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bandwidth is set, it can safely use t.GetBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetBandwidth() Binary {
	if t == nil || t.Bandwidth == nil {
		return nil
	}
	return t.Bandwidth
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth) GetType() E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MtIsn_Neighbor_Instance_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology struct {
	ΛMetadata []ygot.Annotation                                                              `path:"@" ygotAnnotation:"true"`
	Topology  map[uint16]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology `path:"topologies/topology" module:"openconfig-network-instance"`
	ΛTopology []ygot.Annotation                                                              `path:"topologies/@topology" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) IsYANGGoStruct() {}

// NewTopology creates a new entry in the Topology list of the
// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) NewTopology(MtId uint16) (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Topology == nil {
		t.Topology = make(map[uint16]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology)
	}

	key := MtId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Topology[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Topology", key)
	}

	t.Topology[key] = &NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology{
		MtId: &MtId,
	}

	return t.Topology[key], nil
}

// RenameTopology renames an entry in the list Topology within
// the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) RenameTopology(oldK, newK uint16) error {
	if _, ok := t.Topology[newK]; ok {
		return fmt.Errorf("key %v already exists in Topology", newK)
	}

	e, ok := t.Topology[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Topology", oldK)
	}
	e.MtId = &newK

	t.Topology[newK] = e
	delete(t.Topology, oldK)
	return nil
}

// GetOrCreateTopology retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) GetOrCreateTopology(MtId uint16) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology {

	key := MtId

	if v, ok := t.Topology[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTopology(MtId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTopology got unexpected error: %v", err))
	}
	return v
}

// GetTopology retrieves the value with the specified key from
// the Topology map field of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) GetTopology(MtId uint16) *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology {

	if t == nil {
		return nil
	}

	key := MtId

	if lm, ok := t.Topology[key]; ok {
		return lm
	}
	return nil
}

// AppendTopology appends the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology struct to the
// list Topology of NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) AppendTopology(v *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) error {
	if v.MtId == nil {
		return fmt.Errorf("invalid nil key received for MtId")
	}

	key := *v.MtId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Topology == nil {
		t.Topology = make(map[uint16]*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology)
	}

	if _, ok := t.Topology[key]; ok {
		return fmt.Errorf("duplicate key for list Topology %v", key)
	}

	t.Topology[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology/topologies/topology YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology struct {
	ΛMetadata   []ygot.Annotation     `path:"@" ygotAnnotation:"true"`
	Attributes  E_Topology_Attributes `path:"state/attributes" module:"openconfig-network-instance"`
	ΛAttributes []ygot.Annotation     `path:"state/@attributes" ygotAnnotation:"true"`
	MtId        *uint16               `path:"state/mt-id|mt-id" module:"openconfig-network-instance"`
	ΛMtId       []ygot.Annotation     `path:"state/@mt-id|@mt-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) IsYANGGoStruct() {}

// GetAttributes retrieves the value of the leaf Attributes from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attributes is set, it can safely use t.GetAttributes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attributes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) GetAttributes() E_Topology_Attributes {
	if t == nil || t.Attributes == 0 {
		return 0
	}
	return t.Attributes
}

// GetMtId retrieves the value of the leaf MtId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MtId is set, it can safely use t.GetMtId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MtId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) GetMtId() uint16 {
	if t == nil || t.MtId == nil {
		return 0
	}
	return *t.MtId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	return map[string]interface{}{
		"mt-id": *t.MtId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_MultiTopology_Topology) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/nlpid YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Nlpid     []E_Nlpid_Nlpid   `path:"state/nlpid" module:"openconfig-network-instance"`
	ΛNlpid    []ygot.Annotation `path:"state/@nlpid" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid) IsYANGGoStruct() {}

// GetNlpid retrieves the value of the leaf Nlpid from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Nlpid is set, it can safely use t.GetNlpid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Nlpid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid) GetNlpid() []E_Nlpid_Nlpid {
	if t == nil || t.Nlpid == nil {
		return nil
	}
	return t.Nlpid
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_Nlpid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/purge-oi YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ReceivedSystemId  *string           `path:"state/received-system-id" module:"openconfig-network-instance"`
	ΛReceivedSystemId []ygot.Annotation `path:"state/@received-system-id" ygotAnnotation:"true"`
	SourceSystemId    *string           `path:"state/source-system-id" module:"openconfig-network-instance"`
	ΛSourceSystemId   []ygot.Annotation `path:"state/@source-system-id" ygotAnnotation:"true"`
	SystemIdCount     *uint8            `path:"state/system-id-count" module:"openconfig-network-instance"`
	ΛSystemIdCount    []ygot.Annotation `path:"state/@system-id-count" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi) IsYANGGoStruct() {}

// GetReceivedSystemId retrieves the value of the leaf ReceivedSystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ReceivedSystemId is set, it can safely use t.GetReceivedSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ReceivedSystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi) GetReceivedSystemId() string {
	if t == nil || t.ReceivedSystemId == nil {
		return ""
	}
	return *t.ReceivedSystemId
}

// GetSourceSystemId retrieves the value of the leaf SourceSystemId from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceSystemId is set, it can safely use t.GetSourceSystemId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceSystemId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi) GetSourceSystemId() string {
	if t == nil || t.SourceSystemId == nil {
		return ""
	}
	return *t.SourceSystemId
}

// GetSystemIdCount retrieves the value of the leaf SystemIdCount from the NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemIdCount is set, it can safely use t.GetSystemIdCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemIdCount == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi) GetSystemIdCount() uint8 {
	if t == nil || t.SystemIdCount == nil {
		return 0
	}
	return *t.SystemIdCount
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_Tlv_PurgeOi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/undefined-tlvs/undefined-tlv YANG schema element.
type NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint8            `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint8            `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) IsYANGGoStruct() {}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) GetLength() uint8 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) GetType() uint8 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_Lsp_UndefinedTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_RoutePreference represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/route-preference YANG schema element.
type NetworkInstance_Protocol_Isis_Level_RoutePreference struct {
	ΛMetadata                []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExternalRoutePreference  *uint8            `path:"state/external-route-preference" shadow-path:"config/external-route-preference" module:"openconfig-network-instance"`
	ΛExternalRoutePreference []ygot.Annotation `path:"state/@external-route-preference" ygotAnnotation:"true"`
	InternalRoutePreference  *uint8            `path:"state/internal-route-preference" shadow-path:"config/internal-route-preference" module:"openconfig-network-instance"`
	ΛInternalRoutePreference []ygot.Annotation `path:"state/@internal-route-preference" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_RoutePreference implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_RoutePreference) IsYANGGoStruct() {}

// GetExternalRoutePreference retrieves the value of the leaf ExternalRoutePreference from the NetworkInstance_Protocol_Isis_Level_RoutePreference
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRoutePreference is set, it can safely use t.GetExternalRoutePreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRoutePreference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_RoutePreference) GetExternalRoutePreference() uint8 {
	if t == nil || t.ExternalRoutePreference == nil {
		return 0
	}
	return *t.ExternalRoutePreference
}

// GetInternalRoutePreference retrieves the value of the leaf InternalRoutePreference from the NetworkInstance_Protocol_Isis_Level_RoutePreference
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InternalRoutePreference is set, it can safely use t.GetInternalRoutePreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InternalRoutePreference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_RoutePreference) GetInternalRoutePreference() uint8 {
	if t == nil || t.InternalRoutePreference == nil {
		return 0
	}
	return *t.InternalRoutePreference
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_RoutePreference) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_RoutePreference"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_RoutePreference) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_SystemLevelCounters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/system-level-counters YANG schema element.
type NetworkInstance_Protocol_Isis_Level_SystemLevelCounters struct {
	ΛMetadata                   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AuthFails                   *uint32           `path:"state/auth-fails" module:"openconfig-network-instance"`
	ΛAuthFails                  []ygot.Annotation `path:"state/@auth-fails" ygotAnnotation:"true"`
	AuthTypeFails               *uint32           `path:"state/auth-type-fails" module:"openconfig-network-instance"`
	ΛAuthTypeFails              []ygot.Annotation `path:"state/@auth-type-fails" ygotAnnotation:"true"`
	CorruptedLsps               *uint32           `path:"state/corrupted-lsps" module:"openconfig-network-instance"`
	ΛCorruptedLsps              []ygot.Annotation `path:"state/@corrupted-lsps" ygotAnnotation:"true"`
	DatabaseOverloads           *uint32           `path:"state/database-overloads" module:"openconfig-network-instance"`
	ΛDatabaseOverloads          []ygot.Annotation `path:"state/@database-overloads" ygotAnnotation:"true"`
	ExceedMaxSeqNums            *uint32           `path:"state/exceed-max-seq-nums" module:"openconfig-network-instance"`
	ΛExceedMaxSeqNums           []ygot.Annotation `path:"state/@exceed-max-seq-nums" ygotAnnotation:"true"`
	IdLenMismatch               *uint32           `path:"state/id-len-mismatch" module:"openconfig-network-instance"`
	ΛIdLenMismatch              []ygot.Annotation `path:"state/@id-len-mismatch" ygotAnnotation:"true"`
	LspErrors                   *uint32           `path:"state/lsp-errors" module:"openconfig-network-instance"`
	ΛLspErrors                  []ygot.Annotation `path:"state/@lsp-errors" ygotAnnotation:"true"`
	ManualAddressDropFromAreas  *uint32           `path:"state/manual-address-drop-from-areas" module:"openconfig-network-instance"`
	ΛManualAddressDropFromAreas []ygot.Annotation `path:"state/@manual-address-drop-from-areas" ygotAnnotation:"true"`
	MaxAreaAddressMismatches    *uint32           `path:"state/max-area-address-mismatches" module:"openconfig-network-instance"`
	ΛMaxAreaAddressMismatches   []ygot.Annotation `path:"state/@max-area-address-mismatches" ygotAnnotation:"true"`
	OwnLspPurges                *uint32           `path:"state/own-lsp-purges" module:"openconfig-network-instance"`
	ΛOwnLspPurges               []ygot.Annotation `path:"state/@own-lsp-purges" ygotAnnotation:"true"`
	PartChanges                 *uint32           `path:"state/part-changes" module:"openconfig-network-instance"`
	ΛPartChanges                []ygot.Annotation `path:"state/@part-changes" ygotAnnotation:"true"`
	SeqNumSkips                 *uint32           `path:"state/seq-num-skips" module:"openconfig-network-instance"`
	ΛSeqNumSkips                []ygot.Annotation `path:"state/@seq-num-skips" ygotAnnotation:"true"`
	SpfRuns                     *uint32           `path:"state/spf-runs" module:"openconfig-network-instance"`
	ΛSpfRuns                    []ygot.Annotation `path:"state/@spf-runs" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_SystemLevelCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) IsYANGGoStruct() {}

// GetAuthFails retrieves the value of the leaf AuthFails from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthFails is set, it can safely use t.GetAuthFails()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthFails == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetAuthFails() uint32 {
	if t == nil || t.AuthFails == nil {
		return 0
	}
	return *t.AuthFails
}

// GetAuthTypeFails retrieves the value of the leaf AuthTypeFails from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthTypeFails is set, it can safely use t.GetAuthTypeFails()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthTypeFails == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetAuthTypeFails() uint32 {
	if t == nil || t.AuthTypeFails == nil {
		return 0
	}
	return *t.AuthTypeFails
}

// GetCorruptedLsps retrieves the value of the leaf CorruptedLsps from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CorruptedLsps is set, it can safely use t.GetCorruptedLsps()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CorruptedLsps == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetCorruptedLsps() uint32 {
	if t == nil || t.CorruptedLsps == nil {
		return 0
	}
	return *t.CorruptedLsps
}

// GetDatabaseOverloads retrieves the value of the leaf DatabaseOverloads from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DatabaseOverloads is set, it can safely use t.GetDatabaseOverloads()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DatabaseOverloads == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetDatabaseOverloads() uint32 {
	if t == nil || t.DatabaseOverloads == nil {
		return 0
	}
	return *t.DatabaseOverloads
}

// GetExceedMaxSeqNums retrieves the value of the leaf ExceedMaxSeqNums from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExceedMaxSeqNums is set, it can safely use t.GetExceedMaxSeqNums()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExceedMaxSeqNums == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetExceedMaxSeqNums() uint32 {
	if t == nil || t.ExceedMaxSeqNums == nil {
		return 0
	}
	return *t.ExceedMaxSeqNums
}

// GetIdLenMismatch retrieves the value of the leaf IdLenMismatch from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IdLenMismatch is set, it can safely use t.GetIdLenMismatch()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IdLenMismatch == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetIdLenMismatch() uint32 {
	if t == nil || t.IdLenMismatch == nil {
		return 0
	}
	return *t.IdLenMismatch
}

// GetLspErrors retrieves the value of the leaf LspErrors from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LspErrors is set, it can safely use t.GetLspErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LspErrors == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetLspErrors() uint32 {
	if t == nil || t.LspErrors == nil {
		return 0
	}
	return *t.LspErrors
}

// GetManualAddressDropFromAreas retrieves the value of the leaf ManualAddressDropFromAreas from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ManualAddressDropFromAreas is set, it can safely use t.GetManualAddressDropFromAreas()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ManualAddressDropFromAreas == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetManualAddressDropFromAreas() uint32 {
	if t == nil || t.ManualAddressDropFromAreas == nil {
		return 0
	}
	return *t.ManualAddressDropFromAreas
}

// GetMaxAreaAddressMismatches retrieves the value of the leaf MaxAreaAddressMismatches from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxAreaAddressMismatches is set, it can safely use t.GetMaxAreaAddressMismatches()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxAreaAddressMismatches == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetMaxAreaAddressMismatches() uint32 {
	if t == nil || t.MaxAreaAddressMismatches == nil {
		return 0
	}
	return *t.MaxAreaAddressMismatches
}

// GetOwnLspPurges retrieves the value of the leaf OwnLspPurges from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OwnLspPurges is set, it can safely use t.GetOwnLspPurges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OwnLspPurges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetOwnLspPurges() uint32 {
	if t == nil || t.OwnLspPurges == nil {
		return 0
	}
	return *t.OwnLspPurges
}

// GetPartChanges retrieves the value of the leaf PartChanges from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PartChanges is set, it can safely use t.GetPartChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PartChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetPartChanges() uint32 {
	if t == nil || t.PartChanges == nil {
		return 0
	}
	return *t.PartChanges
}

// GetSeqNumSkips retrieves the value of the leaf SeqNumSkips from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SeqNumSkips is set, it can safely use t.GetSeqNumSkips()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SeqNumSkips == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetSeqNumSkips() uint32 {
	if t == nil || t.SeqNumSkips == nil {
		return 0
	}
	return *t.SeqNumSkips
}

// GetSpfRuns retrieves the value of the leaf SpfRuns from the NetworkInstance_Protocol_Isis_Level_SystemLevelCounters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SpfRuns is set, it can safely use t.GetSpfRuns()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SpfRuns == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) GetSpfRuns() uint32 {
	if t == nil || t.SpfRuns == nil {
		return 0
	}
	return *t.SpfRuns
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_SystemLevelCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_SystemLevelCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Isis_Level_TrafficEngineering represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/traffic-engineering YANG schema element.
type NetworkInstance_Protocol_Isis_Level_TrafficEngineering struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled       *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled      []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	Ipv4RouterId  *string           `path:"state/ipv4-router-id" shadow-path:"config/ipv4-router-id" module:"openconfig-network-instance"`
	ΛIpv4RouterId []ygot.Annotation `path:"state/@ipv4-router-id" ygotAnnotation:"true"`
	Ipv6RouterId  *string           `path:"state/ipv6-router-id" shadow-path:"config/ipv6-router-id" module:"openconfig-network-instance"`
	ΛIpv6RouterId []ygot.Annotation `path:"state/@ipv6-router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Isis_Level_TrafficEngineering implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Isis_Level_TrafficEngineering) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Isis_Level_TrafficEngineering
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_TrafficEngineering) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetIpv4RouterId retrieves the value of the leaf Ipv4RouterId from the NetworkInstance_Protocol_Isis_Level_TrafficEngineering
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv4RouterId is set, it can safely use t.GetIpv4RouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv4RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_TrafficEngineering) GetIpv4RouterId() string {
	if t == nil || t.Ipv4RouterId == nil {
		return ""
	}
	return *t.Ipv4RouterId
}

// GetIpv6RouterId retrieves the value of the leaf Ipv6RouterId from the NetworkInstance_Protocol_Isis_Level_TrafficEngineering
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv6RouterId is set, it can safely use t.GetIpv6RouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv6RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Isis_Level_TrafficEngineering) GetIpv6RouterId() string {
	if t == nil || t.Ipv6RouterId == nil {
		return ""
	}
	return *t.Ipv6RouterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Isis_Level_TrafficEngineering) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Isis_Level_TrafficEngineering"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Isis_Level_TrafficEngineering) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2 YANG schema element.
type NetworkInstance_Protocol_Ospfv2 struct {
	ΛMetadata []ygot.Annotation                                                                               `path:"@" ygotAnnotation:"true"`
	Area      map[NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union]*NetworkInstance_Protocol_Ospfv2_Area `path:"areas/area" module:"openconfig-network-instance"`
	ΛArea     []ygot.Annotation                                                                               `path:"areas/@area" ygotAnnotation:"true"`
	Global    *NetworkInstance_Protocol_Ospfv2_Global                                                         `path:"global" module:"openconfig-network-instance"`
	ΛGlobal   []ygot.Annotation                                                                               `path:"@global" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2) IsYANGGoStruct() {}

// NewArea creates a new entry in the Area list of the
// NetworkInstance_Protocol_Ospfv2 struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2) NewArea(Identifier NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) (*NetworkInstance_Protocol_Ospfv2_Area, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Area == nil {
		t.Area = make(map[NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union]*NetworkInstance_Protocol_Ospfv2_Area)
	}

	key := Identifier

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Area[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Area", key)
	}

	t.Area[key] = &NetworkInstance_Protocol_Ospfv2_Area{
		Identifier: Identifier,
	}

	return t.Area[key], nil
}

// RenameArea renames an entry in the list Area within
// the NetworkInstance_Protocol_Ospfv2 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2) RenameArea(oldK, newK NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) error {
	if _, ok := t.Area[newK]; ok {
		return fmt.Errorf("key %v already exists in Area", newK)
	}

	e, ok := t.Area[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Area", oldK)
	}
	e.Identifier = newK

	t.Area[newK] = e
	delete(t.Area, oldK)
	return nil
}

// GetOrCreateArea retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2) GetOrCreateArea(Identifier NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) *NetworkInstance_Protocol_Ospfv2_Area {

	key := Identifier

	if v, ok := t.Area[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewArea(Identifier)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateArea got unexpected error: %v", err))
	}
	return v
}

// GetArea retrieves the value with the specified key from
// the Area map field of NetworkInstance_Protocol_Ospfv2. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2) GetArea(Identifier NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) *NetworkInstance_Protocol_Ospfv2_Area {

	if t == nil {
		return nil
	}

	key := Identifier

	if lm, ok := t.Area[key]; ok {
		return lm
	}
	return nil
}

// AppendArea appends the supplied NetworkInstance_Protocol_Ospfv2_Area struct to the
// list Area of NetworkInstance_Protocol_Ospfv2. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2) AppendArea(v *NetworkInstance_Protocol_Ospfv2_Area) error {
	key := v.Identifier

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Area == nil {
		t.Area = make(map[NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union]*NetworkInstance_Protocol_Ospfv2_Area)
	}

	if _, ok := t.Area[key]; ok {
		return fmt.Errorf("duplicate key for list Area %v", key)
	}

	t.Area[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2) GetOrCreateGlobal() *NetworkInstance_Protocol_Ospfv2_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Protocol_Ospfv2_Global{}
	return t.Global
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Protocol_Ospfv2. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2) GetGlobal() *NetworkInstance_Protocol_Ospfv2_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area struct {
	ΛMetadata    []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	Identifier   NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union        `path:"state/identifier|identifier" shadow-path:"config/identifier" module:"openconfig-network-instance"`
	ΛIdentifier  []ygot.Annotation                                            `path:"state/@identifier|@identifier" ygotAnnotation:"true"`
	Interface    map[string]*NetworkInstance_Protocol_Ospfv2_Area_Interface   `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface   []ygot.Annotation                                            `path:"interfaces/@interface" ygotAnnotation:"true"`
	Lsdb         *NetworkInstance_Protocol_Ospfv2_Area_Lsdb                   `path:"lsdb" module:"openconfig-network-instance"`
	ΛLsdb        []ygot.Annotation                                            `path:"@lsdb" ygotAnnotation:"true"`
	Mpls         *NetworkInstance_Protocol_Ospfv2_Area_Mpls                   `path:"mpls" module:"openconfig-network-instance"`
	ΛMpls        []ygot.Annotation                                            `path:"@mpls" ygotAnnotation:"true"`
	VirtualLink  map[string]*NetworkInstance_Protocol_Ospfv2_Area_VirtualLink `path:"virtual-links/virtual-link" module:"openconfig-network-instance"`
	ΛVirtualLink []ygot.Annotation                                            `path:"virtual-links/@virtual-link" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Protocol_Ospfv2_Area struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area) NewInterface(Id string) (*NetworkInstance_Protocol_Ospfv2_Area_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Protocol_Ospfv2_Area_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Protocol_Ospfv2_Area struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Id = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetOrCreateInterface(Id string) *NetworkInstance_Protocol_Ospfv2_Area_Interface {

	key := Id

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Protocol_Ospfv2_Area. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetInterface(Id string) *NetworkInstance_Protocol_Ospfv2_Area_Interface {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Interface struct to the
// list Interface of NetworkInstance_Protocol_Ospfv2_Area. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area) AppendInterface(v *NetworkInstance_Protocol_Ospfv2_Area_Interface) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewVirtualLink creates a new entry in the VirtualLink list of the
// NetworkInstance_Protocol_Ospfv2_Area struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area) NewVirtualLink(RemoteRouterId string) (*NetworkInstance_Protocol_Ospfv2_Area_VirtualLink, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VirtualLink == nil {
		t.VirtualLink = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_VirtualLink)
	}

	key := RemoteRouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.VirtualLink[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list VirtualLink", key)
	}

	t.VirtualLink[key] = &NetworkInstance_Protocol_Ospfv2_Area_VirtualLink{
		RemoteRouterId: &RemoteRouterId,
	}

	return t.VirtualLink[key], nil
}

// RenameVirtualLink renames an entry in the list VirtualLink within
// the NetworkInstance_Protocol_Ospfv2_Area struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area) RenameVirtualLink(oldK, newK string) error {
	if _, ok := t.VirtualLink[newK]; ok {
		return fmt.Errorf("key %v already exists in VirtualLink", newK)
	}

	e, ok := t.VirtualLink[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in VirtualLink", oldK)
	}
	e.RemoteRouterId = &newK

	t.VirtualLink[newK] = e
	delete(t.VirtualLink, oldK)
	return nil
}

// GetOrCreateVirtualLink retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetOrCreateVirtualLink(RemoteRouterId string) *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink {

	key := RemoteRouterId

	if v, ok := t.VirtualLink[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVirtualLink(RemoteRouterId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVirtualLink got unexpected error: %v", err))
	}
	return v
}

// GetVirtualLink retrieves the value with the specified key from
// the VirtualLink map field of NetworkInstance_Protocol_Ospfv2_Area. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetVirtualLink(RemoteRouterId string) *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink {

	if t == nil {
		return nil
	}

	key := RemoteRouterId

	if lm, ok := t.VirtualLink[key]; ok {
		return lm
	}
	return nil
}

// AppendVirtualLink appends the supplied NetworkInstance_Protocol_Ospfv2_Area_VirtualLink struct to the
// list VirtualLink of NetworkInstance_Protocol_Ospfv2_Area. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_VirtualLink already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area) AppendVirtualLink(v *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) error {
	if v.RemoteRouterId == nil {
		return fmt.Errorf("invalid nil key received for RemoteRouterId")
	}

	key := *v.RemoteRouterId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VirtualLink == nil {
		t.VirtualLink = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_VirtualLink)
	}

	if _, ok := t.VirtualLink[key]; ok {
		return fmt.Errorf("duplicate key for list VirtualLink %v", key)
	}

	t.VirtualLink[key] = v
	return nil
}

// GetOrCreateLsdb retrieves the value of the Lsdb field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetOrCreateLsdb() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb {
	if t.Lsdb != nil {
		return t.Lsdb
	}
	t.Lsdb = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb{}
	return t.Lsdb
}

// GetOrCreateMpls retrieves the value of the Mpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetOrCreateMpls() *NetworkInstance_Protocol_Ospfv2_Area_Mpls {
	if t.Mpls != nil {
		return t.Mpls
	}
	t.Mpls = &NetworkInstance_Protocol_Ospfv2_Area_Mpls{}
	return t.Mpls
}

// GetLsdb returns the value of the Lsdb struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area. If the receiver or the field Lsdb is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetLsdb() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb {
	if t != nil && t.Lsdb != nil {
		return t.Lsdb
	}
	return nil
}

// GetMpls returns the value of the Mpls struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area. If the receiver or the field Mpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetMpls() *NetworkInstance_Protocol_Ospfv2_Area_Mpls {
	if t != nil && t.Mpls != nil {
		return t.Mpls
	}
	return nil
}

// GetIdentifier retrieves the value of the leaf Identifier from the NetworkInstance_Protocol_Ospfv2_Area
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Identifier is set, it can safely use t.GetIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Identifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area) GetIdentifier() NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union {
	if t == nil || t.Identifier == nil {
		return nil
	}
	return t.Identifier
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"identifier": t.Identifier,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/state/identifier within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union() {}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union() {}

// To_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area) To_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface struct {
	ΛMetadata                  []ygot.Annotation                                                   `path:"@" ygotAnnotation:"true"`
	AuthenticationType         *string                                                             `path:"state/authentication-type" shadow-path:"config/authentication-type" module:"openconfig-network-instance"`
	ΛAuthenticationType        []ygot.Annotation                                                   `path:"state/@authentication-type" ygotAnnotation:"true"`
	HideNetwork                *bool                                                               `path:"state/hide-network" shadow-path:"config/hide-network" module:"openconfig-network-instance"`
	ΛHideNetwork               []ygot.Annotation                                                   `path:"state/@hide-network" ygotAnnotation:"true"`
	Id                         *string                                                             `path:"state/id|id" shadow-path:"config/id" module:"openconfig-network-instance"`
	ΛId                        []ygot.Annotation                                                   `path:"state/@id|@id" ygotAnnotation:"true"`
	InterfaceRef               *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef        `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef              []ygot.Annotation                                                   `path:"@interface-ref" ygotAnnotation:"true"`
	LsaFilter                  *NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter           `path:"lsa-filter" module:"openconfig-network-instance"`
	ΛLsaFilter                 []ygot.Annotation                                                   `path:"@lsa-filter" ygotAnnotation:"true"`
	Metric                     *uint16                                                             `path:"state/metric" shadow-path:"config/metric" module:"openconfig-network-instance"`
	ΛMetric                    []ygot.Annotation                                                   `path:"state/@metric" ygotAnnotation:"true"`
	Mpls                       *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls                `path:"mpls" module:"openconfig-network-instance"`
	ΛMpls                      []ygot.Annotation                                                   `path:"@mpls" ygotAnnotation:"true"`
	MultiAreaAdjacencyPrimary  *bool                                                               `path:"state/multi-area-adjacency-primary" shadow-path:"config/multi-area-adjacency-primary" module:"openconfig-network-instance"`
	ΛMultiAreaAdjacencyPrimary []ygot.Annotation                                                   `path:"state/@multi-area-adjacency-primary" ygotAnnotation:"true"`
	Neighbor                   map[string]*NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor                  []ygot.Annotation                                                   `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	NetworkType                E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE                             `path:"state/network-type" shadow-path:"config/network-type" module:"openconfig-network-instance"`
	ΛNetworkType               []ygot.Annotation                                                   `path:"state/@network-type" ygotAnnotation:"true"`
	Passive                    *bool                                                               `path:"state/passive" shadow-path:"config/passive" module:"openconfig-network-instance"`
	ΛPassive                   []ygot.Annotation                                                   `path:"state/@passive" ygotAnnotation:"true"`
	Priority                   *uint8                                                              `path:"state/priority" shadow-path:"config/priority" module:"openconfig-network-instance"`
	ΛPriority                  []ygot.Annotation                                                   `path:"state/@priority" ygotAnnotation:"true"`
	Timers                     *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers              `path:"timers" module:"openconfig-network-instance"`
	ΛTimers                    []ygot.Annotation                                                   `path:"@timers" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Ospfv2_Area_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) NewNeighbor(RouterId string) (*NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor)
	}

	key := RouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor{
		RouterId: &RouterId,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Ospfv2_Area_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.RouterId = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetOrCreateNeighbor(RouterId string) *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor {

	key := RouterId

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(RouterId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Ospfv2_Area_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetNeighbor(RouterId string) *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor {

	if t == nil {
		return nil
	}

	key := RouterId

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Ospfv2_Area_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) AppendNeighbor(v *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) error {
	if v.RouterId == nil {
		return fmt.Errorf("invalid nil key received for RouterId")
	}

	key := *v.RouterId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetOrCreateLsaFilter retrieves the value of the LsaFilter field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetOrCreateLsaFilter() *NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter {
	if t.LsaFilter != nil {
		return t.LsaFilter
	}
	t.LsaFilter = &NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter{}
	return t.LsaFilter
}

// GetOrCreateMpls retrieves the value of the Mpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetOrCreateMpls() *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls {
	if t.Mpls != nil {
		return t.Mpls
	}
	t.Mpls = &NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls{}
	return t.Mpls
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetOrCreateTimers() *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers{}
	return t.Timers
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetInterfaceRef() *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetLsaFilter returns the value of the LsaFilter struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Interface. If the receiver or the field LsaFilter is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetLsaFilter() *NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter {
	if t != nil && t.LsaFilter != nil {
		return t.LsaFilter
	}
	return nil
}

// GetMpls returns the value of the Mpls struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Interface. If the receiver or the field Mpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetMpls() *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls {
	if t != nil && t.Mpls != nil {
		return t.Mpls
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Interface. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetTimers() *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetAuthenticationType retrieves the value of the leaf AuthenticationType from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationType is set, it can safely use t.GetAuthenticationType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetAuthenticationType() string {
	if t == nil || t.AuthenticationType == nil {
		return ""
	}
	return *t.AuthenticationType
}

// GetHideNetwork retrieves the value of the leaf HideNetwork from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HideNetwork is set, it can safely use t.GetHideNetwork()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HideNetwork == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetHideNetwork() bool {
	if t == nil || t.HideNetwork == nil {
		return false
	}
	return *t.HideNetwork
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetMultiAreaAdjacencyPrimary retrieves the value of the leaf MultiAreaAdjacencyPrimary from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultiAreaAdjacencyPrimary is set, it can safely use t.GetMultiAreaAdjacencyPrimary()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultiAreaAdjacencyPrimary == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetMultiAreaAdjacencyPrimary() bool {
	if t == nil || t.MultiAreaAdjacencyPrimary == nil {
		return true
	}
	return *t.MultiAreaAdjacencyPrimary
}

// GetNetworkType retrieves the value of the leaf NetworkType from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NetworkType is set, it can safely use t.GetNetworkType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NetworkType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetNetworkType() E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE {
	if t == nil || t.NetworkType == 0 {
		return 0
	}
	return t.NetworkType
}

// GetPassive retrieves the value of the leaf Passive from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Passive is set, it can safely use t.GetPassive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Passive == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetPassive() bool {
	if t == nil || t.Passive == nil {
		return false
	}
	return *t.Passive
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Ospfv2_Area_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/lsa-filter YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	All       *bool             `path:"state/all" shadow-path:"config/all" module:"openconfig-network-instance"`
	ΛAll      []ygot.Annotation `path:"state/@all" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter) IsYANGGoStruct() {}

// GetAll retrieves the value of the leaf All from the NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if All is set, it can safely use t.GetAll()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.All == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter) GetAll() bool {
	if t == nil || t.All == nil {
		return false
	}
	return *t.All
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_LsaFilter) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls struct {
	ΛMetadata                 []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	IgpLdpSync                *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
	ΛIgpLdpSync               []ygot.Annotation                                               `path:"@igp-ldp-sync" ygotAnnotation:"true"`
	TrafficEngineeringMetric  *uint32                                                         `path:"state/traffic-engineering-metric" shadow-path:"config/traffic-engineering-metric" module:"openconfig-network-instance"`
	ΛTrafficEngineeringMetric []ygot.Annotation                                               `path:"state/@traffic-engineering-metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls) IsYANGGoStruct() {}

// GetOrCreateIgpLdpSync retrieves the value of the IgpLdpSync field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls) GetOrCreateIgpLdpSync() *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync {
	if t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	t.IgpLdpSync = &NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync{}
	return t.IgpLdpSync
}

// GetIgpLdpSync returns the value of the IgpLdpSync struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls. If the receiver or the field IgpLdpSync is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls) GetIgpLdpSync() *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync {
	if t != nil && t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	return nil
}

// GetTrafficEngineeringMetric retrieves the value of the leaf TrafficEngineeringMetric from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrafficEngineeringMetric is set, it can safely use t.GetTrafficEngineeringMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrafficEngineeringMetric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls) GetTrafficEngineeringMetric() uint32 {
	if t == nil || t.TrafficEngineeringMetric == nil {
		return 0
	}
	return *t.TrafficEngineeringMetric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls/igp-ldp-sync YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled             *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	PostSessionUpDelay  *uint32           `path:"state/post-session-up-delay" shadow-path:"config/post-session-up-delay" module:"openconfig-network-instance"`
	ΛPostSessionUpDelay []ygot.Annotation `path:"state/@post-session-up-delay" ygotAnnotation:"true"`
	Synchronized        *bool             `path:"state/synchronized" module:"openconfig-network-instance"`
	ΛSynchronized       []ygot.Annotation `path:"state/@synchronized" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetPostSessionUpDelay retrieves the value of the leaf PostSessionUpDelay from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PostSessionUpDelay is set, it can safely use t.GetPostSessionUpDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PostSessionUpDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync) GetPostSessionUpDelay() uint32 {
	if t == nil || t.PostSessionUpDelay == nil {
		return 0
	}
	return *t.PostSessionUpDelay
}

// GetSynchronized retrieves the value of the leaf Synchronized from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Synchronized is set, it can safely use t.GetSynchronized()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Synchronized == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync) GetSynchronized() bool {
	if t == nil || t.Synchronized == nil {
		return false
	}
	return *t.Synchronized
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor struct {
	ΛMetadata                 []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	AdjacencyState            E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE `path:"state/adjacency-state" module:"openconfig-network-instance"`
	ΛAdjacencyState           []ygot.Annotation                         `path:"state/@adjacency-state" ygotAnnotation:"true"`
	BackupDesignatedRouter    *string                                   `path:"state/backup-designated-router" module:"openconfig-network-instance"`
	ΛBackupDesignatedRouter   []ygot.Annotation                         `path:"state/@backup-designated-router" ygotAnnotation:"true"`
	DeadTime                  *uint64                                   `path:"state/dead-time" module:"openconfig-network-instance"`
	ΛDeadTime                 []ygot.Annotation                         `path:"state/@dead-time" ygotAnnotation:"true"`
	DesignatedRouter          *string                                   `path:"state/designated-router" module:"openconfig-network-instance"`
	ΛDesignatedRouter         []ygot.Annotation                         `path:"state/@designated-router" ygotAnnotation:"true"`
	LastEstablishedTime       *uint64                                   `path:"state/last-established-time" module:"openconfig-network-instance"`
	ΛLastEstablishedTime      []ygot.Annotation                         `path:"state/@last-established-time" ygotAnnotation:"true"`
	Metric                    *uint16                                   `path:"state/metric" shadow-path:"config/metric" module:"openconfig-network-instance"`
	ΛMetric                   []ygot.Annotation                         `path:"state/@metric" ygotAnnotation:"true"`
	OptionalCapabilities      *string                                   `path:"state/optional-capabilities" module:"openconfig-network-instance"`
	ΛOptionalCapabilities     []ygot.Annotation                         `path:"state/@optional-capabilities" ygotAnnotation:"true"`
	Priority                  *uint8                                    `path:"state/priority" module:"openconfig-network-instance"`
	ΛPriority                 []ygot.Annotation                         `path:"state/@priority" ygotAnnotation:"true"`
	RetranmissionQueueLength  *uint32                                   `path:"state/retranmission-queue-length" module:"openconfig-network-instance"`
	ΛRetranmissionQueueLength []ygot.Annotation                         `path:"state/@retranmission-queue-length" ygotAnnotation:"true"`
	RouterId                  *string                                   `path:"state/router-id|router-id" shadow-path:"config/router-id" module:"openconfig-network-instance"`
	ΛRouterId                 []ygot.Annotation                         `path:"state/@router-id|@router-id" ygotAnnotation:"true"`
	StateChanges              *uint32                                   `path:"state/state-changes" module:"openconfig-network-instance"`
	ΛStateChanges             []ygot.Annotation                         `path:"state/@state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) IsYANGGoStruct() {}

// GetAdjacencyState retrieves the value of the leaf AdjacencyState from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjacencyState is set, it can safely use t.GetAdjacencyState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjacencyState == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetAdjacencyState() E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE {
	if t == nil || t.AdjacencyState == 0 {
		return 0
	}
	return t.AdjacencyState
}

// GetBackupDesignatedRouter retrieves the value of the leaf BackupDesignatedRouter from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BackupDesignatedRouter is set, it can safely use t.GetBackupDesignatedRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BackupDesignatedRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetBackupDesignatedRouter() string {
	if t == nil || t.BackupDesignatedRouter == nil {
		return ""
	}
	return *t.BackupDesignatedRouter
}

// GetDeadTime retrieves the value of the leaf DeadTime from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DeadTime is set, it can safely use t.GetDeadTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DeadTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetDeadTime() uint64 {
	if t == nil || t.DeadTime == nil {
		return 0
	}
	return *t.DeadTime
}

// GetDesignatedRouter retrieves the value of the leaf DesignatedRouter from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRouter is set, it can safely use t.GetDesignatedRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetDesignatedRouter() string {
	if t == nil || t.DesignatedRouter == nil {
		return ""
	}
	return *t.DesignatedRouter
}

// GetLastEstablishedTime retrieves the value of the leaf LastEstablishedTime from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastEstablishedTime is set, it can safely use t.GetLastEstablishedTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastEstablishedTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetLastEstablishedTime() uint64 {
	if t == nil || t.LastEstablishedTime == nil {
		return 0
	}
	return *t.LastEstablishedTime
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetOptionalCapabilities retrieves the value of the leaf OptionalCapabilities from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OptionalCapabilities is set, it can safely use t.GetOptionalCapabilities()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OptionalCapabilities == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetOptionalCapabilities() string {
	if t == nil || t.OptionalCapabilities == nil {
		return ""
	}
	return *t.OptionalCapabilities
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetRetranmissionQueueLength retrieves the value of the leaf RetranmissionQueueLength from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetranmissionQueueLength is set, it can safely use t.GetRetranmissionQueueLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetranmissionQueueLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetRetranmissionQueueLength() uint32 {
	if t == nil || t.RetranmissionQueueLength == nil {
		return 0
	}
	return *t.RetranmissionQueueLength
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetStateChanges retrieves the value of the leaf StateChanges from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StateChanges is set, it can safely use t.GetStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StateChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) GetStateChanges() uint32 {
	if t == nil || t.StateChanges == nil {
		return 0
	}
	return *t.StateChanges
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RouterId == nil {
		return nil, fmt.Errorf("nil value for key RouterId")
	}

	return map[string]interface{}{
		"router-id": *t.RouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/timers YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers struct {
	ΛMetadata               []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	DeadInterval            *uint32           `path:"state/dead-interval" shadow-path:"config/dead-interval" module:"openconfig-network-instance"`
	ΛDeadInterval           []ygot.Annotation `path:"state/@dead-interval" ygotAnnotation:"true"`
	HelloInterval           *uint32           `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval          []ygot.Annotation `path:"state/@hello-interval" ygotAnnotation:"true"`
	RetransmissionInterval  *uint32           `path:"state/retransmission-interval" shadow-path:"config/retransmission-interval" module:"openconfig-network-instance"`
	ΛRetransmissionInterval []ygot.Annotation `path:"state/@retransmission-interval" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers) IsYANGGoStruct() {}

// GetDeadInterval retrieves the value of the leaf DeadInterval from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DeadInterval is set, it can safely use t.GetDeadInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DeadInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers) GetDeadInterval() uint32 {
	if t == nil || t.DeadInterval == nil {
		return 0
	}
	return *t.DeadInterval
}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers) GetHelloInterval() uint32 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// GetRetransmissionInterval retrieves the value of the leaf RetransmissionInterval from the NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetransmissionInterval is set, it can safely use t.GetRetransmissionInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetransmissionInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers) GetRetransmissionInterval() uint32 {
	if t == nil || t.RetransmissionInterval == nil {
		return 0
	}
	return *t.RetransmissionInterval
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Interface_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb struct {
	ΛMetadata   []ygot.Annotation                                                                          `path:"@" ygotAnnotation:"true"`
	Identifier  NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union                                 `path:"state/identifier" module:"openconfig-network-instance"`
	ΛIdentifier []ygot.Annotation                                                                          `path:"state/@identifier" ygotAnnotation:"true"`
	LsaType     map[E_OpenconfigOspfTypes_OSPF_LSA_TYPE]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType `path:"lsa-types/lsa-type" module:"openconfig-network-instance"`
	ΛLsaType    []ygot.Annotation                                                                          `path:"lsa-types/@lsa-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb) IsYANGGoStruct() {}

// NewLsaType creates a new entry in the LsaType list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) NewLsaType(Type E_OpenconfigOspfTypes_OSPF_LSA_TYPE) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LsaType == nil {
		t.LsaType = make(map[E_OpenconfigOspfTypes_OSPF_LSA_TYPE]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LsaType[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LsaType", key)
	}

	t.LsaType[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType{
		Type: Type,
	}

	return t.LsaType[key], nil
}

// RenameLsaType renames an entry in the list LsaType within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) RenameLsaType(oldK, newK E_OpenconfigOspfTypes_OSPF_LSA_TYPE) error {
	if _, ok := t.LsaType[newK]; ok {
		return fmt.Errorf("key %v already exists in LsaType", newK)
	}

	e, ok := t.LsaType[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in LsaType", oldK)
	}
	e.Type = newK

	t.LsaType[newK] = e
	delete(t.LsaType, oldK)
	return nil
}

// GetOrCreateLsaType retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) GetOrCreateLsaType(Type E_OpenconfigOspfTypes_OSPF_LSA_TYPE) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType {

	key := Type

	if v, ok := t.LsaType[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLsaType(Type)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLsaType got unexpected error: %v", err))
	}
	return v
}

// GetLsaType retrieves the value with the specified key from
// the LsaType map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) GetLsaType(Type E_OpenconfigOspfTypes_OSPF_LSA_TYPE) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType {

	if t == nil {
		return nil
	}

	key := Type

	if lm, ok := t.LsaType[key]; ok {
		return lm
	}
	return nil
}

// AppendLsaType appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType struct to the
// list LsaType of NetworkInstance_Protocol_Ospfv2_Area_Lsdb. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) AppendLsaType(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) error {
	key := v.Type

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LsaType == nil {
		t.LsaType = make(map[E_OpenconfigOspfTypes_OSPF_LSA_TYPE]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType)
	}

	if _, ok := t.LsaType[key]; ok {
		return fmt.Errorf("duplicate key for list LsaType %v", key)
	}

	t.LsaType[key] = v
	return nil
}

// GetIdentifier retrieves the value of the leaf Identifier from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Identifier is set, it can safely use t.GetIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Identifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) GetIdentifier() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union {
	if t == nil || t.Identifier == nil {
		return nil
	}
	return t.Identifier
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/state/identifier within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union() {}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union() {}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType struct {
	ΛMetadata []ygot.Annotation                                                 `path:"@" ygotAnnotation:"true"`
	Lsa       map[string]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa `path:"lsas/lsa" module:"openconfig-network-instance"`
	ΛLsa      []ygot.Annotation                                                 `path:"lsas/@lsa" ygotAnnotation:"true"`
	Type      E_OpenconfigOspfTypes_OSPF_LSA_TYPE                               `path:"state/type|type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation                                                 `path:"state/@type|@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) IsYANGGoStruct() {}

// NewLsa creates a new entry in the Lsa list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) NewLsa(LinkStateId string) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Lsa == nil {
		t.Lsa = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa)
	}

	key := LinkStateId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Lsa[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Lsa", key)
	}

	t.Lsa[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa{
		LinkStateId: &LinkStateId,
	}

	return t.Lsa[key], nil
}

// RenameLsa renames an entry in the list Lsa within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) RenameLsa(oldK, newK string) error {
	if _, ok := t.Lsa[newK]; ok {
		return fmt.Errorf("key %v already exists in Lsa", newK)
	}

	e, ok := t.Lsa[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Lsa", oldK)
	}
	e.LinkStateId = &newK

	t.Lsa[newK] = e
	delete(t.Lsa, oldK)
	return nil
}

// GetOrCreateLsa retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) GetOrCreateLsa(LinkStateId string) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa {

	key := LinkStateId

	if v, ok := t.Lsa[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLsa(LinkStateId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLsa got unexpected error: %v", err))
	}
	return v
}

// GetLsa retrieves the value with the specified key from
// the Lsa map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) GetLsa(LinkStateId string) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa {

	if t == nil {
		return nil
	}

	key := LinkStateId

	if lm, ok := t.Lsa[key]; ok {
		return lm
	}
	return nil
}

// AppendLsa appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa struct to the
// list Lsa of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) AppendLsa(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) error {
	if v.LinkStateId == nil {
		return fmt.Errorf("invalid nil key received for LinkStateId")
	}

	key := *v.LinkStateId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Lsa == nil {
		t.Lsa = make(map[string]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa)
	}

	if _, ok := t.Lsa[key]; ok {
		return fmt.Errorf("duplicate key for list Lsa %v", key)
	}

	t.Lsa[key] = v
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) GetType() E_OpenconfigOspfTypes_OSPF_LSA_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa struct {
	ΛMetadata          []ygot.Annotation                                                      `path:"@" ygotAnnotation:"true"`
	AdvertisingRouter  *string                                                                `path:"state/advertising-router" module:"openconfig-network-instance"`
	ΛAdvertisingRouter []ygot.Annotation                                                      `path:"state/@advertising-router" ygotAnnotation:"true"`
	Age                *uint16                                                                `path:"state/age" module:"openconfig-network-instance"`
	ΛAge               []ygot.Annotation                                                      `path:"state/@age" ygotAnnotation:"true"`
	AsExternalLsa      *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa   `path:"as-external-lsa" module:"openconfig-network-instance"`
	ΛAsExternalLsa     []ygot.Annotation                                                      `path:"@as-external-lsa" ygotAnnotation:"true"`
	Checksum           *uint16                                                                `path:"state/checksum" module:"openconfig-network-instance"`
	ΛChecksum          []ygot.Annotation                                                      `path:"state/@checksum" ygotAnnotation:"true"`
	LinkStateId        *string                                                                `path:"state/link-state-id|link-state-id" module:"openconfig-network-instance"`
	ΛLinkStateId       []ygot.Annotation                                                      `path:"state/@link-state-id|@link-state-id" ygotAnnotation:"true"`
	NetworkLsa         *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa      `path:"network-lsa" module:"openconfig-network-instance"`
	ΛNetworkLsa        []ygot.Annotation                                                      `path:"@network-lsa" ygotAnnotation:"true"`
	NssaExternalLsa    *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa `path:"nssa-external-lsa" module:"openconfig-network-instance"`
	ΛNssaExternalLsa   []ygot.Annotation                                                      `path:"@nssa-external-lsa" ygotAnnotation:"true"`
	OpaqueLsa          *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa       `path:"opaque-lsa" module:"openconfig-network-instance"`
	ΛOpaqueLsa         []ygot.Annotation                                                      `path:"@opaque-lsa" ygotAnnotation:"true"`
	RouterLsa          *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa       `path:"router-lsa" module:"openconfig-network-instance"`
	ΛRouterLsa         []ygot.Annotation                                                      `path:"@router-lsa" ygotAnnotation:"true"`
	SequenceNumber     *int32                                                                 `path:"state/sequence-number" module:"openconfig-network-instance"`
	ΛSequenceNumber    []ygot.Annotation                                                      `path:"state/@sequence-number" ygotAnnotation:"true"`
	SummaryLsa         *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa      `path:"summary-lsa" module:"openconfig-network-instance"`
	ΛSummaryLsa        []ygot.Annotation                                                      `path:"@summary-lsa" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) IsYANGGoStruct() {}

// GetOrCreateAsExternalLsa retrieves the value of the AsExternalLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOrCreateAsExternalLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa {
	if t.AsExternalLsa != nil {
		return t.AsExternalLsa
	}
	t.AsExternalLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa{}
	return t.AsExternalLsa
}

// GetOrCreateNetworkLsa retrieves the value of the NetworkLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOrCreateNetworkLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa {
	if t.NetworkLsa != nil {
		return t.NetworkLsa
	}
	t.NetworkLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa{}
	return t.NetworkLsa
}

// GetOrCreateNssaExternalLsa retrieves the value of the NssaExternalLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOrCreateNssaExternalLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa {
	if t.NssaExternalLsa != nil {
		return t.NssaExternalLsa
	}
	t.NssaExternalLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa{}
	return t.NssaExternalLsa
}

// GetOrCreateOpaqueLsa retrieves the value of the OpaqueLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOrCreateOpaqueLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa {
	if t.OpaqueLsa != nil {
		return t.OpaqueLsa
	}
	t.OpaqueLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa{}
	return t.OpaqueLsa
}

// GetOrCreateRouterLsa retrieves the value of the RouterLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOrCreateRouterLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa {
	if t.RouterLsa != nil {
		return t.RouterLsa
	}
	t.RouterLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa{}
	return t.RouterLsa
}

// GetOrCreateSummaryLsa retrieves the value of the SummaryLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOrCreateSummaryLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa {
	if t.SummaryLsa != nil {
		return t.SummaryLsa
	}
	t.SummaryLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa{}
	return t.SummaryLsa
}

// GetAsExternalLsa returns the value of the AsExternalLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa. If the receiver or the field AsExternalLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetAsExternalLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa {
	if t != nil && t.AsExternalLsa != nil {
		return t.AsExternalLsa
	}
	return nil
}

// GetNetworkLsa returns the value of the NetworkLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa. If the receiver or the field NetworkLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetNetworkLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa {
	if t != nil && t.NetworkLsa != nil {
		return t.NetworkLsa
	}
	return nil
}

// GetNssaExternalLsa returns the value of the NssaExternalLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa. If the receiver or the field NssaExternalLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetNssaExternalLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa {
	if t != nil && t.NssaExternalLsa != nil {
		return t.NssaExternalLsa
	}
	return nil
}

// GetOpaqueLsa returns the value of the OpaqueLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa. If the receiver or the field OpaqueLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetOpaqueLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa {
	if t != nil && t.OpaqueLsa != nil {
		return t.OpaqueLsa
	}
	return nil
}

// GetRouterLsa returns the value of the RouterLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa. If the receiver or the field RouterLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetRouterLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa {
	if t != nil && t.RouterLsa != nil {
		return t.RouterLsa
	}
	return nil
}

// GetSummaryLsa returns the value of the SummaryLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa. If the receiver or the field SummaryLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetSummaryLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa {
	if t != nil && t.SummaryLsa != nil {
		return t.SummaryLsa
	}
	return nil
}

// GetAdvertisingRouter retrieves the value of the leaf AdvertisingRouter from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdvertisingRouter is set, it can safely use t.GetAdvertisingRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdvertisingRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetAdvertisingRouter() string {
	if t == nil || t.AdvertisingRouter == nil {
		return ""
	}
	return *t.AdvertisingRouter
}

// GetAge retrieves the value of the leaf Age from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Age is set, it can safely use t.GetAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Age == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetAge() uint16 {
	if t == nil || t.Age == nil {
		return 0
	}
	return *t.Age
}

// GetChecksum retrieves the value of the leaf Checksum from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Checksum is set, it can safely use t.GetChecksum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Checksum == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetChecksum() uint16 {
	if t == nil || t.Checksum == nil {
		return 0
	}
	return *t.Checksum
}

// GetLinkStateId retrieves the value of the leaf LinkStateId from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkStateId is set, it can safely use t.GetLinkStateId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkStateId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetLinkStateId() string {
	if t == nil || t.LinkStateId == nil {
		return ""
	}
	return *t.LinkStateId
}

// GetSequenceNumber retrieves the value of the leaf SequenceNumber from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SequenceNumber is set, it can safely use t.GetSequenceNumber()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SequenceNumber == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) GetSequenceNumber() int32 {
	if t == nil || t.SequenceNumber == nil {
		return 0
	}
	return *t.SequenceNumber
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LinkStateId == nil {
		return nil, fmt.Errorf("nil value for key LinkStateId")
	}

	return map[string]interface{}{
		"link-state-id": *t.LinkStateId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa struct {
	ΛMetadata          []ygot.Annotation                                                                            `path:"@" ygotAnnotation:"true"`
	ExternalRouteTag   *uint32                                                                                      `path:"state/external-route-tag" module:"openconfig-network-instance"`
	ΛExternalRouteTag  []ygot.Annotation                                                                            `path:"state/@external-route-tag" ygotAnnotation:"true"`
	ForwardingAddress  *string                                                                                      `path:"state/forwarding-address" module:"openconfig-network-instance"`
	ΛForwardingAddress []ygot.Annotation                                                                            `path:"state/@forwarding-address" ygotAnnotation:"true"`
	Mask               *uint8                                                                                       `path:"state/mask" module:"openconfig-network-instance"`
	ΛMask              []ygot.Annotation                                                                            `path:"state/@mask" ygotAnnotation:"true"`
	Metric             *uint16                                                                                      `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric            []ygot.Annotation                                                                            `path:"state/@metric" ygotAnnotation:"true"`
	MetricType         E_AsExternalLsa_MetricType                                                                   `path:"state/metric-type" module:"openconfig-network-instance"`
	ΛMetricType        []ygot.Annotation                                                                            `path:"state/@metric-type" ygotAnnotation:"true"`
	TypeOfService      map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService `path:"types-of-service/type-of-service" module:"openconfig-network-instance"`
	ΛTypeOfService     []ygot.Annotation                                                                            `path:"types-of-service/@type-of-service" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) IsYANGGoStruct() {}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) NewTypeOfService(Tos uint8) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// RenameTypeOfService renames an entry in the list TypeOfService within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) RenameTypeOfService(oldK, newK uint8) error {
	if _, ok := t.TypeOfService[newK]; ok {
		return fmt.Errorf("key %v already exists in TypeOfService", newK)
	}

	e, ok := t.TypeOfService[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TypeOfService", oldK)
	}
	e.Tos = &newK

	t.TypeOfService[newK] = e
	delete(t.TypeOfService, oldK)
	return nil
}

// GetOrCreateTypeOfService retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetOrCreateTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService {

	key := Tos

	if v, ok := t.TypeOfService[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTypeOfService(Tos)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTypeOfService got unexpected error: %v", err))
	}
	return v
}

// GetTypeOfService retrieves the value with the specified key from
// the TypeOfService map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService {

	if t == nil {
		return nil
	}

	key := Tos

	if lm, ok := t.TypeOfService[key]; ok {
		return lm
	}
	return nil
}

// AppendTypeOfService appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService struct to the
// list TypeOfService of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) AppendTypeOfService(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) error {
	if v.Tos == nil {
		return fmt.Errorf("invalid nil key received for Tos")
	}

	key := *v.Tos

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService)
	}

	if _, ok := t.TypeOfService[key]; ok {
		return fmt.Errorf("duplicate key for list TypeOfService %v", key)
	}

	t.TypeOfService[key] = v
	return nil
}

// GetExternalRouteTag retrieves the value of the leaf ExternalRouteTag from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRouteTag is set, it can safely use t.GetExternalRouteTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRouteTag == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetExternalRouteTag() uint32 {
	if t == nil || t.ExternalRouteTag == nil {
		return 0
	}
	return *t.ExternalRouteTag
}

// GetForwardingAddress retrieves the value of the leaf ForwardingAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingAddress is set, it can safely use t.GetForwardingAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetForwardingAddress() string {
	if t == nil || t.ForwardingAddress == nil {
		return ""
	}
	return *t.ForwardingAddress
}

// GetMask retrieves the value of the leaf Mask from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mask is set, it can safely use t.GetMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mask == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetMask() uint8 {
	if t == nil || t.Mask == nil {
		return 0
	}
	return *t.Mask
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetMetricType retrieves the value of the leaf MetricType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MetricType is set, it can safely use t.GetMetricType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MetricType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) GetMetricType() E_AsExternalLsa_MetricType {
	if t == nil || t.MetricType == 0 {
		return 0
	}
	return t.MetricType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/types-of-service/type-of-service YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExternalRouteTag   *uint32           `path:"state/external-route-tag" module:"openconfig-network-instance"`
	ΛExternalRouteTag  []ygot.Annotation `path:"state/@external-route-tag" ygotAnnotation:"true"`
	ForwardingAddress  *string           `path:"state/forwarding-address" module:"openconfig-network-instance"`
	ΛForwardingAddress []ygot.Annotation `path:"state/@forwarding-address" ygotAnnotation:"true"`
	Metric             *uint16           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric            []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
	Tos                *uint8            `path:"state/tos|tos" module:"openconfig-network-instance"`
	ΛTos               []ygot.Annotation `path:"state/@tos|@tos" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) IsYANGGoStruct() {
}

// GetExternalRouteTag retrieves the value of the leaf ExternalRouteTag from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRouteTag is set, it can safely use t.GetExternalRouteTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRouteTag == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) GetExternalRouteTag() uint32 {
	if t == nil || t.ExternalRouteTag == nil {
		return 0
	}
	return *t.ExternalRouteTag
}

// GetForwardingAddress retrieves the value of the leaf ForwardingAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingAddress is set, it can safely use t.GetForwardingAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) GetForwardingAddress() string {
	if t == nil || t.ForwardingAddress == nil {
		return ""
	}
	return *t.ForwardingAddress
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetTos retrieves the value of the leaf Tos from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tos is set, it can safely use t.GetTos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tos == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) GetTos() uint8 {
	if t == nil || t.Tos == nil {
		return 0
	}
	return *t.Tos
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_AsExternalLsa_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/network-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa struct {
	ΛMetadata       []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AttachedRouter  []string          `path:"state/attached-router" module:"openconfig-network-instance"`
	ΛAttachedRouter []ygot.Annotation `path:"state/@attached-router" ygotAnnotation:"true"`
	NetworkMask     *uint8            `path:"state/network-mask" module:"openconfig-network-instance"`
	ΛNetworkMask    []ygot.Annotation `path:"state/@network-mask" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa) IsYANGGoStruct() {}

// GetAttachedRouter retrieves the value of the leaf AttachedRouter from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AttachedRouter is set, it can safely use t.GetAttachedRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AttachedRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa) GetAttachedRouter() []string {
	if t == nil || t.AttachedRouter == nil {
		return nil
	}
	return t.AttachedRouter
}

// GetNetworkMask retrieves the value of the leaf NetworkMask from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NetworkMask is set, it can safely use t.GetNetworkMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NetworkMask == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa) GetNetworkMask() uint8 {
	if t == nil || t.NetworkMask == nil {
		return 0
	}
	return *t.NetworkMask
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NetworkLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa struct {
	ΛMetadata          []ygot.Annotation                                                                              `path:"@" ygotAnnotation:"true"`
	ExternalRouteTag   *uint32                                                                                        `path:"state/external-route-tag" module:"openconfig-network-instance"`
	ΛExternalRouteTag  []ygot.Annotation                                                                              `path:"state/@external-route-tag" ygotAnnotation:"true"`
	ForwardingAddress  *string                                                                                        `path:"state/forwarding-address" module:"openconfig-network-instance"`
	ΛForwardingAddress []ygot.Annotation                                                                              `path:"state/@forwarding-address" ygotAnnotation:"true"`
	Mask               *uint8                                                                                         `path:"state/mask" module:"openconfig-network-instance"`
	ΛMask              []ygot.Annotation                                                                              `path:"state/@mask" ygotAnnotation:"true"`
	Metric             *uint16                                                                                        `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric            []ygot.Annotation                                                                              `path:"state/@metric" ygotAnnotation:"true"`
	MetricType         E_AsExternalLsa_MetricType                                                                     `path:"state/metric-type" module:"openconfig-network-instance"`
	ΛMetricType        []ygot.Annotation                                                                              `path:"state/@metric-type" ygotAnnotation:"true"`
	Propagate          *bool                                                                                          `path:"state/propagate" module:"openconfig-network-instance"`
	ΛPropagate         []ygot.Annotation                                                                              `path:"state/@propagate" ygotAnnotation:"true"`
	TypeOfService      map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService `path:"types-of-service/type-of-service" module:"openconfig-network-instance"`
	ΛTypeOfService     []ygot.Annotation                                                                              `path:"types-of-service/@type-of-service" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) IsYANGGoStruct() {}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) NewTypeOfService(Tos uint8) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// RenameTypeOfService renames an entry in the list TypeOfService within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) RenameTypeOfService(oldK, newK uint8) error {
	if _, ok := t.TypeOfService[newK]; ok {
		return fmt.Errorf("key %v already exists in TypeOfService", newK)
	}

	e, ok := t.TypeOfService[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TypeOfService", oldK)
	}
	e.Tos = &newK

	t.TypeOfService[newK] = e
	delete(t.TypeOfService, oldK)
	return nil
}

// GetOrCreateTypeOfService retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetOrCreateTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService {

	key := Tos

	if v, ok := t.TypeOfService[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTypeOfService(Tos)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTypeOfService got unexpected error: %v", err))
	}
	return v
}

// GetTypeOfService retrieves the value with the specified key from
// the TypeOfService map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService {

	if t == nil {
		return nil
	}

	key := Tos

	if lm, ok := t.TypeOfService[key]; ok {
		return lm
	}
	return nil
}

// AppendTypeOfService appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService struct to the
// list TypeOfService of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) AppendTypeOfService(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) error {
	if v.Tos == nil {
		return fmt.Errorf("invalid nil key received for Tos")
	}

	key := *v.Tos

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService)
	}

	if _, ok := t.TypeOfService[key]; ok {
		return fmt.Errorf("duplicate key for list TypeOfService %v", key)
	}

	t.TypeOfService[key] = v
	return nil
}

// GetExternalRouteTag retrieves the value of the leaf ExternalRouteTag from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRouteTag is set, it can safely use t.GetExternalRouteTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRouteTag == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetExternalRouteTag() uint32 {
	if t == nil || t.ExternalRouteTag == nil {
		return 0
	}
	return *t.ExternalRouteTag
}

// GetForwardingAddress retrieves the value of the leaf ForwardingAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingAddress is set, it can safely use t.GetForwardingAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetForwardingAddress() string {
	if t == nil || t.ForwardingAddress == nil {
		return ""
	}
	return *t.ForwardingAddress
}

// GetMask retrieves the value of the leaf Mask from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mask is set, it can safely use t.GetMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mask == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetMask() uint8 {
	if t == nil || t.Mask == nil {
		return 0
	}
	return *t.Mask
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetMetricType retrieves the value of the leaf MetricType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MetricType is set, it can safely use t.GetMetricType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MetricType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetMetricType() E_AsExternalLsa_MetricType {
	if t == nil || t.MetricType == 0 {
		return 0
	}
	return t.MetricType
}

// GetPropagate retrieves the value of the leaf Propagate from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Propagate is set, it can safely use t.GetPropagate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Propagate == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) GetPropagate() bool {
	if t == nil || t.Propagate == nil {
		return false
	}
	return *t.Propagate
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/types-of-service/type-of-service YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExternalRouteTag   *uint32           `path:"state/external-route-tag" module:"openconfig-network-instance"`
	ΛExternalRouteTag  []ygot.Annotation `path:"state/@external-route-tag" ygotAnnotation:"true"`
	ForwardingAddress  *string           `path:"state/forwarding-address" module:"openconfig-network-instance"`
	ΛForwardingAddress []ygot.Annotation `path:"state/@forwarding-address" ygotAnnotation:"true"`
	Metric             *uint16           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric            []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
	Tos                *uint8            `path:"state/tos|tos" module:"openconfig-network-instance"`
	ΛTos               []ygot.Annotation `path:"state/@tos|@tos" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) IsYANGGoStruct() {
}

// GetExternalRouteTag retrieves the value of the leaf ExternalRouteTag from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExternalRouteTag is set, it can safely use t.GetExternalRouteTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExternalRouteTag == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) GetExternalRouteTag() uint32 {
	if t == nil || t.ExternalRouteTag == nil {
		return 0
	}
	return *t.ExternalRouteTag
}

// GetForwardingAddress retrieves the value of the leaf ForwardingAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingAddress is set, it can safely use t.GetForwardingAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) GetForwardingAddress() string {
	if t == nil || t.ForwardingAddress == nil {
		return ""
	}
	return *t.ForwardingAddress
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetTos retrieves the value of the leaf Tos from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tos is set, it can safely use t.GetTos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tos == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) GetTos() uint8 {
	if t == nil || t.Tos == nil {
		return 0
	}
	return *t.Tos
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_NssaExternalLsa_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa struct {
	ΛMetadata           []ygot.Annotation                                                                   `path:"@" ygotAnnotation:"true"`
	ExtendedLink        *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink       `path:"extended-link" module:"openconfig-network-instance"`
	ΛExtendedLink       []ygot.Annotation                                                                   `path:"@extended-link" ygotAnnotation:"true"`
	ExtendedPrefix      *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix     `path:"extended-prefix" module:"openconfig-network-instance"`
	ΛExtendedPrefix     []ygot.Annotation                                                                   `path:"@extended-prefix" ygotAnnotation:"true"`
	GraceLsa            *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa           `path:"grace-lsa" module:"openconfig-network-instance"`
	ΛGraceLsa           []ygot.Annotation                                                                   `path:"@grace-lsa" ygotAnnotation:"true"`
	RouterInformation   *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation  `path:"router-information" module:"openconfig-network-instance"`
	ΛRouterInformation  []ygot.Annotation                                                                   `path:"@router-information" ygotAnnotation:"true"`
	Scope               E_OpaqueLsa_Scope                                                                   `path:"state/scope" module:"openconfig-network-instance"`
	ΛScope              []ygot.Annotation                                                                   `path:"state/@scope" ygotAnnotation:"true"`
	TrafficEngineering  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering `path:"traffic-engineering" module:"openconfig-network-instance"`
	ΛTrafficEngineering []ygot.Annotation                                                                   `path:"@traffic-engineering" ygotAnnotation:"true"`
	Type                E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE                                          `path:"state/type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                   `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv          *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv         `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv         []ygot.Annotation                                                                   `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) IsYANGGoStruct() {}

// GetOrCreateExtendedLink retrieves the value of the ExtendedLink field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetOrCreateExtendedLink() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink {
	if t.ExtendedLink != nil {
		return t.ExtendedLink
	}
	t.ExtendedLink = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink{}
	return t.ExtendedLink
}

// GetOrCreateExtendedPrefix retrieves the value of the ExtendedPrefix field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetOrCreateExtendedPrefix() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix {
	if t.ExtendedPrefix != nil {
		return t.ExtendedPrefix
	}
	t.ExtendedPrefix = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix{}
	return t.ExtendedPrefix
}

// GetOrCreateGraceLsa retrieves the value of the GraceLsa field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetOrCreateGraceLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa {
	if t.GraceLsa != nil {
		return t.GraceLsa
	}
	t.GraceLsa = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa{}
	return t.GraceLsa
}

// GetOrCreateRouterInformation retrieves the value of the RouterInformation field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetOrCreateRouterInformation() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation {
	if t.RouterInformation != nil {
		return t.RouterInformation
	}
	t.RouterInformation = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation{}
	return t.RouterInformation
}

// GetOrCreateTrafficEngineering retrieves the value of the TrafficEngineering field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetOrCreateTrafficEngineering() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering {
	if t.TrafficEngineering != nil {
		return t.TrafficEngineering
	}
	t.TrafficEngineering = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering{}
	return t.TrafficEngineering
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv{}
	return t.UnknownTlv
}

// GetExtendedLink returns the value of the ExtendedLink struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa. If the receiver or the field ExtendedLink is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetExtendedLink() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink {
	if t != nil && t.ExtendedLink != nil {
		return t.ExtendedLink
	}
	return nil
}

// GetExtendedPrefix returns the value of the ExtendedPrefix struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa. If the receiver or the field ExtendedPrefix is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetExtendedPrefix() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix {
	if t != nil && t.ExtendedPrefix != nil {
		return t.ExtendedPrefix
	}
	return nil
}

// GetGraceLsa returns the value of the GraceLsa struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa. If the receiver or the field GraceLsa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetGraceLsa() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa {
	if t != nil && t.GraceLsa != nil {
		return t.GraceLsa
	}
	return nil
}

// GetRouterInformation returns the value of the RouterInformation struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa. If the receiver or the field RouterInformation is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetRouterInformation() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation {
	if t != nil && t.RouterInformation != nil {
		return t.RouterInformation
	}
	return nil
}

// GetTrafficEngineering returns the value of the TrafficEngineering struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa. If the receiver or the field TrafficEngineering is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetTrafficEngineering() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering {
	if t != nil && t.TrafficEngineering != nil {
		return t.TrafficEngineering
	}
	return nil
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetScope retrieves the value of the leaf Scope from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Scope is set, it can safely use t.GetScope()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Scope == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetScope() E_OpaqueLsa_Scope {
	if t == nil || t.Scope == 0 {
		return 0
	}
	return t.Scope
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) GetType() E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink struct {
	ΛMetadata []ygot.Annotation                                                                           `path:"@" ygotAnnotation:"true"`
	LinkData  NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union `path:"state/link-data" module:"openconfig-network-instance"`
	ΛLinkData []ygot.Annotation                                                                           `path:"state/@link-data" ygotAnnotation:"true"`
	LinkId    *string                                                                                     `path:"state/link-id" module:"openconfig-network-instance"`
	ΛLinkId   []ygot.Annotation                                                                           `path:"state/@link-id" ygotAnnotation:"true"`
	LinkType  E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE                                               `path:"state/link-type" module:"openconfig-network-instance"`
	ΛLinkType []ygot.Annotation                                                                           `path:"state/@link-type" ygotAnnotation:"true"`
	Tlv       []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv         `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv      []ygot.Annotation                                                                           `path:"tlvs/@tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) IsYANGGoStruct() {
}

// GetLinkData retrieves the value of the leaf LinkData from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkData is set, it can safely use t.GetLinkData()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkData == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) GetLinkData() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union {
	if t == nil || t.LinkData == nil {
		return nil
	}
	return t.LinkData
}

// GetLinkId retrieves the value of the leaf LinkId from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkId is set, it can safely use t.GetLinkId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) GetLinkId() string {
	if t == nil || t.LinkId == nil {
		return ""
	}
	return *t.LinkId
}

// GetLinkType retrieves the value of the leaf LinkType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkType is set, it can safely use t.GetLinkType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) GetLinkType() E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE {
	if t == nil || t.LinkType == 0 {
		return 0
	}
	return t.LinkType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state/link-data within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union() {
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_LinkData_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv struct {
	ΛMetadata     []ygot.Annotation                                                                              `path:"@" ygotAnnotation:"true"`
	AdjacencySid  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
	ΛAdjacencySid []ygot.Annotation                                                                              `path:"@adjacency-sid" ygotAnnotation:"true"`
	Type          E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE                                         `path:"state/type" module:"openconfig-network-instance"`
	ΛType         []ygot.Annotation                                                                              `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv    *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv   `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv   []ygot.Annotation                                                                              `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) IsYANGGoStruct() {
}

// GetOrCreateAdjacencySid retrieves the value of the AdjacencySid field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) GetOrCreateAdjacencySid() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid {
	if t.AdjacencySid != nil {
		return t.AdjacencySid
	}
	t.AdjacencySid = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid{}
	return t.AdjacencySid
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv{}
	return t.UnknownTlv
}

// GetAdjacencySid returns the value of the AdjacencySid struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv. If the receiver or the field AdjacencySid is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) GetAdjacencySid() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid {
	if t != nil && t.AdjacencySid != nil {
		return t.AdjacencySid
	}
	return nil
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) GetType() E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/adjacency-sid YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid struct {
	ΛMetadata                []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	Backup                   *bool                           `path:"state/backup" module:"openconfig-network-instance"`
	ΛBackup                  []ygot.Annotation               `path:"state/@backup" ygotAnnotation:"true"`
	Group                    *bool                           `path:"state/group" module:"openconfig-network-instance"`
	ΛGroup                   []ygot.Annotation               `path:"state/@group" ygotAnnotation:"true"`
	MultiTopologyIdentifier  *uint8                          `path:"state/multi-topology-identifier" module:"openconfig-network-instance"`
	ΛMultiTopologyIdentifier []ygot.Annotation               `path:"state/@multi-topology-identifier" ygotAnnotation:"true"`
	SidType                  E_OpenconfigOspfTypes_SrSidType `path:"state/sid-type" module:"openconfig-network-instance"`
	ΛSidType                 []ygot.Annotation               `path:"state/@sid-type" ygotAnnotation:"true"`
	SidValue                 *uint32                         `path:"state/sid-value" module:"openconfig-network-instance"`
	ΛSidValue                []ygot.Annotation               `path:"state/@sid-value" ygotAnnotation:"true"`
	Weight                   *uint8                          `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight                  []ygot.Annotation               `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) IsYANGGoStruct() {
}

// GetBackup retrieves the value of the leaf Backup from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Backup is set, it can safely use t.GetBackup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Backup == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) GetBackup() bool {
	if t == nil || t.Backup == nil {
		return false
	}
	return *t.Backup
}

// GetGroup retrieves the value of the leaf Group from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Group is set, it can safely use t.GetGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Group == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) GetGroup() bool {
	if t == nil || t.Group == nil {
		return false
	}
	return *t.Group
}

// GetMultiTopologyIdentifier retrieves the value of the leaf MultiTopologyIdentifier from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultiTopologyIdentifier is set, it can safely use t.GetMultiTopologyIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultiTopologyIdentifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) GetMultiTopologyIdentifier() uint8 {
	if t == nil || t.MultiTopologyIdentifier == nil {
		return 0
	}
	return *t.MultiTopologyIdentifier
}

// GetSidType retrieves the value of the leaf SidType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidType is set, it can safely use t.GetSidType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) GetSidType() E_OpenconfigOspfTypes_SrSidType {
	if t == nil || t.SidType == 0 {
		return 0
	}
	return t.SidType
}

// GetSidValue retrieves the value of the leaf SidValue from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidValue is set, it can safely use t.GetSidValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) GetSidValue() uint32 {
	if t == nil || t.SidValue == nil {
		return 0
	}
	return *t.SidValue
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedLink_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix struct {
	ΛMetadata      []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	AddressFamily  E_ExtendedPrefix_AddressFamily                                                        `path:"state/address-family" module:"openconfig-network-instance"`
	ΛAddressFamily []ygot.Annotation                                                                     `path:"state/@address-family" ygotAnnotation:"true"`
	Attached       *bool                                                                                 `path:"state/attached" module:"openconfig-network-instance"`
	ΛAttached      []ygot.Annotation                                                                     `path:"state/@attached" ygotAnnotation:"true"`
	Node           *bool                                                                                 `path:"state/node" module:"openconfig-network-instance"`
	ΛNode          []ygot.Annotation                                                                     `path:"state/@node" ygotAnnotation:"true"`
	Prefix         *string                                                                               `path:"state/prefix" module:"openconfig-network-instance"`
	ΛPrefix        []ygot.Annotation                                                                     `path:"state/@prefix" ygotAnnotation:"true"`
	PrefixLength   *uint8                                                                                `path:"state/prefix-length" module:"openconfig-network-instance"`
	ΛPrefixLength  []ygot.Annotation                                                                     `path:"state/@prefix-length" ygotAnnotation:"true"`
	RouteType      E_ExtendedPrefix_RouteType                                                            `path:"state/route-type" module:"openconfig-network-instance"`
	ΛRouteType     []ygot.Annotation                                                                     `path:"state/@route-type" ygotAnnotation:"true"`
	Tlv            []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv           []ygot.Annotation                                                                     `path:"tlvs/@tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) IsYANGGoStruct() {
}

// GetAddressFamily retrieves the value of the leaf AddressFamily from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AddressFamily is set, it can safely use t.GetAddressFamily()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AddressFamily == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) GetAddressFamily() E_ExtendedPrefix_AddressFamily {
	if t == nil || t.AddressFamily == 0 {
		return 0
	}
	return t.AddressFamily
}

// GetAttached retrieves the value of the leaf Attached from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Attached is set, it can safely use t.GetAttached()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Attached == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) GetAttached() bool {
	if t == nil || t.Attached == nil {
		return false
	}
	return *t.Attached
}

// GetNode retrieves the value of the leaf Node from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Node is set, it can safely use t.GetNode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Node == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) GetNode() bool {
	if t == nil || t.Node == nil {
		return false
	}
	return *t.Node
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetPrefixLength retrieves the value of the leaf PrefixLength from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixLength is set, it can safely use t.GetPrefixLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) GetPrefixLength() uint8 {
	if t == nil || t.PrefixLength == nil {
		return 0
	}
	return *t.PrefixLength
}

// GetRouteType retrieves the value of the leaf RouteType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouteType is set, it can safely use t.GetRouteType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouteType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) GetRouteType() E_ExtendedPrefix_RouteType {
	if t == nil || t.RouteType == 0 {
		return 0
	}
	return t.RouteType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv struct {
	ΛMetadata            []ygot.Annotation                                                                                       `path:"@" ygotAnnotation:"true"`
	ExtendedPrefixRange  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange `path:"extended-prefix-range" module:"openconfig-network-instance"`
	ΛExtendedPrefixRange []ygot.Annotation                                                                                       `path:"@extended-prefix-range" ygotAnnotation:"true"`
	PrefixSid            *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid           `path:"prefix-sid" module:"openconfig-network-instance"`
	ΛPrefixSid           []ygot.Annotation                                                                                       `path:"@prefix-sid" ygotAnnotation:"true"`
	SidLabelBinding      *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding     `path:"sid-label-binding" module:"openconfig-network-instance"`
	ΛSidLabelBinding     []ygot.Annotation                                                                                       `path:"@sid-label-binding" ygotAnnotation:"true"`
	Type                 E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE                                                `path:"state/type" module:"openconfig-network-instance"`
	ΛType                []ygot.Annotation                                                                                       `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv           *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv          `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv          []ygot.Annotation                                                                                       `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) IsYANGGoStruct() {
}

// GetOrCreateExtendedPrefixRange retrieves the value of the ExtendedPrefixRange field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetOrCreateExtendedPrefixRange() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange {
	if t.ExtendedPrefixRange != nil {
		return t.ExtendedPrefixRange
	}
	t.ExtendedPrefixRange = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange{}
	return t.ExtendedPrefixRange
}

// GetOrCreatePrefixSid retrieves the value of the PrefixSid field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetOrCreatePrefixSid() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid {
	if t.PrefixSid != nil {
		return t.PrefixSid
	}
	t.PrefixSid = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid{}
	return t.PrefixSid
}

// GetOrCreateSidLabelBinding retrieves the value of the SidLabelBinding field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetOrCreateSidLabelBinding() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding {
	if t.SidLabelBinding != nil {
		return t.SidLabelBinding
	}
	t.SidLabelBinding = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding{}
	return t.SidLabelBinding
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv{}
	return t.UnknownTlv
}

// GetExtendedPrefixRange returns the value of the ExtendedPrefixRange struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv. If the receiver or the field ExtendedPrefixRange is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetExtendedPrefixRange() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange {
	if t != nil && t.ExtendedPrefixRange != nil {
		return t.ExtendedPrefixRange
	}
	return nil
}

// GetPrefixSid returns the value of the PrefixSid struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv. If the receiver or the field PrefixSid is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetPrefixSid() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid {
	if t != nil && t.PrefixSid != nil {
		return t.PrefixSid
	}
	return nil
}

// GetSidLabelBinding returns the value of the SidLabelBinding struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv. If the receiver or the field SidLabelBinding is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetSidLabelBinding() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding {
	if t != nil && t.SidLabelBinding != nil {
		return t.SidLabelBinding
	}
	return nil
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) GetType() E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/extended-prefix-range YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange struct {
	ΛMetadata      []ygot.Annotation              `path:"@" ygotAnnotation:"true"`
	AddressFamily  E_ExtendedPrefix_AddressFamily `path:"state/address-family" module:"openconfig-network-instance"`
	ΛAddressFamily []ygot.Annotation              `path:"state/@address-family" ygotAnnotation:"true"`
	InterArea      *bool                          `path:"state/inter-area" module:"openconfig-network-instance"`
	ΛInterArea     []ygot.Annotation              `path:"state/@inter-area" ygotAnnotation:"true"`
	Prefix         *string                        `path:"state/prefix" module:"openconfig-network-instance"`
	ΛPrefix        []ygot.Annotation              `path:"state/@prefix" ygotAnnotation:"true"`
	PrefixLength   *uint8                         `path:"state/prefix-length" module:"openconfig-network-instance"`
	ΛPrefixLength  []ygot.Annotation              `path:"state/@prefix-length" ygotAnnotation:"true"`
	RangeSize      *uint16                        `path:"state/range-size" module:"openconfig-network-instance"`
	ΛRangeSize     []ygot.Annotation              `path:"state/@range-size" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) IsYANGGoStruct() {
}

// GetAddressFamily retrieves the value of the leaf AddressFamily from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AddressFamily is set, it can safely use t.GetAddressFamily()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AddressFamily == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) GetAddressFamily() E_ExtendedPrefix_AddressFamily {
	if t == nil || t.AddressFamily == 0 {
		return 0
	}
	return t.AddressFamily
}

// GetInterArea retrieves the value of the leaf InterArea from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterArea is set, it can safely use t.GetInterArea()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterArea == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) GetInterArea() bool {
	if t == nil || t.InterArea == nil {
		return false
	}
	return *t.InterArea
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetPrefixLength retrieves the value of the leaf PrefixLength from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixLength is set, it can safely use t.GetPrefixLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) GetPrefixLength() uint8 {
	if t == nil || t.PrefixLength == nil {
		return 0
	}
	return *t.PrefixLength
}

// GetRangeSize retrieves the value of the leaf RangeSize from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RangeSize is set, it can safely use t.GetRangeSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RangeSize == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) GetRangeSize() uint16 {
	if t == nil || t.RangeSize == nil {
		return 0
	}
	return *t.RangeSize
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_ExtendedPrefixRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid struct {
	ΛMetadata                []ygot.Annotation        `path:"@" ygotAnnotation:"true"`
	Algorithm                *uint8                   `path:"state/algorithm" module:"openconfig-network-instance"`
	ΛAlgorithm               []ygot.Annotation        `path:"state/@algorithm" ygotAnnotation:"true"`
	ExplicitNull             *bool                    `path:"state/explicit-null" module:"openconfig-network-instance"`
	ΛExplicitNull            []ygot.Annotation        `path:"state/@explicit-null" ygotAnnotation:"true"`
	MappingServer            *bool                    `path:"state/mapping-server" module:"openconfig-network-instance"`
	ΛMappingServer           []ygot.Annotation        `path:"state/@mapping-server" ygotAnnotation:"true"`
	MultiTopologyIdentifier  *uint8                   `path:"state/multi-topology-identifier" module:"openconfig-network-instance"`
	ΛMultiTopologyIdentifier []ygot.Annotation        `path:"state/@multi-topology-identifier" ygotAnnotation:"true"`
	NoPhp                    *bool                    `path:"state/no-php" module:"openconfig-network-instance"`
	ΛNoPhp                   []ygot.Annotation        `path:"state/@no-php" ygotAnnotation:"true"`
	SidScope                 E_PrefixSid_SidScope     `path:"state/sid-scope" module:"openconfig-network-instance"`
	ΛSidScope                []ygot.Annotation        `path:"state/@sid-scope" ygotAnnotation:"true"`
	SidValue                 *uint32                  `path:"state/sid-value" module:"openconfig-network-instance"`
	ΛSidValue                []ygot.Annotation        `path:"state/@sid-value" ygotAnnotation:"true"`
	SidValueType             E_PrefixSid_SidValueType `path:"state/sid-value-type" module:"openconfig-network-instance"`
	ΛSidValueType            []ygot.Annotation        `path:"state/@sid-value-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) IsYANGGoStruct() {
}

// GetAlgorithm retrieves the value of the leaf Algorithm from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Algorithm is set, it can safely use t.GetAlgorithm()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Algorithm == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetAlgorithm() uint8 {
	if t == nil || t.Algorithm == nil {
		return 0
	}
	return *t.Algorithm
}

// GetExplicitNull retrieves the value of the leaf ExplicitNull from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExplicitNull is set, it can safely use t.GetExplicitNull()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExplicitNull == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetExplicitNull() bool {
	if t == nil || t.ExplicitNull == nil {
		return false
	}
	return *t.ExplicitNull
}

// GetMappingServer retrieves the value of the leaf MappingServer from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MappingServer is set, it can safely use t.GetMappingServer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MappingServer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetMappingServer() bool {
	if t == nil || t.MappingServer == nil {
		return false
	}
	return *t.MappingServer
}

// GetMultiTopologyIdentifier retrieves the value of the leaf MultiTopologyIdentifier from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultiTopologyIdentifier is set, it can safely use t.GetMultiTopologyIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultiTopologyIdentifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetMultiTopologyIdentifier() uint8 {
	if t == nil || t.MultiTopologyIdentifier == nil {
		return 0
	}
	return *t.MultiTopologyIdentifier
}

// GetNoPhp retrieves the value of the leaf NoPhp from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NoPhp is set, it can safely use t.GetNoPhp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NoPhp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetNoPhp() bool {
	if t == nil || t.NoPhp == nil {
		return false
	}
	return *t.NoPhp
}

// GetSidScope retrieves the value of the leaf SidScope from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidScope is set, it can safely use t.GetSidScope()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidScope == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetSidScope() E_PrefixSid_SidScope {
	if t == nil || t.SidScope == 0 {
		return 0
	}
	return t.SidScope
}

// GetSidValue retrieves the value of the leaf SidValue from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidValue is set, it can safely use t.GetSidValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetSidValue() uint32 {
	if t == nil || t.SidValue == nil {
		return 0
	}
	return *t.SidValue
}

// GetSidValueType retrieves the value of the leaf SidValueType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidValueType is set, it can safely use t.GetSidValueType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidValueType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) GetSidValueType() E_PrefixSid_SidValueType {
	if t == nil || t.SidValueType == 0 {
		return 0
	}
	return t.SidValueType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding struct {
	ΛMetadata                []ygot.Annotation                                                                                         `path:"@" ygotAnnotation:"true"`
	Mirroring                *bool                                                                                                     `path:"state/mirroring" module:"openconfig-network-instance"`
	ΛMirroring               []ygot.Annotation                                                                                         `path:"state/@mirroring" ygotAnnotation:"true"`
	MultiTopologyIdentifier  *uint8                                                                                                    `path:"state/multi-topology-identifier" module:"openconfig-network-instance"`
	ΛMultiTopologyIdentifier []ygot.Annotation                                                                                         `path:"state/@multi-topology-identifier" ygotAnnotation:"true"`
	Tlv                      []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv                     []ygot.Annotation                                                                                         `path:"tlvs/@tlv" ygotAnnotation:"true"`
	Weight                   *uint8                                                                                                    `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight                  []ygot.Annotation                                                                                         `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding) IsYANGGoStruct() {
}

// GetMirroring retrieves the value of the leaf Mirroring from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mirroring is set, it can safely use t.GetMirroring()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mirroring == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding) GetMirroring() bool {
	if t == nil || t.Mirroring == nil {
		return false
	}
	return *t.Mirroring
}

// GetMultiTopologyIdentifier retrieves the value of the leaf MultiTopologyIdentifier from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MultiTopologyIdentifier is set, it can safely use t.GetMultiTopologyIdentifier()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MultiTopologyIdentifier == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding) GetMultiTopologyIdentifier() uint8 {
	if t == nil || t.MultiTopologyIdentifier == nil {
		return 0
	}
	return *t.MultiTopologyIdentifier
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding) GetWeight() uint8 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv struct {
	ΛMetadata        []ygot.Annotation                                                                                                       `path:"@" ygotAnnotation:"true"`
	EroMetric        *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric       `path:"ero-metric" module:"openconfig-network-instance"`
	ΛEroMetric       []ygot.Annotation                                                                                                       `path:"@ero-metric" ygotAnnotation:"true"`
	EroPath          *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath         `path:"ero-path" module:"openconfig-network-instance"`
	ΛEroPath         []ygot.Annotation                                                                                                       `path:"@ero-path" ygotAnnotation:"true"`
	SidLabelBinding  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding `path:"sid-label-binding" module:"openconfig-network-instance"`
	ΛSidLabelBinding []ygot.Annotation                                                                                                       `path:"@sid-label-binding" ygotAnnotation:"true"`
	Type             E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE                                              `path:"state/type" module:"openconfig-network-instance"`
	ΛType            []ygot.Annotation                                                                                                       `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) IsYANGGoStruct() {
}

// GetOrCreateEroMetric retrieves the value of the EroMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetOrCreateEroMetric() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric {
	if t.EroMetric != nil {
		return t.EroMetric
	}
	t.EroMetric = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric{}
	return t.EroMetric
}

// GetOrCreateEroPath retrieves the value of the EroPath field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetOrCreateEroPath() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath {
	if t.EroPath != nil {
		return t.EroPath
	}
	t.EroPath = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath{}
	return t.EroPath
}

// GetOrCreateSidLabelBinding retrieves the value of the SidLabelBinding field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetOrCreateSidLabelBinding() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding {
	if t.SidLabelBinding != nil {
		return t.SidLabelBinding
	}
	t.SidLabelBinding = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding{}
	return t.SidLabelBinding
}

// GetEroMetric returns the value of the EroMetric struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv. If the receiver or the field EroMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetEroMetric() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric {
	if t != nil && t.EroMetric != nil {
		return t.EroMetric
	}
	return nil
}

// GetEroPath returns the value of the EroPath struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv. If the receiver or the field EroPath is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetEroPath() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath {
	if t != nil && t.EroPath != nil {
		return t.EroPath
	}
	return nil
}

// GetSidLabelBinding returns the value of the SidLabelBinding struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv. If the receiver or the field SidLabelBinding is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetSidLabelBinding() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding {
	if t != nil && t.SidLabelBinding != nil {
		return t.SidLabelBinding
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) GetType() E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-metric YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint32           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath struct {
	ΛMetadata []ygot.Annotation                                                                                                         `path:"@" ygotAnnotation:"true"`
	Segment   []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment `path:"segments/segment" module:"openconfig-network-instance"`
	ΛSegment  []ygot.Annotation                                                                                                         `path:"segments/@segment" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment struct {
	ΛMetadata      []ygot.Annotation                                                                                                                     `path:"@" ygotAnnotation:"true"`
	Ipv4Segment    *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment   `path:"ipv4-segment" module:"openconfig-network-instance"`
	ΛIpv4Segment   []ygot.Annotation                                                                                                                     `path:"@ipv4-segment" ygotAnnotation:"true"`
	Loose          *bool                                                                                                                                 `path:"state/loose" module:"openconfig-network-instance"`
	ΛLoose         []ygot.Annotation                                                                                                                     `path:"state/@loose" ygotAnnotation:"true"`
	Type           E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE                                                                  `path:"state/type" module:"openconfig-network-instance"`
	ΛType          []ygot.Annotation                                                                                                                     `path:"state/@type" ygotAnnotation:"true"`
	UnnumberedHop  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop `path:"unnumbered-hop" module:"openconfig-network-instance"`
	ΛUnnumberedHop []ygot.Annotation                                                                                                                     `path:"@unnumbered-hop" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) IsYANGGoStruct() {
}

// GetOrCreateIpv4Segment retrieves the value of the Ipv4Segment field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) GetOrCreateIpv4Segment() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment {
	if t.Ipv4Segment != nil {
		return t.Ipv4Segment
	}
	t.Ipv4Segment = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment{}
	return t.Ipv4Segment
}

// GetOrCreateUnnumberedHop retrieves the value of the UnnumberedHop field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) GetOrCreateUnnumberedHop() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop {
	if t.UnnumberedHop != nil {
		return t.UnnumberedHop
	}
	t.UnnumberedHop = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop{}
	return t.UnnumberedHop
}

// GetIpv4Segment returns the value of the Ipv4Segment struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment. If the receiver or the field Ipv4Segment is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) GetIpv4Segment() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment {
	if t != nil && t.Ipv4Segment != nil {
		return t.Ipv4Segment
	}
	return nil
}

// GetUnnumberedHop returns the value of the UnnumberedHop struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment. If the receiver or the field UnnumberedHop is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) GetUnnumberedHop() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop {
	if t != nil && t.UnnumberedHop != nil {
		return t.UnnumberedHop
	}
	return nil
}

// GetLoose retrieves the value of the leaf Loose from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Loose is set, it can safely use t.GetLoose()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Loose == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) GetLoose() bool {
	if t == nil || t.Loose == nil {
		return false
	}
	return *t.Loose
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) GetType() E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/ipv4-segment YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   *string           `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_Ipv4Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/unnumbered-hop YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InterfaceId  *uint32           `path:"state/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId []ygot.Annotation `path:"state/@interface-id" ygotAnnotation:"true"`
	RouterId     *string           `path:"state/router-id" module:"openconfig-network-instance"`
	ΛRouterId    []ygot.Annotation `path:"state/@router-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop) IsYANGGoStruct() {
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop) GetInterfaceId() uint32 {
	if t == nil || t.InterfaceId == nil {
		return 0
	}
	return *t.InterfaceId
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_EroPath_Segment_UnnumberedHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/sid-label-binding YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding struct {
	ΛMetadata []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	SidType   E_OpenconfigOspfTypes_SrSidType `path:"state/sid-type" module:"openconfig-network-instance"`
	ΛSidType  []ygot.Annotation               `path:"state/@sid-type" ygotAnnotation:"true"`
	SidValue  *uint32                         `path:"state/sid-value" module:"openconfig-network-instance"`
	ΛSidValue []ygot.Annotation               `path:"state/@sid-value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding) IsYANGGoStruct() {
}

// GetSidType retrieves the value of the leaf SidType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidType is set, it can safely use t.GetSidType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding) GetSidType() E_OpenconfigOspfTypes_SrSidType {
	if t == nil || t.SidType == 0 {
		return 0
	}
	return t.SidType
}

// GetSidValue retrieves the value of the leaf SidValue from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SidValue is set, it can safely use t.GetSidValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SidValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding) GetSidValue() uint32 {
	if t == nil || t.SidValue == nil {
		return 0
	}
	return *t.SidValue
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_SidLabelBinding_Tlv_SidLabelBinding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_ExtendedPrefix_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa struct {
	ΛMetadata []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	Tlv       []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv      []ygot.Annotation                                                               `path:"tlvs/@tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv struct {
	ΛMetadata           []ygot.Annotation                                                                        `path:"@" ygotAnnotation:"true"`
	IpInterfaceAddress  *string                                                                                  `path:"state/ip-interface-address" module:"openconfig-network-instance"`
	ΛIpInterfaceAddress []ygot.Annotation                                                                        `path:"state/@ip-interface-address" ygotAnnotation:"true"`
	Period              *uint32                                                                                  `path:"state/period" module:"openconfig-network-instance"`
	ΛPeriod             []ygot.Annotation                                                                        `path:"state/@period" ygotAnnotation:"true"`
	Reason              E_Tlv_Reason                                                                             `path:"state/reason" module:"openconfig-network-instance"`
	ΛReason             []ygot.Annotation                                                                        `path:"state/@reason" ygotAnnotation:"true"`
	Type                E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES                                                `path:"state/type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                        `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv          *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv         []ygot.Annotation                                                                        `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) IsYANGGoStruct() {
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv{}
	return t.UnknownTlv
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetIpInterfaceAddress retrieves the value of the leaf IpInterfaceAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpInterfaceAddress is set, it can safely use t.GetIpInterfaceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpInterfaceAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) GetIpInterfaceAddress() string {
	if t == nil || t.IpInterfaceAddress == nil {
		return ""
	}
	return *t.IpInterfaceAddress
}

// GetPeriod retrieves the value of the leaf Period from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Period is set, it can safely use t.GetPeriod()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Period == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) GetPeriod() uint32 {
	if t == nil || t.Period == nil {
		return 0
	}
	return *t.Period
}

// GetReason retrieves the value of the leaf Reason from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Reason is set, it can safely use t.GetReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Reason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) GetReason() E_Tlv_Reason {
	if t == nil || t.Reason == 0 {
		return 0
	}
	return t.Reason
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) GetType() E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_GraceLsa_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation struct {
	ΛMetadata []ygot.Annotation                                                                        `path:"@" ygotAnnotation:"true"`
	Tlv       []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv      []ygot.Annotation                                                                        `path:"tlvs/@tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv struct {
	ΛMetadata                    []ygot.Annotation                                                                                                  `path:"@" ygotAnnotation:"true"`
	InformationalCapabilities    *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities   `path:"informational-capabilities" module:"openconfig-network-instance"`
	ΛInformationalCapabilities   []ygot.Annotation                                                                                                  `path:"@informational-capabilities" ygotAnnotation:"true"`
	NodeAdministrativeTags       *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags      `path:"node-administrative-tags" module:"openconfig-network-instance"`
	ΛNodeAdministrativeTags      []ygot.Annotation                                                                                                  `path:"@node-administrative-tags" ygotAnnotation:"true"`
	SegmentRoutingAlgorithm      *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm     `path:"segment-routing-algorithm" module:"openconfig-network-instance"`
	ΛSegmentRoutingAlgorithm     []ygot.Annotation                                                                                                  `path:"@segment-routing-algorithm" ygotAnnotation:"true"`
	SegmentRoutingSidLabelRange  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange `path:"segment-routing-sid-label-range" module:"openconfig-network-instance"`
	ΛSegmentRoutingSidLabelRange []ygot.Annotation                                                                                                  `path:"@segment-routing-sid-label-range" ygotAnnotation:"true"`
	Type                         NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union                   `path:"state/type" module:"openconfig-network-instance"`
	ΛType                        []ygot.Annotation                                                                                                  `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv                   *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv                  `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv                  []ygot.Annotation                                                                                                  `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) IsYANGGoStruct() {
}

// GetOrCreateInformationalCapabilities retrieves the value of the InformationalCapabilities field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetOrCreateInformationalCapabilities() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities {
	if t.InformationalCapabilities != nil {
		return t.InformationalCapabilities
	}
	t.InformationalCapabilities = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities{}
	return t.InformationalCapabilities
}

// GetOrCreateNodeAdministrativeTags retrieves the value of the NodeAdministrativeTags field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetOrCreateNodeAdministrativeTags() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags {
	if t.NodeAdministrativeTags != nil {
		return t.NodeAdministrativeTags
	}
	t.NodeAdministrativeTags = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags{}
	return t.NodeAdministrativeTags
}

// GetOrCreateSegmentRoutingAlgorithm retrieves the value of the SegmentRoutingAlgorithm field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetOrCreateSegmentRoutingAlgorithm() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm {
	if t.SegmentRoutingAlgorithm != nil {
		return t.SegmentRoutingAlgorithm
	}
	t.SegmentRoutingAlgorithm = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm{}
	return t.SegmentRoutingAlgorithm
}

// GetOrCreateSegmentRoutingSidLabelRange retrieves the value of the SegmentRoutingSidLabelRange field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetOrCreateSegmentRoutingSidLabelRange() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange {
	if t.SegmentRoutingSidLabelRange != nil {
		return t.SegmentRoutingSidLabelRange
	}
	t.SegmentRoutingSidLabelRange = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange{}
	return t.SegmentRoutingSidLabelRange
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv{}
	return t.UnknownTlv
}

// GetInformationalCapabilities returns the value of the InformationalCapabilities struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv. If the receiver or the field InformationalCapabilities is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetInformationalCapabilities() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities {
	if t != nil && t.InformationalCapabilities != nil {
		return t.InformationalCapabilities
	}
	return nil
}

// GetNodeAdministrativeTags returns the value of the NodeAdministrativeTags struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv. If the receiver or the field NodeAdministrativeTags is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetNodeAdministrativeTags() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags {
	if t != nil && t.NodeAdministrativeTags != nil {
		return t.NodeAdministrativeTags
	}
	return nil
}

// GetSegmentRoutingAlgorithm returns the value of the SegmentRoutingAlgorithm struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv. If the receiver or the field SegmentRoutingAlgorithm is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetSegmentRoutingAlgorithm() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm {
	if t != nil && t.SegmentRoutingAlgorithm != nil {
		return t.SegmentRoutingAlgorithm
	}
	return nil
}

// GetSegmentRoutingSidLabelRange returns the value of the SegmentRoutingSidLabelRange struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv. If the receiver or the field SegmentRoutingSidLabelRange is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetSegmentRoutingSidLabelRange() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange {
	if t != nil && t.SegmentRoutingSidLabelRange != nil {
		return t.SegmentRoutingSidLabelRange
	}
	return nil
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) GetType() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state/type within the YANG schema.
// Union type can be one of [E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES, E_RouterInformation_Tlv_Type_Enum].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union interface {
	// Union type can be one of [E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES, E_RouterInformation_Tlv_Type_Enum]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union ensures that E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union interface.
func (E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union ensures that E_RouterInformation_Tlv_Type_Enum
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union interface.
func (E_RouterInformation_Tlv_Type_Enum) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union() {
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union); ok {
		return v, nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES, E_RouterInformation_Tlv_Type_Enum]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/informational-capabilities YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities struct {
	ΛMetadata               []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	ExperimentalTe          *bool             `path:"state/experimental-te" module:"openconfig-network-instance"`
	ΛExperimentalTe         []ygot.Annotation `path:"state/@experimental-te" ygotAnnotation:"true"`
	GracefulRestartCapable  *bool             `path:"state/graceful-restart-capable" module:"openconfig-network-instance"`
	ΛGracefulRestartCapable []ygot.Annotation `path:"state/@graceful-restart-capable" ygotAnnotation:"true"`
	GracefulRestartHelper   *bool             `path:"state/graceful-restart-helper" module:"openconfig-network-instance"`
	ΛGracefulRestartHelper  []ygot.Annotation `path:"state/@graceful-restart-helper" ygotAnnotation:"true"`
	PointToPointOverLan     *bool             `path:"state/point-to-point-over-lan" module:"openconfig-network-instance"`
	ΛPointToPointOverLan    []ygot.Annotation `path:"state/@point-to-point-over-lan" ygotAnnotation:"true"`
	StubRouter              *bool             `path:"state/stub-router" module:"openconfig-network-instance"`
	ΛStubRouter             []ygot.Annotation `path:"state/@stub-router" ygotAnnotation:"true"`
	TrafficEngineering      *bool             `path:"state/traffic-engineering" module:"openconfig-network-instance"`
	ΛTrafficEngineering     []ygot.Annotation `path:"state/@traffic-engineering" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) IsYANGGoStruct() {
}

// GetExperimentalTe retrieves the value of the leaf ExperimentalTe from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExperimentalTe is set, it can safely use t.GetExperimentalTe()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExperimentalTe == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) GetExperimentalTe() bool {
	if t == nil || t.ExperimentalTe == nil {
		return false
	}
	return *t.ExperimentalTe
}

// GetGracefulRestartCapable retrieves the value of the leaf GracefulRestartCapable from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if GracefulRestartCapable is set, it can safely use t.GetGracefulRestartCapable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.GracefulRestartCapable == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) GetGracefulRestartCapable() bool {
	if t == nil || t.GracefulRestartCapable == nil {
		return false
	}
	return *t.GracefulRestartCapable
}

// GetGracefulRestartHelper retrieves the value of the leaf GracefulRestartHelper from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if GracefulRestartHelper is set, it can safely use t.GetGracefulRestartHelper()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.GracefulRestartHelper == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) GetGracefulRestartHelper() bool {
	if t == nil || t.GracefulRestartHelper == nil {
		return false
	}
	return *t.GracefulRestartHelper
}

// GetPointToPointOverLan retrieves the value of the leaf PointToPointOverLan from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PointToPointOverLan is set, it can safely use t.GetPointToPointOverLan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PointToPointOverLan == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) GetPointToPointOverLan() bool {
	if t == nil || t.PointToPointOverLan == nil {
		return false
	}
	return *t.PointToPointOverLan
}

// GetStubRouter retrieves the value of the leaf StubRouter from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StubRouter is set, it can safely use t.GetStubRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StubRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) GetStubRouter() bool {
	if t == nil || t.StubRouter == nil {
		return false
	}
	return *t.StubRouter
}

// GetTrafficEngineering retrieves the value of the leaf TrafficEngineering from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrafficEngineering is set, it can safely use t.GetTrafficEngineering()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrafficEngineering == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) GetTrafficEngineering() bool {
	if t == nil || t.TrafficEngineering == nil {
		return false
	}
	return *t.TrafficEngineering
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_InformationalCapabilities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/node-administrative-tags YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdministrativeTags  []uint32          `path:"state/administrative-tags" module:"openconfig-network-instance"`
	ΛAdministrativeTags []ygot.Annotation `path:"state/@administrative-tags" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags) IsYANGGoStruct() {
}

// GetAdministrativeTags retrieves the value of the leaf AdministrativeTags from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdministrativeTags is set, it can safely use t.GetAdministrativeTags()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdministrativeTags == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags) GetAdministrativeTags() []uint32 {
	if t == nil || t.AdministrativeTags == nil {
		return nil
	}
	return t.AdministrativeTags
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_NodeAdministrativeTags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-algorithm YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm struct {
	ΛMetadata            []ygot.Annotation                    `path:"@" ygotAnnotation:"true"`
	SupportedAlgorithms  []E_OpenconfigOspfTypes_SR_ALGORITHM `path:"state/supported-algorithms" module:"openconfig-network-instance"`
	ΛSupportedAlgorithms []ygot.Annotation                    `path:"state/@supported-algorithms" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm) IsYANGGoStruct() {
}

// GetSupportedAlgorithms retrieves the value of the leaf SupportedAlgorithms from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SupportedAlgorithms is set, it can safely use t.GetSupportedAlgorithms()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SupportedAlgorithms == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm) GetSupportedAlgorithms() []E_OpenconfigOspfTypes_SR_ALGORITHM {
	if t == nil || t.SupportedAlgorithms == nil {
		return nil
	}
	return t.SupportedAlgorithms
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingAlgorithm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange struct {
	ΛMetadata []ygot.Annotation                                                                                                        `path:"@" ygotAnnotation:"true"`
	Tlv       []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv      []ygot.Annotation                                                                                                        `path:"tlvs/@tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv struct {
	ΛMetadata   []ygot.Annotation                                                                                                                 `path:"@" ygotAnnotation:"true"`
	RangeSize   *uint32                                                                                                                           `path:"state/range-size" module:"openconfig-network-instance"`
	ΛRangeSize  []ygot.Annotation                                                                                                                 `path:"state/@range-size" ygotAnnotation:"true"`
	SidLabel    *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel   `path:"sid-label" module:"openconfig-network-instance"`
	ΛSidLabel   []ygot.Annotation                                                                                                                 `path:"@sid-label" ygotAnnotation:"true"`
	Type        NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union  `path:"state/type" module:"openconfig-network-instance"`
	ΛType       []ygot.Annotation                                                                                                                 `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv []ygot.Annotation                                                                                                                 `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) IsYANGGoStruct() {
}

// GetOrCreateSidLabel retrieves the value of the SidLabel field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) GetOrCreateSidLabel() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel {
	if t.SidLabel != nil {
		return t.SidLabel
	}
	t.SidLabel = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel{}
	return t.SidLabel
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv{}
	return t.UnknownTlv
}

// GetSidLabel returns the value of the SidLabel struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv. If the receiver or the field SidLabel is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) GetSidLabel() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel {
	if t != nil && t.SidLabel != nil {
		return t.SidLabel
	}
	return nil
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetRangeSize retrieves the value of the leaf RangeSize from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RangeSize is set, it can safely use t.GetRangeSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RangeSize == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) GetRangeSize() uint32 {
	if t == nil || t.RangeSize == nil {
		return 0
	}
	return *t.RangeSize
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) GetType() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state/type within the YANG schema.
// Union type can be one of [E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES, E_SegmentRoutingSidLabelRange_Tlv_Type_Enum].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union interface {
	// Union type can be one of [E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES, E_SegmentRoutingSidLabelRange_Tlv_Type_Enum]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union ensures that E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union interface.
func (E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union ensures that E_SegmentRoutingSidLabelRange_Tlv_Type_Enum
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union interface.
func (E_SegmentRoutingSidLabelRange_Tlv_Type_Enum) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union() {
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union); ok {
		return v, nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES, E_SegmentRoutingSidLabelRange_Tlv_Type_Enum]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/sid-label YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel struct {
	ΛMetadata   []ygot.Annotation               `path:"@" ygotAnnotation:"true"`
	EntryType   E_OpenconfigOspfTypes_SrSidType `path:"state/entry-type" module:"openconfig-network-instance"`
	ΛEntryType  []ygot.Annotation               `path:"state/@entry-type" ygotAnnotation:"true"`
	FirstValue  *uint32                         `path:"state/first-value" module:"openconfig-network-instance"`
	ΛFirstValue []ygot.Annotation               `path:"state/@first-value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel) IsYANGGoStruct() {
}

// GetEntryType retrieves the value of the leaf EntryType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EntryType is set, it can safely use t.GetEntryType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EntryType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel) GetEntryType() E_OpenconfigOspfTypes_SrSidType {
	if t == nil || t.EntryType == 0 {
		return 0
	}
	return t.EntryType
}

// GetFirstValue retrieves the value of the leaf FirstValue from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FirstValue is set, it can safely use t.GetFirstValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FirstValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel) GetFirstValue() uint32 {
	if t == nil || t.FirstValue == nil {
		return 0
	}
	return *t.FirstValue
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_SidLabel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_SegmentRoutingSidLabelRange_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_RouterInformation_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering struct {
	ΛMetadata []ygot.Annotation                                                                         `path:"@" ygotAnnotation:"true"`
	Tlv       []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv `path:"tlvs/tlv" module:"openconfig-network-instance"`
	ΛTlv      []ygot.Annotation                                                                         `path:"tlvs/@tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv struct {
	ΛMetadata      []ygot.Annotation                                                                                     `path:"@" ygotAnnotation:"true"`
	Link           *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link          `path:"link" module:"openconfig-network-instance"`
	ΛLink          []ygot.Annotation                                                                                     `path:"@link" ygotAnnotation:"true"`
	NodeAttribute  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute `path:"node-attribute" module:"openconfig-network-instance"`
	ΛNodeAttribute []ygot.Annotation                                                                                     `path:"@node-attribute" ygotAnnotation:"true"`
	RouterAddress  *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress `path:"router-address" module:"openconfig-network-instance"`
	ΛRouterAddress []ygot.Annotation                                                                                     `path:"@router-address" ygotAnnotation:"true"`
	Type           E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE                                                            `path:"state/type" module:"openconfig-network-instance"`
	ΛType          []ygot.Annotation                                                                                     `path:"state/@type" ygotAnnotation:"true"`
	UnknownTlv     *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv    `path:"unknown-tlv" module:"openconfig-network-instance"`
	ΛUnknownTlv    []ygot.Annotation                                                                                     `path:"@unknown-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) IsYANGGoStruct() {
}

// GetOrCreateLink retrieves the value of the Link field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetOrCreateLink() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link {
	if t.Link != nil {
		return t.Link
	}
	t.Link = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link{}
	return t.Link
}

// GetOrCreateNodeAttribute retrieves the value of the NodeAttribute field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetOrCreateNodeAttribute() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute {
	if t.NodeAttribute != nil {
		return t.NodeAttribute
	}
	t.NodeAttribute = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute{}
	return t.NodeAttribute
}

// GetOrCreateRouterAddress retrieves the value of the RouterAddress field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetOrCreateRouterAddress() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress {
	if t.RouterAddress != nil {
		return t.RouterAddress
	}
	t.RouterAddress = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress{}
	return t.RouterAddress
}

// GetOrCreateUnknownTlv retrieves the value of the UnknownTlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetOrCreateUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv {
	if t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	t.UnknownTlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv{}
	return t.UnknownTlv
}

// GetLink returns the value of the Link struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv. If the receiver or the field Link is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetLink() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link {
	if t != nil && t.Link != nil {
		return t.Link
	}
	return nil
}

// GetNodeAttribute returns the value of the NodeAttribute struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv. If the receiver or the field NodeAttribute is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetNodeAttribute() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute {
	if t != nil && t.NodeAttribute != nil {
		return t.NodeAttribute
	}
	return nil
}

// GetRouterAddress returns the value of the RouterAddress struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv. If the receiver or the field RouterAddress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetRouterAddress() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress {
	if t != nil && t.RouterAddress != nil {
		return t.RouterAddress
	}
	return nil
}

// GetUnknownTlv returns the value of the UnknownTlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv. If the receiver or the field UnknownTlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetUnknownTlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv {
	if t != nil && t.UnknownTlv != nil {
		return t.UnknownTlv
	}
	return nil
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) GetType() E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link struct {
	ΛMetadata []ygot.Annotation                                                                                     `path:"@" ygotAnnotation:"true"`
	SubTlv    []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv `path:"sub-tlvs/sub-tlv" module:"openconfig-network-instance"`
	ΛSubTlv   []ygot.Annotation                                                                                     `path:"sub-tlvs/@sub-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv struct {
	ΛMetadata                   []ygot.Annotation                                                                                                                 `path:"@" ygotAnnotation:"true"`
	AdminGroup                  map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup          `path:"administrative-groups/admin-group" module:"openconfig-network-instance"`
	ΛAdminGroup                 []ygot.Annotation                                                                                                                 `path:"administrative-groups/@admin-group" ygotAnnotation:"true"`
	LinkId                      *string                                                                                                                           `path:"state/link-id" module:"openconfig-network-instance"`
	ΛLinkId                     []ygot.Annotation                                                                                                                 `path:"state/@link-id" ygotAnnotation:"true"`
	LinkType                    E_SubTlv_LinkType                                                                                                                 `path:"state/link-type" module:"openconfig-network-instance"`
	ΛLinkType                   []ygot.Annotation                                                                                                                 `path:"state/@link-type" ygotAnnotation:"true"`
	LocalIpAddress              []string                                                                                                                          `path:"state/local-ip-address" module:"openconfig-network-instance"`
	ΛLocalIpAddress             []ygot.Annotation                                                                                                                 `path:"state/@local-ip-address" ygotAnnotation:"true"`
	MaximumBandwidth            Binary                                                                                                                            `path:"state/maximum-bandwidth" module:"openconfig-network-instance"`
	ΛMaximumBandwidth           []ygot.Annotation                                                                                                                 `path:"state/@maximum-bandwidth" ygotAnnotation:"true"`
	MaximumReservableBandwidth  Binary                                                                                                                            `path:"state/maximum-reservable-bandwidth" module:"openconfig-network-instance"`
	ΛMaximumReservableBandwidth []ygot.Annotation                                                                                                                 `path:"state/@maximum-reservable-bandwidth" ygotAnnotation:"true"`
	Metric                      *uint32                                                                                                                           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric                     []ygot.Annotation                                                                                                                 `path:"state/@metric" ygotAnnotation:"true"`
	RemoteIpAddress             []string                                                                                                                          `path:"state/remote-ip-address" module:"openconfig-network-instance"`
	ΛRemoteIpAddress            []ygot.Annotation                                                                                                                 `path:"state/@remote-ip-address" ygotAnnotation:"true"`
	Type                        NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union                     `path:"state/type" module:"openconfig-network-instance"`
	ΛType                       []ygot.Annotation                                                                                                                 `path:"state/@type" ygotAnnotation:"true"`
	UnknownSubtlv               *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv                 `path:"unknown-subtlv" module:"openconfig-network-instance"`
	ΛUnknownSubtlv              []ygot.Annotation                                                                                                                 `path:"@unknown-subtlv" ygotAnnotation:"true"`
	UnknownType                 *uint16                                                                                                                           `path:"state/unknown-type" module:"openconfig-network-instance"`
	ΛUnknownType                []ygot.Annotation                                                                                                                 `path:"state/@unknown-type" ygotAnnotation:"true"`
	UnknownValue                Binary                                                                                                                            `path:"state/unknown-value" module:"openconfig-network-instance"`
	ΛUnknownValue               []ygot.Annotation                                                                                                                 `path:"state/@unknown-value" ygotAnnotation:"true"`
	UnreservedBandwidth         map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth `path:"unreserved-bandwidths/unreserved-bandwidth" module:"openconfig-network-instance"`
	ΛUnreservedBandwidth        []ygot.Annotation                                                                                                                 `path:"unreserved-bandwidths/@unreserved-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) IsYANGGoStruct() {
}

// NewAdminGroup creates a new entry in the AdminGroup list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) NewAdminGroup(BitIndex uint8) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdminGroup == nil {
		t.AdminGroup = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup)
	}

	key := BitIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdminGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdminGroup", key)
	}

	t.AdminGroup[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup{
		BitIndex: &BitIndex,
	}

	return t.AdminGroup[key], nil
}

// RenameAdminGroup renames an entry in the list AdminGroup within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) RenameAdminGroup(oldK, newK uint8) error {
	if _, ok := t.AdminGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in AdminGroup", newK)
	}

	e, ok := t.AdminGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in AdminGroup", oldK)
	}
	e.BitIndex = &newK

	t.AdminGroup[newK] = e
	delete(t.AdminGroup, oldK)
	return nil
}

// GetOrCreateAdminGroup retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetOrCreateAdminGroup(BitIndex uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup {

	key := BitIndex

	if v, ok := t.AdminGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAdminGroup(BitIndex)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAdminGroup got unexpected error: %v", err))
	}
	return v
}

// GetAdminGroup retrieves the value with the specified key from
// the AdminGroup map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetAdminGroup(BitIndex uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup {

	if t == nil {
		return nil
	}

	key := BitIndex

	if lm, ok := t.AdminGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendAdminGroup appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup struct to the
// list AdminGroup of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) AppendAdminGroup(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) error {
	if v.BitIndex == nil {
		return fmt.Errorf("invalid nil key received for BitIndex")
	}

	key := *v.BitIndex

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdminGroup == nil {
		t.AdminGroup = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup)
	}

	if _, ok := t.AdminGroup[key]; ok {
		return fmt.Errorf("duplicate key for list AdminGroup %v", key)
	}

	t.AdminGroup[key] = v
	return nil
}

// NewUnreservedBandwidth creates a new entry in the UnreservedBandwidth list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) NewUnreservedBandwidth(Priority uint8) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnreservedBandwidth == nil {
		t.UnreservedBandwidth = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnreservedBandwidth[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnreservedBandwidth", key)
	}

	t.UnreservedBandwidth[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth{
		Priority: &Priority,
	}

	return t.UnreservedBandwidth[key], nil
}

// RenameUnreservedBandwidth renames an entry in the list UnreservedBandwidth within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) RenameUnreservedBandwidth(oldK, newK uint8) error {
	if _, ok := t.UnreservedBandwidth[newK]; ok {
		return fmt.Errorf("key %v already exists in UnreservedBandwidth", newK)
	}

	e, ok := t.UnreservedBandwidth[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in UnreservedBandwidth", oldK)
	}
	e.Priority = &newK

	t.UnreservedBandwidth[newK] = e
	delete(t.UnreservedBandwidth, oldK)
	return nil
}

// GetOrCreateUnreservedBandwidth retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetOrCreateUnreservedBandwidth(Priority uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth {

	key := Priority

	if v, ok := t.UnreservedBandwidth[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUnreservedBandwidth(Priority)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUnreservedBandwidth got unexpected error: %v", err))
	}
	return v
}

// GetUnreservedBandwidth retrieves the value with the specified key from
// the UnreservedBandwidth map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetUnreservedBandwidth(Priority uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth {

	if t == nil {
		return nil
	}

	key := Priority

	if lm, ok := t.UnreservedBandwidth[key]; ok {
		return lm
	}
	return nil
}

// AppendUnreservedBandwidth appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth struct to the
// list UnreservedBandwidth of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) AppendUnreservedBandwidth(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) error {
	if v.Priority == nil {
		return fmt.Errorf("invalid nil key received for Priority")
	}

	key := *v.Priority

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnreservedBandwidth == nil {
		t.UnreservedBandwidth = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth)
	}

	if _, ok := t.UnreservedBandwidth[key]; ok {
		return fmt.Errorf("duplicate key for list UnreservedBandwidth %v", key)
	}

	t.UnreservedBandwidth[key] = v
	return nil
}

// GetOrCreateUnknownSubtlv retrieves the value of the UnknownSubtlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetOrCreateUnknownSubtlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv {
	if t.UnknownSubtlv != nil {
		return t.UnknownSubtlv
	}
	t.UnknownSubtlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv{}
	return t.UnknownSubtlv
}

// GetUnknownSubtlv returns the value of the UnknownSubtlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv. If the receiver or the field UnknownSubtlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetUnknownSubtlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv {
	if t != nil && t.UnknownSubtlv != nil {
		return t.UnknownSubtlv
	}
	return nil
}

// GetLinkId retrieves the value of the leaf LinkId from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkId is set, it can safely use t.GetLinkId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetLinkId() string {
	if t == nil || t.LinkId == nil {
		return ""
	}
	return *t.LinkId
}

// GetLinkType retrieves the value of the leaf LinkType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkType is set, it can safely use t.GetLinkType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetLinkType() E_SubTlv_LinkType {
	if t == nil || t.LinkType == 0 {
		return 0
	}
	return t.LinkType
}

// GetLocalIpAddress retrieves the value of the leaf LocalIpAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpAddress is set, it can safely use t.GetLocalIpAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetLocalIpAddress() []string {
	if t == nil || t.LocalIpAddress == nil {
		return nil
	}
	return t.LocalIpAddress
}

// GetMaximumBandwidth retrieves the value of the leaf MaximumBandwidth from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumBandwidth is set, it can safely use t.GetMaximumBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetMaximumBandwidth() Binary {
	if t == nil || t.MaximumBandwidth == nil {
		return nil
	}
	return t.MaximumBandwidth
}

// GetMaximumReservableBandwidth retrieves the value of the leaf MaximumReservableBandwidth from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumReservableBandwidth is set, it can safely use t.GetMaximumReservableBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumReservableBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetMaximumReservableBandwidth() Binary {
	if t == nil || t.MaximumReservableBandwidth == nil {
		return nil
	}
	return t.MaximumReservableBandwidth
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetRemoteIpAddress retrieves the value of the leaf RemoteIpAddress from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteIpAddress is set, it can safely use t.GetRemoteIpAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteIpAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetRemoteIpAddress() []string {
	if t == nil || t.RemoteIpAddress == nil {
		return nil
	}
	return t.RemoteIpAddress
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetType() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// GetUnknownType retrieves the value of the leaf UnknownType from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnknownType is set, it can safely use t.GetUnknownType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnknownType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetUnknownType() uint16 {
	if t == nil || t.UnknownType == nil {
		return 0
	}
	return *t.UnknownType
}

// GetUnknownValue retrieves the value of the leaf UnknownValue from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnknownValue is set, it can safely use t.GetUnknownValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnknownValue == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) GetUnknownValue() Binary {
	if t == nil || t.UnknownValue == nil {
		return nil
	}
	return t.UnknownValue
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/type within the YANG schema.
// Union type can be one of [E_Link_SubTlv_Type_Enum, E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union interface {
	// Union type can be one of [E_Link_SubTlv_Type_Enum, E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union ensures that E_Link_SubTlv_Type_Enum
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union interface.
func (E_Link_SubTlv_Type_Enum) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union ensures that E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union interface.
func (E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union() {
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union); ok {
		return v, nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_Type_Union, unknown union type, got: %T, want any of [E_Link_SubTlv_Type_Enum, E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/administrative-groups/admin-group YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BitIndex  *uint8            `path:"state/bit-index|bit-index" module:"openconfig-network-instance"`
	ΛBitIndex []ygot.Annotation `path:"state/@bit-index|@bit-index" ygotAnnotation:"true"`
	Set       *bool             `path:"state/set" module:"openconfig-network-instance"`
	ΛSet      []ygot.Annotation `path:"state/@set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) IsYANGGoStruct() {
}

// GetBitIndex retrieves the value of the leaf BitIndex from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BitIndex is set, it can safely use t.GetBitIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BitIndex == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) GetBitIndex() uint8 {
	if t == nil || t.BitIndex == nil {
		return 0
	}
	return *t.BitIndex
}

// GetSet retrieves the value of the leaf Set from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Set is set, it can safely use t.GetSet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Set == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) GetSet() bool {
	if t == nil || t.Set == nil {
		return false
	}
	return *t.Set
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.BitIndex == nil {
		return nil, fmt.Errorf("nil value for key BitIndex")
	}

	return map[string]interface{}{
		"bit-index": *t.BitIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unknown-subtlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnknownSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unreserved-bandwidths/unreserved-bandwidth YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Priority             *uint8            `path:"state/priority|priority" module:"openconfig-network-instance"`
	ΛPriority            []ygot.Annotation `path:"state/@priority|@priority" ygotAnnotation:"true"`
	UnreservedBandwidth  Binary            `path:"state/unreserved-bandwidth" module:"openconfig-network-instance"`
	ΛUnreservedBandwidth []ygot.Annotation `path:"state/@unreserved-bandwidth" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) IsYANGGoStruct() {
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetUnreservedBandwidth retrieves the value of the leaf UnreservedBandwidth from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnreservedBandwidth is set, it can safely use t.GetUnreservedBandwidth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnreservedBandwidth == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) GetUnreservedBandwidth() Binary {
	if t == nil || t.UnreservedBandwidth == nil {
		return nil
	}
	return t.UnreservedBandwidth
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_Link_SubTlv_UnreservedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute struct {
	ΛMetadata []ygot.Annotation                                                                                              `path:"@" ygotAnnotation:"true"`
	SubTlv    []*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv `path:"sub-tlvs/sub-tlv" module:"openconfig-network-instance"`
	ΛSubTlv   []ygot.Annotation                                                                                              `path:"sub-tlvs/@sub-tlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv struct {
	ΛMetadata           []ygot.Annotation                                                                                                          `path:"@" ygotAnnotation:"true"`
	LocalIpv4Addresses  []string                                                                                                                   `path:"state/local-ipv4-addresses" module:"openconfig-network-instance"`
	ΛLocalIpv4Addresses []ygot.Annotation                                                                                                          `path:"state/@local-ipv4-addresses" ygotAnnotation:"true"`
	LocalIpv6Addresses  []string                                                                                                                   `path:"state/local-ipv6-addresses" module:"openconfig-network-instance"`
	ΛLocalIpv6Addresses []ygot.Annotation                                                                                                          `path:"state/@local-ipv6-addresses" ygotAnnotation:"true"`
	Type                NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union     `path:"state/type" module:"openconfig-network-instance"`
	ΛType               []ygot.Annotation                                                                                                          `path:"state/@type" ygotAnnotation:"true"`
	UnknownSubtlv       *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv `path:"unknown-subtlv" module:"openconfig-network-instance"`
	ΛUnknownSubtlv      []ygot.Annotation                                                                                                          `path:"@unknown-subtlv" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) IsYANGGoStruct() {
}

// GetOrCreateUnknownSubtlv retrieves the value of the UnknownSubtlv field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) GetOrCreateUnknownSubtlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv {
	if t.UnknownSubtlv != nil {
		return t.UnknownSubtlv
	}
	t.UnknownSubtlv = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv{}
	return t.UnknownSubtlv
}

// GetUnknownSubtlv returns the value of the UnknownSubtlv struct pointer
// from NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv. If the receiver or the field UnknownSubtlv is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) GetUnknownSubtlv() *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv {
	if t != nil && t.UnknownSubtlv != nil {
		return t.UnknownSubtlv
	}
	return nil
}

// GetLocalIpv4Addresses retrieves the value of the leaf LocalIpv4Addresses from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpv4Addresses is set, it can safely use t.GetLocalIpv4Addresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpv4Addresses == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) GetLocalIpv4Addresses() []string {
	if t == nil || t.LocalIpv4Addresses == nil {
		return nil
	}
	return t.LocalIpv4Addresses
}

// GetLocalIpv6Addresses retrieves the value of the leaf LocalIpv6Addresses from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalIpv6Addresses is set, it can safely use t.GetLocalIpv6Addresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalIpv6Addresses == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) GetLocalIpv6Addresses() []string {
	if t == nil || t.LocalIpv6Addresses == nil {
		return nil
	}
	return t.LocalIpv6Addresses
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) GetType() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union {
	if t == nil || t.Type == nil {
		return nil
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state/type within the YANG schema.
// Union type can be one of [E_NodeAttribute_SubTlv_Type_Enum, E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union interface {
	// Union type can be one of [E_NodeAttribute_SubTlv_Type_Enum, E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union ensures that E_NodeAttribute_SubTlv_Type_Enum
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union interface.
func (E_NodeAttribute_SubTlv_Type_Enum) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union ensures that E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union interface.
func (E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union() {
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union); ok {
		return v, nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_Type_Union, unknown union type, got: %T, want any of [E_NodeAttribute_SubTlv_Type_Enum, E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/unknown-subtlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_NodeAttribute_SubTlv_UnknownSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/router-address YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   *string           `path:"state/address" module:"openconfig-network-instance"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress) IsYANGGoStruct() {
}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_RouterAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_TrafficEngineering_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/unknown-tlv YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Length    *uint16           `path:"state/length" module:"openconfig-network-instance"`
	ΛLength   []ygot.Annotation `path:"state/@length" ygotAnnotation:"true"`
	Type      *uint16           `path:"state/type" module:"openconfig-network-instance"`
	ΛType     []ygot.Annotation `path:"state/@type" ygotAnnotation:"true"`
	Value     Binary            `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv) IsYANGGoStruct() {}

// GetLength retrieves the value of the leaf Length from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Length is set, it can safely use t.GetLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Length == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv) GetLength() uint16 {
	if t == nil || t.Length == nil {
		return 0
	}
	return *t.Length
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv) GetType() uint16 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_OpaqueLsa_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa struct {
	ΛMetadata         []ygot.Annotation                                                                        `path:"@" ygotAnnotation:"true"`
	LinkData          NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union           `path:"state/link-data" module:"openconfig-network-instance"`
	ΛLinkData         []ygot.Annotation                                                                        `path:"state/@link-data" ygotAnnotation:"true"`
	LinkId            *string                                                                                  `path:"state/link-id" module:"openconfig-network-instance"`
	ΛLinkId           []ygot.Annotation                                                                        `path:"state/@link-id" ygotAnnotation:"true"`
	Metric            *uint16                                                                                  `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric           []ygot.Annotation                                                                        `path:"state/@metric" ygotAnnotation:"true"`
	NumberLinks       *uint16                                                                                  `path:"state/number-links" module:"openconfig-network-instance"`
	ΛNumberLinks      []ygot.Annotation                                                                        `path:"state/@number-links" ygotAnnotation:"true"`
	NumberTosMetrics  *uint16                                                                                  `path:"state/number-tos-metrics" module:"openconfig-network-instance"`
	ΛNumberTosMetrics []ygot.Annotation                                                                        `path:"state/@number-tos-metrics" ygotAnnotation:"true"`
	Type              E_OpenconfigOspfTypes_ROUTER_LSA_TYPES                                                   `path:"state/type" module:"openconfig-network-instance"`
	ΛType             []ygot.Annotation                                                                        `path:"state/@type" ygotAnnotation:"true"`
	TypeOfService     map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService `path:"types-of-service/type-of-service" module:"openconfig-network-instance"`
	ΛTypeOfService    []ygot.Annotation                                                                        `path:"types-of-service/@type-of-service" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) IsYANGGoStruct() {}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) NewTypeOfService(Tos uint8) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// RenameTypeOfService renames an entry in the list TypeOfService within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) RenameTypeOfService(oldK, newK uint8) error {
	if _, ok := t.TypeOfService[newK]; ok {
		return fmt.Errorf("key %v already exists in TypeOfService", newK)
	}

	e, ok := t.TypeOfService[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TypeOfService", oldK)
	}
	e.Tos = &newK

	t.TypeOfService[newK] = e
	delete(t.TypeOfService, oldK)
	return nil
}

// GetOrCreateTypeOfService retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetOrCreateTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService {

	key := Tos

	if v, ok := t.TypeOfService[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTypeOfService(Tos)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTypeOfService got unexpected error: %v", err))
	}
	return v
}

// GetTypeOfService retrieves the value with the specified key from
// the TypeOfService map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService {

	if t == nil {
		return nil
	}

	key := Tos

	if lm, ok := t.TypeOfService[key]; ok {
		return lm
	}
	return nil
}

// AppendTypeOfService appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService struct to the
// list TypeOfService of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) AppendTypeOfService(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) error {
	if v.Tos == nil {
		return fmt.Errorf("invalid nil key received for Tos")
	}

	key := *v.Tos

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService)
	}

	if _, ok := t.TypeOfService[key]; ok {
		return fmt.Errorf("duplicate key for list TypeOfService %v", key)
	}

	t.TypeOfService[key] = v
	return nil
}

// GetLinkData retrieves the value of the leaf LinkData from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkData is set, it can safely use t.GetLinkData()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkData == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetLinkData() NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union {
	if t == nil || t.LinkData == nil {
		return nil
	}
	return t.LinkData
}

// GetLinkId retrieves the value of the leaf LinkId from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkId is set, it can safely use t.GetLinkId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetLinkId() string {
	if t == nil || t.LinkId == nil {
		return ""
	}
	return *t.LinkId
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetNumberLinks retrieves the value of the leaf NumberLinks from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NumberLinks is set, it can safely use t.GetNumberLinks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NumberLinks == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetNumberLinks() uint16 {
	if t == nil || t.NumberLinks == nil {
		return 0
	}
	return *t.NumberLinks
}

// GetNumberTosMetrics retrieves the value of the leaf NumberTosMetrics from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NumberTosMetrics is set, it can safely use t.GetNumberTosMetrics()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NumberTosMetrics == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetNumberTosMetrics() uint16 {
	if t == nil || t.NumberTosMetrics == nil {
		return 0
	}
	return *t.NumberTosMetrics
}

// GetType retrieves the value of the leaf Type from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) GetType() E_OpenconfigOspfTypes_ROUTER_LSA_TYPES {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state/link-data within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union()
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union() {
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa) To_NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_LinkData_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/types-of-service/type-of-service YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint16           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
	Tos       *uint8            `path:"state/tos|tos" module:"openconfig-network-instance"`
	ΛTos      []ygot.Annotation `path:"state/@tos|@tos" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetTos retrieves the value of the leaf Tos from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tos is set, it can safely use t.GetTos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tos == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) GetTos() uint8 {
	if t == nil || t.Tos == nil {
		return 0
	}
	return *t.Tos
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_RouterLsa_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa struct {
	ΛMetadata      []ygot.Annotation                                                                         `path:"@" ygotAnnotation:"true"`
	NetworkMask    *uint8                                                                                    `path:"state/network-mask" module:"openconfig-network-instance"`
	ΛNetworkMask   []ygot.Annotation                                                                         `path:"state/@network-mask" ygotAnnotation:"true"`
	TypeOfService  map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService `path:"types-of-service/type-of-service" module:"openconfig-network-instance"`
	ΛTypeOfService []ygot.Annotation                                                                         `path:"types-of-service/@type-of-service" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) IsYANGGoStruct() {}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) NewTypeOfService(Tos uint8) (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// RenameTypeOfService renames an entry in the list TypeOfService within
// the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) RenameTypeOfService(oldK, newK uint8) error {
	if _, ok := t.TypeOfService[newK]; ok {
		return fmt.Errorf("key %v already exists in TypeOfService", newK)
	}

	e, ok := t.TypeOfService[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TypeOfService", oldK)
	}
	e.Tos = &newK

	t.TypeOfService[newK] = e
	delete(t.TypeOfService, oldK)
	return nil
}

// GetOrCreateTypeOfService retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) GetOrCreateTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService {

	key := Tos

	if v, ok := t.TypeOfService[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTypeOfService(Tos)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTypeOfService got unexpected error: %v", err))
	}
	return v
}

// GetTypeOfService retrieves the value with the specified key from
// the TypeOfService map field of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) GetTypeOfService(Tos uint8) *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService {

	if t == nil {
		return nil
	}

	key := Tos

	if lm, ok := t.TypeOfService[key]; ok {
		return lm
	}
	return nil
}

// AppendTypeOfService appends the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService struct to the
// list TypeOfService of NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) AppendTypeOfService(v *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) error {
	if v.Tos == nil {
		return fmt.Errorf("invalid nil key received for Tos")
	}

	key := *v.Tos

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService)
	}

	if _, ok := t.TypeOfService[key]; ok {
		return fmt.Errorf("duplicate key for list TypeOfService %v", key)
	}

	t.TypeOfService[key] = v
	return nil
}

// GetNetworkMask retrieves the value of the leaf NetworkMask from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NetworkMask is set, it can safely use t.GetNetworkMask()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NetworkMask == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) GetNetworkMask() uint8 {
	if t == nil || t.NetworkMask == nil {
		return 0
	}
	return *t.NetworkMask
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa/types-of-service/type-of-service YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Metric    *uint16           `path:"state/metric" module:"openconfig-network-instance"`
	ΛMetric   []ygot.Annotation `path:"state/@metric" ygotAnnotation:"true"`
	Tos       *uint8            `path:"state/tos|tos" module:"openconfig-network-instance"`
	ΛTos      []ygot.Annotation `path:"state/@tos|@tos" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) IsYANGGoStruct() {
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) GetMetric() uint16 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetTos retrieves the value of the leaf Tos from the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tos is set, it can safely use t.GetTos()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tos == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) GetTos() uint8 {
	if t == nil || t.Tos == nil {
		return 0
	}
	return *t.Tos
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Lsdb_LsaType_Lsa_SummaryLsa_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/mpls YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_Mpls struct {
	ΛMetadata                  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	TrafficEngineeringEnabled  *bool             `path:"state/traffic-engineering-enabled" shadow-path:"config/traffic-engineering-enabled" module:"openconfig-network-instance"`
	ΛTrafficEngineeringEnabled []ygot.Annotation `path:"state/@traffic-engineering-enabled" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_Mpls) IsYANGGoStruct() {}

// GetTrafficEngineeringEnabled retrieves the value of the leaf TrafficEngineeringEnabled from the NetworkInstance_Protocol_Ospfv2_Area_Mpls
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrafficEngineeringEnabled is set, it can safely use t.GetTrafficEngineeringEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrafficEngineeringEnabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Mpls) GetTrafficEngineeringEnabled() bool {
	if t == nil || t.TrafficEngineeringEnabled == nil {
		return false
	}
	return *t.TrafficEngineeringEnabled
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Area_VirtualLink represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links/virtual-link YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Area_VirtualLink struct {
	ΛMetadata                 []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	AdjacencyState            E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE `path:"state/adjacency-state" module:"openconfig-network-instance"`
	ΛAdjacencyState           []ygot.Annotation                         `path:"state/@adjacency-state" ygotAnnotation:"true"`
	BackupDesignatedRouter    *string                                   `path:"state/backup-designated-router" module:"openconfig-network-instance"`
	ΛBackupDesignatedRouter   []ygot.Annotation                         `path:"state/@backup-designated-router" ygotAnnotation:"true"`
	DeadTime                  *uint64                                   `path:"state/dead-time" module:"openconfig-network-instance"`
	ΛDeadTime                 []ygot.Annotation                         `path:"state/@dead-time" ygotAnnotation:"true"`
	DesignatedRouter          *string                                   `path:"state/designated-router" module:"openconfig-network-instance"`
	ΛDesignatedRouter         []ygot.Annotation                         `path:"state/@designated-router" ygotAnnotation:"true"`
	LastEstablishedTime       *uint64                                   `path:"state/last-established-time" module:"openconfig-network-instance"`
	ΛLastEstablishedTime      []ygot.Annotation                         `path:"state/@last-established-time" ygotAnnotation:"true"`
	OptionalCapabilities      *string                                   `path:"state/optional-capabilities" module:"openconfig-network-instance"`
	ΛOptionalCapabilities     []ygot.Annotation                         `path:"state/@optional-capabilities" ygotAnnotation:"true"`
	Priority                  *uint8                                    `path:"state/priority" module:"openconfig-network-instance"`
	ΛPriority                 []ygot.Annotation                         `path:"state/@priority" ygotAnnotation:"true"`
	RemoteRouterId            *string                                   `path:"state/remote-router-id|remote-router-id" shadow-path:"config/remote-router-id" module:"openconfig-network-instance"`
	ΛRemoteRouterId           []ygot.Annotation                         `path:"state/@remote-router-id|@remote-router-id" ygotAnnotation:"true"`
	RetranmissionQueueLength  *uint32                                   `path:"state/retranmission-queue-length" module:"openconfig-network-instance"`
	ΛRetranmissionQueueLength []ygot.Annotation                         `path:"state/@retranmission-queue-length" ygotAnnotation:"true"`
	StateChanges              *uint32                                   `path:"state/state-changes" module:"openconfig-network-instance"`
	ΛStateChanges             []ygot.Annotation                         `path:"state/@state-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Area_VirtualLink implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) IsYANGGoStruct() {}

// GetAdjacencyState retrieves the value of the leaf AdjacencyState from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdjacencyState is set, it can safely use t.GetAdjacencyState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdjacencyState == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetAdjacencyState() E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE {
	if t == nil || t.AdjacencyState == 0 {
		return 0
	}
	return t.AdjacencyState
}

// GetBackupDesignatedRouter retrieves the value of the leaf BackupDesignatedRouter from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BackupDesignatedRouter is set, it can safely use t.GetBackupDesignatedRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BackupDesignatedRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetBackupDesignatedRouter() string {
	if t == nil || t.BackupDesignatedRouter == nil {
		return ""
	}
	return *t.BackupDesignatedRouter
}

// GetDeadTime retrieves the value of the leaf DeadTime from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DeadTime is set, it can safely use t.GetDeadTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DeadTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetDeadTime() uint64 {
	if t == nil || t.DeadTime == nil {
		return 0
	}
	return *t.DeadTime
}

// GetDesignatedRouter retrieves the value of the leaf DesignatedRouter from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRouter is set, it can safely use t.GetDesignatedRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetDesignatedRouter() string {
	if t == nil || t.DesignatedRouter == nil {
		return ""
	}
	return *t.DesignatedRouter
}

// GetLastEstablishedTime retrieves the value of the leaf LastEstablishedTime from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastEstablishedTime is set, it can safely use t.GetLastEstablishedTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastEstablishedTime == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetLastEstablishedTime() uint64 {
	if t == nil || t.LastEstablishedTime == nil {
		return 0
	}
	return *t.LastEstablishedTime
}

// GetOptionalCapabilities retrieves the value of the leaf OptionalCapabilities from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OptionalCapabilities is set, it can safely use t.GetOptionalCapabilities()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OptionalCapabilities == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetOptionalCapabilities() string {
	if t == nil || t.OptionalCapabilities == nil {
		return ""
	}
	return *t.OptionalCapabilities
}

// GetPriority retrieves the value of the leaf Priority from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetRemoteRouterId retrieves the value of the leaf RemoteRouterId from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteRouterId is set, it can safely use t.GetRemoteRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteRouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetRemoteRouterId() string {
	if t == nil || t.RemoteRouterId == nil {
		return ""
	}
	return *t.RemoteRouterId
}

// GetRetranmissionQueueLength retrieves the value of the leaf RetranmissionQueueLength from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetranmissionQueueLength is set, it can safely use t.GetRetranmissionQueueLength()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetranmissionQueueLength == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetRetranmissionQueueLength() uint32 {
	if t == nil || t.RetranmissionQueueLength == nil {
		return 0
	}
	return *t.RetranmissionQueueLength
}

// GetStateChanges retrieves the value of the leaf StateChanges from the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StateChanges is set, it can safely use t.GetStateChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StateChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) GetStateChanges() uint32 {
	if t == nil || t.StateChanges == nil {
		return 0
	}
	return *t.StateChanges
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Area_VirtualLink struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RemoteRouterId == nil {
		return nil, fmt.Errorf("nil value for key RemoteRouterId")
	}

	return map[string]interface{}{
		"remote-router-id": *t.RemoteRouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Area_VirtualLink"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Area_VirtualLink) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global struct {
	ΛMetadata                   []ygot.Annotation                                                                                                                            `path:"@" ygotAnnotation:"true"`
	GracefulRestart             *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart                                                                                      `path:"graceful-restart" module:"openconfig-network-instance"`
	ΛGracefulRestart            []ygot.Annotation                                                                                                                            `path:"@graceful-restart" ygotAnnotation:"true"`
	HideTransitOnlyNetworks     *bool                                                                                                                                        `path:"state/hide-transit-only-networks" shadow-path:"config/hide-transit-only-networks" module:"openconfig-network-instance"`
	ΛHideTransitOnlyNetworks    []ygot.Annotation                                                                                                                            `path:"state/@hide-transit-only-networks" ygotAnnotation:"true"`
	IgpShortcuts                *bool                                                                                                                                        `path:"state/igp-shortcuts" shadow-path:"config/igp-shortcuts" module:"openconfig-network-instance"`
	ΛIgpShortcuts               []ygot.Annotation                                                                                                                            `path:"state/@igp-shortcuts" ygotAnnotation:"true"`
	InterAreaPropagationPolicy  map[NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key]*NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy `path:"inter-area-propagation-policies/inter-area-propagation-policy" module:"openconfig-network-instance"`
	ΛInterAreaPropagationPolicy []ygot.Annotation                                                                                                                            `path:"inter-area-propagation-policies/@inter-area-propagation-policy" ygotAnnotation:"true"`
	LogAdjacencyChanges         *bool                                                                                                                                        `path:"state/log-adjacency-changes" shadow-path:"config/log-adjacency-changes" module:"openconfig-network-instance"`
	ΛLogAdjacencyChanges        []ygot.Annotation                                                                                                                            `path:"state/@log-adjacency-changes" ygotAnnotation:"true"`
	Mpls                        *NetworkInstance_Protocol_Ospfv2_Global_Mpls                                                                                                 `path:"mpls" module:"openconfig-network-instance"`
	ΛMpls                       []ygot.Annotation                                                                                                                            `path:"@mpls" ygotAnnotation:"true"`
	RouterId                    *string                                                                                                                                      `path:"state/router-id" shadow-path:"config/router-id" module:"openconfig-network-instance"`
	ΛRouterId                   []ygot.Annotation                                                                                                                            `path:"state/@router-id" ygotAnnotation:"true"`
	SummaryRouteCostMode        E_Global_SummaryRouteCostMode                                                                                                                `path:"state/summary-route-cost-mode" shadow-path:"config/summary-route-cost-mode" module:"openconfig-network-instance"`
	ΛSummaryRouteCostMode       []ygot.Annotation                                                                                                                            `path:"state/@summary-route-cost-mode" ygotAnnotation:"true"`
	Timers                      *NetworkInstance_Protocol_Ospfv2_Global_Timers                                                                                               `path:"timers" module:"openconfig-network-instance"`
	ΛTimers                     []ygot.Annotation                                                                                                                            `path:"@timers" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global) IsYANGGoStruct() {}

// NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key represents the key for list InterAreaPropagationPolicy of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global.
type NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key struct {
	SrcArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union `path:"src-area"`
	DstArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union `path:"dst-area"`
}

// NewInterAreaPropagationPolicy creates a new entry in the InterAreaPropagationPolicy list of the
// NetworkInstance_Protocol_Ospfv2_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Ospfv2_Global) NewInterAreaPropagationPolicy(SrcArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, DstArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) (*NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InterAreaPropagationPolicy == nil {
		t.InterAreaPropagationPolicy = make(map[NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key]*NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy)
	}

	key := NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key{
		SrcArea: SrcArea,
		DstArea: DstArea,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.InterAreaPropagationPolicy[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list InterAreaPropagationPolicy", key)
	}

	t.InterAreaPropagationPolicy[key] = &NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy{
		SrcArea: SrcArea,
		DstArea: DstArea,
	}

	return t.InterAreaPropagationPolicy[key], nil
}

// RenameInterAreaPropagationPolicy renames an entry in the list InterAreaPropagationPolicy within
// the NetworkInstance_Protocol_Ospfv2_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Ospfv2_Global) RenameInterAreaPropagationPolicy(oldK, newK NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key) error {
	if _, ok := t.InterAreaPropagationPolicy[newK]; ok {
		return fmt.Errorf("key %v already exists in InterAreaPropagationPolicy", newK)
	}

	e, ok := t.InterAreaPropagationPolicy[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in InterAreaPropagationPolicy", oldK)
	}
	e.SrcArea = newK.SrcArea
	e.DstArea = newK.DstArea

	t.InterAreaPropagationPolicy[newK] = e
	delete(t.InterAreaPropagationPolicy, oldK)
	return nil
}

// GetOrCreateInterAreaPropagationPolicy retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Ospfv2_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetOrCreateInterAreaPropagationPolicy(SrcArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, DstArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy {

	key := NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key{
		SrcArea: SrcArea,
		DstArea: DstArea,
	}

	if v, ok := t.InterAreaPropagationPolicy[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterAreaPropagationPolicy(SrcArea, DstArea)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterAreaPropagationPolicy got unexpected error: %v", err))
	}
	return v
}

// GetInterAreaPropagationPolicy retrieves the value with the specified key from
// the InterAreaPropagationPolicy map field of NetworkInstance_Protocol_Ospfv2_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetInterAreaPropagationPolicy(SrcArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, DstArea NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union) *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy {

	if t == nil {
		return nil
	}

	key := NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key{
		SrcArea: SrcArea,
		DstArea: DstArea,
	}

	if lm, ok := t.InterAreaPropagationPolicy[key]; ok {
		return lm
	}
	return nil
}

// AppendInterAreaPropagationPolicy appends the supplied NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy struct to the
// list InterAreaPropagationPolicy of NetworkInstance_Protocol_Ospfv2_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Ospfv2_Global) AppendInterAreaPropagationPolicy(v *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) error {
	key := NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key{
		SrcArea: v.SrcArea,
		DstArea: v.DstArea,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InterAreaPropagationPolicy == nil {
		t.InterAreaPropagationPolicy = make(map[NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy_Key]*NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy)
	}

	if _, ok := t.InterAreaPropagationPolicy[key]; ok {
		return fmt.Errorf("duplicate key for list InterAreaPropagationPolicy %v", key)
	}

	t.InterAreaPropagationPolicy[key] = v
	return nil
}

// GetOrCreateGracefulRestart retrieves the value of the GracefulRestart field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetOrCreateGracefulRestart() *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart {
	if t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	t.GracefulRestart = &NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart{}
	return t.GracefulRestart
}

// GetOrCreateMpls retrieves the value of the Mpls field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetOrCreateMpls() *NetworkInstance_Protocol_Ospfv2_Global_Mpls {
	if t.Mpls != nil {
		return t.Mpls
	}
	t.Mpls = &NetworkInstance_Protocol_Ospfv2_Global_Mpls{}
	return t.Mpls
}

// GetOrCreateTimers retrieves the value of the Timers field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetOrCreateTimers() *NetworkInstance_Protocol_Ospfv2_Global_Timers {
	if t.Timers != nil {
		return t.Timers
	}
	t.Timers = &NetworkInstance_Protocol_Ospfv2_Global_Timers{}
	return t.Timers
}

// GetGracefulRestart returns the value of the GracefulRestart struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global. If the receiver or the field GracefulRestart is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetGracefulRestart() *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart {
	if t != nil && t.GracefulRestart != nil {
		return t.GracefulRestart
	}
	return nil
}

// GetMpls returns the value of the Mpls struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global. If the receiver or the field Mpls is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetMpls() *NetworkInstance_Protocol_Ospfv2_Global_Mpls {
	if t != nil && t.Mpls != nil {
		return t.Mpls
	}
	return nil
}

// GetTimers returns the value of the Timers struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global. If the receiver or the field Timers is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetTimers() *NetworkInstance_Protocol_Ospfv2_Global_Timers {
	if t != nil && t.Timers != nil {
		return t.Timers
	}
	return nil
}

// GetHideTransitOnlyNetworks retrieves the value of the leaf HideTransitOnlyNetworks from the NetworkInstance_Protocol_Ospfv2_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HideTransitOnlyNetworks is set, it can safely use t.GetHideTransitOnlyNetworks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HideTransitOnlyNetworks == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetHideTransitOnlyNetworks() bool {
	if t == nil || t.HideTransitOnlyNetworks == nil {
		return false
	}
	return *t.HideTransitOnlyNetworks
}

// GetIgpShortcuts retrieves the value of the leaf IgpShortcuts from the NetworkInstance_Protocol_Ospfv2_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IgpShortcuts is set, it can safely use t.GetIgpShortcuts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IgpShortcuts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetIgpShortcuts() bool {
	if t == nil || t.IgpShortcuts == nil {
		return false
	}
	return *t.IgpShortcuts
}

// GetLogAdjacencyChanges retrieves the value of the leaf LogAdjacencyChanges from the NetworkInstance_Protocol_Ospfv2_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogAdjacencyChanges is set, it can safely use t.GetLogAdjacencyChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogAdjacencyChanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetLogAdjacencyChanges() bool {
	if t == nil || t.LogAdjacencyChanges == nil {
		return false
	}
	return *t.LogAdjacencyChanges
}

// GetRouterId retrieves the value of the leaf RouterId from the NetworkInstance_Protocol_Ospfv2_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RouterId is set, it can safely use t.GetRouterId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RouterId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetRouterId() string {
	if t == nil || t.RouterId == nil {
		return ""
	}
	return *t.RouterId
}

// GetSummaryRouteCostMode retrieves the value of the leaf SummaryRouteCostMode from the NetworkInstance_Protocol_Ospfv2_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SummaryRouteCostMode is set, it can safely use t.GetSummaryRouteCostMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SummaryRouteCostMode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global) GetSummaryRouteCostMode() E_Global_SummaryRouteCostMode {
	if t == nil || t.SummaryRouteCostMode == 0 {
		return Global_SummaryRouteCostMode_RFC2328_COMPATIBLE
	}
	return t.SummaryRouteCostMode
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/graceful-restart YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled     *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled    []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	HelperOnly  *bool             `path:"state/helper-only" shadow-path:"config/helper-only" module:"openconfig-network-instance"`
	ΛHelperOnly []ygot.Annotation `path:"state/@helper-only" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelperOnly retrieves the value of the leaf HelperOnly from the NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperOnly is set, it can safely use t.GetHelperOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperOnly == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart) GetHelperOnly() bool {
	if t == nil || t.HelperOnly == nil {
		return false
	}
	return *t.HelperOnly
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy struct {
	ΛMetadata            []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	DefaultImportPolicy  E_OpenconfigRoutingPolicy_DefaultPolicyType           `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy []ygot.Annotation                                     `path:"state/@default-import-policy" ygotAnnotation:"true"`
	DstArea              NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union `path:"state/dst-area|dst-area" shadow-path:"config/dst-area" module:"openconfig-network-instance"`
	ΛDstArea             []ygot.Annotation                                     `path:"state/@dst-area|@dst-area" ygotAnnotation:"true"`
	ImportPolicy         []string                                              `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy        []ygot.Annotation                                     `path:"state/@import-policy" ygotAnnotation:"true"`
	SrcArea              NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union `path:"state/src-area|src-area" shadow-path:"config/src-area" module:"openconfig-network-instance"`
	ΛSrcArea             []ygot.Annotation                                     `path:"state/@src-area|@src-area" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) IsYANGGoStruct() {}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetDstArea retrieves the value of the leaf DstArea from the NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DstArea is set, it can safely use t.GetDstArea()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DstArea == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) GetDstArea() NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union {
	if t == nil || t.DstArea == nil {
		return nil
	}
	return t.DstArea
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// GetSrcArea retrieves the value of the leaf SrcArea from the NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SrcArea is set, it can safely use t.GetSrcArea()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SrcArea == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) GetSrcArea() NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union {
	if t == nil || t.SrcArea == nil {
		return nil
	}
	return t.SrcArea
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"dst-area": t.DstArea,
		"src-area": t.SrcArea,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Ospfv2_Global_InterAreaPropagationPolicy) To_NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union(i interface{}) (NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Ospfv2_Area_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Ospfv2_Global_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_Mpls struct {
	ΛMetadata                     []ygot.Annotation                                       `path:"@" ygotAnnotation:"true"`
	IgpLdpSync                    *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
	ΛIgpLdpSync                   []ygot.Annotation                                       `path:"@igp-ldp-sync" ygotAnnotation:"true"`
	TrafficEngineeringExtensions  *bool                                                   `path:"state/traffic-engineering-extensions" shadow-path:"config/traffic-engineering-extensions" module:"openconfig-network-instance"`
	ΛTrafficEngineeringExtensions []ygot.Annotation                                       `path:"state/@traffic-engineering-extensions" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_Mpls) IsYANGGoStruct() {}

// GetOrCreateIgpLdpSync retrieves the value of the IgpLdpSync field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls) GetOrCreateIgpLdpSync() *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync {
	if t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	t.IgpLdpSync = &NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync{}
	return t.IgpLdpSync
}

// GetIgpLdpSync returns the value of the IgpLdpSync struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global_Mpls. If the receiver or the field IgpLdpSync is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls) GetIgpLdpSync() *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync {
	if t != nil && t.IgpLdpSync != nil {
		return t.IgpLdpSync
	}
	return nil
}

// GetTrafficEngineeringExtensions retrieves the value of the leaf TrafficEngineeringExtensions from the NetworkInstance_Protocol_Ospfv2_Global_Mpls
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TrafficEngineeringExtensions is set, it can safely use t.GetTrafficEngineeringExtensions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TrafficEngineeringExtensions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls) GetTrafficEngineeringExtensions() bool {
	if t == nil || t.TrafficEngineeringExtensions == nil {
		return false
	}
	return *t.TrafficEngineeringExtensions
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls/igp-ldp-sync YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync struct {
	ΛMetadata           []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enabled             *bool             `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled            []ygot.Annotation `path:"state/@enabled" ygotAnnotation:"true"`
	PostSessionUpDelay  *uint32           `path:"state/post-session-up-delay" shadow-path:"config/post-session-up-delay" module:"openconfig-network-instance"`
	ΛPostSessionUpDelay []ygot.Annotation `path:"state/@post-session-up-delay" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetPostSessionUpDelay retrieves the value of the leaf PostSessionUpDelay from the NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PostSessionUpDelay is set, it can safely use t.GetPostSessionUpDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PostSessionUpDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) GetPostSessionUpDelay() uint32 {
	if t == nil || t.PostSessionUpDelay == nil {
		return 0
	}
	return *t.PostSessionUpDelay
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_Timers struct {
	ΛMetadata      []ygot.Annotation                                            `path:"@" ygotAnnotation:"true"`
	LsaGeneration  *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration `path:"lsa-generation" module:"openconfig-network-instance"`
	ΛLsaGeneration []ygot.Annotation                                            `path:"@lsa-generation" ygotAnnotation:"true"`
	MaxMetric      *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric     `path:"max-metric" module:"openconfig-network-instance"`
	ΛMaxMetric     []ygot.Annotation                                            `path:"@max-metric" ygotAnnotation:"true"`
	Spf            *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf           `path:"spf" module:"openconfig-network-instance"`
	ΛSpf           []ygot.Annotation                                            `path:"@spf" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_Timers) IsYANGGoStruct() {}

// GetOrCreateLsaGeneration retrieves the value of the LsaGeneration field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) GetOrCreateLsaGeneration() *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration {
	if t.LsaGeneration != nil {
		return t.LsaGeneration
	}
	t.LsaGeneration = &NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration{}
	return t.LsaGeneration
}

// GetOrCreateMaxMetric retrieves the value of the MaxMetric field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) GetOrCreateMaxMetric() *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric {
	if t.MaxMetric != nil {
		return t.MaxMetric
	}
	t.MaxMetric = &NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric{}
	return t.MaxMetric
}

// GetOrCreateSpf retrieves the value of the Spf field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) GetOrCreateSpf() *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf {
	if t.Spf != nil {
		return t.Spf
	}
	t.Spf = &NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf{}
	return t.Spf
}

// GetLsaGeneration returns the value of the LsaGeneration struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global_Timers. If the receiver or the field LsaGeneration is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) GetLsaGeneration() *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration {
	if t != nil && t.LsaGeneration != nil {
		return t.LsaGeneration
	}
	return nil
}

// GetMaxMetric returns the value of the MaxMetric struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global_Timers. If the receiver or the field MaxMetric is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) GetMaxMetric() *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric {
	if t != nil && t.MaxMetric != nil {
		return t.MaxMetric
	}
	return nil
}

// GetSpf returns the value of the Spf struct pointer
// from NetworkInstance_Protocol_Ospfv2_Global_Timers. If the receiver or the field Spf is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) GetSpf() *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf {
	if t != nil && t.Spf != nil {
		return t.Spf
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/lsa-generation YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration struct {
	ΛMetadata     []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	InitialDelay  *uint32                   `path:"state/initial-delay" shadow-path:"config/initial-delay" module:"openconfig-network-instance"`
	ΛInitialDelay []ygot.Annotation         `path:"state/@initial-delay" ygotAnnotation:"true"`
	MaximumDelay  *uint32                   `path:"state/maximum-delay" shadow-path:"config/maximum-delay" module:"openconfig-network-instance"`
	ΛMaximumDelay []ygot.Annotation         `path:"state/@maximum-delay" ygotAnnotation:"true"`
	TimerType     E_LsaGeneration_TimerType `path:"state/timer-type" module:"openconfig-network-instance"`
	ΛTimerType    []ygot.Annotation         `path:"state/@timer-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration) IsYANGGoStruct() {}

// GetInitialDelay retrieves the value of the leaf InitialDelay from the NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InitialDelay is set, it can safely use t.GetInitialDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InitialDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration) GetInitialDelay() uint32 {
	if t == nil || t.InitialDelay == nil {
		return 0
	}
	return *t.InitialDelay
}

// GetMaximumDelay retrieves the value of the leaf MaximumDelay from the NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumDelay is set, it can safely use t.GetMaximumDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration) GetMaximumDelay() uint32 {
	if t == nil || t.MaximumDelay == nil {
		return 0
	}
	return *t.MaximumDelay
}

// GetTimerType retrieves the value of the leaf TimerType from the NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TimerType is set, it can safely use t.GetTimerType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TimerType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration) GetTimerType() E_LsaGeneration_TimerType {
	if t == nil || t.TimerType == 0 {
		return 0
	}
	return t.TimerType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_LsaGeneration) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric struct {
	ΛMetadata []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	Include   []E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE `path:"state/include" shadow-path:"config/include" module:"openconfig-network-instance"`
	ΛInclude  []ygot.Annotation                          `path:"state/@include" ygotAnnotation:"true"`
	Set       *bool                                      `path:"state/set" shadow-path:"config/set" module:"openconfig-network-instance"`
	ΛSet      []ygot.Annotation                          `path:"state/@set" ygotAnnotation:"true"`
	Timeout   *uint64                                    `path:"state/timeout" shadow-path:"config/timeout" module:"openconfig-network-instance"`
	ΛTimeout  []ygot.Annotation                          `path:"state/@timeout" ygotAnnotation:"true"`
	Trigger   []E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER `path:"state/trigger" shadow-path:"config/trigger" module:"openconfig-network-instance"`
	ΛTrigger  []ygot.Annotation                          `path:"state/@trigger" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) IsYANGGoStruct() {}

// GetInclude retrieves the value of the leaf Include from the NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Include is set, it can safely use t.GetInclude()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Include == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) GetInclude() []E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE {
	if t == nil || t.Include == nil {
		return nil
	}
	return t.Include
}

// GetSet retrieves the value of the leaf Set from the NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Set is set, it can safely use t.GetSet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Set == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) GetSet() bool {
	if t == nil || t.Set == nil {
		return false
	}
	return *t.Set
}

// GetTimeout retrieves the value of the leaf Timeout from the NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Timeout is set, it can safely use t.GetTimeout()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Timeout == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) GetTimeout() uint64 {
	if t == nil || t.Timeout == nil {
		return 0
	}
	return *t.Timeout
}

// GetTrigger retrieves the value of the leaf Trigger from the NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Trigger is set, it can safely use t.GetTrigger()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Trigger == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) GetTrigger() []E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER {
	if t == nil || t.Trigger == nil {
		return nil
	}
	return t.Trigger
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_MaxMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/spf YANG schema element.
type NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf struct {
	ΛMetadata     []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	InitialDelay  *uint32                   `path:"state/initial-delay" shadow-path:"config/initial-delay" module:"openconfig-network-instance"`
	ΛInitialDelay []ygot.Annotation         `path:"state/@initial-delay" ygotAnnotation:"true"`
	MaximumDelay  *uint32                   `path:"state/maximum-delay" shadow-path:"config/maximum-delay" module:"openconfig-network-instance"`
	ΛMaximumDelay []ygot.Annotation         `path:"state/@maximum-delay" ygotAnnotation:"true"`
	TimerType     E_LsaGeneration_TimerType `path:"state/timer-type" module:"openconfig-network-instance"`
	ΛTimerType    []ygot.Annotation         `path:"state/@timer-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf) IsYANGGoStruct() {}

// GetInitialDelay retrieves the value of the leaf InitialDelay from the NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InitialDelay is set, it can safely use t.GetInitialDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InitialDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf) GetInitialDelay() uint32 {
	if t == nil || t.InitialDelay == nil {
		return 0
	}
	return *t.InitialDelay
}

// GetMaximumDelay retrieves the value of the leaf MaximumDelay from the NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaximumDelay is set, it can safely use t.GetMaximumDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaximumDelay == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf) GetMaximumDelay() uint32 {
	if t == nil || t.MaximumDelay == nil {
		return 0
	}
	return *t.MaximumDelay
}

// GetTimerType retrieves the value of the leaf TimerType from the NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TimerType is set, it can safely use t.GetTimerType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TimerType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf) GetTimerType() E_LsaGeneration_TimerType {
	if t == nil || t.TimerType == 0 {
		return 0
	}
	return t.TimerType
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Ospfv2_Global_Timers_Spf) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim YANG schema element.
type NetworkInstance_Protocol_Pim struct {
	ΛMetadata  []ygot.Annotation                                  `path:"@" ygotAnnotation:"true"`
	Global     *NetworkInstance_Protocol_Pim_Global               `path:"global" module:"openconfig-network-instance"`
	ΛGlobal    []ygot.Annotation                                  `path:"@global" ygotAnnotation:"true"`
	Interface  map[string]*NetworkInstance_Protocol_Pim_Interface `path:"interfaces/interface" module:"openconfig-network-instance"`
	ΛInterface []ygot.Annotation                                  `path:"interfaces/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// NetworkInstance_Protocol_Pim struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Pim) NewInterface(InterfaceId string) (*NetworkInstance_Protocol_Pim_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Pim_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &NetworkInstance_Protocol_Pim_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the NetworkInstance_Protocol_Pim struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Pim) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.InterfaceId = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Pim. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Pim) GetOrCreateInterface(InterfaceId string) *NetworkInstance_Protocol_Pim_Interface {

	key := InterfaceId

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(InterfaceId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of NetworkInstance_Protocol_Pim. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Pim) GetInterface(InterfaceId string) *NetworkInstance_Protocol_Pim_Interface {

	if t == nil {
		return nil
	}

	key := InterfaceId

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied NetworkInstance_Protocol_Pim_Interface struct to the
// list Interface of NetworkInstance_Protocol_Pim. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Pim_Interface already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Pim) AppendInterface(v *NetworkInstance_Protocol_Pim_Interface) error {
	if v.InterfaceId == nil {
		return fmt.Errorf("invalid nil key received for InterfaceId")
	}

	key := *v.InterfaceId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*NetworkInstance_Protocol_Pim_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Pim) GetOrCreateGlobal() *NetworkInstance_Protocol_Pim_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &NetworkInstance_Protocol_Pim_Global{}
	return t.Global
}

// GetGlobal returns the value of the Global struct pointer
// from NetworkInstance_Protocol_Pim. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Pim) GetGlobal() *NetworkInstance_Protocol_Pim_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Protocol_Pim_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global YANG schema element.
type NetworkInstance_Protocol_Pim_Global struct {
	ΛMetadata        []ygot.Annotation                                               `path:"@" ygotAnnotation:"true"`
	Counters         *NetworkInstance_Protocol_Pim_Global_Counters                   `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters        []ygot.Annotation                                               `path:"state/@counters" ygotAnnotation:"true"`
	NeighborCount    *uint8                                                          `path:"state/neighbor-count" module:"openconfig-network-instance"`
	ΛNeighborCount   []ygot.Annotation                                               `path:"state/@neighbor-count" ygotAnnotation:"true"`
	RendezvousPoint  map[string]*NetworkInstance_Protocol_Pim_Global_RendezvousPoint `path:"rendezvous-points/rendezvous-point" module:"openconfig-network-instance"`
	ΛRendezvousPoint []ygot.Annotation                                               `path:"rendezvous-points/@rendezvous-point" ygotAnnotation:"true"`
	Source           map[string]*NetworkInstance_Protocol_Pim_Global_Source          `path:"sources-joined/source" module:"openconfig-network-instance"`
	ΛSource          []ygot.Annotation                                               `path:"sources-joined/@source" ygotAnnotation:"true"`
	Ssm              *NetworkInstance_Protocol_Pim_Global_Ssm                        `path:"ssm" module:"openconfig-network-instance"`
	ΛSsm             []ygot.Annotation                                               `path:"@ssm" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Global) IsYANGGoStruct() {}

// NewRendezvousPoint creates a new entry in the RendezvousPoint list of the
// NetworkInstance_Protocol_Pim_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Pim_Global) NewRendezvousPoint(Address string) (*NetworkInstance_Protocol_Pim_Global_RendezvousPoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RendezvousPoint == nil {
		t.RendezvousPoint = make(map[string]*NetworkInstance_Protocol_Pim_Global_RendezvousPoint)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RendezvousPoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RendezvousPoint", key)
	}

	t.RendezvousPoint[key] = &NetworkInstance_Protocol_Pim_Global_RendezvousPoint{
		Address: &Address,
	}

	return t.RendezvousPoint[key], nil
}

// RenameRendezvousPoint renames an entry in the list RendezvousPoint within
// the NetworkInstance_Protocol_Pim_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Pim_Global) RenameRendezvousPoint(oldK, newK string) error {
	if _, ok := t.RendezvousPoint[newK]; ok {
		return fmt.Errorf("key %v already exists in RendezvousPoint", newK)
	}

	e, ok := t.RendezvousPoint[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in RendezvousPoint", oldK)
	}
	e.Address = &newK

	t.RendezvousPoint[newK] = e
	delete(t.RendezvousPoint, oldK)
	return nil
}

// GetOrCreateRendezvousPoint retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Pim_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Pim_Global) GetOrCreateRendezvousPoint(Address string) *NetworkInstance_Protocol_Pim_Global_RendezvousPoint {

	key := Address

	if v, ok := t.RendezvousPoint[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRendezvousPoint(Address)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRendezvousPoint got unexpected error: %v", err))
	}
	return v
}

// GetRendezvousPoint retrieves the value with the specified key from
// the RendezvousPoint map field of NetworkInstance_Protocol_Pim_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Pim_Global) GetRendezvousPoint(Address string) *NetworkInstance_Protocol_Pim_Global_RendezvousPoint {

	if t == nil {
		return nil
	}

	key := Address

	if lm, ok := t.RendezvousPoint[key]; ok {
		return lm
	}
	return nil
}

// AppendRendezvousPoint appends the supplied NetworkInstance_Protocol_Pim_Global_RendezvousPoint struct to the
// list RendezvousPoint of NetworkInstance_Protocol_Pim_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Pim_Global_RendezvousPoint already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Pim_Global) AppendRendezvousPoint(v *NetworkInstance_Protocol_Pim_Global_RendezvousPoint) error {
	if v.Address == nil {
		return fmt.Errorf("invalid nil key received for Address")
	}

	key := *v.Address

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RendezvousPoint == nil {
		t.RendezvousPoint = make(map[string]*NetworkInstance_Protocol_Pim_Global_RendezvousPoint)
	}

	if _, ok := t.RendezvousPoint[key]; ok {
		return fmt.Errorf("duplicate key for list RendezvousPoint %v", key)
	}

	t.RendezvousPoint[key] = v
	return nil
}

// NewSource creates a new entry in the Source list of the
// NetworkInstance_Protocol_Pim_Global struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Pim_Global) NewSource(Address string) (*NetworkInstance_Protocol_Pim_Global_Source, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Source == nil {
		t.Source = make(map[string]*NetworkInstance_Protocol_Pim_Global_Source)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Source[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Source", key)
	}

	t.Source[key] = &NetworkInstance_Protocol_Pim_Global_Source{
		Address: &Address,
	}

	return t.Source[key], nil
}

// RenameSource renames an entry in the list Source within
// the NetworkInstance_Protocol_Pim_Global struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Pim_Global) RenameSource(oldK, newK string) error {
	if _, ok := t.Source[newK]; ok {
		return fmt.Errorf("key %v already exists in Source", newK)
	}

	e, ok := t.Source[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Source", oldK)
	}
	e.Address = &newK

	t.Source[newK] = e
	delete(t.Source, oldK)
	return nil
}

// GetOrCreateSource retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Pim_Global. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Pim_Global) GetOrCreateSource(Address string) *NetworkInstance_Protocol_Pim_Global_Source {

	key := Address

	if v, ok := t.Source[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSource(Address)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSource got unexpected error: %v", err))
	}
	return v
}

// GetSource retrieves the value with the specified key from
// the Source map field of NetworkInstance_Protocol_Pim_Global. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Pim_Global) GetSource(Address string) *NetworkInstance_Protocol_Pim_Global_Source {

	if t == nil {
		return nil
	}

	key := Address

	if lm, ok := t.Source[key]; ok {
		return lm
	}
	return nil
}

// AppendSource appends the supplied NetworkInstance_Protocol_Pim_Global_Source struct to the
// list Source of NetworkInstance_Protocol_Pim_Global. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Pim_Global_Source already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Pim_Global) AppendSource(v *NetworkInstance_Protocol_Pim_Global_Source) error {
	if v.Address == nil {
		return fmt.Errorf("invalid nil key received for Address")
	}

	key := *v.Address

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Source == nil {
		t.Source = make(map[string]*NetworkInstance_Protocol_Pim_Global_Source)
	}

	if _, ok := t.Source[key]; ok {
		return fmt.Errorf("duplicate key for list Source %v", key)
	}

	t.Source[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Pim_Global) GetOrCreateCounters() *NetworkInstance_Protocol_Pim_Global_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Protocol_Pim_Global_Counters{}
	return t.Counters
}

// GetOrCreateSsm retrieves the value of the Ssm field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Pim_Global) GetOrCreateSsm() *NetworkInstance_Protocol_Pim_Global_Ssm {
	if t.Ssm != nil {
		return t.Ssm
	}
	t.Ssm = &NetworkInstance_Protocol_Pim_Global_Ssm{}
	return t.Ssm
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Protocol_Pim_Global. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Pim_Global) GetCounters() *NetworkInstance_Protocol_Pim_Global_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetSsm returns the value of the Ssm struct pointer
// from NetworkInstance_Protocol_Pim_Global. If the receiver or the field Ssm is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Pim_Global) GetSsm() *NetworkInstance_Protocol_Pim_Global_Ssm {
	if t != nil && t.Ssm != nil {
		return t.Ssm
	}
	return nil
}

// GetNeighborCount retrieves the value of the leaf NeighborCount from the NetworkInstance_Protocol_Pim_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborCount is set, it can safely use t.GetNeighborCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborCount == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global) GetNeighborCount() uint8 {
	if t == nil || t.NeighborCount == nil {
		return 0
	}
	return *t.NeighborCount
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Global_Counters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/state/counters YANG schema element.
type NetworkInstance_Protocol_Pim_Global_Counters struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BootstrapMessages  *uint32           `path:"bootstrap-messages" module:"openconfig-network-instance"`
	ΛBootstrapMessages []ygot.Annotation `path:"@bootstrap-messages" ygotAnnotation:"true"`
	HelloMessages      *uint32           `path:"hello-messages" module:"openconfig-network-instance"`
	ΛHelloMessages     []ygot.Annotation `path:"@hello-messages" ygotAnnotation:"true"`
	JoinPruneMessages  *uint32           `path:"join-prune-messages" module:"openconfig-network-instance"`
	ΛJoinPruneMessages []ygot.Annotation `path:"@join-prune-messages" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Global_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Global_Counters) IsYANGGoStruct() {}

// GetBootstrapMessages retrieves the value of the leaf BootstrapMessages from the NetworkInstance_Protocol_Pim_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BootstrapMessages is set, it can safely use t.GetBootstrapMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BootstrapMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Counters) GetBootstrapMessages() uint32 {
	if t == nil || t.BootstrapMessages == nil {
		return 0
	}
	return *t.BootstrapMessages
}

// GetHelloMessages retrieves the value of the leaf HelloMessages from the NetworkInstance_Protocol_Pim_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloMessages is set, it can safely use t.GetHelloMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Counters) GetHelloMessages() uint32 {
	if t == nil || t.HelloMessages == nil {
		return 0
	}
	return *t.HelloMessages
}

// GetJoinPruneMessages retrieves the value of the leaf JoinPruneMessages from the NetworkInstance_Protocol_Pim_Global_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if JoinPruneMessages is set, it can safely use t.GetJoinPruneMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.JoinPruneMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Counters) GetJoinPruneMessages() uint32 {
	if t == nil || t.JoinPruneMessages == nil {
		return 0
	}
	return *t.JoinPruneMessages
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Global_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Global_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Global_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Global_RendezvousPoint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/rendezvous-points/rendezvous-point YANG schema element.
type NetworkInstance_Protocol_Pim_Global_RendezvousPoint struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address          *string           `path:"state/address|address" shadow-path:"config/address" module:"openconfig-network-instance"`
	ΛAddress         []ygot.Annotation `path:"state/@address|@address" ygotAnnotation:"true"`
	MulticastGroups  *string           `path:"state/multicast-groups" shadow-path:"config/multicast-groups" module:"openconfig-network-instance"`
	ΛMulticastGroups []ygot.Annotation `path:"state/@multicast-groups" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Global_RendezvousPoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Global_RendezvousPoint) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Pim_Global_RendezvousPoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_RendezvousPoint) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetMulticastGroups retrieves the value of the leaf MulticastGroups from the NetworkInstance_Protocol_Pim_Global_RendezvousPoint
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MulticastGroups is set, it can safely use t.GetMulticastGroups()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MulticastGroups == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_RendezvousPoint) GetMulticastGroups() string {
	if t == nil || t.MulticastGroups == nil {
		return ""
	}
	return *t.MulticastGroups
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Pim_Global_RendezvousPoint struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Pim_Global_RendezvousPoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Global_RendezvousPoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Global_RendezvousPoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Global_RendezvousPoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Global_Source represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/sources-joined/source YANG schema element.
type NetworkInstance_Protocol_Pim_Global_Source struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address              *string           `path:"state/address|address" module:"openconfig-network-instance"`
	ΛAddress             []ygot.Annotation `path:"state/@address|@address" ygotAnnotation:"true"`
	Group                *string           `path:"state/group" module:"openconfig-network-instance"`
	ΛGroup               []ygot.Annotation `path:"state/@group" ygotAnnotation:"true"`
	UpstreamInterfaceId  *string           `path:"state/upstream-interface-id" module:"openconfig-network-instance"`
	ΛUpstreamInterfaceId []ygot.Annotation `path:"state/@upstream-interface-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Global_Source implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Global_Source) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the NetworkInstance_Protocol_Pim_Global_Source
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Source) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetGroup retrieves the value of the leaf Group from the NetworkInstance_Protocol_Pim_Global_Source
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Group is set, it can safely use t.GetGroup()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Group == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Source) GetGroup() string {
	if t == nil || t.Group == nil {
		return ""
	}
	return *t.Group
}

// GetUpstreamInterfaceId retrieves the value of the leaf UpstreamInterfaceId from the NetworkInstance_Protocol_Pim_Global_Source
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UpstreamInterfaceId is set, it can safely use t.GetUpstreamInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UpstreamInterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Source) GetUpstreamInterfaceId() string {
	if t == nil || t.UpstreamInterfaceId == nil {
		return ""
	}
	return *t.UpstreamInterfaceId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Pim_Global_Source struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Pim_Global_Source) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Global_Source) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Global_Source"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Global_Source) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Global_Ssm represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/ssm YANG schema element.
type NetworkInstance_Protocol_Pim_Global_Ssm struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	SsmRanges  *string           `path:"state/ssm-ranges" shadow-path:"config/ssm-ranges" module:"openconfig-network-instance"`
	ΛSsmRanges []ygot.Annotation `path:"state/@ssm-ranges" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Global_Ssm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Global_Ssm) IsYANGGoStruct() {}

// GetSsmRanges retrieves the value of the leaf SsmRanges from the NetworkInstance_Protocol_Pim_Global_Ssm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SsmRanges is set, it can safely use t.GetSsmRanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SsmRanges == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Global_Ssm) GetSsmRanges() string {
	if t == nil || t.SsmRanges == nil {
		return ""
	}
	return *t.SsmRanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Global_Ssm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Global_Ssm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Global_Ssm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface YANG schema element.
type NetworkInstance_Protocol_Pim_Interface struct {
	ΛMetadata          []ygot.Annotation                                           `path:"@" ygotAnnotation:"true"`
	BorderRouter       *bool                                                       `path:"state/border-router" shadow-path:"config/border-router" module:"openconfig-network-instance"`
	ΛBorderRouter      []ygot.Annotation                                           `path:"state/@border-router" ygotAnnotation:"true"`
	BsrBorder          *bool                                                       `path:"state/bsr-border" shadow-path:"config/bsr-border" module:"openconfig-network-instance"`
	ΛBsrBorder         []ygot.Annotation                                           `path:"state/@bsr-border" ygotAnnotation:"true"`
	Counters           *NetworkInstance_Protocol_Pim_Interface_Counters            `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters          []ygot.Annotation                                           `path:"state/@counters" ygotAnnotation:"true"`
	DeadTimer          *uint16                                                     `path:"state/dead-timer" shadow-path:"config/dead-timer" module:"openconfig-network-instance"`
	ΛDeadTimer         []ygot.Annotation                                           `path:"state/@dead-timer" ygotAnnotation:"true"`
	DrPriority         *uint32                                                     `path:"state/dr-priority" shadow-path:"config/dr-priority" module:"openconfig-network-instance"`
	ΛDrPriority        []ygot.Annotation                                           `path:"state/@dr-priority" ygotAnnotation:"true"`
	Enabled            *bool                                                       `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-network-instance"`
	ΛEnabled           []ygot.Annotation                                           `path:"state/@enabled" ygotAnnotation:"true"`
	HelloInterval      *uint8                                                      `path:"state/hello-interval" shadow-path:"config/hello-interval" module:"openconfig-network-instance"`
	ΛHelloInterval     []ygot.Annotation                                           `path:"state/@hello-interval" ygotAnnotation:"true"`
	InterfaceId        *string                                                     `path:"state/interface-id|interface-id" shadow-path:"config/interface-id" module:"openconfig-network-instance"`
	ΛInterfaceId       []ygot.Annotation                                           `path:"state/@interface-id|@interface-id" ygotAnnotation:"true"`
	InterfaceRef       *NetworkInstance_Protocol_Pim_Interface_InterfaceRef        `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef      []ygot.Annotation                                           `path:"@interface-ref" ygotAnnotation:"true"`
	JoinPruneInterval  *uint8                                                      `path:"state/join-prune-interval" shadow-path:"config/join-prune-interval" module:"openconfig-network-instance"`
	ΛJoinPruneInterval []ygot.Annotation                                           `path:"state/@join-prune-interval" ygotAnnotation:"true"`
	Mode               E_OpenconfigPimTypes_PIM_MODE                               `path:"state/mode" shadow-path:"config/mode" module:"openconfig-network-instance"`
	ΛMode              []ygot.Annotation                                           `path:"state/@mode" ygotAnnotation:"true"`
	Neighbor           map[string]*NetworkInstance_Protocol_Pim_Interface_Neighbor `path:"neighbors/neighbor" module:"openconfig-network-instance"`
	ΛNeighbor          []ygot.Annotation                                           `path:"neighbors/@neighbor" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Interface) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// NetworkInstance_Protocol_Pim_Interface struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Pim_Interface) NewNeighbor(NeighborAddress string) (*NetworkInstance_Protocol_Pim_Interface_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Pim_Interface_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &NetworkInstance_Protocol_Pim_Interface_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the NetworkInstance_Protocol_Pim_Interface struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Pim_Interface) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.NeighborAddress = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Pim_Interface. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Pim_Interface) GetOrCreateNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Pim_Interface_Neighbor {

	key := NeighborAddress

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(NeighborAddress)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of NetworkInstance_Protocol_Pim_Interface. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Pim_Interface) GetNeighbor(NeighborAddress string) *NetworkInstance_Protocol_Pim_Interface_Neighbor {

	if t == nil {
		return nil
	}

	key := NeighborAddress

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied NetworkInstance_Protocol_Pim_Interface_Neighbor struct to the
// list Neighbor of NetworkInstance_Protocol_Pim_Interface. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Pim_Interface_Neighbor already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Pim_Interface) AppendNeighbor(v *NetworkInstance_Protocol_Pim_Interface_Neighbor) error {
	if v.NeighborAddress == nil {
		return fmt.Errorf("invalid nil key received for NeighborAddress")
	}

	key := *v.NeighborAddress

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*NetworkInstance_Protocol_Pim_Interface_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Pim_Interface) GetOrCreateCounters() *NetworkInstance_Protocol_Pim_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_Protocol_Pim_Interface_Counters{}
	return t.Counters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Pim_Interface) GetOrCreateInterfaceRef() *NetworkInstance_Protocol_Pim_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Protocol_Pim_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_Protocol_Pim_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Pim_Interface) GetCounters() *NetworkInstance_Protocol_Pim_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Protocol_Pim_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Pim_Interface) GetInterfaceRef() *NetworkInstance_Protocol_Pim_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetBorderRouter retrieves the value of the leaf BorderRouter from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BorderRouter is set, it can safely use t.GetBorderRouter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BorderRouter == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetBorderRouter() bool {
	if t == nil || t.BorderRouter == nil {
		return false
	}
	return *t.BorderRouter
}

// GetBsrBorder retrieves the value of the leaf BsrBorder from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BsrBorder is set, it can safely use t.GetBsrBorder()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BsrBorder == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetBsrBorder() bool {
	if t == nil || t.BsrBorder == nil {
		return false
	}
	return *t.BsrBorder
}

// GetDeadTimer retrieves the value of the leaf DeadTimer from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DeadTimer is set, it can safely use t.GetDeadTimer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DeadTimer == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetDeadTimer() uint16 {
	if t == nil || t.DeadTimer == nil {
		return 0
	}
	return *t.DeadTimer
}

// GetDrPriority retrieves the value of the leaf DrPriority from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DrPriority is set, it can safely use t.GetDrPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DrPriority == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetDrPriority() uint32 {
	if t == nil || t.DrPriority == nil {
		return 0
	}
	return *t.DrPriority
}

// GetEnabled retrieves the value of the leaf Enabled from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetHelloInterval retrieves the value of the leaf HelloInterval from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloInterval is set, it can safely use t.GetHelloInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetHelloInterval() uint8 {
	if t == nil || t.HelloInterval == nil {
		return 0
	}
	return *t.HelloInterval
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetJoinPruneInterval retrieves the value of the leaf JoinPruneInterval from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if JoinPruneInterval is set, it can safely use t.GetJoinPruneInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.JoinPruneInterval == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetJoinPruneInterval() uint8 {
	if t == nil || t.JoinPruneInterval == nil {
		return 0
	}
	return *t.JoinPruneInterval
}

// GetMode retrieves the value of the leaf Mode from the NetworkInstance_Protocol_Pim_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface) GetMode() E_OpenconfigPimTypes_PIM_MODE {
	if t == nil || t.Mode == 0 {
		return 0
	}
	return t.Mode
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Pim_Interface struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Pim_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Interface_Counters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/state/counters YANG schema element.
type NetworkInstance_Protocol_Pim_Interface_Counters struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BootstrapMessages  *uint32           `path:"bootstrap-messages" module:"openconfig-network-instance"`
	ΛBootstrapMessages []ygot.Annotation `path:"@bootstrap-messages" ygotAnnotation:"true"`
	HelloMessages      *uint32           `path:"hello-messages" module:"openconfig-network-instance"`
	ΛHelloMessages     []ygot.Annotation `path:"@hello-messages" ygotAnnotation:"true"`
	JoinPruneMessages  *uint32           `path:"join-prune-messages" module:"openconfig-network-instance"`
	ΛJoinPruneMessages []ygot.Annotation `path:"@join-prune-messages" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Interface_Counters) IsYANGGoStruct() {}

// GetBootstrapMessages retrieves the value of the leaf BootstrapMessages from the NetworkInstance_Protocol_Pim_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BootstrapMessages is set, it can safely use t.GetBootstrapMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BootstrapMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Counters) GetBootstrapMessages() uint32 {
	if t == nil || t.BootstrapMessages == nil {
		return 0
	}
	return *t.BootstrapMessages
}

// GetHelloMessages retrieves the value of the leaf HelloMessages from the NetworkInstance_Protocol_Pim_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloMessages is set, it can safely use t.GetHelloMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Counters) GetHelloMessages() uint32 {
	if t == nil || t.HelloMessages == nil {
		return 0
	}
	return *t.HelloMessages
}

// GetJoinPruneMessages retrieves the value of the leaf JoinPruneMessages from the NetworkInstance_Protocol_Pim_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if JoinPruneMessages is set, it can safely use t.GetJoinPruneMessages()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.JoinPruneMessages == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Counters) GetJoinPruneMessages() uint32 {
	if t == nil || t.JoinPruneMessages == nil {
		return 0
	}
	return *t.JoinPruneMessages
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/interface-ref YANG schema element.
type NetworkInstance_Protocol_Pim_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Protocol_Pim_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Protocol_Pim_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Pim_Interface_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/neighbors/neighbor YANG schema element.
type NetworkInstance_Protocol_Pim_Interface_Neighbor struct {
	ΛMetadata            []ygot.Annotation             `path:"@" ygotAnnotation:"true"`
	DrAddress            *string                       `path:"state/dr-address" module:"openconfig-network-instance"`
	ΛDrAddress           []ygot.Annotation             `path:"state/@dr-address" ygotAnnotation:"true"`
	Mode                 E_OpenconfigPimTypes_PIM_MODE `path:"state/mode" module:"openconfig-network-instance"`
	ΛMode                []ygot.Annotation             `path:"state/@mode" ygotAnnotation:"true"`
	NeighborAddress      *string                       `path:"state/neighbor-address|neighbor-address" module:"openconfig-network-instance"`
	ΛNeighborAddress     []ygot.Annotation             `path:"state/@neighbor-address|@neighbor-address" ygotAnnotation:"true"`
	NeighborEstablished  *uint64                       `path:"state/neighbor-established" module:"openconfig-network-instance"`
	ΛNeighborEstablished []ygot.Annotation             `path:"state/@neighbor-established" ygotAnnotation:"true"`
	NeighborExpires      *uint64                       `path:"state/neighbor-expires" module:"openconfig-network-instance"`
	ΛNeighborExpires     []ygot.Annotation             `path:"state/@neighbor-expires" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Pim_Interface_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Pim_Interface_Neighbor) IsYANGGoStruct() {}

// GetDrAddress retrieves the value of the leaf DrAddress from the NetworkInstance_Protocol_Pim_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DrAddress is set, it can safely use t.GetDrAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DrAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) GetDrAddress() string {
	if t == nil || t.DrAddress == nil {
		return ""
	}
	return *t.DrAddress
}

// GetMode retrieves the value of the leaf Mode from the NetworkInstance_Protocol_Pim_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) GetMode() E_OpenconfigPimTypes_PIM_MODE {
	if t == nil || t.Mode == 0 {
		return 0
	}
	return t.Mode
}

// GetNeighborAddress retrieves the value of the leaf NeighborAddress from the NetworkInstance_Protocol_Pim_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborAddress is set, it can safely use t.GetNeighborAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) GetNeighborAddress() string {
	if t == nil || t.NeighborAddress == nil {
		return ""
	}
	return *t.NeighborAddress
}

// GetNeighborEstablished retrieves the value of the leaf NeighborEstablished from the NetworkInstance_Protocol_Pim_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborEstablished is set, it can safely use t.GetNeighborEstablished()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborEstablished == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) GetNeighborEstablished() uint64 {
	if t == nil || t.NeighborEstablished == nil {
		return 0
	}
	return *t.NeighborEstablished
}

// GetNeighborExpires retrieves the value of the leaf NeighborExpires from the NetworkInstance_Protocol_Pim_Interface_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborExpires is set, it can safely use t.GetNeighborExpires()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborExpires == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) GetNeighborExpires() uint64 {
	if t == nil || t.NeighborExpires == nil {
		return 0
	}
	return *t.NeighborExpires
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Pim_Interface_Neighbor struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Pim_Interface_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Pim_Interface_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Static represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static YANG schema element.
type NetworkInstance_Protocol_Static struct {
	ΛMetadata    []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	Description  *string                                             `path:"state/description" shadow-path:"config/description" module:"openconfig-network-instance"`
	ΛDescription []ygot.Annotation                                   `path:"state/@description" ygotAnnotation:"true"`
	NextHop      map[string]*NetworkInstance_Protocol_Static_NextHop `path:"next-hops/next-hop" module:"openconfig-network-instance"`
	ΛNextHop     []ygot.Annotation                                   `path:"next-hops/@next-hop" ygotAnnotation:"true"`
	Prefix       *string                                             `path:"state/prefix|prefix" shadow-path:"config/prefix" module:"openconfig-network-instance"`
	ΛPrefix      []ygot.Annotation                                   `path:"state/@prefix|@prefix" ygotAnnotation:"true"`
	SetTag       NetworkInstance_Protocol_Static_SetTag_Union        `path:"state/set-tag" shadow-path:"config/set-tag" module:"openconfig-network-instance"`
	ΛSetTag      []ygot.Annotation                                   `path:"state/@set-tag" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Static implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Static) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// NetworkInstance_Protocol_Static struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_Protocol_Static) NewNextHop(Index string) (*NetworkInstance_Protocol_Static_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[string]*NetworkInstance_Protocol_Static_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &NetworkInstance_Protocol_Static_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// RenameNextHop renames an entry in the list NextHop within
// the NetworkInstance_Protocol_Static struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_Protocol_Static) RenameNextHop(oldK, newK string) error {
	if _, ok := t.NextHop[newK]; ok {
		return fmt.Errorf("key %v already exists in NextHop", newK)
	}

	e, ok := t.NextHop[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NextHop", oldK)
	}
	e.Index = &newK

	t.NextHop[newK] = e
	delete(t.NextHop, oldK)
	return nil
}

// GetOrCreateNextHop retrieves the value with the specified keys from
// the receiver NetworkInstance_Protocol_Static. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_Protocol_Static) GetOrCreateNextHop(Index string) *NetworkInstance_Protocol_Static_NextHop {

	key := Index

	if v, ok := t.NextHop[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNextHop(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNextHop got unexpected error: %v", err))
	}
	return v
}

// GetNextHop retrieves the value with the specified key from
// the NextHop map field of NetworkInstance_Protocol_Static. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_Protocol_Static) GetNextHop(Index string) *NetworkInstance_Protocol_Static_NextHop {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.NextHop[key]; ok {
		return lm
	}
	return nil
}

// AppendNextHop appends the supplied NetworkInstance_Protocol_Static_NextHop struct to the
// list NextHop of NetworkInstance_Protocol_Static. If the key value(s) specified in
// the supplied NetworkInstance_Protocol_Static_NextHop already exist in the list, an error is
// returned.
func (t *NetworkInstance_Protocol_Static) AppendNextHop(v *NetworkInstance_Protocol_Static_NextHop) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[string]*NetworkInstance_Protocol_Static_NextHop)
	}

	if _, ok := t.NextHop[key]; ok {
		return fmt.Errorf("duplicate key for list NextHop %v", key)
	}

	t.NextHop[key] = v
	return nil
}

// GetDescription retrieves the value of the leaf Description from the NetworkInstance_Protocol_Static
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetPrefix retrieves the value of the leaf Prefix from the NetworkInstance_Protocol_Static
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefix is set, it can safely use t.GetPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static) GetPrefix() string {
	if t == nil || t.Prefix == nil {
		return ""
	}
	return *t.Prefix
}

// GetSetTag retrieves the value of the leaf SetTag from the NetworkInstance_Protocol_Static
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SetTag is set, it can safely use t.GetSetTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SetTag == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static) GetSetTag() NetworkInstance_Protocol_Static_SetTag_Union {
	if t == nil || t.SetTag == nil {
		return nil
	}
	return t.SetTag
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Static struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Static) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Static) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Static"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Static) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Static_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/state/set-tag within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type NetworkInstance_Protocol_Static_SetTag_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_NetworkInstance_Protocol_Static_SetTag_Union()
}

// Documentation_for_NetworkInstance_Protocol_Static_SetTag_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Static_SetTag_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Static_SetTag_Union() {}

// Documentation_for_NetworkInstance_Protocol_Static_SetTag_Union ensures that UnionUint32
// implements the NetworkInstance_Protocol_Static_SetTag_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_Protocol_Static_SetTag_Union() {}

// To_NetworkInstance_Protocol_Static_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Static_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Static) To_NetworkInstance_Protocol_Static_SetTag_Union(i interface{}) (NetworkInstance_Protocol_Static_SetTag_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Static_SetTag_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Static_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// NetworkInstance_Protocol_Static_NextHop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop YANG schema element.
type NetworkInstance_Protocol_Static_NextHop struct {
	ΛMetadata     []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	Index         *string                                               `path:"state/index|index" shadow-path:"config/index" module:"openconfig-network-instance"`
	ΛIndex        []ygot.Annotation                                     `path:"state/@index|@index" ygotAnnotation:"true"`
	InterfaceRef  *NetworkInstance_Protocol_Static_NextHop_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef []ygot.Annotation                                     `path:"@interface-ref" ygotAnnotation:"true"`
	Metric        *uint32                                               `path:"state/metric" shadow-path:"config/metric" module:"openconfig-network-instance"`
	ΛMetric       []ygot.Annotation                                     `path:"state/@metric" ygotAnnotation:"true"`
	NextHop       NetworkInstance_Protocol_Static_NextHop_NextHop_Union `path:"state/next-hop" shadow-path:"config/next-hop" module:"openconfig-network-instance"`
	ΛNextHop      []ygot.Annotation                                     `path:"state/@next-hop" ygotAnnotation:"true"`
	Recurse       *bool                                                 `path:"state/recurse" shadow-path:"config/recurse" module:"openconfig-network-instance"`
	ΛRecurse      []ygot.Annotation                                     `path:"state/@recurse" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Static_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Static_NextHop) IsYANGGoStruct() {}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_Protocol_Static_NextHop) GetOrCreateInterfaceRef() *NetworkInstance_Protocol_Static_NextHop_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_Protocol_Static_NextHop_InterfaceRef{}
	return t.InterfaceRef
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_Protocol_Static_NextHop. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_Protocol_Static_NextHop) GetInterfaceRef() *NetworkInstance_Protocol_Static_NextHop_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_Protocol_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static_NextHop) GetIndex() string {
	if t == nil || t.Index == nil {
		return ""
	}
	return *t.Index
}

// GetMetric retrieves the value of the leaf Metric from the NetworkInstance_Protocol_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Metric is set, it can safely use t.GetMetric()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Metric == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static_NextHop) GetMetric() uint32 {
	if t == nil || t.Metric == nil {
		return 0
	}
	return *t.Metric
}

// GetNextHop retrieves the value of the leaf NextHop from the NetworkInstance_Protocol_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NextHop is set, it can safely use t.GetNextHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NextHop == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static_NextHop) GetNextHop() NetworkInstance_Protocol_Static_NextHop_NextHop_Union {
	if t == nil || t.NextHop == nil {
		return nil
	}
	return t.NextHop
}

// GetRecurse retrieves the value of the leaf Recurse from the NetworkInstance_Protocol_Static_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Recurse is set, it can safely use t.GetRecurse()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Recurse == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static_NextHop) GetRecurse() bool {
	if t == nil || t.Recurse == nil {
		return false
	}
	return *t.Recurse
}

// ΛListKeyMap returns the keys of the NetworkInstance_Protocol_Static_NextHop struct, which is a YANG list entry.
func (t *NetworkInstance_Protocol_Static_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Static_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Static_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Static_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Protocol_Static_NextHop_NextHop_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state/next-hop within the YANG schema.
// Union type can be one of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, UnionString].
type NetworkInstance_Protocol_Static_NextHop_NextHop_Union interface {
	// Union type can be one of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, UnionString]
	Documentation_for_NetworkInstance_Protocol_Static_NextHop_NextHop_Union()
}

// Documentation_for_NetworkInstance_Protocol_Static_NextHop_NextHop_Union ensures that E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
// implements the NetworkInstance_Protocol_Static_NextHop_NextHop_Union interface.
func (E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) Documentation_for_NetworkInstance_Protocol_Static_NextHop_NextHop_Union() {
}

// Documentation_for_NetworkInstance_Protocol_Static_NextHop_NextHop_Union ensures that UnionString
// implements the NetworkInstance_Protocol_Static_NextHop_NextHop_Union interface.
func (UnionString) Documentation_for_NetworkInstance_Protocol_Static_NextHop_NextHop_Union() {}

// To_NetworkInstance_Protocol_Static_NextHop_NextHop_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_Protocol_Static_NextHop_NextHop_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_Protocol_Static_NextHop) To_NetworkInstance_Protocol_Static_NextHop_NextHop_Union(i interface{}) (NetworkInstance_Protocol_Static_NextHop_NextHop_Union, error) {
	if v, ok := i.(NetworkInstance_Protocol_Static_NextHop_NextHop_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_Protocol_Static_NextHop_NextHop_Union, unknown union type, got: %T, want any of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, string]", i, i)
}

// NetworkInstance_Protocol_Static_NextHop_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/interface-ref YANG schema element.
type NetworkInstance_Protocol_Static_NextHop_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Protocol_Static_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Protocol_Static_NextHop_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Protocol_Static_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static_NextHop_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_Protocol_Static_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Protocol_Static_NextHop_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Protocol_Static_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Protocol_Static_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Protocol_Static_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_RouteLimit represents the /openconfig-network-instance/network-instances/network-instance/route-limits/route-limit YANG schema element.
type NetworkInstance_RouteLimit struct {
	ΛMetadata          []ygot.Annotation                `path:"@" ygotAnnotation:"true"`
	Afi                E_OpenconfigTypes_ADDRESS_FAMILY `path:"state/afi|afi" shadow-path:"config/afi" module:"openconfig-network-instance"`
	ΛAfi               []ygot.Annotation                `path:"state/@afi|@afi" ygotAnnotation:"true"`
	AlarmThreshold     *uint32                          `path:"state/alarm-threshold" shadow-path:"config/alarm-threshold" module:"openconfig-network-instance"`
	ΛAlarmThreshold    []ygot.Annotation                `path:"state/@alarm-threshold" ygotAnnotation:"true"`
	InstalledRoutes    *uint32                          `path:"state/installed-routes" module:"openconfig-network-instance"`
	ΛInstalledRoutes   []ygot.Annotation                `path:"state/@installed-routes" ygotAnnotation:"true"`
	Maximum            *uint32                          `path:"state/maximum" shadow-path:"config/maximum" module:"openconfig-network-instance"`
	ΛMaximum           []ygot.Annotation                `path:"state/@maximum" ygotAnnotation:"true"`
	ThresholdExceeded  *bool                            `path:"state/threshold-exceeded" module:"openconfig-network-instance"`
	ΛThresholdExceeded []ygot.Annotation                `path:"state/@threshold-exceeded" ygotAnnotation:"true"`
	WarningOnly        *bool                            `path:"state/warning-only" shadow-path:"config/warning-only" module:"openconfig-network-instance"`
	ΛWarningOnly       []ygot.Annotation                `path:"state/@warning-only" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_RouteLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_RouteLimit) IsYANGGoStruct() {}

// GetAfi retrieves the value of the leaf Afi from the NetworkInstance_RouteLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Afi is set, it can safely use t.GetAfi()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Afi == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_RouteLimit) GetAfi() E_OpenconfigTypes_ADDRESS_FAMILY {
	if t == nil || t.Afi == 0 {
		return 0
	}
	return t.Afi
}

// GetAlarmThreshold retrieves the value of the leaf AlarmThreshold from the NetworkInstance_RouteLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlarmThreshold is set, it can safely use t.GetAlarmThreshold()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlarmThreshold == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_RouteLimit) GetAlarmThreshold() uint32 {
	if t == nil || t.AlarmThreshold == nil {
		return 0
	}
	return *t.AlarmThreshold
}

// GetInstalledRoutes retrieves the value of the leaf InstalledRoutes from the NetworkInstance_RouteLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstalledRoutes is set, it can safely use t.GetInstalledRoutes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstalledRoutes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_RouteLimit) GetInstalledRoutes() uint32 {
	if t == nil || t.InstalledRoutes == nil {
		return 0
	}
	return *t.InstalledRoutes
}

// GetMaximum retrieves the value of the leaf Maximum from the NetworkInstance_RouteLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Maximum is set, it can safely use t.GetMaximum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Maximum == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_RouteLimit) GetMaximum() uint32 {
	if t == nil || t.Maximum == nil {
		return 0
	}
	return *t.Maximum
}

// GetThresholdExceeded retrieves the value of the leaf ThresholdExceeded from the NetworkInstance_RouteLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ThresholdExceeded is set, it can safely use t.GetThresholdExceeded()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ThresholdExceeded == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_RouteLimit) GetThresholdExceeded() bool {
	if t == nil || t.ThresholdExceeded == nil {
		return false
	}
	return *t.ThresholdExceeded
}

// GetWarningOnly retrieves the value of the leaf WarningOnly from the NetworkInstance_RouteLimit
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if WarningOnly is set, it can safely use t.GetWarningOnly()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.WarningOnly == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_RouteLimit) GetWarningOnly() bool {
	if t == nil || t.WarningOnly == nil {
		return false
	}
	return *t.WarningOnly
}

// ΛListKeyMap returns the keys of the NetworkInstance_RouteLimit struct, which is a YANG list entry.
func (t *NetworkInstance_RouteLimit) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi": t.Afi,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_RouteLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_RouteLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_RouteLimit) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/segment-routing YANG schema element.
type NetworkInstance_SegmentRouting struct {
	ΛMetadata []ygot.Annotation                                                                        `path:"@" ygotAnnotation:"true"`
	Srgb      map[string]*NetworkInstance_SegmentRouting_Srgb                                          `path:"srgbs/srgb" module:"openconfig-network-instance"`
	ΛSrgb     []ygot.Annotation                                                                        `path:"srgbs/@srgb" ygotAnnotation:"true"`
	Srlb      map[string]*NetworkInstance_SegmentRouting_Srlb                                          `path:"srlbs/srlb" module:"openconfig-network-instance"`
	ΛSrlb     []ygot.Annotation                                                                        `path:"srlbs/@srlb" ygotAnnotation:"true"`
	TePolicy  map[NetworkInstance_SegmentRouting_TePolicy_Key]*NetworkInstance_SegmentRouting_TePolicy `path:"te-policies/te-policy" module:"openconfig-network-instance"`
	ΛTePolicy []ygot.Annotation                                                                        `path:"te-policies/@te-policy" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting) IsYANGGoStruct() {}

// NetworkInstance_SegmentRouting_TePolicy_Key represents the key for list TePolicy of element /openconfig-network-instance/network-instances/network-instance/segment-routing.
type NetworkInstance_SegmentRouting_TePolicy_Key struct {
	Color    uint32 `path:"color"`
	Endpoint string `path:"endpoint"`
}

// NewSrgb creates a new entry in the Srgb list of the
// NetworkInstance_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting) NewSrgb(LocalId string) (*NetworkInstance_SegmentRouting_Srgb, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srgb == nil {
		t.Srgb = make(map[string]*NetworkInstance_SegmentRouting_Srgb)
	}

	key := LocalId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Srgb[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Srgb", key)
	}

	t.Srgb[key] = &NetworkInstance_SegmentRouting_Srgb{
		LocalId: &LocalId,
	}

	return t.Srgb[key], nil
}

// RenameSrgb renames an entry in the list Srgb within
// the NetworkInstance_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting) RenameSrgb(oldK, newK string) error {
	if _, ok := t.Srgb[newK]; ok {
		return fmt.Errorf("key %v already exists in Srgb", newK)
	}

	e, ok := t.Srgb[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Srgb", oldK)
	}
	e.LocalId = &newK

	t.Srgb[newK] = e
	delete(t.Srgb, oldK)
	return nil
}

// GetOrCreateSrgb retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting) GetOrCreateSrgb(LocalId string) *NetworkInstance_SegmentRouting_Srgb {

	key := LocalId

	if v, ok := t.Srgb[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSrgb(LocalId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSrgb got unexpected error: %v", err))
	}
	return v
}

// GetSrgb retrieves the value with the specified key from
// the Srgb map field of NetworkInstance_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting) GetSrgb(LocalId string) *NetworkInstance_SegmentRouting_Srgb {

	if t == nil {
		return nil
	}

	key := LocalId

	if lm, ok := t.Srgb[key]; ok {
		return lm
	}
	return nil
}

// AppendSrgb appends the supplied NetworkInstance_SegmentRouting_Srgb struct to the
// list Srgb of NetworkInstance_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_Srgb already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting) AppendSrgb(v *NetworkInstance_SegmentRouting_Srgb) error {
	if v.LocalId == nil {
		return fmt.Errorf("invalid nil key received for LocalId")
	}

	key := *v.LocalId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srgb == nil {
		t.Srgb = make(map[string]*NetworkInstance_SegmentRouting_Srgb)
	}

	if _, ok := t.Srgb[key]; ok {
		return fmt.Errorf("duplicate key for list Srgb %v", key)
	}

	t.Srgb[key] = v
	return nil
}

// NewSrlb creates a new entry in the Srlb list of the
// NetworkInstance_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting) NewSrlb(LocalId string) (*NetworkInstance_SegmentRouting_Srlb, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srlb == nil {
		t.Srlb = make(map[string]*NetworkInstance_SegmentRouting_Srlb)
	}

	key := LocalId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Srlb[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Srlb", key)
	}

	t.Srlb[key] = &NetworkInstance_SegmentRouting_Srlb{
		LocalId: &LocalId,
	}

	return t.Srlb[key], nil
}

// RenameSrlb renames an entry in the list Srlb within
// the NetworkInstance_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting) RenameSrlb(oldK, newK string) error {
	if _, ok := t.Srlb[newK]; ok {
		return fmt.Errorf("key %v already exists in Srlb", newK)
	}

	e, ok := t.Srlb[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Srlb", oldK)
	}
	e.LocalId = &newK

	t.Srlb[newK] = e
	delete(t.Srlb, oldK)
	return nil
}

// GetOrCreateSrlb retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting) GetOrCreateSrlb(LocalId string) *NetworkInstance_SegmentRouting_Srlb {

	key := LocalId

	if v, ok := t.Srlb[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSrlb(LocalId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSrlb got unexpected error: %v", err))
	}
	return v
}

// GetSrlb retrieves the value with the specified key from
// the Srlb map field of NetworkInstance_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting) GetSrlb(LocalId string) *NetworkInstance_SegmentRouting_Srlb {

	if t == nil {
		return nil
	}

	key := LocalId

	if lm, ok := t.Srlb[key]; ok {
		return lm
	}
	return nil
}

// AppendSrlb appends the supplied NetworkInstance_SegmentRouting_Srlb struct to the
// list Srlb of NetworkInstance_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_Srlb already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting) AppendSrlb(v *NetworkInstance_SegmentRouting_Srlb) error {
	if v.LocalId == nil {
		return fmt.Errorf("invalid nil key received for LocalId")
	}

	key := *v.LocalId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srlb == nil {
		t.Srlb = make(map[string]*NetworkInstance_SegmentRouting_Srlb)
	}

	if _, ok := t.Srlb[key]; ok {
		return fmt.Errorf("duplicate key for list Srlb %v", key)
	}

	t.Srlb[key] = v
	return nil
}

// NewTePolicy creates a new entry in the TePolicy list of the
// NetworkInstance_SegmentRouting struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting) NewTePolicy(Color uint32, Endpoint string) (*NetworkInstance_SegmentRouting_TePolicy, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TePolicy == nil {
		t.TePolicy = make(map[NetworkInstance_SegmentRouting_TePolicy_Key]*NetworkInstance_SegmentRouting_TePolicy)
	}

	key := NetworkInstance_SegmentRouting_TePolicy_Key{
		Color:    Color,
		Endpoint: Endpoint,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TePolicy[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TePolicy", key)
	}

	t.TePolicy[key] = &NetworkInstance_SegmentRouting_TePolicy{
		Color:    &Color,
		Endpoint: &Endpoint,
	}

	return t.TePolicy[key], nil
}

// RenameTePolicy renames an entry in the list TePolicy within
// the NetworkInstance_SegmentRouting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting) RenameTePolicy(oldK, newK NetworkInstance_SegmentRouting_TePolicy_Key) error {
	if _, ok := t.TePolicy[newK]; ok {
		return fmt.Errorf("key %v already exists in TePolicy", newK)
	}

	e, ok := t.TePolicy[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TePolicy", oldK)
	}
	e.Color = &newK.Color
	e.Endpoint = &newK.Endpoint

	t.TePolicy[newK] = e
	delete(t.TePolicy, oldK)
	return nil
}

// GetOrCreateTePolicy retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting) GetOrCreateTePolicy(Color uint32, Endpoint string) *NetworkInstance_SegmentRouting_TePolicy {

	key := NetworkInstance_SegmentRouting_TePolicy_Key{
		Color:    Color,
		Endpoint: Endpoint,
	}

	if v, ok := t.TePolicy[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTePolicy(Color, Endpoint)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTePolicy got unexpected error: %v", err))
	}
	return v
}

// GetTePolicy retrieves the value with the specified key from
// the TePolicy map field of NetworkInstance_SegmentRouting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting) GetTePolicy(Color uint32, Endpoint string) *NetworkInstance_SegmentRouting_TePolicy {

	if t == nil {
		return nil
	}

	key := NetworkInstance_SegmentRouting_TePolicy_Key{
		Color:    Color,
		Endpoint: Endpoint,
	}

	if lm, ok := t.TePolicy[key]; ok {
		return lm
	}
	return nil
}

// AppendTePolicy appends the supplied NetworkInstance_SegmentRouting_TePolicy struct to the
// list TePolicy of NetworkInstance_SegmentRouting. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_TePolicy already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting) AppendTePolicy(v *NetworkInstance_SegmentRouting_TePolicy) error {
	if v.Color == nil {
		return fmt.Errorf("invalid nil key for Color")
	}

	if v.Endpoint == nil {
		return fmt.Errorf("invalid nil key for Endpoint")
	}

	key := NetworkInstance_SegmentRouting_TePolicy_Key{
		Color:    *v.Color,
		Endpoint: *v.Endpoint,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TePolicy == nil {
		t.TePolicy = make(map[NetworkInstance_SegmentRouting_TePolicy_Key]*NetworkInstance_SegmentRouting_TePolicy)
	}

	if _, ok := t.TePolicy[key]; ok {
		return fmt.Errorf("duplicate key for list TePolicy %v", key)
	}

	t.TePolicy[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_Srgb represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srgbs/srgb YANG schema element.
type NetworkInstance_SegmentRouting_Srgb struct {
	ΛMetadata        []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	DataplaneType    E_OpenconfigSegmentRoutingTypes_SrDataplaneType `path:"state/dataplane-type" shadow-path:"config/dataplane-type" module:"openconfig-network-instance"`
	ΛDataplaneType   []ygot.Annotation                               `path:"state/@dataplane-type" ygotAnnotation:"true"`
	Ipv6Prefixes     []string                                        `path:"state/ipv6-prefixes" shadow-path:"config/ipv6-prefixes" module:"openconfig-network-instance"`
	ΛIpv6Prefixes    []ygot.Annotation                               `path:"state/@ipv6-prefixes" ygotAnnotation:"true"`
	LocalId          *string                                         `path:"state/local-id|local-id" shadow-path:"config/local-id" module:"openconfig-network-instance"`
	ΛLocalId         []ygot.Annotation                               `path:"state/@local-id|@local-id" ygotAnnotation:"true"`
	MplsLabelBlocks  []string                                        `path:"state/mpls-label-blocks" shadow-path:"config/mpls-label-blocks" module:"openconfig-network-instance"`
	ΛMplsLabelBlocks []ygot.Annotation                               `path:"state/@mpls-label-blocks" ygotAnnotation:"true"`
	Size             *uint32                                         `path:"state/size" module:"openconfig-network-instance"`
	ΛSize            []ygot.Annotation                               `path:"state/@size" ygotAnnotation:"true"`
	Used             *uint32                                         `path:"state/used" module:"openconfig-network-instance"`
	ΛUsed            []ygot.Annotation                               `path:"state/@used" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_Srgb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_Srgb) IsYANGGoStruct() {}

// GetDataplaneType retrieves the value of the leaf DataplaneType from the NetworkInstance_SegmentRouting_Srgb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DataplaneType is set, it can safely use t.GetDataplaneType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DataplaneType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srgb) GetDataplaneType() E_OpenconfigSegmentRoutingTypes_SrDataplaneType {
	if t == nil || t.DataplaneType == 0 {
		return 0
	}
	return t.DataplaneType
}

// GetIpv6Prefixes retrieves the value of the leaf Ipv6Prefixes from the NetworkInstance_SegmentRouting_Srgb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv6Prefixes is set, it can safely use t.GetIpv6Prefixes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv6Prefixes == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srgb) GetIpv6Prefixes() []string {
	if t == nil || t.Ipv6Prefixes == nil {
		return nil
	}
	return t.Ipv6Prefixes
}

// GetLocalId retrieves the value of the leaf LocalId from the NetworkInstance_SegmentRouting_Srgb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalId is set, it can safely use t.GetLocalId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srgb) GetLocalId() string {
	if t == nil || t.LocalId == nil {
		return ""
	}
	return *t.LocalId
}

// GetMplsLabelBlocks retrieves the value of the leaf MplsLabelBlocks from the NetworkInstance_SegmentRouting_Srgb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsLabelBlocks is set, it can safely use t.GetMplsLabelBlocks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsLabelBlocks == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srgb) GetMplsLabelBlocks() []string {
	if t == nil || t.MplsLabelBlocks == nil {
		return nil
	}
	return t.MplsLabelBlocks
}

// GetSize retrieves the value of the leaf Size from the NetworkInstance_SegmentRouting_Srgb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Size is set, it can safely use t.GetSize()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Size == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srgb) GetSize() uint32 {
	if t == nil || t.Size == nil {
		return 0
	}
	return *t.Size
}

// GetUsed retrieves the value of the leaf Used from the NetworkInstance_SegmentRouting_Srgb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Used is set, it can safely use t.GetUsed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Used == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srgb) GetUsed() uint32 {
	if t == nil || t.Used == nil {
		return 0
	}
	return *t.Used
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_Srgb struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_Srgb) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalId == nil {
		return nil, fmt.Errorf("nil value for key LocalId")
	}

	return map[string]interface{}{
		"local-id": *t.LocalId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_Srgb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_Srgb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_Srgb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_Srlb represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srlbs/srlb YANG schema element.
type NetworkInstance_SegmentRouting_Srlb struct {
	ΛMetadata       []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	DataplaneType   E_OpenconfigSegmentRoutingTypes_SrDataplaneType `path:"state/dataplane-type" shadow-path:"config/dataplane-type" module:"openconfig-network-instance"`
	ΛDataplaneType  []ygot.Annotation                               `path:"state/@dataplane-type" ygotAnnotation:"true"`
	Ipv6Prefix      *string                                         `path:"state/ipv6-prefix" shadow-path:"config/ipv6-prefix" module:"openconfig-network-instance"`
	ΛIpv6Prefix     []ygot.Annotation                               `path:"state/@ipv6-prefix" ygotAnnotation:"true"`
	LocalId         *string                                         `path:"state/local-id|local-id" shadow-path:"config/local-id" module:"openconfig-network-instance"`
	ΛLocalId        []ygot.Annotation                               `path:"state/@local-id|@local-id" ygotAnnotation:"true"`
	MplsLabelBlock  *string                                         `path:"state/mpls-label-block" shadow-path:"config/mpls-label-block" module:"openconfig-network-instance"`
	ΛMplsLabelBlock []ygot.Annotation                               `path:"state/@mpls-label-block" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_Srlb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_Srlb) IsYANGGoStruct() {}

// GetDataplaneType retrieves the value of the leaf DataplaneType from the NetworkInstance_SegmentRouting_Srlb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DataplaneType is set, it can safely use t.GetDataplaneType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DataplaneType == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srlb) GetDataplaneType() E_OpenconfigSegmentRoutingTypes_SrDataplaneType {
	if t == nil || t.DataplaneType == 0 {
		return 0
	}
	return t.DataplaneType
}

// GetIpv6Prefix retrieves the value of the leaf Ipv6Prefix from the NetworkInstance_SegmentRouting_Srlb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv6Prefix is set, it can safely use t.GetIpv6Prefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv6Prefix == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srlb) GetIpv6Prefix() string {
	if t == nil || t.Ipv6Prefix == nil {
		return ""
	}
	return *t.Ipv6Prefix
}

// GetLocalId retrieves the value of the leaf LocalId from the NetworkInstance_SegmentRouting_Srlb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LocalId is set, it can safely use t.GetLocalId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LocalId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srlb) GetLocalId() string {
	if t == nil || t.LocalId == nil {
		return ""
	}
	return *t.LocalId
}

// GetMplsLabelBlock retrieves the value of the leaf MplsLabelBlock from the NetworkInstance_SegmentRouting_Srlb
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsLabelBlock is set, it can safely use t.GetMplsLabelBlock()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsLabelBlock == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_Srlb) GetMplsLabelBlock() string {
	if t == nil || t.MplsLabelBlock == nil {
		return ""
	}
	return *t.MplsLabelBlock
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_Srlb struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_Srlb) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalId == nil {
		return nil, fmt.Errorf("nil value for key LocalId")
	}

	return map[string]interface{}{
		"local-id": *t.LocalId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_Srlb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_Srlb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_Srlb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy struct {
	ΛMetadata          []ygot.Annotation                                                                                                    `path:"@" ygotAnnotation:"true"`
	Active             *bool                                                                                                                `path:"state/active" module:"openconfig-network-instance"`
	ΛActive            []ygot.Annotation                                                                                                    `path:"state/@active" ygotAnnotation:"true"`
	ActiveSince        *uint64                                                                                                              `path:"state/active-since" module:"openconfig-network-instance"`
	ΛActiveSince       []ygot.Annotation                                                                                                    `path:"state/@active-since" ygotAnnotation:"true"`
	ActiveTransitions  *uint64                                                                                                              `path:"state/active-transitions" module:"openconfig-network-instance"`
	ΛActiveTransitions []ygot.Annotation                                                                                                    `path:"state/@active-transitions" ygotAnnotation:"true"`
	Bsid               NetworkInstance_SegmentRouting_TePolicy_Bsid_Union                                                                   `path:"state/bsid" module:"openconfig-network-instance"`
	ΛBsid              []ygot.Annotation                                                                                                    `path:"state/@bsid" ygotAnnotation:"true"`
	CandidatePath      map[NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath `path:"candidate-paths/candidate-path" module:"openconfig-network-instance"`
	ΛCandidatePath     []ygot.Annotation                                                                                                    `path:"candidate-paths/@candidate-path" ygotAnnotation:"true"`
	Color              *uint32                                                                                                              `path:"state/color|color" module:"openconfig-network-instance"`
	ΛColor             []ygot.Annotation                                                                                                    `path:"state/@color|@color" ygotAnnotation:"true"`
	Counters           *NetworkInstance_SegmentRouting_TePolicy_Counters                                                                    `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters          []ygot.Annotation                                                                                                    `path:"state/@counters" ygotAnnotation:"true"`
	Endpoint           *string                                                                                                              `path:"state/endpoint|endpoint" module:"openconfig-network-instance"`
	ΛEndpoint          []ygot.Annotation                                                                                                    `path:"state/@endpoint|@endpoint" ygotAnnotation:"true"`
	Name               *string                                                                                                              `path:"state/name" module:"openconfig-network-instance"`
	ΛName              []ygot.Annotation                                                                                                    `path:"state/@name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy) IsYANGGoStruct() {}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key represents the key for list CandidatePath of element /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key struct {
	ProtocolOrigin E_OpenconfigSegmentRoutingTypes_SrteProtocolType `path:"protocol-origin"`
	OriginatorAsn  uint32                                           `path:"originator-asn"`
	OriginatorAddr string                                           `path:"originator-addr"`
	Discriminator  uint32                                           `path:"discriminator"`
}

// NewCandidatePath creates a new entry in the CandidatePath list of the
// NetworkInstance_SegmentRouting_TePolicy struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting_TePolicy) NewCandidatePath(ProtocolOrigin E_OpenconfigSegmentRoutingTypes_SrteProtocolType, OriginatorAsn uint32, OriginatorAddr string, Discriminator uint32) (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.CandidatePath == nil {
		t.CandidatePath = make(map[NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath)
	}

	key := NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key{
		ProtocolOrigin: ProtocolOrigin,
		OriginatorAsn:  OriginatorAsn,
		OriginatorAddr: OriginatorAddr,
		Discriminator:  Discriminator,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.CandidatePath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list CandidatePath", key)
	}

	t.CandidatePath[key] = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath{
		ProtocolOrigin: ProtocolOrigin,
		OriginatorAsn:  &OriginatorAsn,
		OriginatorAddr: &OriginatorAddr,
		Discriminator:  &Discriminator,
	}

	return t.CandidatePath[key], nil
}

// RenameCandidatePath renames an entry in the list CandidatePath within
// the NetworkInstance_SegmentRouting_TePolicy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting_TePolicy) RenameCandidatePath(oldK, newK NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key) error {
	if _, ok := t.CandidatePath[newK]; ok {
		return fmt.Errorf("key %v already exists in CandidatePath", newK)
	}

	e, ok := t.CandidatePath[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in CandidatePath", oldK)
	}
	e.ProtocolOrigin = newK.ProtocolOrigin
	e.OriginatorAsn = &newK.OriginatorAsn
	e.OriginatorAddr = &newK.OriginatorAddr
	e.Discriminator = &newK.Discriminator

	t.CandidatePath[newK] = e
	delete(t.CandidatePath, oldK)
	return nil
}

// GetOrCreateCandidatePath retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting_TePolicy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetOrCreateCandidatePath(ProtocolOrigin E_OpenconfigSegmentRoutingTypes_SrteProtocolType, OriginatorAsn uint32, OriginatorAddr string, Discriminator uint32) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath {

	key := NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key{
		ProtocolOrigin: ProtocolOrigin,
		OriginatorAsn:  OriginatorAsn,
		OriginatorAddr: OriginatorAddr,
		Discriminator:  Discriminator,
	}

	if v, ok := t.CandidatePath[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCandidatePath(ProtocolOrigin, OriginatorAsn, OriginatorAddr, Discriminator)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCandidatePath got unexpected error: %v", err))
	}
	return v
}

// GetCandidatePath retrieves the value with the specified key from
// the CandidatePath map field of NetworkInstance_SegmentRouting_TePolicy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetCandidatePath(ProtocolOrigin E_OpenconfigSegmentRoutingTypes_SrteProtocolType, OriginatorAsn uint32, OriginatorAddr string, Discriminator uint32) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath {

	if t == nil {
		return nil
	}

	key := NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key{
		ProtocolOrigin: ProtocolOrigin,
		OriginatorAsn:  OriginatorAsn,
		OriginatorAddr: OriginatorAddr,
		Discriminator:  Discriminator,
	}

	if lm, ok := t.CandidatePath[key]; ok {
		return lm
	}
	return nil
}

// AppendCandidatePath appends the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath struct to the
// list CandidatePath of NetworkInstance_SegmentRouting_TePolicy. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting_TePolicy) AppendCandidatePath(v *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) error {
	if v.OriginatorAsn == nil {
		return fmt.Errorf("invalid nil key for OriginatorAsn")
	}

	if v.OriginatorAddr == nil {
		return fmt.Errorf("invalid nil key for OriginatorAddr")
	}

	if v.Discriminator == nil {
		return fmt.Errorf("invalid nil key for Discriminator")
	}

	key := NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key{
		ProtocolOrigin: v.ProtocolOrigin,
		OriginatorAsn:  *v.OriginatorAsn,
		OriginatorAddr: *v.OriginatorAddr,
		Discriminator:  *v.Discriminator,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.CandidatePath == nil {
		t.CandidatePath = make(map[NetworkInstance_SegmentRouting_TePolicy_CandidatePath_Key]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath)
	}

	if _, ok := t.CandidatePath[key]; ok {
		return fmt.Errorf("duplicate key for list CandidatePath %v", key)
	}

	t.CandidatePath[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetOrCreateCounters() *NetworkInstance_SegmentRouting_TePolicy_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_SegmentRouting_TePolicy_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_SegmentRouting_TePolicy. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetCounters() *NetworkInstance_SegmentRouting_TePolicy_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetActive retrieves the value of the leaf Active from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetActiveSince retrieves the value of the leaf ActiveSince from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ActiveSince is set, it can safely use t.GetActiveSince()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ActiveSince == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetActiveSince() uint64 {
	if t == nil || t.ActiveSince == nil {
		return 0
	}
	return *t.ActiveSince
}

// GetActiveTransitions retrieves the value of the leaf ActiveTransitions from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ActiveTransitions is set, it can safely use t.GetActiveTransitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ActiveTransitions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetActiveTransitions() uint64 {
	if t == nil || t.ActiveTransitions == nil {
		return 0
	}
	return *t.ActiveTransitions
}

// GetBsid retrieves the value of the leaf Bsid from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Bsid is set, it can safely use t.GetBsid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Bsid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetBsid() NetworkInstance_SegmentRouting_TePolicy_Bsid_Union {
	if t == nil || t.Bsid == nil {
		return nil
	}
	return t.Bsid
}

// GetColor retrieves the value of the leaf Color from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Color is set, it can safely use t.GetColor()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Color == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetColor() uint32 {
	if t == nil || t.Color == nil {
		return 0
	}
	return *t.Color
}

// GetEndpoint retrieves the value of the leaf Endpoint from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Endpoint is set, it can safely use t.GetEndpoint()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Endpoint == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetEndpoint() string {
	if t == nil || t.Endpoint == nil {
		return ""
	}
	return *t.Endpoint
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_SegmentRouting_TePolicy
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_TePolicy struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_TePolicy) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_Bsid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_SegmentRouting_TePolicy_Bsid_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union()
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_SegmentRouting_TePolicy_Bsid_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union() {
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union ensures that UnionString
// implements the NetworkInstance_SegmentRouting_TePolicy_Bsid_Union interface.
func (UnionString) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union() {}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union ensures that UnionUint32
// implements the NetworkInstance_SegmentRouting_TePolicy_Bsid_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union() {}

// To_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_SegmentRouting_TePolicy_Bsid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_SegmentRouting_TePolicy) To_NetworkInstance_SegmentRouting_TePolicy_Bsid_Union(i interface{}) (NetworkInstance_SegmentRouting_TePolicy_Bsid_Union, error) {
	if v, ok := i.(NetworkInstance_SegmentRouting_TePolicy_Bsid_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_SegmentRouting_TePolicy_Bsid_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath struct {
	ΛMetadata          []ygot.Annotation                                                             `path:"@" ygotAnnotation:"true"`
	Active             *bool                                                                         `path:"state/active" module:"openconfig-network-instance"`
	ΛActive            []ygot.Annotation                                                             `path:"state/@active" ygotAnnotation:"true"`
	ActiveSince        *uint64                                                                       `path:"state/active-since" module:"openconfig-network-instance"`
	ΛActiveSince       []ygot.Annotation                                                             `path:"state/@active-since" ygotAnnotation:"true"`
	ActiveTransitions  *uint64                                                                       `path:"state/active-transitions" module:"openconfig-network-instance"`
	ΛActiveTransitions []ygot.Annotation                                                             `path:"state/@active-transitions" ygotAnnotation:"true"`
	Discriminator      *uint32                                                                       `path:"state/discriminator|discriminator" module:"openconfig-network-instance"`
	ΛDiscriminator     []ygot.Annotation                                                             `path:"state/@discriminator|@discriminator" ygotAnnotation:"true"`
	Enlp               E_OpenconfigSegmentRoutingTypes_EnlpType                                      `path:"state/enlp" module:"openconfig-network-instance"`
	ΛEnlp              []ygot.Annotation                                                             `path:"state/@enlp" ygotAnnotation:"true"`
	Name               *string                                                                       `path:"state/name" module:"openconfig-network-instance"`
	ΛName              []ygot.Annotation                                                             `path:"state/@name" ygotAnnotation:"true"`
	OriginatorAddr     *string                                                                       `path:"state/originator-addr|originator-addr" module:"openconfig-network-instance"`
	ΛOriginatorAddr    []ygot.Annotation                                                             `path:"state/@originator-addr|@originator-addr" ygotAnnotation:"true"`
	OriginatorAsn      *uint32                                                                       `path:"state/originator-asn|originator-asn" module:"openconfig-network-instance"`
	ΛOriginatorAsn     []ygot.Annotation                                                             `path:"state/@originator-asn|@originator-asn" ygotAnnotation:"true"`
	Preference         *uint32                                                                       `path:"state/preference" module:"openconfig-network-instance"`
	ΛPreference        []ygot.Annotation                                                             `path:"state/@preference" ygotAnnotation:"true"`
	ProtocolOrigin     E_OpenconfigSegmentRoutingTypes_SrteProtocolType                              `path:"state/protocol-origin|protocol-origin" module:"openconfig-network-instance"`
	ΛProtocolOrigin    []ygot.Annotation                                                             `path:"state/@protocol-origin|@protocol-origin" ygotAnnotation:"true"`
	SegmentList        map[uint32]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList `path:"segment-lists/segment-list" module:"openconfig-network-instance"`
	ΛSegmentList       []ygot.Annotation                                                             `path:"segment-lists/@segment-list" ygotAnnotation:"true"`
	Valid              *bool                                                                         `path:"state/valid" module:"openconfig-network-instance"`
	ΛValid             []ygot.Annotation                                                             `path:"state/@valid" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath) IsYANGGoStruct() {}

// NewSegmentList creates a new entry in the SegmentList list of the
// NetworkInstance_SegmentRouting_TePolicy_CandidatePath struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) NewSegmentList(Id uint32) (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint32]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SegmentList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SegmentList", key)
	}

	t.SegmentList[key] = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList{
		Id: &Id,
	}

	return t.SegmentList[key], nil
}

// RenameSegmentList renames an entry in the list SegmentList within
// the NetworkInstance_SegmentRouting_TePolicy_CandidatePath struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) RenameSegmentList(oldK, newK uint32) error {
	if _, ok := t.SegmentList[newK]; ok {
		return fmt.Errorf("key %v already exists in SegmentList", newK)
	}

	e, ok := t.SegmentList[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SegmentList", oldK)
	}
	e.Id = &newK

	t.SegmentList[newK] = e
	delete(t.SegmentList, oldK)
	return nil
}

// GetOrCreateSegmentList retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting_TePolicy_CandidatePath. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetOrCreateSegmentList(Id uint32) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList {

	key := Id

	if v, ok := t.SegmentList[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSegmentList(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSegmentList got unexpected error: %v", err))
	}
	return v
}

// GetSegmentList retrieves the value with the specified key from
// the SegmentList map field of NetworkInstance_SegmentRouting_TePolicy_CandidatePath. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetSegmentList(Id uint32) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.SegmentList[key]; ok {
		return lm
	}
	return nil
}

// AppendSegmentList appends the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct to the
// list SegmentList of NetworkInstance_SegmentRouting_TePolicy_CandidatePath. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) AppendSegmentList(v *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint32]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList)
	}

	if _, ok := t.SegmentList[key]; ok {
		return fmt.Errorf("duplicate key for list SegmentList %v", key)
	}

	t.SegmentList[key] = v
	return nil
}

// GetActive retrieves the value of the leaf Active from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetActiveSince retrieves the value of the leaf ActiveSince from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ActiveSince is set, it can safely use t.GetActiveSince()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ActiveSince == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetActiveSince() uint64 {
	if t == nil || t.ActiveSince == nil {
		return 0
	}
	return *t.ActiveSince
}

// GetActiveTransitions retrieves the value of the leaf ActiveTransitions from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ActiveTransitions is set, it can safely use t.GetActiveTransitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ActiveTransitions == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetActiveTransitions() uint64 {
	if t == nil || t.ActiveTransitions == nil {
		return 0
	}
	return *t.ActiveTransitions
}

// GetDiscriminator retrieves the value of the leaf Discriminator from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Discriminator is set, it can safely use t.GetDiscriminator()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Discriminator == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetDiscriminator() uint32 {
	if t == nil || t.Discriminator == nil {
		return 0
	}
	return *t.Discriminator
}

// GetEnlp retrieves the value of the leaf Enlp from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enlp is set, it can safely use t.GetEnlp()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enlp == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetEnlp() E_OpenconfigSegmentRoutingTypes_EnlpType {
	if t == nil || t.Enlp == 0 {
		return 0
	}
	return t.Enlp
}

// GetName retrieves the value of the leaf Name from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetOriginatorAddr retrieves the value of the leaf OriginatorAddr from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginatorAddr is set, it can safely use t.GetOriginatorAddr()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginatorAddr == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetOriginatorAddr() string {
	if t == nil || t.OriginatorAddr == nil {
		return ""
	}
	return *t.OriginatorAddr
}

// GetOriginatorAsn retrieves the value of the leaf OriginatorAsn from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginatorAsn is set, it can safely use t.GetOriginatorAsn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginatorAsn == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetOriginatorAsn() uint32 {
	if t == nil || t.OriginatorAsn == nil {
		return 0
	}
	return *t.OriginatorAsn
}

// GetPreference retrieves the value of the leaf Preference from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Preference is set, it can safely use t.GetPreference()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Preference == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetPreference() uint32 {
	if t == nil || t.Preference == nil {
		return 0
	}
	return *t.Preference
}

// GetProtocolOrigin retrieves the value of the leaf ProtocolOrigin from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ProtocolOrigin is set, it can safely use t.GetProtocolOrigin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ProtocolOrigin == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetProtocolOrigin() E_OpenconfigSegmentRoutingTypes_SrteProtocolType {
	if t == nil || t.ProtocolOrigin == 0 {
		return 0
	}
	return t.ProtocolOrigin
}

// GetValid retrieves the value of the leaf Valid from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Valid is set, it can safely use t.GetValid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Valid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) GetValid() bool {
	if t == nil || t.Valid == nil {
		return false
	}
	return *t.Valid
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_TePolicy_CandidatePath struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Discriminator == nil {
		return nil, fmt.Errorf("nil value for key Discriminator")
	}

	if t.OriginatorAddr == nil {
		return nil, fmt.Errorf("nil value for key OriginatorAddr")
	}

	if t.OriginatorAsn == nil {
		return nil, fmt.Errorf("nil value for key OriginatorAsn")
	}

	return map[string]interface{}{
		"discriminator":   *t.Discriminator,
		"originator-addr": *t.OriginatorAddr,
		"originator-asn":  *t.OriginatorAsn,
		"protocol-origin": t.ProtocolOrigin,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct {
	ΛMetadata      []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	Counters       *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters           `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters      []ygot.Annotation                                                                     `path:"state/@counters" ygotAnnotation:"true"`
	Id             *uint32                                                                               `path:"state/id|id" module:"openconfig-network-instance"`
	ΛId            []ygot.Annotation                                                                     `path:"state/@id|@id" ygotAnnotation:"true"`
	InvalidReason  E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason                                   `path:"state/invalid-reason" module:"openconfig-network-instance"`
	ΛInvalidReason []ygot.Annotation                                                                     `path:"state/@invalid-reason" ygotAnnotation:"true"`
	NextHop        map[uint64]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop `path:"next-hops/next-hop" module:"openconfig-network-instance"`
	ΛNextHop       []ygot.Annotation                                                                     `path:"next-hops/@next-hop" ygotAnnotation:"true"`
	Sid            map[uint64]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid     `path:"sids/sid" module:"openconfig-network-instance"`
	ΛSid           []ygot.Annotation                                                                     `path:"sids/@sid" ygotAnnotation:"true"`
	Valid          *bool                                                                                 `path:"state/valid" module:"openconfig-network-instance"`
	ΛValid         []ygot.Annotation                                                                     `path:"state/@valid" ygotAnnotation:"true"`
	Weight         *uint32                                                                               `path:"state/weight" module:"openconfig-network-instance"`
	ΛWeight        []ygot.Annotation                                                                     `path:"state/@weight" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) NewNextHop(Index uint64) (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// RenameNextHop renames an entry in the list NextHop within
// the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) RenameNextHop(oldK, newK uint64) error {
	if _, ok := t.NextHop[newK]; ok {
		return fmt.Errorf("key %v already exists in NextHop", newK)
	}

	e, ok := t.NextHop[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NextHop", oldK)
	}
	e.Index = &newK

	t.NextHop[newK] = e
	delete(t.NextHop, oldK)
	return nil
}

// GetOrCreateNextHop retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetOrCreateNextHop(Index uint64) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop {

	key := Index

	if v, ok := t.NextHop[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNextHop(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNextHop got unexpected error: %v", err))
	}
	return v
}

// GetNextHop retrieves the value with the specified key from
// the NextHop map field of NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetNextHop(Index uint64) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.NextHop[key]; ok {
		return lm
	}
	return nil
}

// AppendNextHop appends the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop struct to the
// list NextHop of NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) AppendNextHop(v *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop)
	}

	if _, ok := t.NextHop[key]; ok {
		return fmt.Errorf("duplicate key for list NextHop %v", key)
	}

	t.NextHop[key] = v
	return nil
}

// NewSid creates a new entry in the Sid list of the
// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct. The keys of the list are populated from the input
// arguments.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) NewSid(Index uint64) (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Sid == nil {
		t.Sid = make(map[uint64]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Sid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Sid", key)
	}

	t.Sid[key] = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid{
		Index: &Index,
	}

	return t.Sid[key], nil
}

// RenameSid renames an entry in the list Sid within
// the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) RenameSid(oldK, newK uint64) error {
	if _, ok := t.Sid[newK]; ok {
		return fmt.Errorf("key %v already exists in Sid", newK)
	}

	e, ok := t.Sid[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Sid", oldK)
	}
	e.Index = &newK

	t.Sid[newK] = e
	delete(t.Sid, oldK)
	return nil
}

// GetOrCreateSid retrieves the value with the specified keys from
// the receiver NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetOrCreateSid(Index uint64) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid {

	key := Index

	if v, ok := t.Sid[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSid(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSid got unexpected error: %v", err))
	}
	return v
}

// GetSid retrieves the value with the specified key from
// the Sid map field of NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetSid(Index uint64) *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Sid[key]; ok {
		return lm
	}
	return nil
}

// AppendSid appends the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid struct to the
// list Sid of NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the key value(s) specified in
// the supplied NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid already exist in the list, an error is
// returned.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) AppendSid(v *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Sid == nil {
		t.Sid = make(map[uint64]*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid)
	}

	if _, ok := t.Sid[key]; ok {
		return fmt.Errorf("duplicate key for list Sid %v", key)
	}

	t.Sid[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetOrCreateCounters() *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetCounters() *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetId retrieves the value of the leaf Id from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetId() uint32 {
	if t == nil || t.Id == nil {
		return 0
	}
	return *t.Id
}

// GetInvalidReason retrieves the value of the leaf InvalidReason from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidReason is set, it can safely use t.GetInvalidReason()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidReason == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetInvalidReason() E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason {
	if t == nil || t.InvalidReason == 0 {
		return 0
	}
	return t.InvalidReason
}

// GetValid retrieves the value of the leaf Valid from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Valid is set, it can safely use t.GetValid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Valid == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetValid() bool {
	if t == nil || t.Valid == nil {
		return false
	}
	return *t.Valid
}

// GetWeight retrieves the value of the leaf Weight from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Weight is set, it can safely use t.GetWeight()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Weight == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) GetWeight() uint32 {
	if t == nil || t.Weight == nil {
		return 0
	}
	return *t.Weight
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/state/counters YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	OutLabeledOctets  *uint64           `path:"out-labeled-octets" module:"openconfig-network-instance"`
	ΛOutLabeledOctets []ygot.Annotation `path:"@out-labeled-octets" ygotAnnotation:"true"`
	OutLabeledPkts    *uint64           `path:"out-labeled-pkts" module:"openconfig-network-instance"`
	ΛOutLabeledPkts   []ygot.Annotation `path:"@out-labeled-pkts" ygotAnnotation:"true"`
	OutOctets         *uint64           `path:"out-octets" module:"openconfig-network-instance"`
	ΛOutOctets        []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts           *uint64           `path:"out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts          []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) IsYANGGoStruct() {}

// GetOutLabeledOctets retrieves the value of the leaf OutLabeledOctets from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutLabeledOctets is set, it can safely use t.GetOutLabeledOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutLabeledOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) GetOutLabeledOctets() uint64 {
	if t == nil || t.OutLabeledOctets == nil {
		return 0
	}
	return *t.OutLabeledOctets
}

// GetOutLabeledPkts retrieves the value of the leaf OutLabeledPkts from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutLabeledPkts is set, it can safely use t.GetOutLabeledPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutLabeledPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) GetOutLabeledPkts() uint64 {
	if t == nil || t.OutLabeledPkts == nil {
		return 0
	}
	return *t.OutLabeledPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop struct {
	ΛMetadata             []ygot.Annotation                                                                                      `path:"@" ygotAnnotation:"true"`
	Counters              *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters                    `path:"state/counters" module:"openconfig-network-instance"`
	ΛCounters             []ygot.Annotation                                                                                      `path:"state/@counters" ygotAnnotation:"true"`
	EncapsulateHeader     E_OpenconfigAftTypes_EncapsulationHeaderType                                                           `path:"state/encapsulate-header" module:"openconfig-network-instance"`
	ΛEncapsulateHeader    []ygot.Annotation                                                                                      `path:"state/@encapsulate-header" ygotAnnotation:"true"`
	Index                 *uint64                                                                                                `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex                []ygot.Annotation                                                                                      `path:"state/@index|@index" ygotAnnotation:"true"`
	InterfaceRef          *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef                `path:"interface-ref" module:"openconfig-network-instance"`
	ΛInterfaceRef         []ygot.Annotation                                                                                      `path:"@interface-ref" ygotAnnotation:"true"`
	IpAddress             *string                                                                                                `path:"state/ip-address" module:"openconfig-network-instance"`
	ΛIpAddress            []ygot.Annotation                                                                                      `path:"state/@ip-address" ygotAnnotation:"true"`
	MacAddress            *string                                                                                                `path:"state/mac-address" module:"openconfig-network-instance"`
	ΛMacAddress           []ygot.Annotation                                                                                      `path:"state/@mac-address" ygotAnnotation:"true"`
	OriginProtocol        E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                                          `path:"state/origin-protocol" module:"openconfig-network-instance"`
	ΛOriginProtocol       []ygot.Annotation                                                                                      `path:"state/@origin-protocol" ygotAnnotation:"true"`
	PushedMplsLabelStack  []NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union `path:"state/pushed-mpls-label-stack" module:"openconfig-network-instance"`
	ΛPushedMplsLabelStack []ygot.Annotation                                                                                      `path:"state/@pushed-mpls-label-stack" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetOrCreateCounters() *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters{}
	return t.Counters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetOrCreateInterfaceRef() *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef{}
	return t.InterfaceRef
}

// GetCounters returns the value of the Counters struct pointer
// from NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetCounters() *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetInterfaceRef() *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEncapsulateHeader retrieves the value of the leaf EncapsulateHeader from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EncapsulateHeader is set, it can safely use t.GetEncapsulateHeader()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EncapsulateHeader == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetEncapsulateHeader() E_OpenconfigAftTypes_EncapsulationHeaderType {
	if t == nil || t.EncapsulateHeader == 0 {
		return 0
	}
	return t.EncapsulateHeader
}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetIpAddress retrieves the value of the leaf IpAddress from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpAddress is set, it can safely use t.GetIpAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetIpAddress() string {
	if t == nil || t.IpAddress == nil {
		return ""
	}
	return *t.IpAddress
}

// GetMacAddress retrieves the value of the leaf MacAddress from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MacAddress is set, it can safely use t.GetMacAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MacAddress == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetMacAddress() string {
	if t == nil || t.MacAddress == nil {
		return ""
	}
	return *t.MacAddress
}

// GetOriginProtocol retrieves the value of the leaf OriginProtocol from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OriginProtocol is set, it can safely use t.GetOriginProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OriginProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetOriginProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.OriginProtocol == 0 {
		return 0
	}
	return t.OriginProtocol
}

// GetPushedMplsLabelStack retrieves the value of the leaf PushedMplsLabelStack from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PushedMplsLabelStack is set, it can safely use t.GetPushedMplsLabelStack()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PushedMplsLabelStack == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) GetPushedMplsLabelStack() []NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union {
	if t == nil || t.PushedMplsLabelStack == nil {
		return nil
	}
	return t.PushedMplsLabelStack
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/pushed-mpls-label-stack within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32].
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionUint32]
	Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union()
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union() {
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union ensures that UnionUint32
// implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union() {
}

// To_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop) To_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union(i interface{}) (NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union, error) {
	if v, ok := i.(NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_PushedMplsLabelStack_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, uint32]", i, i)
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/counters YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	OutLabeledOctets  *uint64           `path:"out-labeled-octets" module:"openconfig-network-instance"`
	ΛOutLabeledOctets []ygot.Annotation `path:"@out-labeled-octets" ygotAnnotation:"true"`
	OutLabeledPkts    *uint64           `path:"out-labeled-pkts" module:"openconfig-network-instance"`
	ΛOutLabeledPkts   []ygot.Annotation `path:"@out-labeled-pkts" ygotAnnotation:"true"`
	OutOctets         *uint64           `path:"out-octets" module:"openconfig-network-instance"`
	ΛOutOctets        []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts           *uint64           `path:"out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts          []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) IsYANGGoStruct() {
}

// GetOutLabeledOctets retrieves the value of the leaf OutLabeledOctets from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutLabeledOctets is set, it can safely use t.GetOutLabeledOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutLabeledOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) GetOutLabeledOctets() uint64 {
	if t == nil || t.OutLabeledOctets == nil {
		return 0
	}
	return *t.OutLabeledOctets
}

// GetOutLabeledPkts retrieves the value of the leaf OutLabeledPkts from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutLabeledPkts is set, it can safely use t.GetOutLabeledPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutLabeledPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) GetOutLabeledPkts() uint64 {
	if t == nil || t.OutLabeledPkts == nil {
		return 0
	}
	return *t.OutLabeledPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/interface-ref YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" module:"openconfig-network-instance"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" module:"openconfig-network-instance"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef) IsYANGGoStruct() {
}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid struct {
	ΛMetadata []ygot.Annotation                                                                 `path:"@" ygotAnnotation:"true"`
	Index     *uint64                                                                           `path:"state/index|index" module:"openconfig-network-instance"`
	ΛIndex    []ygot.Annotation                                                                 `path:"state/@index|@index" ygotAnnotation:"true"`
	MplsTc    *uint8                                                                            `path:"state/mpls-tc" module:"openconfig-network-instance"`
	ΛMplsTc   []ygot.Annotation                                                                 `path:"state/@mpls-tc" ygotAnnotation:"true"`
	MplsTtl   *uint8                                                                            `path:"state/mpls-ttl" module:"openconfig-network-instance"`
	ΛMplsTtl  []ygot.Annotation                                                                 `path:"state/@mpls-ttl" ygotAnnotation:"true"`
	Value     NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union `path:"state/value" module:"openconfig-network-instance"`
	ΛValue    []ygot.Annotation                                                                 `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) IsYANGGoStruct() {}

// GetIndex retrieves the value of the leaf Index from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) GetIndex() uint64 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetMplsTc retrieves the value of the leaf MplsTc from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTc is set, it can safely use t.GetMplsTc()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTc == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) GetMplsTc() uint8 {
	if t == nil || t.MplsTc == nil {
		return 0
	}
	return *t.MplsTc
}

// GetMplsTtl retrieves the value of the leaf MplsTtl from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MplsTtl is set, it can safely use t.GetMplsTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MplsTtl == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) GetMplsTtl() uint8 {
	if t == nil || t.MplsTtl == nil {
		return 0
	}
	return *t.MplsTtl
}

// GetValue retrieves the value of the leaf Value from the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) GetValue() NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid struct, which is a YANG list entry.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value within the YANG schema.
// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32].
type NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union interface {
	// Union type can be one of [E_OpenconfigMplsTypes_MplsLabel_Enum, UnionString, UnionUint32]
	Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union()
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union ensures that E_OpenconfigMplsTypes_MplsLabel_Enum
// implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union interface.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union() {
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union ensures that UnionString
// implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union interface.
func (UnionString) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union() {
}

// Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union ensures that UnionUint32
// implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union interface.
func (UnionUint32) Documentation_for_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union() {
}

// To_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union takes an input interface{} and attempts to convert it to a struct
// which implements the NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid) To_NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union(i interface{}) (NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union, error) {
	if v, ok := i.(NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to NetworkInstance_SegmentRouting_TePolicy_CandidatePath_SegmentList_Sid_Value_Union, unknown union type, got: %T, want any of [E_OpenconfigMplsTypes_MplsLabel_Enum, string, uint32]", i, i)
}

// NetworkInstance_SegmentRouting_TePolicy_Counters represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/counters YANG schema element.
type NetworkInstance_SegmentRouting_TePolicy_Counters struct {
	ΛMetadata         []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	InLabeledOctets   *uint64           `path:"in-labeled-octets" module:"openconfig-network-instance"`
	ΛInLabeledOctets  []ygot.Annotation `path:"@in-labeled-octets" ygotAnnotation:"true"`
	InLabeledPkts     *uint64           `path:"in-labeled-pkts" module:"openconfig-network-instance"`
	ΛInLabeledPkts    []ygot.Annotation `path:"@in-labeled-pkts" ygotAnnotation:"true"`
	InOctets          *uint64           `path:"in-octets" module:"openconfig-network-instance"`
	ΛInOctets         []ygot.Annotation `path:"@in-octets" ygotAnnotation:"true"`
	InPkts            *uint64           `path:"in-pkts" module:"openconfig-network-instance"`
	ΛInPkts           []ygot.Annotation `path:"@in-pkts" ygotAnnotation:"true"`
	OutLabeledOctets  *uint64           `path:"out-labeled-octets" module:"openconfig-network-instance"`
	ΛOutLabeledOctets []ygot.Annotation `path:"@out-labeled-octets" ygotAnnotation:"true"`
	OutLabeledPkts    *uint64           `path:"out-labeled-pkts" module:"openconfig-network-instance"`
	ΛOutLabeledPkts   []ygot.Annotation `path:"@out-labeled-pkts" ygotAnnotation:"true"`
	OutOctets         *uint64           `path:"out-octets" module:"openconfig-network-instance"`
	ΛOutOctets        []ygot.Annotation `path:"@out-octets" ygotAnnotation:"true"`
	OutPkts           *uint64           `path:"out-pkts" module:"openconfig-network-instance"`
	ΛOutPkts          []ygot.Annotation `path:"@out-pkts" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_SegmentRouting_TePolicy_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_SegmentRouting_TePolicy_Counters) IsYANGGoStruct() {}

// GetInLabeledOctets retrieves the value of the leaf InLabeledOctets from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InLabeledOctets is set, it can safely use t.GetInLabeledOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InLabeledOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetInLabeledOctets() uint64 {
	if t == nil || t.InLabeledOctets == nil {
		return 0
	}
	return *t.InLabeledOctets
}

// GetInLabeledPkts retrieves the value of the leaf InLabeledPkts from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InLabeledPkts is set, it can safely use t.GetInLabeledPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InLabeledPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetInLabeledPkts() uint64 {
	if t == nil || t.InLabeledPkts == nil {
		return 0
	}
	return *t.InLabeledPkts
}

// GetInOctets retrieves the value of the leaf InOctets from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOctets is set, it can safely use t.GetInOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetInOctets() uint64 {
	if t == nil || t.InOctets == nil {
		return 0
	}
	return *t.InOctets
}

// GetInPkts retrieves the value of the leaf InPkts from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPkts is set, it can safely use t.GetInPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetInPkts() uint64 {
	if t == nil || t.InPkts == nil {
		return 0
	}
	return *t.InPkts
}

// GetOutLabeledOctets retrieves the value of the leaf OutLabeledOctets from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutLabeledOctets is set, it can safely use t.GetOutLabeledOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutLabeledOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetOutLabeledOctets() uint64 {
	if t == nil || t.OutLabeledOctets == nil {
		return 0
	}
	return *t.OutLabeledOctets
}

// GetOutLabeledPkts retrieves the value of the leaf OutLabeledPkts from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutLabeledPkts is set, it can safely use t.GetOutLabeledPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutLabeledPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetOutLabeledPkts() uint64 {
	if t == nil || t.OutLabeledPkts == nil {
		return 0
	}
	return *t.OutLabeledPkts
}

// GetOutOctets retrieves the value of the leaf OutOctets from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutOctets is set, it can safely use t.GetOutOctets()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutOctets == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetOutOctets() uint64 {
	if t == nil || t.OutOctets == nil {
		return 0
	}
	return *t.OutOctets
}

// GetOutPkts retrieves the value of the leaf OutPkts from the NetworkInstance_SegmentRouting_TePolicy_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPkts is set, it can safely use t.GetOutPkts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPkts == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) GetOutPkts() uint64 {
	if t == nil || t.OutPkts == nil {
		return 0
	}
	return *t.OutPkts
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_SegmentRouting_TePolicy_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_SegmentRouting_TePolicy_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Table represents the /openconfig-network-instance/network-instances/network-instance/tables/table YANG schema element.
type NetworkInstance_Table struct {
	ΛMetadata      []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	AddressFamily  E_OpenconfigTypes_ADDRESS_FAMILY              `path:"state/address-family|address-family" shadow-path:"config/address-family" module:"openconfig-network-instance"`
	ΛAddressFamily []ygot.Annotation                             `path:"state/@address-family|@address-family" ygotAnnotation:"true"`
	Protocol       E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"state/protocol|protocol" shadow-path:"config/protocol" module:"openconfig-network-instance"`
	ΛProtocol      []ygot.Annotation                             `path:"state/@protocol|@protocol" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Table implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Table) IsYANGGoStruct() {}

// GetAddressFamily retrieves the value of the leaf AddressFamily from the NetworkInstance_Table
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AddressFamily is set, it can safely use t.GetAddressFamily()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AddressFamily == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Table) GetAddressFamily() E_OpenconfigTypes_ADDRESS_FAMILY {
	if t == nil || t.AddressFamily == 0 {
		return 0
	}
	return t.AddressFamily
}

// GetProtocol retrieves the value of the leaf Protocol from the NetworkInstance_Table
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Protocol is set, it can safely use t.GetProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Protocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Table) GetProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.Protocol == 0 {
		return 0
	}
	return t.Protocol
}

// ΛListKeyMap returns the keys of the NetworkInstance_Table struct, which is a YANG list entry.
func (t *NetworkInstance_Table) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"address-family": t.AddressFamily,
		"protocol":       t.Protocol,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Table) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Table"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Table) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_TableConnection represents the /openconfig-network-instance/network-instances/network-instance/table-connections/table-connection YANG schema element.
type NetworkInstance_TableConnection struct {
	ΛMetadata                 []ygot.Annotation                             `path:"@" ygotAnnotation:"true"`
	AddressFamily             E_OpenconfigTypes_ADDRESS_FAMILY              `path:"state/address-family|address-family" shadow-path:"config/address-family" module:"openconfig-network-instance"`
	ΛAddressFamily            []ygot.Annotation                             `path:"state/@address-family|@address-family" ygotAnnotation:"true"`
	DefaultImportPolicy       E_OpenconfigRoutingPolicy_DefaultPolicyType   `path:"state/default-import-policy" shadow-path:"config/default-import-policy" module:"openconfig-network-instance"`
	ΛDefaultImportPolicy      []ygot.Annotation                             `path:"state/@default-import-policy" ygotAnnotation:"true"`
	DisableMetricPropagation  *bool                                         `path:"state/disable-metric-propagation" shadow-path:"config/disable-metric-propagation" module:"openconfig-network-instance"`
	ΛDisableMetricPropagation []ygot.Annotation                             `path:"state/@disable-metric-propagation" ygotAnnotation:"true"`
	DstProtocol               E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"state/dst-protocol|dst-protocol" shadow-path:"config/dst-protocol" module:"openconfig-network-instance"`
	ΛDstProtocol              []ygot.Annotation                             `path:"state/@dst-protocol|@dst-protocol" ygotAnnotation:"true"`
	ImportPolicy              []string                                      `path:"state/import-policy" shadow-path:"config/import-policy" module:"openconfig-network-instance"`
	ΛImportPolicy             []ygot.Annotation                             `path:"state/@import-policy" ygotAnnotation:"true"`
	SrcProtocol               E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"state/src-protocol|src-protocol" shadow-path:"config/src-protocol" module:"openconfig-network-instance"`
	ΛSrcProtocol              []ygot.Annotation                             `path:"state/@src-protocol|@src-protocol" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_TableConnection implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_TableConnection) IsYANGGoStruct() {}

// GetAddressFamily retrieves the value of the leaf AddressFamily from the NetworkInstance_TableConnection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AddressFamily is set, it can safely use t.GetAddressFamily()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AddressFamily == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_TableConnection) GetAddressFamily() E_OpenconfigTypes_ADDRESS_FAMILY {
	if t == nil || t.AddressFamily == 0 {
		return 0
	}
	return t.AddressFamily
}

// GetDefaultImportPolicy retrieves the value of the leaf DefaultImportPolicy from the NetworkInstance_TableConnection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DefaultImportPolicy is set, it can safely use t.GetDefaultImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DefaultImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_TableConnection) GetDefaultImportPolicy() E_OpenconfigRoutingPolicy_DefaultPolicyType {
	if t == nil || t.DefaultImportPolicy == 0 {
		return OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE
	}
	return t.DefaultImportPolicy
}

// GetDisableMetricPropagation retrieves the value of the leaf DisableMetricPropagation from the NetworkInstance_TableConnection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DisableMetricPropagation is set, it can safely use t.GetDisableMetricPropagation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DisableMetricPropagation == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_TableConnection) GetDisableMetricPropagation() bool {
	if t == nil || t.DisableMetricPropagation == nil {
		return false
	}
	return *t.DisableMetricPropagation
}

// GetDstProtocol retrieves the value of the leaf DstProtocol from the NetworkInstance_TableConnection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DstProtocol is set, it can safely use t.GetDstProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DstProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_TableConnection) GetDstProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.DstProtocol == 0 {
		return 0
	}
	return t.DstProtocol
}

// GetImportPolicy retrieves the value of the leaf ImportPolicy from the NetworkInstance_TableConnection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ImportPolicy is set, it can safely use t.GetImportPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ImportPolicy == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_TableConnection) GetImportPolicy() []string {
	if t == nil || t.ImportPolicy == nil {
		return nil
	}
	return t.ImportPolicy
}

// GetSrcProtocol retrieves the value of the leaf SrcProtocol from the NetworkInstance_TableConnection
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SrcProtocol is set, it can safely use t.GetSrcProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SrcProtocol == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_TableConnection) GetSrcProtocol() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.SrcProtocol == 0 {
		return 0
	}
	return t.SrcProtocol
}

// ΛListKeyMap returns the keys of the NetworkInstance_TableConnection struct, which is a YANG list entry.
func (t *NetworkInstance_TableConnection) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"address-family": t.AddressFamily,
		"dst-protocol":   t.DstProtocol,
		"src-protocol":   t.SrcProtocol,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_TableConnection) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_TableConnection"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_TableConnection) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// NetworkInstance_Vlan represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan YANG schema element.
type NetworkInstance_Vlan struct {
	ΛMetadata []ygot.Annotation              `path:"@" ygotAnnotation:"true"`
	Member    []*NetworkInstance_Vlan_Member `path:"members/member" module:"openconfig-network-instance"`
	ΛMember   []ygot.Annotation              `path:"members/@member" ygotAnnotation:"true"`
	Name      *string                        `path:"state/name" shadow-path:"config/name" module:"openconfig-network-instance"`
	ΛName     []ygot.Annotation              `path:"state/@name" ygotAnnotation:"true"`
	Status    E_Vlan_Status                  `path:"state/status" shadow-path:"config/status" module:"openconfig-network-instance"`
	ΛStatus   []ygot.Annotation              `path:"state/@status" ygotAnnotation:"true"`
	VlanId    *uint16                        `path:"state/vlan-id|vlan-id" shadow-path:"config/vlan-id" module:"openconfig-network-instance"`
	ΛVlanId   []ygot.Annotation              `path:"state/@vlan-id|@vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Vlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Vlan) IsYANGGoStruct() {}

// GetName retrieves the value of the leaf Name from the NetworkInstance_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Vlan) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetStatus retrieves the value of the leaf Status from the NetworkInstance_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Status is set, it can safely use t.GetStatus()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Status == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Vlan) GetStatus() E_Vlan_Status {
	if t == nil || t.Status == 0 {
		return Vlan_Status_ACTIVE
	}
	return t.Status
}

// GetVlanId retrieves the value of the leaf VlanId from the NetworkInstance_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanId is set, it can safely use t.GetVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanId == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Vlan) GetVlanId() uint16 {
	if t == nil || t.VlanId == nil {
		return 0
	}
	return *t.VlanId
}

// ΛListKeyMap returns the keys of the NetworkInstance_Vlan struct, which is a YANG list entry.
func (t *NetworkInstance_Vlan) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VlanId == nil {
		return nil, fmt.Errorf("nil value for key VlanId")
	}

	return map[string]interface{}{
		"vlan-id": *t.VlanId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Vlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Vlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Vlan) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// NetworkInstance_Vlan_Member represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan/members/member YANG schema element.
type NetworkInstance_Vlan_Member struct {
	ΛMetadata  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface  *string           `path:"state/interface" module:"openconfig-network-instance"`
	ΛInterface []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that NetworkInstance_Vlan_Member implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*NetworkInstance_Vlan_Member) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the NetworkInstance_Vlan_Member
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *NetworkInstance_Vlan_Member) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *NetworkInstance_Vlan_Member) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["NetworkInstance_Vlan_Member"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *NetworkInstance_Vlan_Member) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpticalAmplifier represents the /openconfig-optical-amplifier/optical-amplifier YANG schema element.
type OpticalAmplifier struct {
	ΛMetadata           []ygot.Annotation                               `path:"@" ygotAnnotation:"true"`
	Amplifier           map[string]*OpticalAmplifier_Amplifier          `path:"amplifiers/amplifier" module:"openconfig-optical-amplifier"`
	ΛAmplifier          []ygot.Annotation                               `path:"amplifiers/@amplifier" ygotAnnotation:"true"`
	SupervisoryChannel  map[string]*OpticalAmplifier_SupervisoryChannel `path:"supervisory-channels/supervisory-channel" module:"openconfig-optical-amplifier"`
	ΛSupervisoryChannel []ygot.Annotation                               `path:"supervisory-channels/@supervisory-channel" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier) IsYANGGoStruct() {}

// NewAmplifier creates a new entry in the Amplifier list of the
// OpticalAmplifier struct. The keys of the list are populated from the input
// arguments.
func (t *OpticalAmplifier) NewAmplifier(Name string) (*OpticalAmplifier_Amplifier, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Amplifier == nil {
		t.Amplifier = make(map[string]*OpticalAmplifier_Amplifier)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Amplifier[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Amplifier", key)
	}

	t.Amplifier[key] = &OpticalAmplifier_Amplifier{
		Name: &Name,
	}

	return t.Amplifier[key], nil
}

// RenameAmplifier renames an entry in the list Amplifier within
// the OpticalAmplifier struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *OpticalAmplifier) RenameAmplifier(oldK, newK string) error {
	if _, ok := t.Amplifier[newK]; ok {
		return fmt.Errorf("key %v already exists in Amplifier", newK)
	}

	e, ok := t.Amplifier[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Amplifier", oldK)
	}
	e.Name = &newK

	t.Amplifier[newK] = e
	delete(t.Amplifier, oldK)
	return nil
}

// GetOrCreateAmplifier retrieves the value with the specified keys from
// the receiver OpticalAmplifier. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *OpticalAmplifier) GetOrCreateAmplifier(Name string) *OpticalAmplifier_Amplifier {

	key := Name

	if v, ok := t.Amplifier[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAmplifier(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAmplifier got unexpected error: %v", err))
	}
	return v
}

// GetAmplifier retrieves the value with the specified key from
// the Amplifier map field of OpticalAmplifier. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *OpticalAmplifier) GetAmplifier(Name string) *OpticalAmplifier_Amplifier {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Amplifier[key]; ok {
		return lm
	}
	return nil
}

// AppendAmplifier appends the supplied OpticalAmplifier_Amplifier struct to the
// list Amplifier of OpticalAmplifier. If the key value(s) specified in
// the supplied OpticalAmplifier_Amplifier already exist in the list, an error is
// returned.
func (t *OpticalAmplifier) AppendAmplifier(v *OpticalAmplifier_Amplifier) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Amplifier == nil {
		t.Amplifier = make(map[string]*OpticalAmplifier_Amplifier)
	}

	if _, ok := t.Amplifier[key]; ok {
		return fmt.Errorf("duplicate key for list Amplifier %v", key)
	}

	t.Amplifier[key] = v
	return nil
}

// NewSupervisoryChannel creates a new entry in the SupervisoryChannel list of the
// OpticalAmplifier struct. The keys of the list are populated from the input
// arguments.
func (t *OpticalAmplifier) NewSupervisoryChannel(Interface string) (*OpticalAmplifier_SupervisoryChannel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SupervisoryChannel == nil {
		t.SupervisoryChannel = make(map[string]*OpticalAmplifier_SupervisoryChannel)
	}

	key := Interface

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SupervisoryChannel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SupervisoryChannel", key)
	}

	t.SupervisoryChannel[key] = &OpticalAmplifier_SupervisoryChannel{
		Interface: &Interface,
	}

	return t.SupervisoryChannel[key], nil
}

// RenameSupervisoryChannel renames an entry in the list SupervisoryChannel within
// the OpticalAmplifier struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *OpticalAmplifier) RenameSupervisoryChannel(oldK, newK string) error {
	if _, ok := t.SupervisoryChannel[newK]; ok {
		return fmt.Errorf("key %v already exists in SupervisoryChannel", newK)
	}

	e, ok := t.SupervisoryChannel[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in SupervisoryChannel", oldK)
	}
	e.Interface = &newK

	t.SupervisoryChannel[newK] = e
	delete(t.SupervisoryChannel, oldK)
	return nil
}

// GetOrCreateSupervisoryChannel retrieves the value with the specified keys from
// the receiver OpticalAmplifier. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *OpticalAmplifier) GetOrCreateSupervisoryChannel(Interface string) *OpticalAmplifier_SupervisoryChannel {

	key := Interface

	if v, ok := t.SupervisoryChannel[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSupervisoryChannel(Interface)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSupervisoryChannel got unexpected error: %v", err))
	}
	return v
}

// GetSupervisoryChannel retrieves the value with the specified key from
// the SupervisoryChannel map field of OpticalAmplifier. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *OpticalAmplifier) GetSupervisoryChannel(Interface string) *OpticalAmplifier_SupervisoryChannel {

	if t == nil {
		return nil
	}

	key := Interface

	if lm, ok := t.SupervisoryChannel[key]; ok {
		return lm
	}
	return nil
}

// AppendSupervisoryChannel appends the supplied OpticalAmplifier_SupervisoryChannel struct to the
// list SupervisoryChannel of OpticalAmplifier. If the key value(s) specified in
// the supplied OpticalAmplifier_SupervisoryChannel already exist in the list, an error is
// returned.
func (t *OpticalAmplifier) AppendSupervisoryChannel(v *OpticalAmplifier_SupervisoryChannel) error {
	if v.Interface == nil {
		return fmt.Errorf("invalid nil key received for Interface")
	}

	key := *v.Interface

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SupervisoryChannel == nil {
		t.SupervisoryChannel = make(map[string]*OpticalAmplifier_SupervisoryChannel)
	}

	if _, ok := t.SupervisoryChannel[key]; ok {
		return fmt.Errorf("duplicate key for list SupervisoryChannel %v", key)
	}

	t.SupervisoryChannel[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpticalAmplifier_Amplifier represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier YANG schema element.
type OpticalAmplifier_Amplifier struct {
	ΛMetadata          []ygot.Annotation                                   `path:"@" ygotAnnotation:"true"`
	ActualGain         *OpticalAmplifier_Amplifier_ActualGain              `path:"state/actual-gain" module:"openconfig-optical-amplifier"`
	ΛActualGain        []ygot.Annotation                                   `path:"state/@actual-gain" ygotAnnotation:"true"`
	ActualGainTilt     *OpticalAmplifier_Amplifier_ActualGainTilt          `path:"state/actual-gain-tilt" module:"openconfig-optical-amplifier"`
	ΛActualGainTilt    []ygot.Annotation                                   `path:"state/@actual-gain-tilt" ygotAnnotation:"true"`
	AmpMode            E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE `path:"state/amp-mode" shadow-path:"config/amp-mode" module:"openconfig-optical-amplifier"`
	ΛAmpMode           []ygot.Annotation                                   `path:"state/@amp-mode" ygotAnnotation:"true"`
	Component          *string                                             `path:"state/component" module:"openconfig-optical-amplifier"`
	ΛComponent         []ygot.Annotation                                   `path:"state/@component" ygotAnnotation:"true"`
	EgressPort         *string                                             `path:"state/egress-port" module:"openconfig-optical-amplifier"`
	ΛEgressPort        []ygot.Annotation                                   `path:"state/@egress-port" ygotAnnotation:"true"`
	Enabled            *bool                                               `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-optical-amplifier"`
	ΛEnabled           []ygot.Annotation                                   `path:"state/@enabled" ygotAnnotation:"true"`
	FiberTypeProfile   E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE     `path:"state/fiber-type-profile" shadow-path:"config/fiber-type-profile" module:"openconfig-optical-amplifier"`
	ΛFiberTypeProfile  []ygot.Annotation                                   `path:"state/@fiber-type-profile" ygotAnnotation:"true"`
	GainRange          E_OpenconfigOpticalAmplifier_GAIN_RANGE             `path:"state/gain-range" shadow-path:"config/gain-range" module:"openconfig-optical-amplifier"`
	ΛGainRange         []ygot.Annotation                                   `path:"state/@gain-range" ygotAnnotation:"true"`
	IngressPort        *string                                             `path:"state/ingress-port" module:"openconfig-optical-amplifier"`
	ΛIngressPort       []ygot.Annotation                                   `path:"state/@ingress-port" ygotAnnotation:"true"`
	InputPowerCBand    *OpticalAmplifier_Amplifier_InputPowerCBand         `path:"state/input-power-c-band" module:"openconfig-optical-amplifier"`
	ΛInputPowerCBand   []ygot.Annotation                                   `path:"state/@input-power-c-band" ygotAnnotation:"true"`
	InputPowerLBand    *OpticalAmplifier_Amplifier_InputPowerLBand         `path:"state/input-power-l-band" module:"openconfig-optical-amplifier"`
	ΛInputPowerLBand   []ygot.Annotation                                   `path:"state/@input-power-l-band" ygotAnnotation:"true"`
	InputPowerTotal    *OpticalAmplifier_Amplifier_InputPowerTotal         `path:"state/input-power-total" module:"openconfig-optical-amplifier"`
	ΛInputPowerTotal   []ygot.Annotation                                   `path:"state/@input-power-total" ygotAnnotation:"true"`
	LaserBiasCurrent   *OpticalAmplifier_Amplifier_LaserBiasCurrent        `path:"state/laser-bias-current" module:"openconfig-optical-amplifier"`
	ΛLaserBiasCurrent  []ygot.Annotation                                   `path:"state/@laser-bias-current" ygotAnnotation:"true"`
	MaxGain            *float64                                            `path:"state/max-gain" shadow-path:"config/max-gain" module:"openconfig-optical-amplifier"`
	ΛMaxGain           []ygot.Annotation                                   `path:"state/@max-gain" ygotAnnotation:"true"`
	MaxOutputPower     *float64                                            `path:"state/max-output-power" shadow-path:"config/max-output-power" module:"openconfig-optical-amplifier"`
	ΛMaxOutputPower    []ygot.Annotation                                   `path:"state/@max-output-power" ygotAnnotation:"true"`
	MinGain            *float64                                            `path:"state/min-gain" shadow-path:"config/min-gain" module:"openconfig-optical-amplifier"`
	ΛMinGain           []ygot.Annotation                                   `path:"state/@min-gain" ygotAnnotation:"true"`
	Name               *string                                             `path:"state/name|name" shadow-path:"config/name" module:"openconfig-optical-amplifier"`
	ΛName              []ygot.Annotation                                   `path:"state/@name|@name" ygotAnnotation:"true"`
	OpticalReturnLoss  *OpticalAmplifier_Amplifier_OpticalReturnLoss       `path:"state/optical-return-loss" module:"openconfig-optical-amplifier"`
	ΛOpticalReturnLoss []ygot.Annotation                                   `path:"state/@optical-return-loss" ygotAnnotation:"true"`
	OutputPowerCBand   *OpticalAmplifier_Amplifier_OutputPowerCBand        `path:"state/output-power-c-band" module:"openconfig-optical-amplifier"`
	ΛOutputPowerCBand  []ygot.Annotation                                   `path:"state/@output-power-c-band" ygotAnnotation:"true"`
	OutputPowerLBand   *OpticalAmplifier_Amplifier_OutputPowerLBand        `path:"state/output-power-l-band" module:"openconfig-optical-amplifier"`
	ΛOutputPowerLBand  []ygot.Annotation                                   `path:"state/@output-power-l-band" ygotAnnotation:"true"`
	OutputPowerTotal   *OpticalAmplifier_Amplifier_OutputPowerTotal        `path:"state/output-power-total" module:"openconfig-optical-amplifier"`
	ΛOutputPowerTotal  []ygot.Annotation                                   `path:"state/@output-power-total" ygotAnnotation:"true"`
	TargetGain         *float64                                            `path:"state/target-gain" shadow-path:"config/target-gain" module:"openconfig-optical-amplifier"`
	ΛTargetGain        []ygot.Annotation                                   `path:"state/@target-gain" ygotAnnotation:"true"`
	TargetGainTilt     *float64                                            `path:"state/target-gain-tilt" shadow-path:"config/target-gain-tilt" module:"openconfig-optical-amplifier"`
	ΛTargetGainTilt    []ygot.Annotation                                   `path:"state/@target-gain-tilt" ygotAnnotation:"true"`
	TargetOutputPower  *float64                                            `path:"state/target-output-power" shadow-path:"config/target-output-power" module:"openconfig-optical-amplifier"`
	ΛTargetOutputPower []ygot.Annotation                                   `path:"state/@target-output-power" ygotAnnotation:"true"`
	Type               E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE `path:"state/type" shadow-path:"config/type" module:"openconfig-optical-amplifier"`
	ΛType              []ygot.Annotation                                   `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier) IsYANGGoStruct() {}

// GetOrCreateActualGain retrieves the value of the ActualGain field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateActualGain() *OpticalAmplifier_Amplifier_ActualGain {
	if t.ActualGain != nil {
		return t.ActualGain
	}
	t.ActualGain = &OpticalAmplifier_Amplifier_ActualGain{}
	return t.ActualGain
}

// GetOrCreateActualGainTilt retrieves the value of the ActualGainTilt field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateActualGainTilt() *OpticalAmplifier_Amplifier_ActualGainTilt {
	if t.ActualGainTilt != nil {
		return t.ActualGainTilt
	}
	t.ActualGainTilt = &OpticalAmplifier_Amplifier_ActualGainTilt{}
	return t.ActualGainTilt
}

// GetOrCreateInputPowerCBand retrieves the value of the InputPowerCBand field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateInputPowerCBand() *OpticalAmplifier_Amplifier_InputPowerCBand {
	if t.InputPowerCBand != nil {
		return t.InputPowerCBand
	}
	t.InputPowerCBand = &OpticalAmplifier_Amplifier_InputPowerCBand{}
	return t.InputPowerCBand
}

// GetOrCreateInputPowerLBand retrieves the value of the InputPowerLBand field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateInputPowerLBand() *OpticalAmplifier_Amplifier_InputPowerLBand {
	if t.InputPowerLBand != nil {
		return t.InputPowerLBand
	}
	t.InputPowerLBand = &OpticalAmplifier_Amplifier_InputPowerLBand{}
	return t.InputPowerLBand
}

// GetOrCreateInputPowerTotal retrieves the value of the InputPowerTotal field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateInputPowerTotal() *OpticalAmplifier_Amplifier_InputPowerTotal {
	if t.InputPowerTotal != nil {
		return t.InputPowerTotal
	}
	t.InputPowerTotal = &OpticalAmplifier_Amplifier_InputPowerTotal{}
	return t.InputPowerTotal
}

// GetOrCreateLaserBiasCurrent retrieves the value of the LaserBiasCurrent field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateLaserBiasCurrent() *OpticalAmplifier_Amplifier_LaserBiasCurrent {
	if t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	t.LaserBiasCurrent = &OpticalAmplifier_Amplifier_LaserBiasCurrent{}
	return t.LaserBiasCurrent
}

// GetOrCreateOpticalReturnLoss retrieves the value of the OpticalReturnLoss field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateOpticalReturnLoss() *OpticalAmplifier_Amplifier_OpticalReturnLoss {
	if t.OpticalReturnLoss != nil {
		return t.OpticalReturnLoss
	}
	t.OpticalReturnLoss = &OpticalAmplifier_Amplifier_OpticalReturnLoss{}
	return t.OpticalReturnLoss
}

// GetOrCreateOutputPowerCBand retrieves the value of the OutputPowerCBand field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateOutputPowerCBand() *OpticalAmplifier_Amplifier_OutputPowerCBand {
	if t.OutputPowerCBand != nil {
		return t.OutputPowerCBand
	}
	t.OutputPowerCBand = &OpticalAmplifier_Amplifier_OutputPowerCBand{}
	return t.OutputPowerCBand
}

// GetOrCreateOutputPowerLBand retrieves the value of the OutputPowerLBand field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateOutputPowerLBand() *OpticalAmplifier_Amplifier_OutputPowerLBand {
	if t.OutputPowerLBand != nil {
		return t.OutputPowerLBand
	}
	t.OutputPowerLBand = &OpticalAmplifier_Amplifier_OutputPowerLBand{}
	return t.OutputPowerLBand
}

// GetOrCreateOutputPowerTotal retrieves the value of the OutputPowerTotal field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_Amplifier) GetOrCreateOutputPowerTotal() *OpticalAmplifier_Amplifier_OutputPowerTotal {
	if t.OutputPowerTotal != nil {
		return t.OutputPowerTotal
	}
	t.OutputPowerTotal = &OpticalAmplifier_Amplifier_OutputPowerTotal{}
	return t.OutputPowerTotal
}

// GetActualGain returns the value of the ActualGain struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field ActualGain is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetActualGain() *OpticalAmplifier_Amplifier_ActualGain {
	if t != nil && t.ActualGain != nil {
		return t.ActualGain
	}
	return nil
}

// GetActualGainTilt returns the value of the ActualGainTilt struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field ActualGainTilt is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetActualGainTilt() *OpticalAmplifier_Amplifier_ActualGainTilt {
	if t != nil && t.ActualGainTilt != nil {
		return t.ActualGainTilt
	}
	return nil
}

// GetInputPowerCBand returns the value of the InputPowerCBand struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field InputPowerCBand is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetInputPowerCBand() *OpticalAmplifier_Amplifier_InputPowerCBand {
	if t != nil && t.InputPowerCBand != nil {
		return t.InputPowerCBand
	}
	return nil
}

// GetInputPowerLBand returns the value of the InputPowerLBand struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field InputPowerLBand is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetInputPowerLBand() *OpticalAmplifier_Amplifier_InputPowerLBand {
	if t != nil && t.InputPowerLBand != nil {
		return t.InputPowerLBand
	}
	return nil
}

// GetInputPowerTotal returns the value of the InputPowerTotal struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field InputPowerTotal is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetInputPowerTotal() *OpticalAmplifier_Amplifier_InputPowerTotal {
	if t != nil && t.InputPowerTotal != nil {
		return t.InputPowerTotal
	}
	return nil
}

// GetLaserBiasCurrent returns the value of the LaserBiasCurrent struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field LaserBiasCurrent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetLaserBiasCurrent() *OpticalAmplifier_Amplifier_LaserBiasCurrent {
	if t != nil && t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	return nil
}

// GetOpticalReturnLoss returns the value of the OpticalReturnLoss struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field OpticalReturnLoss is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetOpticalReturnLoss() *OpticalAmplifier_Amplifier_OpticalReturnLoss {
	if t != nil && t.OpticalReturnLoss != nil {
		return t.OpticalReturnLoss
	}
	return nil
}

// GetOutputPowerCBand returns the value of the OutputPowerCBand struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field OutputPowerCBand is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetOutputPowerCBand() *OpticalAmplifier_Amplifier_OutputPowerCBand {
	if t != nil && t.OutputPowerCBand != nil {
		return t.OutputPowerCBand
	}
	return nil
}

// GetOutputPowerLBand returns the value of the OutputPowerLBand struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field OutputPowerLBand is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetOutputPowerLBand() *OpticalAmplifier_Amplifier_OutputPowerLBand {
	if t != nil && t.OutputPowerLBand != nil {
		return t.OutputPowerLBand
	}
	return nil
}

// GetOutputPowerTotal returns the value of the OutputPowerTotal struct pointer
// from OpticalAmplifier_Amplifier. If the receiver or the field OutputPowerTotal is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_Amplifier) GetOutputPowerTotal() *OpticalAmplifier_Amplifier_OutputPowerTotal {
	if t != nil && t.OutputPowerTotal != nil {
		return t.OutputPowerTotal
	}
	return nil
}

// GetAmpMode retrieves the value of the leaf AmpMode from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AmpMode is set, it can safely use t.GetAmpMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AmpMode == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetAmpMode() E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE {
	if t == nil || t.AmpMode == 0 {
		return 0
	}
	return t.AmpMode
}

// GetComponent retrieves the value of the leaf Component from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Component is set, it can safely use t.GetComponent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Component == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetComponent() string {
	if t == nil || t.Component == nil {
		return ""
	}
	return *t.Component
}

// GetEgressPort retrieves the value of the leaf EgressPort from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EgressPort is set, it can safely use t.GetEgressPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EgressPort == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetEgressPort() string {
	if t == nil || t.EgressPort == nil {
		return ""
	}
	return *t.EgressPort
}

// GetEnabled retrieves the value of the leaf Enabled from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetFiberTypeProfile retrieves the value of the leaf FiberTypeProfile from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FiberTypeProfile is set, it can safely use t.GetFiberTypeProfile()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FiberTypeProfile == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetFiberTypeProfile() E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE {
	if t == nil || t.FiberTypeProfile == 0 {
		return 0
	}
	return t.FiberTypeProfile
}

// GetGainRange retrieves the value of the leaf GainRange from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if GainRange is set, it can safely use t.GetGainRange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.GainRange == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetGainRange() E_OpenconfigOpticalAmplifier_GAIN_RANGE {
	if t == nil || t.GainRange == 0 {
		return 0
	}
	return t.GainRange
}

// GetIngressPort retrieves the value of the leaf IngressPort from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IngressPort is set, it can safely use t.GetIngressPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IngressPort == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetIngressPort() string {
	if t == nil || t.IngressPort == nil {
		return ""
	}
	return *t.IngressPort
}

// GetMaxGain retrieves the value of the leaf MaxGain from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxGain is set, it can safely use t.GetMaxGain()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxGain == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetMaxGain() float64 {
	if t == nil || t.MaxGain == nil {
		return 0.0
	}
	return *t.MaxGain
}

// GetMaxOutputPower retrieves the value of the leaf MaxOutputPower from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxOutputPower is set, it can safely use t.GetMaxOutputPower()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxOutputPower == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetMaxOutputPower() float64 {
	if t == nil || t.MaxOutputPower == nil {
		return 0.0
	}
	return *t.MaxOutputPower
}

// GetMinGain retrieves the value of the leaf MinGain from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinGain is set, it can safely use t.GetMinGain()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinGain == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetMinGain() float64 {
	if t == nil || t.MinGain == nil {
		return 0.0
	}
	return *t.MinGain
}

// GetName retrieves the value of the leaf Name from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetTargetGain retrieves the value of the leaf TargetGain from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetGain is set, it can safely use t.GetTargetGain()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetGain == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetTargetGain() float64 {
	if t == nil || t.TargetGain == nil {
		return 0.0
	}
	return *t.TargetGain
}

// GetTargetGainTilt retrieves the value of the leaf TargetGainTilt from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetGainTilt is set, it can safely use t.GetTargetGainTilt()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetGainTilt == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetTargetGainTilt() float64 {
	if t == nil || t.TargetGainTilt == nil {
		return 0.0
	}
	return *t.TargetGainTilt
}

// GetTargetOutputPower retrieves the value of the leaf TargetOutputPower from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TargetOutputPower is set, it can safely use t.GetTargetOutputPower()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TargetOutputPower == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetTargetOutputPower() float64 {
	if t == nil || t.TargetOutputPower == nil {
		return 0.0
	}
	return *t.TargetOutputPower
}

// GetType retrieves the value of the leaf Type from the OpticalAmplifier_Amplifier
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier) GetType() E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the OpticalAmplifier_Amplifier struct, which is a YANG list entry.
func (t *OpticalAmplifier_Amplifier) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpticalAmplifier_Amplifier_ActualGain represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/actual-gain YANG schema element.
type OpticalAmplifier_Amplifier_ActualGain struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_ActualGain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_ActualGain) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_ActualGain
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGain) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_ActualGain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_ActualGain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_ActualGain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_ActualGainTilt represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/actual-gain-tilt YANG schema element.
type OpticalAmplifier_Amplifier_ActualGainTilt struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_ActualGainTilt implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_ActualGainTilt) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_ActualGainTilt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_ActualGainTilt"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_ActualGainTilt) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_InputPowerCBand represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/input-power-c-band YANG schema element.
type OpticalAmplifier_Amplifier_InputPowerCBand struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_InputPowerCBand implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_InputPowerCBand) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_InputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_InputPowerCBand"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_InputPowerCBand) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_InputPowerLBand represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/input-power-l-band YANG schema element.
type OpticalAmplifier_Amplifier_InputPowerLBand struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_InputPowerLBand implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_InputPowerLBand) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_InputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_InputPowerLBand"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_InputPowerLBand) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_InputPowerTotal represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/input-power-total YANG schema element.
type OpticalAmplifier_Amplifier_InputPowerTotal struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_InputPowerTotal implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_InputPowerTotal) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_InputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_InputPowerTotal"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_InputPowerTotal) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_LaserBiasCurrent represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/laser-bias-current YANG schema element.
type OpticalAmplifier_Amplifier_LaserBiasCurrent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_LaserBiasCurrent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_LaserBiasCurrent) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_LaserBiasCurrent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_LaserBiasCurrent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_OpticalReturnLoss represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/optical-return-loss YANG schema element.
type OpticalAmplifier_Amplifier_OpticalReturnLoss struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_OpticalReturnLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_OpticalReturnLoss) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_OpticalReturnLoss
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_OpticalReturnLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_OpticalReturnLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_OutputPowerCBand represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/output-power-c-band YANG schema element.
type OpticalAmplifier_Amplifier_OutputPowerCBand struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_OutputPowerCBand implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_OutputPowerCBand) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_OutputPowerCBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_OutputPowerCBand"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_OutputPowerCBand) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_OutputPowerLBand represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/output-power-l-band YANG schema element.
type OpticalAmplifier_Amplifier_OutputPowerLBand struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_OutputPowerLBand implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_OutputPowerLBand) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_OutputPowerLBand
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_OutputPowerLBand"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_OutputPowerLBand) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_Amplifier_OutputPowerTotal represents the /openconfig-optical-amplifier/optical-amplifier/amplifiers/amplifier/state/output-power-total YANG schema element.
type OpticalAmplifier_Amplifier_OutputPowerTotal struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_Amplifier_OutputPowerTotal implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_Amplifier_OutputPowerTotal) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_Amplifier_OutputPowerTotal
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_Amplifier_OutputPowerTotal"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_Amplifier_OutputPowerTotal) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_SupervisoryChannel represents the /openconfig-optical-amplifier/optical-amplifier/supervisory-channels/supervisory-channel YANG schema element.
type OpticalAmplifier_SupervisoryChannel struct {
	ΛMetadata         []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	InputPower        *OpticalAmplifier_SupervisoryChannel_InputPower       `path:"state/input-power" module:"openconfig-optical-amplifier"`
	ΛInputPower       []ygot.Annotation                                     `path:"state/@input-power" ygotAnnotation:"true"`
	Interface         *string                                               `path:"state/interface|interface" shadow-path:"config/interface" module:"openconfig-optical-amplifier"`
	ΛInterface        []ygot.Annotation                                     `path:"state/@interface|@interface" ygotAnnotation:"true"`
	LaserBiasCurrent  *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent `path:"state/laser-bias-current" module:"openconfig-optical-amplifier"`
	ΛLaserBiasCurrent []ygot.Annotation                                     `path:"state/@laser-bias-current" ygotAnnotation:"true"`
	OutputFrequency   *uint64                                               `path:"state/output-frequency" module:"openconfig-optical-amplifier"`
	ΛOutputFrequency  []ygot.Annotation                                     `path:"state/@output-frequency" ygotAnnotation:"true"`
	OutputPower       *OpticalAmplifier_SupervisoryChannel_OutputPower      `path:"state/output-power" module:"openconfig-optical-amplifier"`
	ΛOutputPower      []ygot.Annotation                                     `path:"state/@output-power" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_SupervisoryChannel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_SupervisoryChannel) IsYANGGoStruct() {}

// GetOrCreateInputPower retrieves the value of the InputPower field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_SupervisoryChannel) GetOrCreateInputPower() *OpticalAmplifier_SupervisoryChannel_InputPower {
	if t.InputPower != nil {
		return t.InputPower
	}
	t.InputPower = &OpticalAmplifier_SupervisoryChannel_InputPower{}
	return t.InputPower
}

// GetOrCreateLaserBiasCurrent retrieves the value of the LaserBiasCurrent field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_SupervisoryChannel) GetOrCreateLaserBiasCurrent() *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent {
	if t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	t.LaserBiasCurrent = &OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent{}
	return t.LaserBiasCurrent
}

// GetOrCreateOutputPower retrieves the value of the OutputPower field
// or returns the existing field if it already exists.
func (t *OpticalAmplifier_SupervisoryChannel) GetOrCreateOutputPower() *OpticalAmplifier_SupervisoryChannel_OutputPower {
	if t.OutputPower != nil {
		return t.OutputPower
	}
	t.OutputPower = &OpticalAmplifier_SupervisoryChannel_OutputPower{}
	return t.OutputPower
}

// GetInputPower returns the value of the InputPower struct pointer
// from OpticalAmplifier_SupervisoryChannel. If the receiver or the field InputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_SupervisoryChannel) GetInputPower() *OpticalAmplifier_SupervisoryChannel_InputPower {
	if t != nil && t.InputPower != nil {
		return t.InputPower
	}
	return nil
}

// GetLaserBiasCurrent returns the value of the LaserBiasCurrent struct pointer
// from OpticalAmplifier_SupervisoryChannel. If the receiver or the field LaserBiasCurrent is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_SupervisoryChannel) GetLaserBiasCurrent() *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent {
	if t != nil && t.LaserBiasCurrent != nil {
		return t.LaserBiasCurrent
	}
	return nil
}

// GetOutputPower returns the value of the OutputPower struct pointer
// from OpticalAmplifier_SupervisoryChannel. If the receiver or the field OutputPower is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *OpticalAmplifier_SupervisoryChannel) GetOutputPower() *OpticalAmplifier_SupervisoryChannel_OutputPower {
	if t != nil && t.OutputPower != nil {
		return t.OutputPower
	}
	return nil
}

// GetInterface retrieves the value of the leaf Interface from the OpticalAmplifier_SupervisoryChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetOutputFrequency retrieves the value of the leaf OutputFrequency from the OpticalAmplifier_SupervisoryChannel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutputFrequency is set, it can safely use t.GetOutputFrequency()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutputFrequency == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel) GetOutputFrequency() uint64 {
	if t == nil || t.OutputFrequency == nil {
		return 0
	}
	return *t.OutputFrequency
}

// ΛListKeyMap returns the keys of the OpticalAmplifier_SupervisoryChannel struct, which is a YANG list entry.
func (t *OpticalAmplifier_SupervisoryChannel) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Interface == nil {
		return nil, fmt.Errorf("nil value for key Interface")
	}

	return map[string]interface{}{
		"interface": *t.Interface,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_SupervisoryChannel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_SupervisoryChannel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_SupervisoryChannel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_SupervisoryChannel_InputPower represents the /openconfig-optical-amplifier/optical-amplifier/supervisory-channels/supervisory-channel/state/input-power YANG schema element.
type OpticalAmplifier_SupervisoryChannel_InputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_SupervisoryChannel_InputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_SupervisoryChannel_InputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_SupervisoryChannel_InputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_SupervisoryChannel_InputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_SupervisoryChannel_InputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent represents the /openconfig-optical-amplifier/optical-amplifier/supervisory-channels/supervisory-channel/state/laser-bias-current YANG schema element.
type OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_SupervisoryChannel_LaserBiasCurrent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpticalAmplifier_SupervisoryChannel_OutputPower represents the /openconfig-optical-amplifier/optical-amplifier/supervisory-channels/supervisory-channel/state/output-power YANG schema element.
type OpticalAmplifier_SupervisoryChannel_OutputPower struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-optical-amplifier"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-optical-amplifier"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-optical-amplifier"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-optical-amplifier"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-optical-amplifier"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-optical-amplifier"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-optical-amplifier"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that OpticalAmplifier_SupervisoryChannel_OutputPower implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpticalAmplifier_SupervisoryChannel_OutputPower) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the OpticalAmplifier_SupervisoryChannel_OutputPower
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpticalAmplifier_SupervisoryChannel_OutputPower"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpticalAmplifier_SupervisoryChannel_OutputPower) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent represents the /openconfig-relay-agent/relay-agent YANG schema element.
type RelayAgent struct {
	ΛMetadata []ygot.Annotation  `path:"@" ygotAnnotation:"true"`
	Dhcp      *RelayAgent_Dhcp   `path:"dhcp" module:"openconfig-relay-agent"`
	ΛDhcp     []ygot.Annotation  `path:"@dhcp" ygotAnnotation:"true"`
	Dhcpv6    *RelayAgent_Dhcpv6 `path:"dhcpv6" module:"openconfig-relay-agent"`
	ΛDhcpv6   []ygot.Annotation  `path:"@dhcpv6" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent) IsYANGGoStruct() {}

// GetOrCreateDhcp retrieves the value of the Dhcp field
// or returns the existing field if it already exists.
func (t *RelayAgent) GetOrCreateDhcp() *RelayAgent_Dhcp {
	if t.Dhcp != nil {
		return t.Dhcp
	}
	t.Dhcp = &RelayAgent_Dhcp{}
	return t.Dhcp
}

// GetOrCreateDhcpv6 retrieves the value of the Dhcpv6 field
// or returns the existing field if it already exists.
func (t *RelayAgent) GetOrCreateDhcpv6() *RelayAgent_Dhcpv6 {
	if t.Dhcpv6 != nil {
		return t.Dhcpv6
	}
	t.Dhcpv6 = &RelayAgent_Dhcpv6{}
	return t.Dhcpv6
}

// GetDhcp returns the value of the Dhcp struct pointer
// from RelayAgent. If the receiver or the field Dhcp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent) GetDhcp() *RelayAgent_Dhcp {
	if t != nil && t.Dhcp != nil {
		return t.Dhcp
	}
	return nil
}

// GetDhcpv6 returns the value of the Dhcpv6 struct pointer
// from RelayAgent. If the receiver or the field Dhcpv6 is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent) GetDhcpv6() *RelayAgent_Dhcpv6 {
	if t != nil && t.Dhcpv6 != nil {
		return t.Dhcpv6
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RelayAgent_Dhcp represents the /openconfig-relay-agent/relay-agent/dhcp YANG schema element.
type RelayAgent_Dhcp struct {
	ΛMetadata               []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	AgentInformationOption  *RelayAgent_Dhcp_AgentInformationOption `path:"agent-information-option" module:"openconfig-relay-agent"`
	ΛAgentInformationOption []ygot.Annotation                       `path:"@agent-information-option" ygotAnnotation:"true"`
	EnableRelayAgent        *bool                                   `path:"state/enable-relay-agent" shadow-path:"config/enable-relay-agent" module:"openconfig-relay-agent"`
	ΛEnableRelayAgent       []ygot.Annotation                       `path:"state/@enable-relay-agent" ygotAnnotation:"true"`
	Interface               map[string]*RelayAgent_Dhcp_Interface   `path:"interfaces/interface" module:"openconfig-relay-agent"`
	ΛInterface              []ygot.Annotation                       `path:"interfaces/@interface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcp) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// RelayAgent_Dhcp struct. The keys of the list are populated from the input
// arguments.
func (t *RelayAgent_Dhcp) NewInterface(Id string) (*RelayAgent_Dhcp_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*RelayAgent_Dhcp_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &RelayAgent_Dhcp_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the RelayAgent_Dhcp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RelayAgent_Dhcp) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Id = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver RelayAgent_Dhcp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RelayAgent_Dhcp) GetOrCreateInterface(Id string) *RelayAgent_Dhcp_Interface {

	key := Id

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of RelayAgent_Dhcp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RelayAgent_Dhcp) GetInterface(Id string) *RelayAgent_Dhcp_Interface {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied RelayAgent_Dhcp_Interface struct to the
// list Interface of RelayAgent_Dhcp. If the key value(s) specified in
// the supplied RelayAgent_Dhcp_Interface already exist in the list, an error is
// returned.
func (t *RelayAgent_Dhcp) AppendInterface(v *RelayAgent_Dhcp_Interface) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*RelayAgent_Dhcp_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetOrCreateAgentInformationOption retrieves the value of the AgentInformationOption field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcp) GetOrCreateAgentInformationOption() *RelayAgent_Dhcp_AgentInformationOption {
	if t.AgentInformationOption != nil {
		return t.AgentInformationOption
	}
	t.AgentInformationOption = &RelayAgent_Dhcp_AgentInformationOption{}
	return t.AgentInformationOption
}

// GetAgentInformationOption returns the value of the AgentInformationOption struct pointer
// from RelayAgent_Dhcp. If the receiver or the field AgentInformationOption is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcp) GetAgentInformationOption() *RelayAgent_Dhcp_AgentInformationOption {
	if t != nil && t.AgentInformationOption != nil {
		return t.AgentInformationOption
	}
	return nil
}

// GetEnableRelayAgent retrieves the value of the leaf EnableRelayAgent from the RelayAgent_Dhcp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableRelayAgent is set, it can safely use t.GetEnableRelayAgent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableRelayAgent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp) GetEnableRelayAgent() bool {
	if t == nil || t.EnableRelayAgent == nil {
		return false
	}
	return *t.EnableRelayAgent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RelayAgent_Dhcp_AgentInformationOption represents the /openconfig-relay-agent/relay-agent/dhcp/agent-information-option YANG schema element.
type RelayAgent_Dhcp_AgentInformationOption struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enable    *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-relay-agent"`
	ΛEnable   []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcp_AgentInformationOption implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcp_AgentInformationOption) IsYANGGoStruct() {}

// GetEnable retrieves the value of the leaf Enable from the RelayAgent_Dhcp_AgentInformationOption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_AgentInformationOption) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcp_AgentInformationOption) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcp_AgentInformationOption"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcp_AgentInformationOption) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcp_Interface represents the /openconfig-relay-agent/relay-agent/dhcp/interfaces/interface YANG schema element.
type RelayAgent_Dhcp_Interface struct {
	ΛMetadata               []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	AgentInformationOption  *RelayAgent_Dhcp_Interface_AgentInformationOption `path:"agent-information-option" module:"openconfig-relay-agent"`
	ΛAgentInformationOption []ygot.Annotation                                 `path:"@agent-information-option" ygotAnnotation:"true"`
	Counters                *RelayAgent_Dhcp_Interface_Counters               `path:"state/counters" module:"openconfig-relay-agent"`
	ΛCounters               []ygot.Annotation                                 `path:"state/@counters" ygotAnnotation:"true"`
	Enable                  *bool                                             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-relay-agent"`
	ΛEnable                 []ygot.Annotation                                 `path:"state/@enable" ygotAnnotation:"true"`
	HelperAddress           []string                                          `path:"state/helper-address" shadow-path:"config/helper-address" module:"openconfig-relay-agent"`
	ΛHelperAddress          []ygot.Annotation                                 `path:"state/@helper-address" ygotAnnotation:"true"`
	Id                      *string                                           `path:"state/id|id" shadow-path:"config/id" module:"openconfig-relay-agent"`
	ΛId                     []ygot.Annotation                                 `path:"state/@id|@id" ygotAnnotation:"true"`
	InterfaceRef            *RelayAgent_Dhcp_Interface_InterfaceRef           `path:"interface-ref" module:"openconfig-relay-agent"`
	ΛInterfaceRef           []ygot.Annotation                                 `path:"@interface-ref" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcp_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcp_Interface) IsYANGGoStruct() {}

// GetOrCreateAgentInformationOption retrieves the value of the AgentInformationOption field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcp_Interface) GetOrCreateAgentInformationOption() *RelayAgent_Dhcp_Interface_AgentInformationOption {
	if t.AgentInformationOption != nil {
		return t.AgentInformationOption
	}
	t.AgentInformationOption = &RelayAgent_Dhcp_Interface_AgentInformationOption{}
	return t.AgentInformationOption
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcp_Interface) GetOrCreateCounters() *RelayAgent_Dhcp_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &RelayAgent_Dhcp_Interface_Counters{}
	return t.Counters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcp_Interface) GetOrCreateInterfaceRef() *RelayAgent_Dhcp_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &RelayAgent_Dhcp_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetAgentInformationOption returns the value of the AgentInformationOption struct pointer
// from RelayAgent_Dhcp_Interface. If the receiver or the field AgentInformationOption is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcp_Interface) GetAgentInformationOption() *RelayAgent_Dhcp_Interface_AgentInformationOption {
	if t != nil && t.AgentInformationOption != nil {
		return t.AgentInformationOption
	}
	return nil
}

// GetCounters returns the value of the Counters struct pointer
// from RelayAgent_Dhcp_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcp_Interface) GetCounters() *RelayAgent_Dhcp_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from RelayAgent_Dhcp_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcp_Interface) GetInterfaceRef() *RelayAgent_Dhcp_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetEnable retrieves the value of the leaf Enable from the RelayAgent_Dhcp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// GetHelperAddress retrieves the value of the leaf HelperAddress from the RelayAgent_Dhcp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperAddress is set, it can safely use t.GetHelperAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperAddress == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface) GetHelperAddress() []string {
	if t == nil || t.HelperAddress == nil {
		return nil
	}
	return t.HelperAddress
}

// GetId retrieves the value of the leaf Id from the RelayAgent_Dhcp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// ΛListKeyMap returns the keys of the RelayAgent_Dhcp_Interface struct, which is a YANG list entry.
func (t *RelayAgent_Dhcp_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcp_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcp_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcp_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RelayAgent_Dhcp_Interface_AgentInformationOption represents the /openconfig-relay-agent/relay-agent/dhcp/interfaces/interface/agent-information-option YANG schema element.
type RelayAgent_Dhcp_Interface_AgentInformationOption struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	CircuitId      *string           `path:"state/circuit-id" shadow-path:"config/circuit-id" module:"openconfig-relay-agent"`
	ΛCircuitId     []ygot.Annotation `path:"state/@circuit-id" ygotAnnotation:"true"`
	Enable         *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-relay-agent"`
	ΛEnable        []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
	RemoteId       *string           `path:"state/remote-id" shadow-path:"config/remote-id" module:"openconfig-relay-agent"`
	ΛRemoteId      []ygot.Annotation `path:"state/@remote-id" ygotAnnotation:"true"`
	SentCircuitId  *string           `path:"state/sent-circuit-id" module:"openconfig-relay-agent"`
	ΛSentCircuitId []ygot.Annotation `path:"state/@sent-circuit-id" ygotAnnotation:"true"`
	SentRemoteId   *string           `path:"state/sent-remote-id" module:"openconfig-relay-agent"`
	ΛSentRemoteId  []ygot.Annotation `path:"state/@sent-remote-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcp_Interface_AgentInformationOption implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcp_Interface_AgentInformationOption) IsYANGGoStruct() {}

// GetCircuitId retrieves the value of the leaf CircuitId from the RelayAgent_Dhcp_Interface_AgentInformationOption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CircuitId is set, it can safely use t.GetCircuitId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CircuitId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) GetCircuitId() string {
	if t == nil || t.CircuitId == nil {
		return ""
	}
	return *t.CircuitId
}

// GetEnable retrieves the value of the leaf Enable from the RelayAgent_Dhcp_Interface_AgentInformationOption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// GetRemoteId retrieves the value of the leaf RemoteId from the RelayAgent_Dhcp_Interface_AgentInformationOption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteId is set, it can safely use t.GetRemoteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) GetRemoteId() string {
	if t == nil || t.RemoteId == nil {
		return ""
	}
	return *t.RemoteId
}

// GetSentCircuitId retrieves the value of the leaf SentCircuitId from the RelayAgent_Dhcp_Interface_AgentInformationOption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SentCircuitId is set, it can safely use t.GetSentCircuitId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SentCircuitId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) GetSentCircuitId() string {
	if t == nil || t.SentCircuitId == nil {
		return ""
	}
	return *t.SentCircuitId
}

// GetSentRemoteId retrieves the value of the leaf SentRemoteId from the RelayAgent_Dhcp_Interface_AgentInformationOption
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SentRemoteId is set, it can safely use t.GetSentRemoteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SentRemoteId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) GetSentRemoteId() string {
	if t == nil || t.SentRemoteId == nil {
		return ""
	}
	return *t.SentRemoteId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcp_Interface_AgentInformationOption"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcp_Interface_AgentInformationOption) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcp_Interface_Counters represents the /openconfig-relay-agent/relay-agent/dhcp/interfaces/interface/state/counters YANG schema element.
type RelayAgent_Dhcp_Interface_Counters struct {
	ΛMetadata             []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BootreplySent         *uint64           `path:"bootreply-sent" module:"openconfig-relay-agent"`
	ΛBootreplySent        []ygot.Annotation `path:"@bootreply-sent" ygotAnnotation:"true"`
	BootrequestReceived   *uint64           `path:"bootrequest-received" module:"openconfig-relay-agent"`
	ΛBootrequestReceived  []ygot.Annotation `path:"@bootrequest-received" ygotAnnotation:"true"`
	BootrequestSent       *uint64           `path:"bootrequest-sent" module:"openconfig-relay-agent"`
	ΛBootrequestSent      []ygot.Annotation `path:"@bootrequest-sent" ygotAnnotation:"true"`
	DhcpAckSent           *uint64           `path:"dhcp-ack-sent" module:"openconfig-relay-agent"`
	ΛDhcpAckSent          []ygot.Annotation `path:"@dhcp-ack-sent" ygotAnnotation:"true"`
	DhcpDeclineReceived   *uint64           `path:"dhcp-decline-received" module:"openconfig-relay-agent"`
	ΛDhcpDeclineReceived  []ygot.Annotation `path:"@dhcp-decline-received" ygotAnnotation:"true"`
	DhcpDiscoverReceived  *uint64           `path:"dhcp-discover-received" module:"openconfig-relay-agent"`
	ΛDhcpDiscoverReceived []ygot.Annotation `path:"@dhcp-discover-received" ygotAnnotation:"true"`
	DhcpInformReceived    *uint64           `path:"dhcp-inform-received" module:"openconfig-relay-agent"`
	ΛDhcpInformReceived   []ygot.Annotation `path:"@dhcp-inform-received" ygotAnnotation:"true"`
	DhcpNackSent          *uint64           `path:"dhcp-nack-sent" module:"openconfig-relay-agent"`
	ΛDhcpNackSent         []ygot.Annotation `path:"@dhcp-nack-sent" ygotAnnotation:"true"`
	DhcpOfferSent         *uint64           `path:"dhcp-offer-sent" module:"openconfig-relay-agent"`
	ΛDhcpOfferSent        []ygot.Annotation `path:"@dhcp-offer-sent" ygotAnnotation:"true"`
	DhcpReleaseReceived   *uint64           `path:"dhcp-release-received" module:"openconfig-relay-agent"`
	ΛDhcpReleaseReceived  []ygot.Annotation `path:"@dhcp-release-received" ygotAnnotation:"true"`
	DhcpRequestReceived   *uint64           `path:"dhcp-request-received" module:"openconfig-relay-agent"`
	ΛDhcpRequestReceived  []ygot.Annotation `path:"@dhcp-request-received" ygotAnnotation:"true"`
	InvalidOpcode         *uint64           `path:"invalid-opcode" module:"openconfig-relay-agent"`
	ΛInvalidOpcode        []ygot.Annotation `path:"@invalid-opcode" ygotAnnotation:"true"`
	InvalidOptions        *uint64           `path:"invalid-options" module:"openconfig-relay-agent"`
	ΛInvalidOptions       []ygot.Annotation `path:"@invalid-options" ygotAnnotation:"true"`
	TotalDropped          *uint64           `path:"total-dropped" module:"openconfig-relay-agent"`
	ΛTotalDropped         []ygot.Annotation `path:"@total-dropped" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcp_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcp_Interface_Counters) IsYANGGoStruct() {}

// GetBootreplySent retrieves the value of the leaf BootreplySent from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BootreplySent is set, it can safely use t.GetBootreplySent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BootreplySent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetBootreplySent() uint64 {
	if t == nil || t.BootreplySent == nil {
		return 0
	}
	return *t.BootreplySent
}

// GetBootrequestReceived retrieves the value of the leaf BootrequestReceived from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BootrequestReceived is set, it can safely use t.GetBootrequestReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BootrequestReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetBootrequestReceived() uint64 {
	if t == nil || t.BootrequestReceived == nil {
		return 0
	}
	return *t.BootrequestReceived
}

// GetBootrequestSent retrieves the value of the leaf BootrequestSent from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BootrequestSent is set, it can safely use t.GetBootrequestSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BootrequestSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetBootrequestSent() uint64 {
	if t == nil || t.BootrequestSent == nil {
		return 0
	}
	return *t.BootrequestSent
}

// GetDhcpAckSent retrieves the value of the leaf DhcpAckSent from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpAckSent is set, it can safely use t.GetDhcpAckSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpAckSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpAckSent() uint64 {
	if t == nil || t.DhcpAckSent == nil {
		return 0
	}
	return *t.DhcpAckSent
}

// GetDhcpDeclineReceived retrieves the value of the leaf DhcpDeclineReceived from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpDeclineReceived is set, it can safely use t.GetDhcpDeclineReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpDeclineReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpDeclineReceived() uint64 {
	if t == nil || t.DhcpDeclineReceived == nil {
		return 0
	}
	return *t.DhcpDeclineReceived
}

// GetDhcpDiscoverReceived retrieves the value of the leaf DhcpDiscoverReceived from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpDiscoverReceived is set, it can safely use t.GetDhcpDiscoverReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpDiscoverReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpDiscoverReceived() uint64 {
	if t == nil || t.DhcpDiscoverReceived == nil {
		return 0
	}
	return *t.DhcpDiscoverReceived
}

// GetDhcpInformReceived retrieves the value of the leaf DhcpInformReceived from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpInformReceived is set, it can safely use t.GetDhcpInformReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpInformReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpInformReceived() uint64 {
	if t == nil || t.DhcpInformReceived == nil {
		return 0
	}
	return *t.DhcpInformReceived
}

// GetDhcpNackSent retrieves the value of the leaf DhcpNackSent from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpNackSent is set, it can safely use t.GetDhcpNackSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpNackSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpNackSent() uint64 {
	if t == nil || t.DhcpNackSent == nil {
		return 0
	}
	return *t.DhcpNackSent
}

// GetDhcpOfferSent retrieves the value of the leaf DhcpOfferSent from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpOfferSent is set, it can safely use t.GetDhcpOfferSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpOfferSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpOfferSent() uint64 {
	if t == nil || t.DhcpOfferSent == nil {
		return 0
	}
	return *t.DhcpOfferSent
}

// GetDhcpReleaseReceived retrieves the value of the leaf DhcpReleaseReceived from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpReleaseReceived is set, it can safely use t.GetDhcpReleaseReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpReleaseReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpReleaseReceived() uint64 {
	if t == nil || t.DhcpReleaseReceived == nil {
		return 0
	}
	return *t.DhcpReleaseReceived
}

// GetDhcpRequestReceived retrieves the value of the leaf DhcpRequestReceived from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DhcpRequestReceived is set, it can safely use t.GetDhcpRequestReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DhcpRequestReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetDhcpRequestReceived() uint64 {
	if t == nil || t.DhcpRequestReceived == nil {
		return 0
	}
	return *t.DhcpRequestReceived
}

// GetInvalidOpcode retrieves the value of the leaf InvalidOpcode from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidOpcode is set, it can safely use t.GetInvalidOpcode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidOpcode == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetInvalidOpcode() uint64 {
	if t == nil || t.InvalidOpcode == nil {
		return 0
	}
	return *t.InvalidOpcode
}

// GetInvalidOptions retrieves the value of the leaf InvalidOptions from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidOptions is set, it can safely use t.GetInvalidOptions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidOptions == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetInvalidOptions() uint64 {
	if t == nil || t.InvalidOptions == nil {
		return 0
	}
	return *t.InvalidOptions
}

// GetTotalDropped retrieves the value of the leaf TotalDropped from the RelayAgent_Dhcp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalDropped is set, it can safely use t.GetTotalDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalDropped == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_Counters) GetTotalDropped() uint64 {
	if t == nil || t.TotalDropped == nil {
		return 0
	}
	return *t.TotalDropped
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcp_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcp_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcp_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcp_Interface_InterfaceRef represents the /openconfig-relay-agent/relay-agent/dhcp/interfaces/interface/interface-ref YANG schema element.
type RelayAgent_Dhcp_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-relay-agent"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-relay-agent"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcp_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcp_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the RelayAgent_Dhcp_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the RelayAgent_Dhcp_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcp_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcp_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcp_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcp_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcpv6 represents the /openconfig-relay-agent/relay-agent/dhcpv6 YANG schema element.
type RelayAgent_Dhcpv6 struct {
	ΛMetadata         []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	EnableRelayAgent  *bool                                   `path:"state/enable-relay-agent" shadow-path:"config/enable-relay-agent" module:"openconfig-relay-agent"`
	ΛEnableRelayAgent []ygot.Annotation                       `path:"state/@enable-relay-agent" ygotAnnotation:"true"`
	Interface         map[string]*RelayAgent_Dhcpv6_Interface `path:"interfaces/interface" module:"openconfig-relay-agent"`
	ΛInterface        []ygot.Annotation                       `path:"interfaces/@interface" ygotAnnotation:"true"`
	Options           *RelayAgent_Dhcpv6_Options              `path:"options" module:"openconfig-relay-agent"`
	ΛOptions          []ygot.Annotation                       `path:"@options" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcpv6) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// RelayAgent_Dhcpv6 struct. The keys of the list are populated from the input
// arguments.
func (t *RelayAgent_Dhcpv6) NewInterface(Id string) (*RelayAgent_Dhcpv6_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*RelayAgent_Dhcpv6_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &RelayAgent_Dhcpv6_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the RelayAgent_Dhcpv6 struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RelayAgent_Dhcpv6) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Id = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver RelayAgent_Dhcpv6. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RelayAgent_Dhcpv6) GetOrCreateInterface(Id string) *RelayAgent_Dhcpv6_Interface {

	key := Id

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of RelayAgent_Dhcpv6. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RelayAgent_Dhcpv6) GetInterface(Id string) *RelayAgent_Dhcpv6_Interface {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied RelayAgent_Dhcpv6_Interface struct to the
// list Interface of RelayAgent_Dhcpv6. If the key value(s) specified in
// the supplied RelayAgent_Dhcpv6_Interface already exist in the list, an error is
// returned.
func (t *RelayAgent_Dhcpv6) AppendInterface(v *RelayAgent_Dhcpv6_Interface) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*RelayAgent_Dhcpv6_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetOrCreateOptions retrieves the value of the Options field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcpv6) GetOrCreateOptions() *RelayAgent_Dhcpv6_Options {
	if t.Options != nil {
		return t.Options
	}
	t.Options = &RelayAgent_Dhcpv6_Options{}
	return t.Options
}

// GetOptions returns the value of the Options struct pointer
// from RelayAgent_Dhcpv6. If the receiver or the field Options is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcpv6) GetOptions() *RelayAgent_Dhcpv6_Options {
	if t != nil && t.Options != nil {
		return t.Options
	}
	return nil
}

// GetEnableRelayAgent retrieves the value of the leaf EnableRelayAgent from the RelayAgent_Dhcpv6
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableRelayAgent is set, it can safely use t.GetEnableRelayAgent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableRelayAgent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6) GetEnableRelayAgent() bool {
	if t == nil || t.EnableRelayAgent == nil {
		return false
	}
	return *t.EnableRelayAgent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcpv6) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RelayAgent_Dhcpv6_Interface represents the /openconfig-relay-agent/relay-agent/dhcpv6/interfaces/interface YANG schema element.
type RelayAgent_Dhcpv6_Interface struct {
	ΛMetadata      []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Counters       *RelayAgent_Dhcpv6_Interface_Counters     `path:"state/counters" module:"openconfig-relay-agent"`
	ΛCounters      []ygot.Annotation                         `path:"state/@counters" ygotAnnotation:"true"`
	Enable         *bool                                     `path:"state/enable" shadow-path:"config/enable" module:"openconfig-relay-agent"`
	ΛEnable        []ygot.Annotation                         `path:"state/@enable" ygotAnnotation:"true"`
	HelperAddress  []string                                  `path:"state/helper-address" shadow-path:"config/helper-address" module:"openconfig-relay-agent"`
	ΛHelperAddress []ygot.Annotation                         `path:"state/@helper-address" ygotAnnotation:"true"`
	Id             *string                                   `path:"state/id|id" shadow-path:"config/id" module:"openconfig-relay-agent"`
	ΛId            []ygot.Annotation                         `path:"state/@id|@id" ygotAnnotation:"true"`
	InterfaceRef   *RelayAgent_Dhcpv6_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-relay-agent"`
	ΛInterfaceRef  []ygot.Annotation                         `path:"@interface-ref" ygotAnnotation:"true"`
	Options        *RelayAgent_Dhcpv6_Interface_Options      `path:"options" module:"openconfig-relay-agent"`
	ΛOptions       []ygot.Annotation                         `path:"@options" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcpv6_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcpv6_Interface) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcpv6_Interface) GetOrCreateCounters() *RelayAgent_Dhcpv6_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &RelayAgent_Dhcpv6_Interface_Counters{}
	return t.Counters
}

// GetOrCreateInterfaceRef retrieves the value of the InterfaceRef field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcpv6_Interface) GetOrCreateInterfaceRef() *RelayAgent_Dhcpv6_Interface_InterfaceRef {
	if t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	t.InterfaceRef = &RelayAgent_Dhcpv6_Interface_InterfaceRef{}
	return t.InterfaceRef
}

// GetOrCreateOptions retrieves the value of the Options field
// or returns the existing field if it already exists.
func (t *RelayAgent_Dhcpv6_Interface) GetOrCreateOptions() *RelayAgent_Dhcpv6_Interface_Options {
	if t.Options != nil {
		return t.Options
	}
	t.Options = &RelayAgent_Dhcpv6_Interface_Options{}
	return t.Options
}

// GetCounters returns the value of the Counters struct pointer
// from RelayAgent_Dhcpv6_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcpv6_Interface) GetCounters() *RelayAgent_Dhcpv6_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetInterfaceRef returns the value of the InterfaceRef struct pointer
// from RelayAgent_Dhcpv6_Interface. If the receiver or the field InterfaceRef is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcpv6_Interface) GetInterfaceRef() *RelayAgent_Dhcpv6_Interface_InterfaceRef {
	if t != nil && t.InterfaceRef != nil {
		return t.InterfaceRef
	}
	return nil
}

// GetOptions returns the value of the Options struct pointer
// from RelayAgent_Dhcpv6_Interface. If the receiver or the field Options is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RelayAgent_Dhcpv6_Interface) GetOptions() *RelayAgent_Dhcpv6_Interface_Options {
	if t != nil && t.Options != nil {
		return t.Options
	}
	return nil
}

// GetEnable retrieves the value of the leaf Enable from the RelayAgent_Dhcpv6_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// GetHelperAddress retrieves the value of the leaf HelperAddress from the RelayAgent_Dhcpv6_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelperAddress is set, it can safely use t.GetHelperAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelperAddress == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface) GetHelperAddress() []string {
	if t == nil || t.HelperAddress == nil {
		return nil
	}
	return t.HelperAddress
}

// GetId retrieves the value of the leaf Id from the RelayAgent_Dhcpv6_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// ΛListKeyMap returns the keys of the RelayAgent_Dhcpv6_Interface struct, which is a YANG list entry.
func (t *RelayAgent_Dhcpv6_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcpv6_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcpv6_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcpv6_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RelayAgent_Dhcpv6_Interface_Counters represents the /openconfig-relay-agent/relay-agent/dhcpv6/interfaces/interface/state/counters YANG schema element.
type RelayAgent_Dhcpv6_Interface_Counters struct {
	ΛMetadata                  []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Dhcpv6AdverstiseSent       *uint64           `path:"dhcpv6-adverstise-sent" module:"openconfig-relay-agent"`
	ΛDhcpv6AdverstiseSent      []ygot.Annotation `path:"@dhcpv6-adverstise-sent" ygotAnnotation:"true"`
	Dhcpv6ConfirmReceived      *uint64           `path:"dhcpv6-confirm-received" module:"openconfig-relay-agent"`
	ΛDhcpv6ConfirmReceived     []ygot.Annotation `path:"@dhcpv6-confirm-received" ygotAnnotation:"true"`
	Dhcpv6DeclineReceived      *uint64           `path:"dhcpv6-decline-received" module:"openconfig-relay-agent"`
	ΛDhcpv6DeclineReceived     []ygot.Annotation `path:"@dhcpv6-decline-received" ygotAnnotation:"true"`
	Dhcpv6InfoRequestReceived  *uint64           `path:"dhcpv6-info-request-received" module:"openconfig-relay-agent"`
	ΛDhcpv6InfoRequestReceived []ygot.Annotation `path:"@dhcpv6-info-request-received" ygotAnnotation:"true"`
	Dhcpv6RebindReceived       *uint64           `path:"dhcpv6-rebind-received" module:"openconfig-relay-agent"`
	ΛDhcpv6RebindReceived      []ygot.Annotation `path:"@dhcpv6-rebind-received" ygotAnnotation:"true"`
	Dhcpv6ReconfigureSent      *uint64           `path:"dhcpv6-reconfigure-sent" module:"openconfig-relay-agent"`
	ΛDhcpv6ReconfigureSent     []ygot.Annotation `path:"@dhcpv6-reconfigure-sent" ygotAnnotation:"true"`
	Dhcpv6RelayForwSent        *uint64           `path:"dhcpv6-relay-forw-sent" module:"openconfig-relay-agent"`
	ΛDhcpv6RelayForwSent       []ygot.Annotation `path:"@dhcpv6-relay-forw-sent" ygotAnnotation:"true"`
	Dhcpv6RelayReplyReceived   *uint64           `path:"dhcpv6-relay-reply-received" module:"openconfig-relay-agent"`
	ΛDhcpv6RelayReplyReceived  []ygot.Annotation `path:"@dhcpv6-relay-reply-received" ygotAnnotation:"true"`
	Dhcpv6ReleaseReceived      *uint64           `path:"dhcpv6-release-received" module:"openconfig-relay-agent"`
	ΛDhcpv6ReleaseReceived     []ygot.Annotation `path:"@dhcpv6-release-received" ygotAnnotation:"true"`
	Dhcpv6ReplySent            *uint64           `path:"dhcpv6-reply-sent" module:"openconfig-relay-agent"`
	ΛDhcpv6ReplySent           []ygot.Annotation `path:"@dhcpv6-reply-sent" ygotAnnotation:"true"`
	Dhcpv6RequestReceived      *uint64           `path:"dhcpv6-request-received" module:"openconfig-relay-agent"`
	ΛDhcpv6RequestReceived     []ygot.Annotation `path:"@dhcpv6-request-received" ygotAnnotation:"true"`
	Dhcpv6SolicitReceived      *uint64           `path:"dhcpv6-solicit-received" module:"openconfig-relay-agent"`
	ΛDhcpv6SolicitReceived     []ygot.Annotation `path:"@dhcpv6-solicit-received" ygotAnnotation:"true"`
	InvalidOpcode              *uint64           `path:"invalid-opcode" module:"openconfig-relay-agent"`
	ΛInvalidOpcode             []ygot.Annotation `path:"@invalid-opcode" ygotAnnotation:"true"`
	InvalidOptions             *uint64           `path:"invalid-options" module:"openconfig-relay-agent"`
	ΛInvalidOptions            []ygot.Annotation `path:"@invalid-options" ygotAnnotation:"true"`
	TotalDropped               *uint64           `path:"total-dropped" module:"openconfig-relay-agent"`
	ΛTotalDropped              []ygot.Annotation `path:"@total-dropped" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcpv6_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcpv6_Interface_Counters) IsYANGGoStruct() {}

// GetDhcpv6AdverstiseSent retrieves the value of the leaf Dhcpv6AdverstiseSent from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6AdverstiseSent is set, it can safely use t.GetDhcpv6AdverstiseSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6AdverstiseSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6AdverstiseSent() uint64 {
	if t == nil || t.Dhcpv6AdverstiseSent == nil {
		return 0
	}
	return *t.Dhcpv6AdverstiseSent
}

// GetDhcpv6ConfirmReceived retrieves the value of the leaf Dhcpv6ConfirmReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6ConfirmReceived is set, it can safely use t.GetDhcpv6ConfirmReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6ConfirmReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6ConfirmReceived() uint64 {
	if t == nil || t.Dhcpv6ConfirmReceived == nil {
		return 0
	}
	return *t.Dhcpv6ConfirmReceived
}

// GetDhcpv6DeclineReceived retrieves the value of the leaf Dhcpv6DeclineReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6DeclineReceived is set, it can safely use t.GetDhcpv6DeclineReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6DeclineReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6DeclineReceived() uint64 {
	if t == nil || t.Dhcpv6DeclineReceived == nil {
		return 0
	}
	return *t.Dhcpv6DeclineReceived
}

// GetDhcpv6InfoRequestReceived retrieves the value of the leaf Dhcpv6InfoRequestReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6InfoRequestReceived is set, it can safely use t.GetDhcpv6InfoRequestReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6InfoRequestReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6InfoRequestReceived() uint64 {
	if t == nil || t.Dhcpv6InfoRequestReceived == nil {
		return 0
	}
	return *t.Dhcpv6InfoRequestReceived
}

// GetDhcpv6RebindReceived retrieves the value of the leaf Dhcpv6RebindReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6RebindReceived is set, it can safely use t.GetDhcpv6RebindReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6RebindReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6RebindReceived() uint64 {
	if t == nil || t.Dhcpv6RebindReceived == nil {
		return 0
	}
	return *t.Dhcpv6RebindReceived
}

// GetDhcpv6ReconfigureSent retrieves the value of the leaf Dhcpv6ReconfigureSent from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6ReconfigureSent is set, it can safely use t.GetDhcpv6ReconfigureSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6ReconfigureSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6ReconfigureSent() uint64 {
	if t == nil || t.Dhcpv6ReconfigureSent == nil {
		return 0
	}
	return *t.Dhcpv6ReconfigureSent
}

// GetDhcpv6RelayForwSent retrieves the value of the leaf Dhcpv6RelayForwSent from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6RelayForwSent is set, it can safely use t.GetDhcpv6RelayForwSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6RelayForwSent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6RelayForwSent() uint64 {
	if t == nil || t.Dhcpv6RelayForwSent == nil {
		return 0
	}
	return *t.Dhcpv6RelayForwSent
}

// GetDhcpv6RelayReplyReceived retrieves the value of the leaf Dhcpv6RelayReplyReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6RelayReplyReceived is set, it can safely use t.GetDhcpv6RelayReplyReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6RelayReplyReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6RelayReplyReceived() uint64 {
	if t == nil || t.Dhcpv6RelayReplyReceived == nil {
		return 0
	}
	return *t.Dhcpv6RelayReplyReceived
}

// GetDhcpv6ReleaseReceived retrieves the value of the leaf Dhcpv6ReleaseReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6ReleaseReceived is set, it can safely use t.GetDhcpv6ReleaseReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6ReleaseReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6ReleaseReceived() uint64 {
	if t == nil || t.Dhcpv6ReleaseReceived == nil {
		return 0
	}
	return *t.Dhcpv6ReleaseReceived
}

// GetDhcpv6ReplySent retrieves the value of the leaf Dhcpv6ReplySent from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6ReplySent is set, it can safely use t.GetDhcpv6ReplySent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6ReplySent == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6ReplySent() uint64 {
	if t == nil || t.Dhcpv6ReplySent == nil {
		return 0
	}
	return *t.Dhcpv6ReplySent
}

// GetDhcpv6RequestReceived retrieves the value of the leaf Dhcpv6RequestReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6RequestReceived is set, it can safely use t.GetDhcpv6RequestReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6RequestReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6RequestReceived() uint64 {
	if t == nil || t.Dhcpv6RequestReceived == nil {
		return 0
	}
	return *t.Dhcpv6RequestReceived
}

// GetDhcpv6SolicitReceived retrieves the value of the leaf Dhcpv6SolicitReceived from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Dhcpv6SolicitReceived is set, it can safely use t.GetDhcpv6SolicitReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Dhcpv6SolicitReceived == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetDhcpv6SolicitReceived() uint64 {
	if t == nil || t.Dhcpv6SolicitReceived == nil {
		return 0
	}
	return *t.Dhcpv6SolicitReceived
}

// GetInvalidOpcode retrieves the value of the leaf InvalidOpcode from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidOpcode is set, it can safely use t.GetInvalidOpcode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidOpcode == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetInvalidOpcode() uint64 {
	if t == nil || t.InvalidOpcode == nil {
		return 0
	}
	return *t.InvalidOpcode
}

// GetInvalidOptions retrieves the value of the leaf InvalidOptions from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InvalidOptions is set, it can safely use t.GetInvalidOptions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InvalidOptions == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetInvalidOptions() uint64 {
	if t == nil || t.InvalidOptions == nil {
		return 0
	}
	return *t.InvalidOptions
}

// GetTotalDropped retrieves the value of the leaf TotalDropped from the RelayAgent_Dhcpv6_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TotalDropped is set, it can safely use t.GetTotalDropped()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TotalDropped == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Counters) GetTotalDropped() uint64 {
	if t == nil || t.TotalDropped == nil {
		return 0
	}
	return *t.TotalDropped
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcpv6_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcpv6_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcpv6_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcpv6_Interface_InterfaceRef represents the /openconfig-relay-agent/relay-agent/dhcpv6/interfaces/interface/interface-ref YANG schema element.
type RelayAgent_Dhcpv6_Interface_InterfaceRef struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-relay-agent"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-relay-agent"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcpv6_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcpv6_Interface_InterfaceRef) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the RelayAgent_Dhcpv6_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_InterfaceRef) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the RelayAgent_Dhcpv6_Interface_InterfaceRef
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_InterfaceRef) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcpv6_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcpv6_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcpv6_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcpv6_Interface_Options represents the /openconfig-relay-agent/relay-agent/dhcpv6/interfaces/interface/options YANG schema element.
type RelayAgent_Dhcpv6_Interface_Options struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EnableInterfaceId  *bool             `path:"state/enable-interface-id" shadow-path:"config/enable-interface-id" module:"openconfig-relay-agent"`
	ΛEnableInterfaceId []ygot.Annotation `path:"state/@enable-interface-id" ygotAnnotation:"true"`
	EnableRemoteId     *bool             `path:"state/enable-remote-id" shadow-path:"config/enable-remote-id" module:"openconfig-relay-agent"`
	ΛEnableRemoteId    []ygot.Annotation `path:"state/@enable-remote-id" ygotAnnotation:"true"`
	InterfaceId        *string           `path:"state/interface-id" shadow-path:"config/interface-id" module:"openconfig-relay-agent"`
	ΛInterfaceId       []ygot.Annotation `path:"state/@interface-id" ygotAnnotation:"true"`
	RemoteId           *string           `path:"state/remote-id" shadow-path:"config/remote-id" module:"openconfig-relay-agent"`
	ΛRemoteId          []ygot.Annotation `path:"state/@remote-id" ygotAnnotation:"true"`
	SentInterfaceId    *string           `path:"state/sent-interface-id" module:"openconfig-relay-agent"`
	ΛSentInterfaceId   []ygot.Annotation `path:"state/@sent-interface-id" ygotAnnotation:"true"`
	SentRemoteId       *string           `path:"state/sent-remote-id" module:"openconfig-relay-agent"`
	ΛSentRemoteId      []ygot.Annotation `path:"state/@sent-remote-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcpv6_Interface_Options implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcpv6_Interface_Options) IsYANGGoStruct() {}

// GetEnableInterfaceId retrieves the value of the leaf EnableInterfaceId from the RelayAgent_Dhcpv6_Interface_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableInterfaceId is set, it can safely use t.GetEnableInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableInterfaceId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Options) GetEnableInterfaceId() bool {
	if t == nil || t.EnableInterfaceId == nil {
		return false
	}
	return *t.EnableInterfaceId
}

// GetEnableRemoteId retrieves the value of the leaf EnableRemoteId from the RelayAgent_Dhcpv6_Interface_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableRemoteId is set, it can safely use t.GetEnableRemoteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableRemoteId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Options) GetEnableRemoteId() bool {
	if t == nil || t.EnableRemoteId == nil {
		return false
	}
	return *t.EnableRemoteId
}

// GetInterfaceId retrieves the value of the leaf InterfaceId from the RelayAgent_Dhcpv6_Interface_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InterfaceId is set, it can safely use t.GetInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InterfaceId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Options) GetInterfaceId() string {
	if t == nil || t.InterfaceId == nil {
		return ""
	}
	return *t.InterfaceId
}

// GetRemoteId retrieves the value of the leaf RemoteId from the RelayAgent_Dhcpv6_Interface_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemoteId is set, it can safely use t.GetRemoteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemoteId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Options) GetRemoteId() string {
	if t == nil || t.RemoteId == nil {
		return ""
	}
	return *t.RemoteId
}

// GetSentInterfaceId retrieves the value of the leaf SentInterfaceId from the RelayAgent_Dhcpv6_Interface_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SentInterfaceId is set, it can safely use t.GetSentInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SentInterfaceId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Options) GetSentInterfaceId() string {
	if t == nil || t.SentInterfaceId == nil {
		return ""
	}
	return *t.SentInterfaceId
}

// GetSentRemoteId retrieves the value of the leaf SentRemoteId from the RelayAgent_Dhcpv6_Interface_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SentRemoteId is set, it can safely use t.GetSentRemoteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SentRemoteId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Interface_Options) GetSentRemoteId() string {
	if t == nil || t.SentRemoteId == nil {
		return ""
	}
	return *t.SentRemoteId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcpv6_Interface_Options) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcpv6_Interface_Options"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcpv6_Interface_Options) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RelayAgent_Dhcpv6_Options represents the /openconfig-relay-agent/relay-agent/dhcpv6/options YANG schema element.
type RelayAgent_Dhcpv6_Options struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	EnableInterfaceId  *bool             `path:"state/enable-interface-id" shadow-path:"config/enable-interface-id" module:"openconfig-relay-agent"`
	ΛEnableInterfaceId []ygot.Annotation `path:"state/@enable-interface-id" ygotAnnotation:"true"`
	EnableRemoteId     *bool             `path:"state/enable-remote-id" shadow-path:"config/enable-remote-id" module:"openconfig-relay-agent"`
	ΛEnableRemoteId    []ygot.Annotation `path:"state/@enable-remote-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RelayAgent_Dhcpv6_Options implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RelayAgent_Dhcpv6_Options) IsYANGGoStruct() {}

// GetEnableInterfaceId retrieves the value of the leaf EnableInterfaceId from the RelayAgent_Dhcpv6_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableInterfaceId is set, it can safely use t.GetEnableInterfaceId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableInterfaceId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Options) GetEnableInterfaceId() bool {
	if t == nil || t.EnableInterfaceId == nil {
		return false
	}
	return *t.EnableInterfaceId
}

// GetEnableRemoteId retrieves the value of the leaf EnableRemoteId from the RelayAgent_Dhcpv6_Options
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableRemoteId is set, it can safely use t.GetEnableRemoteId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableRemoteId == nil'
// before retrieving the leaf's value.
func (t *RelayAgent_Dhcpv6_Options) GetEnableRemoteId() bool {
	if t == nil || t.EnableRemoteId == nil {
		return false
	}
	return *t.EnableRemoteId
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RelayAgent_Dhcpv6_Options) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RelayAgent_Dhcpv6_Options"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RelayAgent_Dhcpv6_Options) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RoutingPolicy represents the /openconfig-routing-policy/routing-policy YANG schema element.
type RoutingPolicy struct {
	ΛMetadata         []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	DefinedSets       *RoutingPolicy_DefinedSets                 `path:"defined-sets" module:"openconfig-routing-policy"`
	ΛDefinedSets      []ygot.Annotation                          `path:"@defined-sets" ygotAnnotation:"true"`
	PolicyDefinition  map[string]*RoutingPolicy_PolicyDefinition `path:"policy-definitions/policy-definition" module:"openconfig-routing-policy"`
	ΛPolicyDefinition []ygot.Annotation                          `path:"policy-definitions/@policy-definition" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy) IsYANGGoStruct() {}

// NewPolicyDefinition creates a new entry in the PolicyDefinition list of the
// RoutingPolicy struct. The keys of the list are populated from the input
// arguments.
func (t *RoutingPolicy) NewPolicyDefinition(Name string) (*RoutingPolicy_PolicyDefinition, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PolicyDefinition == nil {
		t.PolicyDefinition = make(map[string]*RoutingPolicy_PolicyDefinition)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PolicyDefinition[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PolicyDefinition", key)
	}

	t.PolicyDefinition[key] = &RoutingPolicy_PolicyDefinition{
		Name: &Name,
	}

	return t.PolicyDefinition[key], nil
}

// RenamePolicyDefinition renames an entry in the list PolicyDefinition within
// the RoutingPolicy struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RoutingPolicy) RenamePolicyDefinition(oldK, newK string) error {
	if _, ok := t.PolicyDefinition[newK]; ok {
		return fmt.Errorf("key %v already exists in PolicyDefinition", newK)
	}

	e, ok := t.PolicyDefinition[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PolicyDefinition", oldK)
	}
	e.Name = &newK

	t.PolicyDefinition[newK] = e
	delete(t.PolicyDefinition, oldK)
	return nil
}

// GetOrCreatePolicyDefinition retrieves the value with the specified keys from
// the receiver RoutingPolicy. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RoutingPolicy) GetOrCreatePolicyDefinition(Name string) *RoutingPolicy_PolicyDefinition {

	key := Name

	if v, ok := t.PolicyDefinition[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPolicyDefinition(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePolicyDefinition got unexpected error: %v", err))
	}
	return v
}

// GetPolicyDefinition retrieves the value with the specified key from
// the PolicyDefinition map field of RoutingPolicy. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RoutingPolicy) GetPolicyDefinition(Name string) *RoutingPolicy_PolicyDefinition {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.PolicyDefinition[key]; ok {
		return lm
	}
	return nil
}

// AppendPolicyDefinition appends the supplied RoutingPolicy_PolicyDefinition struct to the
// list PolicyDefinition of RoutingPolicy. If the key value(s) specified in
// the supplied RoutingPolicy_PolicyDefinition already exist in the list, an error is
// returned.
func (t *RoutingPolicy) AppendPolicyDefinition(v *RoutingPolicy_PolicyDefinition) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PolicyDefinition == nil {
		t.PolicyDefinition = make(map[string]*RoutingPolicy_PolicyDefinition)
	}

	if _, ok := t.PolicyDefinition[key]; ok {
		return fmt.Errorf("duplicate key for list PolicyDefinition %v", key)
	}

	t.PolicyDefinition[key] = v
	return nil
}

// GetOrCreateDefinedSets retrieves the value of the DefinedSets field
// or returns the existing field if it already exists.
func (t *RoutingPolicy) GetOrCreateDefinedSets() *RoutingPolicy_DefinedSets {
	if t.DefinedSets != nil {
		return t.DefinedSets
	}
	t.DefinedSets = &RoutingPolicy_DefinedSets{}
	return t.DefinedSets
}

// GetDefinedSets returns the value of the DefinedSets struct pointer
// from RoutingPolicy. If the receiver or the field DefinedSets is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy) GetDefinedSets() *RoutingPolicy_DefinedSets {
	if t != nil && t.DefinedSets != nil {
		return t.DefinedSets
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RoutingPolicy_DefinedSets represents the /openconfig-routing-policy/routing-policy/defined-sets YANG schema element.
type RoutingPolicy_DefinedSets struct {
	ΛMetadata    []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	NeighborSet  map[string]*RoutingPolicy_DefinedSets_NeighborSet `path:"neighbor-sets/neighbor-set" module:"openconfig-routing-policy"`
	ΛNeighborSet []ygot.Annotation                                 `path:"neighbor-sets/@neighbor-set" ygotAnnotation:"true"`
	PrefixSet    map[string]*RoutingPolicy_DefinedSets_PrefixSet   `path:"prefix-sets/prefix-set" module:"openconfig-routing-policy"`
	ΛPrefixSet   []ygot.Annotation                                 `path:"prefix-sets/@prefix-set" ygotAnnotation:"true"`
	TagSet       map[string]*RoutingPolicy_DefinedSets_TagSet      `path:"tag-sets/tag-set" module:"openconfig-routing-policy"`
	ΛTagSet      []ygot.Annotation                                 `path:"tag-sets/@tag-set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_DefinedSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_DefinedSets) IsYANGGoStruct() {}

// NewNeighborSet creates a new entry in the NeighborSet list of the
// RoutingPolicy_DefinedSets struct. The keys of the list are populated from the input
// arguments.
func (t *RoutingPolicy_DefinedSets) NewNeighborSet(Name string) (*RoutingPolicy_DefinedSets_NeighborSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NeighborSet == nil {
		t.NeighborSet = make(map[string]*RoutingPolicy_DefinedSets_NeighborSet)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NeighborSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NeighborSet", key)
	}

	t.NeighborSet[key] = &RoutingPolicy_DefinedSets_NeighborSet{
		Name: &Name,
	}

	return t.NeighborSet[key], nil
}

// RenameNeighborSet renames an entry in the list NeighborSet within
// the RoutingPolicy_DefinedSets struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RoutingPolicy_DefinedSets) RenameNeighborSet(oldK, newK string) error {
	if _, ok := t.NeighborSet[newK]; ok {
		return fmt.Errorf("key %v already exists in NeighborSet", newK)
	}

	e, ok := t.NeighborSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NeighborSet", oldK)
	}
	e.Name = &newK

	t.NeighborSet[newK] = e
	delete(t.NeighborSet, oldK)
	return nil
}

// GetOrCreateNeighborSet retrieves the value with the specified keys from
// the receiver RoutingPolicy_DefinedSets. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RoutingPolicy_DefinedSets) GetOrCreateNeighborSet(Name string) *RoutingPolicy_DefinedSets_NeighborSet {

	key := Name

	if v, ok := t.NeighborSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighborSet(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighborSet got unexpected error: %v", err))
	}
	return v
}

// GetNeighborSet retrieves the value with the specified key from
// the NeighborSet map field of RoutingPolicy_DefinedSets. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RoutingPolicy_DefinedSets) GetNeighborSet(Name string) *RoutingPolicy_DefinedSets_NeighborSet {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.NeighborSet[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighborSet appends the supplied RoutingPolicy_DefinedSets_NeighborSet struct to the
// list NeighborSet of RoutingPolicy_DefinedSets. If the key value(s) specified in
// the supplied RoutingPolicy_DefinedSets_NeighborSet already exist in the list, an error is
// returned.
func (t *RoutingPolicy_DefinedSets) AppendNeighborSet(v *RoutingPolicy_DefinedSets_NeighborSet) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NeighborSet == nil {
		t.NeighborSet = make(map[string]*RoutingPolicy_DefinedSets_NeighborSet)
	}

	if _, ok := t.NeighborSet[key]; ok {
		return fmt.Errorf("duplicate key for list NeighborSet %v", key)
	}

	t.NeighborSet[key] = v
	return nil
}

// NewPrefixSet creates a new entry in the PrefixSet list of the
// RoutingPolicy_DefinedSets struct. The keys of the list are populated from the input
// arguments.
func (t *RoutingPolicy_DefinedSets) NewPrefixSet(Name string) (*RoutingPolicy_DefinedSets_PrefixSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSet == nil {
		t.PrefixSet = make(map[string]*RoutingPolicy_DefinedSets_PrefixSet)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSet", key)
	}

	t.PrefixSet[key] = &RoutingPolicy_DefinedSets_PrefixSet{
		Name: &Name,
	}

	return t.PrefixSet[key], nil
}

// RenamePrefixSet renames an entry in the list PrefixSet within
// the RoutingPolicy_DefinedSets struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RoutingPolicy_DefinedSets) RenamePrefixSet(oldK, newK string) error {
	if _, ok := t.PrefixSet[newK]; ok {
		return fmt.Errorf("key %v already exists in PrefixSet", newK)
	}

	e, ok := t.PrefixSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in PrefixSet", oldK)
	}
	e.Name = &newK

	t.PrefixSet[newK] = e
	delete(t.PrefixSet, oldK)
	return nil
}

// GetOrCreatePrefixSet retrieves the value with the specified keys from
// the receiver RoutingPolicy_DefinedSets. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RoutingPolicy_DefinedSets) GetOrCreatePrefixSet(Name string) *RoutingPolicy_DefinedSets_PrefixSet {

	key := Name

	if v, ok := t.PrefixSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefixSet(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefixSet got unexpected error: %v", err))
	}
	return v
}

// GetPrefixSet retrieves the value with the specified key from
// the PrefixSet map field of RoutingPolicy_DefinedSets. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RoutingPolicy_DefinedSets) GetPrefixSet(Name string) *RoutingPolicy_DefinedSets_PrefixSet {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.PrefixSet[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefixSet appends the supplied RoutingPolicy_DefinedSets_PrefixSet struct to the
// list PrefixSet of RoutingPolicy_DefinedSets. If the key value(s) specified in
// the supplied RoutingPolicy_DefinedSets_PrefixSet already exist in the list, an error is
// returned.
func (t *RoutingPolicy_DefinedSets) AppendPrefixSet(v *RoutingPolicy_DefinedSets_PrefixSet) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSet == nil {
		t.PrefixSet = make(map[string]*RoutingPolicy_DefinedSets_PrefixSet)
	}

	if _, ok := t.PrefixSet[key]; ok {
		return fmt.Errorf("duplicate key for list PrefixSet %v", key)
	}

	t.PrefixSet[key] = v
	return nil
}

// NewTagSet creates a new entry in the TagSet list of the
// RoutingPolicy_DefinedSets struct. The keys of the list are populated from the input
// arguments.
func (t *RoutingPolicy_DefinedSets) NewTagSet(Name string) (*RoutingPolicy_DefinedSets_TagSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TagSet == nil {
		t.TagSet = make(map[string]*RoutingPolicy_DefinedSets_TagSet)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TagSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TagSet", key)
	}

	t.TagSet[key] = &RoutingPolicy_DefinedSets_TagSet{
		Name: &Name,
	}

	return t.TagSet[key], nil
}

// RenameTagSet renames an entry in the list TagSet within
// the RoutingPolicy_DefinedSets struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RoutingPolicy_DefinedSets) RenameTagSet(oldK, newK string) error {
	if _, ok := t.TagSet[newK]; ok {
		return fmt.Errorf("key %v already exists in TagSet", newK)
	}

	e, ok := t.TagSet[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in TagSet", oldK)
	}
	e.Name = &newK

	t.TagSet[newK] = e
	delete(t.TagSet, oldK)
	return nil
}

// GetOrCreateTagSet retrieves the value with the specified keys from
// the receiver RoutingPolicy_DefinedSets. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RoutingPolicy_DefinedSets) GetOrCreateTagSet(Name string) *RoutingPolicy_DefinedSets_TagSet {

	key := Name

	if v, ok := t.TagSet[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTagSet(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTagSet got unexpected error: %v", err))
	}
	return v
}

// GetTagSet retrieves the value with the specified key from
// the TagSet map field of RoutingPolicy_DefinedSets. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RoutingPolicy_DefinedSets) GetTagSet(Name string) *RoutingPolicy_DefinedSets_TagSet {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.TagSet[key]; ok {
		return lm
	}
	return nil
}

// AppendTagSet appends the supplied RoutingPolicy_DefinedSets_TagSet struct to the
// list TagSet of RoutingPolicy_DefinedSets. If the key value(s) specified in
// the supplied RoutingPolicy_DefinedSets_TagSet already exist in the list, an error is
// returned.
func (t *RoutingPolicy_DefinedSets) AppendTagSet(v *RoutingPolicy_DefinedSets_TagSet) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TagSet == nil {
		t.TagSet = make(map[string]*RoutingPolicy_DefinedSets_TagSet)
	}

	if _, ok := t.TagSet[key]; ok {
		return fmt.Errorf("duplicate key for list TagSet %v", key)
	}

	t.TagSet[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_DefinedSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_DefinedSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_DefinedSets) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// RoutingPolicy_DefinedSets_NeighborSet represents the /openconfig-routing-policy/routing-policy/defined-sets/neighbor-sets/neighbor-set YANG schema element.
type RoutingPolicy_DefinedSets_NeighborSet struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   []string          `path:"state/address" shadow-path:"config/address" module:"openconfig-routing-policy"`
	ΛAddress  []ygot.Annotation `path:"state/@address" ygotAnnotation:"true"`
	Name      *string           `path:"state/name|name" shadow-path:"config/name" module:"openconfig-routing-policy"`
	ΛName     []ygot.Annotation `path:"state/@name|@name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_DefinedSets_NeighborSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_DefinedSets_NeighborSet) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the RoutingPolicy_DefinedSets_NeighborSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_NeighborSet) GetAddress() []string {
	if t == nil || t.Address == nil {
		return nil
	}
	return t.Address
}

// GetName retrieves the value of the leaf Name from the RoutingPolicy_DefinedSets_NeighborSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_NeighborSet) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the RoutingPolicy_DefinedSets_NeighborSet struct, which is a YANG list entry.
func (t *RoutingPolicy_DefinedSets_NeighborSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_DefinedSets_NeighborSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_DefinedSets_NeighborSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_DefinedSets_NeighborSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_DefinedSets_PrefixSet represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set YANG schema element.
type RoutingPolicy_DefinedSets_PrefixSet struct {
	ΛMetadata []ygot.Annotation                                                                              `path:"@" ygotAnnotation:"true"`
	Mode      E_PrefixSet_Mode                                                                               `path:"state/mode" shadow-path:"config/mode" module:"openconfig-routing-policy"`
	ΛMode     []ygot.Annotation                                                                              `path:"state/@mode" ygotAnnotation:"true"`
	Name      *string                                                                                        `path:"state/name|name" shadow-path:"config/name" module:"openconfig-routing-policy"`
	ΛName     []ygot.Annotation                                                                              `path:"state/@name|@name" ygotAnnotation:"true"`
	Prefix    map[RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key]*RoutingPolicy_DefinedSets_PrefixSet_Prefix `path:"prefixes/prefix" module:"openconfig-routing-policy"`
	ΛPrefix   []ygot.Annotation                                                                              `path:"prefixes/@prefix" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_DefinedSets_PrefixSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_DefinedSets_PrefixSet) IsYANGGoStruct() {}

// RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key represents the key for list Prefix of element /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set.
type RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key struct {
	IpPrefix        string `path:"ip-prefix"`
	MasklengthRange string `path:"masklength-range"`
}

// NewPrefix creates a new entry in the Prefix list of the
// RoutingPolicy_DefinedSets_PrefixSet struct. The keys of the list are populated from the input
// arguments.
func (t *RoutingPolicy_DefinedSets_PrefixSet) NewPrefix(IpPrefix string, MasklengthRange string) (*RoutingPolicy_DefinedSets_PrefixSet_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key]*RoutingPolicy_DefinedSets_PrefixSet_Prefix)
	}

	key := RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key{
		IpPrefix:        IpPrefix,
		MasklengthRange: MasklengthRange,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &RoutingPolicy_DefinedSets_PrefixSet_Prefix{
		IpPrefix:        &IpPrefix,
		MasklengthRange: &MasklengthRange,
	}

	return t.Prefix[key], nil
}

// RenamePrefix renames an entry in the list Prefix within
// the RoutingPolicy_DefinedSets_PrefixSet struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RoutingPolicy_DefinedSets_PrefixSet) RenamePrefix(oldK, newK RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key) error {
	if _, ok := t.Prefix[newK]; ok {
		return fmt.Errorf("key %v already exists in Prefix", newK)
	}

	e, ok := t.Prefix[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Prefix", oldK)
	}
	e.IpPrefix = &newK.IpPrefix
	e.MasklengthRange = &newK.MasklengthRange

	t.Prefix[newK] = e
	delete(t.Prefix, oldK)
	return nil
}

// GetOrCreatePrefix retrieves the value with the specified keys from
// the receiver RoutingPolicy_DefinedSets_PrefixSet. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RoutingPolicy_DefinedSets_PrefixSet) GetOrCreatePrefix(IpPrefix string, MasklengthRange string) *RoutingPolicy_DefinedSets_PrefixSet_Prefix {

	key := RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key{
		IpPrefix:        IpPrefix,
		MasklengthRange: MasklengthRange,
	}

	if v, ok := t.Prefix[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewPrefix(IpPrefix, MasklengthRange)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreatePrefix got unexpected error: %v", err))
	}
	return v
}

// GetPrefix retrieves the value with the specified key from
// the Prefix map field of RoutingPolicy_DefinedSets_PrefixSet. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RoutingPolicy_DefinedSets_PrefixSet) GetPrefix(IpPrefix string, MasklengthRange string) *RoutingPolicy_DefinedSets_PrefixSet_Prefix {

	if t == nil {
		return nil
	}

	key := RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key{
		IpPrefix:        IpPrefix,
		MasklengthRange: MasklengthRange,
	}

	if lm, ok := t.Prefix[key]; ok {
		return lm
	}
	return nil
}

// AppendPrefix appends the supplied RoutingPolicy_DefinedSets_PrefixSet_Prefix struct to the
// list Prefix of RoutingPolicy_DefinedSets_PrefixSet. If the key value(s) specified in
// the supplied RoutingPolicy_DefinedSets_PrefixSet_Prefix already exist in the list, an error is
// returned.
func (t *RoutingPolicy_DefinedSets_PrefixSet) AppendPrefix(v *RoutingPolicy_DefinedSets_PrefixSet_Prefix) error {
	if v.IpPrefix == nil {
		return fmt.Errorf("invalid nil key for IpPrefix")
	}

	if v.MasklengthRange == nil {
		return fmt.Errorf("invalid nil key for MasklengthRange")
	}

	key := RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key{
		IpPrefix:        *v.IpPrefix,
		MasklengthRange: *v.MasklengthRange,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[RoutingPolicy_DefinedSets_PrefixSet_Prefix_Key]*RoutingPolicy_DefinedSets_PrefixSet_Prefix)
	}

	if _, ok := t.Prefix[key]; ok {
		return fmt.Errorf("duplicate key for list Prefix %v", key)
	}

	t.Prefix[key] = v
	return nil
}

// GetMode retrieves the value of the leaf Mode from the RoutingPolicy_DefinedSets_PrefixSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_PrefixSet) GetMode() E_PrefixSet_Mode {
	if t == nil || t.Mode == 0 {
		return 0
	}
	return t.Mode
}

// GetName retrieves the value of the leaf Name from the RoutingPolicy_DefinedSets_PrefixSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_PrefixSet) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the RoutingPolicy_DefinedSets_PrefixSet struct, which is a YANG list entry.
func (t *RoutingPolicy_DefinedSets_PrefixSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_DefinedSets_PrefixSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_DefinedSets_PrefixSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_DefinedSets_PrefixSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_DefinedSets_PrefixSet_Prefix represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/prefixes/prefix YANG schema element.
type RoutingPolicy_DefinedSets_PrefixSet_Prefix struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	IpPrefix         *string           `path:"state/ip-prefix|ip-prefix" shadow-path:"config/ip-prefix" module:"openconfig-routing-policy"`
	ΛIpPrefix        []ygot.Annotation `path:"state/@ip-prefix|@ip-prefix" ygotAnnotation:"true"`
	MasklengthRange  *string           `path:"state/masklength-range|masklength-range" shadow-path:"config/masklength-range" module:"openconfig-routing-policy"`
	ΛMasklengthRange []ygot.Annotation `path:"state/@masklength-range|@masklength-range" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_DefinedSets_PrefixSet_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_DefinedSets_PrefixSet_Prefix) IsYANGGoStruct() {}

// GetIpPrefix retrieves the value of the leaf IpPrefix from the RoutingPolicy_DefinedSets_PrefixSet_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IpPrefix is set, it can safely use t.GetIpPrefix()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IpPrefix == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_PrefixSet_Prefix) GetIpPrefix() string {
	if t == nil || t.IpPrefix == nil {
		return ""
	}
	return *t.IpPrefix
}

// GetMasklengthRange retrieves the value of the leaf MasklengthRange from the RoutingPolicy_DefinedSets_PrefixSet_Prefix
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MasklengthRange is set, it can safely use t.GetMasklengthRange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MasklengthRange == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_PrefixSet_Prefix) GetMasklengthRange() string {
	if t == nil || t.MasklengthRange == nil {
		return ""
	}
	return *t.MasklengthRange
}

// ΛListKeyMap returns the keys of the RoutingPolicy_DefinedSets_PrefixSet_Prefix struct, which is a YANG list entry.
func (t *RoutingPolicy_DefinedSets_PrefixSet_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.IpPrefix == nil {
		return nil, fmt.Errorf("nil value for key IpPrefix")
	}

	if t.MasklengthRange == nil {
		return nil, fmt.Errorf("nil value for key MasklengthRange")
	}

	return map[string]interface{}{
		"ip-prefix":        *t.IpPrefix,
		"masklength-range": *t.MasklengthRange,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_DefinedSets_PrefixSet_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_DefinedSets_PrefixSet_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_DefinedSets_PrefixSet_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_DefinedSets_TagSet represents the /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set YANG schema element.
type RoutingPolicy_DefinedSets_TagSet struct {
	ΛMetadata []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	Name      *string                                           `path:"state/name|name" shadow-path:"config/name" module:"openconfig-routing-policy"`
	ΛName     []ygot.Annotation                                 `path:"state/@name|@name" ygotAnnotation:"true"`
	TagValue  []RoutingPolicy_DefinedSets_TagSet_TagValue_Union `path:"state/tag-value" shadow-path:"config/tag-value" module:"openconfig-routing-policy"`
	ΛTagValue []ygot.Annotation                                 `path:"state/@tag-value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_DefinedSets_TagSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_DefinedSets_TagSet) IsYANGGoStruct() {}

// GetName retrieves the value of the leaf Name from the RoutingPolicy_DefinedSets_TagSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_TagSet) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetTagValue retrieves the value of the leaf TagValue from the RoutingPolicy_DefinedSets_TagSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TagValue is set, it can safely use t.GetTagValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TagValue == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_DefinedSets_TagSet) GetTagValue() []RoutingPolicy_DefinedSets_TagSet_TagValue_Union {
	if t == nil || t.TagValue == nil {
		return nil
	}
	return t.TagValue
}

// ΛListKeyMap returns the keys of the RoutingPolicy_DefinedSets_TagSet struct, which is a YANG list entry.
func (t *RoutingPolicy_DefinedSets_TagSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_DefinedSets_TagSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_DefinedSets_TagSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_DefinedSets_TagSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_DefinedSets_TagSet_TagValue_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/state/tag-value within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type RoutingPolicy_DefinedSets_TagSet_TagValue_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_RoutingPolicy_DefinedSets_TagSet_TagValue_Union()
}

// Documentation_for_RoutingPolicy_DefinedSets_TagSet_TagValue_Union ensures that UnionString
// implements the RoutingPolicy_DefinedSets_TagSet_TagValue_Union interface.
func (UnionString) Documentation_for_RoutingPolicy_DefinedSets_TagSet_TagValue_Union() {}

// Documentation_for_RoutingPolicy_DefinedSets_TagSet_TagValue_Union ensures that UnionUint32
// implements the RoutingPolicy_DefinedSets_TagSet_TagValue_Union interface.
func (UnionUint32) Documentation_for_RoutingPolicy_DefinedSets_TagSet_TagValue_Union() {}

// To_RoutingPolicy_DefinedSets_TagSet_TagValue_Union takes an input interface{} and attempts to convert it to a struct
// which implements the RoutingPolicy_DefinedSets_TagSet_TagValue_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *RoutingPolicy_DefinedSets_TagSet) To_RoutingPolicy_DefinedSets_TagSet_TagValue_Union(i interface{}) (RoutingPolicy_DefinedSets_TagSet_TagValue_Union, error) {
	if v, ok := i.(RoutingPolicy_DefinedSets_TagSet_TagValue_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to RoutingPolicy_DefinedSets_TagSet_TagValue_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// RoutingPolicy_PolicyDefinition represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition YANG schema element.
type RoutingPolicy_PolicyDefinition struct {
	ΛMetadata  []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	Name       *string                                              `path:"state/name|name" shadow-path:"config/name" module:"openconfig-routing-policy"`
	ΛName      []ygot.Annotation                                    `path:"state/@name|@name" ygotAnnotation:"true"`
	Statement  map[string]*RoutingPolicy_PolicyDefinition_Statement `path:"statements/statement" module:"openconfig-routing-policy"`
	ΛStatement []ygot.Annotation                                    `path:"statements/@statement" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition) IsYANGGoStruct() {}

// NewStatement creates a new entry in the Statement list of the
// RoutingPolicy_PolicyDefinition struct. The keys of the list are populated from the input
// arguments.
func (t *RoutingPolicy_PolicyDefinition) NewStatement(Name string) (*RoutingPolicy_PolicyDefinition_Statement, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Statement == nil {
		t.Statement = make(map[string]*RoutingPolicy_PolicyDefinition_Statement)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Statement[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Statement", key)
	}

	t.Statement[key] = &RoutingPolicy_PolicyDefinition_Statement{
		Name: &Name,
	}

	return t.Statement[key], nil
}

// RenameStatement renames an entry in the list Statement within
// the RoutingPolicy_PolicyDefinition struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *RoutingPolicy_PolicyDefinition) RenameStatement(oldK, newK string) error {
	if _, ok := t.Statement[newK]; ok {
		return fmt.Errorf("key %v already exists in Statement", newK)
	}

	e, ok := t.Statement[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Statement", oldK)
	}
	e.Name = &newK

	t.Statement[newK] = e
	delete(t.Statement, oldK)
	return nil
}

// GetOrCreateStatement retrieves the value with the specified keys from
// the receiver RoutingPolicy_PolicyDefinition. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *RoutingPolicy_PolicyDefinition) GetOrCreateStatement(Name string) *RoutingPolicy_PolicyDefinition_Statement {

	key := Name

	if v, ok := t.Statement[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewStatement(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateStatement got unexpected error: %v", err))
	}
	return v
}

// GetStatement retrieves the value with the specified key from
// the Statement map field of RoutingPolicy_PolicyDefinition. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *RoutingPolicy_PolicyDefinition) GetStatement(Name string) *RoutingPolicy_PolicyDefinition_Statement {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Statement[key]; ok {
		return lm
	}
	return nil
}

// AppendStatement appends the supplied RoutingPolicy_PolicyDefinition_Statement struct to the
// list Statement of RoutingPolicy_PolicyDefinition. If the key value(s) specified in
// the supplied RoutingPolicy_PolicyDefinition_Statement already exist in the list, an error is
// returned.
func (t *RoutingPolicy_PolicyDefinition) AppendStatement(v *RoutingPolicy_PolicyDefinition_Statement) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Statement == nil {
		t.Statement = make(map[string]*RoutingPolicy_PolicyDefinition_Statement)
	}

	if _, ok := t.Statement[key]; ok {
		return fmt.Errorf("duplicate key for list Statement %v", key)
	}

	t.Statement[key] = v
	return nil
}

// GetName retrieves the value of the leaf Name from the RoutingPolicy_PolicyDefinition
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the RoutingPolicy_PolicyDefinition struct, which is a YANG list entry.
func (t *RoutingPolicy_PolicyDefinition) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement struct {
	ΛMetadata   []ygot.Annotation                                    `path:"@" ygotAnnotation:"true"`
	Actions     *RoutingPolicy_PolicyDefinition_Statement_Actions    `path:"actions" module:"openconfig-routing-policy"`
	ΛActions    []ygot.Annotation                                    `path:"@actions" ygotAnnotation:"true"`
	Conditions  *RoutingPolicy_PolicyDefinition_Statement_Conditions `path:"conditions" module:"openconfig-routing-policy"`
	ΛConditions []ygot.Annotation                                    `path:"@conditions" ygotAnnotation:"true"`
	Name        *string                                              `path:"state/name|name" shadow-path:"config/name" module:"openconfig-routing-policy"`
	ΛName       []ygot.Annotation                                    `path:"state/@name|@name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement) IsYANGGoStruct() {}

// GetOrCreateActions retrieves the value of the Actions field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement) GetOrCreateActions() *RoutingPolicy_PolicyDefinition_Statement_Actions {
	if t.Actions != nil {
		return t.Actions
	}
	t.Actions = &RoutingPolicy_PolicyDefinition_Statement_Actions{}
	return t.Actions
}

// GetOrCreateConditions retrieves the value of the Conditions field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement) GetOrCreateConditions() *RoutingPolicy_PolicyDefinition_Statement_Conditions {
	if t.Conditions != nil {
		return t.Conditions
	}
	t.Conditions = &RoutingPolicy_PolicyDefinition_Statement_Conditions{}
	return t.Conditions
}

// GetActions returns the value of the Actions struct pointer
// from RoutingPolicy_PolicyDefinition_Statement. If the receiver or the field Actions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement) GetActions() *RoutingPolicy_PolicyDefinition_Statement_Actions {
	if t != nil && t.Actions != nil {
		return t.Actions
	}
	return nil
}

// GetConditions returns the value of the Conditions struct pointer
// from RoutingPolicy_PolicyDefinition_Statement. If the receiver or the field Conditions is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement) GetConditions() *RoutingPolicy_PolicyDefinition_Statement_Conditions {
	if t != nil && t.Conditions != nil {
		return t.Conditions
	}
	return nil
}

// GetName retrieves the value of the leaf Name from the RoutingPolicy_PolicyDefinition_Statement
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the RoutingPolicy_PolicyDefinition_Statement struct, which is a YANG list entry.
func (t *RoutingPolicy_PolicyDefinition_Statement) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Actions represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Actions struct {
	ΛMetadata     []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	PolicyResult  E_OpenconfigRoutingPolicy_PolicyResultType               `path:"state/policy-result" shadow-path:"config/policy-result" module:"openconfig-routing-policy"`
	ΛPolicyResult []ygot.Annotation                                        `path:"state/@policy-result" ygotAnnotation:"true"`
	SetTag        *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag `path:"set-tag" module:"openconfig-routing-policy"`
	ΛSetTag       []ygot.Annotation                                        `path:"@set-tag" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Actions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Actions) IsYANGGoStruct() {}

// GetOrCreateSetTag retrieves the value of the SetTag field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions) GetOrCreateSetTag() *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag {
	if t.SetTag != nil {
		return t.SetTag
	}
	t.SetTag = &RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag{}
	return t.SetTag
}

// GetSetTag returns the value of the SetTag struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Actions. If the receiver or the field SetTag is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions) GetSetTag() *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag {
	if t != nil && t.SetTag != nil {
		return t.SetTag
	}
	return nil
}

// GetPolicyResult retrieves the value of the leaf PolicyResult from the RoutingPolicy_PolicyDefinition_Statement_Actions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PolicyResult is set, it can safely use t.GetPolicyResult()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PolicyResult == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions) GetPolicyResult() E_OpenconfigRoutingPolicy_PolicyResultType {
	if t == nil || t.PolicyResult == 0 {
		return 0
	}
	return t.PolicyResult
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Actions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag struct {
	ΛMetadata  []ygot.Annotation                                                  `path:"@" ygotAnnotation:"true"`
	Inline     *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline    `path:"inline" module:"openconfig-routing-policy"`
	ΛInline    []ygot.Annotation                                                  `path:"@inline" ygotAnnotation:"true"`
	Mode       E_SetTag_Mode                                                      `path:"state/mode" shadow-path:"config/mode" module:"openconfig-routing-policy"`
	ΛMode      []ygot.Annotation                                                  `path:"state/@mode" ygotAnnotation:"true"`
	Reference  *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference `path:"reference" module:"openconfig-routing-policy"`
	ΛReference []ygot.Annotation                                                  `path:"@reference" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) IsYANGGoStruct() {}

// GetOrCreateInline retrieves the value of the Inline field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) GetOrCreateInline() *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline {
	if t.Inline != nil {
		return t.Inline
	}
	t.Inline = &RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline{}
	return t.Inline
}

// GetOrCreateReference retrieves the value of the Reference field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) GetOrCreateReference() *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference {
	if t.Reference != nil {
		return t.Reference
	}
	t.Reference = &RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference{}
	return t.Reference
}

// GetInline returns the value of the Inline struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag. If the receiver or the field Inline is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) GetInline() *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline {
	if t != nil && t.Inline != nil {
		return t.Inline
	}
	return nil
}

// GetReference returns the value of the Reference struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag. If the receiver or the field Reference is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) GetReference() *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference {
	if t != nil && t.Reference != nil {
		return t.Reference
	}
	return nil
}

// GetMode retrieves the value of the leaf Mode from the RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mode is set, it can safely use t.GetMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mode == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) GetMode() E_SetTag_Mode {
	if t == nil || t.Mode == 0 {
		return 0
	}
	return t.Mode
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline struct {
	ΛMetadata []ygot.Annotation                                                          `path:"@" ygotAnnotation:"true"`
	Tag       []RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union `path:"state/tag" shadow-path:"config/tag" module:"openconfig-routing-policy"`
	ΛTag      []ygot.Annotation                                                          `path:"state/@tag" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline) IsYANGGoStruct() {}

// GetTag retrieves the value of the leaf Tag from the RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Tag is set, it can safely use t.GetTag()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Tag == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline) GetTag() []RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union {
	if t == nil || t.Tag == nil {
		return nil
	}
	return t.Tag
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/state/tag within the YANG schema.
// Union type can be one of [UnionString, UnionUint32].
type RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union interface {
	// Union type can be one of [UnionString, UnionUint32]
	Documentation_for_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union()
}

// Documentation_for_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union ensures that UnionString
// implements the RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union interface.
func (UnionString) Documentation_for_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union() {
}

// Documentation_for_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union ensures that UnionUint32
// implements the RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union interface.
func (UnionUint32) Documentation_for_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union() {
}

// To_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline) To_RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union(i interface{}) (RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union, error) {
	if v, ok := i.(RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Inline_Tag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
}

// RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/reference YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	TagSet    *string           `path:"state/tag-set" shadow-path:"config/tag-set" module:"openconfig-routing-policy"`
	ΛTagSet   []ygot.Annotation `path:"state/@tag-set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference) IsYANGGoStruct() {}

// GetTagSet retrieves the value of the leaf TagSet from the RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TagSet is set, it can safely use t.GetTagSet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TagSet == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference) GetTagSet() string {
	if t == nil || t.TagSet == nil {
		return ""
	}
	return *t.TagSet
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Actions_SetTag_Reference) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Conditions represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Conditions struct {
	ΛMetadata          []ygot.Annotation                                                     `path:"@" ygotAnnotation:"true"`
	CallPolicy         *string                                                               `path:"state/call-policy" shadow-path:"config/call-policy" module:"openconfig-routing-policy"`
	ΛCallPolicy        []ygot.Annotation                                                     `path:"state/@call-policy" ygotAnnotation:"true"`
	InstallProtocolEq  E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                         `path:"state/install-protocol-eq" shadow-path:"config/install-protocol-eq" module:"openconfig-routing-policy"`
	ΛInstallProtocolEq []ygot.Annotation                                                     `path:"state/@install-protocol-eq" ygotAnnotation:"true"`
	MatchInterface     *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface   `path:"match-interface" module:"openconfig-routing-policy"`
	ΛMatchInterface    []ygot.Annotation                                                     `path:"@match-interface" ygotAnnotation:"true"`
	MatchNeighborSet   *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet `path:"match-neighbor-set" module:"openconfig-routing-policy"`
	ΛMatchNeighborSet  []ygot.Annotation                                                     `path:"@match-neighbor-set" ygotAnnotation:"true"`
	MatchPrefixSet     *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet   `path:"match-prefix-set" module:"openconfig-routing-policy"`
	ΛMatchPrefixSet    []ygot.Annotation                                                     `path:"@match-prefix-set" ygotAnnotation:"true"`
	MatchTagSet        *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet      `path:"match-tag-set" module:"openconfig-routing-policy"`
	ΛMatchTagSet       []ygot.Annotation                                                     `path:"@match-tag-set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Conditions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Conditions) IsYANGGoStruct() {}

// GetOrCreateMatchInterface retrieves the value of the MatchInterface field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetOrCreateMatchInterface() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface {
	if t.MatchInterface != nil {
		return t.MatchInterface
	}
	t.MatchInterface = &RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface{}
	return t.MatchInterface
}

// GetOrCreateMatchNeighborSet retrieves the value of the MatchNeighborSet field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetOrCreateMatchNeighborSet() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet {
	if t.MatchNeighborSet != nil {
		return t.MatchNeighborSet
	}
	t.MatchNeighborSet = &RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet{}
	return t.MatchNeighborSet
}

// GetOrCreateMatchPrefixSet retrieves the value of the MatchPrefixSet field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetOrCreateMatchPrefixSet() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet {
	if t.MatchPrefixSet != nil {
		return t.MatchPrefixSet
	}
	t.MatchPrefixSet = &RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet{}
	return t.MatchPrefixSet
}

// GetOrCreateMatchTagSet retrieves the value of the MatchTagSet field
// or returns the existing field if it already exists.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetOrCreateMatchTagSet() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet {
	if t.MatchTagSet != nil {
		return t.MatchTagSet
	}
	t.MatchTagSet = &RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet{}
	return t.MatchTagSet
}

// GetMatchInterface returns the value of the MatchInterface struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Conditions. If the receiver or the field MatchInterface is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetMatchInterface() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface {
	if t != nil && t.MatchInterface != nil {
		return t.MatchInterface
	}
	return nil
}

// GetMatchNeighborSet returns the value of the MatchNeighborSet struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Conditions. If the receiver or the field MatchNeighborSet is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetMatchNeighborSet() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet {
	if t != nil && t.MatchNeighborSet != nil {
		return t.MatchNeighborSet
	}
	return nil
}

// GetMatchPrefixSet returns the value of the MatchPrefixSet struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Conditions. If the receiver or the field MatchPrefixSet is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetMatchPrefixSet() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet {
	if t != nil && t.MatchPrefixSet != nil {
		return t.MatchPrefixSet
	}
	return nil
}

// GetMatchTagSet returns the value of the MatchTagSet struct pointer
// from RoutingPolicy_PolicyDefinition_Statement_Conditions. If the receiver or the field MatchTagSet is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetMatchTagSet() *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet {
	if t != nil && t.MatchTagSet != nil {
		return t.MatchTagSet
	}
	return nil
}

// GetCallPolicy retrieves the value of the leaf CallPolicy from the RoutingPolicy_PolicyDefinition_Statement_Conditions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CallPolicy is set, it can safely use t.GetCallPolicy()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CallPolicy == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetCallPolicy() string {
	if t == nil || t.CallPolicy == nil {
		return ""
	}
	return *t.CallPolicy
}

// GetInstallProtocolEq retrieves the value of the leaf InstallProtocolEq from the RoutingPolicy_PolicyDefinition_Statement_Conditions
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InstallProtocolEq is set, it can safely use t.GetInstallProtocolEq()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InstallProtocolEq == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) GetInstallProtocolEq() E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE {
	if t == nil || t.InstallProtocolEq == 0 {
		return 0
	}
	return t.InstallProtocolEq
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Conditions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-interface YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Interface     *string           `path:"state/interface" shadow-path:"config/interface" module:"openconfig-routing-policy"`
	ΛInterface    []ygot.Annotation `path:"state/@interface" ygotAnnotation:"true"`
	Subinterface  *uint32           `path:"state/subinterface" shadow-path:"config/subinterface" module:"openconfig-routing-policy"`
	ΛSubinterface []ygot.Annotation `path:"state/@subinterface" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface) IsYANGGoStruct() {}

// GetInterface retrieves the value of the leaf Interface from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interface is set, it can safely use t.GetInterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interface == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface) GetInterface() string {
	if t == nil || t.Interface == nil {
		return ""
	}
	return *t.Interface
}

// GetSubinterface retrieves the value of the leaf Subinterface from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Subinterface is set, it can safely use t.GetSubinterface()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Subinterface == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface) GetSubinterface() uint32 {
	if t == nil || t.Subinterface == nil {
		return 0
	}
	return *t.Subinterface
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchInterface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet struct {
	ΛMetadata        []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	MatchSetOptions  E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType `path:"state/match-set-options" shadow-path:"config/match-set-options" module:"openconfig-routing-policy"`
	ΛMatchSetOptions []ygot.Annotation                                     `path:"state/@match-set-options" ygotAnnotation:"true"`
	NeighborSet      *string                                               `path:"state/neighbor-set" shadow-path:"config/neighbor-set" module:"openconfig-routing-policy"`
	ΛNeighborSet     []ygot.Annotation                                     `path:"state/@neighbor-set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet) IsYANGGoStruct() {}

// GetMatchSetOptions retrieves the value of the leaf MatchSetOptions from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchSetOptions is set, it can safely use t.GetMatchSetOptions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchSetOptions == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet) GetMatchSetOptions() E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType {
	if t == nil || t.MatchSetOptions == 0 {
		return OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_ANY
	}
	return t.MatchSetOptions
}

// GetNeighborSet retrieves the value of the leaf NeighborSet from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NeighborSet is set, it can safely use t.GetNeighborSet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NeighborSet == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet) GetNeighborSet() string {
	if t == nil || t.NeighborSet == nil {
		return ""
	}
	return *t.NeighborSet
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchNeighborSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet struct {
	ΛMetadata        []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	MatchSetOptions  E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType `path:"state/match-set-options" shadow-path:"config/match-set-options" module:"openconfig-routing-policy"`
	ΛMatchSetOptions []ygot.Annotation                                     `path:"state/@match-set-options" ygotAnnotation:"true"`
	PrefixSet        *string                                               `path:"state/prefix-set" shadow-path:"config/prefix-set" module:"openconfig-routing-policy"`
	ΛPrefixSet       []ygot.Annotation                                     `path:"state/@prefix-set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet) IsYANGGoStruct() {}

// GetMatchSetOptions retrieves the value of the leaf MatchSetOptions from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchSetOptions is set, it can safely use t.GetMatchSetOptions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchSetOptions == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet) GetMatchSetOptions() E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType {
	if t == nil || t.MatchSetOptions == 0 {
		return OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_ANY
	}
	return t.MatchSetOptions
}

// GetPrefixSet retrieves the value of the leaf PrefixSet from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PrefixSet is set, it can safely use t.GetPrefixSet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PrefixSet == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet) GetPrefixSet() string {
	if t == nil || t.PrefixSet == nil {
		return ""
	}
	return *t.PrefixSet
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchPrefixSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set YANG schema element.
type RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet struct {
	ΛMetadata        []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	MatchSetOptions  E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType `path:"state/match-set-options" shadow-path:"config/match-set-options" module:"openconfig-routing-policy"`
	ΛMatchSetOptions []ygot.Annotation                                     `path:"state/@match-set-options" ygotAnnotation:"true"`
	TagSet           *string                                               `path:"state/tag-set" shadow-path:"config/tag-set" module:"openconfig-routing-policy"`
	ΛTagSet          []ygot.Annotation                                     `path:"state/@tag-set" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet) IsYANGGoStruct() {}

// GetMatchSetOptions retrieves the value of the leaf MatchSetOptions from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MatchSetOptions is set, it can safely use t.GetMatchSetOptions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MatchSetOptions == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet) GetMatchSetOptions() E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType {
	if t == nil || t.MatchSetOptions == 0 {
		return OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_ANY
	}
	return t.MatchSetOptions
}

// GetTagSet retrieves the value of the leaf TagSet from the RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TagSet is set, it can safely use t.GetTagSet()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TagSet == nil'
// before retrieving the leaf's value.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet) GetTagSet() string {
	if t == nil || t.TagSet == nil {
		return ""
	}
	return *t.TagSet
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *RoutingPolicy_PolicyDefinition_Statement_Conditions_MatchTagSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Stp represents the /openconfig-spanning-tree/stp YANG schema element.
type Stp struct {
	ΛMetadata  []ygot.Annotation         `path:"@" ygotAnnotation:"true"`
	Global     *Stp_Global               `path:"global" module:"openconfig-spanning-tree"`
	ΛGlobal    []ygot.Annotation         `path:"@global" ygotAnnotation:"true"`
	Interface  map[string]*Stp_Interface `path:"interfaces/interface" module:"openconfig-spanning-tree"`
	ΛInterface []ygot.Annotation         `path:"interfaces/@interface" ygotAnnotation:"true"`
	Mstp       *Stp_Mstp                 `path:"mstp" module:"openconfig-spanning-tree"`
	ΛMstp      []ygot.Annotation         `path:"@mstp" ygotAnnotation:"true"`
	Rstp       *Stp_Rstp                 `path:"rstp" module:"openconfig-spanning-tree"`
	ΛRstp      []ygot.Annotation         `path:"@rstp" ygotAnnotation:"true"`
	Vlan       map[uint16]*Stp_Vlan      `path:"rapid-pvst/vlan" module:"openconfig-spanning-tree"`
	ΛVlan      []ygot.Annotation         `path:"rapid-pvst/@vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// Stp struct. The keys of the list are populated from the input
// arguments.
func (t *Stp) NewInterface(Name string) (*Stp_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Stp_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Stp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Stp) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Stp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Stp) GetOrCreateInterface(Name string) *Stp_Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Stp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Stp) GetInterface(Name string) *Stp_Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Stp_Interface struct to the
// list Interface of Stp. If the key value(s) specified in
// the supplied Stp_Interface already exist in the list, an error is
// returned.
func (t *Stp) AppendInterface(v *Stp_Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// NewVlan creates a new entry in the Vlan list of the
// Stp struct. The keys of the list are populated from the input
// arguments.
func (t *Stp) NewVlan(VlanId uint16) (*Stp_Vlan, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Vlan == nil {
		t.Vlan = make(map[uint16]*Stp_Vlan)
	}

	key := VlanId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Vlan[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Vlan", key)
	}

	t.Vlan[key] = &Stp_Vlan{
		VlanId: &VlanId,
	}

	return t.Vlan[key], nil
}

// RenameVlan renames an entry in the list Vlan within
// the Stp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Stp) RenameVlan(oldK, newK uint16) error {
	if _, ok := t.Vlan[newK]; ok {
		return fmt.Errorf("key %v already exists in Vlan", newK)
	}

	e, ok := t.Vlan[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Vlan", oldK)
	}
	e.VlanId = &newK

	t.Vlan[newK] = e
	delete(t.Vlan, oldK)
	return nil
}

// GetOrCreateVlan retrieves the value with the specified keys from
// the receiver Stp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Stp) GetOrCreateVlan(VlanId uint16) *Stp_Vlan {

	key := VlanId

	if v, ok := t.Vlan[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewVlan(VlanId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateVlan got unexpected error: %v", err))
	}
	return v
}

// GetVlan retrieves the value with the specified key from
// the Vlan map field of Stp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Stp) GetVlan(VlanId uint16) *Stp_Vlan {

	if t == nil {
		return nil
	}

	key := VlanId

	if lm, ok := t.Vlan[key]; ok {
		return lm
	}
	return nil
}

// AppendVlan appends the supplied Stp_Vlan struct to the
// list Vlan of Stp. If the key value(s) specified in
// the supplied Stp_Vlan already exist in the list, an error is
// returned.
func (t *Stp) AppendVlan(v *Stp_Vlan) error {
	if v.VlanId == nil {
		return fmt.Errorf("invalid nil key received for VlanId")
	}

	key := *v.VlanId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Vlan == nil {
		t.Vlan = make(map[uint16]*Stp_Vlan)
	}

	if _, ok := t.Vlan[key]; ok {
		return fmt.Errorf("duplicate key for list Vlan %v", key)
	}

	t.Vlan[key] = v
	return nil
}

// GetOrCreateGlobal retrieves the value of the Global field
// or returns the existing field if it already exists.
func (t *Stp) GetOrCreateGlobal() *Stp_Global {
	if t.Global != nil {
		return t.Global
	}
	t.Global = &Stp_Global{}
	return t.Global
}

// GetOrCreateMstp retrieves the value of the Mstp field
// or returns the existing field if it already exists.
func (t *Stp) GetOrCreateMstp() *Stp_Mstp {
	if t.Mstp != nil {
		return t.Mstp
	}
	t.Mstp = &Stp_Mstp{}
	return t.Mstp
}

// GetOrCreateRstp retrieves the value of the Rstp field
// or returns the existing field if it already exists.
func (t *Stp) GetOrCreateRstp() *Stp_Rstp {
	if t.Rstp != nil {
		return t.Rstp
	}
	t.Rstp = &Stp_Rstp{}
	return t.Rstp
}

// GetGlobal returns the value of the Global struct pointer
// from Stp. If the receiver or the field Global is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Stp) GetGlobal() *Stp_Global {
	if t != nil && t.Global != nil {
		return t.Global
	}
	return nil
}

// GetMstp returns the value of the Mstp struct pointer
// from Stp. If the receiver or the field Mstp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Stp) GetMstp() *Stp_Mstp {
	if t != nil && t.Mstp != nil {
		return t.Mstp
	}
	return nil
}

// GetRstp returns the value of the Rstp struct pointer
// from Stp. If the receiver or the field Rstp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Stp) GetRstp() *Stp_Rstp {
	if t != nil && t.Rstp != nil {
		return t.Rstp
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Global represents the /openconfig-spanning-tree/stp/global YANG schema element.
type Stp_Global struct {
	ΛMetadata                   []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	BpduFilter                  *bool                                        `path:"state/bpdu-filter" shadow-path:"config/bpdu-filter" module:"openconfig-spanning-tree"`
	ΛBpduFilter                 []ygot.Annotation                            `path:"state/@bpdu-filter" ygotAnnotation:"true"`
	BpduGuard                   *bool                                        `path:"state/bpdu-guard" shadow-path:"config/bpdu-guard" module:"openconfig-spanning-tree"`
	ΛBpduGuard                  []ygot.Annotation                            `path:"state/@bpdu-guard" ygotAnnotation:"true"`
	BpduguardTimeoutRecovery    *uint8                                       `path:"state/bpduguard-timeout-recovery" shadow-path:"config/bpduguard-timeout-recovery" module:"openconfig-spanning-tree"`
	ΛBpduguardTimeoutRecovery   []ygot.Annotation                            `path:"state/@bpduguard-timeout-recovery" ygotAnnotation:"true"`
	BridgeAssurance             *bool                                        `path:"state/bridge-assurance" shadow-path:"config/bridge-assurance" module:"openconfig-spanning-tree"`
	ΛBridgeAssurance            []ygot.Annotation                            `path:"state/@bridge-assurance" ygotAnnotation:"true"`
	EnabledProtocol             []E_OpenconfigSpanningTreeTypes_STP_PROTOCOL `path:"state/enabled-protocol" shadow-path:"config/enabled-protocol" module:"openconfig-spanning-tree"`
	ΛEnabledProtocol            []ygot.Annotation                            `path:"state/@enabled-protocol" ygotAnnotation:"true"`
	EtherchannelMisconfigGuard  *bool                                        `path:"state/etherchannel-misconfig-guard" shadow-path:"config/etherchannel-misconfig-guard" module:"openconfig-spanning-tree"`
	ΛEtherchannelMisconfigGuard []ygot.Annotation                            `path:"state/@etherchannel-misconfig-guard" ygotAnnotation:"true"`
	LoopGuard                   *bool                                        `path:"state/loop-guard" shadow-path:"config/loop-guard" module:"openconfig-spanning-tree"`
	ΛLoopGuard                  []ygot.Annotation                            `path:"state/@loop-guard" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Global) IsYANGGoStruct() {}

// GetBpduFilter retrieves the value of the leaf BpduFilter from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduFilter is set, it can safely use t.GetBpduFilter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduFilter == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetBpduFilter() bool {
	if t == nil || t.BpduFilter == nil {
		return false
	}
	return *t.BpduFilter
}

// GetBpduGuard retrieves the value of the leaf BpduGuard from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduGuard is set, it can safely use t.GetBpduGuard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduGuard == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetBpduGuard() bool {
	if t == nil || t.BpduGuard == nil {
		return false
	}
	return *t.BpduGuard
}

// GetBpduguardTimeoutRecovery retrieves the value of the leaf BpduguardTimeoutRecovery from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduguardTimeoutRecovery is set, it can safely use t.GetBpduguardTimeoutRecovery()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduguardTimeoutRecovery == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetBpduguardTimeoutRecovery() uint8 {
	if t == nil || t.BpduguardTimeoutRecovery == nil {
		return 0
	}
	return *t.BpduguardTimeoutRecovery
}

// GetBridgeAssurance retrieves the value of the leaf BridgeAssurance from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgeAssurance is set, it can safely use t.GetBridgeAssurance()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgeAssurance == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetBridgeAssurance() bool {
	if t == nil || t.BridgeAssurance == nil {
		return false
	}
	return *t.BridgeAssurance
}

// GetEnabledProtocol retrieves the value of the leaf EnabledProtocol from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnabledProtocol is set, it can safely use t.GetEnabledProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnabledProtocol == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetEnabledProtocol() []E_OpenconfigSpanningTreeTypes_STP_PROTOCOL {
	if t == nil || t.EnabledProtocol == nil {
		return nil
	}
	return t.EnabledProtocol
}

// GetEtherchannelMisconfigGuard retrieves the value of the leaf EtherchannelMisconfigGuard from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EtherchannelMisconfigGuard is set, it can safely use t.GetEtherchannelMisconfigGuard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EtherchannelMisconfigGuard == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetEtherchannelMisconfigGuard() bool {
	if t == nil || t.EtherchannelMisconfigGuard == nil {
		return false
	}
	return *t.EtherchannelMisconfigGuard
}

// GetLoopGuard retrieves the value of the leaf LoopGuard from the Stp_Global
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LoopGuard is set, it can safely use t.GetLoopGuard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LoopGuard == nil'
// before retrieving the leaf's value.
func (t *Stp_Global) GetLoopGuard() bool {
	if t == nil || t.LoopGuard == nil {
		return false
	}
	return *t.LoopGuard
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Global) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Interface represents the /openconfig-spanning-tree/stp/interfaces/interface YANG schema element.
type Stp_Interface struct {
	ΛMetadata   []ygot.Annotation                           `path:"@" ygotAnnotation:"true"`
	BpduFilter  *bool                                       `path:"state/bpdu-filter" shadow-path:"config/bpdu-filter" module:"openconfig-spanning-tree"`
	ΛBpduFilter []ygot.Annotation                           `path:"state/@bpdu-filter" ygotAnnotation:"true"`
	BpduGuard   *bool                                       `path:"state/bpdu-guard" shadow-path:"config/bpdu-guard" module:"openconfig-spanning-tree"`
	ΛBpduGuard  []ygot.Annotation                           `path:"state/@bpdu-guard" ygotAnnotation:"true"`
	EdgePort    E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT `path:"state/edge-port" shadow-path:"config/edge-port" module:"openconfig-spanning-tree"`
	ΛEdgePort   []ygot.Annotation                           `path:"state/@edge-port" ygotAnnotation:"true"`
	Guard       E_OpenconfigSpanningTreeTypes_StpGuardType  `path:"state/guard" shadow-path:"config/guard" module:"openconfig-spanning-tree"`
	ΛGuard      []ygot.Annotation                           `path:"state/@guard" ygotAnnotation:"true"`
	LinkType    E_OpenconfigSpanningTreeTypes_StpLinkType   `path:"state/link-type" shadow-path:"config/link-type" module:"openconfig-spanning-tree"`
	ΛLinkType   []ygot.Annotation                           `path:"state/@link-type" ygotAnnotation:"true"`
	Name        *string                                     `path:"state/name|name" shadow-path:"config/name" module:"openconfig-spanning-tree"`
	ΛName       []ygot.Annotation                           `path:"state/@name|@name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Interface) IsYANGGoStruct() {}

// GetBpduFilter retrieves the value of the leaf BpduFilter from the Stp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduFilter is set, it can safely use t.GetBpduFilter()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduFilter == nil'
// before retrieving the leaf's value.
func (t *Stp_Interface) GetBpduFilter() bool {
	if t == nil || t.BpduFilter == nil {
		return false
	}
	return *t.BpduFilter
}

// GetBpduGuard retrieves the value of the leaf BpduGuard from the Stp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduGuard is set, it can safely use t.GetBpduGuard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduGuard == nil'
// before retrieving the leaf's value.
func (t *Stp_Interface) GetBpduGuard() bool {
	if t == nil || t.BpduGuard == nil {
		return false
	}
	return *t.BpduGuard
}

// GetEdgePort retrieves the value of the leaf EdgePort from the Stp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EdgePort is set, it can safely use t.GetEdgePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EdgePort == nil'
// before retrieving the leaf's value.
func (t *Stp_Interface) GetEdgePort() E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT {
	if t == nil || t.EdgePort == 0 {
		return 0
	}
	return t.EdgePort
}

// GetGuard retrieves the value of the leaf Guard from the Stp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Guard is set, it can safely use t.GetGuard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Guard == nil'
// before retrieving the leaf's value.
func (t *Stp_Interface) GetGuard() E_OpenconfigSpanningTreeTypes_StpGuardType {
	if t == nil || t.Guard == 0 {
		return 0
	}
	return t.Guard
}

// GetLinkType retrieves the value of the leaf LinkType from the Stp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkType is set, it can safely use t.GetLinkType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkType == nil'
// before retrieving the leaf's value.
func (t *Stp_Interface) GetLinkType() E_OpenconfigSpanningTreeTypes_StpLinkType {
	if t == nil || t.LinkType == 0 {
		return 0
	}
	return t.LinkType
}

// GetName retrieves the value of the leaf Name from the Stp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Stp_Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// ΛListKeyMap returns the keys of the Stp_Interface struct, which is a YANG list entry.
func (t *Stp_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Mstp represents the /openconfig-spanning-tree/stp/mstp YANG schema element.
type Stp_Mstp struct {
	ΛMetadata        []ygot.Annotation                `path:"@" ygotAnnotation:"true"`
	ForwardingDelay  *uint8                           `path:"state/forwarding-delay" shadow-path:"config/forwarding-delay" module:"openconfig-spanning-tree"`
	ΛForwardingDelay []ygot.Annotation                `path:"state/@forwarding-delay" ygotAnnotation:"true"`
	HelloTime        *uint8                           `path:"state/hello-time" shadow-path:"config/hello-time" module:"openconfig-spanning-tree"`
	ΛHelloTime       []ygot.Annotation                `path:"state/@hello-time" ygotAnnotation:"true"`
	HoldCount        *uint8                           `path:"state/hold-count" shadow-path:"config/hold-count" module:"openconfig-spanning-tree"`
	ΛHoldCount       []ygot.Annotation                `path:"state/@hold-count" ygotAnnotation:"true"`
	MaxAge           *uint8                           `path:"state/max-age" shadow-path:"config/max-age" module:"openconfig-spanning-tree"`
	ΛMaxAge          []ygot.Annotation                `path:"state/@max-age" ygotAnnotation:"true"`
	MaxHop           *uint8                           `path:"state/max-hop" shadow-path:"config/max-hop" module:"openconfig-spanning-tree"`
	ΛMaxHop          []ygot.Annotation                `path:"state/@max-hop" ygotAnnotation:"true"`
	MstInstance      map[uint16]*Stp_Mstp_MstInstance `path:"mst-instances/mst-instance" module:"openconfig-spanning-tree"`
	ΛMstInstance     []ygot.Annotation                `path:"mst-instances/@mst-instance" ygotAnnotation:"true"`
	Name             *string                          `path:"state/name" shadow-path:"config/name" module:"openconfig-spanning-tree"`
	ΛName            []ygot.Annotation                `path:"state/@name" ygotAnnotation:"true"`
	Revision         *uint32                          `path:"state/revision" shadow-path:"config/revision" module:"openconfig-spanning-tree"`
	ΛRevision        []ygot.Annotation                `path:"state/@revision" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Mstp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Mstp) IsYANGGoStruct() {}

// NewMstInstance creates a new entry in the MstInstance list of the
// Stp_Mstp struct. The keys of the list are populated from the input
// arguments.
func (t *Stp_Mstp) NewMstInstance(MstId uint16) (*Stp_Mstp_MstInstance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MstInstance == nil {
		t.MstInstance = make(map[uint16]*Stp_Mstp_MstInstance)
	}

	key := MstId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.MstInstance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list MstInstance", key)
	}

	t.MstInstance[key] = &Stp_Mstp_MstInstance{
		MstId: &MstId,
	}

	return t.MstInstance[key], nil
}

// RenameMstInstance renames an entry in the list MstInstance within
// the Stp_Mstp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Stp_Mstp) RenameMstInstance(oldK, newK uint16) error {
	if _, ok := t.MstInstance[newK]; ok {
		return fmt.Errorf("key %v already exists in MstInstance", newK)
	}

	e, ok := t.MstInstance[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in MstInstance", oldK)
	}
	e.MstId = &newK

	t.MstInstance[newK] = e
	delete(t.MstInstance, oldK)
	return nil
}

// GetOrCreateMstInstance retrieves the value with the specified keys from
// the receiver Stp_Mstp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Stp_Mstp) GetOrCreateMstInstance(MstId uint16) *Stp_Mstp_MstInstance {

	key := MstId

	if v, ok := t.MstInstance[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewMstInstance(MstId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateMstInstance got unexpected error: %v", err))
	}
	return v
}

// GetMstInstance retrieves the value with the specified key from
// the MstInstance map field of Stp_Mstp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Stp_Mstp) GetMstInstance(MstId uint16) *Stp_Mstp_MstInstance {

	if t == nil {
		return nil
	}

	key := MstId

	if lm, ok := t.MstInstance[key]; ok {
		return lm
	}
	return nil
}

// AppendMstInstance appends the supplied Stp_Mstp_MstInstance struct to the
// list MstInstance of Stp_Mstp. If the key value(s) specified in
// the supplied Stp_Mstp_MstInstance already exist in the list, an error is
// returned.
func (t *Stp_Mstp) AppendMstInstance(v *Stp_Mstp_MstInstance) error {
	if v.MstId == nil {
		return fmt.Errorf("invalid nil key received for MstId")
	}

	key := *v.MstId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MstInstance == nil {
		t.MstInstance = make(map[uint16]*Stp_Mstp_MstInstance)
	}

	if _, ok := t.MstInstance[key]; ok {
		return fmt.Errorf("duplicate key for list MstInstance %v", key)
	}

	t.MstInstance[key] = v
	return nil
}

// GetForwardingDelay retrieves the value of the leaf ForwardingDelay from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingDelay is set, it can safely use t.GetForwardingDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingDelay == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetForwardingDelay() uint8 {
	if t == nil || t.ForwardingDelay == nil {
		return 0
	}
	return *t.ForwardingDelay
}

// GetHelloTime retrieves the value of the leaf HelloTime from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloTime is set, it can safely use t.GetHelloTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloTime == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetHelloTime() uint8 {
	if t == nil || t.HelloTime == nil {
		return 0
	}
	return *t.HelloTime
}

// GetHoldCount retrieves the value of the leaf HoldCount from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldCount is set, it can safely use t.GetHoldCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldCount == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetHoldCount() uint8 {
	if t == nil || t.HoldCount == nil {
		return 6
	}
	return *t.HoldCount
}

// GetMaxAge retrieves the value of the leaf MaxAge from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxAge is set, it can safely use t.GetMaxAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxAge == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetMaxAge() uint8 {
	if t == nil || t.MaxAge == nil {
		return 0
	}
	return *t.MaxAge
}

// GetMaxHop retrieves the value of the leaf MaxHop from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxHop is set, it can safely use t.GetMaxHop()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxHop == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetMaxHop() uint8 {
	if t == nil || t.MaxHop == nil {
		return 0
	}
	return *t.MaxHop
}

// GetName retrieves the value of the leaf Name from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetRevision retrieves the value of the leaf Revision from the Stp_Mstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Revision is set, it can safely use t.GetRevision()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Revision == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp) GetRevision() uint32 {
	if t == nil || t.Revision == nil {
		return 0
	}
	return *t.Revision
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Mstp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Mstp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Mstp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Mstp_MstInstance represents the /openconfig-spanning-tree/stp/mstp/mst-instances/mst-instance YANG schema element.
type Stp_Mstp_MstInstance struct {
	ΛMetadata               []ygot.Annotation                          `path:"@" ygotAnnotation:"true"`
	BridgeAddress           *string                                    `path:"state/bridge-address" module:"openconfig-spanning-tree"`
	ΛBridgeAddress          []ygot.Annotation                          `path:"state/@bridge-address" ygotAnnotation:"true"`
	BridgePriority          *uint32                                    `path:"state/bridge-priority" shadow-path:"config/bridge-priority" module:"openconfig-spanning-tree"`
	ΛBridgePriority         []ygot.Annotation                          `path:"state/@bridge-priority" ygotAnnotation:"true"`
	DesignatedRootAddress   *string                                    `path:"state/designated-root-address" module:"openconfig-spanning-tree"`
	ΛDesignatedRootAddress  []ygot.Annotation                          `path:"state/@designated-root-address" ygotAnnotation:"true"`
	DesignatedRootPriority  *uint32                                    `path:"state/designated-root-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedRootPriority []ygot.Annotation                          `path:"state/@designated-root-priority" ygotAnnotation:"true"`
	HoldTime                *uint8                                     `path:"state/hold-time" module:"openconfig-spanning-tree"`
	ΛHoldTime               []ygot.Annotation                          `path:"state/@hold-time" ygotAnnotation:"true"`
	Interface               map[string]*Stp_Mstp_MstInstance_Interface `path:"interfaces/interface" module:"openconfig-spanning-tree"`
	ΛInterface              []ygot.Annotation                          `path:"interfaces/@interface" ygotAnnotation:"true"`
	LastTopologyChange      *uint64                                    `path:"state/last-topology-change" module:"openconfig-spanning-tree"`
	ΛLastTopologyChange     []ygot.Annotation                          `path:"state/@last-topology-change" ygotAnnotation:"true"`
	MstId                   *uint16                                    `path:"state/mst-id|mst-id" shadow-path:"config/mst-id" module:"openconfig-spanning-tree"`
	ΛMstId                  []ygot.Annotation                          `path:"state/@mst-id|@mst-id" ygotAnnotation:"true"`
	RootCost                *uint32                                    `path:"state/root-cost" module:"openconfig-spanning-tree"`
	ΛRootCost               []ygot.Annotation                          `path:"state/@root-cost" ygotAnnotation:"true"`
	RootPort                *uint16                                    `path:"state/root-port" module:"openconfig-spanning-tree"`
	ΛRootPort               []ygot.Annotation                          `path:"state/@root-port" ygotAnnotation:"true"`
	TopologyChanges         *uint64                                    `path:"state/topology-changes" module:"openconfig-spanning-tree"`
	ΛTopologyChanges        []ygot.Annotation                          `path:"state/@topology-changes" ygotAnnotation:"true"`
	Vlan                    []Stp_Mstp_MstInstance_Vlan_Union          `path:"state/vlan" shadow-path:"config/vlan" module:"openconfig-spanning-tree"`
	ΛVlan                   []ygot.Annotation                          `path:"state/@vlan" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Mstp_MstInstance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Mstp_MstInstance) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// Stp_Mstp_MstInstance struct. The keys of the list are populated from the input
// arguments.
func (t *Stp_Mstp_MstInstance) NewInterface(Name string) (*Stp_Mstp_MstInstance_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Mstp_MstInstance_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Stp_Mstp_MstInstance_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Stp_Mstp_MstInstance struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Stp_Mstp_MstInstance) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Stp_Mstp_MstInstance. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Stp_Mstp_MstInstance) GetOrCreateInterface(Name string) *Stp_Mstp_MstInstance_Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Stp_Mstp_MstInstance. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Stp_Mstp_MstInstance) GetInterface(Name string) *Stp_Mstp_MstInstance_Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Stp_Mstp_MstInstance_Interface struct to the
// list Interface of Stp_Mstp_MstInstance. If the key value(s) specified in
// the supplied Stp_Mstp_MstInstance_Interface already exist in the list, an error is
// returned.
func (t *Stp_Mstp_MstInstance) AppendInterface(v *Stp_Mstp_MstInstance_Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Mstp_MstInstance_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetBridgeAddress retrieves the value of the leaf BridgeAddress from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgeAddress is set, it can safely use t.GetBridgeAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgeAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetBridgeAddress() string {
	if t == nil || t.BridgeAddress == nil {
		return ""
	}
	return *t.BridgeAddress
}

// GetBridgePriority retrieves the value of the leaf BridgePriority from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgePriority is set, it can safely use t.GetBridgePriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgePriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetBridgePriority() uint32 {
	if t == nil || t.BridgePriority == nil {
		return 0
	}
	return *t.BridgePriority
}

// GetDesignatedRootAddress retrieves the value of the leaf DesignatedRootAddress from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootAddress is set, it can safely use t.GetDesignatedRootAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetDesignatedRootAddress() string {
	if t == nil || t.DesignatedRootAddress == nil {
		return ""
	}
	return *t.DesignatedRootAddress
}

// GetDesignatedRootPriority retrieves the value of the leaf DesignatedRootPriority from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootPriority is set, it can safely use t.GetDesignatedRootPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetDesignatedRootPriority() uint32 {
	if t == nil || t.DesignatedRootPriority == nil {
		return 0
	}
	return *t.DesignatedRootPriority
}

// GetHoldTime retrieves the value of the leaf HoldTime from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetHoldTime() uint8 {
	if t == nil || t.HoldTime == nil {
		return 0
	}
	return *t.HoldTime
}

// GetLastTopologyChange retrieves the value of the leaf LastTopologyChange from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastTopologyChange is set, it can safely use t.GetLastTopologyChange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastTopologyChange == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetLastTopologyChange() uint64 {
	if t == nil || t.LastTopologyChange == nil {
		return 0
	}
	return *t.LastTopologyChange
}

// GetMstId retrieves the value of the leaf MstId from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MstId is set, it can safely use t.GetMstId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MstId == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetMstId() uint16 {
	if t == nil || t.MstId == nil {
		return 0
	}
	return *t.MstId
}

// GetRootCost retrieves the value of the leaf RootCost from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootCost is set, it can safely use t.GetRootCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootCost == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetRootCost() uint32 {
	if t == nil || t.RootCost == nil {
		return 0
	}
	return *t.RootCost
}

// GetRootPort retrieves the value of the leaf RootPort from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootPort is set, it can safely use t.GetRootPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootPort == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetRootPort() uint16 {
	if t == nil || t.RootPort == nil {
		return 0
	}
	return *t.RootPort
}

// GetTopologyChanges retrieves the value of the leaf TopologyChanges from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TopologyChanges is set, it can safely use t.GetTopologyChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TopologyChanges == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetTopologyChanges() uint64 {
	if t == nil || t.TopologyChanges == nil {
		return 0
	}
	return *t.TopologyChanges
}

// GetVlan retrieves the value of the leaf Vlan from the Stp_Mstp_MstInstance
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Vlan is set, it can safely use t.GetVlan()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Vlan == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance) GetVlan() []Stp_Mstp_MstInstance_Vlan_Union {
	if t == nil || t.Vlan == nil {
		return nil
	}
	return t.Vlan
}

// ΛListKeyMap returns the keys of the Stp_Mstp_MstInstance struct, which is a YANG list entry.
func (t *Stp_Mstp_MstInstance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MstId == nil {
		return nil, fmt.Errorf("nil value for key MstId")
	}

	return map[string]interface{}{
		"mst-id": *t.MstId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Mstp_MstInstance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Mstp_MstInstance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Mstp_MstInstance) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Mstp_MstInstance_Vlan_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-spanning-tree/stp/mstp/mst-instances/mst-instance/state/vlan within the YANG schema.
// Union type can be one of [UnionString, UnionUint16].
type Stp_Mstp_MstInstance_Vlan_Union interface {
	// Union type can be one of [UnionString, UnionUint16]
	Documentation_for_Stp_Mstp_MstInstance_Vlan_Union()
}

// Documentation_for_Stp_Mstp_MstInstance_Vlan_Union ensures that UnionString
// implements the Stp_Mstp_MstInstance_Vlan_Union interface.
func (UnionString) Documentation_for_Stp_Mstp_MstInstance_Vlan_Union() {}

// Documentation_for_Stp_Mstp_MstInstance_Vlan_Union ensures that UnionUint16
// implements the Stp_Mstp_MstInstance_Vlan_Union interface.
func (UnionUint16) Documentation_for_Stp_Mstp_MstInstance_Vlan_Union() {}

// To_Stp_Mstp_MstInstance_Vlan_Union takes an input interface{} and attempts to convert it to a struct
// which implements the Stp_Mstp_MstInstance_Vlan_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *Stp_Mstp_MstInstance) To_Stp_Mstp_MstInstance_Vlan_Union(i interface{}) (Stp_Mstp_MstInstance_Vlan_Union, error) {
	if v, ok := i.(Stp_Mstp_MstInstance_Vlan_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	case uint16:
		return UnionUint16(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to Stp_Mstp_MstInstance_Vlan_Union, unknown union type, got: %T, want any of [string, uint16]", i, i)
}

// Stp_Mstp_MstInstance_Interface represents the /openconfig-spanning-tree/stp/mstp/mst-instances/mst-instance/interfaces/interface YANG schema element.
type Stp_Mstp_MstInstance_Interface struct {
	ΛMetadata                 []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	Cost                      *uint32                                      `path:"state/cost" shadow-path:"config/cost" module:"openconfig-spanning-tree"`
	ΛCost                     []ygot.Annotation                            `path:"state/@cost" ygotAnnotation:"true"`
	Counters                  *Stp_Mstp_MstInstance_Interface_Counters     `path:"state/counters" module:"openconfig-spanning-tree"`
	ΛCounters                 []ygot.Annotation                            `path:"state/@counters" ygotAnnotation:"true"`
	DesignatedBridgeAddress   *string                                      `path:"state/designated-bridge-address" module:"openconfig-spanning-tree"`
	ΛDesignatedBridgeAddress  []ygot.Annotation                            `path:"state/@designated-bridge-address" ygotAnnotation:"true"`
	DesignatedBridgePriority  *uint32                                      `path:"state/designated-bridge-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedBridgePriority []ygot.Annotation                            `path:"state/@designated-bridge-priority" ygotAnnotation:"true"`
	DesignatedCost            *uint32                                      `path:"state/designated-cost" module:"openconfig-spanning-tree"`
	ΛDesignatedCost           []ygot.Annotation                            `path:"state/@designated-cost" ygotAnnotation:"true"`
	DesignatedPortNum         *uint16                                      `path:"state/designated-port-num" module:"openconfig-spanning-tree"`
	ΛDesignatedPortNum        []ygot.Annotation                            `path:"state/@designated-port-num" ygotAnnotation:"true"`
	DesignatedPortPriority    *uint8                                       `path:"state/designated-port-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedPortPriority   []ygot.Annotation                            `path:"state/@designated-port-priority" ygotAnnotation:"true"`
	DesignatedRootAddress     *string                                      `path:"state/designated-root-address" module:"openconfig-spanning-tree"`
	ΛDesignatedRootAddress    []ygot.Annotation                            `path:"state/@designated-root-address" ygotAnnotation:"true"`
	DesignatedRootPriority    *uint32                                      `path:"state/designated-root-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedRootPriority   []ygot.Annotation                            `path:"state/@designated-root-priority" ygotAnnotation:"true"`
	ForwardTransisitions      *uint64                                      `path:"state/forward-transisitions" module:"openconfig-spanning-tree"`
	ΛForwardTransisitions     []ygot.Annotation                            `path:"state/@forward-transisitions" ygotAnnotation:"true"`
	Name                      *string                                      `path:"state/name|name" shadow-path:"config/name" module:"openconfig-spanning-tree"`
	ΛName                     []ygot.Annotation                            `path:"state/@name|@name" ygotAnnotation:"true"`
	PortNum                   *uint16                                      `path:"state/port-num" module:"openconfig-spanning-tree"`
	ΛPortNum                  []ygot.Annotation                            `path:"state/@port-num" ygotAnnotation:"true"`
	PortPriority              *uint8                                       `path:"state/port-priority" shadow-path:"config/port-priority" module:"openconfig-spanning-tree"`
	ΛPortPriority             []ygot.Annotation                            `path:"state/@port-priority" ygotAnnotation:"true"`
	PortState                 E_OpenconfigSpanningTreeTypes_STP_PORT_STATE `path:"state/port-state" module:"openconfig-spanning-tree"`
	ΛPortState                []ygot.Annotation                            `path:"state/@port-state" ygotAnnotation:"true"`
	Role                      E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE  `path:"state/role" module:"openconfig-spanning-tree"`
	ΛRole                     []ygot.Annotation                            `path:"state/@role" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Mstp_MstInstance_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Mstp_MstInstance_Interface) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Stp_Mstp_MstInstance_Interface) GetOrCreateCounters() *Stp_Mstp_MstInstance_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Stp_Mstp_MstInstance_Interface_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from Stp_Mstp_MstInstance_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Stp_Mstp_MstInstance_Interface) GetCounters() *Stp_Mstp_MstInstance_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetCost retrieves the value of the leaf Cost from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Cost is set, it can safely use t.GetCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Cost == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetCost() uint32 {
	if t == nil || t.Cost == nil {
		return 0
	}
	return *t.Cost
}

// GetDesignatedBridgeAddress retrieves the value of the leaf DesignatedBridgeAddress from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedBridgeAddress is set, it can safely use t.GetDesignatedBridgeAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedBridgeAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedBridgeAddress() string {
	if t == nil || t.DesignatedBridgeAddress == nil {
		return ""
	}
	return *t.DesignatedBridgeAddress
}

// GetDesignatedBridgePriority retrieves the value of the leaf DesignatedBridgePriority from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedBridgePriority is set, it can safely use t.GetDesignatedBridgePriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedBridgePriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedBridgePriority() uint32 {
	if t == nil || t.DesignatedBridgePriority == nil {
		return 0
	}
	return *t.DesignatedBridgePriority
}

// GetDesignatedCost retrieves the value of the leaf DesignatedCost from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedCost is set, it can safely use t.GetDesignatedCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedCost == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedCost() uint32 {
	if t == nil || t.DesignatedCost == nil {
		return 0
	}
	return *t.DesignatedCost
}

// GetDesignatedPortNum retrieves the value of the leaf DesignatedPortNum from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedPortNum is set, it can safely use t.GetDesignatedPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedPortNum == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedPortNum() uint16 {
	if t == nil || t.DesignatedPortNum == nil {
		return 0
	}
	return *t.DesignatedPortNum
}

// GetDesignatedPortPriority retrieves the value of the leaf DesignatedPortPriority from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedPortPriority is set, it can safely use t.GetDesignatedPortPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedPortPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedPortPriority() uint8 {
	if t == nil || t.DesignatedPortPriority == nil {
		return 0
	}
	return *t.DesignatedPortPriority
}

// GetDesignatedRootAddress retrieves the value of the leaf DesignatedRootAddress from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootAddress is set, it can safely use t.GetDesignatedRootAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedRootAddress() string {
	if t == nil || t.DesignatedRootAddress == nil {
		return ""
	}
	return *t.DesignatedRootAddress
}

// GetDesignatedRootPriority retrieves the value of the leaf DesignatedRootPriority from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootPriority is set, it can safely use t.GetDesignatedRootPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetDesignatedRootPriority() uint32 {
	if t == nil || t.DesignatedRootPriority == nil {
		return 0
	}
	return *t.DesignatedRootPriority
}

// GetForwardTransisitions retrieves the value of the leaf ForwardTransisitions from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardTransisitions is set, it can safely use t.GetForwardTransisitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardTransisitions == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetForwardTransisitions() uint64 {
	if t == nil || t.ForwardTransisitions == nil {
		return 0
	}
	return *t.ForwardTransisitions
}

// GetName retrieves the value of the leaf Name from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPortNum retrieves the value of the leaf PortNum from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortNum is set, it can safely use t.GetPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortNum == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetPortNum() uint16 {
	if t == nil || t.PortNum == nil {
		return 0
	}
	return *t.PortNum
}

// GetPortPriority retrieves the value of the leaf PortPriority from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortPriority is set, it can safely use t.GetPortPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetPortPriority() uint8 {
	if t == nil || t.PortPriority == nil {
		return 0
	}
	return *t.PortPriority
}

// GetPortState retrieves the value of the leaf PortState from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortState is set, it can safely use t.GetPortState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortState == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetPortState() E_OpenconfigSpanningTreeTypes_STP_PORT_STATE {
	if t == nil || t.PortState == 0 {
		return 0
	}
	return t.PortState
}

// GetRole retrieves the value of the leaf Role from the Stp_Mstp_MstInstance_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Role is set, it can safely use t.GetRole()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Role == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface) GetRole() E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE {
	if t == nil || t.Role == 0 {
		return 0
	}
	return t.Role
}

// ΛListKeyMap returns the keys of the Stp_Mstp_MstInstance_Interface struct, which is a YANG list entry.
func (t *Stp_Mstp_MstInstance_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Mstp_MstInstance_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Mstp_MstInstance_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Mstp_MstInstance_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Stp_Mstp_MstInstance_Interface_Counters represents the /openconfig-spanning-tree/stp/mstp/mst-instances/mst-instance/interfaces/interface/state/counters YANG schema element.
type Stp_Mstp_MstInstance_Interface_Counters struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BpduReceived  *uint64           `path:"bpdu-received" module:"openconfig-spanning-tree"`
	ΛBpduReceived []ygot.Annotation `path:"@bpdu-received" ygotAnnotation:"true"`
	BpduSent      *uint64           `path:"bpdu-sent" module:"openconfig-spanning-tree"`
	ΛBpduSent     []ygot.Annotation `path:"@bpdu-sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Mstp_MstInstance_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Mstp_MstInstance_Interface_Counters) IsYANGGoStruct() {}

// GetBpduReceived retrieves the value of the leaf BpduReceived from the Stp_Mstp_MstInstance_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduReceived is set, it can safely use t.GetBpduReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduReceived == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface_Counters) GetBpduReceived() uint64 {
	if t == nil || t.BpduReceived == nil {
		return 0
	}
	return *t.BpduReceived
}

// GetBpduSent retrieves the value of the leaf BpduSent from the Stp_Mstp_MstInstance_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduSent is set, it can safely use t.GetBpduSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduSent == nil'
// before retrieving the leaf's value.
func (t *Stp_Mstp_MstInstance_Interface_Counters) GetBpduSent() uint64 {
	if t == nil || t.BpduSent == nil {
		return 0
	}
	return *t.BpduSent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Mstp_MstInstance_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Mstp_MstInstance_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Mstp_MstInstance_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// Stp_Rstp represents the /openconfig-spanning-tree/stp/rstp YANG schema element.
type Stp_Rstp struct {
	ΛMetadata               []ygot.Annotation              `path:"@" ygotAnnotation:"true"`
	BridgeAddress           *string                        `path:"state/bridge-address" module:"openconfig-spanning-tree"`
	ΛBridgeAddress          []ygot.Annotation              `path:"state/@bridge-address" ygotAnnotation:"true"`
	BridgePriority          *uint32                        `path:"state/bridge-priority" shadow-path:"config/bridge-priority" module:"openconfig-spanning-tree"`
	ΛBridgePriority         []ygot.Annotation              `path:"state/@bridge-priority" ygotAnnotation:"true"`
	DesignatedRootAddress   *string                        `path:"state/designated-root-address" module:"openconfig-spanning-tree"`
	ΛDesignatedRootAddress  []ygot.Annotation              `path:"state/@designated-root-address" ygotAnnotation:"true"`
	DesignatedRootPriority  *uint32                        `path:"state/designated-root-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedRootPriority []ygot.Annotation              `path:"state/@designated-root-priority" ygotAnnotation:"true"`
	ForwardingDelay         *uint8                         `path:"state/forwarding-delay" shadow-path:"config/forwarding-delay" module:"openconfig-spanning-tree"`
	ΛForwardingDelay        []ygot.Annotation              `path:"state/@forwarding-delay" ygotAnnotation:"true"`
	HelloTime               *uint8                         `path:"state/hello-time" shadow-path:"config/hello-time" module:"openconfig-spanning-tree"`
	ΛHelloTime              []ygot.Annotation              `path:"state/@hello-time" ygotAnnotation:"true"`
	HoldCount               *uint8                         `path:"state/hold-count" shadow-path:"config/hold-count" module:"openconfig-spanning-tree"`
	ΛHoldCount              []ygot.Annotation              `path:"state/@hold-count" ygotAnnotation:"true"`
	HoldTime                *uint8                         `path:"state/hold-time" module:"openconfig-spanning-tree"`
	ΛHoldTime               []ygot.Annotation              `path:"state/@hold-time" ygotAnnotation:"true"`
	Interface               map[string]*Stp_Rstp_Interface `path:"interfaces/interface" module:"openconfig-spanning-tree"`
	ΛInterface              []ygot.Annotation              `path:"interfaces/@interface" ygotAnnotation:"true"`
	LastTopologyChange      *uint64                        `path:"state/last-topology-change" module:"openconfig-spanning-tree"`
	ΛLastTopologyChange     []ygot.Annotation              `path:"state/@last-topology-change" ygotAnnotation:"true"`
	MaxAge                  *uint8                         `path:"state/max-age" shadow-path:"config/max-age" module:"openconfig-spanning-tree"`
	ΛMaxAge                 []ygot.Annotation              `path:"state/@max-age" ygotAnnotation:"true"`
	RootCost                *uint32                        `path:"state/root-cost" module:"openconfig-spanning-tree"`
	ΛRootCost               []ygot.Annotation              `path:"state/@root-cost" ygotAnnotation:"true"`
	RootPort                *uint16                        `path:"state/root-port" module:"openconfig-spanning-tree"`
	ΛRootPort               []ygot.Annotation              `path:"state/@root-port" ygotAnnotation:"true"`
	TopologyChanges         *uint64                        `path:"state/topology-changes" module:"openconfig-spanning-tree"`
	ΛTopologyChanges        []ygot.Annotation              `path:"state/@topology-changes" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Rstp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Rstp) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// Stp_Rstp struct. The keys of the list are populated from the input
// arguments.
func (t *Stp_Rstp) NewInterface(Name string) (*Stp_Rstp_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Rstp_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Stp_Rstp_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Stp_Rstp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Stp_Rstp) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Stp_Rstp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Stp_Rstp) GetOrCreateInterface(Name string) *Stp_Rstp_Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Stp_Rstp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Stp_Rstp) GetInterface(Name string) *Stp_Rstp_Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Stp_Rstp_Interface struct to the
// list Interface of Stp_Rstp. If the key value(s) specified in
// the supplied Stp_Rstp_Interface already exist in the list, an error is
// returned.
func (t *Stp_Rstp) AppendInterface(v *Stp_Rstp_Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Rstp_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetBridgeAddress retrieves the value of the leaf BridgeAddress from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgeAddress is set, it can safely use t.GetBridgeAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgeAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetBridgeAddress() string {
	if t == nil || t.BridgeAddress == nil {
		return ""
	}
	return *t.BridgeAddress
}

// GetBridgePriority retrieves the value of the leaf BridgePriority from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgePriority is set, it can safely use t.GetBridgePriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgePriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetBridgePriority() uint32 {
	if t == nil || t.BridgePriority == nil {
		return 0
	}
	return *t.BridgePriority
}

// GetDesignatedRootAddress retrieves the value of the leaf DesignatedRootAddress from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootAddress is set, it can safely use t.GetDesignatedRootAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetDesignatedRootAddress() string {
	if t == nil || t.DesignatedRootAddress == nil {
		return ""
	}
	return *t.DesignatedRootAddress
}

// GetDesignatedRootPriority retrieves the value of the leaf DesignatedRootPriority from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootPriority is set, it can safely use t.GetDesignatedRootPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetDesignatedRootPriority() uint32 {
	if t == nil || t.DesignatedRootPriority == nil {
		return 0
	}
	return *t.DesignatedRootPriority
}

// GetForwardingDelay retrieves the value of the leaf ForwardingDelay from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingDelay is set, it can safely use t.GetForwardingDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingDelay == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetForwardingDelay() uint8 {
	if t == nil || t.ForwardingDelay == nil {
		return 0
	}
	return *t.ForwardingDelay
}

// GetHelloTime retrieves the value of the leaf HelloTime from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloTime is set, it can safely use t.GetHelloTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloTime == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetHelloTime() uint8 {
	if t == nil || t.HelloTime == nil {
		return 0
	}
	return *t.HelloTime
}

// GetHoldCount retrieves the value of the leaf HoldCount from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldCount is set, it can safely use t.GetHoldCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldCount == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetHoldCount() uint8 {
	if t == nil || t.HoldCount == nil {
		return 6
	}
	return *t.HoldCount
}

// GetHoldTime retrieves the value of the leaf HoldTime from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetHoldTime() uint8 {
	if t == nil || t.HoldTime == nil {
		return 0
	}
	return *t.HoldTime
}

// GetLastTopologyChange retrieves the value of the leaf LastTopologyChange from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastTopologyChange is set, it can safely use t.GetLastTopologyChange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastTopologyChange == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetLastTopologyChange() uint64 {
	if t == nil || t.LastTopologyChange == nil {
		return 0
	}
	return *t.LastTopologyChange
}

// GetMaxAge retrieves the value of the leaf MaxAge from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxAge is set, it can safely use t.GetMaxAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxAge == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetMaxAge() uint8 {
	if t == nil || t.MaxAge == nil {
		return 0
	}
	return *t.MaxAge
}

// GetRootCost retrieves the value of the leaf RootCost from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootCost is set, it can safely use t.GetRootCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootCost == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetRootCost() uint32 {
	if t == nil || t.RootCost == nil {
		return 0
	}
	return *t.RootCost
}

// GetRootPort retrieves the value of the leaf RootPort from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootPort is set, it can safely use t.GetRootPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootPort == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetRootPort() uint16 {
	if t == nil || t.RootPort == nil {
		return 0
	}
	return *t.RootPort
}

// GetTopologyChanges retrieves the value of the leaf TopologyChanges from the Stp_Rstp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TopologyChanges is set, it can safely use t.GetTopologyChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TopologyChanges == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp) GetTopologyChanges() uint64 {
	if t == nil || t.TopologyChanges == nil {
		return 0
	}
	return *t.TopologyChanges
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Rstp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Rstp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Rstp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Rstp_Interface represents the /openconfig-spanning-tree/stp/rstp/interfaces/interface YANG schema element.
type Stp_Rstp_Interface struct {
	ΛMetadata                 []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	Cost                      *uint32                                      `path:"state/cost" shadow-path:"config/cost" module:"openconfig-spanning-tree"`
	ΛCost                     []ygot.Annotation                            `path:"state/@cost" ygotAnnotation:"true"`
	Counters                  *Stp_Rstp_Interface_Counters                 `path:"state/counters" module:"openconfig-spanning-tree"`
	ΛCounters                 []ygot.Annotation                            `path:"state/@counters" ygotAnnotation:"true"`
	DesignatedBridgeAddress   *string                                      `path:"state/designated-bridge-address" module:"openconfig-spanning-tree"`
	ΛDesignatedBridgeAddress  []ygot.Annotation                            `path:"state/@designated-bridge-address" ygotAnnotation:"true"`
	DesignatedBridgePriority  *uint32                                      `path:"state/designated-bridge-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedBridgePriority []ygot.Annotation                            `path:"state/@designated-bridge-priority" ygotAnnotation:"true"`
	DesignatedCost            *uint32                                      `path:"state/designated-cost" module:"openconfig-spanning-tree"`
	ΛDesignatedCost           []ygot.Annotation                            `path:"state/@designated-cost" ygotAnnotation:"true"`
	DesignatedPortNum         *uint16                                      `path:"state/designated-port-num" module:"openconfig-spanning-tree"`
	ΛDesignatedPortNum        []ygot.Annotation                            `path:"state/@designated-port-num" ygotAnnotation:"true"`
	DesignatedPortPriority    *uint8                                       `path:"state/designated-port-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedPortPriority   []ygot.Annotation                            `path:"state/@designated-port-priority" ygotAnnotation:"true"`
	DesignatedRootAddress     *string                                      `path:"state/designated-root-address" module:"openconfig-spanning-tree"`
	ΛDesignatedRootAddress    []ygot.Annotation                            `path:"state/@designated-root-address" ygotAnnotation:"true"`
	DesignatedRootPriority    *uint32                                      `path:"state/designated-root-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedRootPriority   []ygot.Annotation                            `path:"state/@designated-root-priority" ygotAnnotation:"true"`
	ForwardTransisitions      *uint64                                      `path:"state/forward-transisitions" module:"openconfig-spanning-tree"`
	ΛForwardTransisitions     []ygot.Annotation                            `path:"state/@forward-transisitions" ygotAnnotation:"true"`
	Name                      *string                                      `path:"state/name|name" shadow-path:"config/name" module:"openconfig-spanning-tree"`
	ΛName                     []ygot.Annotation                            `path:"state/@name|@name" ygotAnnotation:"true"`
	PortNum                   *uint16                                      `path:"state/port-num" module:"openconfig-spanning-tree"`
	ΛPortNum                  []ygot.Annotation                            `path:"state/@port-num" ygotAnnotation:"true"`
	PortPriority              *uint8                                       `path:"state/port-priority" shadow-path:"config/port-priority" module:"openconfig-spanning-tree"`
	ΛPortPriority             []ygot.Annotation                            `path:"state/@port-priority" ygotAnnotation:"true"`
	PortState                 E_OpenconfigSpanningTreeTypes_STP_PORT_STATE `path:"state/port-state" module:"openconfig-spanning-tree"`
	ΛPortState                []ygot.Annotation                            `path:"state/@port-state" ygotAnnotation:"true"`
	Role                      E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE  `path:"state/role" module:"openconfig-spanning-tree"`
	ΛRole                     []ygot.Annotation                            `path:"state/@role" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Rstp_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Rstp_Interface) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Stp_Rstp_Interface) GetOrCreateCounters() *Stp_Rstp_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Stp_Rstp_Interface_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from Stp_Rstp_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Stp_Rstp_Interface) GetCounters() *Stp_Rstp_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetCost retrieves the value of the leaf Cost from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Cost is set, it can safely use t.GetCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Cost == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetCost() uint32 {
	if t == nil || t.Cost == nil {
		return 0
	}
	return *t.Cost
}

// GetDesignatedBridgeAddress retrieves the value of the leaf DesignatedBridgeAddress from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedBridgeAddress is set, it can safely use t.GetDesignatedBridgeAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedBridgeAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedBridgeAddress() string {
	if t == nil || t.DesignatedBridgeAddress == nil {
		return ""
	}
	return *t.DesignatedBridgeAddress
}

// GetDesignatedBridgePriority retrieves the value of the leaf DesignatedBridgePriority from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedBridgePriority is set, it can safely use t.GetDesignatedBridgePriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedBridgePriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedBridgePriority() uint32 {
	if t == nil || t.DesignatedBridgePriority == nil {
		return 0
	}
	return *t.DesignatedBridgePriority
}

// GetDesignatedCost retrieves the value of the leaf DesignatedCost from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedCost is set, it can safely use t.GetDesignatedCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedCost == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedCost() uint32 {
	if t == nil || t.DesignatedCost == nil {
		return 0
	}
	return *t.DesignatedCost
}

// GetDesignatedPortNum retrieves the value of the leaf DesignatedPortNum from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedPortNum is set, it can safely use t.GetDesignatedPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedPortNum == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedPortNum() uint16 {
	if t == nil || t.DesignatedPortNum == nil {
		return 0
	}
	return *t.DesignatedPortNum
}

// GetDesignatedPortPriority retrieves the value of the leaf DesignatedPortPriority from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedPortPriority is set, it can safely use t.GetDesignatedPortPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedPortPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedPortPriority() uint8 {
	if t == nil || t.DesignatedPortPriority == nil {
		return 0
	}
	return *t.DesignatedPortPriority
}

// GetDesignatedRootAddress retrieves the value of the leaf DesignatedRootAddress from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootAddress is set, it can safely use t.GetDesignatedRootAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedRootAddress() string {
	if t == nil || t.DesignatedRootAddress == nil {
		return ""
	}
	return *t.DesignatedRootAddress
}

// GetDesignatedRootPriority retrieves the value of the leaf DesignatedRootPriority from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootPriority is set, it can safely use t.GetDesignatedRootPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetDesignatedRootPriority() uint32 {
	if t == nil || t.DesignatedRootPriority == nil {
		return 0
	}
	return *t.DesignatedRootPriority
}

// GetForwardTransisitions retrieves the value of the leaf ForwardTransisitions from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardTransisitions is set, it can safely use t.GetForwardTransisitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardTransisitions == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetForwardTransisitions() uint64 {
	if t == nil || t.ForwardTransisitions == nil {
		return 0
	}
	return *t.ForwardTransisitions
}

// GetName retrieves the value of the leaf Name from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPortNum retrieves the value of the leaf PortNum from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortNum is set, it can safely use t.GetPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortNum == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetPortNum() uint16 {
	if t == nil || t.PortNum == nil {
		return 0
	}
	return *t.PortNum
}

// GetPortPriority retrieves the value of the leaf PortPriority from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortPriority is set, it can safely use t.GetPortPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetPortPriority() uint8 {
	if t == nil || t.PortPriority == nil {
		return 0
	}
	return *t.PortPriority
}

// GetPortState retrieves the value of the leaf PortState from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortState is set, it can safely use t.GetPortState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortState == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetPortState() E_OpenconfigSpanningTreeTypes_STP_PORT_STATE {
	if t == nil || t.PortState == 0 {
		return 0
	}
	return t.PortState
}

// GetRole retrieves the value of the leaf Role from the Stp_Rstp_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Role is set, it can safely use t.GetRole()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Role == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface) GetRole() E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE {
	if t == nil || t.Role == 0 {
		return 0
	}
	return t.Role
}

// ΛListKeyMap returns the keys of the Stp_Rstp_Interface struct, which is a YANG list entry.
func (t *Stp_Rstp_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Rstp_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Rstp_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Rstp_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Rstp_Interface_Counters represents the /openconfig-spanning-tree/stp/rstp/interfaces/interface/state/counters YANG schema element.
type Stp_Rstp_Interface_Counters struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BpduReceived  *uint64           `path:"bpdu-received" module:"openconfig-spanning-tree"`
	ΛBpduReceived []ygot.Annotation `path:"@bpdu-received" ygotAnnotation:"true"`
	BpduSent      *uint64           `path:"bpdu-sent" module:"openconfig-spanning-tree"`
	ΛBpduSent     []ygot.Annotation `path:"@bpdu-sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Rstp_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Rstp_Interface_Counters) IsYANGGoStruct() {}

// GetBpduReceived retrieves the value of the leaf BpduReceived from the Stp_Rstp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduReceived is set, it can safely use t.GetBpduReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduReceived == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface_Counters) GetBpduReceived() uint64 {
	if t == nil || t.BpduReceived == nil {
		return 0
	}
	return *t.BpduReceived
}

// GetBpduSent retrieves the value of the leaf BpduSent from the Stp_Rstp_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduSent is set, it can safely use t.GetBpduSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduSent == nil'
// before retrieving the leaf's value.
func (t *Stp_Rstp_Interface_Counters) GetBpduSent() uint64 {
	if t == nil || t.BpduSent == nil {
		return 0
	}
	return *t.BpduSent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Rstp_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Rstp_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Rstp_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Vlan represents the /openconfig-spanning-tree/stp/rapid-pvst/vlan YANG schema element.
type Stp_Vlan struct {
	ΛMetadata               []ygot.Annotation              `path:"@" ygotAnnotation:"true"`
	BridgeAddress           *string                        `path:"state/bridge-address" module:"openconfig-spanning-tree"`
	ΛBridgeAddress          []ygot.Annotation              `path:"state/@bridge-address" ygotAnnotation:"true"`
	BridgePriority          *uint32                        `path:"state/bridge-priority" shadow-path:"config/bridge-priority" module:"openconfig-spanning-tree"`
	ΛBridgePriority         []ygot.Annotation              `path:"state/@bridge-priority" ygotAnnotation:"true"`
	DesignatedRootAddress   *string                        `path:"state/designated-root-address" module:"openconfig-spanning-tree"`
	ΛDesignatedRootAddress  []ygot.Annotation              `path:"state/@designated-root-address" ygotAnnotation:"true"`
	DesignatedRootPriority  *uint32                        `path:"state/designated-root-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedRootPriority []ygot.Annotation              `path:"state/@designated-root-priority" ygotAnnotation:"true"`
	ForwardingDelay         *uint8                         `path:"state/forwarding-delay" shadow-path:"config/forwarding-delay" module:"openconfig-spanning-tree"`
	ΛForwardingDelay        []ygot.Annotation              `path:"state/@forwarding-delay" ygotAnnotation:"true"`
	HelloTime               *uint8                         `path:"state/hello-time" shadow-path:"config/hello-time" module:"openconfig-spanning-tree"`
	ΛHelloTime              []ygot.Annotation              `path:"state/@hello-time" ygotAnnotation:"true"`
	HoldCount               *uint8                         `path:"state/hold-count" shadow-path:"config/hold-count" module:"openconfig-spanning-tree"`
	ΛHoldCount              []ygot.Annotation              `path:"state/@hold-count" ygotAnnotation:"true"`
	HoldTime                *uint8                         `path:"state/hold-time" module:"openconfig-spanning-tree"`
	ΛHoldTime               []ygot.Annotation              `path:"state/@hold-time" ygotAnnotation:"true"`
	Interface               map[string]*Stp_Vlan_Interface `path:"interfaces/interface" module:"openconfig-spanning-tree"`
	ΛInterface              []ygot.Annotation              `path:"interfaces/@interface" ygotAnnotation:"true"`
	LastTopologyChange      *uint64                        `path:"state/last-topology-change" module:"openconfig-spanning-tree"`
	ΛLastTopologyChange     []ygot.Annotation              `path:"state/@last-topology-change" ygotAnnotation:"true"`
	MaxAge                  *uint8                         `path:"state/max-age" shadow-path:"config/max-age" module:"openconfig-spanning-tree"`
	ΛMaxAge                 []ygot.Annotation              `path:"state/@max-age" ygotAnnotation:"true"`
	RootCost                *uint32                        `path:"state/root-cost" module:"openconfig-spanning-tree"`
	ΛRootCost               []ygot.Annotation              `path:"state/@root-cost" ygotAnnotation:"true"`
	RootPort                *uint16                        `path:"state/root-port" module:"openconfig-spanning-tree"`
	ΛRootPort               []ygot.Annotation              `path:"state/@root-port" ygotAnnotation:"true"`
	TopologyChanges         *uint64                        `path:"state/topology-changes" module:"openconfig-spanning-tree"`
	ΛTopologyChanges        []ygot.Annotation              `path:"state/@topology-changes" ygotAnnotation:"true"`
	VlanId                  *uint16                        `path:"state/vlan-id|vlan-id" shadow-path:"config/vlan-id" module:"openconfig-spanning-tree"`
	ΛVlanId                 []ygot.Annotation              `path:"state/@vlan-id|@vlan-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Vlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Vlan) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// Stp_Vlan struct. The keys of the list are populated from the input
// arguments.
func (t *Stp_Vlan) NewInterface(Name string) (*Stp_Vlan_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Vlan_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &Stp_Vlan_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// RenameInterface renames an entry in the list Interface within
// the Stp_Vlan struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *Stp_Vlan) RenameInterface(oldK, newK string) error {
	if _, ok := t.Interface[newK]; ok {
		return fmt.Errorf("key %v already exists in Interface", newK)
	}

	e, ok := t.Interface[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Interface", oldK)
	}
	e.Name = &newK

	t.Interface[newK] = e
	delete(t.Interface, oldK)
	return nil
}

// GetOrCreateInterface retrieves the value with the specified keys from
// the receiver Stp_Vlan. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *Stp_Vlan) GetOrCreateInterface(Name string) *Stp_Vlan_Interface {

	key := Name

	if v, ok := t.Interface[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewInterface(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateInterface got unexpected error: %v", err))
	}
	return v
}

// GetInterface retrieves the value with the specified key from
// the Interface map field of Stp_Vlan. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *Stp_Vlan) GetInterface(Name string) *Stp_Vlan_Interface {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.Interface[key]; ok {
		return lm
	}
	return nil
}

// AppendInterface appends the supplied Stp_Vlan_Interface struct to the
// list Interface of Stp_Vlan. If the key value(s) specified in
// the supplied Stp_Vlan_Interface already exist in the list, an error is
// returned.
func (t *Stp_Vlan) AppendInterface(v *Stp_Vlan_Interface) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*Stp_Vlan_Interface)
	}

	if _, ok := t.Interface[key]; ok {
		return fmt.Errorf("duplicate key for list Interface %v", key)
	}

	t.Interface[key] = v
	return nil
}

// GetBridgeAddress retrieves the value of the leaf BridgeAddress from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgeAddress is set, it can safely use t.GetBridgeAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgeAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetBridgeAddress() string {
	if t == nil || t.BridgeAddress == nil {
		return ""
	}
	return *t.BridgeAddress
}

// GetBridgePriority retrieves the value of the leaf BridgePriority from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BridgePriority is set, it can safely use t.GetBridgePriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BridgePriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetBridgePriority() uint32 {
	if t == nil || t.BridgePriority == nil {
		return 0
	}
	return *t.BridgePriority
}

// GetDesignatedRootAddress retrieves the value of the leaf DesignatedRootAddress from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootAddress is set, it can safely use t.GetDesignatedRootAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetDesignatedRootAddress() string {
	if t == nil || t.DesignatedRootAddress == nil {
		return ""
	}
	return *t.DesignatedRootAddress
}

// GetDesignatedRootPriority retrieves the value of the leaf DesignatedRootPriority from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootPriority is set, it can safely use t.GetDesignatedRootPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetDesignatedRootPriority() uint32 {
	if t == nil || t.DesignatedRootPriority == nil {
		return 0
	}
	return *t.DesignatedRootPriority
}

// GetForwardingDelay retrieves the value of the leaf ForwardingDelay from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardingDelay is set, it can safely use t.GetForwardingDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardingDelay == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetForwardingDelay() uint8 {
	if t == nil || t.ForwardingDelay == nil {
		return 0
	}
	return *t.ForwardingDelay
}

// GetHelloTime retrieves the value of the leaf HelloTime from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HelloTime is set, it can safely use t.GetHelloTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HelloTime == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetHelloTime() uint8 {
	if t == nil || t.HelloTime == nil {
		return 0
	}
	return *t.HelloTime
}

// GetHoldCount retrieves the value of the leaf HoldCount from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldCount is set, it can safely use t.GetHoldCount()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldCount == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetHoldCount() uint8 {
	if t == nil || t.HoldCount == nil {
		return 6
	}
	return *t.HoldCount
}

// GetHoldTime retrieves the value of the leaf HoldTime from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if HoldTime is set, it can safely use t.GetHoldTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.HoldTime == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetHoldTime() uint8 {
	if t == nil || t.HoldTime == nil {
		return 0
	}
	return *t.HoldTime
}

// GetLastTopologyChange retrieves the value of the leaf LastTopologyChange from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastTopologyChange is set, it can safely use t.GetLastTopologyChange()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastTopologyChange == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetLastTopologyChange() uint64 {
	if t == nil || t.LastTopologyChange == nil {
		return 0
	}
	return *t.LastTopologyChange
}

// GetMaxAge retrieves the value of the leaf MaxAge from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxAge is set, it can safely use t.GetMaxAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxAge == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetMaxAge() uint8 {
	if t == nil || t.MaxAge == nil {
		return 0
	}
	return *t.MaxAge
}

// GetRootCost retrieves the value of the leaf RootCost from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootCost is set, it can safely use t.GetRootCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootCost == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetRootCost() uint32 {
	if t == nil || t.RootCost == nil {
		return 0
	}
	return *t.RootCost
}

// GetRootPort retrieves the value of the leaf RootPort from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootPort is set, it can safely use t.GetRootPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootPort == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetRootPort() uint16 {
	if t == nil || t.RootPort == nil {
		return 0
	}
	return *t.RootPort
}

// GetTopologyChanges retrieves the value of the leaf TopologyChanges from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TopologyChanges is set, it can safely use t.GetTopologyChanges()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TopologyChanges == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetTopologyChanges() uint64 {
	if t == nil || t.TopologyChanges == nil {
		return 0
	}
	return *t.TopologyChanges
}

// GetVlanId retrieves the value of the leaf VlanId from the Stp_Vlan
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VlanId is set, it can safely use t.GetVlanId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VlanId == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan) GetVlanId() uint16 {
	if t == nil || t.VlanId == nil {
		return 0
	}
	return *t.VlanId
}

// ΛListKeyMap returns the keys of the Stp_Vlan struct, which is a YANG list entry.
func (t *Stp_Vlan) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VlanId == nil {
		return nil, fmt.Errorf("nil value for key VlanId")
	}

	return map[string]interface{}{
		"vlan-id": *t.VlanId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Vlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Vlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Vlan) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Vlan_Interface represents the /openconfig-spanning-tree/stp/rapid-pvst/vlan/interfaces/interface YANG schema element.
type Stp_Vlan_Interface struct {
	ΛMetadata                 []ygot.Annotation                            `path:"@" ygotAnnotation:"true"`
	Cost                      *uint32                                      `path:"state/cost" shadow-path:"config/cost" module:"openconfig-spanning-tree"`
	ΛCost                     []ygot.Annotation                            `path:"state/@cost" ygotAnnotation:"true"`
	Counters                  *Stp_Vlan_Interface_Counters                 `path:"state/counters" module:"openconfig-spanning-tree"`
	ΛCounters                 []ygot.Annotation                            `path:"state/@counters" ygotAnnotation:"true"`
	DesignatedBridgeAddress   *string                                      `path:"state/designated-bridge-address" module:"openconfig-spanning-tree"`
	ΛDesignatedBridgeAddress  []ygot.Annotation                            `path:"state/@designated-bridge-address" ygotAnnotation:"true"`
	DesignatedBridgePriority  *uint32                                      `path:"state/designated-bridge-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedBridgePriority []ygot.Annotation                            `path:"state/@designated-bridge-priority" ygotAnnotation:"true"`
	DesignatedCost            *uint32                                      `path:"state/designated-cost" module:"openconfig-spanning-tree"`
	ΛDesignatedCost           []ygot.Annotation                            `path:"state/@designated-cost" ygotAnnotation:"true"`
	DesignatedPortNum         *uint16                                      `path:"state/designated-port-num" module:"openconfig-spanning-tree"`
	ΛDesignatedPortNum        []ygot.Annotation                            `path:"state/@designated-port-num" ygotAnnotation:"true"`
	DesignatedPortPriority    *uint8                                       `path:"state/designated-port-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedPortPriority   []ygot.Annotation                            `path:"state/@designated-port-priority" ygotAnnotation:"true"`
	DesignatedRootAddress     *string                                      `path:"state/designated-root-address" module:"openconfig-spanning-tree"`
	ΛDesignatedRootAddress    []ygot.Annotation                            `path:"state/@designated-root-address" ygotAnnotation:"true"`
	DesignatedRootPriority    *uint32                                      `path:"state/designated-root-priority" module:"openconfig-spanning-tree"`
	ΛDesignatedRootPriority   []ygot.Annotation                            `path:"state/@designated-root-priority" ygotAnnotation:"true"`
	ForwardTransisitions      *uint64                                      `path:"state/forward-transisitions" module:"openconfig-spanning-tree"`
	ΛForwardTransisitions     []ygot.Annotation                            `path:"state/@forward-transisitions" ygotAnnotation:"true"`
	Name                      *string                                      `path:"state/name|name" shadow-path:"config/name" module:"openconfig-spanning-tree"`
	ΛName                     []ygot.Annotation                            `path:"state/@name|@name" ygotAnnotation:"true"`
	PortNum                   *uint16                                      `path:"state/port-num" module:"openconfig-spanning-tree"`
	ΛPortNum                  []ygot.Annotation                            `path:"state/@port-num" ygotAnnotation:"true"`
	PortPriority              *uint8                                       `path:"state/port-priority" shadow-path:"config/port-priority" module:"openconfig-spanning-tree"`
	ΛPortPriority             []ygot.Annotation                            `path:"state/@port-priority" ygotAnnotation:"true"`
	PortState                 E_OpenconfigSpanningTreeTypes_STP_PORT_STATE `path:"state/port-state" module:"openconfig-spanning-tree"`
	ΛPortState                []ygot.Annotation                            `path:"state/@port-state" ygotAnnotation:"true"`
	Role                      E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE  `path:"state/role" module:"openconfig-spanning-tree"`
	ΛRole                     []ygot.Annotation                            `path:"state/@role" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Vlan_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Vlan_Interface) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *Stp_Vlan_Interface) GetOrCreateCounters() *Stp_Vlan_Interface_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &Stp_Vlan_Interface_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from Stp_Vlan_Interface. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *Stp_Vlan_Interface) GetCounters() *Stp_Vlan_Interface_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetCost retrieves the value of the leaf Cost from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Cost is set, it can safely use t.GetCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Cost == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetCost() uint32 {
	if t == nil || t.Cost == nil {
		return 0
	}
	return *t.Cost
}

// GetDesignatedBridgeAddress retrieves the value of the leaf DesignatedBridgeAddress from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedBridgeAddress is set, it can safely use t.GetDesignatedBridgeAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedBridgeAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedBridgeAddress() string {
	if t == nil || t.DesignatedBridgeAddress == nil {
		return ""
	}
	return *t.DesignatedBridgeAddress
}

// GetDesignatedBridgePriority retrieves the value of the leaf DesignatedBridgePriority from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedBridgePriority is set, it can safely use t.GetDesignatedBridgePriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedBridgePriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedBridgePriority() uint32 {
	if t == nil || t.DesignatedBridgePriority == nil {
		return 0
	}
	return *t.DesignatedBridgePriority
}

// GetDesignatedCost retrieves the value of the leaf DesignatedCost from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedCost is set, it can safely use t.GetDesignatedCost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedCost == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedCost() uint32 {
	if t == nil || t.DesignatedCost == nil {
		return 0
	}
	return *t.DesignatedCost
}

// GetDesignatedPortNum retrieves the value of the leaf DesignatedPortNum from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedPortNum is set, it can safely use t.GetDesignatedPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedPortNum == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedPortNum() uint16 {
	if t == nil || t.DesignatedPortNum == nil {
		return 0
	}
	return *t.DesignatedPortNum
}

// GetDesignatedPortPriority retrieves the value of the leaf DesignatedPortPriority from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedPortPriority is set, it can safely use t.GetDesignatedPortPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedPortPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedPortPriority() uint8 {
	if t == nil || t.DesignatedPortPriority == nil {
		return 0
	}
	return *t.DesignatedPortPriority
}

// GetDesignatedRootAddress retrieves the value of the leaf DesignatedRootAddress from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootAddress is set, it can safely use t.GetDesignatedRootAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootAddress == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedRootAddress() string {
	if t == nil || t.DesignatedRootAddress == nil {
		return ""
	}
	return *t.DesignatedRootAddress
}

// GetDesignatedRootPriority retrieves the value of the leaf DesignatedRootPriority from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DesignatedRootPriority is set, it can safely use t.GetDesignatedRootPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DesignatedRootPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetDesignatedRootPriority() uint32 {
	if t == nil || t.DesignatedRootPriority == nil {
		return 0
	}
	return *t.DesignatedRootPriority
}

// GetForwardTransisitions retrieves the value of the leaf ForwardTransisitions from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ForwardTransisitions is set, it can safely use t.GetForwardTransisitions()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ForwardTransisitions == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetForwardTransisitions() uint64 {
	if t == nil || t.ForwardTransisitions == nil {
		return 0
	}
	return *t.ForwardTransisitions
}

// GetName retrieves the value of the leaf Name from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPortNum retrieves the value of the leaf PortNum from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortNum is set, it can safely use t.GetPortNum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortNum == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetPortNum() uint16 {
	if t == nil || t.PortNum == nil {
		return 0
	}
	return *t.PortNum
}

// GetPortPriority retrieves the value of the leaf PortPriority from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortPriority is set, it can safely use t.GetPortPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortPriority == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetPortPriority() uint8 {
	if t == nil || t.PortPriority == nil {
		return 0
	}
	return *t.PortPriority
}

// GetPortState retrieves the value of the leaf PortState from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortState is set, it can safely use t.GetPortState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortState == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetPortState() E_OpenconfigSpanningTreeTypes_STP_PORT_STATE {
	if t == nil || t.PortState == 0 {
		return 0
	}
	return t.PortState
}

// GetRole retrieves the value of the leaf Role from the Stp_Vlan_Interface
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Role is set, it can safely use t.GetRole()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Role == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface) GetRole() E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE {
	if t == nil || t.Role == 0 {
		return 0
	}
	return t.Role
}

// ΛListKeyMap returns the keys of the Stp_Vlan_Interface struct, which is a YANG list entry.
func (t *Stp_Vlan_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Vlan_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Vlan_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Vlan_Interface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// Stp_Vlan_Interface_Counters represents the /openconfig-spanning-tree/stp/rapid-pvst/vlan/interfaces/interface/state/counters YANG schema element.
type Stp_Vlan_Interface_Counters struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	BpduReceived  *uint64           `path:"bpdu-received" module:"openconfig-spanning-tree"`
	ΛBpduReceived []ygot.Annotation `path:"@bpdu-received" ygotAnnotation:"true"`
	BpduSent      *uint64           `path:"bpdu-sent" module:"openconfig-spanning-tree"`
	ΛBpduSent     []ygot.Annotation `path:"@bpdu-sent" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that Stp_Vlan_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Stp_Vlan_Interface_Counters) IsYANGGoStruct() {}

// GetBpduReceived retrieves the value of the leaf BpduReceived from the Stp_Vlan_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduReceived is set, it can safely use t.GetBpduReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduReceived == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface_Counters) GetBpduReceived() uint64 {
	if t == nil || t.BpduReceived == nil {
		return 0
	}
	return *t.BpduReceived
}

// GetBpduSent retrieves the value of the leaf BpduSent from the Stp_Vlan_Interface_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BpduSent is set, it can safely use t.GetBpduSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BpduSent == nil'
// before retrieving the leaf's value.
func (t *Stp_Vlan_Interface_Counters) GetBpduSent() uint64 {
	if t == nil || t.BpduSent == nil {
		return 0
	}
	return *t.BpduSent
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Stp_Vlan_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Stp_Vlan_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Stp_Vlan_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System represents the /openconfig-system/system YANG schema element.
type System struct {
	ΛMetadata        []ygot.Annotation                      `path:"@" ygotAnnotation:"true"`
	Aaa              *System_Aaa                            `path:"aaa" module:"openconfig-system"`
	ΛAaa             []ygot.Annotation                      `path:"@aaa" ygotAnnotation:"true"`
	Alarm            map[string]*System_Alarm               `path:"alarms/alarm" module:"openconfig-system"`
	ΛAlarm           []ygot.Annotation                      `path:"alarms/@alarm" ygotAnnotation:"true"`
	BootTime         *uint64                                `path:"state/boot-time" module:"openconfig-system"`
	ΛBootTime        []ygot.Annotation                      `path:"state/@boot-time" ygotAnnotation:"true"`
	Clock            *System_Clock                          `path:"clock" module:"openconfig-system"`
	ΛClock           []ygot.Annotation                      `path:"@clock" ygotAnnotation:"true"`
	Cpu              map[System_Cpu_Index_Union]*System_Cpu `path:"cpus/cpu" module:"openconfig-system"`
	ΛCpu             []ygot.Annotation                      `path:"cpus/@cpu" ygotAnnotation:"true"`
	CurrentDatetime  *string                                `path:"state/current-datetime" module:"openconfig-system"`
	ΛCurrentDatetime []ygot.Annotation                      `path:"state/@current-datetime" ygotAnnotation:"true"`
	Dns              *System_Dns                            `path:"dns" module:"openconfig-system"`
	ΛDns             []ygot.Annotation                      `path:"@dns" ygotAnnotation:"true"`
	DomainName       *string                                `path:"state/domain-name" shadow-path:"config/domain-name" module:"openconfig-system"`
	ΛDomainName      []ygot.Annotation                      `path:"state/@domain-name" ygotAnnotation:"true"`
	GrpcServer       *System_GrpcServer                     `path:"grpc-server" module:"openconfig-system"`
	ΛGrpcServer      []ygot.Annotation                      `path:"@grpc-server" ygotAnnotation:"true"`
	Hostname         *string                                `path:"state/hostname" shadow-path:"config/hostname" module:"openconfig-system"`
	ΛHostname        []ygot.Annotation                      `path:"state/@hostname" ygotAnnotation:"true"`
	License          *System_License                        `path:"license" module:"openconfig-system"`
	ΛLicense         []ygot.Annotation                      `path:"@license" ygotAnnotation:"true"`
	Logging          *System_Logging                        `path:"logging" module:"openconfig-system"`
	ΛLogging         []ygot.Annotation                      `path:"@logging" ygotAnnotation:"true"`
	LoginBanner      *string                                `path:"state/login-banner" shadow-path:"config/login-banner" module:"openconfig-system"`
	ΛLoginBanner     []ygot.Annotation                      `path:"state/@login-banner" ygotAnnotation:"true"`
	Memory           *System_Memory                         `path:"memory" module:"openconfig-system"`
	ΛMemory          []ygot.Annotation                      `path:"@memory" ygotAnnotation:"true"`
	Messages         *System_Messages                       `path:"messages" module:"openconfig-system"`
	ΛMessages        []ygot.Annotation                      `path:"@messages" ygotAnnotation:"true"`
	MotdBanner       *string                                `path:"state/motd-banner" shadow-path:"config/motd-banner" module:"openconfig-system"`
	ΛMotdBanner      []ygot.Annotation                      `path:"state/@motd-banner" ygotAnnotation:"true"`
	Ntp              *System_Ntp                            `path:"ntp" module:"openconfig-system"`
	ΛNtp             []ygot.Annotation                      `path:"@ntp" ygotAnnotation:"true"`
	Process          map[uint64]*System_Process             `path:"processes/process" module:"openconfig-system"`
	ΛProcess         []ygot.Annotation                      `path:"processes/@process" ygotAnnotation:"true"`
	SshServer        *System_SshServer                      `path:"ssh-server" module:"openconfig-system"`
	ΛSshServer       []ygot.Annotation                      `path:"@ssh-server" ygotAnnotation:"true"`
	TelnetServer     *System_TelnetServer                   `path:"telnet-server" module:"openconfig-system"`
	ΛTelnetServer    []ygot.Annotation                      `path:"@telnet-server" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System) IsYANGGoStruct() {}

// NewAlarm creates a new entry in the Alarm list of the
// System struct. The keys of the list are populated from the input
// arguments.
func (t *System) NewAlarm(Id string) (*System_Alarm, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Alarm == nil {
		t.Alarm = make(map[string]*System_Alarm)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Alarm[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Alarm", key)
	}

	t.Alarm[key] = &System_Alarm{
		Id: &Id,
	}

	return t.Alarm[key], nil
}

// RenameAlarm renames an entry in the list Alarm within
// the System struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System) RenameAlarm(oldK, newK string) error {
	if _, ok := t.Alarm[newK]; ok {
		return fmt.Errorf("key %v already exists in Alarm", newK)
	}

	e, ok := t.Alarm[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Alarm", oldK)
	}
	e.Id = &newK

	t.Alarm[newK] = e
	delete(t.Alarm, oldK)
	return nil
}

// GetOrCreateAlarm retrieves the value with the specified keys from
// the receiver System. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System) GetOrCreateAlarm(Id string) *System_Alarm {

	key := Id

	if v, ok := t.Alarm[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAlarm(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAlarm got unexpected error: %v", err))
	}
	return v
}

// GetAlarm retrieves the value with the specified key from
// the Alarm map field of System. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System) GetAlarm(Id string) *System_Alarm {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Alarm[key]; ok {
		return lm
	}
	return nil
}

// AppendAlarm appends the supplied System_Alarm struct to the
// list Alarm of System. If the key value(s) specified in
// the supplied System_Alarm already exist in the list, an error is
// returned.
func (t *System) AppendAlarm(v *System_Alarm) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Alarm == nil {
		t.Alarm = make(map[string]*System_Alarm)
	}

	if _, ok := t.Alarm[key]; ok {
		return fmt.Errorf("duplicate key for list Alarm %v", key)
	}

	t.Alarm[key] = v
	return nil
}

// NewCpu creates a new entry in the Cpu list of the
// System struct. The keys of the list are populated from the input
// arguments.
func (t *System) NewCpu(Index System_Cpu_Index_Union) (*System_Cpu, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Cpu == nil {
		t.Cpu = make(map[System_Cpu_Index_Union]*System_Cpu)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Cpu[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Cpu", key)
	}

	t.Cpu[key] = &System_Cpu{
		Index: Index,
	}

	return t.Cpu[key], nil
}

// RenameCpu renames an entry in the list Cpu within
// the System struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System) RenameCpu(oldK, newK System_Cpu_Index_Union) error {
	if _, ok := t.Cpu[newK]; ok {
		return fmt.Errorf("key %v already exists in Cpu", newK)
	}

	e, ok := t.Cpu[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Cpu", oldK)
	}
	e.Index = newK

	t.Cpu[newK] = e
	delete(t.Cpu, oldK)
	return nil
}

// GetOrCreateCpu retrieves the value with the specified keys from
// the receiver System. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System) GetOrCreateCpu(Index System_Cpu_Index_Union) *System_Cpu {

	key := Index

	if v, ok := t.Cpu[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewCpu(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateCpu got unexpected error: %v", err))
	}
	return v
}

// GetCpu retrieves the value with the specified key from
// the Cpu map field of System. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System) GetCpu(Index System_Cpu_Index_Union) *System_Cpu {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Cpu[key]; ok {
		return lm
	}
	return nil
}

// AppendCpu appends the supplied System_Cpu struct to the
// list Cpu of System. If the key value(s) specified in
// the supplied System_Cpu already exist in the list, an error is
// returned.
func (t *System) AppendCpu(v *System_Cpu) error {
	key := v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Cpu == nil {
		t.Cpu = make(map[System_Cpu_Index_Union]*System_Cpu)
	}

	if _, ok := t.Cpu[key]; ok {
		return fmt.Errorf("duplicate key for list Cpu %v", key)
	}

	t.Cpu[key] = v
	return nil
}

// NewProcess creates a new entry in the Process list of the
// System struct. The keys of the list are populated from the input
// arguments.
func (t *System) NewProcess(Pid uint64) (*System_Process, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Process == nil {
		t.Process = make(map[uint64]*System_Process)
	}

	key := Pid

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Process[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Process", key)
	}

	t.Process[key] = &System_Process{
		Pid: &Pid,
	}

	return t.Process[key], nil
}

// RenameProcess renames an entry in the list Process within
// the System struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System) RenameProcess(oldK, newK uint64) error {
	if _, ok := t.Process[newK]; ok {
		return fmt.Errorf("key %v already exists in Process", newK)
	}

	e, ok := t.Process[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Process", oldK)
	}
	e.Pid = &newK

	t.Process[newK] = e
	delete(t.Process, oldK)
	return nil
}

// GetOrCreateProcess retrieves the value with the specified keys from
// the receiver System. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System) GetOrCreateProcess(Pid uint64) *System_Process {

	key := Pid

	if v, ok := t.Process[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewProcess(Pid)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateProcess got unexpected error: %v", err))
	}
	return v
}

// GetProcess retrieves the value with the specified key from
// the Process map field of System. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System) GetProcess(Pid uint64) *System_Process {

	if t == nil {
		return nil
	}

	key := Pid

	if lm, ok := t.Process[key]; ok {
		return lm
	}
	return nil
}

// AppendProcess appends the supplied System_Process struct to the
// list Process of System. If the key value(s) specified in
// the supplied System_Process already exist in the list, an error is
// returned.
func (t *System) AppendProcess(v *System_Process) error {
	if v.Pid == nil {
		return fmt.Errorf("invalid nil key received for Pid")
	}

	key := *v.Pid

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Process == nil {
		t.Process = make(map[uint64]*System_Process)
	}

	if _, ok := t.Process[key]; ok {
		return fmt.Errorf("duplicate key for list Process %v", key)
	}

	t.Process[key] = v
	return nil
}

// GetOrCreateAaa retrieves the value of the Aaa field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateAaa() *System_Aaa {
	if t.Aaa != nil {
		return t.Aaa
	}
	t.Aaa = &System_Aaa{}
	return t.Aaa
}

// GetOrCreateClock retrieves the value of the Clock field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateClock() *System_Clock {
	if t.Clock != nil {
		return t.Clock
	}
	t.Clock = &System_Clock{}
	return t.Clock
}

// GetOrCreateDns retrieves the value of the Dns field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateDns() *System_Dns {
	if t.Dns != nil {
		return t.Dns
	}
	t.Dns = &System_Dns{}
	return t.Dns
}

// GetOrCreateGrpcServer retrieves the value of the GrpcServer field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateGrpcServer() *System_GrpcServer {
	if t.GrpcServer != nil {
		return t.GrpcServer
	}
	t.GrpcServer = &System_GrpcServer{}
	return t.GrpcServer
}

// GetOrCreateLicense retrieves the value of the License field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateLicense() *System_License {
	if t.License != nil {
		return t.License
	}
	t.License = &System_License{}
	return t.License
}

// GetOrCreateLogging retrieves the value of the Logging field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateLogging() *System_Logging {
	if t.Logging != nil {
		return t.Logging
	}
	t.Logging = &System_Logging{}
	return t.Logging
}

// GetOrCreateMemory retrieves the value of the Memory field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateMemory() *System_Memory {
	if t.Memory != nil {
		return t.Memory
	}
	t.Memory = &System_Memory{}
	return t.Memory
}

// GetOrCreateMessages retrieves the value of the Messages field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateMessages() *System_Messages {
	if t.Messages != nil {
		return t.Messages
	}
	t.Messages = &System_Messages{}
	return t.Messages
}

// GetOrCreateNtp retrieves the value of the Ntp field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateNtp() *System_Ntp {
	if t.Ntp != nil {
		return t.Ntp
	}
	t.Ntp = &System_Ntp{}
	return t.Ntp
}

// GetOrCreateSshServer retrieves the value of the SshServer field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateSshServer() *System_SshServer {
	if t.SshServer != nil {
		return t.SshServer
	}
	t.SshServer = &System_SshServer{}
	return t.SshServer
}

// GetOrCreateTelnetServer retrieves the value of the TelnetServer field
// or returns the existing field if it already exists.
func (t *System) GetOrCreateTelnetServer() *System_TelnetServer {
	if t.TelnetServer != nil {
		return t.TelnetServer
	}
	t.TelnetServer = &System_TelnetServer{}
	return t.TelnetServer
}

// GetAaa returns the value of the Aaa struct pointer
// from System. If the receiver or the field Aaa is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetAaa() *System_Aaa {
	if t != nil && t.Aaa != nil {
		return t.Aaa
	}
	return nil
}

// GetClock returns the value of the Clock struct pointer
// from System. If the receiver or the field Clock is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetClock() *System_Clock {
	if t != nil && t.Clock != nil {
		return t.Clock
	}
	return nil
}

// GetDns returns the value of the Dns struct pointer
// from System. If the receiver or the field Dns is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetDns() *System_Dns {
	if t != nil && t.Dns != nil {
		return t.Dns
	}
	return nil
}

// GetGrpcServer returns the value of the GrpcServer struct pointer
// from System. If the receiver or the field GrpcServer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetGrpcServer() *System_GrpcServer {
	if t != nil && t.GrpcServer != nil {
		return t.GrpcServer
	}
	return nil
}

// GetLicense returns the value of the License struct pointer
// from System. If the receiver or the field License is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetLicense() *System_License {
	if t != nil && t.License != nil {
		return t.License
	}
	return nil
}

// GetLogging returns the value of the Logging struct pointer
// from System. If the receiver or the field Logging is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetLogging() *System_Logging {
	if t != nil && t.Logging != nil {
		return t.Logging
	}
	return nil
}

// GetMemory returns the value of the Memory struct pointer
// from System. If the receiver or the field Memory is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetMemory() *System_Memory {
	if t != nil && t.Memory != nil {
		return t.Memory
	}
	return nil
}

// GetMessages returns the value of the Messages struct pointer
// from System. If the receiver or the field Messages is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetMessages() *System_Messages {
	if t != nil && t.Messages != nil {
		return t.Messages
	}
	return nil
}

// GetNtp returns the value of the Ntp struct pointer
// from System. If the receiver or the field Ntp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetNtp() *System_Ntp {
	if t != nil && t.Ntp != nil {
		return t.Ntp
	}
	return nil
}

// GetSshServer returns the value of the SshServer struct pointer
// from System. If the receiver or the field SshServer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetSshServer() *System_SshServer {
	if t != nil && t.SshServer != nil {
		return t.SshServer
	}
	return nil
}

// GetTelnetServer returns the value of the TelnetServer struct pointer
// from System. If the receiver or the field TelnetServer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System) GetTelnetServer() *System_TelnetServer {
	if t != nil && t.TelnetServer != nil {
		return t.TelnetServer
	}
	return nil
}

// GetBootTime retrieves the value of the leaf BootTime from the System
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BootTime is set, it can safely use t.GetBootTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BootTime == nil'
// before retrieving the leaf's value.
func (t *System) GetBootTime() uint64 {
	if t == nil || t.BootTime == nil {
		return 0
	}
	return *t.BootTime
}

// GetCurrentDatetime retrieves the value of the leaf CurrentDatetime from the System
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CurrentDatetime is set, it can safely use t.GetCurrentDatetime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CurrentDatetime == nil'
// before retrieving the leaf's value.
func (t *System) GetCurrentDatetime() string {
	if t == nil || t.CurrentDatetime == nil {
		return ""
	}
	return *t.CurrentDatetime
}

// GetDomainName retrieves the value of the leaf DomainName from the System
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if DomainName is set, it can safely use t.GetDomainName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.DomainName == nil'
// before retrieving the leaf's value.
func (t *System) GetDomainName() string {
	if t == nil || t.DomainName == nil {
		return ""
	}
	return *t.DomainName
}

// GetHostname retrieves the value of the leaf Hostname from the System
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Hostname is set, it can safely use t.GetHostname()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Hostname == nil'
// before retrieving the leaf's value.
func (t *System) GetHostname() string {
	if t == nil || t.Hostname == nil {
		return ""
	}
	return *t.Hostname
}

// GetLoginBanner retrieves the value of the leaf LoginBanner from the System
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LoginBanner is set, it can safely use t.GetLoginBanner()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LoginBanner == nil'
// before retrieving the leaf's value.
func (t *System) GetLoginBanner() string {
	if t == nil || t.LoginBanner == nil {
		return ""
	}
	return *t.LoginBanner
}

// GetMotdBanner retrieves the value of the leaf MotdBanner from the System
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MotdBanner is set, it can safely use t.GetMotdBanner()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MotdBanner == nil'
// before retrieving the leaf's value.
func (t *System) GetMotdBanner() string {
	if t == nil || t.MotdBanner == nil {
		return ""
	}
	return *t.MotdBanner
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa represents the /openconfig-system/system/aaa YANG schema element.
type System_Aaa struct {
	ΛMetadata       []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Accounting      *System_Aaa_Accounting             `path:"accounting" module:"openconfig-system"`
	ΛAccounting     []ygot.Annotation                  `path:"@accounting" ygotAnnotation:"true"`
	Authentication  *System_Aaa_Authentication         `path:"authentication" module:"openconfig-system"`
	ΛAuthentication []ygot.Annotation                  `path:"@authentication" ygotAnnotation:"true"`
	Authorization   *System_Aaa_Authorization          `path:"authorization" module:"openconfig-system"`
	ΛAuthorization  []ygot.Annotation                  `path:"@authorization" ygotAnnotation:"true"`
	ServerGroup     map[string]*System_Aaa_ServerGroup `path:"server-groups/server-group" module:"openconfig-system"`
	ΛServerGroup    []ygot.Annotation                  `path:"server-groups/@server-group" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa) IsYANGGoStruct() {}

// NewServerGroup creates a new entry in the ServerGroup list of the
// System_Aaa struct. The keys of the list are populated from the input
// arguments.
func (t *System_Aaa) NewServerGroup(Name string) (*System_Aaa_ServerGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ServerGroup == nil {
		t.ServerGroup = make(map[string]*System_Aaa_ServerGroup)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ServerGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ServerGroup", key)
	}

	t.ServerGroup[key] = &System_Aaa_ServerGroup{
		Name: &Name,
	}

	return t.ServerGroup[key], nil
}

// RenameServerGroup renames an entry in the list ServerGroup within
// the System_Aaa struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Aaa) RenameServerGroup(oldK, newK string) error {
	if _, ok := t.ServerGroup[newK]; ok {
		return fmt.Errorf("key %v already exists in ServerGroup", newK)
	}

	e, ok := t.ServerGroup[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in ServerGroup", oldK)
	}
	e.Name = &newK

	t.ServerGroup[newK] = e
	delete(t.ServerGroup, oldK)
	return nil
}

// GetOrCreateServerGroup retrieves the value with the specified keys from
// the receiver System_Aaa. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Aaa) GetOrCreateServerGroup(Name string) *System_Aaa_ServerGroup {

	key := Name

	if v, ok := t.ServerGroup[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewServerGroup(Name)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateServerGroup got unexpected error: %v", err))
	}
	return v
}

// GetServerGroup retrieves the value with the specified key from
// the ServerGroup map field of System_Aaa. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Aaa) GetServerGroup(Name string) *System_Aaa_ServerGroup {

	if t == nil {
		return nil
	}

	key := Name

	if lm, ok := t.ServerGroup[key]; ok {
		return lm
	}
	return nil
}

// AppendServerGroup appends the supplied System_Aaa_ServerGroup struct to the
// list ServerGroup of System_Aaa. If the key value(s) specified in
// the supplied System_Aaa_ServerGroup already exist in the list, an error is
// returned.
func (t *System_Aaa) AppendServerGroup(v *System_Aaa_ServerGroup) error {
	if v.Name == nil {
		return fmt.Errorf("invalid nil key received for Name")
	}

	key := *v.Name

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ServerGroup == nil {
		t.ServerGroup = make(map[string]*System_Aaa_ServerGroup)
	}

	if _, ok := t.ServerGroup[key]; ok {
		return fmt.Errorf("duplicate key for list ServerGroup %v", key)
	}

	t.ServerGroup[key] = v
	return nil
}

// GetOrCreateAccounting retrieves the value of the Accounting field
// or returns the existing field if it already exists.
func (t *System_Aaa) GetOrCreateAccounting() *System_Aaa_Accounting {
	if t.Accounting != nil {
		return t.Accounting
	}
	t.Accounting = &System_Aaa_Accounting{}
	return t.Accounting
}

// GetOrCreateAuthentication retrieves the value of the Authentication field
// or returns the existing field if it already exists.
func (t *System_Aaa) GetOrCreateAuthentication() *System_Aaa_Authentication {
	if t.Authentication != nil {
		return t.Authentication
	}
	t.Authentication = &System_Aaa_Authentication{}
	return t.Authentication
}

// GetOrCreateAuthorization retrieves the value of the Authorization field
// or returns the existing field if it already exists.
func (t *System_Aaa) GetOrCreateAuthorization() *System_Aaa_Authorization {
	if t.Authorization != nil {
		return t.Authorization
	}
	t.Authorization = &System_Aaa_Authorization{}
	return t.Authorization
}

// GetAccounting returns the value of the Accounting struct pointer
// from System_Aaa. If the receiver or the field Accounting is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa) GetAccounting() *System_Aaa_Accounting {
	if t != nil && t.Accounting != nil {
		return t.Accounting
	}
	return nil
}

// GetAuthentication returns the value of the Authentication struct pointer
// from System_Aaa. If the receiver or the field Authentication is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa) GetAuthentication() *System_Aaa_Authentication {
	if t != nil && t.Authentication != nil {
		return t.Authentication
	}
	return nil
}

// GetAuthorization returns the value of the Authorization struct pointer
// from System_Aaa. If the receiver or the field Authorization is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa) GetAuthorization() *System_Aaa_Authorization {
	if t != nil && t.Authorization != nil {
		return t.Authorization
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_Accounting represents the /openconfig-system/system/aaa/accounting YANG schema element.
type System_Aaa_Accounting struct {
	ΛMetadata         []ygot.Annotation                                                               `path:"@" ygotAnnotation:"true"`
	AccountingMethod  []System_Aaa_Accounting_AccountingMethod_Union                                  `path:"state/accounting-method" shadow-path:"config/accounting-method" module:"openconfig-system"`
	ΛAccountingMethod []ygot.Annotation                                                               `path:"state/@accounting-method" ygotAnnotation:"true"`
	Event             map[E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE]*System_Aaa_Accounting_Event `path:"events/event" module:"openconfig-system"`
	ΛEvent            []ygot.Annotation                                                               `path:"events/@event" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Accounting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Accounting) IsYANGGoStruct() {}

// NewEvent creates a new entry in the Event list of the
// System_Aaa_Accounting struct. The keys of the list are populated from the input
// arguments.
func (t *System_Aaa_Accounting) NewEvent(EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) (*System_Aaa_Accounting_Event, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Event == nil {
		t.Event = make(map[E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE]*System_Aaa_Accounting_Event)
	}

	key := EventType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Event[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Event", key)
	}

	t.Event[key] = &System_Aaa_Accounting_Event{
		EventType: EventType,
	}

	return t.Event[key], nil
}

// RenameEvent renames an entry in the list Event within
// the System_Aaa_Accounting struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Aaa_Accounting) RenameEvent(oldK, newK E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) error {
	if _, ok := t.Event[newK]; ok {
		return fmt.Errorf("key %v already exists in Event", newK)
	}

	e, ok := t.Event[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Event", oldK)
	}
	e.EventType = newK

	t.Event[newK] = e
	delete(t.Event, oldK)
	return nil
}

// GetOrCreateEvent retrieves the value with the specified keys from
// the receiver System_Aaa_Accounting. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Aaa_Accounting) GetOrCreateEvent(EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) *System_Aaa_Accounting_Event {

	key := EventType

	if v, ok := t.Event[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewEvent(EventType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateEvent got unexpected error: %v", err))
	}
	return v
}

// GetEvent retrieves the value with the specified key from
// the Event map field of System_Aaa_Accounting. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Aaa_Accounting) GetEvent(EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) *System_Aaa_Accounting_Event {

	if t == nil {
		return nil
	}

	key := EventType

	if lm, ok := t.Event[key]; ok {
		return lm
	}
	return nil
}

// AppendEvent appends the supplied System_Aaa_Accounting_Event struct to the
// list Event of System_Aaa_Accounting. If the key value(s) specified in
// the supplied System_Aaa_Accounting_Event already exist in the list, an error is
// returned.
func (t *System_Aaa_Accounting) AppendEvent(v *System_Aaa_Accounting_Event) error {
	key := v.EventType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Event == nil {
		t.Event = make(map[E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE]*System_Aaa_Accounting_Event)
	}

	if _, ok := t.Event[key]; ok {
		return fmt.Errorf("duplicate key for list Event %v", key)
	}

	t.Event[key] = v
	return nil
}

// GetAccountingMethod retrieves the value of the leaf AccountingMethod from the System_Aaa_Accounting
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AccountingMethod is set, it can safely use t.GetAccountingMethod()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AccountingMethod == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Accounting) GetAccountingMethod() []System_Aaa_Accounting_AccountingMethod_Union {
	if t == nil || t.AccountingMethod == nil {
		return nil
	}
	return t.AccountingMethod
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Accounting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Accounting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Accounting) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_Accounting_AccountingMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/accounting/state/accounting-method within the YANG schema.
// Union type can be one of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, UnionString].
type System_Aaa_Accounting_AccountingMethod_Union interface {
	// Union type can be one of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, UnionString]
	Documentation_for_System_Aaa_Accounting_AccountingMethod_Union()
}

// Documentation_for_System_Aaa_Accounting_AccountingMethod_Union ensures that E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the System_Aaa_Accounting_AccountingMethod_Union interface.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Documentation_for_System_Aaa_Accounting_AccountingMethod_Union() {
}

// Documentation_for_System_Aaa_Accounting_AccountingMethod_Union ensures that UnionString
// implements the System_Aaa_Accounting_AccountingMethod_Union interface.
func (UnionString) Documentation_for_System_Aaa_Accounting_AccountingMethod_Union() {}

// To_System_Aaa_Accounting_AccountingMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_Aaa_Accounting_AccountingMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_Aaa_Accounting) To_System_Aaa_Accounting_AccountingMethod_Union(i interface{}) (System_Aaa_Accounting_AccountingMethod_Union, error) {
	if v, ok := i.(System_Aaa_Accounting_AccountingMethod_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_Aaa_Accounting_AccountingMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
}

// System_Aaa_Accounting_Event represents the /openconfig-system/system/aaa/accounting/events/event YANG schema element.
type System_Aaa_Accounting_Event struct {
	ΛMetadata  []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	EventType  E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE `path:"state/event-type|event-type" shadow-path:"config/event-type" module:"openconfig-system"`
	ΛEventType []ygot.Annotation                              `path:"state/@event-type|@event-type" ygotAnnotation:"true"`
	Record     E_Event_Record                                 `path:"state/record" shadow-path:"config/record" module:"openconfig-system"`
	ΛRecord    []ygot.Annotation                              `path:"state/@record" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Accounting_Event implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Accounting_Event) IsYANGGoStruct() {}

// GetEventType retrieves the value of the leaf EventType from the System_Aaa_Accounting_Event
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EventType is set, it can safely use t.GetEventType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EventType == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Accounting_Event) GetEventType() E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE {
	if t == nil || t.EventType == 0 {
		return 0
	}
	return t.EventType
}

// GetRecord retrieves the value of the leaf Record from the System_Aaa_Accounting_Event
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Record is set, it can safely use t.GetRecord()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Record == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Accounting_Event) GetRecord() E_Event_Record {
	if t == nil || t.Record == 0 {
		return 0
	}
	return t.Record
}

// ΛListKeyMap returns the keys of the System_Aaa_Accounting_Event struct, which is a YANG list entry.
func (t *System_Aaa_Accounting_Event) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"event-type": t.EventType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Accounting_Event) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Accounting_Event"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Accounting_Event) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_Authentication represents the /openconfig-system/system/aaa/authentication YANG schema element.
type System_Aaa_Authentication struct {
	ΛMetadata             []ygot.Annotation                                      `path:"@" ygotAnnotation:"true"`
	AdminUser             *System_Aaa_Authentication_AdminUser                   `path:"admin-user" module:"openconfig-system"`
	ΛAdminUser            []ygot.Annotation                                      `path:"@admin-user" ygotAnnotation:"true"`
	AuthenticationMethod  []System_Aaa_Authentication_AuthenticationMethod_Union `path:"state/authentication-method" shadow-path:"config/authentication-method" module:"openconfig-system"`
	ΛAuthenticationMethod []ygot.Annotation                                      `path:"state/@authentication-method" ygotAnnotation:"true"`
	User                  map[string]*System_Aaa_Authentication_User             `path:"users/user" module:"openconfig-system"`
	ΛUser                 []ygot.Annotation                                      `path:"users/@user" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Authentication) IsYANGGoStruct() {}

// NewUser creates a new entry in the User list of the
// System_Aaa_Authentication struct. The keys of the list are populated from the input
// arguments.
func (t *System_Aaa_Authentication) NewUser(Username string) (*System_Aaa_Authentication_User, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.User == nil {
		t.User = make(map[string]*System_Aaa_Authentication_User)
	}

	key := Username

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.User[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list User", key)
	}

	t.User[key] = &System_Aaa_Authentication_User{
		Username: &Username,
	}

	return t.User[key], nil
}

// RenameUser renames an entry in the list User within
// the System_Aaa_Authentication struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Aaa_Authentication) RenameUser(oldK, newK string) error {
	if _, ok := t.User[newK]; ok {
		return fmt.Errorf("key %v already exists in User", newK)
	}

	e, ok := t.User[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in User", oldK)
	}
	e.Username = &newK

	t.User[newK] = e
	delete(t.User, oldK)
	return nil
}

// GetOrCreateUser retrieves the value with the specified keys from
// the receiver System_Aaa_Authentication. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Aaa_Authentication) GetOrCreateUser(Username string) *System_Aaa_Authentication_User {

	key := Username

	if v, ok := t.User[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewUser(Username)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateUser got unexpected error: %v", err))
	}
	return v
}

// GetUser retrieves the value with the specified key from
// the User map field of System_Aaa_Authentication. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Aaa_Authentication) GetUser(Username string) *System_Aaa_Authentication_User {

	if t == nil {
		return nil
	}

	key := Username

	if lm, ok := t.User[key]; ok {
		return lm
	}
	return nil
}

// AppendUser appends the supplied System_Aaa_Authentication_User struct to the
// list User of System_Aaa_Authentication. If the key value(s) specified in
// the supplied System_Aaa_Authentication_User already exist in the list, an error is
// returned.
func (t *System_Aaa_Authentication) AppendUser(v *System_Aaa_Authentication_User) error {
	if v.Username == nil {
		return fmt.Errorf("invalid nil key received for Username")
	}

	key := *v.Username

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.User == nil {
		t.User = make(map[string]*System_Aaa_Authentication_User)
	}

	if _, ok := t.User[key]; ok {
		return fmt.Errorf("duplicate key for list User %v", key)
	}

	t.User[key] = v
	return nil
}

// GetOrCreateAdminUser retrieves the value of the AdminUser field
// or returns the existing field if it already exists.
func (t *System_Aaa_Authentication) GetOrCreateAdminUser() *System_Aaa_Authentication_AdminUser {
	if t.AdminUser != nil {
		return t.AdminUser
	}
	t.AdminUser = &System_Aaa_Authentication_AdminUser{}
	return t.AdminUser
}

// GetAdminUser returns the value of the AdminUser struct pointer
// from System_Aaa_Authentication. If the receiver or the field AdminUser is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa_Authentication) GetAdminUser() *System_Aaa_Authentication_AdminUser {
	if t != nil && t.AdminUser != nil {
		return t.AdminUser
	}
	return nil
}

// GetAuthenticationMethod retrieves the value of the leaf AuthenticationMethod from the System_Aaa_Authentication
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthenticationMethod is set, it can safely use t.GetAuthenticationMethod()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthenticationMethod == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication) GetAuthenticationMethod() []System_Aaa_Authentication_AuthenticationMethod_Union {
	if t == nil || t.AuthenticationMethod == nil {
		return nil
	}
	return t.AuthenticationMethod
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Authentication) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_Authentication_AuthenticationMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authentication/state/authentication-method within the YANG schema.
// Union type can be one of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, UnionString].
type System_Aaa_Authentication_AuthenticationMethod_Union interface {
	// Union type can be one of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, UnionString]
	Documentation_for_System_Aaa_Authentication_AuthenticationMethod_Union()
}

// Documentation_for_System_Aaa_Authentication_AuthenticationMethod_Union ensures that E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the System_Aaa_Authentication_AuthenticationMethod_Union interface.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Documentation_for_System_Aaa_Authentication_AuthenticationMethod_Union() {
}

// Documentation_for_System_Aaa_Authentication_AuthenticationMethod_Union ensures that UnionString
// implements the System_Aaa_Authentication_AuthenticationMethod_Union interface.
func (UnionString) Documentation_for_System_Aaa_Authentication_AuthenticationMethod_Union() {}

// To_System_Aaa_Authentication_AuthenticationMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_Aaa_Authentication_AuthenticationMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_Aaa_Authentication) To_System_Aaa_Authentication_AuthenticationMethod_Union(i interface{}) (System_Aaa_Authentication_AuthenticationMethod_Union, error) {
	if v, ok := i.(System_Aaa_Authentication_AuthenticationMethod_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_Aaa_Authentication_AuthenticationMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
}

// System_Aaa_Authentication_AdminUser represents the /openconfig-system/system/aaa/authentication/admin-user YANG schema element.
type System_Aaa_Authentication_AdminUser struct {
	ΛMetadata            []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AdminPassword        *string           `path:"state/admin-password" shadow-path:"config/admin-password" module:"openconfig-system"`
	ΛAdminPassword       []ygot.Annotation `path:"state/@admin-password" ygotAnnotation:"true"`
	AdminPasswordHashed  *string           `path:"state/admin-password-hashed" shadow-path:"config/admin-password-hashed" module:"openconfig-system"`
	ΛAdminPasswordHashed []ygot.Annotation `path:"state/@admin-password-hashed" ygotAnnotation:"true"`
	AdminUsername        *string           `path:"state/admin-username" module:"openconfig-system"`
	ΛAdminUsername       []ygot.Annotation `path:"state/@admin-username" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Authentication_AdminUser implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Authentication_AdminUser) IsYANGGoStruct() {}

// GetAdminPassword retrieves the value of the leaf AdminPassword from the System_Aaa_Authentication_AdminUser
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminPassword is set, it can safely use t.GetAdminPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminPassword == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_AdminUser) GetAdminPassword() string {
	if t == nil || t.AdminPassword == nil {
		return ""
	}
	return *t.AdminPassword
}

// GetAdminPasswordHashed retrieves the value of the leaf AdminPasswordHashed from the System_Aaa_Authentication_AdminUser
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminPasswordHashed is set, it can safely use t.GetAdminPasswordHashed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminPasswordHashed == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_AdminUser) GetAdminPasswordHashed() string {
	if t == nil || t.AdminPasswordHashed == nil {
		return ""
	}
	return *t.AdminPasswordHashed
}

// GetAdminUsername retrieves the value of the leaf AdminUsername from the System_Aaa_Authentication_AdminUser
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminUsername is set, it can safely use t.GetAdminUsername()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminUsername == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_AdminUser) GetAdminUsername() string {
	if t == nil || t.AdminUsername == nil {
		return ""
	}
	return *t.AdminUsername
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Authentication_AdminUser) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Authentication_AdminUser"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Authentication_AdminUser) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Aaa_Authentication_User represents the /openconfig-system/system/aaa/authentication/users/user YANG schema element.
type System_Aaa_Authentication_User struct {
	ΛMetadata       []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Password        *string                                   `path:"state/password" shadow-path:"config/password" module:"openconfig-system"`
	ΛPassword       []ygot.Annotation                         `path:"state/@password" ygotAnnotation:"true"`
	PasswordHashed  *string                                   `path:"state/password-hashed" shadow-path:"config/password-hashed" module:"openconfig-system"`
	ΛPasswordHashed []ygot.Annotation                         `path:"state/@password-hashed" ygotAnnotation:"true"`
	Role            System_Aaa_Authentication_User_Role_Union `path:"state/role" shadow-path:"config/role" module:"openconfig-system"`
	ΛRole           []ygot.Annotation                         `path:"state/@role" ygotAnnotation:"true"`
	SshKey          *string                                   `path:"state/ssh-key" shadow-path:"config/ssh-key" module:"openconfig-system"`
	ΛSshKey         []ygot.Annotation                         `path:"state/@ssh-key" ygotAnnotation:"true"`
	Username        *string                                   `path:"state/username|username" shadow-path:"config/username" module:"openconfig-system"`
	ΛUsername       []ygot.Annotation                         `path:"state/@username|@username" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Authentication_User implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Authentication_User) IsYANGGoStruct() {}

// GetPassword retrieves the value of the leaf Password from the System_Aaa_Authentication_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Password is set, it can safely use t.GetPassword()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Password == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_User) GetPassword() string {
	if t == nil || t.Password == nil {
		return ""
	}
	return *t.Password
}

// GetPasswordHashed retrieves the value of the leaf PasswordHashed from the System_Aaa_Authentication_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PasswordHashed is set, it can safely use t.GetPasswordHashed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PasswordHashed == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_User) GetPasswordHashed() string {
	if t == nil || t.PasswordHashed == nil {
		return ""
	}
	return *t.PasswordHashed
}

// GetRole retrieves the value of the leaf Role from the System_Aaa_Authentication_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Role is set, it can safely use t.GetRole()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Role == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_User) GetRole() System_Aaa_Authentication_User_Role_Union {
	if t == nil || t.Role == nil {
		return nil
	}
	return t.Role
}

// GetSshKey retrieves the value of the leaf SshKey from the System_Aaa_Authentication_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SshKey is set, it can safely use t.GetSshKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SshKey == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_User) GetSshKey() string {
	if t == nil || t.SshKey == nil {
		return ""
	}
	return *t.SshKey
}

// GetUsername retrieves the value of the leaf Username from the System_Aaa_Authentication_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Username is set, it can safely use t.GetUsername()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Username == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authentication_User) GetUsername() string {
	if t == nil || t.Username == nil {
		return ""
	}
	return *t.Username
}

// ΛListKeyMap returns the keys of the System_Aaa_Authentication_User struct, which is a YANG list entry.
func (t *System_Aaa_Authentication_User) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Username == nil {
		return nil, fmt.Errorf("nil value for key Username")
	}

	return map[string]interface{}{
		"username": *t.Username,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Authentication_User) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Authentication_User"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Authentication_User) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Aaa_Authentication_User_Role_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authentication/users/user/state/role within the YANG schema.
// Union type can be one of [E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES, UnionString].
type System_Aaa_Authentication_User_Role_Union interface {
	// Union type can be one of [E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES, UnionString]
	Documentation_for_System_Aaa_Authentication_User_Role_Union()
}

// Documentation_for_System_Aaa_Authentication_User_Role_Union ensures that E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
// implements the System_Aaa_Authentication_User_Role_Union interface.
func (E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) Documentation_for_System_Aaa_Authentication_User_Role_Union() {
}

// Documentation_for_System_Aaa_Authentication_User_Role_Union ensures that UnionString
// implements the System_Aaa_Authentication_User_Role_Union interface.
func (UnionString) Documentation_for_System_Aaa_Authentication_User_Role_Union() {}

// To_System_Aaa_Authentication_User_Role_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_Aaa_Authentication_User_Role_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_Aaa_Authentication_User) To_System_Aaa_Authentication_User_Role_Union(i interface{}) (System_Aaa_Authentication_User_Role_Union, error) {
	if v, ok := i.(System_Aaa_Authentication_User_Role_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_Aaa_Authentication_User_Role_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES, string]", i, i)
}

// System_Aaa_Authorization represents the /openconfig-system/system/aaa/authorization YANG schema element.
type System_Aaa_Authorization struct {
	ΛMetadata            []ygot.Annotation                                                                     `path:"@" ygotAnnotation:"true"`
	AuthorizationMethod  []System_Aaa_Authorization_AuthorizationMethod_Union                                  `path:"state/authorization-method" shadow-path:"config/authorization-method" module:"openconfig-system"`
	ΛAuthorizationMethod []ygot.Annotation                                                                     `path:"state/@authorization-method" ygotAnnotation:"true"`
	Event                map[E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE]*System_Aaa_Authorization_Event `path:"events/event" module:"openconfig-system"`
	ΛEvent               []ygot.Annotation                                                                     `path:"events/@event" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Authorization implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Authorization) IsYANGGoStruct() {}

// NewEvent creates a new entry in the Event list of the
// System_Aaa_Authorization struct. The keys of the list are populated from the input
// arguments.
func (t *System_Aaa_Authorization) NewEvent(EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) (*System_Aaa_Authorization_Event, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Event == nil {
		t.Event = make(map[E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE]*System_Aaa_Authorization_Event)
	}

	key := EventType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Event[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Event", key)
	}

	t.Event[key] = &System_Aaa_Authorization_Event{
		EventType: EventType,
	}

	return t.Event[key], nil
}

// RenameEvent renames an entry in the list Event within
// the System_Aaa_Authorization struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Aaa_Authorization) RenameEvent(oldK, newK E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) error {
	if _, ok := t.Event[newK]; ok {
		return fmt.Errorf("key %v already exists in Event", newK)
	}

	e, ok := t.Event[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Event", oldK)
	}
	e.EventType = newK

	t.Event[newK] = e
	delete(t.Event, oldK)
	return nil
}

// GetOrCreateEvent retrieves the value with the specified keys from
// the receiver System_Aaa_Authorization. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Aaa_Authorization) GetOrCreateEvent(EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) *System_Aaa_Authorization_Event {

	key := EventType

	if v, ok := t.Event[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewEvent(EventType)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateEvent got unexpected error: %v", err))
	}
	return v
}

// GetEvent retrieves the value with the specified key from
// the Event map field of System_Aaa_Authorization. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Aaa_Authorization) GetEvent(EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) *System_Aaa_Authorization_Event {

	if t == nil {
		return nil
	}

	key := EventType

	if lm, ok := t.Event[key]; ok {
		return lm
	}
	return nil
}

// AppendEvent appends the supplied System_Aaa_Authorization_Event struct to the
// list Event of System_Aaa_Authorization. If the key value(s) specified in
// the supplied System_Aaa_Authorization_Event already exist in the list, an error is
// returned.
func (t *System_Aaa_Authorization) AppendEvent(v *System_Aaa_Authorization_Event) error {
	key := v.EventType

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Event == nil {
		t.Event = make(map[E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE]*System_Aaa_Authorization_Event)
	}

	if _, ok := t.Event[key]; ok {
		return fmt.Errorf("duplicate key for list Event %v", key)
	}

	t.Event[key] = v
	return nil
}

// GetAuthorizationMethod retrieves the value of the leaf AuthorizationMethod from the System_Aaa_Authorization
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthorizationMethod is set, it can safely use t.GetAuthorizationMethod()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthorizationMethod == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authorization) GetAuthorizationMethod() []System_Aaa_Authorization_AuthorizationMethod_Union {
	if t == nil || t.AuthorizationMethod == nil {
		return nil
	}
	return t.AuthorizationMethod
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Authorization) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Authorization"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Authorization) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_Authorization_AuthorizationMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authorization/state/authorization-method within the YANG schema.
// Union type can be one of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, UnionString].
type System_Aaa_Authorization_AuthorizationMethod_Union interface {
	// Union type can be one of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, UnionString]
	Documentation_for_System_Aaa_Authorization_AuthorizationMethod_Union()
}

// Documentation_for_System_Aaa_Authorization_AuthorizationMethod_Union ensures that E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the System_Aaa_Authorization_AuthorizationMethod_Union interface.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Documentation_for_System_Aaa_Authorization_AuthorizationMethod_Union() {
}

// Documentation_for_System_Aaa_Authorization_AuthorizationMethod_Union ensures that UnionString
// implements the System_Aaa_Authorization_AuthorizationMethod_Union interface.
func (UnionString) Documentation_for_System_Aaa_Authorization_AuthorizationMethod_Union() {}

// To_System_Aaa_Authorization_AuthorizationMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_Aaa_Authorization_AuthorizationMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_Aaa_Authorization) To_System_Aaa_Authorization_AuthorizationMethod_Union(i interface{}) (System_Aaa_Authorization_AuthorizationMethod_Union, error) {
	if v, ok := i.(System_Aaa_Authorization_AuthorizationMethod_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_Aaa_Authorization_AuthorizationMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
}

// System_Aaa_Authorization_Event represents the /openconfig-system/system/aaa/authorization/events/event YANG schema element.
type System_Aaa_Authorization_Event struct {
	ΛMetadata  []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	EventType  E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE `path:"state/event-type|event-type" shadow-path:"config/event-type" module:"openconfig-system"`
	ΛEventType []ygot.Annotation                                 `path:"state/@event-type|@event-type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_Authorization_Event implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_Authorization_Event) IsYANGGoStruct() {}

// GetEventType retrieves the value of the leaf EventType from the System_Aaa_Authorization_Event
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EventType is set, it can safely use t.GetEventType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EventType == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_Authorization_Event) GetEventType() E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE {
	if t == nil || t.EventType == 0 {
		return 0
	}
	return t.EventType
}

// ΛListKeyMap returns the keys of the System_Aaa_Authorization_Event struct, which is a YANG list entry.
func (t *System_Aaa_Authorization_Event) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"event-type": t.EventType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_Authorization_Event) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_Authorization_Event"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_Authorization_Event) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Aaa_ServerGroup represents the /openconfig-system/system/aaa/server-groups/server-group YANG schema element.
type System_Aaa_ServerGroup struct {
	ΛMetadata []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Name      *string                                   `path:"state/name|name" shadow-path:"config/name" module:"openconfig-system"`
	ΛName     []ygot.Annotation                         `path:"state/@name|@name" ygotAnnotation:"true"`
	Server    map[string]*System_Aaa_ServerGroup_Server `path:"servers/server" module:"openconfig-system"`
	ΛServer   []ygot.Annotation                         `path:"servers/@server" ygotAnnotation:"true"`
	Type      E_OpenconfigAaaTypes_AAA_SERVER_TYPE      `path:"state/type" shadow-path:"config/type" module:"openconfig-system"`
	ΛType     []ygot.Annotation                         `path:"state/@type" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_ServerGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_ServerGroup) IsYANGGoStruct() {}

// NewServer creates a new entry in the Server list of the
// System_Aaa_ServerGroup struct. The keys of the list are populated from the input
// arguments.
func (t *System_Aaa_ServerGroup) NewServer(Address string) (*System_Aaa_ServerGroup_Server, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*System_Aaa_ServerGroup_Server)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Server[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Server", key)
	}

	t.Server[key] = &System_Aaa_ServerGroup_Server{
		Address: &Address,
	}

	return t.Server[key], nil
}

// RenameServer renames an entry in the list Server within
// the System_Aaa_ServerGroup struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Aaa_ServerGroup) RenameServer(oldK, newK string) error {
	if _, ok := t.Server[newK]; ok {
		return fmt.Errorf("key %v already exists in Server", newK)
	}

	e, ok := t.Server[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Server", oldK)
	}
	e.Address = &newK

	t.Server[newK] = e
	delete(t.Server, oldK)
	return nil
}

// GetOrCreateServer retrieves the value with the specified keys from
// the receiver System_Aaa_ServerGroup. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Aaa_ServerGroup) GetOrCreateServer(Address string) *System_Aaa_ServerGroup_Server {

	key := Address

	if v, ok := t.Server[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewServer(Address)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateServer got unexpected error: %v", err))
	}
	return v
}

// GetServer retrieves the value with the specified key from
// the Server map field of System_Aaa_ServerGroup. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Aaa_ServerGroup) GetServer(Address string) *System_Aaa_ServerGroup_Server {

	if t == nil {
		return nil
	}

	key := Address

	if lm, ok := t.Server[key]; ok {
		return lm
	}
	return nil
}

// AppendServer appends the supplied System_Aaa_ServerGroup_Server struct to the
// list Server of System_Aaa_ServerGroup. If the key value(s) specified in
// the supplied System_Aaa_ServerGroup_Server already exist in the list, an error is
// returned.
func (t *System_Aaa_ServerGroup) AppendServer(v *System_Aaa_ServerGroup_Server) error {
	if v.Address == nil {
		return fmt.Errorf("invalid nil key received for Address")
	}

	key := *v.Address

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*System_Aaa_ServerGroup_Server)
	}

	if _, ok := t.Server[key]; ok {
		return fmt.Errorf("duplicate key for list Server %v", key)
	}

	t.Server[key] = v
	return nil
}

// GetName retrieves the value of the leaf Name from the System_Aaa_ServerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetType retrieves the value of the leaf Type from the System_Aaa_ServerGroup
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup) GetType() E_OpenconfigAaaTypes_AAA_SERVER_TYPE {
	if t == nil || t.Type == 0 {
		return 0
	}
	return t.Type
}

// ΛListKeyMap returns the keys of the System_Aaa_ServerGroup struct, which is a YANG list entry.
func (t *System_Aaa_ServerGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_ServerGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_ServerGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_ServerGroup) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_ServerGroup_Server represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server YANG schema element.
type System_Aaa_ServerGroup_Server struct {
	ΛMetadata           []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	Address             *string                               `path:"state/address|address" shadow-path:"config/address" module:"openconfig-system"`
	ΛAddress            []ygot.Annotation                     `path:"state/@address|@address" ygotAnnotation:"true"`
	ConnectionAborts    *uint64                               `path:"state/connection-aborts" module:"openconfig-system"`
	ΛConnectionAborts   []ygot.Annotation                     `path:"state/@connection-aborts" ygotAnnotation:"true"`
	ConnectionCloses    *uint64                               `path:"state/connection-closes" module:"openconfig-system"`
	ΛConnectionCloses   []ygot.Annotation                     `path:"state/@connection-closes" ygotAnnotation:"true"`
	ConnectionFailures  *uint64                               `path:"state/connection-failures" module:"openconfig-system"`
	ΛConnectionFailures []ygot.Annotation                     `path:"state/@connection-failures" ygotAnnotation:"true"`
	ConnectionOpens     *uint64                               `path:"state/connection-opens" module:"openconfig-system"`
	ΛConnectionOpens    []ygot.Annotation                     `path:"state/@connection-opens" ygotAnnotation:"true"`
	ConnectionTimeouts  *uint64                               `path:"state/connection-timeouts" module:"openconfig-system"`
	ΛConnectionTimeouts []ygot.Annotation                     `path:"state/@connection-timeouts" ygotAnnotation:"true"`
	ErrorsReceived      *uint64                               `path:"state/errors-received" module:"openconfig-system"`
	ΛErrorsReceived     []ygot.Annotation                     `path:"state/@errors-received" ygotAnnotation:"true"`
	MessagesReceived    *uint64                               `path:"state/messages-received" module:"openconfig-system"`
	ΛMessagesReceived   []ygot.Annotation                     `path:"state/@messages-received" ygotAnnotation:"true"`
	MessagesSent        *uint64                               `path:"state/messages-sent" module:"openconfig-system"`
	ΛMessagesSent       []ygot.Annotation                     `path:"state/@messages-sent" ygotAnnotation:"true"`
	Name                *string                               `path:"state/name" shadow-path:"config/name" module:"openconfig-system"`
	ΛName               []ygot.Annotation                     `path:"state/@name" ygotAnnotation:"true"`
	Radius              *System_Aaa_ServerGroup_Server_Radius `path:"radius" module:"openconfig-system"`
	ΛRadius             []ygot.Annotation                     `path:"@radius" ygotAnnotation:"true"`
	Tacacs              *System_Aaa_ServerGroup_Server_Tacacs `path:"tacacs" module:"openconfig-system"`
	ΛTacacs             []ygot.Annotation                     `path:"@tacacs" ygotAnnotation:"true"`
	Timeout             *uint16                               `path:"state/timeout" shadow-path:"config/timeout" module:"openconfig-system"`
	ΛTimeout            []ygot.Annotation                     `path:"state/@timeout" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_ServerGroup_Server implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_ServerGroup_Server) IsYANGGoStruct() {}

// GetOrCreateRadius retrieves the value of the Radius field
// or returns the existing field if it already exists.
func (t *System_Aaa_ServerGroup_Server) GetOrCreateRadius() *System_Aaa_ServerGroup_Server_Radius {
	if t.Radius != nil {
		return t.Radius
	}
	t.Radius = &System_Aaa_ServerGroup_Server_Radius{}
	return t.Radius
}

// GetOrCreateTacacs retrieves the value of the Tacacs field
// or returns the existing field if it already exists.
func (t *System_Aaa_ServerGroup_Server) GetOrCreateTacacs() *System_Aaa_ServerGroup_Server_Tacacs {
	if t.Tacacs != nil {
		return t.Tacacs
	}
	t.Tacacs = &System_Aaa_ServerGroup_Server_Tacacs{}
	return t.Tacacs
}

// GetRadius returns the value of the Radius struct pointer
// from System_Aaa_ServerGroup_Server. If the receiver or the field Radius is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa_ServerGroup_Server) GetRadius() *System_Aaa_ServerGroup_Server_Radius {
	if t != nil && t.Radius != nil {
		return t.Radius
	}
	return nil
}

// GetTacacs returns the value of the Tacacs struct pointer
// from System_Aaa_ServerGroup_Server. If the receiver or the field Tacacs is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa_ServerGroup_Server) GetTacacs() *System_Aaa_ServerGroup_Server_Tacacs {
	if t != nil && t.Tacacs != nil {
		return t.Tacacs
	}
	return nil
}

// GetAddress retrieves the value of the leaf Address from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetConnectionAborts retrieves the value of the leaf ConnectionAborts from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectionAborts is set, it can safely use t.GetConnectionAborts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectionAborts == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetConnectionAborts() uint64 {
	if t == nil || t.ConnectionAborts == nil {
		return 0
	}
	return *t.ConnectionAborts
}

// GetConnectionCloses retrieves the value of the leaf ConnectionCloses from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectionCloses is set, it can safely use t.GetConnectionCloses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectionCloses == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetConnectionCloses() uint64 {
	if t == nil || t.ConnectionCloses == nil {
		return 0
	}
	return *t.ConnectionCloses
}

// GetConnectionFailures retrieves the value of the leaf ConnectionFailures from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectionFailures is set, it can safely use t.GetConnectionFailures()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectionFailures == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetConnectionFailures() uint64 {
	if t == nil || t.ConnectionFailures == nil {
		return 0
	}
	return *t.ConnectionFailures
}

// GetConnectionOpens retrieves the value of the leaf ConnectionOpens from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectionOpens is set, it can safely use t.GetConnectionOpens()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectionOpens == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetConnectionOpens() uint64 {
	if t == nil || t.ConnectionOpens == nil {
		return 0
	}
	return *t.ConnectionOpens
}

// GetConnectionTimeouts retrieves the value of the leaf ConnectionTimeouts from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ConnectionTimeouts is set, it can safely use t.GetConnectionTimeouts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ConnectionTimeouts == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetConnectionTimeouts() uint64 {
	if t == nil || t.ConnectionTimeouts == nil {
		return 0
	}
	return *t.ConnectionTimeouts
}

// GetErrorsReceived retrieves the value of the leaf ErrorsReceived from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ErrorsReceived is set, it can safely use t.GetErrorsReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ErrorsReceived == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetErrorsReceived() uint64 {
	if t == nil || t.ErrorsReceived == nil {
		return 0
	}
	return *t.ErrorsReceived
}

// GetMessagesReceived retrieves the value of the leaf MessagesReceived from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MessagesReceived is set, it can safely use t.GetMessagesReceived()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MessagesReceived == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetMessagesReceived() uint64 {
	if t == nil || t.MessagesReceived == nil {
		return 0
	}
	return *t.MessagesReceived
}

// GetMessagesSent retrieves the value of the leaf MessagesSent from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MessagesSent is set, it can safely use t.GetMessagesSent()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MessagesSent == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetMessagesSent() uint64 {
	if t == nil || t.MessagesSent == nil {
		return 0
	}
	return *t.MessagesSent
}

// GetName retrieves the value of the leaf Name from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetTimeout retrieves the value of the leaf Timeout from the System_Aaa_ServerGroup_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Timeout is set, it can safely use t.GetTimeout()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Timeout == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server) GetTimeout() uint16 {
	if t == nil || t.Timeout == nil {
		return 0
	}
	return *t.Timeout
}

// ΛListKeyMap returns the keys of the System_Aaa_ServerGroup_Server struct, which is a YANG list entry.
func (t *System_Aaa_ServerGroup_Server) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_ServerGroup_Server) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_ServerGroup_Server"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_ServerGroup_Server) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Aaa_ServerGroup_Server_Radius represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/radius YANG schema element.
type System_Aaa_ServerGroup_Server_Radius struct {
	ΛMetadata           []ygot.Annotation                              `path:"@" ygotAnnotation:"true"`
	AcctPort            *uint16                                        `path:"state/acct-port" shadow-path:"config/acct-port" module:"openconfig-system"`
	ΛAcctPort           []ygot.Annotation                              `path:"state/@acct-port" ygotAnnotation:"true"`
	AuthPort            *uint16                                        `path:"state/auth-port" shadow-path:"config/auth-port" module:"openconfig-system"`
	ΛAuthPort           []ygot.Annotation                              `path:"state/@auth-port" ygotAnnotation:"true"`
	Counters            *System_Aaa_ServerGroup_Server_Radius_Counters `path:"state/counters" module:"openconfig-system"`
	ΛCounters           []ygot.Annotation                              `path:"state/@counters" ygotAnnotation:"true"`
	RetransmitAttempts  *uint8                                         `path:"state/retransmit-attempts" shadow-path:"config/retransmit-attempts" module:"openconfig-system"`
	ΛRetransmitAttempts []ygot.Annotation                              `path:"state/@retransmit-attempts" ygotAnnotation:"true"`
	SecretKey           *string                                        `path:"state/secret-key" shadow-path:"config/secret-key" module:"openconfig-system"`
	ΛSecretKey          []ygot.Annotation                              `path:"state/@secret-key" ygotAnnotation:"true"`
	SecretKeyHashed     *string                                        `path:"state/secret-key-hashed" shadow-path:"config/secret-key-hashed" module:"openconfig-system"`
	ΛSecretKeyHashed    []ygot.Annotation                              `path:"state/@secret-key-hashed" ygotAnnotation:"true"`
	SourceAddress       *string                                        `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-system"`
	ΛSourceAddress      []ygot.Annotation                              `path:"state/@source-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_ServerGroup_Server_Radius implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_ServerGroup_Server_Radius) IsYANGGoStruct() {}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *System_Aaa_ServerGroup_Server_Radius) GetOrCreateCounters() *System_Aaa_ServerGroup_Server_Radius_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &System_Aaa_ServerGroup_Server_Radius_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from System_Aaa_ServerGroup_Server_Radius. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Aaa_ServerGroup_Server_Radius) GetCounters() *System_Aaa_ServerGroup_Server_Radius_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetAcctPort retrieves the value of the leaf AcctPort from the System_Aaa_ServerGroup_Server_Radius
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AcctPort is set, it can safely use t.GetAcctPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AcctPort == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius) GetAcctPort() uint16 {
	if t == nil || t.AcctPort == nil {
		return 1813
	}
	return *t.AcctPort
}

// GetAuthPort retrieves the value of the leaf AuthPort from the System_Aaa_ServerGroup_Server_Radius
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthPort is set, it can safely use t.GetAuthPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthPort == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius) GetAuthPort() uint16 {
	if t == nil || t.AuthPort == nil {
		return 1812
	}
	return *t.AuthPort
}

// GetRetransmitAttempts retrieves the value of the leaf RetransmitAttempts from the System_Aaa_ServerGroup_Server_Radius
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetransmitAttempts is set, it can safely use t.GetRetransmitAttempts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetransmitAttempts == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius) GetRetransmitAttempts() uint8 {
	if t == nil || t.RetransmitAttempts == nil {
		return 0
	}
	return *t.RetransmitAttempts
}

// GetSecretKey retrieves the value of the leaf SecretKey from the System_Aaa_ServerGroup_Server_Radius
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SecretKey is set, it can safely use t.GetSecretKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SecretKey == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius) GetSecretKey() string {
	if t == nil || t.SecretKey == nil {
		return ""
	}
	return *t.SecretKey
}

// GetSecretKeyHashed retrieves the value of the leaf SecretKeyHashed from the System_Aaa_ServerGroup_Server_Radius
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SecretKeyHashed is set, it can safely use t.GetSecretKeyHashed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SecretKeyHashed == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius) GetSecretKeyHashed() string {
	if t == nil || t.SecretKeyHashed == nil {
		return ""
	}
	return *t.SecretKeyHashed
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the System_Aaa_ServerGroup_Server_Radius
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_ServerGroup_Server_Radius) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_ServerGroup_Server_Radius"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_ServerGroup_Server_Radius) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Aaa_ServerGroup_Server_Radius_Counters represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/radius/state/counters YANG schema element.
type System_Aaa_ServerGroup_Server_Radius_Counters struct {
	ΛMetadata              []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AccessAccepts          *uint64           `path:"access-accepts" module:"openconfig-system"`
	ΛAccessAccepts         []ygot.Annotation `path:"@access-accepts" ygotAnnotation:"true"`
	AccessRejects          *uint64           `path:"access-rejects" module:"openconfig-system"`
	ΛAccessRejects         []ygot.Annotation `path:"@access-rejects" ygotAnnotation:"true"`
	RetriedAccessRequests  *uint64           `path:"retried-access-requests" module:"openconfig-system"`
	ΛRetriedAccessRequests []ygot.Annotation `path:"@retried-access-requests" ygotAnnotation:"true"`
	TimeoutAccessRequests  *uint64           `path:"timeout-access-requests" module:"openconfig-system"`
	ΛTimeoutAccessRequests []ygot.Annotation `path:"@timeout-access-requests" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_ServerGroup_Server_Radius_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_ServerGroup_Server_Radius_Counters) IsYANGGoStruct() {}

// GetAccessAccepts retrieves the value of the leaf AccessAccepts from the System_Aaa_ServerGroup_Server_Radius_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AccessAccepts is set, it can safely use t.GetAccessAccepts()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AccessAccepts == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius_Counters) GetAccessAccepts() uint64 {
	if t == nil || t.AccessAccepts == nil {
		return 0
	}
	return *t.AccessAccepts
}

// GetAccessRejects retrieves the value of the leaf AccessRejects from the System_Aaa_ServerGroup_Server_Radius_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AccessRejects is set, it can safely use t.GetAccessRejects()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AccessRejects == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius_Counters) GetAccessRejects() uint64 {
	if t == nil || t.AccessRejects == nil {
		return 0
	}
	return *t.AccessRejects
}

// GetRetriedAccessRequests retrieves the value of the leaf RetriedAccessRequests from the System_Aaa_ServerGroup_Server_Radius_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RetriedAccessRequests is set, it can safely use t.GetRetriedAccessRequests()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RetriedAccessRequests == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius_Counters) GetRetriedAccessRequests() uint64 {
	if t == nil || t.RetriedAccessRequests == nil {
		return 0
	}
	return *t.RetriedAccessRequests
}

// GetTimeoutAccessRequests retrieves the value of the leaf TimeoutAccessRequests from the System_Aaa_ServerGroup_Server_Radius_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TimeoutAccessRequests is set, it can safely use t.GetTimeoutAccessRequests()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TimeoutAccessRequests == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Radius_Counters) GetTimeoutAccessRequests() uint64 {
	if t == nil || t.TimeoutAccessRequests == nil {
		return 0
	}
	return *t.TimeoutAccessRequests
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_ServerGroup_Server_Radius_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_ServerGroup_Server_Radius_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_ServerGroup_Server_Radius_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Aaa_ServerGroup_Server_Tacacs represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/tacacs YANG schema element.
type System_Aaa_ServerGroup_Server_Tacacs struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Port             *uint16           `path:"state/port" shadow-path:"config/port" module:"openconfig-system"`
	ΛPort            []ygot.Annotation `path:"state/@port" ygotAnnotation:"true"`
	SecretKey        *string           `path:"state/secret-key" shadow-path:"config/secret-key" module:"openconfig-system"`
	ΛSecretKey       []ygot.Annotation `path:"state/@secret-key" ygotAnnotation:"true"`
	SecretKeyHashed  *string           `path:"state/secret-key-hashed" shadow-path:"config/secret-key-hashed" module:"openconfig-system"`
	ΛSecretKeyHashed []ygot.Annotation `path:"state/@secret-key-hashed" ygotAnnotation:"true"`
	SourceAddress    *string           `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-system"`
	ΛSourceAddress   []ygot.Annotation `path:"state/@source-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Aaa_ServerGroup_Server_Tacacs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Aaa_ServerGroup_Server_Tacacs) IsYANGGoStruct() {}

// GetPort retrieves the value of the leaf Port from the System_Aaa_ServerGroup_Server_Tacacs
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Port is set, it can safely use t.GetPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Port == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Tacacs) GetPort() uint16 {
	if t == nil || t.Port == nil {
		return 49
	}
	return *t.Port
}

// GetSecretKey retrieves the value of the leaf SecretKey from the System_Aaa_ServerGroup_Server_Tacacs
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SecretKey is set, it can safely use t.GetSecretKey()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SecretKey == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Tacacs) GetSecretKey() string {
	if t == nil || t.SecretKey == nil {
		return ""
	}
	return *t.SecretKey
}

// GetSecretKeyHashed retrieves the value of the leaf SecretKeyHashed from the System_Aaa_ServerGroup_Server_Tacacs
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SecretKeyHashed is set, it can safely use t.GetSecretKeyHashed()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SecretKeyHashed == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Tacacs) GetSecretKeyHashed() string {
	if t == nil || t.SecretKeyHashed == nil {
		return ""
	}
	return *t.SecretKeyHashed
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the System_Aaa_ServerGroup_Server_Tacacs
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *System_Aaa_ServerGroup_Server_Tacacs) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Aaa_ServerGroup_Server_Tacacs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Aaa_ServerGroup_Server_Tacacs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Aaa_ServerGroup_Server_Tacacs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Alarm represents the /openconfig-system/system/alarms/alarm YANG schema element.
type System_Alarm struct {
	ΛMetadata    []ygot.Annotation                                `path:"@" ygotAnnotation:"true"`
	Id           *string                                          `path:"state/id|id" module:"openconfig-system"`
	ΛId          []ygot.Annotation                                `path:"state/@id|@id" ygotAnnotation:"true"`
	Resource     *string                                          `path:"state/resource" module:"openconfig-system"`
	ΛResource    []ygot.Annotation                                `path:"state/@resource" ygotAnnotation:"true"`
	Severity     E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY `path:"state/severity" module:"openconfig-system"`
	ΛSeverity    []ygot.Annotation                                `path:"state/@severity" ygotAnnotation:"true"`
	Text         *string                                          `path:"state/text" module:"openconfig-system"`
	ΛText        []ygot.Annotation                                `path:"state/@text" ygotAnnotation:"true"`
	TimeCreated  *uint64                                          `path:"state/time-created" module:"openconfig-system"`
	ΛTimeCreated []ygot.Annotation                                `path:"state/@time-created" ygotAnnotation:"true"`
	TypeId       System_Alarm_TypeId_Union                        `path:"state/type-id" module:"openconfig-system"`
	ΛTypeId      []ygot.Annotation                                `path:"state/@type-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Alarm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Alarm) IsYANGGoStruct() {}

// GetId retrieves the value of the leaf Id from the System_Alarm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *System_Alarm) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetResource retrieves the value of the leaf Resource from the System_Alarm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Resource is set, it can safely use t.GetResource()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Resource == nil'
// before retrieving the leaf's value.
func (t *System_Alarm) GetResource() string {
	if t == nil || t.Resource == nil {
		return ""
	}
	return *t.Resource
}

// GetSeverity retrieves the value of the leaf Severity from the System_Alarm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Severity is set, it can safely use t.GetSeverity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Severity == nil'
// before retrieving the leaf's value.
func (t *System_Alarm) GetSeverity() E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY {
	if t == nil || t.Severity == 0 {
		return 0
	}
	return t.Severity
}

// GetText retrieves the value of the leaf Text from the System_Alarm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Text is set, it can safely use t.GetText()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Text == nil'
// before retrieving the leaf's value.
func (t *System_Alarm) GetText() string {
	if t == nil || t.Text == nil {
		return ""
	}
	return *t.Text
}

// GetTimeCreated retrieves the value of the leaf TimeCreated from the System_Alarm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TimeCreated is set, it can safely use t.GetTimeCreated()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TimeCreated == nil'
// before retrieving the leaf's value.
func (t *System_Alarm) GetTimeCreated() uint64 {
	if t == nil || t.TimeCreated == nil {
		return 0
	}
	return *t.TimeCreated
}

// GetTypeId retrieves the value of the leaf TypeId from the System_Alarm
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TypeId is set, it can safely use t.GetTypeId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TypeId == nil'
// before retrieving the leaf's value.
func (t *System_Alarm) GetTypeId() System_Alarm_TypeId_Union {
	if t == nil || t.TypeId == nil {
		return nil
	}
	return t.TypeId
}

// ΛListKeyMap returns the keys of the System_Alarm struct, which is a YANG list entry.
func (t *System_Alarm) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Alarm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Alarm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Alarm) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Alarm_TypeId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/alarms/alarm/state/type-id within the YANG schema.
// Union type can be one of [E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID, UnionString].
type System_Alarm_TypeId_Union interface {
	// Union type can be one of [E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID, UnionString]
	Documentation_for_System_Alarm_TypeId_Union()
}

// Documentation_for_System_Alarm_TypeId_Union ensures that E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
// implements the System_Alarm_TypeId_Union interface.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) Documentation_for_System_Alarm_TypeId_Union() {
}

// Documentation_for_System_Alarm_TypeId_Union ensures that UnionString
// implements the System_Alarm_TypeId_Union interface.
func (UnionString) Documentation_for_System_Alarm_TypeId_Union() {}

// To_System_Alarm_TypeId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_Alarm_TypeId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_Alarm) To_System_Alarm_TypeId_Union(i interface{}) (System_Alarm_TypeId_Union, error) {
	if v, ok := i.(System_Alarm_TypeId_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_Alarm_TypeId_Union, unknown union type, got: %T, want any of [E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID, string]", i, i)
}

// System_Clock represents the /openconfig-system/system/clock YANG schema element.
type System_Clock struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	TimezoneName  *string           `path:"state/timezone-name" shadow-path:"config/timezone-name" module:"openconfig-system"`
	ΛTimezoneName []ygot.Annotation `path:"state/@timezone-name" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Clock implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Clock) IsYANGGoStruct() {}

// GetTimezoneName retrieves the value of the leaf TimezoneName from the System_Clock
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TimezoneName is set, it can safely use t.GetTimezoneName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TimezoneName == nil'
// before retrieving the leaf's value.
func (t *System_Clock) GetTimezoneName() string {
	if t == nil || t.TimezoneName == nil {
		return ""
	}
	return *t.TimezoneName
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Clock) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Clock"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Clock) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu represents the /openconfig-system/system/cpus/cpu YANG schema element.
type System_Cpu struct {
	ΛMetadata          []ygot.Annotation             `path:"@" ygotAnnotation:"true"`
	HardwareInterrupt  *System_Cpu_HardwareInterrupt `path:"state/hardware-interrupt" module:"openconfig-system"`
	ΛHardwareInterrupt []ygot.Annotation             `path:"state/@hardware-interrupt" ygotAnnotation:"true"`
	Idle               *System_Cpu_Idle              `path:"state/idle" module:"openconfig-system"`
	ΛIdle              []ygot.Annotation             `path:"state/@idle" ygotAnnotation:"true"`
	Index              System_Cpu_Index_Union        `path:"state/index|index" module:"openconfig-system"`
	ΛIndex             []ygot.Annotation             `path:"state/@index|@index" ygotAnnotation:"true"`
	Kernel             *System_Cpu_Kernel            `path:"state/kernel" module:"openconfig-system"`
	ΛKernel            []ygot.Annotation             `path:"state/@kernel" ygotAnnotation:"true"`
	Nice               *System_Cpu_Nice              `path:"state/nice" module:"openconfig-system"`
	ΛNice              []ygot.Annotation             `path:"state/@nice" ygotAnnotation:"true"`
	SoftwareInterrupt  *System_Cpu_SoftwareInterrupt `path:"state/software-interrupt" module:"openconfig-system"`
	ΛSoftwareInterrupt []ygot.Annotation             `path:"state/@software-interrupt" ygotAnnotation:"true"`
	Total              *System_Cpu_Total             `path:"state/total" module:"openconfig-system"`
	ΛTotal             []ygot.Annotation             `path:"state/@total" ygotAnnotation:"true"`
	User               *System_Cpu_User              `path:"state/user" module:"openconfig-system"`
	ΛUser              []ygot.Annotation             `path:"state/@user" ygotAnnotation:"true"`
	Wait               *System_Cpu_Wait              `path:"state/wait" module:"openconfig-system"`
	ΛWait              []ygot.Annotation             `path:"state/@wait" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu) IsYANGGoStruct() {}

// GetOrCreateHardwareInterrupt retrieves the value of the HardwareInterrupt field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateHardwareInterrupt() *System_Cpu_HardwareInterrupt {
	if t.HardwareInterrupt != nil {
		return t.HardwareInterrupt
	}
	t.HardwareInterrupt = &System_Cpu_HardwareInterrupt{}
	return t.HardwareInterrupt
}

// GetOrCreateIdle retrieves the value of the Idle field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateIdle() *System_Cpu_Idle {
	if t.Idle != nil {
		return t.Idle
	}
	t.Idle = &System_Cpu_Idle{}
	return t.Idle
}

// GetOrCreateKernel retrieves the value of the Kernel field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateKernel() *System_Cpu_Kernel {
	if t.Kernel != nil {
		return t.Kernel
	}
	t.Kernel = &System_Cpu_Kernel{}
	return t.Kernel
}

// GetOrCreateNice retrieves the value of the Nice field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateNice() *System_Cpu_Nice {
	if t.Nice != nil {
		return t.Nice
	}
	t.Nice = &System_Cpu_Nice{}
	return t.Nice
}

// GetOrCreateSoftwareInterrupt retrieves the value of the SoftwareInterrupt field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateSoftwareInterrupt() *System_Cpu_SoftwareInterrupt {
	if t.SoftwareInterrupt != nil {
		return t.SoftwareInterrupt
	}
	t.SoftwareInterrupt = &System_Cpu_SoftwareInterrupt{}
	return t.SoftwareInterrupt
}

// GetOrCreateTotal retrieves the value of the Total field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateTotal() *System_Cpu_Total {
	if t.Total != nil {
		return t.Total
	}
	t.Total = &System_Cpu_Total{}
	return t.Total
}

// GetOrCreateUser retrieves the value of the User field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateUser() *System_Cpu_User {
	if t.User != nil {
		return t.User
	}
	t.User = &System_Cpu_User{}
	return t.User
}

// GetOrCreateWait retrieves the value of the Wait field
// or returns the existing field if it already exists.
func (t *System_Cpu) GetOrCreateWait() *System_Cpu_Wait {
	if t.Wait != nil {
		return t.Wait
	}
	t.Wait = &System_Cpu_Wait{}
	return t.Wait
}

// GetHardwareInterrupt returns the value of the HardwareInterrupt struct pointer
// from System_Cpu. If the receiver or the field HardwareInterrupt is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetHardwareInterrupt() *System_Cpu_HardwareInterrupt {
	if t != nil && t.HardwareInterrupt != nil {
		return t.HardwareInterrupt
	}
	return nil
}

// GetIdle returns the value of the Idle struct pointer
// from System_Cpu. If the receiver or the field Idle is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetIdle() *System_Cpu_Idle {
	if t != nil && t.Idle != nil {
		return t.Idle
	}
	return nil
}

// GetKernel returns the value of the Kernel struct pointer
// from System_Cpu. If the receiver or the field Kernel is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetKernel() *System_Cpu_Kernel {
	if t != nil && t.Kernel != nil {
		return t.Kernel
	}
	return nil
}

// GetNice returns the value of the Nice struct pointer
// from System_Cpu. If the receiver or the field Nice is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetNice() *System_Cpu_Nice {
	if t != nil && t.Nice != nil {
		return t.Nice
	}
	return nil
}

// GetSoftwareInterrupt returns the value of the SoftwareInterrupt struct pointer
// from System_Cpu. If the receiver or the field SoftwareInterrupt is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetSoftwareInterrupt() *System_Cpu_SoftwareInterrupt {
	if t != nil && t.SoftwareInterrupt != nil {
		return t.SoftwareInterrupt
	}
	return nil
}

// GetTotal returns the value of the Total struct pointer
// from System_Cpu. If the receiver or the field Total is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetTotal() *System_Cpu_Total {
	if t != nil && t.Total != nil {
		return t.Total
	}
	return nil
}

// GetUser returns the value of the User struct pointer
// from System_Cpu. If the receiver or the field User is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetUser() *System_Cpu_User {
	if t != nil && t.User != nil {
		return t.User
	}
	return nil
}

// GetWait returns the value of the Wait struct pointer
// from System_Cpu. If the receiver or the field Wait is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Cpu) GetWait() *System_Cpu_Wait {
	if t != nil && t.Wait != nil {
		return t.Wait
	}
	return nil
}

// GetIndex retrieves the value of the leaf Index from the System_Cpu
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *System_Cpu) GetIndex() System_Cpu_Index_Union {
	if t == nil || t.Index == nil {
		return nil
	}
	return t.Index
}

// ΛListKeyMap returns the keys of the System_Cpu struct, which is a YANG list entry.
func (t *System_Cpu) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"index": t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_Index_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/cpus/cpu/state/index within the YANG schema.
// Union type can be one of [E_Cpu_Index_Enum, UnionUint32].
type System_Cpu_Index_Union interface {
	// Union type can be one of [E_Cpu_Index_Enum, UnionUint32]
	Documentation_for_System_Cpu_Index_Union()
}

// Documentation_for_System_Cpu_Index_Union ensures that E_Cpu_Index_Enum
// implements the System_Cpu_Index_Union interface.
func (E_Cpu_Index_Enum) Documentation_for_System_Cpu_Index_Union() {}

// Documentation_for_System_Cpu_Index_Union ensures that UnionUint32
// implements the System_Cpu_Index_Union interface.
func (UnionUint32) Documentation_for_System_Cpu_Index_Union() {}

// To_System_Cpu_Index_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_Cpu_Index_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_Cpu) To_System_Cpu_Index_Union(i interface{}) (System_Cpu_Index_Union, error) {
	if v, ok := i.(System_Cpu_Index_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case uint32:
		return UnionUint32(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_Cpu_Index_Union, unknown union type, got: %T, want any of [E_Cpu_Index_Enum, uint32]", i, i)
}

// System_Cpu_HardwareInterrupt represents the /openconfig-system/system/cpus/cpu/state/hardware-interrupt YANG schema element.
type System_Cpu_HardwareInterrupt struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_HardwareInterrupt implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_HardwareInterrupt) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_HardwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_HardwareInterrupt) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_HardwareInterrupt) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_HardwareInterrupt"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_HardwareInterrupt) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_Idle represents the /openconfig-system/system/cpus/cpu/state/idle YANG schema element.
type System_Cpu_Idle struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_Idle implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_Idle) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_Idle
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Idle) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_Idle) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_Idle"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_Idle) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_Kernel represents the /openconfig-system/system/cpus/cpu/state/kernel YANG schema element.
type System_Cpu_Kernel struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_Kernel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_Kernel) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_Kernel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Kernel) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_Kernel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_Kernel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_Kernel) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_Nice represents the /openconfig-system/system/cpus/cpu/state/nice YANG schema element.
type System_Cpu_Nice struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_Nice implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_Nice) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_Nice
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Nice) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_Nice) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_Nice"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_Nice) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_SoftwareInterrupt represents the /openconfig-system/system/cpus/cpu/state/software-interrupt YANG schema element.
type System_Cpu_SoftwareInterrupt struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_SoftwareInterrupt implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_SoftwareInterrupt) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_SoftwareInterrupt
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_SoftwareInterrupt) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_SoftwareInterrupt) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_SoftwareInterrupt"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_SoftwareInterrupt) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_Total represents the /openconfig-system/system/cpus/cpu/state/total YANG schema element.
type System_Cpu_Total struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_Total implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_Total) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_Total
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Total) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_Total) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_Total"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_Total) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_User represents the /openconfig-system/system/cpus/cpu/state/user YANG schema element.
type System_Cpu_User struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_User implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_User) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_User
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_User) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_User) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_User"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_User) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Cpu_Wait represents the /openconfig-system/system/cpus/cpu/state/wait YANG schema element.
type System_Cpu_Wait struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *uint8            `path:"avg" module:"openconfig-system"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *uint8            `path:"instant" module:"openconfig-system"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-system"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *uint8            `path:"max" module:"openconfig-system"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-system"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *uint8            `path:"min" module:"openconfig-system"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-system"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Cpu_Wait implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Cpu_Wait) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetAvg() uint8 {
	if t == nil || t.Avg == nil {
		return 0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetInstant() uint8 {
	if t == nil || t.Instant == nil {
		return 0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetMax() uint8 {
	if t == nil || t.Max == nil {
		return 0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetMin() uint8 {
	if t == nil || t.Min == nil {
		return 0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the System_Cpu_Wait
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *System_Cpu_Wait) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Cpu_Wait) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Cpu_Wait"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Cpu_Wait) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Dns represents the /openconfig-system/system/dns YANG schema element.
type System_Dns struct {
	ΛMetadata  []ygot.Annotation                `path:"@" ygotAnnotation:"true"`
	HostEntry  map[string]*System_Dns_HostEntry `path:"host-entries/host-entry" module:"openconfig-system"`
	ΛHostEntry []ygot.Annotation                `path:"host-entries/@host-entry" ygotAnnotation:"true"`
	Search     []string                         `path:"state/search" shadow-path:"config/search" module:"openconfig-system"`
	ΛSearch    []ygot.Annotation                `path:"state/@search" ygotAnnotation:"true"`
	Server     map[string]*System_Dns_Server    `path:"servers/server" module:"openconfig-system"`
	ΛServer    []ygot.Annotation                `path:"servers/@server" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Dns implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Dns) IsYANGGoStruct() {}

// NewHostEntry creates a new entry in the HostEntry list of the
// System_Dns struct. The keys of the list are populated from the input
// arguments.
func (t *System_Dns) NewHostEntry(Hostname string) (*System_Dns_HostEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.HostEntry == nil {
		t.HostEntry = make(map[string]*System_Dns_HostEntry)
	}

	key := Hostname

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.HostEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list HostEntry", key)
	}

	t.HostEntry[key] = &System_Dns_HostEntry{
		Hostname: &Hostname,
	}

	return t.HostEntry[key], nil
}

// RenameHostEntry renames an entry in the list HostEntry within
// the System_Dns struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Dns) RenameHostEntry(oldK, newK string) error {
	if _, ok := t.HostEntry[newK]; ok {
		return fmt.Errorf("key %v already exists in HostEntry", newK)
	}

	e, ok := t.HostEntry[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in HostEntry", oldK)
	}
	e.Hostname = &newK

	t.HostEntry[newK] = e
	delete(t.HostEntry, oldK)
	return nil
}

// GetOrCreateHostEntry retrieves the value with the specified keys from
// the receiver System_Dns. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Dns) GetOrCreateHostEntry(Hostname string) *System_Dns_HostEntry {

	key := Hostname

	if v, ok := t.HostEntry[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewHostEntry(Hostname)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateHostEntry got unexpected error: %v", err))
	}
	return v
}

// GetHostEntry retrieves the value with the specified key from
// the HostEntry map field of System_Dns. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Dns) GetHostEntry(Hostname string) *System_Dns_HostEntry {

	if t == nil {
		return nil
	}

	key := Hostname

	if lm, ok := t.HostEntry[key]; ok {
		return lm
	}
	return nil
}

// AppendHostEntry appends the supplied System_Dns_HostEntry struct to the
// list HostEntry of System_Dns. If the key value(s) specified in
// the supplied System_Dns_HostEntry already exist in the list, an error is
// returned.
func (t *System_Dns) AppendHostEntry(v *System_Dns_HostEntry) error {
	if v.Hostname == nil {
		return fmt.Errorf("invalid nil key received for Hostname")
	}

	key := *v.Hostname

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.HostEntry == nil {
		t.HostEntry = make(map[string]*System_Dns_HostEntry)
	}

	if _, ok := t.HostEntry[key]; ok {
		return fmt.Errorf("duplicate key for list HostEntry %v", key)
	}

	t.HostEntry[key] = v
	return nil
}

// NewServer creates a new entry in the Server list of the
// System_Dns struct. The keys of the list are populated from the input
// arguments.
func (t *System_Dns) NewServer(Address string) (*System_Dns_Server, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*System_Dns_Server)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Server[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Server", key)
	}

	t.Server[key] = &System_Dns_Server{
		Address: &Address,
	}

	return t.Server[key], nil
}

// RenameServer renames an entry in the list Server within
// the System_Dns struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Dns) RenameServer(oldK, newK string) error {
	if _, ok := t.Server[newK]; ok {
		return fmt.Errorf("key %v already exists in Server", newK)
	}

	e, ok := t.Server[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Server", oldK)
	}
	e.Address = &newK

	t.Server[newK] = e
	delete(t.Server, oldK)
	return nil
}

// GetOrCreateServer retrieves the value with the specified keys from
// the receiver System_Dns. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Dns) GetOrCreateServer(Address string) *System_Dns_Server {

	key := Address

	if v, ok := t.Server[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewServer(Address)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateServer got unexpected error: %v", err))
	}
	return v
}

// GetServer retrieves the value with the specified key from
// the Server map field of System_Dns. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Dns) GetServer(Address string) *System_Dns_Server {

	if t == nil {
		return nil
	}

	key := Address

	if lm, ok := t.Server[key]; ok {
		return lm
	}
	return nil
}

// AppendServer appends the supplied System_Dns_Server struct to the
// list Server of System_Dns. If the key value(s) specified in
// the supplied System_Dns_Server already exist in the list, an error is
// returned.
func (t *System_Dns) AppendServer(v *System_Dns_Server) error {
	if v.Address == nil {
		return fmt.Errorf("invalid nil key received for Address")
	}

	key := *v.Address

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*System_Dns_Server)
	}

	if _, ok := t.Server[key]; ok {
		return fmt.Errorf("duplicate key for list Server %v", key)
	}

	t.Server[key] = v
	return nil
}

// GetSearch retrieves the value of the leaf Search from the System_Dns
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Search is set, it can safely use t.GetSearch()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Search == nil'
// before retrieving the leaf's value.
func (t *System_Dns) GetSearch() []string {
	if t == nil || t.Search == nil {
		return nil
	}
	return t.Search
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Dns) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Dns"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Dns) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Dns_HostEntry represents the /openconfig-system/system/dns/host-entries/host-entry YANG schema element.
type System_Dns_HostEntry struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Alias        []string          `path:"state/alias" shadow-path:"config/alias" module:"openconfig-system"`
	ΛAlias       []ygot.Annotation `path:"state/@alias" ygotAnnotation:"true"`
	Hostname     *string           `path:"state/hostname|hostname" shadow-path:"config/hostname" module:"openconfig-system"`
	ΛHostname    []ygot.Annotation `path:"state/@hostname|@hostname" ygotAnnotation:"true"`
	Ipv4Address  []string          `path:"state/ipv4-address" shadow-path:"config/ipv4-address" module:"openconfig-system"`
	ΛIpv4Address []ygot.Annotation `path:"state/@ipv4-address" ygotAnnotation:"true"`
	Ipv6Address  []string          `path:"state/ipv6-address" shadow-path:"config/ipv6-address" module:"openconfig-system"`
	ΛIpv6Address []ygot.Annotation `path:"state/@ipv6-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Dns_HostEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Dns_HostEntry) IsYANGGoStruct() {}

// GetAlias retrieves the value of the leaf Alias from the System_Dns_HostEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Alias is set, it can safely use t.GetAlias()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Alias == nil'
// before retrieving the leaf's value.
func (t *System_Dns_HostEntry) GetAlias() []string {
	if t == nil || t.Alias == nil {
		return nil
	}
	return t.Alias
}

// GetHostname retrieves the value of the leaf Hostname from the System_Dns_HostEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Hostname is set, it can safely use t.GetHostname()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Hostname == nil'
// before retrieving the leaf's value.
func (t *System_Dns_HostEntry) GetHostname() string {
	if t == nil || t.Hostname == nil {
		return ""
	}
	return *t.Hostname
}

// GetIpv4Address retrieves the value of the leaf Ipv4Address from the System_Dns_HostEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv4Address is set, it can safely use t.GetIpv4Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv4Address == nil'
// before retrieving the leaf's value.
func (t *System_Dns_HostEntry) GetIpv4Address() []string {
	if t == nil || t.Ipv4Address == nil {
		return nil
	}
	return t.Ipv4Address
}

// GetIpv6Address retrieves the value of the leaf Ipv6Address from the System_Dns_HostEntry
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ipv6Address is set, it can safely use t.GetIpv6Address()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ipv6Address == nil'
// before retrieving the leaf's value.
func (t *System_Dns_HostEntry) GetIpv6Address() []string {
	if t == nil || t.Ipv6Address == nil {
		return nil
	}
	return t.Ipv6Address
}

// ΛListKeyMap returns the keys of the System_Dns_HostEntry struct, which is a YANG list entry.
func (t *System_Dns_HostEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Hostname == nil {
		return nil, fmt.Errorf("nil value for key Hostname")
	}

	return map[string]interface{}{
		"hostname": *t.Hostname,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Dns_HostEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Dns_HostEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Dns_HostEntry) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Dns_Server represents the /openconfig-system/system/dns/servers/server YANG schema element.
type System_Dns_Server struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Address   *string           `path:"state/address|address" shadow-path:"config/address" module:"openconfig-system"`
	ΛAddress  []ygot.Annotation `path:"state/@address|@address" ygotAnnotation:"true"`
	Port      *uint16           `path:"state/port" shadow-path:"config/port" module:"openconfig-system"`
	ΛPort     []ygot.Annotation `path:"state/@port" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Dns_Server implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Dns_Server) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the System_Dns_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *System_Dns_Server) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetPort retrieves the value of the leaf Port from the System_Dns_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Port is set, it can safely use t.GetPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Port == nil'
// before retrieving the leaf's value.
func (t *System_Dns_Server) GetPort() uint16 {
	if t == nil || t.Port == nil {
		return 53
	}
	return *t.Port
}

// ΛListKeyMap returns the keys of the System_Dns_Server struct, which is a YANG list entry.
func (t *System_Dns_Server) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Dns_Server) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Dns_Server"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Dns_Server) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_GrpcServer represents the /openconfig-system/system/grpc-server YANG schema element.
type System_GrpcServer struct {
	ΛMetadata               []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	CertificateId           *string                                   `path:"state/certificate-id" shadow-path:"config/certificate-id" module:"openconfig-system"`
	ΛCertificateId          []ygot.Annotation                         `path:"state/@certificate-id" ygotAnnotation:"true"`
	Enable                  *bool                                     `path:"state/enable" shadow-path:"config/enable" module:"openconfig-system"`
	ΛEnable                 []ygot.Annotation                         `path:"state/@enable" ygotAnnotation:"true"`
	ListenAddresses         []System_GrpcServer_ListenAddresses_Union `path:"state/listen-addresses" shadow-path:"config/listen-addresses" module:"openconfig-system"`
	ΛListenAddresses        []ygot.Annotation                         `path:"state/@listen-addresses" ygotAnnotation:"true"`
	MetadataAuthentication  *bool                                     `path:"state/metadata-authentication" shadow-path:"config/metadata-authentication" module:"openconfig-system"`
	ΛMetadataAuthentication []ygot.Annotation                         `path:"state/@metadata-authentication" ygotAnnotation:"true"`
	Port                    *uint16                                   `path:"state/port" shadow-path:"config/port" module:"openconfig-system"`
	ΛPort                   []ygot.Annotation                         `path:"state/@port" ygotAnnotation:"true"`
	TransportSecurity       *bool                                     `path:"state/transport-security" shadow-path:"config/transport-security" module:"openconfig-system"`
	ΛTransportSecurity      []ygot.Annotation                         `path:"state/@transport-security" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_GrpcServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_GrpcServer) IsYANGGoStruct() {}

// GetCertificateId retrieves the value of the leaf CertificateId from the System_GrpcServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CertificateId is set, it can safely use t.GetCertificateId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CertificateId == nil'
// before retrieving the leaf's value.
func (t *System_GrpcServer) GetCertificateId() string {
	if t == nil || t.CertificateId == nil {
		return ""
	}
	return *t.CertificateId
}

// GetEnable retrieves the value of the leaf Enable from the System_GrpcServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *System_GrpcServer) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return true
	}
	return *t.Enable
}

// GetListenAddresses retrieves the value of the leaf ListenAddresses from the System_GrpcServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ListenAddresses is set, it can safely use t.GetListenAddresses()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ListenAddresses == nil'
// before retrieving the leaf's value.
func (t *System_GrpcServer) GetListenAddresses() []System_GrpcServer_ListenAddresses_Union {
	if t == nil || t.ListenAddresses == nil {
		return nil
	}
	return t.ListenAddresses
}

// GetMetadataAuthentication retrieves the value of the leaf MetadataAuthentication from the System_GrpcServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MetadataAuthentication is set, it can safely use t.GetMetadataAuthentication()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MetadataAuthentication == nil'
// before retrieving the leaf's value.
func (t *System_GrpcServer) GetMetadataAuthentication() bool {
	if t == nil || t.MetadataAuthentication == nil {
		return false
	}
	return *t.MetadataAuthentication
}

// GetPort retrieves the value of the leaf Port from the System_GrpcServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Port is set, it can safely use t.GetPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Port == nil'
// before retrieving the leaf's value.
func (t *System_GrpcServer) GetPort() uint16 {
	if t == nil || t.Port == nil {
		return 9339
	}
	return *t.Port
}

// GetTransportSecurity retrieves the value of the leaf TransportSecurity from the System_GrpcServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TransportSecurity is set, it can safely use t.GetTransportSecurity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TransportSecurity == nil'
// before retrieving the leaf's value.
func (t *System_GrpcServer) GetTransportSecurity() bool {
	if t == nil || t.TransportSecurity == nil {
		return true
	}
	return *t.TransportSecurity
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_GrpcServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_GrpcServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_GrpcServer) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_GrpcServer_ListenAddresses_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/grpc-server/state/listen-addresses within the YANG schema.
// Union type can be one of [E_GrpcServer_ListenAddresses_Enum, UnionString].
type System_GrpcServer_ListenAddresses_Union interface {
	// Union type can be one of [E_GrpcServer_ListenAddresses_Enum, UnionString]
	Documentation_for_System_GrpcServer_ListenAddresses_Union()
}

// Documentation_for_System_GrpcServer_ListenAddresses_Union ensures that E_GrpcServer_ListenAddresses_Enum
// implements the System_GrpcServer_ListenAddresses_Union interface.
func (E_GrpcServer_ListenAddresses_Enum) Documentation_for_System_GrpcServer_ListenAddresses_Union() {
}

// Documentation_for_System_GrpcServer_ListenAddresses_Union ensures that UnionString
// implements the System_GrpcServer_ListenAddresses_Union interface.
func (UnionString) Documentation_for_System_GrpcServer_ListenAddresses_Union() {}

// To_System_GrpcServer_ListenAddresses_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_GrpcServer_ListenAddresses_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_GrpcServer) To_System_GrpcServer_ListenAddresses_Union(i interface{}) (System_GrpcServer_ListenAddresses_Union, error) {
	if v, ok := i.(System_GrpcServer_ListenAddresses_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_GrpcServer_ListenAddresses_Union, unknown union type, got: %T, want any of [E_GrpcServer_ListenAddresses_Enum, string]", i, i)
}

// System_License represents the /openconfig-system/system/license YANG schema element.
type System_License struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	License   map[string]*System_License_License `path:"licenses/license" module:"openconfig-system"`
	ΛLicense  []ygot.Annotation                  `path:"licenses/@license" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_License implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_License) IsYANGGoStruct() {}

// NewLicense creates a new entry in the License list of the
// System_License struct. The keys of the list are populated from the input
// arguments.
func (t *System_License) NewLicense(LicenseId string) (*System_License_License, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.License == nil {
		t.License = make(map[string]*System_License_License)
	}

	key := LicenseId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.License[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list License", key)
	}

	t.License[key] = &System_License_License{
		LicenseId: &LicenseId,
	}

	return t.License[key], nil
}

// RenameLicense renames an entry in the list License within
// the System_License struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_License) RenameLicense(oldK, newK string) error {
	if _, ok := t.License[newK]; ok {
		return fmt.Errorf("key %v already exists in License", newK)
	}

	e, ok := t.License[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in License", oldK)
	}
	e.LicenseId = &newK

	t.License[newK] = e
	delete(t.License, oldK)
	return nil
}

// GetOrCreateLicense retrieves the value with the specified keys from
// the receiver System_License. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_License) GetOrCreateLicense(LicenseId string) *System_License_License {

	key := LicenseId

	if v, ok := t.License[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewLicense(LicenseId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateLicense got unexpected error: %v", err))
	}
	return v
}

// GetLicense retrieves the value with the specified key from
// the License map field of System_License. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_License) GetLicense(LicenseId string) *System_License_License {

	if t == nil {
		return nil
	}

	key := LicenseId

	if lm, ok := t.License[key]; ok {
		return lm
	}
	return nil
}

// AppendLicense appends the supplied System_License_License struct to the
// list License of System_License. If the key value(s) specified in
// the supplied System_License_License already exist in the list, an error is
// returned.
func (t *System_License) AppendLicense(v *System_License_License) error {
	if v.LicenseId == nil {
		return fmt.Errorf("invalid nil key received for LicenseId")
	}

	key := *v.LicenseId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.License == nil {
		t.License = make(map[string]*System_License_License)
	}

	if _, ok := t.License[key]; ok {
		return fmt.Errorf("duplicate key for list License %v", key)
	}

	t.License[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_License) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_License"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_License) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_License_License represents the /openconfig-system/system/license/licenses/license YANG schema element.
type System_License_License struct {
	ΛMetadata       []ygot.Annotation                        `path:"@" ygotAnnotation:"true"`
	Active          *bool                                    `path:"state/active" shadow-path:"config/active" module:"openconfig-system"`
	ΛActive         []ygot.Annotation                        `path:"state/@active" ygotAnnotation:"true"`
	Description     *string                                  `path:"state/description" module:"openconfig-system"`
	ΛDescription    []ygot.Annotation                        `path:"state/@description" ygotAnnotation:"true"`
	ExpirationDate  *uint64                                  `path:"state/expiration-date" module:"openconfig-system"`
	ΛExpirationDate []ygot.Annotation                        `path:"state/@expiration-date" ygotAnnotation:"true"`
	Expired         *bool                                    `path:"state/expired" module:"openconfig-system"`
	ΛExpired        []ygot.Annotation                        `path:"state/@expired" ygotAnnotation:"true"`
	InUse           *bool                                    `path:"state/in-use" module:"openconfig-system"`
	ΛInUse          []ygot.Annotation                        `path:"state/@in-use" ygotAnnotation:"true"`
	IssueDate       *uint64                                  `path:"state/issue-date" module:"openconfig-system"`
	ΛIssueDate      []ygot.Annotation                        `path:"state/@issue-date" ygotAnnotation:"true"`
	LicenseData     System_License_License_LicenseData_Union `path:"state/license-data" shadow-path:"config/license-data" module:"openconfig-system"`
	ΛLicenseData    []ygot.Annotation                        `path:"state/@license-data" ygotAnnotation:"true"`
	LicenseId       *string                                  `path:"state/license-id|license-id" shadow-path:"config/license-id" module:"openconfig-system"`
	ΛLicenseId      []ygot.Annotation                        `path:"state/@license-id|@license-id" ygotAnnotation:"true"`
	Valid           *bool                                    `path:"state/valid" module:"openconfig-system"`
	ΛValid          []ygot.Annotation                        `path:"state/@valid" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_License_License implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_License_License) IsYANGGoStruct() {}

// GetActive retrieves the value of the leaf Active from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Active is set, it can safely use t.GetActive()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Active == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetActive() bool {
	if t == nil || t.Active == nil {
		return false
	}
	return *t.Active
}

// GetDescription retrieves the value of the leaf Description from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetExpirationDate retrieves the value of the leaf ExpirationDate from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ExpirationDate is set, it can safely use t.GetExpirationDate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ExpirationDate == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetExpirationDate() uint64 {
	if t == nil || t.ExpirationDate == nil {
		return 0
	}
	return *t.ExpirationDate
}

// GetExpired retrieves the value of the leaf Expired from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Expired is set, it can safely use t.GetExpired()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Expired == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetExpired() bool {
	if t == nil || t.Expired == nil {
		return false
	}
	return *t.Expired
}

// GetInUse retrieves the value of the leaf InUse from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUse is set, it can safely use t.GetInUse()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUse == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetInUse() bool {
	if t == nil || t.InUse == nil {
		return false
	}
	return *t.InUse
}

// GetIssueDate retrieves the value of the leaf IssueDate from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if IssueDate is set, it can safely use t.GetIssueDate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.IssueDate == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetIssueDate() uint64 {
	if t == nil || t.IssueDate == nil {
		return 0
	}
	return *t.IssueDate
}

// GetLicenseData retrieves the value of the leaf LicenseData from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LicenseData is set, it can safely use t.GetLicenseData()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LicenseData == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetLicenseData() System_License_License_LicenseData_Union {
	if t == nil || t.LicenseData == nil {
		return nil
	}
	return t.LicenseData
}

// GetLicenseId retrieves the value of the leaf LicenseId from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LicenseId is set, it can safely use t.GetLicenseId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LicenseId == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetLicenseId() string {
	if t == nil || t.LicenseId == nil {
		return ""
	}
	return *t.LicenseId
}

// GetValid retrieves the value of the leaf Valid from the System_License_License
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Valid is set, it can safely use t.GetValid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Valid == nil'
// before retrieving the leaf's value.
func (t *System_License_License) GetValid() bool {
	if t == nil || t.Valid == nil {
		return false
	}
	return *t.Valid
}

// ΛListKeyMap returns the keys of the System_License_License struct, which is a YANG list entry.
func (t *System_License_License) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LicenseId == nil {
		return nil, fmt.Errorf("nil value for key LicenseId")
	}

	return map[string]interface{}{
		"license-id": *t.LicenseId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_License_License) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_License_License"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_License_License) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_License_License_LicenseData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/license/licenses/license/state/license-data within the YANG schema.
// Union type can be one of [Binary, UnionString].
type System_License_License_LicenseData_Union interface {
	// Union type can be one of [Binary, UnionString]
	Documentation_for_System_License_License_LicenseData_Union()
}

// Documentation_for_System_License_License_LicenseData_Union ensures that Binary
// implements the System_License_License_LicenseData_Union interface.
func (Binary) Documentation_for_System_License_License_LicenseData_Union() {}

// Documentation_for_System_License_License_LicenseData_Union ensures that UnionString
// implements the System_License_License_LicenseData_Union interface.
func (UnionString) Documentation_for_System_License_License_LicenseData_Union() {}

// To_System_License_License_LicenseData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the System_License_License_LicenseData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *System_License_License) To_System_License_License_LicenseData_Union(i interface{}) (System_License_License_LicenseData_Union, error) {
	if v, ok := i.(System_License_License_LicenseData_Union); ok {
		return v, nil
	}
	switch v := i.(type) {
	case []byte:
		return Binary(v), nil
	case string:
		return UnionString(v), nil
	}
	return nil, fmt.Errorf("cannot convert %v to System_License_License_LicenseData_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
}

// System_Logging represents the /openconfig-system/system/logging YANG schema element.
type System_Logging struct {
	ΛMetadata     []ygot.Annotation                       `path:"@" ygotAnnotation:"true"`
	Console       *System_Logging_Console                 `path:"console" module:"openconfig-system"`
	ΛConsole      []ygot.Annotation                       `path:"@console" ygotAnnotation:"true"`
	RemoteServer  map[string]*System_Logging_RemoteServer `path:"remote-servers/remote-server" module:"openconfig-system"`
	ΛRemoteServer []ygot.Annotation                       `path:"remote-servers/@remote-server" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Logging implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Logging) IsYANGGoStruct() {}

// NewRemoteServer creates a new entry in the RemoteServer list of the
// System_Logging struct. The keys of the list are populated from the input
// arguments.
func (t *System_Logging) NewRemoteServer(Host string) (*System_Logging_RemoteServer, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteServer == nil {
		t.RemoteServer = make(map[string]*System_Logging_RemoteServer)
	}

	key := Host

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RemoteServer[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RemoteServer", key)
	}

	t.RemoteServer[key] = &System_Logging_RemoteServer{
		Host: &Host,
	}

	return t.RemoteServer[key], nil
}

// RenameRemoteServer renames an entry in the list RemoteServer within
// the System_Logging struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Logging) RenameRemoteServer(oldK, newK string) error {
	if _, ok := t.RemoteServer[newK]; ok {
		return fmt.Errorf("key %v already exists in RemoteServer", newK)
	}

	e, ok := t.RemoteServer[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in RemoteServer", oldK)
	}
	e.Host = &newK

	t.RemoteServer[newK] = e
	delete(t.RemoteServer, oldK)
	return nil
}

// GetOrCreateRemoteServer retrieves the value with the specified keys from
// the receiver System_Logging. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Logging) GetOrCreateRemoteServer(Host string) *System_Logging_RemoteServer {

	key := Host

	if v, ok := t.RemoteServer[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewRemoteServer(Host)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateRemoteServer got unexpected error: %v", err))
	}
	return v
}

// GetRemoteServer retrieves the value with the specified key from
// the RemoteServer map field of System_Logging. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Logging) GetRemoteServer(Host string) *System_Logging_RemoteServer {

	if t == nil {
		return nil
	}

	key := Host

	if lm, ok := t.RemoteServer[key]; ok {
		return lm
	}
	return nil
}

// AppendRemoteServer appends the supplied System_Logging_RemoteServer struct to the
// list RemoteServer of System_Logging. If the key value(s) specified in
// the supplied System_Logging_RemoteServer already exist in the list, an error is
// returned.
func (t *System_Logging) AppendRemoteServer(v *System_Logging_RemoteServer) error {
	if v.Host == nil {
		return fmt.Errorf("invalid nil key received for Host")
	}

	key := *v.Host

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteServer == nil {
		t.RemoteServer = make(map[string]*System_Logging_RemoteServer)
	}

	if _, ok := t.RemoteServer[key]; ok {
		return fmt.Errorf("duplicate key for list RemoteServer %v", key)
	}

	t.RemoteServer[key] = v
	return nil
}

// GetOrCreateConsole retrieves the value of the Console field
// or returns the existing field if it already exists.
func (t *System_Logging) GetOrCreateConsole() *System_Logging_Console {
	if t.Console != nil {
		return t.Console
	}
	t.Console = &System_Logging_Console{}
	return t.Console
}

// GetConsole returns the value of the Console struct pointer
// from System_Logging. If the receiver or the field Console is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Logging) GetConsole() *System_Logging_Console {
	if t != nil && t.Console != nil {
		return t.Console
	}
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Logging) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Logging"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Logging) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Logging_Console represents the /openconfig-system/system/logging/console YANG schema element.
type System_Logging_Console struct {
	ΛMetadata []ygot.Annotation                                                        `path:"@" ygotAnnotation:"true"`
	Selector  map[System_Logging_Console_Selector_Key]*System_Logging_Console_Selector `path:"selectors/selector" module:"openconfig-system"`
	ΛSelector []ygot.Annotation                                                        `path:"selectors/@selector" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Logging_Console implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Logging_Console) IsYANGGoStruct() {}

// System_Logging_Console_Selector_Key represents the key for list Selector of element /openconfig-system/system/logging/console.
type System_Logging_Console_Selector_Key struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity"`
}

// NewSelector creates a new entry in the Selector list of the
// System_Logging_Console struct. The keys of the list are populated from the input
// arguments.
func (t *System_Logging_Console) NewSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) (*System_Logging_Console_Selector, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Selector == nil {
		t.Selector = make(map[System_Logging_Console_Selector_Key]*System_Logging_Console_Selector)
	}

	key := System_Logging_Console_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Selector[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Selector", key)
	}

	t.Selector[key] = &System_Logging_Console_Selector{
		Facility: Facility,
		Severity: Severity,
	}

	return t.Selector[key], nil
}

// RenameSelector renames an entry in the list Selector within
// the System_Logging_Console struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Logging_Console) RenameSelector(oldK, newK System_Logging_Console_Selector_Key) error {
	if _, ok := t.Selector[newK]; ok {
		return fmt.Errorf("key %v already exists in Selector", newK)
	}

	e, ok := t.Selector[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Selector", oldK)
	}
	e.Facility = newK.Facility
	e.Severity = newK.Severity

	t.Selector[newK] = e
	delete(t.Selector, oldK)
	return nil
}

// GetOrCreateSelector retrieves the value with the specified keys from
// the receiver System_Logging_Console. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Logging_Console) GetOrCreateSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) *System_Logging_Console_Selector {

	key := System_Logging_Console_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	if v, ok := t.Selector[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSelector(Facility, Severity)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSelector got unexpected error: %v", err))
	}
	return v
}

// GetSelector retrieves the value with the specified key from
// the Selector map field of System_Logging_Console. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Logging_Console) GetSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) *System_Logging_Console_Selector {

	if t == nil {
		return nil
	}

	key := System_Logging_Console_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	if lm, ok := t.Selector[key]; ok {
		return lm
	}
	return nil
}

// AppendSelector appends the supplied System_Logging_Console_Selector struct to the
// list Selector of System_Logging_Console. If the key value(s) specified in
// the supplied System_Logging_Console_Selector already exist in the list, an error is
// returned.
func (t *System_Logging_Console) AppendSelector(v *System_Logging_Console_Selector) error {
	key := System_Logging_Console_Selector_Key{
		Facility: v.Facility,
		Severity: v.Severity,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Selector == nil {
		t.Selector = make(map[System_Logging_Console_Selector_Key]*System_Logging_Console_Selector)
	}

	if _, ok := t.Selector[key]; ok {
		return fmt.Errorf("duplicate key for list Selector %v", key)
	}

	t.Selector[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Logging_Console) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Logging_Console"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Logging_Console) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Logging_Console_Selector represents the /openconfig-system/system/logging/console/selectors/selector YANG schema element.
type System_Logging_Console_Selector struct {
	ΛMetadata []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Facility  E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"state/facility|facility" shadow-path:"config/facility" module:"openconfig-system"`
	ΛFacility []ygot.Annotation                         `path:"state/@facility|@facility" ygotAnnotation:"true"`
	Severity  E_OpenconfigSystemLogging_SyslogSeverity  `path:"state/severity|severity" shadow-path:"config/severity" module:"openconfig-system"`
	ΛSeverity []ygot.Annotation                         `path:"state/@severity|@severity" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Logging_Console_Selector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Logging_Console_Selector) IsYANGGoStruct() {}

// GetFacility retrieves the value of the leaf Facility from the System_Logging_Console_Selector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Facility is set, it can safely use t.GetFacility()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Facility == nil'
// before retrieving the leaf's value.
func (t *System_Logging_Console_Selector) GetFacility() E_OpenconfigSystemLogging_SYSLOG_FACILITY {
	if t == nil || t.Facility == 0 {
		return 0
	}
	return t.Facility
}

// GetSeverity retrieves the value of the leaf Severity from the System_Logging_Console_Selector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Severity is set, it can safely use t.GetSeverity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Severity == nil'
// before retrieving the leaf's value.
func (t *System_Logging_Console_Selector) GetSeverity() E_OpenconfigSystemLogging_SyslogSeverity {
	if t == nil || t.Severity == 0 {
		return 0
	}
	return t.Severity
}

// ΛListKeyMap returns the keys of the System_Logging_Console_Selector struct, which is a YANG list entry.
func (t *System_Logging_Console_Selector) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"facility": t.Facility,
		"severity": t.Severity,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Logging_Console_Selector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Logging_Console_Selector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Logging_Console_Selector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Logging_RemoteServer represents the /openconfig-system/system/logging/remote-servers/remote-server YANG schema element.
type System_Logging_RemoteServer struct {
	ΛMetadata      []ygot.Annotation                                                                  `path:"@" ygotAnnotation:"true"`
	Host           *string                                                                            `path:"state/host|host" shadow-path:"config/host" module:"openconfig-system"`
	ΛHost          []ygot.Annotation                                                                  `path:"state/@host|@host" ygotAnnotation:"true"`
	RemotePort     *uint16                                                                            `path:"state/remote-port" shadow-path:"config/remote-port" module:"openconfig-system"`
	ΛRemotePort    []ygot.Annotation                                                                  `path:"state/@remote-port" ygotAnnotation:"true"`
	Selector       map[System_Logging_RemoteServer_Selector_Key]*System_Logging_RemoteServer_Selector `path:"selectors/selector" module:"openconfig-system"`
	ΛSelector      []ygot.Annotation                                                                  `path:"selectors/@selector" ygotAnnotation:"true"`
	SourceAddress  *string                                                                            `path:"state/source-address" shadow-path:"config/source-address" module:"openconfig-system"`
	ΛSourceAddress []ygot.Annotation                                                                  `path:"state/@source-address" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Logging_RemoteServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Logging_RemoteServer) IsYANGGoStruct() {}

// System_Logging_RemoteServer_Selector_Key represents the key for list Selector of element /openconfig-system/system/logging/remote-servers/remote-server.
type System_Logging_RemoteServer_Selector_Key struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity"`
}

// NewSelector creates a new entry in the Selector list of the
// System_Logging_RemoteServer struct. The keys of the list are populated from the input
// arguments.
func (t *System_Logging_RemoteServer) NewSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) (*System_Logging_RemoteServer_Selector, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Selector == nil {
		t.Selector = make(map[System_Logging_RemoteServer_Selector_Key]*System_Logging_RemoteServer_Selector)
	}

	key := System_Logging_RemoteServer_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Selector[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Selector", key)
	}

	t.Selector[key] = &System_Logging_RemoteServer_Selector{
		Facility: Facility,
		Severity: Severity,
	}

	return t.Selector[key], nil
}

// RenameSelector renames an entry in the list Selector within
// the System_Logging_RemoteServer struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Logging_RemoteServer) RenameSelector(oldK, newK System_Logging_RemoteServer_Selector_Key) error {
	if _, ok := t.Selector[newK]; ok {
		return fmt.Errorf("key %v already exists in Selector", newK)
	}

	e, ok := t.Selector[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Selector", oldK)
	}
	e.Facility = newK.Facility
	e.Severity = newK.Severity

	t.Selector[newK] = e
	delete(t.Selector, oldK)
	return nil
}

// GetOrCreateSelector retrieves the value with the specified keys from
// the receiver System_Logging_RemoteServer. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Logging_RemoteServer) GetOrCreateSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) *System_Logging_RemoteServer_Selector {

	key := System_Logging_RemoteServer_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	if v, ok := t.Selector[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewSelector(Facility, Severity)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateSelector got unexpected error: %v", err))
	}
	return v
}

// GetSelector retrieves the value with the specified key from
// the Selector map field of System_Logging_RemoteServer. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Logging_RemoteServer) GetSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) *System_Logging_RemoteServer_Selector {

	if t == nil {
		return nil
	}

	key := System_Logging_RemoteServer_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	if lm, ok := t.Selector[key]; ok {
		return lm
	}
	return nil
}

// AppendSelector appends the supplied System_Logging_RemoteServer_Selector struct to the
// list Selector of System_Logging_RemoteServer. If the key value(s) specified in
// the supplied System_Logging_RemoteServer_Selector already exist in the list, an error is
// returned.
func (t *System_Logging_RemoteServer) AppendSelector(v *System_Logging_RemoteServer_Selector) error {
	key := System_Logging_RemoteServer_Selector_Key{
		Facility: v.Facility,
		Severity: v.Severity,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Selector == nil {
		t.Selector = make(map[System_Logging_RemoteServer_Selector_Key]*System_Logging_RemoteServer_Selector)
	}

	if _, ok := t.Selector[key]; ok {
		return fmt.Errorf("duplicate key for list Selector %v", key)
	}

	t.Selector[key] = v
	return nil
}

// GetHost retrieves the value of the leaf Host from the System_Logging_RemoteServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Host is set, it can safely use t.GetHost()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Host == nil'
// before retrieving the leaf's value.
func (t *System_Logging_RemoteServer) GetHost() string {
	if t == nil || t.Host == nil {
		return ""
	}
	return *t.Host
}

// GetRemotePort retrieves the value of the leaf RemotePort from the System_Logging_RemoteServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RemotePort is set, it can safely use t.GetRemotePort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RemotePort == nil'
// before retrieving the leaf's value.
func (t *System_Logging_RemoteServer) GetRemotePort() uint16 {
	if t == nil || t.RemotePort == nil {
		return 514
	}
	return *t.RemotePort
}

// GetSourceAddress retrieves the value of the leaf SourceAddress from the System_Logging_RemoteServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SourceAddress is set, it can safely use t.GetSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SourceAddress == nil'
// before retrieving the leaf's value.
func (t *System_Logging_RemoteServer) GetSourceAddress() string {
	if t == nil || t.SourceAddress == nil {
		return ""
	}
	return *t.SourceAddress
}

// ΛListKeyMap returns the keys of the System_Logging_RemoteServer struct, which is a YANG list entry.
func (t *System_Logging_RemoteServer) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Host == nil {
		return nil, fmt.Errorf("nil value for key Host")
	}

	return map[string]interface{}{
		"host": *t.Host,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Logging_RemoteServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Logging_RemoteServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Logging_RemoteServer) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Logging_RemoteServer_Selector represents the /openconfig-system/system/logging/remote-servers/remote-server/selectors/selector YANG schema element.
type System_Logging_RemoteServer_Selector struct {
	ΛMetadata []ygot.Annotation                         `path:"@" ygotAnnotation:"true"`
	Facility  E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"state/facility|facility" shadow-path:"config/facility" module:"openconfig-system"`
	ΛFacility []ygot.Annotation                         `path:"state/@facility|@facility" ygotAnnotation:"true"`
	Severity  E_OpenconfigSystemLogging_SyslogSeverity  `path:"state/severity|severity" shadow-path:"config/severity" module:"openconfig-system"`
	ΛSeverity []ygot.Annotation                         `path:"state/@severity|@severity" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Logging_RemoteServer_Selector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Logging_RemoteServer_Selector) IsYANGGoStruct() {}

// GetFacility retrieves the value of the leaf Facility from the System_Logging_RemoteServer_Selector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Facility is set, it can safely use t.GetFacility()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Facility == nil'
// before retrieving the leaf's value.
func (t *System_Logging_RemoteServer_Selector) GetFacility() E_OpenconfigSystemLogging_SYSLOG_FACILITY {
	if t == nil || t.Facility == 0 {
		return 0
	}
	return t.Facility
}

// GetSeverity retrieves the value of the leaf Severity from the System_Logging_RemoteServer_Selector
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Severity is set, it can safely use t.GetSeverity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Severity == nil'
// before retrieving the leaf's value.
func (t *System_Logging_RemoteServer_Selector) GetSeverity() E_OpenconfigSystemLogging_SyslogSeverity {
	if t == nil || t.Severity == 0 {
		return 0
	}
	return t.Severity
}

// ΛListKeyMap returns the keys of the System_Logging_RemoteServer_Selector struct, which is a YANG list entry.
func (t *System_Logging_RemoteServer_Selector) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"facility": t.Facility,
		"severity": t.Severity,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Logging_RemoteServer_Selector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Logging_RemoteServer_Selector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Logging_RemoteServer_Selector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// System_Memory represents the /openconfig-system/system/memory YANG schema element.
type System_Memory struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Physical  *uint64           `path:"state/physical" module:"openconfig-system"`
	ΛPhysical []ygot.Annotation `path:"state/@physical" ygotAnnotation:"true"`
	Reserved  *uint64           `path:"state/reserved" module:"openconfig-system"`
	ΛReserved []ygot.Annotation `path:"state/@reserved" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Memory implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Memory) IsYANGGoStruct() {}

// GetPhysical retrieves the value of the leaf Physical from the System_Memory
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Physical is set, it can safely use t.GetPhysical()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Physical == nil'
// before retrieving the leaf's value.
func (t *System_Memory) GetPhysical() uint64 {
	if t == nil || t.Physical == nil {
		return 0
	}
	return *t.Physical
}

// GetReserved retrieves the value of the leaf Reserved from the System_Memory
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Reserved is set, it can safely use t.GetReserved()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Reserved == nil'
// before retrieving the leaf's value.
func (t *System_Memory) GetReserved() uint64 {
	if t == nil || t.Reserved == nil {
		return 0
	}
	return *t.Reserved
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Memory) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Memory"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Memory) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Messages represents the /openconfig-system/system/messages YANG schema element.
type System_Messages struct {
	ΛMetadata     []ygot.Annotation                                                    `path:"@" ygotAnnotation:"true"`
	DebugService  map[E_OpenconfigMessages_DEBUG_SERVICE]*System_Messages_DebugService `path:"debug-entries/debug-service" module:"openconfig-system"`
	ΛDebugService []ygot.Annotation                                                    `path:"debug-entries/@debug-service" ygotAnnotation:"true"`
	Message       *System_Messages_Message                                             `path:"state/message" module:"openconfig-system"`
	ΛMessage      []ygot.Annotation                                                    `path:"state/@message" ygotAnnotation:"true"`
	Severity      E_OpenconfigSystemLogging_SyslogSeverity                             `path:"state/severity" shadow-path:"config/severity" module:"openconfig-system"`
	ΛSeverity     []ygot.Annotation                                                    `path:"state/@severity" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Messages) IsYANGGoStruct() {}

// NewDebugService creates a new entry in the DebugService list of the
// System_Messages struct. The keys of the list are populated from the input
// arguments.
func (t *System_Messages) NewDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) (*System_Messages_DebugService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DebugService == nil {
		t.DebugService = make(map[E_OpenconfigMessages_DEBUG_SERVICE]*System_Messages_DebugService)
	}

	key := Service

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DebugService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DebugService", key)
	}

	t.DebugService[key] = &System_Messages_DebugService{
		Service: Service,
	}

	return t.DebugService[key], nil
}

// RenameDebugService renames an entry in the list DebugService within
// the System_Messages struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Messages) RenameDebugService(oldK, newK E_OpenconfigMessages_DEBUG_SERVICE) error {
	if _, ok := t.DebugService[newK]; ok {
		return fmt.Errorf("key %v already exists in DebugService", newK)
	}

	e, ok := t.DebugService[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in DebugService", oldK)
	}
	e.Service = newK

	t.DebugService[newK] = e
	delete(t.DebugService, oldK)
	return nil
}

// GetOrCreateDebugService retrieves the value with the specified keys from
// the receiver System_Messages. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Messages) GetOrCreateDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) *System_Messages_DebugService {

	key := Service

	if v, ok := t.DebugService[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewDebugService(Service)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateDebugService got unexpected error: %v", err))
	}
	return v
}

// GetDebugService retrieves the value with the specified key from
// the DebugService map field of System_Messages. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Messages) GetDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) *System_Messages_DebugService {

	if t == nil {
		return nil
	}

	key := Service

	if lm, ok := t.DebugService[key]; ok {
		return lm
	}
	return nil
}

// AppendDebugService appends the supplied System_Messages_DebugService struct to the
// list DebugService of System_Messages. If the key value(s) specified in
// the supplied System_Messages_DebugService already exist in the list, an error is
// returned.
func (t *System_Messages) AppendDebugService(v *System_Messages_DebugService) error {
	key := v.Service

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DebugService == nil {
		t.DebugService = make(map[E_OpenconfigMessages_DEBUG_SERVICE]*System_Messages_DebugService)
	}

	if _, ok := t.DebugService[key]; ok {
		return fmt.Errorf("duplicate key for list DebugService %v", key)
	}

	t.DebugService[key] = v
	return nil
}

// GetOrCreateMessage retrieves the value of the Message field
// or returns the existing field if it already exists.
func (t *System_Messages) GetOrCreateMessage() *System_Messages_Message {
	if t.Message != nil {
		return t.Message
	}
	t.Message = &System_Messages_Message{}
	return t.Message
}

// GetMessage returns the value of the Message struct pointer
// from System_Messages. If the receiver or the field Message is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *System_Messages) GetMessage() *System_Messages_Message {
	if t != nil && t.Message != nil {
		return t.Message
	}
	return nil
}

// GetSeverity retrieves the value of the leaf Severity from the System_Messages
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Severity is set, it can safely use t.GetSeverity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Severity == nil'
// before retrieving the leaf's value.
func (t *System_Messages) GetSeverity() E_OpenconfigSystemLogging_SyslogSeverity {
	if t == nil || t.Severity == 0 {
		return 0
	}
	return t.Severity
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Messages) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Messages_DebugService represents the /openconfig-system/system/messages/debug-entries/debug-service YANG schema element.
type System_Messages_DebugService struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Enabled   *bool                              `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-system"`
	ΛEnabled  []ygot.Annotation                  `path:"state/@enabled" ygotAnnotation:"true"`
	Service   E_OpenconfigMessages_DEBUG_SERVICE `path:"state/service|service" shadow-path:"config/service" module:"openconfig-system"`
	ΛService  []ygot.Annotation                  `path:"state/@service|@service" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Messages_DebugService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Messages_DebugService) IsYANGGoStruct() {}

// GetEnabled retrieves the value of the leaf Enabled from the System_Messages_DebugService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *System_Messages_DebugService) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetService retrieves the value of the leaf Service from the System_Messages_DebugService
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Service is set, it can safely use t.GetService()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Service == nil'
// before retrieving the leaf's value.
func (t *System_Messages_DebugService) GetService() E_OpenconfigMessages_DEBUG_SERVICE {
	if t == nil || t.Service == 0 {
		return 0
	}
	return t.Service
}

// ΛListKeyMap returns the keys of the System_Messages_DebugService struct, which is a YANG list entry.
func (t *System_Messages_DebugService) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"service": t.Service,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Messages_DebugService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Messages_DebugService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Messages_DebugService) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Messages_Message represents the /openconfig-system/system/messages/state/message YANG schema element.
type System_Messages_Message struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	AppName   *string           `path:"app-name" module:"openconfig-system"`
	ΛAppName  []ygot.Annotation `path:"@app-name" ygotAnnotation:"true"`
	Msg       *string           `path:"msg" module:"openconfig-system"`
	ΛMsg      []ygot.Annotation `path:"@msg" ygotAnnotation:"true"`
	Msgid     *string           `path:"msgid" module:"openconfig-system"`
	ΛMsgid    []ygot.Annotation `path:"@msgid" ygotAnnotation:"true"`
	Priority  *uint8            `path:"priority" module:"openconfig-system"`
	ΛPriority []ygot.Annotation `path:"@priority" ygotAnnotation:"true"`
	Procid    *string           `path:"procid" module:"openconfig-system"`
	ΛProcid   []ygot.Annotation `path:"@procid" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Messages_Message implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Messages_Message) IsYANGGoStruct() {}

// GetAppName retrieves the value of the leaf AppName from the System_Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AppName is set, it can safely use t.GetAppName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AppName == nil'
// before retrieving the leaf's value.
func (t *System_Messages_Message) GetAppName() string {
	if t == nil || t.AppName == nil {
		return ""
	}
	return *t.AppName
}

// GetMsg retrieves the value of the leaf Msg from the System_Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Msg is set, it can safely use t.GetMsg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Msg == nil'
// before retrieving the leaf's value.
func (t *System_Messages_Message) GetMsg() string {
	if t == nil || t.Msg == nil {
		return ""
	}
	return *t.Msg
}

// GetMsgid retrieves the value of the leaf Msgid from the System_Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Msgid is set, it can safely use t.GetMsgid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Msgid == nil'
// before retrieving the leaf's value.
func (t *System_Messages_Message) GetMsgid() string {
	if t == nil || t.Msgid == nil {
		return ""
	}
	return *t.Msgid
}

// GetPriority retrieves the value of the leaf Priority from the System_Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Priority is set, it can safely use t.GetPriority()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Priority == nil'
// before retrieving the leaf's value.
func (t *System_Messages_Message) GetPriority() uint8 {
	if t == nil || t.Priority == nil {
		return 0
	}
	return *t.Priority
}

// GetProcid retrieves the value of the leaf Procid from the System_Messages_Message
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Procid is set, it can safely use t.GetProcid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Procid == nil'
// before retrieving the leaf's value.
func (t *System_Messages_Message) GetProcid() string {
	if t == nil || t.Procid == nil {
		return ""
	}
	return *t.Procid
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Messages_Message) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Messages_Message"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Messages_Message) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Ntp represents the /openconfig-system/system/ntp YANG schema element.
type System_Ntp struct {
	ΛMetadata         []ygot.Annotation             `path:"@" ygotAnnotation:"true"`
	AuthMismatch      *uint64                       `path:"state/auth-mismatch" module:"openconfig-system"`
	ΛAuthMismatch     []ygot.Annotation             `path:"state/@auth-mismatch" ygotAnnotation:"true"`
	EnableNtpAuth     *bool                         `path:"state/enable-ntp-auth" shadow-path:"config/enable-ntp-auth" module:"openconfig-system"`
	ΛEnableNtpAuth    []ygot.Annotation             `path:"state/@enable-ntp-auth" ygotAnnotation:"true"`
	Enabled           *bool                         `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-system"`
	ΛEnabled          []ygot.Annotation             `path:"state/@enabled" ygotAnnotation:"true"`
	NtpKey            map[uint16]*System_Ntp_NtpKey `path:"ntp-keys/ntp-key" module:"openconfig-system"`
	ΛNtpKey           []ygot.Annotation             `path:"ntp-keys/@ntp-key" ygotAnnotation:"true"`
	NtpSourceAddress  *string                       `path:"state/ntp-source-address" shadow-path:"config/ntp-source-address" module:"openconfig-system"`
	ΛNtpSourceAddress []ygot.Annotation             `path:"state/@ntp-source-address" ygotAnnotation:"true"`
	Server            map[string]*System_Ntp_Server `path:"servers/server" module:"openconfig-system"`
	ΛServer           []ygot.Annotation             `path:"servers/@server" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Ntp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Ntp) IsYANGGoStruct() {}

// NewNtpKey creates a new entry in the NtpKey list of the
// System_Ntp struct. The keys of the list are populated from the input
// arguments.
func (t *System_Ntp) NewNtpKey(KeyId uint16) (*System_Ntp_NtpKey, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NtpKey == nil {
		t.NtpKey = make(map[uint16]*System_Ntp_NtpKey)
	}

	key := KeyId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NtpKey[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NtpKey", key)
	}

	t.NtpKey[key] = &System_Ntp_NtpKey{
		KeyId: &KeyId,
	}

	return t.NtpKey[key], nil
}

// RenameNtpKey renames an entry in the list NtpKey within
// the System_Ntp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Ntp) RenameNtpKey(oldK, newK uint16) error {
	if _, ok := t.NtpKey[newK]; ok {
		return fmt.Errorf("key %v already exists in NtpKey", newK)
	}

	e, ok := t.NtpKey[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in NtpKey", oldK)
	}
	e.KeyId = &newK

	t.NtpKey[newK] = e
	delete(t.NtpKey, oldK)
	return nil
}

// GetOrCreateNtpKey retrieves the value with the specified keys from
// the receiver System_Ntp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Ntp) GetOrCreateNtpKey(KeyId uint16) *System_Ntp_NtpKey {

	key := KeyId

	if v, ok := t.NtpKey[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNtpKey(KeyId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNtpKey got unexpected error: %v", err))
	}
	return v
}

// GetNtpKey retrieves the value with the specified key from
// the NtpKey map field of System_Ntp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Ntp) GetNtpKey(KeyId uint16) *System_Ntp_NtpKey {

	if t == nil {
		return nil
	}

	key := KeyId

	if lm, ok := t.NtpKey[key]; ok {
		return lm
	}
	return nil
}

// AppendNtpKey appends the supplied System_Ntp_NtpKey struct to the
// list NtpKey of System_Ntp. If the key value(s) specified in
// the supplied System_Ntp_NtpKey already exist in the list, an error is
// returned.
func (t *System_Ntp) AppendNtpKey(v *System_Ntp_NtpKey) error {
	if v.KeyId == nil {
		return fmt.Errorf("invalid nil key received for KeyId")
	}

	key := *v.KeyId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NtpKey == nil {
		t.NtpKey = make(map[uint16]*System_Ntp_NtpKey)
	}

	if _, ok := t.NtpKey[key]; ok {
		return fmt.Errorf("duplicate key for list NtpKey %v", key)
	}

	t.NtpKey[key] = v
	return nil
}

// NewServer creates a new entry in the Server list of the
// System_Ntp struct. The keys of the list are populated from the input
// arguments.
func (t *System_Ntp) NewServer(Address string) (*System_Ntp_Server, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*System_Ntp_Server)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Server[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Server", key)
	}

	t.Server[key] = &System_Ntp_Server{
		Address: &Address,
	}

	return t.Server[key], nil
}

// RenameServer renames an entry in the list Server within
// the System_Ntp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *System_Ntp) RenameServer(oldK, newK string) error {
	if _, ok := t.Server[newK]; ok {
		return fmt.Errorf("key %v already exists in Server", newK)
	}

	e, ok := t.Server[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Server", oldK)
	}
	e.Address = &newK

	t.Server[newK] = e
	delete(t.Server, oldK)
	return nil
}

// GetOrCreateServer retrieves the value with the specified keys from
// the receiver System_Ntp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *System_Ntp) GetOrCreateServer(Address string) *System_Ntp_Server {

	key := Address

	if v, ok := t.Server[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewServer(Address)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateServer got unexpected error: %v", err))
	}
	return v
}

// GetServer retrieves the value with the specified key from
// the Server map field of System_Ntp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *System_Ntp) GetServer(Address string) *System_Ntp_Server {

	if t == nil {
		return nil
	}

	key := Address

	if lm, ok := t.Server[key]; ok {
		return lm
	}
	return nil
}

// AppendServer appends the supplied System_Ntp_Server struct to the
// list Server of System_Ntp. If the key value(s) specified in
// the supplied System_Ntp_Server already exist in the list, an error is
// returned.
func (t *System_Ntp) AppendServer(v *System_Ntp_Server) error {
	if v.Address == nil {
		return fmt.Errorf("invalid nil key received for Address")
	}

	key := *v.Address

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*System_Ntp_Server)
	}

	if _, ok := t.Server[key]; ok {
		return fmt.Errorf("duplicate key for list Server %v", key)
	}

	t.Server[key] = v
	return nil
}

// GetAuthMismatch retrieves the value of the leaf AuthMismatch from the System_Ntp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AuthMismatch is set, it can safely use t.GetAuthMismatch()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AuthMismatch == nil'
// before retrieving the leaf's value.
func (t *System_Ntp) GetAuthMismatch() uint64 {
	if t == nil || t.AuthMismatch == nil {
		return 0
	}
	return *t.AuthMismatch
}

// GetEnableNtpAuth retrieves the value of the leaf EnableNtpAuth from the System_Ntp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if EnableNtpAuth is set, it can safely use t.GetEnableNtpAuth()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.EnableNtpAuth == nil'
// before retrieving the leaf's value.
func (t *System_Ntp) GetEnableNtpAuth() bool {
	if t == nil || t.EnableNtpAuth == nil {
		return false
	}
	return *t.EnableNtpAuth
}

// GetEnabled retrieves the value of the leaf Enabled from the System_Ntp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *System_Ntp) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetNtpSourceAddress retrieves the value of the leaf NtpSourceAddress from the System_Ntp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if NtpSourceAddress is set, it can safely use t.GetNtpSourceAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.NtpSourceAddress == nil'
// before retrieving the leaf's value.
func (t *System_Ntp) GetNtpSourceAddress() string {
	if t == nil || t.NtpSourceAddress == nil {
		return ""
	}
	return *t.NtpSourceAddress
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Ntp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Ntp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Ntp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Ntp_NtpKey represents the /openconfig-system/system/ntp/ntp-keys/ntp-key YANG schema element.
type System_Ntp_NtpKey struct {
	ΛMetadata []ygot.Annotation                `path:"@" ygotAnnotation:"true"`
	KeyId     *uint16                          `path:"state/key-id|key-id" shadow-path:"config/key-id" module:"openconfig-system"`
	ΛKeyId    []ygot.Annotation                `path:"state/@key-id|@key-id" ygotAnnotation:"true"`
	KeyType   E_OpenconfigSystem_NTP_AUTH_TYPE `path:"state/key-type" shadow-path:"config/key-type" module:"openconfig-system"`
	ΛKeyType  []ygot.Annotation                `path:"state/@key-type" ygotAnnotation:"true"`
	KeyValue  *string                          `path:"state/key-value" shadow-path:"config/key-value" module:"openconfig-system"`
	ΛKeyValue []ygot.Annotation                `path:"state/@key-value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Ntp_NtpKey implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Ntp_NtpKey) IsYANGGoStruct() {}

// GetKeyId retrieves the value of the leaf KeyId from the System_Ntp_NtpKey
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeyId is set, it can safely use t.GetKeyId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeyId == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_NtpKey) GetKeyId() uint16 {
	if t == nil || t.KeyId == nil {
		return 0
	}
	return *t.KeyId
}

// GetKeyType retrieves the value of the leaf KeyType from the System_Ntp_NtpKey
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeyType is set, it can safely use t.GetKeyType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeyType == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_NtpKey) GetKeyType() E_OpenconfigSystem_NTP_AUTH_TYPE {
	if t == nil || t.KeyType == 0 {
		return 0
	}
	return t.KeyType
}

// GetKeyValue retrieves the value of the leaf KeyValue from the System_Ntp_NtpKey
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if KeyValue is set, it can safely use t.GetKeyValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.KeyValue == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_NtpKey) GetKeyValue() string {
	if t == nil || t.KeyValue == nil {
		return ""
	}
	return *t.KeyValue
}

// ΛListKeyMap returns the keys of the System_Ntp_NtpKey struct, which is a YANG list entry.
func (t *System_Ntp_NtpKey) ΛListKeyMap() (map[string]interface{}, error) {
	if t.KeyId == nil {
		return nil, fmt.Errorf("nil value for key KeyId")
	}

	return map[string]interface{}{
		"key-id": *t.KeyId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Ntp_NtpKey) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Ntp_NtpKey"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Ntp_NtpKey) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Ntp_Server represents the /openconfig-system/system/ntp/servers/server YANG schema element.
type System_Ntp_Server struct {
	ΛMetadata        []ygot.Annotation        `path:"@" ygotAnnotation:"true"`
	Address          *string                  `path:"state/address|address" shadow-path:"config/address" module:"openconfig-system"`
	ΛAddress         []ygot.Annotation        `path:"state/@address|@address" ygotAnnotation:"true"`
	AssociationType  E_Server_AssociationType `path:"state/association-type" shadow-path:"config/association-type" module:"openconfig-system"`
	ΛAssociationType []ygot.Annotation        `path:"state/@association-type" ygotAnnotation:"true"`
	Iburst           *bool                    `path:"state/iburst" shadow-path:"config/iburst" module:"openconfig-system"`
	ΛIburst          []ygot.Annotation        `path:"state/@iburst" ygotAnnotation:"true"`
	Offset           *uint64                  `path:"state/offset" module:"openconfig-system"`
	ΛOffset          []ygot.Annotation        `path:"state/@offset" ygotAnnotation:"true"`
	PollInterval     *uint32                  `path:"state/poll-interval" module:"openconfig-system"`
	ΛPollInterval    []ygot.Annotation        `path:"state/@poll-interval" ygotAnnotation:"true"`
	Port             *uint16                  `path:"state/port" shadow-path:"config/port" module:"openconfig-system"`
	ΛPort            []ygot.Annotation        `path:"state/@port" ygotAnnotation:"true"`
	Prefer           *bool                    `path:"state/prefer" shadow-path:"config/prefer" module:"openconfig-system"`
	ΛPrefer          []ygot.Annotation        `path:"state/@prefer" ygotAnnotation:"true"`
	RootDelay        *uint32                  `path:"state/root-delay" module:"openconfig-system"`
	ΛRootDelay       []ygot.Annotation        `path:"state/@root-delay" ygotAnnotation:"true"`
	RootDispersion   *uint64                  `path:"state/root-dispersion" module:"openconfig-system"`
	ΛRootDispersion  []ygot.Annotation        `path:"state/@root-dispersion" ygotAnnotation:"true"`
	Stratum          *uint8                   `path:"state/stratum" module:"openconfig-system"`
	ΛStratum         []ygot.Annotation        `path:"state/@stratum" ygotAnnotation:"true"`
	Version          *uint8                   `path:"state/version" shadow-path:"config/version" module:"openconfig-system"`
	ΛVersion         []ygot.Annotation        `path:"state/@version" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Ntp_Server implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Ntp_Server) IsYANGGoStruct() {}

// GetAddress retrieves the value of the leaf Address from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Address is set, it can safely use t.GetAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Address == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetAddress() string {
	if t == nil || t.Address == nil {
		return ""
	}
	return *t.Address
}

// GetAssociationType retrieves the value of the leaf AssociationType from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AssociationType is set, it can safely use t.GetAssociationType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AssociationType == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetAssociationType() E_Server_AssociationType {
	if t == nil || t.AssociationType == 0 {
		return Server_AssociationType_SERVER
	}
	return t.AssociationType
}

// GetIburst retrieves the value of the leaf Iburst from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Iburst is set, it can safely use t.GetIburst()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Iburst == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetIburst() bool {
	if t == nil || t.Iburst == nil {
		return false
	}
	return *t.Iburst
}

// GetOffset retrieves the value of the leaf Offset from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Offset is set, it can safely use t.GetOffset()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Offset == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetOffset() uint64 {
	if t == nil || t.Offset == nil {
		return 0
	}
	return *t.Offset
}

// GetPollInterval retrieves the value of the leaf PollInterval from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PollInterval is set, it can safely use t.GetPollInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PollInterval == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetPollInterval() uint32 {
	if t == nil || t.PollInterval == nil {
		return 0
	}
	return *t.PollInterval
}

// GetPort retrieves the value of the leaf Port from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Port is set, it can safely use t.GetPort()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Port == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetPort() uint16 {
	if t == nil || t.Port == nil {
		return 123
	}
	return *t.Port
}

// GetPrefer retrieves the value of the leaf Prefer from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Prefer is set, it can safely use t.GetPrefer()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Prefer == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetPrefer() bool {
	if t == nil || t.Prefer == nil {
		return false
	}
	return *t.Prefer
}

// GetRootDelay retrieves the value of the leaf RootDelay from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootDelay is set, it can safely use t.GetRootDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootDelay == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetRootDelay() uint32 {
	if t == nil || t.RootDelay == nil {
		return 0
	}
	return *t.RootDelay
}

// GetRootDispersion retrieves the value of the leaf RootDispersion from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RootDispersion is set, it can safely use t.GetRootDispersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RootDispersion == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetRootDispersion() uint64 {
	if t == nil || t.RootDispersion == nil {
		return 0
	}
	return *t.RootDispersion
}

// GetStratum retrieves the value of the leaf Stratum from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Stratum is set, it can safely use t.GetStratum()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Stratum == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetStratum() uint8 {
	if t == nil || t.Stratum == nil {
		return 0
	}
	return *t.Stratum
}

// GetVersion retrieves the value of the leaf Version from the System_Ntp_Server
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Version is set, it can safely use t.GetVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Version == nil'
// before retrieving the leaf's value.
func (t *System_Ntp_Server) GetVersion() uint8 {
	if t == nil || t.Version == nil {
		return 4
	}
	return *t.Version
}

// ΛListKeyMap returns the keys of the System_Ntp_Server struct, which is a YANG list entry.
func (t *System_Ntp_Server) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Ntp_Server) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Ntp_Server"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Ntp_Server) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_Process represents the /openconfig-system/system/processes/process YANG schema element.
type System_Process struct {
	ΛMetadata          []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Args               []string          `path:"state/args" module:"openconfig-system"`
	ΛArgs              []ygot.Annotation `path:"state/@args" ygotAnnotation:"true"`
	CpuUsageSystem     *uint64           `path:"state/cpu-usage-system" module:"openconfig-system"`
	ΛCpuUsageSystem    []ygot.Annotation `path:"state/@cpu-usage-system" ygotAnnotation:"true"`
	CpuUsageUser       *uint64           `path:"state/cpu-usage-user" module:"openconfig-system"`
	ΛCpuUsageUser      []ygot.Annotation `path:"state/@cpu-usage-user" ygotAnnotation:"true"`
	CpuUtilization     *uint8            `path:"state/cpu-utilization" module:"openconfig-system"`
	ΛCpuUtilization    []ygot.Annotation `path:"state/@cpu-utilization" ygotAnnotation:"true"`
	MemoryUsage        *uint64           `path:"state/memory-usage" module:"openconfig-system"`
	ΛMemoryUsage       []ygot.Annotation `path:"state/@memory-usage" ygotAnnotation:"true"`
	MemoryUtilization  *uint8            `path:"state/memory-utilization" module:"openconfig-system"`
	ΛMemoryUtilization []ygot.Annotation `path:"state/@memory-utilization" ygotAnnotation:"true"`
	Name               *string           `path:"state/name" module:"openconfig-system"`
	ΛName              []ygot.Annotation `path:"state/@name" ygotAnnotation:"true"`
	Pid                *uint64           `path:"state/pid|pid" module:"openconfig-system"`
	ΛPid               []ygot.Annotation `path:"state/@pid|@pid" ygotAnnotation:"true"`
	StartTime          *uint64           `path:"state/start-time" module:"openconfig-system"`
	ΛStartTime         []ygot.Annotation `path:"state/@start-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_Process implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_Process) IsYANGGoStruct() {}

// GetArgs retrieves the value of the leaf Args from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Args is set, it can safely use t.GetArgs()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Args == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetArgs() []string {
	if t == nil || t.Args == nil {
		return nil
	}
	return t.Args
}

// GetCpuUsageSystem retrieves the value of the leaf CpuUsageSystem from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CpuUsageSystem is set, it can safely use t.GetCpuUsageSystem()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CpuUsageSystem == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetCpuUsageSystem() uint64 {
	if t == nil || t.CpuUsageSystem == nil {
		return 0
	}
	return *t.CpuUsageSystem
}

// GetCpuUsageUser retrieves the value of the leaf CpuUsageUser from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CpuUsageUser is set, it can safely use t.GetCpuUsageUser()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CpuUsageUser == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetCpuUsageUser() uint64 {
	if t == nil || t.CpuUsageUser == nil {
		return 0
	}
	return *t.CpuUsageUser
}

// GetCpuUtilization retrieves the value of the leaf CpuUtilization from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CpuUtilization is set, it can safely use t.GetCpuUtilization()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CpuUtilization == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetCpuUtilization() uint8 {
	if t == nil || t.CpuUtilization == nil {
		return 0
	}
	return *t.CpuUtilization
}

// GetMemoryUsage retrieves the value of the leaf MemoryUsage from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MemoryUsage is set, it can safely use t.GetMemoryUsage()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MemoryUsage == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetMemoryUsage() uint64 {
	if t == nil || t.MemoryUsage == nil {
		return 0
	}
	return *t.MemoryUsage
}

// GetMemoryUtilization retrieves the value of the leaf MemoryUtilization from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MemoryUtilization is set, it can safely use t.GetMemoryUtilization()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MemoryUtilization == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetMemoryUtilization() uint8 {
	if t == nil || t.MemoryUtilization == nil {
		return 0
	}
	return *t.MemoryUtilization
}

// GetName retrieves the value of the leaf Name from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Name is set, it can safely use t.GetName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Name == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetName() string {
	if t == nil || t.Name == nil {
		return ""
	}
	return *t.Name
}

// GetPid retrieves the value of the leaf Pid from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Pid is set, it can safely use t.GetPid()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Pid == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetPid() uint64 {
	if t == nil || t.Pid == nil {
		return 0
	}
	return *t.Pid
}

// GetStartTime retrieves the value of the leaf StartTime from the System_Process
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if StartTime is set, it can safely use t.GetStartTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.StartTime == nil'
// before retrieving the leaf's value.
func (t *System_Process) GetStartTime() uint64 {
	if t == nil || t.StartTime == nil {
		return 0
	}
	return *t.StartTime
}

// ΛListKeyMap returns the keys of the System_Process struct, which is a YANG list entry.
func (t *System_Process) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Pid == nil {
		return nil, fmt.Errorf("nil value for key Pid")
	}

	return map[string]interface{}{
		"pid": *t.Pid,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_Process) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_Process"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_Process) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_SshServer represents the /openconfig-system/system/ssh-server YANG schema element.
type System_SshServer struct {
	ΛMetadata        []ygot.Annotation           `path:"@" ygotAnnotation:"true"`
	Enable           *bool                       `path:"state/enable" shadow-path:"config/enable" module:"openconfig-system"`
	ΛEnable          []ygot.Annotation           `path:"state/@enable" ygotAnnotation:"true"`
	ProtocolVersion  E_SshServer_ProtocolVersion `path:"state/protocol-version" shadow-path:"config/protocol-version" module:"openconfig-system"`
	ΛProtocolVersion []ygot.Annotation           `path:"state/@protocol-version" ygotAnnotation:"true"`
	RateLimit        *uint16                     `path:"state/rate-limit" shadow-path:"config/rate-limit" module:"openconfig-system"`
	ΛRateLimit       []ygot.Annotation           `path:"state/@rate-limit" ygotAnnotation:"true"`
	SessionLimit     *uint16                     `path:"state/session-limit" shadow-path:"config/session-limit" module:"openconfig-system"`
	ΛSessionLimit    []ygot.Annotation           `path:"state/@session-limit" ygotAnnotation:"true"`
	Timeout          *uint16                     `path:"state/timeout" shadow-path:"config/timeout" module:"openconfig-system"`
	ΛTimeout         []ygot.Annotation           `path:"state/@timeout" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_SshServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_SshServer) IsYANGGoStruct() {}

// GetEnable retrieves the value of the leaf Enable from the System_SshServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *System_SshServer) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return true
	}
	return *t.Enable
}

// GetProtocolVersion retrieves the value of the leaf ProtocolVersion from the System_SshServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ProtocolVersion is set, it can safely use t.GetProtocolVersion()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ProtocolVersion == nil'
// before retrieving the leaf's value.
func (t *System_SshServer) GetProtocolVersion() E_SshServer_ProtocolVersion {
	if t == nil || t.ProtocolVersion == 0 {
		return SshServer_ProtocolVersion_V2
	}
	return t.ProtocolVersion
}

// GetRateLimit retrieves the value of the leaf RateLimit from the System_SshServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RateLimit is set, it can safely use t.GetRateLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RateLimit == nil'
// before retrieving the leaf's value.
func (t *System_SshServer) GetRateLimit() uint16 {
	if t == nil || t.RateLimit == nil {
		return 0
	}
	return *t.RateLimit
}

// GetSessionLimit retrieves the value of the leaf SessionLimit from the System_SshServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SessionLimit is set, it can safely use t.GetSessionLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SessionLimit == nil'
// before retrieving the leaf's value.
func (t *System_SshServer) GetSessionLimit() uint16 {
	if t == nil || t.SessionLimit == nil {
		return 0
	}
	return *t.SessionLimit
}

// GetTimeout retrieves the value of the leaf Timeout from the System_SshServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Timeout is set, it can safely use t.GetTimeout()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Timeout == nil'
// before retrieving the leaf's value.
func (t *System_SshServer) GetTimeout() uint16 {
	if t == nil || t.Timeout == nil {
		return 0
	}
	return *t.Timeout
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_SshServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_SshServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_SshServer) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// System_TelnetServer represents the /openconfig-system/system/telnet-server YANG schema element.
type System_TelnetServer struct {
	ΛMetadata     []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Enable        *bool             `path:"state/enable" shadow-path:"config/enable" module:"openconfig-system"`
	ΛEnable       []ygot.Annotation `path:"state/@enable" ygotAnnotation:"true"`
	RateLimit     *uint16           `path:"state/rate-limit" shadow-path:"config/rate-limit" module:"openconfig-system"`
	ΛRateLimit    []ygot.Annotation `path:"state/@rate-limit" ygotAnnotation:"true"`
	SessionLimit  *uint16           `path:"state/session-limit" shadow-path:"config/session-limit" module:"openconfig-system"`
	ΛSessionLimit []ygot.Annotation `path:"state/@session-limit" ygotAnnotation:"true"`
	Timeout       *uint16           `path:"state/timeout" shadow-path:"config/timeout" module:"openconfig-system"`
	ΛTimeout      []ygot.Annotation `path:"state/@timeout" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that System_TelnetServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*System_TelnetServer) IsYANGGoStruct() {}

// GetEnable retrieves the value of the leaf Enable from the System_TelnetServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enable is set, it can safely use t.GetEnable()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enable == nil'
// before retrieving the leaf's value.
func (t *System_TelnetServer) GetEnable() bool {
	if t == nil || t.Enable == nil {
		return false
	}
	return *t.Enable
}

// GetRateLimit retrieves the value of the leaf RateLimit from the System_TelnetServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RateLimit is set, it can safely use t.GetRateLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RateLimit == nil'
// before retrieving the leaf's value.
func (t *System_TelnetServer) GetRateLimit() uint16 {
	if t == nil || t.RateLimit == nil {
		return 0
	}
	return *t.RateLimit
}

// GetSessionLimit retrieves the value of the leaf SessionLimit from the System_TelnetServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SessionLimit is set, it can safely use t.GetSessionLimit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SessionLimit == nil'
// before retrieving the leaf's value.
func (t *System_TelnetServer) GetSessionLimit() uint16 {
	if t == nil || t.SessionLimit == nil {
		return 0
	}
	return *t.SessionLimit
}

// GetTimeout retrieves the value of the leaf Timeout from the System_TelnetServer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Timeout is set, it can safely use t.GetTimeout()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Timeout == nil'
// before retrieving the leaf's value.
func (t *System_TelnetServer) GetTimeout() uint16 {
	if t == nil || t.Timeout == nil {
		return 0
	}
	return *t.Timeout
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *System_TelnetServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["System_TelnetServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *System_TelnetServer) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// TerminalDevice represents the /openconfig-terminal-device/terminal-device YANG schema element.
type TerminalDevice struct {
	ΛMetadata []ygot.Annotation                  `path:"@" ygotAnnotation:"true"`
	Channel   map[uint32]*TerminalDevice_Channel `path:"logical-channels/channel" module:"openconfig-terminal-device"`
	ΛChannel  []ygot.Annotation                  `path:"logical-channels/@channel" ygotAnnotation:"true"`
	Mode      map[uint16]*TerminalDevice_Mode    `path:"operational-modes/mode" module:"openconfig-terminal-device"`
	ΛMode     []ygot.Annotation                  `path:"operational-modes/@mode" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice) IsYANGGoStruct() {}

// NewChannel creates a new entry in the Channel list of the
// TerminalDevice struct. The keys of the list are populated from the input
// arguments.
func (t *TerminalDevice) NewChannel(Index uint32) (*TerminalDevice_Channel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Channel == nil {
		t.Channel = make(map[uint32]*TerminalDevice_Channel)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Channel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Channel", key)
	}

	t.Channel[key] = &TerminalDevice_Channel{
		Index: &Index,
	}

	return t.Channel[key], nil
}

// RenameChannel renames an entry in the list Channel within
// the TerminalDevice struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *TerminalDevice) RenameChannel(oldK, newK uint32) error {
	if _, ok := t.Channel[newK]; ok {
		return fmt.Errorf("key %v already exists in Channel", newK)
	}

	e, ok := t.Channel[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Channel", oldK)
	}
	e.Index = &newK

	t.Channel[newK] = e
	delete(t.Channel, oldK)
	return nil
}

// GetOrCreateChannel retrieves the value with the specified keys from
// the receiver TerminalDevice. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *TerminalDevice) GetOrCreateChannel(Index uint32) *TerminalDevice_Channel {

	key := Index

	if v, ok := t.Channel[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewChannel(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateChannel got unexpected error: %v", err))
	}
	return v
}

// GetChannel retrieves the value with the specified key from
// the Channel map field of TerminalDevice. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *TerminalDevice) GetChannel(Index uint32) *TerminalDevice_Channel {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Channel[key]; ok {
		return lm
	}
	return nil
}

// AppendChannel appends the supplied TerminalDevice_Channel struct to the
// list Channel of TerminalDevice. If the key value(s) specified in
// the supplied TerminalDevice_Channel already exist in the list, an error is
// returned.
func (t *TerminalDevice) AppendChannel(v *TerminalDevice_Channel) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Channel == nil {
		t.Channel = make(map[uint32]*TerminalDevice_Channel)
	}

	if _, ok := t.Channel[key]; ok {
		return fmt.Errorf("duplicate key for list Channel %v", key)
	}

	t.Channel[key] = v
	return nil
}

// NewMode creates a new entry in the Mode list of the
// TerminalDevice struct. The keys of the list are populated from the input
// arguments.
func (t *TerminalDevice) NewMode(ModeId uint16) (*TerminalDevice_Mode, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Mode == nil {
		t.Mode = make(map[uint16]*TerminalDevice_Mode)
	}

	key := ModeId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Mode[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Mode", key)
	}

	t.Mode[key] = &TerminalDevice_Mode{
		ModeId: &ModeId,
	}

	return t.Mode[key], nil
}

// RenameMode renames an entry in the list Mode within
// the TerminalDevice struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *TerminalDevice) RenameMode(oldK, newK uint16) error {
	if _, ok := t.Mode[newK]; ok {
		return fmt.Errorf("key %v already exists in Mode", newK)
	}

	e, ok := t.Mode[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Mode", oldK)
	}
	e.ModeId = &newK

	t.Mode[newK] = e
	delete(t.Mode, oldK)
	return nil
}

// GetOrCreateMode retrieves the value with the specified keys from
// the receiver TerminalDevice. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *TerminalDevice) GetOrCreateMode(ModeId uint16) *TerminalDevice_Mode {

	key := ModeId

	if v, ok := t.Mode[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewMode(ModeId)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateMode got unexpected error: %v", err))
	}
	return v
}

// GetMode retrieves the value with the specified key from
// the Mode map field of TerminalDevice. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *TerminalDevice) GetMode(ModeId uint16) *TerminalDevice_Mode {

	if t == nil {
		return nil
	}

	key := ModeId

	if lm, ok := t.Mode[key]; ok {
		return lm
	}
	return nil
}

// AppendMode appends the supplied TerminalDevice_Mode struct to the
// list Mode of TerminalDevice. If the key value(s) specified in
// the supplied TerminalDevice_Mode already exist in the list, an error is
// returned.
func (t *TerminalDevice) AppendMode(v *TerminalDevice_Mode) error {
	if v.ModeId == nil {
		return fmt.Errorf("invalid nil key received for ModeId")
	}

	key := *v.ModeId

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Mode == nil {
		t.Mode = make(map[uint16]*TerminalDevice_Mode)
	}

	if _, ok := t.Mode[key]; ok {
		return fmt.Errorf("duplicate key for list Mode %v", key)
	}

	t.Mode[key] = v
	return nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// TerminalDevice_Channel represents the /openconfig-terminal-device/terminal-device/logical-channels/channel YANG schema element.
type TerminalDevice_Channel struct {
	ΛMetadata           []ygot.Annotation                                        `path:"@" ygotAnnotation:"true"`
	AdminState          E_OpenconfigTransportTypes_AdminStateType                `path:"state/admin-state" shadow-path:"config/admin-state" module:"openconfig-terminal-device"`
	ΛAdminState         []ygot.Annotation                                        `path:"state/@admin-state" ygotAnnotation:"true"`
	Assignment          map[uint32]*TerminalDevice_Channel_Assignment            `path:"logical-channel-assignments/assignment" module:"openconfig-terminal-device"`
	ΛAssignment         []ygot.Annotation                                        `path:"logical-channel-assignments/@assignment" ygotAnnotation:"true"`
	Description         *string                                                  `path:"state/description" shadow-path:"config/description" module:"openconfig-terminal-device"`
	ΛDescription        []ygot.Annotation                                        `path:"state/@description" ygotAnnotation:"true"`
	Ethernet            *TerminalDevice_Channel_Ethernet                         `path:"ethernet" module:"openconfig-terminal-device"`
	ΛEthernet           []ygot.Annotation                                        `path:"@ethernet" ygotAnnotation:"true"`
	Index               *uint32                                                  `path:"state/index|index" shadow-path:"config/index" module:"openconfig-terminal-device"`
	ΛIndex              []ygot.Annotation                                        `path:"state/@index|@index" ygotAnnotation:"true"`
	Ingress             *TerminalDevice_Channel_Ingress                          `path:"ingress" module:"openconfig-terminal-device"`
	ΛIngress            []ygot.Annotation                                        `path:"@ingress" ygotAnnotation:"true"`
	LinkState           E_Channel_LinkState                                      `path:"state/link-state" module:"openconfig-terminal-device"`
	ΛLinkState          []ygot.Annotation                                        `path:"state/@link-state" ygotAnnotation:"true"`
	LogicalChannelType  E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE `path:"state/logical-channel-type" shadow-path:"config/logical-channel-type" module:"openconfig-terminal-device"`
	ΛLogicalChannelType []ygot.Annotation                                        `path:"state/@logical-channel-type" ygotAnnotation:"true"`
	LoopbackMode        E_OpenconfigTransportTypes_LoopbackModeType              `path:"state/loopback-mode" shadow-path:"config/loopback-mode" module:"openconfig-terminal-device"`
	ΛLoopbackMode       []ygot.Annotation                                        `path:"state/@loopback-mode" ygotAnnotation:"true"`
	Otn                 *TerminalDevice_Channel_Otn                              `path:"otn" module:"openconfig-terminal-device"`
	ΛOtn                []ygot.Annotation                                        `path:"@otn" ygotAnnotation:"true"`
	RateClass           E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE     `path:"state/rate-class" shadow-path:"config/rate-class" module:"openconfig-terminal-device"`
	ΛRateClass          []ygot.Annotation                                        `path:"state/@rate-class" ygotAnnotation:"true"`
	TestSignal          *bool                                                    `path:"state/test-signal" shadow-path:"config/test-signal" module:"openconfig-terminal-device"`
	ΛTestSignal         []ygot.Annotation                                        `path:"state/@test-signal" ygotAnnotation:"true"`
	TribProtocol        E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE       `path:"state/trib-protocol" shadow-path:"config/trib-protocol" module:"openconfig-terminal-device"`
	ΛTribProtocol       []ygot.Annotation                                        `path:"state/@trib-protocol" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel) IsYANGGoStruct() {}

// NewAssignment creates a new entry in the Assignment list of the
// TerminalDevice_Channel struct. The keys of the list are populated from the input
// arguments.
func (t *TerminalDevice_Channel) NewAssignment(Index uint32) (*TerminalDevice_Channel_Assignment, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Assignment == nil {
		t.Assignment = make(map[uint32]*TerminalDevice_Channel_Assignment)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Assignment[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Assignment", key)
	}

	t.Assignment[key] = &TerminalDevice_Channel_Assignment{
		Index: &Index,
	}

	return t.Assignment[key], nil
}

// RenameAssignment renames an entry in the list Assignment within
// the TerminalDevice_Channel struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *TerminalDevice_Channel) RenameAssignment(oldK, newK uint32) error {
	if _, ok := t.Assignment[newK]; ok {
		return fmt.Errorf("key %v already exists in Assignment", newK)
	}

	e, ok := t.Assignment[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Assignment", oldK)
	}
	e.Index = &newK

	t.Assignment[newK] = e
	delete(t.Assignment, oldK)
	return nil
}

// GetOrCreateAssignment retrieves the value with the specified keys from
// the receiver TerminalDevice_Channel. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *TerminalDevice_Channel) GetOrCreateAssignment(Index uint32) *TerminalDevice_Channel_Assignment {

	key := Index

	if v, ok := t.Assignment[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewAssignment(Index)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateAssignment got unexpected error: %v", err))
	}
	return v
}

// GetAssignment retrieves the value with the specified key from
// the Assignment map field of TerminalDevice_Channel. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *TerminalDevice_Channel) GetAssignment(Index uint32) *TerminalDevice_Channel_Assignment {

	if t == nil {
		return nil
	}

	key := Index

	if lm, ok := t.Assignment[key]; ok {
		return lm
	}
	return nil
}

// AppendAssignment appends the supplied TerminalDevice_Channel_Assignment struct to the
// list Assignment of TerminalDevice_Channel. If the key value(s) specified in
// the supplied TerminalDevice_Channel_Assignment already exist in the list, an error is
// returned.
func (t *TerminalDevice_Channel) AppendAssignment(v *TerminalDevice_Channel_Assignment) error {
	if v.Index == nil {
		return fmt.Errorf("invalid nil key received for Index")
	}

	key := *v.Index

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Assignment == nil {
		t.Assignment = make(map[uint32]*TerminalDevice_Channel_Assignment)
	}

	if _, ok := t.Assignment[key]; ok {
		return fmt.Errorf("duplicate key for list Assignment %v", key)
	}

	t.Assignment[key] = v
	return nil
}

// GetOrCreateEthernet retrieves the value of the Ethernet field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel) GetOrCreateEthernet() *TerminalDevice_Channel_Ethernet {
	if t.Ethernet != nil {
		return t.Ethernet
	}
	t.Ethernet = &TerminalDevice_Channel_Ethernet{}
	return t.Ethernet
}

// GetOrCreateIngress retrieves the value of the Ingress field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel) GetOrCreateIngress() *TerminalDevice_Channel_Ingress {
	if t.Ingress != nil {
		return t.Ingress
	}
	t.Ingress = &TerminalDevice_Channel_Ingress{}
	return t.Ingress
}

// GetOrCreateOtn retrieves the value of the Otn field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel) GetOrCreateOtn() *TerminalDevice_Channel_Otn {
	if t.Otn != nil {
		return t.Otn
	}
	t.Otn = &TerminalDevice_Channel_Otn{}
	return t.Otn
}

// GetEthernet returns the value of the Ethernet struct pointer
// from TerminalDevice_Channel. If the receiver or the field Ethernet is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel) GetEthernet() *TerminalDevice_Channel_Ethernet {
	if t != nil && t.Ethernet != nil {
		return t.Ethernet
	}
	return nil
}

// GetIngress returns the value of the Ingress struct pointer
// from TerminalDevice_Channel. If the receiver or the field Ingress is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel) GetIngress() *TerminalDevice_Channel_Ingress {
	if t != nil && t.Ingress != nil {
		return t.Ingress
	}
	return nil
}

// GetOtn returns the value of the Otn struct pointer
// from TerminalDevice_Channel. If the receiver or the field Otn is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel) GetOtn() *TerminalDevice_Channel_Otn {
	if t != nil && t.Otn != nil {
		return t.Otn
	}
	return nil
}

// GetAdminState retrieves the value of the leaf AdminState from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AdminState is set, it can safely use t.GetAdminState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AdminState == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetAdminState() E_OpenconfigTransportTypes_AdminStateType {
	if t == nil || t.AdminState == 0 {
		return 0
	}
	return t.AdminState
}

// GetDescription retrieves the value of the leaf Description from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetIndex retrieves the value of the leaf Index from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetIndex() uint32 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLinkState retrieves the value of the leaf LinkState from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LinkState is set, it can safely use t.GetLinkState()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LinkState == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetLinkState() E_Channel_LinkState {
	if t == nil || t.LinkState == 0 {
		return 0
	}
	return t.LinkState
}

// GetLogicalChannelType retrieves the value of the leaf LogicalChannelType from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogicalChannelType is set, it can safely use t.GetLogicalChannelType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogicalChannelType == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetLogicalChannelType() E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE {
	if t == nil || t.LogicalChannelType == 0 {
		return 0
	}
	return t.LogicalChannelType
}

// GetLoopbackMode retrieves the value of the leaf LoopbackMode from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LoopbackMode is set, it can safely use t.GetLoopbackMode()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LoopbackMode == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetLoopbackMode() E_OpenconfigTransportTypes_LoopbackModeType {
	if t == nil || t.LoopbackMode == 0 {
		return OpenconfigTransportTypes_LoopbackModeType_NONE
	}
	return t.LoopbackMode
}

// GetRateClass retrieves the value of the leaf RateClass from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RateClass is set, it can safely use t.GetRateClass()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RateClass == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetRateClass() E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE {
	if t == nil || t.RateClass == 0 {
		return 0
	}
	return t.RateClass
}

// GetTestSignal retrieves the value of the leaf TestSignal from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TestSignal is set, it can safely use t.GetTestSignal()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TestSignal == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetTestSignal() bool {
	if t == nil || t.TestSignal == nil {
		return false
	}
	return *t.TestSignal
}

// GetTribProtocol retrieves the value of the leaf TribProtocol from the TerminalDevice_Channel
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TribProtocol is set, it can safely use t.GetTribProtocol()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TribProtocol == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel) GetTribProtocol() E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE {
	if t == nil || t.TribProtocol == 0 {
		return 0
	}
	return t.TribProtocol
}

// ΛListKeyMap returns the keys of the TerminalDevice_Channel struct, which is a YANG list entry.
func (t *TerminalDevice_Channel) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// TerminalDevice_Channel_Assignment represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/logical-channel-assignments/assignment YANG schema element.
type TerminalDevice_Channel_Assignment struct {
	ΛMetadata           []ygot.Annotation                                 `path:"@" ygotAnnotation:"true"`
	Allocation          *float64                                          `path:"state/allocation" shadow-path:"config/allocation" module:"openconfig-terminal-device"`
	ΛAllocation         []ygot.Annotation                                 `path:"state/@allocation" ygotAnnotation:"true"`
	AssignmentType      E_Assignment_AssignmentType                       `path:"state/assignment-type" shadow-path:"config/assignment-type" module:"openconfig-terminal-device"`
	ΛAssignmentType     []ygot.Annotation                                 `path:"state/@assignment-type" ygotAnnotation:"true"`
	Description         *string                                           `path:"state/description" shadow-path:"config/description" module:"openconfig-terminal-device"`
	ΛDescription        []ygot.Annotation                                 `path:"state/@description" ygotAnnotation:"true"`
	Index               *uint32                                           `path:"state/index|index" shadow-path:"config/index" module:"openconfig-terminal-device"`
	ΛIndex              []ygot.Annotation                                 `path:"state/@index|@index" ygotAnnotation:"true"`
	LogicalChannel      *uint32                                           `path:"state/logical-channel" shadow-path:"config/logical-channel" module:"openconfig-terminal-device"`
	ΛLogicalChannel     []ygot.Annotation                                 `path:"state/@logical-channel" ygotAnnotation:"true"`
	Mapping             E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL `path:"state/mapping" shadow-path:"config/mapping" module:"openconfig-terminal-device"`
	ΛMapping            []ygot.Annotation                                 `path:"state/@mapping" ygotAnnotation:"true"`
	OpticalChannel      *string                                           `path:"state/optical-channel" shadow-path:"config/optical-channel" module:"openconfig-terminal-device"`
	ΛOpticalChannel     []ygot.Annotation                                 `path:"state/@optical-channel" ygotAnnotation:"true"`
	TributarySlotIndex  *int32                                            `path:"state/tributary-slot-index" shadow-path:"config/tributary-slot-index" module:"openconfig-terminal-device"`
	ΛTributarySlotIndex []ygot.Annotation                                 `path:"state/@tributary-slot-index" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Assignment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Assignment) IsYANGGoStruct() {}

// GetAllocation retrieves the value of the leaf Allocation from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Allocation is set, it can safely use t.GetAllocation()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Allocation == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetAllocation() float64 {
	if t == nil || t.Allocation == nil {
		return 0.0
	}
	return *t.Allocation
}

// GetAssignmentType retrieves the value of the leaf AssignmentType from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AssignmentType is set, it can safely use t.GetAssignmentType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AssignmentType == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetAssignmentType() E_Assignment_AssignmentType {
	if t == nil || t.AssignmentType == 0 {
		return 0
	}
	return t.AssignmentType
}

// GetDescription retrieves the value of the leaf Description from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetIndex retrieves the value of the leaf Index from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Index is set, it can safely use t.GetIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Index == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetIndex() uint32 {
	if t == nil || t.Index == nil {
		return 0
	}
	return *t.Index
}

// GetLogicalChannel retrieves the value of the leaf LogicalChannel from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LogicalChannel is set, it can safely use t.GetLogicalChannel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LogicalChannel == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetLogicalChannel() uint32 {
	if t == nil || t.LogicalChannel == nil {
		return 0
	}
	return *t.LogicalChannel
}

// GetMapping retrieves the value of the leaf Mapping from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Mapping is set, it can safely use t.GetMapping()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Mapping == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetMapping() E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL {
	if t == nil || t.Mapping == 0 {
		return 0
	}
	return t.Mapping
}

// GetOpticalChannel retrieves the value of the leaf OpticalChannel from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OpticalChannel is set, it can safely use t.GetOpticalChannel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OpticalChannel == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetOpticalChannel() string {
	if t == nil || t.OpticalChannel == nil {
		return ""
	}
	return *t.OpticalChannel
}

// GetTributarySlotIndex retrieves the value of the leaf TributarySlotIndex from the TerminalDevice_Channel_Assignment
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TributarySlotIndex is set, it can safely use t.GetTributarySlotIndex()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TributarySlotIndex == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Assignment) GetTributarySlotIndex() int32 {
	if t == nil || t.TributarySlotIndex == nil {
		return 0
	}
	return *t.TributarySlotIndex
}

// ΛListKeyMap returns the keys of the TerminalDevice_Channel_Assignment struct, which is a YANG list entry.
func (t *TerminalDevice_Channel_Assignment) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Assignment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Assignment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Assignment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Ethernet represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/ethernet YANG schema element.
type TerminalDevice_Channel_Ethernet struct {
	ΛMetadata                    []ygot.Annotation                     `path:"@" ygotAnnotation:"true"`
	AlsDelay                     *uint32                               `path:"state/als-delay" shadow-path:"config/als-delay" module:"openconfig-terminal-device"`
	ΛAlsDelay                    []ygot.Annotation                     `path:"state/@als-delay" ygotAnnotation:"true"`
	ClientAls                    E_Ethernet_ClientAls                  `path:"state/client-als" shadow-path:"config/client-als" module:"openconfig-terminal-device"`
	ΛClientAls                   []ygot.Annotation                     `path:"state/@client-als" ygotAnnotation:"true"`
	In_8021QFrames               *uint64                               `path:"state/in-8021q-frames" module:"openconfig-terminal-device"`
	ΛIn_8021QFrames              []ygot.Annotation                     `path:"state/@in-8021q-frames" ygotAnnotation:"true"`
	InBlockErrors                *uint64                               `path:"state/in-block-errors" module:"openconfig-terminal-device"`
	ΛInBlockErrors               []ygot.Annotation                     `path:"state/@in-block-errors" ygotAnnotation:"true"`
	InCrcErrors                  *uint64                               `path:"state/in-crc-errors" module:"openconfig-terminal-device"`
	ΛInCrcErrors                 []ygot.Annotation                     `path:"state/@in-crc-errors" ygotAnnotation:"true"`
	InFragmentFrames             *uint64                               `path:"state/in-fragment-frames" module:"openconfig-terminal-device"`
	ΛInFragmentFrames            []ygot.Annotation                     `path:"state/@in-fragment-frames" ygotAnnotation:"true"`
	InJabberFrames               *uint64                               `path:"state/in-jabber-frames" module:"openconfig-terminal-device"`
	ΛInJabberFrames              []ygot.Annotation                     `path:"state/@in-jabber-frames" ygotAnnotation:"true"`
	InMacControlFrames           *uint64                               `path:"state/in-mac-control-frames" module:"openconfig-terminal-device"`
	ΛInMacControlFrames          []ygot.Annotation                     `path:"state/@in-mac-control-frames" ygotAnnotation:"true"`
	InMacPauseFrames             *uint64                               `path:"state/in-mac-pause-frames" module:"openconfig-terminal-device"`
	ΛInMacPauseFrames            []ygot.Annotation                     `path:"state/@in-mac-pause-frames" ygotAnnotation:"true"`
	InOversizeFrames             *uint64                               `path:"state/in-oversize-frames" module:"openconfig-terminal-device"`
	ΛInOversizeFrames            []ygot.Annotation                     `path:"state/@in-oversize-frames" ygotAnnotation:"true"`
	InPcsBipErrors               *uint64                               `path:"state/in-pcs-bip-errors" module:"openconfig-terminal-device"`
	ΛInPcsBipErrors              []ygot.Annotation                     `path:"state/@in-pcs-bip-errors" ygotAnnotation:"true"`
	InPcsErroredSeconds          *uint64                               `path:"state/in-pcs-errored-seconds" module:"openconfig-terminal-device"`
	ΛInPcsErroredSeconds         []ygot.Annotation                     `path:"state/@in-pcs-errored-seconds" ygotAnnotation:"true"`
	InPcsSeverelyErroredSeconds  *uint64                               `path:"state/in-pcs-severely-errored-seconds" module:"openconfig-terminal-device"`
	ΛInPcsSeverelyErroredSeconds []ygot.Annotation                     `path:"state/@in-pcs-severely-errored-seconds" ygotAnnotation:"true"`
	InPcsUnavailableSeconds      *uint64                               `path:"state/in-pcs-unavailable-seconds" module:"openconfig-terminal-device"`
	ΛInPcsUnavailableSeconds     []ygot.Annotation                     `path:"state/@in-pcs-unavailable-seconds" ygotAnnotation:"true"`
	InUndersizeFrames            *uint64                               `path:"state/in-undersize-frames" module:"openconfig-terminal-device"`
	ΛInUndersizeFrames           []ygot.Annotation                     `path:"state/@in-undersize-frames" ygotAnnotation:"true"`
	Lldp                         *TerminalDevice_Channel_Ethernet_Lldp `path:"lldp" module:"openconfig-terminal-device"`
	ΛLldp                        []ygot.Annotation                     `path:"@lldp" ygotAnnotation:"true"`
	Out_8021QFrames              *uint64                               `path:"state/out-8021q-frames" module:"openconfig-terminal-device"`
	ΛOut_8021QFrames             []ygot.Annotation                     `path:"state/@out-8021q-frames" ygotAnnotation:"true"`
	OutBlockErrors               *uint64                               `path:"state/out-block-errors" module:"openconfig-terminal-device"`
	ΛOutBlockErrors              []ygot.Annotation                     `path:"state/@out-block-errors" ygotAnnotation:"true"`
	OutCrcErrors                 *uint64                               `path:"state/out-crc-errors" module:"openconfig-terminal-device"`
	ΛOutCrcErrors                []ygot.Annotation                     `path:"state/@out-crc-errors" ygotAnnotation:"true"`
	OutMacControlFrames          *uint64                               `path:"state/out-mac-control-frames" module:"openconfig-terminal-device"`
	ΛOutMacControlFrames         []ygot.Annotation                     `path:"state/@out-mac-control-frames" ygotAnnotation:"true"`
	OutMacPauseFrames            *uint64                               `path:"state/out-mac-pause-frames" module:"openconfig-terminal-device"`
	ΛOutMacPauseFrames           []ygot.Annotation                     `path:"state/@out-mac-pause-frames" ygotAnnotation:"true"`
	OutPcsBipErrors              *uint64                               `path:"state/out-pcs-bip-errors" module:"openconfig-terminal-device"`
	ΛOutPcsBipErrors             []ygot.Annotation                     `path:"state/@out-pcs-bip-errors" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Ethernet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Ethernet) IsYANGGoStruct() {}

// GetOrCreateLldp retrieves the value of the Lldp field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel_Ethernet) GetOrCreateLldp() *TerminalDevice_Channel_Ethernet_Lldp {
	if t.Lldp != nil {
		return t.Lldp
	}
	t.Lldp = &TerminalDevice_Channel_Ethernet_Lldp{}
	return t.Lldp
}

// GetLldp returns the value of the Lldp struct pointer
// from TerminalDevice_Channel_Ethernet. If the receiver or the field Lldp is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel_Ethernet) GetLldp() *TerminalDevice_Channel_Ethernet_Lldp {
	if t != nil && t.Lldp != nil {
		return t.Lldp
	}
	return nil
}

// GetAlsDelay retrieves the value of the leaf AlsDelay from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if AlsDelay is set, it can safely use t.GetAlsDelay()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.AlsDelay == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetAlsDelay() uint32 {
	if t == nil || t.AlsDelay == nil {
		return 0
	}
	return *t.AlsDelay
}

// GetClientAls retrieves the value of the leaf ClientAls from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ClientAls is set, it can safely use t.GetClientAls()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ClientAls == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetClientAls() E_Ethernet_ClientAls {
	if t == nil || t.ClientAls == 0 {
		return Ethernet_ClientAls_ETHERNET
	}
	return t.ClientAls
}

// GetIn_8021QFrames retrieves the value of the leaf In_8021QFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if In_8021QFrames is set, it can safely use t.GetIn_8021QFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.In_8021QFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetIn_8021QFrames() uint64 {
	if t == nil || t.In_8021QFrames == nil {
		return 0
	}
	return *t.In_8021QFrames
}

// GetInBlockErrors retrieves the value of the leaf InBlockErrors from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InBlockErrors is set, it can safely use t.GetInBlockErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InBlockErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInBlockErrors() uint64 {
	if t == nil || t.InBlockErrors == nil {
		return 0
	}
	return *t.InBlockErrors
}

// GetInCrcErrors retrieves the value of the leaf InCrcErrors from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InCrcErrors is set, it can safely use t.GetInCrcErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InCrcErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInCrcErrors() uint64 {
	if t == nil || t.InCrcErrors == nil {
		return 0
	}
	return *t.InCrcErrors
}

// GetInFragmentFrames retrieves the value of the leaf InFragmentFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InFragmentFrames is set, it can safely use t.GetInFragmentFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InFragmentFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInFragmentFrames() uint64 {
	if t == nil || t.InFragmentFrames == nil {
		return 0
	}
	return *t.InFragmentFrames
}

// GetInJabberFrames retrieves the value of the leaf InJabberFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InJabberFrames is set, it can safely use t.GetInJabberFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InJabberFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInJabberFrames() uint64 {
	if t == nil || t.InJabberFrames == nil {
		return 0
	}
	return *t.InJabberFrames
}

// GetInMacControlFrames retrieves the value of the leaf InMacControlFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InMacControlFrames is set, it can safely use t.GetInMacControlFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InMacControlFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInMacControlFrames() uint64 {
	if t == nil || t.InMacControlFrames == nil {
		return 0
	}
	return *t.InMacControlFrames
}

// GetInMacPauseFrames retrieves the value of the leaf InMacPauseFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InMacPauseFrames is set, it can safely use t.GetInMacPauseFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InMacPauseFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInMacPauseFrames() uint64 {
	if t == nil || t.InMacPauseFrames == nil {
		return 0
	}
	return *t.InMacPauseFrames
}

// GetInOversizeFrames retrieves the value of the leaf InOversizeFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InOversizeFrames is set, it can safely use t.GetInOversizeFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InOversizeFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInOversizeFrames() uint64 {
	if t == nil || t.InOversizeFrames == nil {
		return 0
	}
	return *t.InOversizeFrames
}

// GetInPcsBipErrors retrieves the value of the leaf InPcsBipErrors from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPcsBipErrors is set, it can safely use t.GetInPcsBipErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPcsBipErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInPcsBipErrors() uint64 {
	if t == nil || t.InPcsBipErrors == nil {
		return 0
	}
	return *t.InPcsBipErrors
}

// GetInPcsErroredSeconds retrieves the value of the leaf InPcsErroredSeconds from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPcsErroredSeconds is set, it can safely use t.GetInPcsErroredSeconds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPcsErroredSeconds == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInPcsErroredSeconds() uint64 {
	if t == nil || t.InPcsErroredSeconds == nil {
		return 0
	}
	return *t.InPcsErroredSeconds
}

// GetInPcsSeverelyErroredSeconds retrieves the value of the leaf InPcsSeverelyErroredSeconds from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPcsSeverelyErroredSeconds is set, it can safely use t.GetInPcsSeverelyErroredSeconds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPcsSeverelyErroredSeconds == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInPcsSeverelyErroredSeconds() uint64 {
	if t == nil || t.InPcsSeverelyErroredSeconds == nil {
		return 0
	}
	return *t.InPcsSeverelyErroredSeconds
}

// GetInPcsUnavailableSeconds retrieves the value of the leaf InPcsUnavailableSeconds from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InPcsUnavailableSeconds is set, it can safely use t.GetInPcsUnavailableSeconds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InPcsUnavailableSeconds == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInPcsUnavailableSeconds() uint64 {
	if t == nil || t.InPcsUnavailableSeconds == nil {
		return 0
	}
	return *t.InPcsUnavailableSeconds
}

// GetInUndersizeFrames retrieves the value of the leaf InUndersizeFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if InUndersizeFrames is set, it can safely use t.GetInUndersizeFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.InUndersizeFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetInUndersizeFrames() uint64 {
	if t == nil || t.InUndersizeFrames == nil {
		return 0
	}
	return *t.InUndersizeFrames
}

// GetOut_8021QFrames retrieves the value of the leaf Out_8021QFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Out_8021QFrames is set, it can safely use t.GetOut_8021QFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Out_8021QFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetOut_8021QFrames() uint64 {
	if t == nil || t.Out_8021QFrames == nil {
		return 0
	}
	return *t.Out_8021QFrames
}

// GetOutBlockErrors retrieves the value of the leaf OutBlockErrors from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutBlockErrors is set, it can safely use t.GetOutBlockErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutBlockErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetOutBlockErrors() uint64 {
	if t == nil || t.OutBlockErrors == nil {
		return 0
	}
	return *t.OutBlockErrors
}

// GetOutCrcErrors retrieves the value of the leaf OutCrcErrors from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutCrcErrors is set, it can safely use t.GetOutCrcErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutCrcErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetOutCrcErrors() uint64 {
	if t == nil || t.OutCrcErrors == nil {
		return 0
	}
	return *t.OutCrcErrors
}

// GetOutMacControlFrames retrieves the value of the leaf OutMacControlFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutMacControlFrames is set, it can safely use t.GetOutMacControlFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutMacControlFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetOutMacControlFrames() uint64 {
	if t == nil || t.OutMacControlFrames == nil {
		return 0
	}
	return *t.OutMacControlFrames
}

// GetOutMacPauseFrames retrieves the value of the leaf OutMacPauseFrames from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutMacPauseFrames is set, it can safely use t.GetOutMacPauseFrames()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutMacPauseFrames == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetOutMacPauseFrames() uint64 {
	if t == nil || t.OutMacPauseFrames == nil {
		return 0
	}
	return *t.OutMacPauseFrames
}

// GetOutPcsBipErrors retrieves the value of the leaf OutPcsBipErrors from the TerminalDevice_Channel_Ethernet
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OutPcsBipErrors is set, it can safely use t.GetOutPcsBipErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OutPcsBipErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet) GetOutPcsBipErrors() uint64 {
	if t == nil || t.OutPcsBipErrors == nil {
		return 0
	}
	return *t.OutPcsBipErrors
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Ethernet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Ethernet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Ethernet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Ethernet_Lldp represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/ethernet/lldp YANG schema element.
type TerminalDevice_Channel_Ethernet_Lldp struct {
	ΛMetadata []ygot.Annotation                                         `path:"@" ygotAnnotation:"true"`
	Counters  *TerminalDevice_Channel_Ethernet_Lldp_Counters            `path:"state/counters" module:"openconfig-terminal-device"`
	ΛCounters []ygot.Annotation                                         `path:"state/@counters" ygotAnnotation:"true"`
	Enabled   *bool                                                     `path:"state/enabled" shadow-path:"config/enabled" module:"openconfig-terminal-device"`
	ΛEnabled  []ygot.Annotation                                         `path:"state/@enabled" ygotAnnotation:"true"`
	Neighbor  map[string]*TerminalDevice_Channel_Ethernet_Lldp_Neighbor `path:"neighbors/neighbor" module:"openconfig-terminal-device"`
	ΛNeighbor []ygot.Annotation                                         `path:"neighbors/@neighbor" ygotAnnotation:"true"`
	Snooping  *bool                                                     `path:"state/snooping" shadow-path:"config/snooping" module:"openconfig-terminal-device"`
	ΛSnooping []ygot.Annotation                                         `path:"state/@snooping" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Ethernet_Lldp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Ethernet_Lldp) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// TerminalDevice_Channel_Ethernet_Lldp struct. The keys of the list are populated from the input
// arguments.
func (t *TerminalDevice_Channel_Ethernet_Lldp) NewNeighbor(Id string) (*TerminalDevice_Channel_Ethernet_Lldp_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*TerminalDevice_Channel_Ethernet_Lldp_Neighbor)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &TerminalDevice_Channel_Ethernet_Lldp_Neighbor{
		Id: &Id,
	}

	return t.Neighbor[key], nil
}

// RenameNeighbor renames an entry in the list Neighbor within
// the TerminalDevice_Channel_Ethernet_Lldp struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *TerminalDevice_Channel_Ethernet_Lldp) RenameNeighbor(oldK, newK string) error {
	if _, ok := t.Neighbor[newK]; ok {
		return fmt.Errorf("key %v already exists in Neighbor", newK)
	}

	e, ok := t.Neighbor[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Neighbor", oldK)
	}
	e.Id = &newK

	t.Neighbor[newK] = e
	delete(t.Neighbor, oldK)
	return nil
}

// GetOrCreateNeighbor retrieves the value with the specified keys from
// the receiver TerminalDevice_Channel_Ethernet_Lldp. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *TerminalDevice_Channel_Ethernet_Lldp) GetOrCreateNeighbor(Id string) *TerminalDevice_Channel_Ethernet_Lldp_Neighbor {

	key := Id

	if v, ok := t.Neighbor[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewNeighbor(Id)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateNeighbor got unexpected error: %v", err))
	}
	return v
}

// GetNeighbor retrieves the value with the specified key from
// the Neighbor map field of TerminalDevice_Channel_Ethernet_Lldp. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *TerminalDevice_Channel_Ethernet_Lldp) GetNeighbor(Id string) *TerminalDevice_Channel_Ethernet_Lldp_Neighbor {

	if t == nil {
		return nil
	}

	key := Id

	if lm, ok := t.Neighbor[key]; ok {
		return lm
	}
	return nil
}

// AppendNeighbor appends the supplied TerminalDevice_Channel_Ethernet_Lldp_Neighbor struct to the
// list Neighbor of TerminalDevice_Channel_Ethernet_Lldp. If the key value(s) specified in
// the supplied TerminalDevice_Channel_Ethernet_Lldp_Neighbor already exist in the list, an error is
// returned.
func (t *TerminalDevice_Channel_Ethernet_Lldp) AppendNeighbor(v *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) error {
	if v.Id == nil {
		return fmt.Errorf("invalid nil key received for Id")
	}

	key := *v.Id

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*TerminalDevice_Channel_Ethernet_Lldp_Neighbor)
	}

	if _, ok := t.Neighbor[key]; ok {
		return fmt.Errorf("duplicate key for list Neighbor %v", key)
	}

	t.Neighbor[key] = v
	return nil
}

// GetOrCreateCounters retrieves the value of the Counters field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel_Ethernet_Lldp) GetOrCreateCounters() *TerminalDevice_Channel_Ethernet_Lldp_Counters {
	if t.Counters != nil {
		return t.Counters
	}
	t.Counters = &TerminalDevice_Channel_Ethernet_Lldp_Counters{}
	return t.Counters
}

// GetCounters returns the value of the Counters struct pointer
// from TerminalDevice_Channel_Ethernet_Lldp. If the receiver or the field Counters is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel_Ethernet_Lldp) GetCounters() *TerminalDevice_Channel_Ethernet_Lldp_Counters {
	if t != nil && t.Counters != nil {
		return t.Counters
	}
	return nil
}

// GetEnabled retrieves the value of the leaf Enabled from the TerminalDevice_Channel_Ethernet_Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Enabled is set, it can safely use t.GetEnabled()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Enabled == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp) GetEnabled() bool {
	if t == nil || t.Enabled == nil {
		return false
	}
	return *t.Enabled
}

// GetSnooping retrieves the value of the leaf Snooping from the TerminalDevice_Channel_Ethernet_Lldp
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Snooping is set, it can safely use t.GetSnooping()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Snooping == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp) GetSnooping() bool {
	if t == nil || t.Snooping == nil {
		return false
	}
	return *t.Snooping
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Ethernet_Lldp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Ethernet_Lldp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Ethernet_Lldp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Ethernet_Lldp_Counters represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/ethernet/lldp/state/counters YANG schema element.
type TerminalDevice_Channel_Ethernet_Lldp_Counters struct {
	ΛMetadata      []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	FrameDiscard   *uint64           `path:"frame-discard" module:"openconfig-terminal-device"`
	ΛFrameDiscard  []ygot.Annotation `path:"@frame-discard" ygotAnnotation:"true"`
	FrameErrorIn   *uint64           `path:"frame-error-in" module:"openconfig-terminal-device"`
	ΛFrameErrorIn  []ygot.Annotation `path:"@frame-error-in" ygotAnnotation:"true"`
	FrameErrorOut  *uint64           `path:"frame-error-out" module:"openconfig-terminal-device"`
	ΛFrameErrorOut []ygot.Annotation `path:"@frame-error-out" ygotAnnotation:"true"`
	FrameIn        *uint64           `path:"frame-in" module:"openconfig-terminal-device"`
	ΛFrameIn       []ygot.Annotation `path:"@frame-in" ygotAnnotation:"true"`
	FrameOut       *uint64           `path:"frame-out" module:"openconfig-terminal-device"`
	ΛFrameOut      []ygot.Annotation `path:"@frame-out" ygotAnnotation:"true"`
	LastClear      *string           `path:"last-clear" module:"openconfig-terminal-device"`
	ΛLastClear     []ygot.Annotation `path:"@last-clear" ygotAnnotation:"true"`
	TlvDiscard     *uint64           `path:"tlv-discard" module:"openconfig-terminal-device"`
	ΛTlvDiscard    []ygot.Annotation `path:"@tlv-discard" ygotAnnotation:"true"`
	TlvUnknown     *uint64           `path:"tlv-unknown" module:"openconfig-terminal-device"`
	ΛTlvUnknown    []ygot.Annotation `path:"@tlv-unknown" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Ethernet_Lldp_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Ethernet_Lldp_Counters) IsYANGGoStruct() {}

// GetFrameDiscard retrieves the value of the leaf FrameDiscard from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameDiscard is set, it can safely use t.GetFrameDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameDiscard == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetFrameDiscard() uint64 {
	if t == nil || t.FrameDiscard == nil {
		return 0
	}
	return *t.FrameDiscard
}

// GetFrameErrorIn retrieves the value of the leaf FrameErrorIn from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameErrorIn is set, it can safely use t.GetFrameErrorIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameErrorIn == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetFrameErrorIn() uint64 {
	if t == nil || t.FrameErrorIn == nil {
		return 0
	}
	return *t.FrameErrorIn
}

// GetFrameErrorOut retrieves the value of the leaf FrameErrorOut from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameErrorOut is set, it can safely use t.GetFrameErrorOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameErrorOut == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetFrameErrorOut() uint64 {
	if t == nil || t.FrameErrorOut == nil {
		return 0
	}
	return *t.FrameErrorOut
}

// GetFrameIn retrieves the value of the leaf FrameIn from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameIn is set, it can safely use t.GetFrameIn()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameIn == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetFrameIn() uint64 {
	if t == nil || t.FrameIn == nil {
		return 0
	}
	return *t.FrameIn
}

// GetFrameOut retrieves the value of the leaf FrameOut from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FrameOut is set, it can safely use t.GetFrameOut()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FrameOut == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetFrameOut() uint64 {
	if t == nil || t.FrameOut == nil {
		return 0
	}
	return *t.FrameOut
}

// GetLastClear retrieves the value of the leaf LastClear from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastClear is set, it can safely use t.GetLastClear()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastClear == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetLastClear() string {
	if t == nil || t.LastClear == nil {
		return ""
	}
	return *t.LastClear
}

// GetTlvDiscard retrieves the value of the leaf TlvDiscard from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvDiscard is set, it can safely use t.GetTlvDiscard()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvDiscard == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetTlvDiscard() uint64 {
	if t == nil || t.TlvDiscard == nil {
		return 0
	}
	return *t.TlvDiscard
}

// GetTlvUnknown retrieves the value of the leaf TlvUnknown from the TerminalDevice_Channel_Ethernet_Lldp_Counters
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TlvUnknown is set, it can safely use t.GetTlvUnknown()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TlvUnknown == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) GetTlvUnknown() uint64 {
	if t == nil || t.TlvUnknown == nil {
		return 0
	}
	return *t.TlvUnknown
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Ethernet_Lldp_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Ethernet_Lldp_Neighbor represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/ethernet/lldp/neighbors/neighbor YANG schema element.
type TerminalDevice_Channel_Ethernet_Lldp_Neighbor struct {
	ΛMetadata              []ygot.Annotation                                                                                            `path:"@" ygotAnnotation:"true"`
	Age                    *uint64                                                                                                      `path:"state/age" module:"openconfig-terminal-device"`
	ΛAge                   []ygot.Annotation                                                                                            `path:"state/@age" ygotAnnotation:"true"`
	ChassisId              *string                                                                                                      `path:"state/chassis-id" module:"openconfig-terminal-device"`
	ΛChassisId             []ygot.Annotation                                                                                            `path:"state/@chassis-id" ygotAnnotation:"true"`
	ChassisIdType          E_OpenconfigLldpTypes_ChassisIdType                                                                          `path:"state/chassis-id-type" module:"openconfig-terminal-device"`
	ΛChassisIdType         []ygot.Annotation                                                                                            `path:"state/@chassis-id-type" ygotAnnotation:"true"`
	Id                     *string                                                                                                      `path:"state/id|id" module:"openconfig-terminal-device"`
	ΛId                    []ygot.Annotation                                                                                            `path:"state/@id|@id" ygotAnnotation:"true"`
	LastUpdate             *int64                                                                                                       `path:"state/last-update" module:"openconfig-terminal-device"`
	ΛLastUpdate            []ygot.Annotation                                                                                            `path:"state/@last-update" ygotAnnotation:"true"`
	ManagementAddress      *string                                                                                                      `path:"state/management-address" module:"openconfig-terminal-device"`
	ΛManagementAddress     []ygot.Annotation                                                                                            `path:"state/@management-address" ygotAnnotation:"true"`
	ManagementAddressType  *string                                                                                                      `path:"state/management-address-type" module:"openconfig-terminal-device"`
	ΛManagementAddressType []ygot.Annotation                                                                                            `path:"state/@management-address-type" ygotAnnotation:"true"`
	PortDescription        *string                                                                                                      `path:"state/port-description" module:"openconfig-terminal-device"`
	ΛPortDescription       []ygot.Annotation                                                                                            `path:"state/@port-description" ygotAnnotation:"true"`
	PortId                 *string                                                                                                      `path:"state/port-id" module:"openconfig-terminal-device"`
	ΛPortId                []ygot.Annotation                                                                                            `path:"state/@port-id" ygotAnnotation:"true"`
	PortIdType             E_OpenconfigLldpTypes_PortIdType                                                                             `path:"state/port-id-type" module:"openconfig-terminal-device"`
	ΛPortIdType            []ygot.Annotation                                                                                            `path:"state/@port-id-type" ygotAnnotation:"true"`
	SystemDescription      *string                                                                                                      `path:"state/system-description" module:"openconfig-terminal-device"`
	ΛSystemDescription     []ygot.Annotation                                                                                            `path:"state/@system-description" ygotAnnotation:"true"`
	SystemName             *string                                                                                                      `path:"state/system-name" module:"openconfig-terminal-device"`
	ΛSystemName            []ygot.Annotation                                                                                            `path:"state/@system-name" ygotAnnotation:"true"`
	Tlv                    map[TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key]*TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv `path:"custom-tlvs/tlv" module:"openconfig-terminal-device"`
	ΛTlv                   []ygot.Annotation                                                                                            `path:"custom-tlvs/@tlv" ygotAnnotation:"true"`
	Ttl                    *uint16                                                                                                      `path:"state/ttl" module:"openconfig-terminal-device"`
	ΛTtl                   []ygot.Annotation                                                                                            `path:"state/@ttl" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Ethernet_Lldp_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Ethernet_Lldp_Neighbor) IsYANGGoStruct() {}

// TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key represents the key for list Tlv of element /openconfig-terminal-device/terminal-device/logical-channels/channel/ethernet/lldp/neighbors/neighbor.
type TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key struct {
	Type       int32  `path:"type"`
	Oui        string `path:"oui"`
	OuiSubtype string `path:"oui-subtype"`
}

// NewTlv creates a new entry in the Tlv list of the
// TerminalDevice_Channel_Ethernet_Lldp_Neighbor struct. The keys of the list are populated from the input
// arguments.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) NewTlv(Type int32, Oui string, OuiSubtype string) (*TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key]*TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv)
	}

	key := TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key{
		Type:       Type,
		Oui:        Oui,
		OuiSubtype: OuiSubtype,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tlv", key)
	}

	t.Tlv[key] = &TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv{
		Type:       &Type,
		Oui:        &Oui,
		OuiSubtype: &OuiSubtype,
	}

	return t.Tlv[key], nil
}

// RenameTlv renames an entry in the list Tlv within
// the TerminalDevice_Channel_Ethernet_Lldp_Neighbor struct. The entry with key oldK is renamed to newK updating
// the key within the value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) RenameTlv(oldK, newK TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key) error {
	if _, ok := t.Tlv[newK]; ok {
		return fmt.Errorf("key %v already exists in Tlv", newK)
	}

	e, ok := t.Tlv[oldK]
	if !ok {
		return fmt.Errorf("key %v not found in Tlv", oldK)
	}
	e.Type = &newK.Type
	e.Oui = &newK.Oui
	e.OuiSubtype = &newK.OuiSubtype

	t.Tlv[newK] = e
	delete(t.Tlv, oldK)
	return nil
}

// GetOrCreateTlv retrieves the value with the specified keys from
// the receiver TerminalDevice_Channel_Ethernet_Lldp_Neighbor. If the entry does not exist, then it is created.
// It returns the existing or new list member.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetOrCreateTlv(Type int32, Oui string, OuiSubtype string) *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv {

	key := TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key{
		Type:       Type,
		Oui:        Oui,
		OuiSubtype: OuiSubtype,
	}

	if v, ok := t.Tlv[key]; ok {
		return v
	}
	// Panic if we receive an error, since we should have retrieved an existing
	// list member. This allows chaining of GetOrCreate methods.
	v, err := t.NewTlv(Type, Oui, OuiSubtype)
	if err != nil {
		panic(fmt.Sprintf("GetOrCreateTlv got unexpected error: %v", err))
	}
	return v
}

// GetTlv retrieves the value with the specified key from
// the Tlv map field of TerminalDevice_Channel_Ethernet_Lldp_Neighbor. If the receiver is nil, or
// the specified key is not present in the list, nil is returned such that Get*
// methods may be safely chained.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetTlv(Type int32, Oui string, OuiSubtype string) *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv {

	if t == nil {
		return nil
	}

	key := TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key{
		Type:       Type,
		Oui:        Oui,
		OuiSubtype: OuiSubtype,
	}

	if lm, ok := t.Tlv[key]; ok {
		return lm
	}
	return nil
}

// AppendTlv appends the supplied TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv struct to the
// list Tlv of TerminalDevice_Channel_Ethernet_Lldp_Neighbor. If the key value(s) specified in
// the supplied TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv already exist in the list, an error is
// returned.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) AppendTlv(v *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) error {
	if v.Type == nil {
		return fmt.Errorf("invalid nil key for Type")
	}

	if v.Oui == nil {
		return fmt.Errorf("invalid nil key for Oui")
	}

	if v.OuiSubtype == nil {
		return fmt.Errorf("invalid nil key for OuiSubtype")
	}

	key := TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key{
		Type:       *v.Type,
		Oui:        *v.Oui,
		OuiSubtype: *v.OuiSubtype,
	}

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv_Key]*TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv)
	}

	if _, ok := t.Tlv[key]; ok {
		return fmt.Errorf("duplicate key for list Tlv %v", key)
	}

	t.Tlv[key] = v
	return nil
}

// GetAge retrieves the value of the leaf Age from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Age is set, it can safely use t.GetAge()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Age == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetAge() uint64 {
	if t == nil || t.Age == nil {
		return 0
	}
	return *t.Age
}

// GetChassisId retrieves the value of the leaf ChassisId from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChassisId is set, it can safely use t.GetChassisId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChassisId == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetChassisId() string {
	if t == nil || t.ChassisId == nil {
		return ""
	}
	return *t.ChassisId
}

// GetChassisIdType retrieves the value of the leaf ChassisIdType from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ChassisIdType is set, it can safely use t.GetChassisIdType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ChassisIdType == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetChassisIdType() E_OpenconfigLldpTypes_ChassisIdType {
	if t == nil || t.ChassisIdType == 0 {
		return 0
	}
	return t.ChassisIdType
}

// GetId retrieves the value of the leaf Id from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Id is set, it can safely use t.GetId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Id == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetId() string {
	if t == nil || t.Id == nil {
		return ""
	}
	return *t.Id
}

// GetLastUpdate retrieves the value of the leaf LastUpdate from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if LastUpdate is set, it can safely use t.GetLastUpdate()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.LastUpdate == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetLastUpdate() int64 {
	if t == nil || t.LastUpdate == nil {
		return 0
	}
	return *t.LastUpdate
}

// GetManagementAddress retrieves the value of the leaf ManagementAddress from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ManagementAddress is set, it can safely use t.GetManagementAddress()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ManagementAddress == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetManagementAddress() string {
	if t == nil || t.ManagementAddress == nil {
		return ""
	}
	return *t.ManagementAddress
}

// GetManagementAddressType retrieves the value of the leaf ManagementAddressType from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ManagementAddressType is set, it can safely use t.GetManagementAddressType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ManagementAddressType == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetManagementAddressType() string {
	if t == nil || t.ManagementAddressType == nil {
		return ""
	}
	return *t.ManagementAddressType
}

// GetPortDescription retrieves the value of the leaf PortDescription from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortDescription is set, it can safely use t.GetPortDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortDescription == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetPortDescription() string {
	if t == nil || t.PortDescription == nil {
		return ""
	}
	return *t.PortDescription
}

// GetPortId retrieves the value of the leaf PortId from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortId is set, it can safely use t.GetPortId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortId == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetPortId() string {
	if t == nil || t.PortId == nil {
		return ""
	}
	return *t.PortId
}

// GetPortIdType retrieves the value of the leaf PortIdType from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PortIdType is set, it can safely use t.GetPortIdType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PortIdType == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetPortIdType() E_OpenconfigLldpTypes_PortIdType {
	if t == nil || t.PortIdType == 0 {
		return 0
	}
	return t.PortIdType
}

// GetSystemDescription retrieves the value of the leaf SystemDescription from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemDescription is set, it can safely use t.GetSystemDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemDescription == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetSystemDescription() string {
	if t == nil || t.SystemDescription == nil {
		return ""
	}
	return *t.SystemDescription
}

// GetSystemName retrieves the value of the leaf SystemName from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SystemName is set, it can safely use t.GetSystemName()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SystemName == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetSystemName() string {
	if t == nil || t.SystemName == nil {
		return ""
	}
	return *t.SystemName
}

// GetTtl retrieves the value of the leaf Ttl from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Ttl is set, it can safely use t.GetTtl()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Ttl == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) GetTtl() uint16 {
	if t == nil || t.Ttl == nil {
		return 0
	}
	return *t.Ttl
}

// ΛListKeyMap returns the keys of the TerminalDevice_Channel_Ethernet_Lldp_Neighbor struct, which is a YANG list entry.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Ethernet_Lldp_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/ethernet/lldp/neighbors/neighbor/custom-tlvs/tlv YANG schema element.
type TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv struct {
	ΛMetadata   []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Oui         *string           `path:"state/oui|oui" module:"openconfig-terminal-device"`
	ΛOui        []ygot.Annotation `path:"state/@oui|@oui" ygotAnnotation:"true"`
	OuiSubtype  *string           `path:"state/oui-subtype|oui-subtype" module:"openconfig-terminal-device"`
	ΛOuiSubtype []ygot.Annotation `path:"state/@oui-subtype|@oui-subtype" ygotAnnotation:"true"`
	Type        *int32            `path:"state/type|type" module:"openconfig-terminal-device"`
	ΛType       []ygot.Annotation `path:"state/@type|@type" ygotAnnotation:"true"`
	Value       Binary            `path:"state/value" module:"openconfig-terminal-device"`
	ΛValue      []ygot.Annotation `path:"state/@value" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) IsYANGGoStruct() {}

// GetOui retrieves the value of the leaf Oui from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Oui is set, it can safely use t.GetOui()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Oui == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) GetOui() string {
	if t == nil || t.Oui == nil {
		return ""
	}
	return *t.Oui
}

// GetOuiSubtype retrieves the value of the leaf OuiSubtype from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if OuiSubtype is set, it can safely use t.GetOuiSubtype()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.OuiSubtype == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) GetOuiSubtype() string {
	if t == nil || t.OuiSubtype == nil {
		return ""
	}
	return *t.OuiSubtype
}

// GetType retrieves the value of the leaf Type from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Type is set, it can safely use t.GetType()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Type == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) GetType() int32 {
	if t == nil || t.Type == nil {
		return 0
	}
	return *t.Type
}

// GetValue retrieves the value of the leaf Value from the TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Value is set, it can safely use t.GetValue()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Value == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) GetValue() Binary {
	if t == nil || t.Value == nil {
		return nil
	}
	return t.Value
}

// ΛListKeyMap returns the keys of the TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv struct, which is a YANG list entry.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Oui == nil {
		return nil, fmt.Errorf("nil value for key Oui")
	}

	if t.OuiSubtype == nil {
		return nil, fmt.Errorf("nil value for key OuiSubtype")
	}

	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"oui":         *t.Oui,
		"oui-subtype": *t.OuiSubtype,
		"type":        *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Ethernet_Lldp_Neighbor_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Ingress represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/ingress YANG schema element.
type TerminalDevice_Channel_Ingress struct {
	ΛMetadata        []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	PhysicalChannel  []uint16          `path:"state/physical-channel" shadow-path:"config/physical-channel" module:"openconfig-terminal-device"`
	ΛPhysicalChannel []ygot.Annotation `path:"state/@physical-channel" ygotAnnotation:"true"`
	Transceiver      *string           `path:"state/transceiver" shadow-path:"config/transceiver" module:"openconfig-terminal-device"`
	ΛTransceiver     []ygot.Annotation `path:"state/@transceiver" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Ingress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Ingress) IsYANGGoStruct() {}

// GetPhysicalChannel retrieves the value of the leaf PhysicalChannel from the TerminalDevice_Channel_Ingress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if PhysicalChannel is set, it can safely use t.GetPhysicalChannel()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.PhysicalChannel == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ingress) GetPhysicalChannel() []uint16 {
	if t == nil || t.PhysicalChannel == nil {
		return nil
	}
	return t.PhysicalChannel
}

// GetTransceiver retrieves the value of the leaf Transceiver from the TerminalDevice_Channel_Ingress
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Transceiver is set, it can safely use t.GetTransceiver()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Transceiver == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Ingress) GetTransceiver() string {
	if t == nil || t.Transceiver == nil {
		return ""
	}
	return *t.Transceiver
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Ingress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Ingress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Ingress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Otn represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/otn YANG schema element.
type TerminalDevice_Channel_Otn struct {
	ΛMetadata                 []ygot.Annotation                                     `path:"@" ygotAnnotation:"true"`
	BackgroundBlockErrors     *uint64                                               `path:"state/background-block-errors" module:"openconfig-terminal-device"`
	ΛBackgroundBlockErrors    []ygot.Annotation                                     `path:"state/@background-block-errors" ygotAnnotation:"true"`
	CodeViolations            *uint64                                               `path:"state/code-violations" module:"openconfig-terminal-device"`
	ΛCodeViolations           []ygot.Annotation                                     `path:"state/@code-violations" ygotAnnotation:"true"`
	ErroredBlocks             *uint64                                               `path:"state/errored-blocks" module:"openconfig-terminal-device"`
	ΛErroredBlocks            []ygot.Annotation                                     `path:"state/@errored-blocks" ygotAnnotation:"true"`
	ErroredSeconds            *uint64                                               `path:"state/errored-seconds" module:"openconfig-terminal-device"`
	ΛErroredSeconds           []ygot.Annotation                                     `path:"state/@errored-seconds" ygotAnnotation:"true"`
	Esnr                      *TerminalDevice_Channel_Otn_Esnr                      `path:"state/esnr" module:"openconfig-terminal-device"`
	ΛEsnr                     []ygot.Annotation                                     `path:"state/@esnr" ygotAnnotation:"true"`
	FecCorrectedBits          *uint64                                               `path:"state/fec-corrected-bits" module:"openconfig-terminal-device"`
	ΛFecCorrectedBits         []ygot.Annotation                                     `path:"state/@fec-corrected-bits" ygotAnnotation:"true"`
	FecCorrectedBytes         *uint64                                               `path:"state/fec-corrected-bytes" module:"openconfig-terminal-device"`
	ΛFecCorrectedBytes        []ygot.Annotation                                     `path:"state/@fec-corrected-bytes" ygotAnnotation:"true"`
	FecUncorrectableBlocks    *uint64                                               `path:"state/fec-uncorrectable-blocks" module:"openconfig-terminal-device"`
	ΛFecUncorrectableBlocks   []ygot.Annotation                                     `path:"state/@fec-uncorrectable-blocks" ygotAnnotation:"true"`
	FecUncorrectableWords     *uint64                                               `path:"state/fec-uncorrectable-words" module:"openconfig-terminal-device"`
	ΛFecUncorrectableWords    []ygot.Annotation                                     `path:"state/@fec-uncorrectable-words" ygotAnnotation:"true"`
	PostFecBer                *TerminalDevice_Channel_Otn_PostFecBer                `path:"state/post-fec-ber" module:"openconfig-terminal-device"`
	ΛPostFecBer               []ygot.Annotation                                     `path:"state/@post-fec-ber" ygotAnnotation:"true"`
	PreFecBer                 *TerminalDevice_Channel_Otn_PreFecBer                 `path:"state/pre-fec-ber" module:"openconfig-terminal-device"`
	ΛPreFecBer                []ygot.Annotation                                     `path:"state/@pre-fec-ber" ygotAnnotation:"true"`
	QValue                    *TerminalDevice_Channel_Otn_QValue                    `path:"state/q-value" module:"openconfig-terminal-device"`
	ΛQValue                   []ygot.Annotation                                     `path:"state/@q-value" ygotAnnotation:"true"`
	RdiMsg                    *string                                               `path:"state/rdi-msg" module:"openconfig-terminal-device"`
	ΛRdiMsg                   []ygot.Annotation                                     `path:"state/@rdi-msg" ygotAnnotation:"true"`
	SeverelyErroredSeconds    *uint64                                               `path:"state/severely-errored-seconds" module:"openconfig-terminal-device"`
	ΛSeverelyErroredSeconds   []ygot.Annotation                                     `path:"state/@severely-errored-seconds" ygotAnnotation:"true"`
	TributarySlotGranularity  E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY `path:"state/tributary-slot-granularity" shadow-path:"config/tributary-slot-granularity" module:"openconfig-terminal-device"`
	ΛTributarySlotGranularity []ygot.Annotation                                     `path:"state/@tributary-slot-granularity" ygotAnnotation:"true"`
	TtiMsgAuto                *bool                                                 `path:"state/tti-msg-auto" shadow-path:"config/tti-msg-auto" module:"openconfig-terminal-device"`
	ΛTtiMsgAuto               []ygot.Annotation                                     `path:"state/@tti-msg-auto" ygotAnnotation:"true"`
	TtiMsgExpected            *string                                               `path:"state/tti-msg-expected" shadow-path:"config/tti-msg-expected" module:"openconfig-terminal-device"`
	ΛTtiMsgExpected           []ygot.Annotation                                     `path:"state/@tti-msg-expected" ygotAnnotation:"true"`
	TtiMsgRecv                *string                                               `path:"state/tti-msg-recv" module:"openconfig-terminal-device"`
	ΛTtiMsgRecv               []ygot.Annotation                                     `path:"state/@tti-msg-recv" ygotAnnotation:"true"`
	TtiMsgTransmit            *string                                               `path:"state/tti-msg-transmit" shadow-path:"config/tti-msg-transmit" module:"openconfig-terminal-device"`
	ΛTtiMsgTransmit           []ygot.Annotation                                     `path:"state/@tti-msg-transmit" ygotAnnotation:"true"`
	UnavailableSeconds        *uint64                                               `path:"state/unavailable-seconds" module:"openconfig-terminal-device"`
	ΛUnavailableSeconds       []ygot.Annotation                                     `path:"state/@unavailable-seconds" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Otn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Otn) IsYANGGoStruct() {}

// GetOrCreateEsnr retrieves the value of the Esnr field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel_Otn) GetOrCreateEsnr() *TerminalDevice_Channel_Otn_Esnr {
	if t.Esnr != nil {
		return t.Esnr
	}
	t.Esnr = &TerminalDevice_Channel_Otn_Esnr{}
	return t.Esnr
}

// GetOrCreatePostFecBer retrieves the value of the PostFecBer field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel_Otn) GetOrCreatePostFecBer() *TerminalDevice_Channel_Otn_PostFecBer {
	if t.PostFecBer != nil {
		return t.PostFecBer
	}
	t.PostFecBer = &TerminalDevice_Channel_Otn_PostFecBer{}
	return t.PostFecBer
}

// GetOrCreatePreFecBer retrieves the value of the PreFecBer field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel_Otn) GetOrCreatePreFecBer() *TerminalDevice_Channel_Otn_PreFecBer {
	if t.PreFecBer != nil {
		return t.PreFecBer
	}
	t.PreFecBer = &TerminalDevice_Channel_Otn_PreFecBer{}
	return t.PreFecBer
}

// GetOrCreateQValue retrieves the value of the QValue field
// or returns the existing field if it already exists.
func (t *TerminalDevice_Channel_Otn) GetOrCreateQValue() *TerminalDevice_Channel_Otn_QValue {
	if t.QValue != nil {
		return t.QValue
	}
	t.QValue = &TerminalDevice_Channel_Otn_QValue{}
	return t.QValue
}

// GetEsnr returns the value of the Esnr struct pointer
// from TerminalDevice_Channel_Otn. If the receiver or the field Esnr is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel_Otn) GetEsnr() *TerminalDevice_Channel_Otn_Esnr {
	if t != nil && t.Esnr != nil {
		return t.Esnr
	}
	return nil
}

// GetPostFecBer returns the value of the PostFecBer struct pointer
// from TerminalDevice_Channel_Otn. If the receiver or the field PostFecBer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel_Otn) GetPostFecBer() *TerminalDevice_Channel_Otn_PostFecBer {
	if t != nil && t.PostFecBer != nil {
		return t.PostFecBer
	}
	return nil
}

// GetPreFecBer returns the value of the PreFecBer struct pointer
// from TerminalDevice_Channel_Otn. If the receiver or the field PreFecBer is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel_Otn) GetPreFecBer() *TerminalDevice_Channel_Otn_PreFecBer {
	if t != nil && t.PreFecBer != nil {
		return t.PreFecBer
	}
	return nil
}

// GetQValue returns the value of the QValue struct pointer
// from TerminalDevice_Channel_Otn. If the receiver or the field QValue is nil, nil
// is returned such that the Get* methods can be safely chained.
func (t *TerminalDevice_Channel_Otn) GetQValue() *TerminalDevice_Channel_Otn_QValue {
	if t != nil && t.QValue != nil {
		return t.QValue
	}
	return nil
}

// GetBackgroundBlockErrors retrieves the value of the leaf BackgroundBlockErrors from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if BackgroundBlockErrors is set, it can safely use t.GetBackgroundBlockErrors()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.BackgroundBlockErrors == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetBackgroundBlockErrors() uint64 {
	if t == nil || t.BackgroundBlockErrors == nil {
		return 0
	}
	return *t.BackgroundBlockErrors
}

// GetCodeViolations retrieves the value of the leaf CodeViolations from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if CodeViolations is set, it can safely use t.GetCodeViolations()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.CodeViolations == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetCodeViolations() uint64 {
	if t == nil || t.CodeViolations == nil {
		return 0
	}
	return *t.CodeViolations
}

// GetErroredBlocks retrieves the value of the leaf ErroredBlocks from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ErroredBlocks is set, it can safely use t.GetErroredBlocks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ErroredBlocks == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetErroredBlocks() uint64 {
	if t == nil || t.ErroredBlocks == nil {
		return 0
	}
	return *t.ErroredBlocks
}

// GetErroredSeconds retrieves the value of the leaf ErroredSeconds from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ErroredSeconds is set, it can safely use t.GetErroredSeconds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ErroredSeconds == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetErroredSeconds() uint64 {
	if t == nil || t.ErroredSeconds == nil {
		return 0
	}
	return *t.ErroredSeconds
}

// GetFecCorrectedBits retrieves the value of the leaf FecCorrectedBits from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecCorrectedBits is set, it can safely use t.GetFecCorrectedBits()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecCorrectedBits == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetFecCorrectedBits() uint64 {
	if t == nil || t.FecCorrectedBits == nil {
		return 0
	}
	return *t.FecCorrectedBits
}

// GetFecCorrectedBytes retrieves the value of the leaf FecCorrectedBytes from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecCorrectedBytes is set, it can safely use t.GetFecCorrectedBytes()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecCorrectedBytes == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetFecCorrectedBytes() uint64 {
	if t == nil || t.FecCorrectedBytes == nil {
		return 0
	}
	return *t.FecCorrectedBytes
}

// GetFecUncorrectableBlocks retrieves the value of the leaf FecUncorrectableBlocks from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecUncorrectableBlocks is set, it can safely use t.GetFecUncorrectableBlocks()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecUncorrectableBlocks == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetFecUncorrectableBlocks() uint64 {
	if t == nil || t.FecUncorrectableBlocks == nil {
		return 0
	}
	return *t.FecUncorrectableBlocks
}

// GetFecUncorrectableWords retrieves the value of the leaf FecUncorrectableWords from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if FecUncorrectableWords is set, it can safely use t.GetFecUncorrectableWords()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.FecUncorrectableWords == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetFecUncorrectableWords() uint64 {
	if t == nil || t.FecUncorrectableWords == nil {
		return 0
	}
	return *t.FecUncorrectableWords
}

// GetRdiMsg retrieves the value of the leaf RdiMsg from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if RdiMsg is set, it can safely use t.GetRdiMsg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.RdiMsg == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetRdiMsg() string {
	if t == nil || t.RdiMsg == nil {
		return ""
	}
	return *t.RdiMsg
}

// GetSeverelyErroredSeconds retrieves the value of the leaf SeverelyErroredSeconds from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if SeverelyErroredSeconds is set, it can safely use t.GetSeverelyErroredSeconds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.SeverelyErroredSeconds == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetSeverelyErroredSeconds() uint64 {
	if t == nil || t.SeverelyErroredSeconds == nil {
		return 0
	}
	return *t.SeverelyErroredSeconds
}

// GetTributarySlotGranularity retrieves the value of the leaf TributarySlotGranularity from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TributarySlotGranularity is set, it can safely use t.GetTributarySlotGranularity()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TributarySlotGranularity == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetTributarySlotGranularity() E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY {
	if t == nil || t.TributarySlotGranularity == 0 {
		return 0
	}
	return t.TributarySlotGranularity
}

// GetTtiMsgAuto retrieves the value of the leaf TtiMsgAuto from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TtiMsgAuto is set, it can safely use t.GetTtiMsgAuto()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TtiMsgAuto == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetTtiMsgAuto() bool {
	if t == nil || t.TtiMsgAuto == nil {
		return false
	}
	return *t.TtiMsgAuto
}

// GetTtiMsgExpected retrieves the value of the leaf TtiMsgExpected from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TtiMsgExpected is set, it can safely use t.GetTtiMsgExpected()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TtiMsgExpected == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetTtiMsgExpected() string {
	if t == nil || t.TtiMsgExpected == nil {
		return ""
	}
	return *t.TtiMsgExpected
}

// GetTtiMsgRecv retrieves the value of the leaf TtiMsgRecv from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TtiMsgRecv is set, it can safely use t.GetTtiMsgRecv()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TtiMsgRecv == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetTtiMsgRecv() string {
	if t == nil || t.TtiMsgRecv == nil {
		return ""
	}
	return *t.TtiMsgRecv
}

// GetTtiMsgTransmit retrieves the value of the leaf TtiMsgTransmit from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if TtiMsgTransmit is set, it can safely use t.GetTtiMsgTransmit()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.TtiMsgTransmit == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetTtiMsgTransmit() string {
	if t == nil || t.TtiMsgTransmit == nil {
		return ""
	}
	return *t.TtiMsgTransmit
}

// GetUnavailableSeconds retrieves the value of the leaf UnavailableSeconds from the TerminalDevice_Channel_Otn
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if UnavailableSeconds is set, it can safely use t.GetUnavailableSeconds()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.UnavailableSeconds == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn) GetUnavailableSeconds() uint64 {
	if t == nil || t.UnavailableSeconds == nil {
		return 0
	}
	return *t.UnavailableSeconds
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Otn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Otn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Otn) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// TerminalDevice_Channel_Otn_Esnr represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/otn/state/esnr YANG schema element.
type TerminalDevice_Channel_Otn_Esnr struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Otn_Esnr implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Otn_Esnr) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the TerminalDevice_Channel_Otn_Esnr
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_Esnr) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Otn_Esnr) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Otn_Esnr"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Otn_Esnr) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Otn_PostFecBer represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/otn/state/post-fec-ber YANG schema element.
type TerminalDevice_Channel_Otn_PostFecBer struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Otn_PostFecBer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Otn_PostFecBer) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the TerminalDevice_Channel_Otn_PostFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PostFecBer) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Otn_PostFecBer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Otn_PostFecBer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Otn_PostFecBer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Otn_PreFecBer represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/otn/state/pre-fec-ber YANG schema element.
type TerminalDevice_Channel_Otn_PreFecBer struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Otn_PreFecBer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Otn_PreFecBer) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the TerminalDevice_Channel_Otn_PreFecBer
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_PreFecBer) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Otn_PreFecBer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Otn_PreFecBer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Otn_PreFecBer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Channel_Otn_QValue represents the /openconfig-terminal-device/terminal-device/logical-channels/channel/otn/state/q-value YANG schema element.
type TerminalDevice_Channel_Otn_QValue struct {
	ΛMetadata []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Avg       *float64          `path:"avg" module:"openconfig-terminal-device"`
	ΛAvg      []ygot.Annotation `path:"@avg" ygotAnnotation:"true"`
	Instant   *float64          `path:"instant" module:"openconfig-terminal-device"`
	ΛInstant  []ygot.Annotation `path:"@instant" ygotAnnotation:"true"`
	Interval  *uint64           `path:"interval" module:"openconfig-terminal-device"`
	ΛInterval []ygot.Annotation `path:"@interval" ygotAnnotation:"true"`
	Max       *float64          `path:"max" module:"openconfig-terminal-device"`
	ΛMax      []ygot.Annotation `path:"@max" ygotAnnotation:"true"`
	MaxTime   *uint64           `path:"max-time" module:"openconfig-terminal-device"`
	ΛMaxTime  []ygot.Annotation `path:"@max-time" ygotAnnotation:"true"`
	Min       *float64          `path:"min" module:"openconfig-terminal-device"`
	ΛMin      []ygot.Annotation `path:"@min" ygotAnnotation:"true"`
	MinTime   *uint64           `path:"min-time" module:"openconfig-terminal-device"`
	ΛMinTime  []ygot.Annotation `path:"@min-time" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Channel_Otn_QValue implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Channel_Otn_QValue) IsYANGGoStruct() {}

// GetAvg retrieves the value of the leaf Avg from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Avg is set, it can safely use t.GetAvg()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Avg == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetAvg() float64 {
	if t == nil || t.Avg == nil {
		return 0.0
	}
	return *t.Avg
}

// GetInstant retrieves the value of the leaf Instant from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Instant is set, it can safely use t.GetInstant()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Instant == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetInstant() float64 {
	if t == nil || t.Instant == nil {
		return 0.0
	}
	return *t.Instant
}

// GetInterval retrieves the value of the leaf Interval from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Interval is set, it can safely use t.GetInterval()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Interval == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetInterval() uint64 {
	if t == nil || t.Interval == nil {
		return 0
	}
	return *t.Interval
}

// GetMax retrieves the value of the leaf Max from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Max is set, it can safely use t.GetMax()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Max == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetMax() float64 {
	if t == nil || t.Max == nil {
		return 0.0
	}
	return *t.Max
}

// GetMaxTime retrieves the value of the leaf MaxTime from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MaxTime is set, it can safely use t.GetMaxTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MaxTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetMaxTime() uint64 {
	if t == nil || t.MaxTime == nil {
		return 0
	}
	return *t.MaxTime
}

// GetMin retrieves the value of the leaf Min from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Min is set, it can safely use t.GetMin()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Min == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetMin() float64 {
	if t == nil || t.Min == nil {
		return 0.0
	}
	return *t.Min
}

// GetMinTime retrieves the value of the leaf MinTime from the TerminalDevice_Channel_Otn_QValue
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if MinTime is set, it can safely use t.GetMinTime()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.MinTime == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Channel_Otn_QValue) GetMinTime() uint64 {
	if t == nil || t.MinTime == nil {
		return 0
	}
	return *t.MinTime
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Channel_Otn_QValue) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Channel_Otn_QValue"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Channel_Otn_QValue) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// TerminalDevice_Mode represents the /openconfig-terminal-device/terminal-device/operational-modes/mode YANG schema element.
type TerminalDevice_Mode struct {
	ΛMetadata    []ygot.Annotation `path:"@" ygotAnnotation:"true"`
	Description  *string           `path:"state/description" module:"openconfig-terminal-device"`
	ΛDescription []ygot.Annotation `path:"state/@description" ygotAnnotation:"true"`
	ModeId       *uint16           `path:"state/mode-id|mode-id" module:"openconfig-terminal-device"`
	ΛModeId      []ygot.Annotation `path:"state/@mode-id|@mode-id" ygotAnnotation:"true"`
	VendorId     *string           `path:"state/vendor-id" module:"openconfig-terminal-device"`
	ΛVendorId    []ygot.Annotation `path:"state/@vendor-id" ygotAnnotation:"true"`
}

// IsYANGGoStruct ensures that TerminalDevice_Mode implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*TerminalDevice_Mode) IsYANGGoStruct() {}

// GetDescription retrieves the value of the leaf Description from the TerminalDevice_Mode
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if Description is set, it can safely use t.GetDescription()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.Description == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Mode) GetDescription() string {
	if t == nil || t.Description == nil {
		return ""
	}
	return *t.Description
}

// GetModeId retrieves the value of the leaf ModeId from the TerminalDevice_Mode
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if ModeId is set, it can safely use t.GetModeId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.ModeId == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Mode) GetModeId() uint16 {
	if t == nil || t.ModeId == nil {
		return 0
	}
	return *t.ModeId
}

// GetVendorId retrieves the value of the leaf VendorId from the TerminalDevice_Mode
// struct. Caution should be exercised whilst using this method since it will return
// the Go zero value if the field is explicitly unset. If the caller explicitly does
// not care if VendorId is set, it can safely use t.GetVendorId()
// to retrieve the value. In the case that the caller has different actions based on
// whether the leaf is set or unset, it should use 'if t.VendorId == nil'
// before retrieving the leaf's value.
func (t *TerminalDevice_Mode) GetVendorId() string {
	if t == nil || t.VendorId == nil {
		return ""
	}
	return *t.VendorId
}

// ΛListKeyMap returns the keys of the TerminalDevice_Mode struct, which is a YANG list entry.
func (t *TerminalDevice_Mode) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModeId == nil {
		return nil, fmt.Errorf("nil value for key ModeId")
	}

	return map[string]interface{}{
		"mode-id": *t.ModeId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *TerminalDevice_Mode) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["TerminalDevice_Mode"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *TerminalDevice_Mode) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// E_Address_Status is a derived int64 type which is used to represent
// the enumerated node Address_Status. An additional value named
// Address_Status_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Address_Status int64

// IsYANGGoEnum ensures that Address_Status implements the yang.GoEnum
// interface. This ensures that Address_Status can be identified as a
// mapped type for a YANG enumeration.
func (E_Address_Status) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Address_Status.
func (E_Address_Status) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Address_Status.
func (e E_Address_Status) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Address_Status")
}

const (
	// Address_Status_UNSET corresponds to the value UNSET of Address_Status
	Address_Status_UNSET E_Address_Status = 0
	// Address_Status_PREFERRED corresponds to the value PREFERRED of Address_Status
	Address_Status_PREFERRED E_Address_Status = 1
	// Address_Status_DEPRECATED corresponds to the value DEPRECATED of Address_Status
	Address_Status_DEPRECATED E_Address_Status = 2
	// Address_Status_INVALID corresponds to the value INVALID of Address_Status
	Address_Status_INVALID E_Address_Status = 3
	// Address_Status_INACCESSIBLE corresponds to the value INACCESSIBLE of Address_Status
	Address_Status_INACCESSIBLE E_Address_Status = 4
	// Address_Status_UNKNOWN corresponds to the value UNKNOWN of Address_Status
	Address_Status_UNKNOWN E_Address_Status = 5
	// Address_Status_TENTATIVE corresponds to the value TENTATIVE of Address_Status
	Address_Status_TENTATIVE E_Address_Status = 6
	// Address_Status_DUPLICATE corresponds to the value DUPLICATE of Address_Status
	Address_Status_DUPLICATE E_Address_Status = 7
	// Address_Status_OPTIMISTIC corresponds to the value OPTIMISTIC of Address_Status
	Address_Status_OPTIMISTIC E_Address_Status = 8
)

// E_AdjacencySid_Flags is a derived int64 type which is used to represent
// the enumerated node AdjacencySid_Flags. An additional value named
// AdjacencySid_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_AdjacencySid_Flags int64

// IsYANGGoEnum ensures that AdjacencySid_Flags implements the yang.GoEnum
// interface. This ensures that AdjacencySid_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_AdjacencySid_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  AdjacencySid_Flags.
func (E_AdjacencySid_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_AdjacencySid_Flags.
func (e E_AdjacencySid_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_AdjacencySid_Flags")
}

const (
	// AdjacencySid_Flags_UNSET corresponds to the value UNSET of AdjacencySid_Flags
	AdjacencySid_Flags_UNSET E_AdjacencySid_Flags = 0
	// AdjacencySid_Flags_ADDRESS_FAMILY corresponds to the value ADDRESS_FAMILY of AdjacencySid_Flags
	AdjacencySid_Flags_ADDRESS_FAMILY E_AdjacencySid_Flags = 1
	// AdjacencySid_Flags_BACKUP corresponds to the value BACKUP of AdjacencySid_Flags
	AdjacencySid_Flags_BACKUP E_AdjacencySid_Flags = 2
	// AdjacencySid_Flags_VALUE corresponds to the value VALUE of AdjacencySid_Flags
	AdjacencySid_Flags_VALUE E_AdjacencySid_Flags = 3
	// AdjacencySid_Flags_LOCAL corresponds to the value LOCAL of AdjacencySid_Flags
	AdjacencySid_Flags_LOCAL E_AdjacencySid_Flags = 4
	// AdjacencySid_Flags_SET corresponds to the value SET of AdjacencySid_Flags
	AdjacencySid_Flags_SET E_AdjacencySid_Flags = 5
)

// E_AdjacencySid_SidId_Enum is a derived int64 type which is used to represent
// the enumerated node AdjacencySid_SidId_Enum. An additional value named
// AdjacencySid_SidId_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_AdjacencySid_SidId_Enum int64

// IsYANGGoEnum ensures that AdjacencySid_SidId_Enum implements the yang.GoEnum
// interface. This ensures that AdjacencySid_SidId_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_AdjacencySid_SidId_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  AdjacencySid_SidId_Enum.
func (E_AdjacencySid_SidId_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_AdjacencySid_SidId_Enum.
func (e E_AdjacencySid_SidId_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_AdjacencySid_SidId_Enum")
}

const (
	// AdjacencySid_SidId_Enum_UNSET corresponds to the value UNSET of AdjacencySid_SidId_Enum
	AdjacencySid_SidId_Enum_UNSET E_AdjacencySid_SidId_Enum = 0
	// AdjacencySid_SidId_Enum_DYNAMIC corresponds to the value DYNAMIC of AdjacencySid_SidId_Enum
	AdjacencySid_SidId_Enum_DYNAMIC E_AdjacencySid_SidId_Enum = 1
)

// E_Adjacency_Nlpid is a derived int64 type which is used to represent
// the enumerated node Adjacency_Nlpid. An additional value named
// Adjacency_Nlpid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Adjacency_Nlpid int64

// IsYANGGoEnum ensures that Adjacency_Nlpid implements the yang.GoEnum
// interface. This ensures that Adjacency_Nlpid can be identified as a
// mapped type for a YANG enumeration.
func (E_Adjacency_Nlpid) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Adjacency_Nlpid.
func (E_Adjacency_Nlpid) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Adjacency_Nlpid.
func (e E_Adjacency_Nlpid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Adjacency_Nlpid")
}

const (
	// Adjacency_Nlpid_UNSET corresponds to the value UNSET of Adjacency_Nlpid
	Adjacency_Nlpid_UNSET E_Adjacency_Nlpid = 0
	// Adjacency_Nlpid_IPV4 corresponds to the value IPV4 of Adjacency_Nlpid
	Adjacency_Nlpid_IPV4 E_Adjacency_Nlpid = 1
	// Adjacency_Nlpid_IPV6 corresponds to the value IPV6 of Adjacency_Nlpid
	Adjacency_Nlpid_IPV6 E_Adjacency_Nlpid = 2
)

// E_ApsModule_ForceToPort is a derived int64 type which is used to represent
// the enumerated node ApsModule_ForceToPort. An additional value named
// ApsModule_ForceToPort_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_ApsModule_ForceToPort int64

// IsYANGGoEnum ensures that ApsModule_ForceToPort implements the yang.GoEnum
// interface. This ensures that ApsModule_ForceToPort can be identified as a
// mapped type for a YANG enumeration.
func (E_ApsModule_ForceToPort) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  ApsModule_ForceToPort.
func (E_ApsModule_ForceToPort) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_ApsModule_ForceToPort.
func (e E_ApsModule_ForceToPort) String() string {
	return ygot.EnumLogString(e, int64(e), "E_ApsModule_ForceToPort")
}

const (
	// ApsModule_ForceToPort_UNSET corresponds to the value UNSET of ApsModule_ForceToPort
	ApsModule_ForceToPort_UNSET E_ApsModule_ForceToPort = 0
	// ApsModule_ForceToPort_NONE corresponds to the value NONE of ApsModule_ForceToPort
	ApsModule_ForceToPort_NONE E_ApsModule_ForceToPort = 1
	// ApsModule_ForceToPort_PRIMARY corresponds to the value PRIMARY of ApsModule_ForceToPort
	ApsModule_ForceToPort_PRIMARY E_ApsModule_ForceToPort = 2
	// ApsModule_ForceToPort_SECONDARY corresponds to the value SECONDARY of ApsModule_ForceToPort
	ApsModule_ForceToPort_SECONDARY E_ApsModule_ForceToPort = 3
)

// E_AsExternalLsa_MetricType is a derived int64 type which is used to represent
// the enumerated node AsExternalLsa_MetricType. An additional value named
// AsExternalLsa_MetricType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_AsExternalLsa_MetricType int64

// IsYANGGoEnum ensures that AsExternalLsa_MetricType implements the yang.GoEnum
// interface. This ensures that AsExternalLsa_MetricType can be identified as a
// mapped type for a YANG enumeration.
func (E_AsExternalLsa_MetricType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  AsExternalLsa_MetricType.
func (E_AsExternalLsa_MetricType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_AsExternalLsa_MetricType.
func (e E_AsExternalLsa_MetricType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_AsExternalLsa_MetricType")
}

const (
	// AsExternalLsa_MetricType_UNSET corresponds to the value UNSET of AsExternalLsa_MetricType
	AsExternalLsa_MetricType_UNSET E_AsExternalLsa_MetricType = 0
	// AsExternalLsa_MetricType_TYPE_1 corresponds to the value TYPE_1 of AsExternalLsa_MetricType
	AsExternalLsa_MetricType_TYPE_1 E_AsExternalLsa_MetricType = 1
	// AsExternalLsa_MetricType_TYPE_2 corresponds to the value TYPE_2 of AsExternalLsa_MetricType
	AsExternalLsa_MetricType_TYPE_2 E_AsExternalLsa_MetricType = 2
)

// E_Assignment_AssignmentType is a derived int64 type which is used to represent
// the enumerated node Assignment_AssignmentType. An additional value named
// Assignment_AssignmentType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Assignment_AssignmentType int64

// IsYANGGoEnum ensures that Assignment_AssignmentType implements the yang.GoEnum
// interface. This ensures that Assignment_AssignmentType can be identified as a
// mapped type for a YANG enumeration.
func (E_Assignment_AssignmentType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Assignment_AssignmentType.
func (E_Assignment_AssignmentType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Assignment_AssignmentType.
func (e E_Assignment_AssignmentType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Assignment_AssignmentType")
}

const (
	// Assignment_AssignmentType_UNSET corresponds to the value UNSET of Assignment_AssignmentType
	Assignment_AssignmentType_UNSET E_Assignment_AssignmentType = 0
	// Assignment_AssignmentType_LOGICAL_CHANNEL corresponds to the value LOGICAL_CHANNEL of Assignment_AssignmentType
	Assignment_AssignmentType_LOGICAL_CHANNEL E_Assignment_AssignmentType = 1
	// Assignment_AssignmentType_OPTICAL_CHANNEL corresponds to the value OPTICAL_CHANNEL of Assignment_AssignmentType
	Assignment_AssignmentType_OPTICAL_CHANNEL E_Assignment_AssignmentType = 2
)

// E_Authentication_CryptoType is a derived int64 type which is used to represent
// the enumerated node Authentication_CryptoType. An additional value named
// Authentication_CryptoType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Authentication_CryptoType int64

// IsYANGGoEnum ensures that Authentication_CryptoType implements the yang.GoEnum
// interface. This ensures that Authentication_CryptoType can be identified as a
// mapped type for a YANG enumeration.
func (E_Authentication_CryptoType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Authentication_CryptoType.
func (E_Authentication_CryptoType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Authentication_CryptoType.
func (e E_Authentication_CryptoType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Authentication_CryptoType")
}

const (
	// Authentication_CryptoType_UNSET corresponds to the value UNSET of Authentication_CryptoType
	Authentication_CryptoType_UNSET E_Authentication_CryptoType = 0
	// Authentication_CryptoType_HMAC_MD5 corresponds to the value HMAC_MD5 of Authentication_CryptoType
	Authentication_CryptoType_HMAC_MD5 E_Authentication_CryptoType = 1
	// Authentication_CryptoType_CLEARTEXT corresponds to the value CLEARTEXT of Authentication_CryptoType
	Authentication_CryptoType_CLEARTEXT E_Authentication_CryptoType = 2
)

// E_BandwidthReservation_Priority_Enum is a derived int64 type which is used to represent
// the enumerated node BandwidthReservation_Priority_Enum. An additional value named
// BandwidthReservation_Priority_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_BandwidthReservation_Priority_Enum int64

// IsYANGGoEnum ensures that BandwidthReservation_Priority_Enum implements the yang.GoEnum
// interface. This ensures that BandwidthReservation_Priority_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_BandwidthReservation_Priority_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  BandwidthReservation_Priority_Enum.
func (E_BandwidthReservation_Priority_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_BandwidthReservation_Priority_Enum.
func (e E_BandwidthReservation_Priority_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_BandwidthReservation_Priority_Enum")
}

const (
	// BandwidthReservation_Priority_Enum_UNSET corresponds to the value UNSET of BandwidthReservation_Priority_Enum
	BandwidthReservation_Priority_Enum_UNSET E_BandwidthReservation_Priority_Enum = 0
	// BandwidthReservation_Priority_Enum_ALL corresponds to the value ALL of BandwidthReservation_Priority_Enum
	BandwidthReservation_Priority_Enum_ALL E_BandwidthReservation_Priority_Enum = 1
)

// E_Capability_Flags is a derived int64 type which is used to represent
// the enumerated node Capability_Flags. An additional value named
// Capability_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Capability_Flags int64

// IsYANGGoEnum ensures that Capability_Flags implements the yang.GoEnum
// interface. This ensures that Capability_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_Capability_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Capability_Flags.
func (E_Capability_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Capability_Flags.
func (e E_Capability_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Capability_Flags")
}

const (
	// Capability_Flags_UNSET corresponds to the value UNSET of Capability_Flags
	Capability_Flags_UNSET E_Capability_Flags = 0
	// Capability_Flags_FLOOD corresponds to the value FLOOD of Capability_Flags
	Capability_Flags_FLOOD E_Capability_Flags = 1
	// Capability_Flags_DOWN corresponds to the value DOWN of Capability_Flags
	Capability_Flags_DOWN E_Capability_Flags = 2
)

// E_Channel_LinkState is a derived int64 type which is used to represent
// the enumerated node Channel_LinkState. An additional value named
// Channel_LinkState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Channel_LinkState int64

// IsYANGGoEnum ensures that Channel_LinkState implements the yang.GoEnum
// interface. This ensures that Channel_LinkState can be identified as a
// mapped type for a YANG enumeration.
func (E_Channel_LinkState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Channel_LinkState.
func (E_Channel_LinkState) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Channel_LinkState.
func (e E_Channel_LinkState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Channel_LinkState")
}

const (
	// Channel_LinkState_UNSET corresponds to the value UNSET of Channel_LinkState
	Channel_LinkState_UNSET E_Channel_LinkState = 0
	// Channel_LinkState_UP corresponds to the value UP of Channel_LinkState
	Channel_LinkState_UP E_Channel_LinkState = 1
	// Channel_LinkState_DOWN corresponds to the value DOWN of Channel_LinkState
	Channel_LinkState_DOWN E_Channel_LinkState = 2
	// Channel_LinkState_TESTING corresponds to the value TESTING of Channel_LinkState
	Channel_LinkState_TESTING E_Channel_LinkState = 3
)

// E_Cpu_Index_Enum is a derived int64 type which is used to represent
// the enumerated node Cpu_Index_Enum. An additional value named
// Cpu_Index_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Cpu_Index_Enum int64

// IsYANGGoEnum ensures that Cpu_Index_Enum implements the yang.GoEnum
// interface. This ensures that Cpu_Index_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_Cpu_Index_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Cpu_Index_Enum.
func (E_Cpu_Index_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Cpu_Index_Enum.
func (e E_Cpu_Index_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Cpu_Index_Enum")
}

const (
	// Cpu_Index_Enum_UNSET corresponds to the value UNSET of Cpu_Index_Enum
	Cpu_Index_Enum_UNSET E_Cpu_Index_Enum = 0
	// Cpu_Index_Enum_ALL corresponds to the value ALL of Cpu_Index_Enum
	Cpu_Index_Enum_ALL E_Cpu_Index_Enum = 1
)

// E_DefaultMetric_Flags is a derived int64 type which is used to represent
// the enumerated node DefaultMetric_Flags. An additional value named
// DefaultMetric_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_DefaultMetric_Flags int64

// IsYANGGoEnum ensures that DefaultMetric_Flags implements the yang.GoEnum
// interface. This ensures that DefaultMetric_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_DefaultMetric_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  DefaultMetric_Flags.
func (E_DefaultMetric_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_DefaultMetric_Flags.
func (e E_DefaultMetric_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_DefaultMetric_Flags")
}

const (
	// DefaultMetric_Flags_UNSET corresponds to the value UNSET of DefaultMetric_Flags
	DefaultMetric_Flags_UNSET E_DefaultMetric_Flags = 0
	// DefaultMetric_Flags_INTERNAL corresponds to the value INTERNAL of DefaultMetric_Flags
	DefaultMetric_Flags_INTERNAL E_DefaultMetric_Flags = 1
)

// E_Entry_EntryType is a derived int64 type which is used to represent
// the enumerated node Entry_EntryType. An additional value named
// Entry_EntryType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Entry_EntryType int64

// IsYANGGoEnum ensures that Entry_EntryType implements the yang.GoEnum
// interface. This ensures that Entry_EntryType can be identified as a
// mapped type for a YANG enumeration.
func (E_Entry_EntryType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Entry_EntryType.
func (E_Entry_EntryType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Entry_EntryType.
func (e E_Entry_EntryType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Entry_EntryType")
}

const (
	// Entry_EntryType_UNSET corresponds to the value UNSET of Entry_EntryType
	Entry_EntryType_UNSET E_Entry_EntryType = 0
	// Entry_EntryType_STATIC corresponds to the value STATIC of Entry_EntryType
	Entry_EntryType_STATIC E_Entry_EntryType = 1
	// Entry_EntryType_DYNAMIC corresponds to the value DYNAMIC of Entry_EntryType
	Entry_EntryType_DYNAMIC E_Entry_EntryType = 2
)

// E_Ethernet_ClientAls is a derived int64 type which is used to represent
// the enumerated node Ethernet_ClientAls. An additional value named
// Ethernet_ClientAls_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Ethernet_ClientAls int64

// IsYANGGoEnum ensures that Ethernet_ClientAls implements the yang.GoEnum
// interface. This ensures that Ethernet_ClientAls can be identified as a
// mapped type for a YANG enumeration.
func (E_Ethernet_ClientAls) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Ethernet_ClientAls.
func (E_Ethernet_ClientAls) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Ethernet_ClientAls.
func (e E_Ethernet_ClientAls) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Ethernet_ClientAls")
}

const (
	// Ethernet_ClientAls_UNSET corresponds to the value UNSET of Ethernet_ClientAls
	Ethernet_ClientAls_UNSET E_Ethernet_ClientAls = 0
	// Ethernet_ClientAls_NONE corresponds to the value NONE of Ethernet_ClientAls
	Ethernet_ClientAls_NONE E_Ethernet_ClientAls = 1
	// Ethernet_ClientAls_LASER_SHUTDOWN corresponds to the value LASER_SHUTDOWN of Ethernet_ClientAls
	Ethernet_ClientAls_LASER_SHUTDOWN E_Ethernet_ClientAls = 2
	// Ethernet_ClientAls_ETHERNET corresponds to the value ETHERNET of Ethernet_ClientAls
	Ethernet_ClientAls_ETHERNET E_Ethernet_ClientAls = 3
)

// E_Ethernet_DuplexMode is a derived int64 type which is used to represent
// the enumerated node Ethernet_DuplexMode. An additional value named
// Ethernet_DuplexMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Ethernet_DuplexMode int64

// IsYANGGoEnum ensures that Ethernet_DuplexMode implements the yang.GoEnum
// interface. This ensures that Ethernet_DuplexMode can be identified as a
// mapped type for a YANG enumeration.
func (E_Ethernet_DuplexMode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Ethernet_DuplexMode.
func (E_Ethernet_DuplexMode) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Ethernet_DuplexMode.
func (e E_Ethernet_DuplexMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Ethernet_DuplexMode")
}

const (
	// Ethernet_DuplexMode_UNSET corresponds to the value UNSET of Ethernet_DuplexMode
	Ethernet_DuplexMode_UNSET E_Ethernet_DuplexMode = 0
	// Ethernet_DuplexMode_FULL corresponds to the value FULL of Ethernet_DuplexMode
	Ethernet_DuplexMode_FULL E_Ethernet_DuplexMode = 1
	// Ethernet_DuplexMode_HALF corresponds to the value HALF of Ethernet_DuplexMode
	Ethernet_DuplexMode_HALF E_Ethernet_DuplexMode = 2
)

// E_Ethernet_NegotiatedDuplexMode is a derived int64 type which is used to represent
// the enumerated node Ethernet_NegotiatedDuplexMode. An additional value named
// Ethernet_NegotiatedDuplexMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Ethernet_NegotiatedDuplexMode int64

// IsYANGGoEnum ensures that Ethernet_NegotiatedDuplexMode implements the yang.GoEnum
// interface. This ensures that Ethernet_NegotiatedDuplexMode can be identified as a
// mapped type for a YANG enumeration.
func (E_Ethernet_NegotiatedDuplexMode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Ethernet_NegotiatedDuplexMode.
func (E_Ethernet_NegotiatedDuplexMode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_Ethernet_NegotiatedDuplexMode.
func (e E_Ethernet_NegotiatedDuplexMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Ethernet_NegotiatedDuplexMode")
}

const (
	// Ethernet_NegotiatedDuplexMode_UNSET corresponds to the value UNSET of Ethernet_NegotiatedDuplexMode
	Ethernet_NegotiatedDuplexMode_UNSET E_Ethernet_NegotiatedDuplexMode = 0
	// Ethernet_NegotiatedDuplexMode_FULL corresponds to the value FULL of Ethernet_NegotiatedDuplexMode
	Ethernet_NegotiatedDuplexMode_FULL E_Ethernet_NegotiatedDuplexMode = 1
	// Ethernet_NegotiatedDuplexMode_HALF corresponds to the value HALF of Ethernet_NegotiatedDuplexMode
	Ethernet_NegotiatedDuplexMode_HALF E_Ethernet_NegotiatedDuplexMode = 2
)

// E_Event_Record is a derived int64 type which is used to represent
// the enumerated node Event_Record. An additional value named
// Event_Record_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Event_Record int64

// IsYANGGoEnum ensures that Event_Record implements the yang.GoEnum
// interface. This ensures that Event_Record can be identified as a
// mapped type for a YANG enumeration.
func (E_Event_Record) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Event_Record.
func (E_Event_Record) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Event_Record.
func (e E_Event_Record) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Event_Record")
}

const (
	// Event_Record_UNSET corresponds to the value UNSET of Event_Record
	Event_Record_UNSET E_Event_Record = 0
	// Event_Record_START_STOP corresponds to the value START_STOP of Event_Record
	Event_Record_START_STOP E_Event_Record = 1
	// Event_Record_STOP corresponds to the value STOP of Event_Record
	Event_Record_STOP E_Event_Record = 2
)

// E_ExplicitRouteObject_Type is a derived int64 type which is used to represent
// the enumerated node ExplicitRouteObject_Type. An additional value named
// ExplicitRouteObject_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_ExplicitRouteObject_Type int64

// IsYANGGoEnum ensures that ExplicitRouteObject_Type implements the yang.GoEnum
// interface. This ensures that ExplicitRouteObject_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_ExplicitRouteObject_Type) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  ExplicitRouteObject_Type.
func (E_ExplicitRouteObject_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_ExplicitRouteObject_Type.
func (e E_ExplicitRouteObject_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_ExplicitRouteObject_Type")
}

const (
	// ExplicitRouteObject_Type_UNSET corresponds to the value UNSET of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_UNSET E_ExplicitRouteObject_Type = 0
	// ExplicitRouteObject_Type_IPV4 corresponds to the value IPV4 of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_IPV4 E_ExplicitRouteObject_Type = 1
	// ExplicitRouteObject_Type_IPV6 corresponds to the value IPV6 of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_IPV6 E_ExplicitRouteObject_Type = 2
	// ExplicitRouteObject_Type_ASN corresponds to the value ASN of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_ASN E_ExplicitRouteObject_Type = 3
	// ExplicitRouteObject_Type_ASN4 corresponds to the value ASN4 of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_ASN4 E_ExplicitRouteObject_Type = 4
	// ExplicitRouteObject_Type_LABEL corresponds to the value LABEL of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_LABEL E_ExplicitRouteObject_Type = 5
	// ExplicitRouteObject_Type_UNNUMBERED_INTERFACE corresponds to the value UNNUMBERED_INTERFACE of ExplicitRouteObject_Type
	ExplicitRouteObject_Type_UNNUMBERED_INTERFACE E_ExplicitRouteObject_Type = 6
)

// E_ExtendedPrefix_AddressFamily is a derived int64 type which is used to represent
// the enumerated node ExtendedPrefix_AddressFamily. An additional value named
// ExtendedPrefix_AddressFamily_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_ExtendedPrefix_AddressFamily int64

// IsYANGGoEnum ensures that ExtendedPrefix_AddressFamily implements the yang.GoEnum
// interface. This ensures that ExtendedPrefix_AddressFamily can be identified as a
// mapped type for a YANG enumeration.
func (E_ExtendedPrefix_AddressFamily) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  ExtendedPrefix_AddressFamily.
func (E_ExtendedPrefix_AddressFamily) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_ExtendedPrefix_AddressFamily.
func (e E_ExtendedPrefix_AddressFamily) String() string {
	return ygot.EnumLogString(e, int64(e), "E_ExtendedPrefix_AddressFamily")
}

const (
	// ExtendedPrefix_AddressFamily_UNSET corresponds to the value UNSET of ExtendedPrefix_AddressFamily
	ExtendedPrefix_AddressFamily_UNSET E_ExtendedPrefix_AddressFamily = 0
	// ExtendedPrefix_AddressFamily_IPV4_UNICAST corresponds to the value IPV4_UNICAST of ExtendedPrefix_AddressFamily
	ExtendedPrefix_AddressFamily_IPV4_UNICAST E_ExtendedPrefix_AddressFamily = 1
)

// E_ExtendedPrefix_RouteType is a derived int64 type which is used to represent
// the enumerated node ExtendedPrefix_RouteType. An additional value named
// ExtendedPrefix_RouteType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_ExtendedPrefix_RouteType int64

// IsYANGGoEnum ensures that ExtendedPrefix_RouteType implements the yang.GoEnum
// interface. This ensures that ExtendedPrefix_RouteType can be identified as a
// mapped type for a YANG enumeration.
func (E_ExtendedPrefix_RouteType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  ExtendedPrefix_RouteType.
func (E_ExtendedPrefix_RouteType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_ExtendedPrefix_RouteType.
func (e E_ExtendedPrefix_RouteType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_ExtendedPrefix_RouteType")
}

const (
	// ExtendedPrefix_RouteType_UNSET corresponds to the value UNSET of ExtendedPrefix_RouteType
	ExtendedPrefix_RouteType_UNSET E_ExtendedPrefix_RouteType = 0
	// ExtendedPrefix_RouteType_UNSPECIFIED corresponds to the value UNSPECIFIED of ExtendedPrefix_RouteType
	ExtendedPrefix_RouteType_UNSPECIFIED E_ExtendedPrefix_RouteType = 1
	// ExtendedPrefix_RouteType_INTRA_AREA corresponds to the value INTRA_AREA of ExtendedPrefix_RouteType
	ExtendedPrefix_RouteType_INTRA_AREA E_ExtendedPrefix_RouteType = 2
	// ExtendedPrefix_RouteType_INTER_AREA corresponds to the value INTER_AREA of ExtendedPrefix_RouteType
	ExtendedPrefix_RouteType_INTER_AREA E_ExtendedPrefix_RouteType = 4
	// ExtendedPrefix_RouteType_AS_EXTERNAL corresponds to the value AS_EXTERNAL of ExtendedPrefix_RouteType
	ExtendedPrefix_RouteType_AS_EXTERNAL E_ExtendedPrefix_RouteType = 6
	// ExtendedPrefix_RouteType_NSSA_EXTERNAL corresponds to the value NSSA_EXTERNAL of ExtendedPrefix_RouteType
	ExtendedPrefix_RouteType_NSSA_EXTERNAL E_ExtendedPrefix_RouteType = 8
)

// E_Flags_Flags is a derived int64 type which is used to represent
// the enumerated node Flags_Flags. An additional value named
// Flags_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Flags_Flags int64

// IsYANGGoEnum ensures that Flags_Flags implements the yang.GoEnum
// interface. This ensures that Flags_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_Flags_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Flags_Flags.
func (E_Flags_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Flags_Flags.
func (e E_Flags_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Flags_Flags")
}

const (
	// Flags_Flags_UNSET corresponds to the value UNSET of Flags_Flags
	Flags_Flags_UNSET E_Flags_Flags = 0
	// Flags_Flags_EXTERNAL_FLAG corresponds to the value EXTERNAL_FLAG of Flags_Flags
	Flags_Flags_EXTERNAL_FLAG E_Flags_Flags = 1
	// Flags_Flags_READVERTISEMENT_FLAG corresponds to the value READVERTISEMENT_FLAG of Flags_Flags
	Flags_Flags_READVERTISEMENT_FLAG E_Flags_Flags = 2
	// Flags_Flags_NODE_FLAG corresponds to the value NODE_FLAG of Flags_Flags
	Flags_Flags_NODE_FLAG E_Flags_Flags = 3
)

// E_Global_SummaryRouteCostMode is a derived int64 type which is used to represent
// the enumerated node Global_SummaryRouteCostMode. An additional value named
// Global_SummaryRouteCostMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Global_SummaryRouteCostMode int64

// IsYANGGoEnum ensures that Global_SummaryRouteCostMode implements the yang.GoEnum
// interface. This ensures that Global_SummaryRouteCostMode can be identified as a
// mapped type for a YANG enumeration.
func (E_Global_SummaryRouteCostMode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Global_SummaryRouteCostMode.
func (E_Global_SummaryRouteCostMode) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Global_SummaryRouteCostMode.
func (e E_Global_SummaryRouteCostMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Global_SummaryRouteCostMode")
}

const (
	// Global_SummaryRouteCostMode_UNSET corresponds to the value UNSET of Global_SummaryRouteCostMode
	Global_SummaryRouteCostMode_UNSET E_Global_SummaryRouteCostMode = 0
	// Global_SummaryRouteCostMode_RFC1583_COMPATIBLE corresponds to the value RFC1583_COMPATIBLE of Global_SummaryRouteCostMode
	Global_SummaryRouteCostMode_RFC1583_COMPATIBLE E_Global_SummaryRouteCostMode = 1
	// Global_SummaryRouteCostMode_RFC2328_COMPATIBLE corresponds to the value RFC2328_COMPATIBLE of Global_SummaryRouteCostMode
	Global_SummaryRouteCostMode_RFC2328_COMPATIBLE E_Global_SummaryRouteCostMode = 2
)

// E_GracefulRestart_Mode is a derived int64 type which is used to represent
// the enumerated node GracefulRestart_Mode. An additional value named
// GracefulRestart_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_GracefulRestart_Mode int64

// IsYANGGoEnum ensures that GracefulRestart_Mode implements the yang.GoEnum
// interface. This ensures that GracefulRestart_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_GracefulRestart_Mode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  GracefulRestart_Mode.
func (E_GracefulRestart_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_GracefulRestart_Mode.
func (e E_GracefulRestart_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_GracefulRestart_Mode")
}

const (
	// GracefulRestart_Mode_UNSET corresponds to the value UNSET of GracefulRestart_Mode
	GracefulRestart_Mode_UNSET E_GracefulRestart_Mode = 0
	// GracefulRestart_Mode_HELPER_ONLY corresponds to the value HELPER_ONLY of GracefulRestart_Mode
	GracefulRestart_Mode_HELPER_ONLY E_GracefulRestart_Mode = 1
	// GracefulRestart_Mode_BILATERAL corresponds to the value BILATERAL of GracefulRestart_Mode
	GracefulRestart_Mode_BILATERAL E_GracefulRestart_Mode = 2
	// GracefulRestart_Mode_REMOTE_HELPER corresponds to the value REMOTE_HELPER of GracefulRestart_Mode
	GracefulRestart_Mode_REMOTE_HELPER E_GracefulRestart_Mode = 3
)

// E_GrpcServer_ListenAddresses_Enum is a derived int64 type which is used to represent
// the enumerated node GrpcServer_ListenAddresses_Enum. An additional value named
// GrpcServer_ListenAddresses_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_GrpcServer_ListenAddresses_Enum int64

// IsYANGGoEnum ensures that GrpcServer_ListenAddresses_Enum implements the yang.GoEnum
// interface. This ensures that GrpcServer_ListenAddresses_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_GrpcServer_ListenAddresses_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  GrpcServer_ListenAddresses_Enum.
func (E_GrpcServer_ListenAddresses_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_GrpcServer_ListenAddresses_Enum.
func (e E_GrpcServer_ListenAddresses_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_GrpcServer_ListenAddresses_Enum")
}

const (
	// GrpcServer_ListenAddresses_Enum_UNSET corresponds to the value UNSET of GrpcServer_ListenAddresses_Enum
	GrpcServer_ListenAddresses_Enum_UNSET E_GrpcServer_ListenAddresses_Enum = 0
	// GrpcServer_ListenAddresses_Enum_ANY corresponds to the value ANY of GrpcServer_ListenAddresses_Enum
	GrpcServer_ListenAddresses_Enum_ANY E_GrpcServer_ListenAddresses_Enum = 1
)

// E_IETFInterfaces_InterfaceType is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_InterfaceType. An additional value named
// IETFInterfaces_InterfaceType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_InterfaceType int64

// IsYANGGoEnum ensures that IETFInterfaces_InterfaceType implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_InterfaceType can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_InterfaceType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_InterfaceType.
func (E_IETFInterfaces_InterfaceType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_IETFInterfaces_InterfaceType.
func (e E_IETFInterfaces_InterfaceType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_InterfaceType")
}

const (
	// IETFInterfaces_InterfaceType_UNSET corresponds to the value UNSET of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_UNSET E_IETFInterfaces_InterfaceType = 0
	// IETFInterfaces_InterfaceType_a12MppSwitch corresponds to the value a12MppSwitch of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_a12MppSwitch E_IETFInterfaces_InterfaceType = 1
	// IETFInterfaces_InterfaceType_aal2 corresponds to the value aal2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aal2 E_IETFInterfaces_InterfaceType = 2
	// IETFInterfaces_InterfaceType_aal5 corresponds to the value aal5 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aal5 E_IETFInterfaces_InterfaceType = 3
	// IETFInterfaces_InterfaceType_actelisMetaLOOP corresponds to the value actelisMetaLOOP of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_actelisMetaLOOP E_IETFInterfaces_InterfaceType = 4
	// IETFInterfaces_InterfaceType_adsl corresponds to the value adsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_adsl E_IETFInterfaces_InterfaceType = 5
	// IETFInterfaces_InterfaceType_adsl2 corresponds to the value adsl2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_adsl2 E_IETFInterfaces_InterfaceType = 6
	// IETFInterfaces_InterfaceType_adsl2plus corresponds to the value adsl2plus of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_adsl2plus E_IETFInterfaces_InterfaceType = 7
	// IETFInterfaces_InterfaceType_aflane8023 corresponds to the value aflane8023 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aflane8023 E_IETFInterfaces_InterfaceType = 8
	// IETFInterfaces_InterfaceType_aflane8025 corresponds to the value aflane8025 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aflane8025 E_IETFInterfaces_InterfaceType = 9
	// IETFInterfaces_InterfaceType_aluELP corresponds to the value aluELP of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluELP E_IETFInterfaces_InterfaceType = 10
	// IETFInterfaces_InterfaceType_aluEpon corresponds to the value aluEpon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEpon E_IETFInterfaces_InterfaceType = 11
	// IETFInterfaces_InterfaceType_aluEponLogicalLink corresponds to the value aluEponLogicalLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEponLogicalLink E_IETFInterfaces_InterfaceType = 12
	// IETFInterfaces_InterfaceType_aluEponOnu corresponds to the value aluEponOnu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEponOnu E_IETFInterfaces_InterfaceType = 13
	// IETFInterfaces_InterfaceType_aluEponPhysicalUni corresponds to the value aluEponPhysicalUni of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEponPhysicalUni E_IETFInterfaces_InterfaceType = 14
	// IETFInterfaces_InterfaceType_aluGponOnu corresponds to the value aluGponOnu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluGponOnu E_IETFInterfaces_InterfaceType = 15
	// IETFInterfaces_InterfaceType_aluGponPhysicalUni corresponds to the value aluGponPhysicalUni of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluGponPhysicalUni E_IETFInterfaces_InterfaceType = 16
	// IETFInterfaces_InterfaceType_arap corresponds to the value arap of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_arap E_IETFInterfaces_InterfaceType = 17
	// IETFInterfaces_InterfaceType_arcnet corresponds to the value arcnet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_arcnet E_IETFInterfaces_InterfaceType = 18
	// IETFInterfaces_InterfaceType_arcnetPlus corresponds to the value arcnetPlus of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_arcnetPlus E_IETFInterfaces_InterfaceType = 19
	// IETFInterfaces_InterfaceType_async corresponds to the value async of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_async E_IETFInterfaces_InterfaceType = 20
	// IETFInterfaces_InterfaceType_atm corresponds to the value atm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atm E_IETFInterfaces_InterfaceType = 21
	// IETFInterfaces_InterfaceType_atmDxi corresponds to the value atmDxi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmDxi E_IETFInterfaces_InterfaceType = 22
	// IETFInterfaces_InterfaceType_atmFuni corresponds to the value atmFuni of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmFuni E_IETFInterfaces_InterfaceType = 23
	// IETFInterfaces_InterfaceType_atmIma corresponds to the value atmIma of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmIma E_IETFInterfaces_InterfaceType = 24
	// IETFInterfaces_InterfaceType_atmLogical corresponds to the value atmLogical of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmLogical E_IETFInterfaces_InterfaceType = 25
	// IETFInterfaces_InterfaceType_atmRadio corresponds to the value atmRadio of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmRadio E_IETFInterfaces_InterfaceType = 26
	// IETFInterfaces_InterfaceType_atmSubInterface corresponds to the value atmSubInterface of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmSubInterface E_IETFInterfaces_InterfaceType = 27
	// IETFInterfaces_InterfaceType_atmVciEndPt corresponds to the value atmVciEndPt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmVciEndPt E_IETFInterfaces_InterfaceType = 28
	// IETFInterfaces_InterfaceType_atmVirtual corresponds to the value atmVirtual of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmVirtual E_IETFInterfaces_InterfaceType = 29
	// IETFInterfaces_InterfaceType_atmbond corresponds to the value atmbond of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmbond E_IETFInterfaces_InterfaceType = 30
	// IETFInterfaces_InterfaceType_aviciOpticalEther corresponds to the value aviciOpticalEther of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aviciOpticalEther E_IETFInterfaces_InterfaceType = 31
	// IETFInterfaces_InterfaceType_basicISDN corresponds to the value basicISDN of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_basicISDN E_IETFInterfaces_InterfaceType = 32
	// IETFInterfaces_InterfaceType_bgppolicyaccounting corresponds to the value bgppolicyaccounting of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bgppolicyaccounting E_IETFInterfaces_InterfaceType = 33
	// IETFInterfaces_InterfaceType_bits corresponds to the value bits of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bits E_IETFInterfaces_InterfaceType = 34
	// IETFInterfaces_InterfaceType_bridge corresponds to the value bridge of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bridge E_IETFInterfaces_InterfaceType = 35
	// IETFInterfaces_InterfaceType_bsc corresponds to the value bsc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bsc E_IETFInterfaces_InterfaceType = 36
	// IETFInterfaces_InterfaceType_cableDownstreamRfPort corresponds to the value cableDownstreamRfPort of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cableDownstreamRfPort E_IETFInterfaces_InterfaceType = 37
	// IETFInterfaces_InterfaceType_capwapDot11Bss corresponds to the value capwapDot11Bss of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_capwapDot11Bss E_IETFInterfaces_InterfaceType = 38
	// IETFInterfaces_InterfaceType_capwapDot11Profile corresponds to the value capwapDot11Profile of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_capwapDot11Profile E_IETFInterfaces_InterfaceType = 39
	// IETFInterfaces_InterfaceType_capwapWtpVirtualRadio corresponds to the value capwapWtpVirtualRadio of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_capwapWtpVirtualRadio E_IETFInterfaces_InterfaceType = 40
	// IETFInterfaces_InterfaceType_cblVectaStar corresponds to the value cblVectaStar of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cblVectaStar E_IETFInterfaces_InterfaceType = 41
	// IETFInterfaces_InterfaceType_cctEmul corresponds to the value cctEmul of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cctEmul E_IETFInterfaces_InterfaceType = 42
	// IETFInterfaces_InterfaceType_ces corresponds to the value ces of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ces E_IETFInterfaces_InterfaceType = 43
	// IETFInterfaces_InterfaceType_channel corresponds to the value channel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_channel E_IETFInterfaces_InterfaceType = 44
	// IETFInterfaces_InterfaceType_ciscoISLvlan corresponds to the value ciscoISLvlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ciscoISLvlan E_IETFInterfaces_InterfaceType = 45
	// IETFInterfaces_InterfaceType_cnr corresponds to the value cnr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cnr E_IETFInterfaces_InterfaceType = 46
	// IETFInterfaces_InterfaceType_coffee corresponds to the value coffee of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_coffee E_IETFInterfaces_InterfaceType = 47
	// IETFInterfaces_InterfaceType_compositeLink corresponds to the value compositeLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_compositeLink E_IETFInterfaces_InterfaceType = 48
	// IETFInterfaces_InterfaceType_dcn corresponds to the value dcn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dcn E_IETFInterfaces_InterfaceType = 49
	// IETFInterfaces_InterfaceType_ddnX25 corresponds to the value ddnX25 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ddnX25 E_IETFInterfaces_InterfaceType = 50
	// IETFInterfaces_InterfaceType_digitalPowerline corresponds to the value digitalPowerline of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_digitalPowerline E_IETFInterfaces_InterfaceType = 51
	// IETFInterfaces_InterfaceType_digitalWrapperOverheadChannel corresponds to the value digitalWrapperOverheadChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_digitalWrapperOverheadChannel E_IETFInterfaces_InterfaceType = 52
	// IETFInterfaces_InterfaceType_dlsw corresponds to the value dlsw of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dlsw E_IETFInterfaces_InterfaceType = 53
	// IETFInterfaces_InterfaceType_docsCableDownstream corresponds to the value docsCableDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableDownstream E_IETFInterfaces_InterfaceType = 54
	// IETFInterfaces_InterfaceType_docsCableMCmtsDownstream corresponds to the value docsCableMCmtsDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableMCmtsDownstream E_IETFInterfaces_InterfaceType = 55
	// IETFInterfaces_InterfaceType_docsCableMaclayer corresponds to the value docsCableMaclayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableMaclayer E_IETFInterfaces_InterfaceType = 56
	// IETFInterfaces_InterfaceType_docsCableNdf corresponds to the value docsCableNdf of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableNdf E_IETFInterfaces_InterfaceType = 57
	// IETFInterfaces_InterfaceType_docsCableNdr corresponds to the value docsCableNdr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableNdr E_IETFInterfaces_InterfaceType = 58
	// IETFInterfaces_InterfaceType_docsCableScte55d1FwdOob corresponds to the value docsCableScte55d1FwdOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d1FwdOob E_IETFInterfaces_InterfaceType = 59
	// IETFInterfaces_InterfaceType_docsCableScte55d1RetOob corresponds to the value docsCableScte55d1RetOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d1RetOob E_IETFInterfaces_InterfaceType = 60
	// IETFInterfaces_InterfaceType_docsCableScte55d2DsOob corresponds to the value docsCableScte55d2DsOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d2DsOob E_IETFInterfaces_InterfaceType = 61
	// IETFInterfaces_InterfaceType_docsCableScte55d2UsOob corresponds to the value docsCableScte55d2UsOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d2UsOob E_IETFInterfaces_InterfaceType = 62
	// IETFInterfaces_InterfaceType_docsCableUpstream corresponds to the value docsCableUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableUpstream E_IETFInterfaces_InterfaceType = 63
	// IETFInterfaces_InterfaceType_docsCableUpstreamChannel corresponds to the value docsCableUpstreamChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableUpstreamChannel E_IETFInterfaces_InterfaceType = 64
	// IETFInterfaces_InterfaceType_docsCableUpstreamRfPort corresponds to the value docsCableUpstreamRfPort of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableUpstreamRfPort E_IETFInterfaces_InterfaceType = 65
	// IETFInterfaces_InterfaceType_docsOfdmDownstream corresponds to the value docsOfdmDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsOfdmDownstream E_IETFInterfaces_InterfaceType = 66
	// IETFInterfaces_InterfaceType_docsOfdmaUpstream corresponds to the value docsOfdmaUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsOfdmaUpstream E_IETFInterfaces_InterfaceType = 67
	// IETFInterfaces_InterfaceType_ds0 corresponds to the value ds0 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds0 E_IETFInterfaces_InterfaceType = 68
	// IETFInterfaces_InterfaceType_ds0Bundle corresponds to the value ds0Bundle of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds0Bundle E_IETFInterfaces_InterfaceType = 69
	// IETFInterfaces_InterfaceType_ds1 corresponds to the value ds1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds1 E_IETFInterfaces_InterfaceType = 70
	// IETFInterfaces_InterfaceType_ds1FDL corresponds to the value ds1FDL of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds1FDL E_IETFInterfaces_InterfaceType = 71
	// IETFInterfaces_InterfaceType_ds3 corresponds to the value ds3 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds3 E_IETFInterfaces_InterfaceType = 72
	// IETFInterfaces_InterfaceType_dtm corresponds to the value dtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dtm E_IETFInterfaces_InterfaceType = 73
	// IETFInterfaces_InterfaceType_dvbAsiIn corresponds to the value dvbAsiIn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbAsiIn E_IETFInterfaces_InterfaceType = 74
	// IETFInterfaces_InterfaceType_dvbAsiOut corresponds to the value dvbAsiOut of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbAsiOut E_IETFInterfaces_InterfaceType = 75
	// IETFInterfaces_InterfaceType_dvbRccDownstream corresponds to the value dvbRccDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRccDownstream E_IETFInterfaces_InterfaceType = 76
	// IETFInterfaces_InterfaceType_dvbRccMacLayer corresponds to the value dvbRccMacLayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRccMacLayer E_IETFInterfaces_InterfaceType = 77
	// IETFInterfaces_InterfaceType_dvbRccUpstream corresponds to the value dvbRccUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRccUpstream E_IETFInterfaces_InterfaceType = 78
	// IETFInterfaces_InterfaceType_dvbRcsMacLayer corresponds to the value dvbRcsMacLayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRcsMacLayer E_IETFInterfaces_InterfaceType = 79
	// IETFInterfaces_InterfaceType_dvbRcsTdma corresponds to the value dvbRcsTdma of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRcsTdma E_IETFInterfaces_InterfaceType = 80
	// IETFInterfaces_InterfaceType_dvbTdm corresponds to the value dvbTdm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbTdm E_IETFInterfaces_InterfaceType = 81
	// IETFInterfaces_InterfaceType_e1 corresponds to the value e1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_e1 E_IETFInterfaces_InterfaceType = 82
	// IETFInterfaces_InterfaceType_econet corresponds to the value econet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_econet E_IETFInterfaces_InterfaceType = 83
	// IETFInterfaces_InterfaceType_eon corresponds to the value eon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_eon E_IETFInterfaces_InterfaceType = 84
	// IETFInterfaces_InterfaceType_eplrs corresponds to the value eplrs of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_eplrs E_IETFInterfaces_InterfaceType = 85
	// IETFInterfaces_InterfaceType_escon corresponds to the value escon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_escon E_IETFInterfaces_InterfaceType = 86
	// IETFInterfaces_InterfaceType_ethernet3Mbit corresponds to the value ethernet3Mbit of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ethernet3Mbit E_IETFInterfaces_InterfaceType = 87
	// IETFInterfaces_InterfaceType_ethernetCsmacd corresponds to the value ethernetCsmacd of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ethernetCsmacd E_IETFInterfaces_InterfaceType = 88
	// IETFInterfaces_InterfaceType_fast corresponds to the value fast of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fast E_IETFInterfaces_InterfaceType = 89
	// IETFInterfaces_InterfaceType_fastEther corresponds to the value fastEther of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fastEther E_IETFInterfaces_InterfaceType = 90
	// IETFInterfaces_InterfaceType_fastEtherFX corresponds to the value fastEtherFX of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fastEtherFX E_IETFInterfaces_InterfaceType = 91
	// IETFInterfaces_InterfaceType_fastdsl corresponds to the value fastdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fastdsl E_IETFInterfaces_InterfaceType = 92
	// IETFInterfaces_InterfaceType_fcipLink corresponds to the value fcipLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fcipLink E_IETFInterfaces_InterfaceType = 93
	// IETFInterfaces_InterfaceType_fddi corresponds to the value fddi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fddi E_IETFInterfaces_InterfaceType = 94
	// IETFInterfaces_InterfaceType_fibreChannel corresponds to the value fibreChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fibreChannel E_IETFInterfaces_InterfaceType = 95
	// IETFInterfaces_InterfaceType_frDlciEndPt corresponds to the value frDlciEndPt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frDlciEndPt E_IETFInterfaces_InterfaceType = 96
	// IETFInterfaces_InterfaceType_frForward corresponds to the value frForward of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frForward E_IETFInterfaces_InterfaceType = 97
	// IETFInterfaces_InterfaceType_frameRelay corresponds to the value frameRelay of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelay E_IETFInterfaces_InterfaceType = 98
	// IETFInterfaces_InterfaceType_frameRelayInterconnect corresponds to the value frameRelayInterconnect of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelayInterconnect E_IETFInterfaces_InterfaceType = 99
	// IETFInterfaces_InterfaceType_frameRelayMPI corresponds to the value frameRelayMPI of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelayMPI E_IETFInterfaces_InterfaceType = 100
	// IETFInterfaces_InterfaceType_frameRelayService corresponds to the value frameRelayService of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelayService E_IETFInterfaces_InterfaceType = 101
	// IETFInterfaces_InterfaceType_frf16MfrBundle corresponds to the value frf16MfrBundle of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frf16MfrBundle E_IETFInterfaces_InterfaceType = 102
	// IETFInterfaces_InterfaceType_g703at2mb corresponds to the value g703at2mb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g703at2mb E_IETFInterfaces_InterfaceType = 103
	// IETFInterfaces_InterfaceType_g703at64k corresponds to the value g703at64k of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g703at64k E_IETFInterfaces_InterfaceType = 104
	// IETFInterfaces_InterfaceType_g9981 corresponds to the value g9981 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g9981 E_IETFInterfaces_InterfaceType = 105
	// IETFInterfaces_InterfaceType_g9982 corresponds to the value g9982 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g9982 E_IETFInterfaces_InterfaceType = 106
	// IETFInterfaces_InterfaceType_g9983 corresponds to the value g9983 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g9983 E_IETFInterfaces_InterfaceType = 107
	// IETFInterfaces_InterfaceType_gfast corresponds to the value gfast of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gfast E_IETFInterfaces_InterfaceType = 108
	// IETFInterfaces_InterfaceType_gfp corresponds to the value gfp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gfp E_IETFInterfaces_InterfaceType = 109
	// IETFInterfaces_InterfaceType_gigabitEthernet corresponds to the value gigabitEthernet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gigabitEthernet E_IETFInterfaces_InterfaceType = 110
	// IETFInterfaces_InterfaceType_gpon corresponds to the value gpon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gpon E_IETFInterfaces_InterfaceType = 111
	// IETFInterfaces_InterfaceType_gr303IDT corresponds to the value gr303IDT of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gr303IDT E_IETFInterfaces_InterfaceType = 112
	// IETFInterfaces_InterfaceType_gr303RDT corresponds to the value gr303RDT of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gr303RDT E_IETFInterfaces_InterfaceType = 113
	// IETFInterfaces_InterfaceType_gtp corresponds to the value gtp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gtp E_IETFInterfaces_InterfaceType = 114
	// IETFInterfaces_InterfaceType_h323Gatekeeper corresponds to the value h323Gatekeeper of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_h323Gatekeeper E_IETFInterfaces_InterfaceType = 115
	// IETFInterfaces_InterfaceType_h323Proxy corresponds to the value h323Proxy of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_h323Proxy E_IETFInterfaces_InterfaceType = 116
	// IETFInterfaces_InterfaceType_hdh1822 corresponds to the value hdh1822 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hdh1822 E_IETFInterfaces_InterfaceType = 117
	// IETFInterfaces_InterfaceType_hdlc corresponds to the value hdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hdlc E_IETFInterfaces_InterfaceType = 118
	// IETFInterfaces_InterfaceType_hdsl2 corresponds to the value hdsl2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hdsl2 E_IETFInterfaces_InterfaceType = 119
	// IETFInterfaces_InterfaceType_hiperlan2 corresponds to the value hiperlan2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hiperlan2 E_IETFInterfaces_InterfaceType = 120
	// IETFInterfaces_InterfaceType_hippi corresponds to the value hippi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hippi E_IETFInterfaces_InterfaceType = 121
	// IETFInterfaces_InterfaceType_hippiInterface corresponds to the value hippiInterface of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hippiInterface E_IETFInterfaces_InterfaceType = 122
	// IETFInterfaces_InterfaceType_homepna corresponds to the value homepna of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_homepna E_IETFInterfaces_InterfaceType = 123
	// IETFInterfaces_InterfaceType_hostPad corresponds to the value hostPad of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hostPad E_IETFInterfaces_InterfaceType = 124
	// IETFInterfaces_InterfaceType_hssi corresponds to the value hssi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hssi E_IETFInterfaces_InterfaceType = 125
	// IETFInterfaces_InterfaceType_hyperchannel corresponds to the value hyperchannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hyperchannel E_IETFInterfaces_InterfaceType = 126
	// IETFInterfaces_InterfaceType_iana_interface_type corresponds to the value iana_interface_type of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iana_interface_type E_IETFInterfaces_InterfaceType = 127
	// IETFInterfaces_InterfaceType_ibm370parChan corresponds to the value ibm370parChan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ibm370parChan E_IETFInterfaces_InterfaceType = 128
	// IETFInterfaces_InterfaceType_idsl corresponds to the value idsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_idsl E_IETFInterfaces_InterfaceType = 129
	// IETFInterfaces_InterfaceType_ieee1394 corresponds to the value ieee1394 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee1394 E_IETFInterfaces_InterfaceType = 130
	// IETFInterfaces_InterfaceType_ieee80211 corresponds to the value ieee80211 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee80211 E_IETFInterfaces_InterfaceType = 131
	// IETFInterfaces_InterfaceType_ieee80212 corresponds to the value ieee80212 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee80212 E_IETFInterfaces_InterfaceType = 132
	// IETFInterfaces_InterfaceType_ieee802154 corresponds to the value ieee802154 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee802154 E_IETFInterfaces_InterfaceType = 133
	// IETFInterfaces_InterfaceType_ieee80216WMAN corresponds to the value ieee80216WMAN of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee80216WMAN E_IETFInterfaces_InterfaceType = 134
	// IETFInterfaces_InterfaceType_ieee8023adLag corresponds to the value ieee8023adLag of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee8023adLag E_IETFInterfaces_InterfaceType = 135
	// IETFInterfaces_InterfaceType_if_gsn corresponds to the value if_gsn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_if_gsn E_IETFInterfaces_InterfaceType = 136
	// IETFInterfaces_InterfaceType_ifPwType corresponds to the value ifPwType of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ifPwType E_IETFInterfaces_InterfaceType = 137
	// IETFInterfaces_InterfaceType_ifVfiType corresponds to the value ifVfiType of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ifVfiType E_IETFInterfaces_InterfaceType = 138
	// IETFInterfaces_InterfaceType_ilan corresponds to the value ilan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ilan E_IETFInterfaces_InterfaceType = 139
	// IETFInterfaces_InterfaceType_imt corresponds to the value imt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_imt E_IETFInterfaces_InterfaceType = 140
	// IETFInterfaces_InterfaceType_infiniband corresponds to the value infiniband of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_infiniband E_IETFInterfaces_InterfaceType = 141
	// IETFInterfaces_InterfaceType_interleave corresponds to the value interleave of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_interleave E_IETFInterfaces_InterfaceType = 142
	// IETFInterfaces_InterfaceType_ip corresponds to the value ip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ip E_IETFInterfaces_InterfaceType = 143
	// IETFInterfaces_InterfaceType_ipForward corresponds to the value ipForward of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipForward E_IETFInterfaces_InterfaceType = 144
	// IETFInterfaces_InterfaceType_ipOverAtm corresponds to the value ipOverAtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipOverAtm E_IETFInterfaces_InterfaceType = 145
	// IETFInterfaces_InterfaceType_ipOverCdlc corresponds to the value ipOverCdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipOverCdlc E_IETFInterfaces_InterfaceType = 146
	// IETFInterfaces_InterfaceType_ipOverClaw corresponds to the value ipOverClaw of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipOverClaw E_IETFInterfaces_InterfaceType = 147
	// IETFInterfaces_InterfaceType_ipSwitch corresponds to the value ipSwitch of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipSwitch E_IETFInterfaces_InterfaceType = 148
	// IETFInterfaces_InterfaceType_isdn corresponds to the value isdn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isdn E_IETFInterfaces_InterfaceType = 149
	// IETFInterfaces_InterfaceType_isdns corresponds to the value isdns of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isdns E_IETFInterfaces_InterfaceType = 150
	// IETFInterfaces_InterfaceType_isdnu corresponds to the value isdnu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isdnu E_IETFInterfaces_InterfaceType = 151
	// IETFInterfaces_InterfaceType_iso88022llc corresponds to the value iso88022llc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88022llc E_IETFInterfaces_InterfaceType = 152
	// IETFInterfaces_InterfaceType_iso88023Csmacd corresponds to the value iso88023Csmacd of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88023Csmacd E_IETFInterfaces_InterfaceType = 153
	// IETFInterfaces_InterfaceType_iso88024TokenBus corresponds to the value iso88024TokenBus of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88024TokenBus E_IETFInterfaces_InterfaceType = 154
	// IETFInterfaces_InterfaceType_iso88025CRFPInt corresponds to the value iso88025CRFPInt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025CRFPInt E_IETFInterfaces_InterfaceType = 155
	// IETFInterfaces_InterfaceType_iso88025Dtr corresponds to the value iso88025Dtr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025Dtr E_IETFInterfaces_InterfaceType = 156
	// IETFInterfaces_InterfaceType_iso88025Fiber corresponds to the value iso88025Fiber of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025Fiber E_IETFInterfaces_InterfaceType = 157
	// IETFInterfaces_InterfaceType_iso88025TokenRing corresponds to the value iso88025TokenRing of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025TokenRing E_IETFInterfaces_InterfaceType = 158
	// IETFInterfaces_InterfaceType_iso88026Man corresponds to the value iso88026Man of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88026Man E_IETFInterfaces_InterfaceType = 159
	// IETFInterfaces_InterfaceType_isup corresponds to the value isup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isup E_IETFInterfaces_InterfaceType = 160
	// IETFInterfaces_InterfaceType_l2vlan corresponds to the value l2vlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_l2vlan E_IETFInterfaces_InterfaceType = 161
	// IETFInterfaces_InterfaceType_l3ipvlan corresponds to the value l3ipvlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_l3ipvlan E_IETFInterfaces_InterfaceType = 162
	// IETFInterfaces_InterfaceType_l3ipxvlan corresponds to the value l3ipxvlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_l3ipxvlan E_IETFInterfaces_InterfaceType = 163
	// IETFInterfaces_InterfaceType_lapb corresponds to the value lapb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lapb E_IETFInterfaces_InterfaceType = 164
	// IETFInterfaces_InterfaceType_lapd corresponds to the value lapd of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lapd E_IETFInterfaces_InterfaceType = 165
	// IETFInterfaces_InterfaceType_lapf corresponds to the value lapf of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lapf E_IETFInterfaces_InterfaceType = 166
	// IETFInterfaces_InterfaceType_linegroup corresponds to the value linegroup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_linegroup E_IETFInterfaces_InterfaceType = 167
	// IETFInterfaces_InterfaceType_lmp corresponds to the value lmp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lmp E_IETFInterfaces_InterfaceType = 168
	// IETFInterfaces_InterfaceType_localTalk corresponds to the value localTalk of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_localTalk E_IETFInterfaces_InterfaceType = 169
	// IETFInterfaces_InterfaceType_macSecControlledIF corresponds to the value macSecControlledIF of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_macSecControlledIF E_IETFInterfaces_InterfaceType = 170
	// IETFInterfaces_InterfaceType_macSecUncontrolledIF corresponds to the value macSecUncontrolledIF of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_macSecUncontrolledIF E_IETFInterfaces_InterfaceType = 171
	// IETFInterfaces_InterfaceType_mediaMailOverIp corresponds to the value mediaMailOverIp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mediaMailOverIp E_IETFInterfaces_InterfaceType = 172
	// IETFInterfaces_InterfaceType_mfSigLink corresponds to the value mfSigLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mfSigLink E_IETFInterfaces_InterfaceType = 173
	// IETFInterfaces_InterfaceType_miox25 corresponds to the value miox25 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_miox25 E_IETFInterfaces_InterfaceType = 174
	// IETFInterfaces_InterfaceType_mocaVersion1 corresponds to the value mocaVersion1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mocaVersion1 E_IETFInterfaces_InterfaceType = 175
	// IETFInterfaces_InterfaceType_modem corresponds to the value modem of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_modem E_IETFInterfaces_InterfaceType = 176
	// IETFInterfaces_InterfaceType_mpc corresponds to the value mpc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mpc E_IETFInterfaces_InterfaceType = 177
	// IETFInterfaces_InterfaceType_mpegTransport corresponds to the value mpegTransport of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mpegTransport E_IETFInterfaces_InterfaceType = 178
	// IETFInterfaces_InterfaceType_mpls corresponds to the value mpls of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mpls E_IETFInterfaces_InterfaceType = 179
	// IETFInterfaces_InterfaceType_mplsTunnel corresponds to the value mplsTunnel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mplsTunnel E_IETFInterfaces_InterfaceType = 180
	// IETFInterfaces_InterfaceType_msdsl corresponds to the value msdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_msdsl E_IETFInterfaces_InterfaceType = 181
	// IETFInterfaces_InterfaceType_mvl corresponds to the value mvl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mvl E_IETFInterfaces_InterfaceType = 182
	// IETFInterfaces_InterfaceType_myrinet corresponds to the value myrinet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_myrinet E_IETFInterfaces_InterfaceType = 183
	// IETFInterfaces_InterfaceType_nfas corresponds to the value nfas of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_nfas E_IETFInterfaces_InterfaceType = 184
	// IETFInterfaces_InterfaceType_nsip corresponds to the value nsip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_nsip E_IETFInterfaces_InterfaceType = 185
	// IETFInterfaces_InterfaceType_opticalChannel corresponds to the value opticalChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_opticalChannel E_IETFInterfaces_InterfaceType = 186
	// IETFInterfaces_InterfaceType_opticalChannelGroup corresponds to the value opticalChannelGroup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_opticalChannelGroup E_IETFInterfaces_InterfaceType = 187
	// IETFInterfaces_InterfaceType_opticalTransport corresponds to the value opticalTransport of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_opticalTransport E_IETFInterfaces_InterfaceType = 188
	// IETFInterfaces_InterfaceType_other corresponds to the value other of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_other E_IETFInterfaces_InterfaceType = 189
	// IETFInterfaces_InterfaceType_otnOdu corresponds to the value otnOdu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_otnOdu E_IETFInterfaces_InterfaceType = 190
	// IETFInterfaces_InterfaceType_otnOtu corresponds to the value otnOtu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_otnOtu E_IETFInterfaces_InterfaceType = 191
	// IETFInterfaces_InterfaceType_para corresponds to the value para of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_para E_IETFInterfaces_InterfaceType = 192
	// IETFInterfaces_InterfaceType_pdnEtherLoop1 corresponds to the value pdnEtherLoop1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pdnEtherLoop1 E_IETFInterfaces_InterfaceType = 193
	// IETFInterfaces_InterfaceType_pdnEtherLoop2 corresponds to the value pdnEtherLoop2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pdnEtherLoop2 E_IETFInterfaces_InterfaceType = 194
	// IETFInterfaces_InterfaceType_pip corresponds to the value pip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pip E_IETFInterfaces_InterfaceType = 195
	// IETFInterfaces_InterfaceType_plc corresponds to the value plc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_plc E_IETFInterfaces_InterfaceType = 196
	// IETFInterfaces_InterfaceType_pon155 corresponds to the value pon155 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pon155 E_IETFInterfaces_InterfaceType = 197
	// IETFInterfaces_InterfaceType_pon622 corresponds to the value pon622 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pon622 E_IETFInterfaces_InterfaceType = 198
	// IETFInterfaces_InterfaceType_pos corresponds to the value pos of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pos E_IETFInterfaces_InterfaceType = 199
	// IETFInterfaces_InterfaceType_ppp corresponds to the value ppp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ppp E_IETFInterfaces_InterfaceType = 200
	// IETFInterfaces_InterfaceType_pppMultilinkBundle corresponds to the value pppMultilinkBundle of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pppMultilinkBundle E_IETFInterfaces_InterfaceType = 201
	// IETFInterfaces_InterfaceType_primaryISDN corresponds to the value primaryISDN of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_primaryISDN E_IETFInterfaces_InterfaceType = 202
	// IETFInterfaces_InterfaceType_propAtm corresponds to the value propAtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propAtm E_IETFInterfaces_InterfaceType = 203
	// IETFInterfaces_InterfaceType_propBWAp2Mp corresponds to the value propBWAp2Mp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propBWAp2Mp E_IETFInterfaces_InterfaceType = 204
	// IETFInterfaces_InterfaceType_propCnls corresponds to the value propCnls of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propCnls E_IETFInterfaces_InterfaceType = 205
	// IETFInterfaces_InterfaceType_propDocsWirelessDownstream corresponds to the value propDocsWirelessDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propDocsWirelessDownstream E_IETFInterfaces_InterfaceType = 206
	// IETFInterfaces_InterfaceType_propDocsWirelessMaclayer corresponds to the value propDocsWirelessMaclayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propDocsWirelessMaclayer E_IETFInterfaces_InterfaceType = 207
	// IETFInterfaces_InterfaceType_propDocsWirelessUpstream corresponds to the value propDocsWirelessUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propDocsWirelessUpstream E_IETFInterfaces_InterfaceType = 208
	// IETFInterfaces_InterfaceType_propMultiplexor corresponds to the value propMultiplexor of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propMultiplexor E_IETFInterfaces_InterfaceType = 209
	// IETFInterfaces_InterfaceType_propPointToPointSerial corresponds to the value propPointToPointSerial of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propPointToPointSerial E_IETFInterfaces_InterfaceType = 210
	// IETFInterfaces_InterfaceType_propVirtual corresponds to the value propVirtual of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propVirtual E_IETFInterfaces_InterfaceType = 211
	// IETFInterfaces_InterfaceType_propWirelessP2P corresponds to the value propWirelessP2P of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propWirelessP2P E_IETFInterfaces_InterfaceType = 212
	// IETFInterfaces_InterfaceType_proteon10Mbit corresponds to the value proteon10Mbit of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_proteon10Mbit E_IETFInterfaces_InterfaceType = 213
	// IETFInterfaces_InterfaceType_proteon80Mbit corresponds to the value proteon80Mbit of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_proteon80Mbit E_IETFInterfaces_InterfaceType = 214
	// IETFInterfaces_InterfaceType_ptm corresponds to the value ptm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ptm E_IETFInterfaces_InterfaceType = 215
	// IETFInterfaces_InterfaceType_q2931 corresponds to the value q2931 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_q2931 E_IETFInterfaces_InterfaceType = 216
	// IETFInterfaces_InterfaceType_qam corresponds to the value qam of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_qam E_IETFInterfaces_InterfaceType = 217
	// IETFInterfaces_InterfaceType_qllc corresponds to the value qllc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_qllc E_IETFInterfaces_InterfaceType = 218
	// IETFInterfaces_InterfaceType_radioMAC corresponds to the value radioMAC of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_radioMAC E_IETFInterfaces_InterfaceType = 219
	// IETFInterfaces_InterfaceType_radsl corresponds to the value radsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_radsl E_IETFInterfaces_InterfaceType = 220
	// IETFInterfaces_InterfaceType_reachDSL corresponds to the value reachDSL of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_reachDSL E_IETFInterfaces_InterfaceType = 221
	// IETFInterfaces_InterfaceType_regular1822 corresponds to the value regular1822 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_regular1822 E_IETFInterfaces_InterfaceType = 222
	// IETFInterfaces_InterfaceType_rfc1483 corresponds to the value rfc1483 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rfc1483 E_IETFInterfaces_InterfaceType = 223
	// IETFInterfaces_InterfaceType_rfc877x25 corresponds to the value rfc877x25 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rfc877x25 E_IETFInterfaces_InterfaceType = 224
	// IETFInterfaces_InterfaceType_rpr corresponds to the value rpr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rpr E_IETFInterfaces_InterfaceType = 225
	// IETFInterfaces_InterfaceType_rs232 corresponds to the value rs232 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rs232 E_IETFInterfaces_InterfaceType = 226
	// IETFInterfaces_InterfaceType_rsrb corresponds to the value rsrb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rsrb E_IETFInterfaces_InterfaceType = 227
	// IETFInterfaces_InterfaceType_sdci corresponds to the value sdci of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sdci E_IETFInterfaces_InterfaceType = 228
	// IETFInterfaces_InterfaceType_sdlc corresponds to the value sdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sdlc E_IETFInterfaces_InterfaceType = 229
	// IETFInterfaces_InterfaceType_sdsl corresponds to the value sdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sdsl E_IETFInterfaces_InterfaceType = 230
	// IETFInterfaces_InterfaceType_shdsl corresponds to the value shdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_shdsl E_IETFInterfaces_InterfaceType = 231
	// IETFInterfaces_InterfaceType_sip corresponds to the value sip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sip E_IETFInterfaces_InterfaceType = 232
	// IETFInterfaces_InterfaceType_sipSig corresponds to the value sipSig of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sipSig E_IETFInterfaces_InterfaceType = 233
	// IETFInterfaces_InterfaceType_sipTg corresponds to the value sipTg of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sipTg E_IETFInterfaces_InterfaceType = 234
	// IETFInterfaces_InterfaceType_sixToFour corresponds to the value sixToFour of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sixToFour E_IETFInterfaces_InterfaceType = 235
	// IETFInterfaces_InterfaceType_slip corresponds to the value slip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_slip E_IETFInterfaces_InterfaceType = 236
	// IETFInterfaces_InterfaceType_smdsDxi corresponds to the value smdsDxi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_smdsDxi E_IETFInterfaces_InterfaceType = 237
	// IETFInterfaces_InterfaceType_smdsIcip corresponds to the value smdsIcip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_smdsIcip E_IETFInterfaces_InterfaceType = 238
	// IETFInterfaces_InterfaceType_softwareLoopback corresponds to the value softwareLoopback of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_softwareLoopback E_IETFInterfaces_InterfaceType = 239
	// IETFInterfaces_InterfaceType_sonet corresponds to the value sonet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonet E_IETFInterfaces_InterfaceType = 240
	// IETFInterfaces_InterfaceType_sonetOverheadChannel corresponds to the value sonetOverheadChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonetOverheadChannel E_IETFInterfaces_InterfaceType = 241
	// IETFInterfaces_InterfaceType_sonetPath corresponds to the value sonetPath of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonetPath E_IETFInterfaces_InterfaceType = 242
	// IETFInterfaces_InterfaceType_sonetVT corresponds to the value sonetVT of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonetVT E_IETFInterfaces_InterfaceType = 243
	// IETFInterfaces_InterfaceType_srp corresponds to the value srp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_srp E_IETFInterfaces_InterfaceType = 244
	// IETFInterfaces_InterfaceType_ss7SigLink corresponds to the value ss7SigLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ss7SigLink E_IETFInterfaces_InterfaceType = 245
	// IETFInterfaces_InterfaceType_stackToStack corresponds to the value stackToStack of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_stackToStack E_IETFInterfaces_InterfaceType = 246
	// IETFInterfaces_InterfaceType_starLan corresponds to the value starLan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_starLan E_IETFInterfaces_InterfaceType = 247
	// IETFInterfaces_InterfaceType_tdlc corresponds to the value tdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_tdlc E_IETFInterfaces_InterfaceType = 248
	// IETFInterfaces_InterfaceType_teLink corresponds to the value teLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_teLink E_IETFInterfaces_InterfaceType = 249
	// IETFInterfaces_InterfaceType_termPad corresponds to the value termPad of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_termPad E_IETFInterfaces_InterfaceType = 250
	// IETFInterfaces_InterfaceType_tr008 corresponds to the value tr008 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_tr008 E_IETFInterfaces_InterfaceType = 251
	// IETFInterfaces_InterfaceType_transpHdlc corresponds to the value transpHdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_transpHdlc E_IETFInterfaces_InterfaceType = 252
	// IETFInterfaces_InterfaceType_tunnel corresponds to the value tunnel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_tunnel E_IETFInterfaces_InterfaceType = 253
	// IETFInterfaces_InterfaceType_ultra corresponds to the value ultra of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ultra E_IETFInterfaces_InterfaceType = 254
	// IETFInterfaces_InterfaceType_usb corresponds to the value usb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_usb E_IETFInterfaces_InterfaceType = 255
	// IETFInterfaces_InterfaceType_v11 corresponds to the value v11 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v11 E_IETFInterfaces_InterfaceType = 256
	// IETFInterfaces_InterfaceType_v35 corresponds to the value v35 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v35 E_IETFInterfaces_InterfaceType = 257
	// IETFInterfaces_InterfaceType_v36 corresponds to the value v36 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v36 E_IETFInterfaces_InterfaceType = 258
	// IETFInterfaces_InterfaceType_v37 corresponds to the value v37 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v37 E_IETFInterfaces_InterfaceType = 259
	// IETFInterfaces_InterfaceType_vdsl corresponds to the value vdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vdsl E_IETFInterfaces_InterfaceType = 260
	// IETFInterfaces_InterfaceType_vdsl2 corresponds to the value vdsl2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vdsl2 E_IETFInterfaces_InterfaceType = 261
	// IETFInterfaces_InterfaceType_virtualIpAddress corresponds to the value virtualIpAddress of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_virtualIpAddress E_IETFInterfaces_InterfaceType = 262
	// IETFInterfaces_InterfaceType_virtualTg corresponds to the value virtualTg of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_virtualTg E_IETFInterfaces_InterfaceType = 263
	// IETFInterfaces_InterfaceType_vmwareNicTeam corresponds to the value vmwareNicTeam of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vmwareNicTeam E_IETFInterfaces_InterfaceType = 264
	// IETFInterfaces_InterfaceType_vmwareVirtualNic corresponds to the value vmwareVirtualNic of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vmwareVirtualNic E_IETFInterfaces_InterfaceType = 265
	// IETFInterfaces_InterfaceType_voiceDID corresponds to the value voiceDID of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceDID E_IETFInterfaces_InterfaceType = 266
	// IETFInterfaces_InterfaceType_voiceEBS corresponds to the value voiceEBS of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEBS E_IETFInterfaces_InterfaceType = 267
	// IETFInterfaces_InterfaceType_voiceEM corresponds to the value voiceEM of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEM E_IETFInterfaces_InterfaceType = 268
	// IETFInterfaces_InterfaceType_voiceEMFGD corresponds to the value voiceEMFGD of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEMFGD E_IETFInterfaces_InterfaceType = 269
	// IETFInterfaces_InterfaceType_voiceEncap corresponds to the value voiceEncap of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEncap E_IETFInterfaces_InterfaceType = 270
	// IETFInterfaces_InterfaceType_voiceFGDEANA corresponds to the value voiceFGDEANA of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFGDEANA E_IETFInterfaces_InterfaceType = 271
	// IETFInterfaces_InterfaceType_voiceFGDOS corresponds to the value voiceFGDOS of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFGDOS E_IETFInterfaces_InterfaceType = 272
	// IETFInterfaces_InterfaceType_voiceFXO corresponds to the value voiceFXO of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFXO E_IETFInterfaces_InterfaceType = 273
	// IETFInterfaces_InterfaceType_voiceFXS corresponds to the value voiceFXS of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFXS E_IETFInterfaces_InterfaceType = 274
	// IETFInterfaces_InterfaceType_voiceOverAtm corresponds to the value voiceOverAtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverAtm E_IETFInterfaces_InterfaceType = 275
	// IETFInterfaces_InterfaceType_voiceOverCable corresponds to the value voiceOverCable of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverCable E_IETFInterfaces_InterfaceType = 276
	// IETFInterfaces_InterfaceType_voiceOverFrameRelay corresponds to the value voiceOverFrameRelay of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverFrameRelay E_IETFInterfaces_InterfaceType = 277
	// IETFInterfaces_InterfaceType_voiceOverIp corresponds to the value voiceOverIp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverIp E_IETFInterfaces_InterfaceType = 278
	// IETFInterfaces_InterfaceType_wwanPP corresponds to the value wwanPP of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_wwanPP E_IETFInterfaces_InterfaceType = 279
	// IETFInterfaces_InterfaceType_wwanPP2 corresponds to the value wwanPP2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_wwanPP2 E_IETFInterfaces_InterfaceType = 280
	// IETFInterfaces_InterfaceType_x213 corresponds to the value x213 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x213 E_IETFInterfaces_InterfaceType = 281
	// IETFInterfaces_InterfaceType_x25huntGroup corresponds to the value x25huntGroup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x25huntGroup E_IETFInterfaces_InterfaceType = 282
	// IETFInterfaces_InterfaceType_x25mlp corresponds to the value x25mlp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x25mlp E_IETFInterfaces_InterfaceType = 283
	// IETFInterfaces_InterfaceType_x25ple corresponds to the value x25ple of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x25ple E_IETFInterfaces_InterfaceType = 284
	// IETFInterfaces_InterfaceType_x86Laps corresponds to the value x86Laps of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x86Laps E_IETFInterfaces_InterfaceType = 285
	// IETFInterfaces_InterfaceType_xboxWireless corresponds to the value xboxWireless of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_xboxWireless E_IETFInterfaces_InterfaceType = 286
)

// E_IgpFloodingBandwidth_ThresholdSpecification is a derived int64 type which is used to represent
// the enumerated node IgpFloodingBandwidth_ThresholdSpecification. An additional value named
// IgpFloodingBandwidth_ThresholdSpecification_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IgpFloodingBandwidth_ThresholdSpecification int64

// IsYANGGoEnum ensures that IgpFloodingBandwidth_ThresholdSpecification implements the yang.GoEnum
// interface. This ensures that IgpFloodingBandwidth_ThresholdSpecification can be identified as a
// mapped type for a YANG enumeration.
func (E_IgpFloodingBandwidth_ThresholdSpecification) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IgpFloodingBandwidth_ThresholdSpecification.
func (E_IgpFloodingBandwidth_ThresholdSpecification) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IgpFloodingBandwidth_ThresholdSpecification.
func (e E_IgpFloodingBandwidth_ThresholdSpecification) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IgpFloodingBandwidth_ThresholdSpecification")
}

const (
	// IgpFloodingBandwidth_ThresholdSpecification_UNSET corresponds to the value UNSET of IgpFloodingBandwidth_ThresholdSpecification
	IgpFloodingBandwidth_ThresholdSpecification_UNSET E_IgpFloodingBandwidth_ThresholdSpecification = 0
	// IgpFloodingBandwidth_ThresholdSpecification_MIRRORED_UP_DOWN corresponds to the value MIRRORED_UP_DOWN of IgpFloodingBandwidth_ThresholdSpecification
	IgpFloodingBandwidth_ThresholdSpecification_MIRRORED_UP_DOWN E_IgpFloodingBandwidth_ThresholdSpecification = 1
	// IgpFloodingBandwidth_ThresholdSpecification_SEPARATE_UP_DOWN corresponds to the value SEPARATE_UP_DOWN of IgpFloodingBandwidth_ThresholdSpecification
	IgpFloodingBandwidth_ThresholdSpecification_SEPARATE_UP_DOWN E_IgpFloodingBandwidth_ThresholdSpecification = 2
)

// E_IgpFloodingBandwidth_ThresholdType is a derived int64 type which is used to represent
// the enumerated node IgpFloodingBandwidth_ThresholdType. An additional value named
// IgpFloodingBandwidth_ThresholdType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IgpFloodingBandwidth_ThresholdType int64

// IsYANGGoEnum ensures that IgpFloodingBandwidth_ThresholdType implements the yang.GoEnum
// interface. This ensures that IgpFloodingBandwidth_ThresholdType can be identified as a
// mapped type for a YANG enumeration.
func (E_IgpFloodingBandwidth_ThresholdType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IgpFloodingBandwidth_ThresholdType.
func (E_IgpFloodingBandwidth_ThresholdType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IgpFloodingBandwidth_ThresholdType.
func (e E_IgpFloodingBandwidth_ThresholdType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IgpFloodingBandwidth_ThresholdType")
}

const (
	// IgpFloodingBandwidth_ThresholdType_UNSET corresponds to the value UNSET of IgpFloodingBandwidth_ThresholdType
	IgpFloodingBandwidth_ThresholdType_UNSET E_IgpFloodingBandwidth_ThresholdType = 0
	// IgpFloodingBandwidth_ThresholdType_DELTA corresponds to the value DELTA of IgpFloodingBandwidth_ThresholdType
	IgpFloodingBandwidth_ThresholdType_DELTA E_IgpFloodingBandwidth_ThresholdType = 1
	// IgpFloodingBandwidth_ThresholdType_THRESHOLD_CROSSED corresponds to the value THRESHOLD_CROSSED of IgpFloodingBandwidth_ThresholdType
	IgpFloodingBandwidth_ThresholdType_THRESHOLD_CROSSED E_IgpFloodingBandwidth_ThresholdType = 2
)

// E_Interface_AdminStatus is a derived int64 type which is used to represent
// the enumerated node Interface_AdminStatus. An additional value named
// Interface_AdminStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Interface_AdminStatus int64

// IsYANGGoEnum ensures that Interface_AdminStatus implements the yang.GoEnum
// interface. This ensures that Interface_AdminStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_Interface_AdminStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Interface_AdminStatus.
func (E_Interface_AdminStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Interface_AdminStatus.
func (e E_Interface_AdminStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Interface_AdminStatus")
}

const (
	// Interface_AdminStatus_UNSET corresponds to the value UNSET of Interface_AdminStatus
	Interface_AdminStatus_UNSET E_Interface_AdminStatus = 0
	// Interface_AdminStatus_UP corresponds to the value UP of Interface_AdminStatus
	Interface_AdminStatus_UP E_Interface_AdminStatus = 1
	// Interface_AdminStatus_DOWN corresponds to the value DOWN of Interface_AdminStatus
	Interface_AdminStatus_DOWN E_Interface_AdminStatus = 2
	// Interface_AdminStatus_TESTING corresponds to the value TESTING of Interface_AdminStatus
	Interface_AdminStatus_TESTING E_Interface_AdminStatus = 3
)

// E_Interface_OperStatus is a derived int64 type which is used to represent
// the enumerated node Interface_OperStatus. An additional value named
// Interface_OperStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Interface_OperStatus int64

// IsYANGGoEnum ensures that Interface_OperStatus implements the yang.GoEnum
// interface. This ensures that Interface_OperStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_Interface_OperStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Interface_OperStatus.
func (E_Interface_OperStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Interface_OperStatus.
func (e E_Interface_OperStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Interface_OperStatus")
}

const (
	// Interface_OperStatus_UNSET corresponds to the value UNSET of Interface_OperStatus
	Interface_OperStatus_UNSET E_Interface_OperStatus = 0
	// Interface_OperStatus_UP corresponds to the value UP of Interface_OperStatus
	Interface_OperStatus_UP E_Interface_OperStatus = 2
	// Interface_OperStatus_DOWN corresponds to the value DOWN of Interface_OperStatus
	Interface_OperStatus_DOWN E_Interface_OperStatus = 3
	// Interface_OperStatus_TESTING corresponds to the value TESTING of Interface_OperStatus
	Interface_OperStatus_TESTING E_Interface_OperStatus = 4
	// Interface_OperStatus_UNKNOWN corresponds to the value UNKNOWN of Interface_OperStatus
	Interface_OperStatus_UNKNOWN E_Interface_OperStatus = 5
	// Interface_OperStatus_DORMANT corresponds to the value DORMANT of Interface_OperStatus
	Interface_OperStatus_DORMANT E_Interface_OperStatus = 6
	// Interface_OperStatus_NOT_PRESENT corresponds to the value NOT_PRESENT of Interface_OperStatus
	Interface_OperStatus_NOT_PRESENT E_Interface_OperStatus = 7
	// Interface_OperStatus_LOWER_LAYER_DOWN corresponds to the value LOWER_LAYER_DOWN of Interface_OperStatus
	Interface_OperStatus_LOWER_LAYER_DOWN E_Interface_OperStatus = 8
)

// E_Ipv4Srlg_Flags is a derived int64 type which is used to represent
// the enumerated node Ipv4Srlg_Flags. An additional value named
// Ipv4Srlg_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Ipv4Srlg_Flags int64

// IsYANGGoEnum ensures that Ipv4Srlg_Flags implements the yang.GoEnum
// interface. This ensures that Ipv4Srlg_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_Ipv4Srlg_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Ipv4Srlg_Flags.
func (E_Ipv4Srlg_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Ipv4Srlg_Flags.
func (e E_Ipv4Srlg_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Ipv4Srlg_Flags")
}

const (
	// Ipv4Srlg_Flags_UNSET corresponds to the value UNSET of Ipv4Srlg_Flags
	Ipv4Srlg_Flags_UNSET E_Ipv4Srlg_Flags = 0
	// Ipv4Srlg_Flags_NUMBERED corresponds to the value NUMBERED of Ipv4Srlg_Flags
	Ipv4Srlg_Flags_NUMBERED E_Ipv4Srlg_Flags = 1
)

// E_Ipv6Srlg_Flags is a derived int64 type which is used to represent
// the enumerated node Ipv6Srlg_Flags. An additional value named
// Ipv6Srlg_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Ipv6Srlg_Flags int64

// IsYANGGoEnum ensures that Ipv6Srlg_Flags implements the yang.GoEnum
// interface. This ensures that Ipv6Srlg_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_Ipv6Srlg_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Ipv6Srlg_Flags.
func (E_Ipv6Srlg_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Ipv6Srlg_Flags.
func (e E_Ipv6Srlg_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Ipv6Srlg_Flags")
}

const (
	// Ipv6Srlg_Flags_UNSET corresponds to the value UNSET of Ipv6Srlg_Flags
	Ipv6Srlg_Flags_UNSET E_Ipv6Srlg_Flags = 0
	// Ipv6Srlg_Flags_NA corresponds to the value NA of Ipv6Srlg_Flags
	Ipv6Srlg_Flags_NA E_Ipv6Srlg_Flags = 1
)

// E_LanAdjacencySid_Flags is a derived int64 type which is used to represent
// the enumerated node LanAdjacencySid_Flags. An additional value named
// LanAdjacencySid_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_LanAdjacencySid_Flags int64

// IsYANGGoEnum ensures that LanAdjacencySid_Flags implements the yang.GoEnum
// interface. This ensures that LanAdjacencySid_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_LanAdjacencySid_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  LanAdjacencySid_Flags.
func (E_LanAdjacencySid_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_LanAdjacencySid_Flags.
func (e E_LanAdjacencySid_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_LanAdjacencySid_Flags")
}

const (
	// LanAdjacencySid_Flags_UNSET corresponds to the value UNSET of LanAdjacencySid_Flags
	LanAdjacencySid_Flags_UNSET E_LanAdjacencySid_Flags = 0
	// LanAdjacencySid_Flags_ADDRESS_FAMILY corresponds to the value ADDRESS_FAMILY of LanAdjacencySid_Flags
	LanAdjacencySid_Flags_ADDRESS_FAMILY E_LanAdjacencySid_Flags = 1
	// LanAdjacencySid_Flags_BACKUP corresponds to the value BACKUP of LanAdjacencySid_Flags
	LanAdjacencySid_Flags_BACKUP E_LanAdjacencySid_Flags = 2
	// LanAdjacencySid_Flags_VALUE corresponds to the value VALUE of LanAdjacencySid_Flags
	LanAdjacencySid_Flags_VALUE E_LanAdjacencySid_Flags = 3
	// LanAdjacencySid_Flags_LOCAL corresponds to the value LOCAL of LanAdjacencySid_Flags
	LanAdjacencySid_Flags_LOCAL E_LanAdjacencySid_Flags = 4
	// LanAdjacencySid_Flags_SET corresponds to the value SET of LanAdjacencySid_Flags
	LanAdjacencySid_Flags_SET E_LanAdjacencySid_Flags = 5
)

// E_LinkAttributes_LocalProtection is a derived int64 type which is used to represent
// the enumerated node LinkAttributes_LocalProtection. An additional value named
// LinkAttributes_LocalProtection_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_LinkAttributes_LocalProtection int64

// IsYANGGoEnum ensures that LinkAttributes_LocalProtection implements the yang.GoEnum
// interface. This ensures that LinkAttributes_LocalProtection can be identified as a
// mapped type for a YANG enumeration.
func (E_LinkAttributes_LocalProtection) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  LinkAttributes_LocalProtection.
func (E_LinkAttributes_LocalProtection) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_LinkAttributes_LocalProtection.
func (e E_LinkAttributes_LocalProtection) String() string {
	return ygot.EnumLogString(e, int64(e), "E_LinkAttributes_LocalProtection")
}

const (
	// LinkAttributes_LocalProtection_UNSET corresponds to the value UNSET of LinkAttributes_LocalProtection
	LinkAttributes_LocalProtection_UNSET E_LinkAttributes_LocalProtection = 0
	// LinkAttributes_LocalProtection_LOCAL_PROTECTION corresponds to the value LOCAL_PROTECTION of LinkAttributes_LocalProtection
	LinkAttributes_LocalProtection_LOCAL_PROTECTION E_LinkAttributes_LocalProtection = 1
	// LinkAttributes_LocalProtection_LINK_EXCLUDED corresponds to the value LINK_EXCLUDED of LinkAttributes_LocalProtection
	LinkAttributes_LocalProtection_LINK_EXCLUDED E_LinkAttributes_LocalProtection = 2
)

// E_LinkProtectionType_Type is a derived int64 type which is used to represent
// the enumerated node LinkProtectionType_Type. An additional value named
// LinkProtectionType_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_LinkProtectionType_Type int64

// IsYANGGoEnum ensures that LinkProtectionType_Type implements the yang.GoEnum
// interface. This ensures that LinkProtectionType_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_LinkProtectionType_Type) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  LinkProtectionType_Type.
func (E_LinkProtectionType_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_LinkProtectionType_Type.
func (e E_LinkProtectionType_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_LinkProtectionType_Type")
}

const (
	// LinkProtectionType_Type_UNSET corresponds to the value UNSET of LinkProtectionType_Type
	LinkProtectionType_Type_UNSET E_LinkProtectionType_Type = 0
	// LinkProtectionType_Type_EXTRA_TRAFFIC corresponds to the value EXTRA_TRAFFIC of LinkProtectionType_Type
	LinkProtectionType_Type_EXTRA_TRAFFIC E_LinkProtectionType_Type = 1
	// LinkProtectionType_Type_UNPROTECTED corresponds to the value UNPROTECTED of LinkProtectionType_Type
	LinkProtectionType_Type_UNPROTECTED E_LinkProtectionType_Type = 2
	// LinkProtectionType_Type_SHARED corresponds to the value SHARED of LinkProtectionType_Type
	LinkProtectionType_Type_SHARED E_LinkProtectionType_Type = 3
	// LinkProtectionType_Type_ONE_ONE corresponds to the value ONE_ONE of LinkProtectionType_Type
	LinkProtectionType_Type_ONE_ONE E_LinkProtectionType_Type = 4
	// LinkProtectionType_Type_PLUS_ONE corresponds to the value PLUS_ONE of LinkProtectionType_Type
	LinkProtectionType_Type_PLUS_ONE E_LinkProtectionType_Type = 5
	// LinkProtectionType_Type_ENHANCED corresponds to the value ENHANCED of LinkProtectionType_Type
	LinkProtectionType_Type_ENHANCED E_LinkProtectionType_Type = 6
)

// E_Link_SubTlv_Type_Enum is a derived int64 type which is used to represent
// the enumerated node Link_SubTlv_Type_Enum. An additional value named
// Link_SubTlv_Type_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Link_SubTlv_Type_Enum int64

// IsYANGGoEnum ensures that Link_SubTlv_Type_Enum implements the yang.GoEnum
// interface. This ensures that Link_SubTlv_Type_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_Link_SubTlv_Type_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Link_SubTlv_Type_Enum.
func (E_Link_SubTlv_Type_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Link_SubTlv_Type_Enum.
func (e E_Link_SubTlv_Type_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Link_SubTlv_Type_Enum")
}

const (
	// Link_SubTlv_Type_Enum_UNSET corresponds to the value UNSET of Link_SubTlv_Type_Enum
	Link_SubTlv_Type_Enum_UNSET E_Link_SubTlv_Type_Enum = 0
	// Link_SubTlv_Type_Enum_UNKNOWN corresponds to the value UNKNOWN of Link_SubTlv_Type_Enum
	Link_SubTlv_Type_Enum_UNKNOWN E_Link_SubTlv_Type_Enum = 1
)

// E_LsaGeneration_TimerType is a derived int64 type which is used to represent
// the enumerated node LsaGeneration_TimerType. An additional value named
// LsaGeneration_TimerType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_LsaGeneration_TimerType int64

// IsYANGGoEnum ensures that LsaGeneration_TimerType implements the yang.GoEnum
// interface. This ensures that LsaGeneration_TimerType can be identified as a
// mapped type for a YANG enumeration.
func (E_LsaGeneration_TimerType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  LsaGeneration_TimerType.
func (E_LsaGeneration_TimerType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_LsaGeneration_TimerType.
func (e E_LsaGeneration_TimerType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_LsaGeneration_TimerType")
}

const (
	// LsaGeneration_TimerType_UNSET corresponds to the value UNSET of LsaGeneration_TimerType
	LsaGeneration_TimerType_UNSET E_LsaGeneration_TimerType = 0
	// LsaGeneration_TimerType_LINEAR_BACKOFF corresponds to the value LINEAR_BACKOFF of LsaGeneration_TimerType
	LsaGeneration_TimerType_LINEAR_BACKOFF E_LsaGeneration_TimerType = 1
	// LsaGeneration_TimerType_EXPONENTIAL_BACKOFF corresponds to the value EXPONENTIAL_BACKOFF of LsaGeneration_TimerType
	LsaGeneration_TimerType_EXPONENTIAL_BACKOFF E_LsaGeneration_TimerType = 2
)

// E_Lsp_Flags is a derived int64 type which is used to represent
// the enumerated node Lsp_Flags. An additional value named
// Lsp_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Lsp_Flags int64

// IsYANGGoEnum ensures that Lsp_Flags implements the yang.GoEnum
// interface. This ensures that Lsp_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_Lsp_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Lsp_Flags.
func (E_Lsp_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Lsp_Flags.
func (e E_Lsp_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Lsp_Flags")
}

const (
	// Lsp_Flags_UNSET corresponds to the value UNSET of Lsp_Flags
	Lsp_Flags_UNSET E_Lsp_Flags = 0
	// Lsp_Flags_PARTITION_REPAIR corresponds to the value PARTITION_REPAIR of Lsp_Flags
	Lsp_Flags_PARTITION_REPAIR E_Lsp_Flags = 1
	// Lsp_Flags_ATTACHED_ERROR corresponds to the value ATTACHED_ERROR of Lsp_Flags
	Lsp_Flags_ATTACHED_ERROR E_Lsp_Flags = 2
	// Lsp_Flags_ATTACHED_EXPENSE corresponds to the value ATTACHED_EXPENSE of Lsp_Flags
	Lsp_Flags_ATTACHED_EXPENSE E_Lsp_Flags = 3
	// Lsp_Flags_ATTACHED_DELAY corresponds to the value ATTACHED_DELAY of Lsp_Flags
	Lsp_Flags_ATTACHED_DELAY E_Lsp_Flags = 4
	// Lsp_Flags_ATTACHED_DEFAULT corresponds to the value ATTACHED_DEFAULT of Lsp_Flags
	Lsp_Flags_ATTACHED_DEFAULT E_Lsp_Flags = 5
	// Lsp_Flags_OVERLOAD corresponds to the value OVERLOAD of Lsp_Flags
	Lsp_Flags_OVERLOAD E_Lsp_Flags = 6
)

// E_Lsp_PduType is a derived int64 type which is used to represent
// the enumerated node Lsp_PduType. An additional value named
// Lsp_PduType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Lsp_PduType int64

// IsYANGGoEnum ensures that Lsp_PduType implements the yang.GoEnum
// interface. This ensures that Lsp_PduType can be identified as a
// mapped type for a YANG enumeration.
func (E_Lsp_PduType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Lsp_PduType.
func (E_Lsp_PduType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Lsp_PduType.
func (e E_Lsp_PduType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Lsp_PduType")
}

const (
	// Lsp_PduType_UNSET corresponds to the value UNSET of Lsp_PduType
	Lsp_PduType_UNSET E_Lsp_PduType = 0
	// Lsp_PduType_LEVEL_1 corresponds to the value LEVEL_1 of Lsp_PduType
	Lsp_PduType_LEVEL_1 E_Lsp_PduType = 1
	// Lsp_PduType_LEVEL_2 corresponds to the value LEVEL_2 of Lsp_PduType
	Lsp_PduType_LEVEL_2 E_Lsp_PduType = 2
)

// E_NamedExplicitPath_SidSelectionMode is a derived int64 type which is used to represent
// the enumerated node NamedExplicitPath_SidSelectionMode. An additional value named
// NamedExplicitPath_SidSelectionMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_NamedExplicitPath_SidSelectionMode int64

// IsYANGGoEnum ensures that NamedExplicitPath_SidSelectionMode implements the yang.GoEnum
// interface. This ensures that NamedExplicitPath_SidSelectionMode can be identified as a
// mapped type for a YANG enumeration.
func (E_NamedExplicitPath_SidSelectionMode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  NamedExplicitPath_SidSelectionMode.
func (E_NamedExplicitPath_SidSelectionMode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_NamedExplicitPath_SidSelectionMode.
func (e E_NamedExplicitPath_SidSelectionMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_NamedExplicitPath_SidSelectionMode")
}

const (
	// NamedExplicitPath_SidSelectionMode_UNSET corresponds to the value UNSET of NamedExplicitPath_SidSelectionMode
	NamedExplicitPath_SidSelectionMode_UNSET E_NamedExplicitPath_SidSelectionMode = 0
	// NamedExplicitPath_SidSelectionMode_ADJ_SID_ONLY corresponds to the value ADJ_SID_ONLY of NamedExplicitPath_SidSelectionMode
	NamedExplicitPath_SidSelectionMode_ADJ_SID_ONLY E_NamedExplicitPath_SidSelectionMode = 1
	// NamedExplicitPath_SidSelectionMode_MIXED_MODE corresponds to the value MIXED_MODE of NamedExplicitPath_SidSelectionMode
	NamedExplicitPath_SidSelectionMode_MIXED_MODE E_NamedExplicitPath_SidSelectionMode = 2
)

// E_Neighbor_NeighborState is a derived int64 type which is used to represent
// the enumerated node Neighbor_NeighborState. An additional value named
// Neighbor_NeighborState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Neighbor_NeighborState int64

// IsYANGGoEnum ensures that Neighbor_NeighborState implements the yang.GoEnum
// interface. This ensures that Neighbor_NeighborState can be identified as a
// mapped type for a YANG enumeration.
func (E_Neighbor_NeighborState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Neighbor_NeighborState.
func (E_Neighbor_NeighborState) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Neighbor_NeighborState.
func (e E_Neighbor_NeighborState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Neighbor_NeighborState")
}

const (
	// Neighbor_NeighborState_UNSET corresponds to the value UNSET of Neighbor_NeighborState
	Neighbor_NeighborState_UNSET E_Neighbor_NeighborState = 0
	// Neighbor_NeighborState_INCOMPLETE corresponds to the value INCOMPLETE of Neighbor_NeighborState
	Neighbor_NeighborState_INCOMPLETE E_Neighbor_NeighborState = 1
	// Neighbor_NeighborState_REACHABLE corresponds to the value REACHABLE of Neighbor_NeighborState
	Neighbor_NeighborState_REACHABLE E_Neighbor_NeighborState = 2
	// Neighbor_NeighborState_STALE corresponds to the value STALE of Neighbor_NeighborState
	Neighbor_NeighborState_STALE E_Neighbor_NeighborState = 3
	// Neighbor_NeighborState_DELAY corresponds to the value DELAY of Neighbor_NeighborState
	Neighbor_NeighborState_DELAY E_Neighbor_NeighborState = 4
	// Neighbor_NeighborState_PROBE corresponds to the value PROBE of Neighbor_NeighborState
	Neighbor_NeighborState_PROBE E_Neighbor_NeighborState = 5
)

// E_Neighbor_NeighborStatus is a derived int64 type which is used to represent
// the enumerated node Neighbor_NeighborStatus. An additional value named
// Neighbor_NeighborStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Neighbor_NeighborStatus int64

// IsYANGGoEnum ensures that Neighbor_NeighborStatus implements the yang.GoEnum
// interface. This ensures that Neighbor_NeighborStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_Neighbor_NeighborStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Neighbor_NeighborStatus.
func (E_Neighbor_NeighborStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Neighbor_NeighborStatus.
func (e E_Neighbor_NeighborStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Neighbor_NeighborStatus")
}

const (
	// Neighbor_NeighborStatus_UNSET corresponds to the value UNSET of Neighbor_NeighborStatus
	Neighbor_NeighborStatus_UNSET E_Neighbor_NeighborStatus = 0
	// Neighbor_NeighborStatus_UP corresponds to the value UP of Neighbor_NeighborStatus
	Neighbor_NeighborStatus_UP E_Neighbor_NeighborStatus = 1
	// Neighbor_NeighborStatus_DOWN corresponds to the value DOWN of Neighbor_NeighborStatus
	Neighbor_NeighborStatus_DOWN E_Neighbor_NeighborStatus = 2
)

// E_Neighbor_SessionState is a derived int64 type which is used to represent
// the enumerated node Neighbor_SessionState. An additional value named
// Neighbor_SessionState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Neighbor_SessionState int64

// IsYANGGoEnum ensures that Neighbor_SessionState implements the yang.GoEnum
// interface. This ensures that Neighbor_SessionState can be identified as a
// mapped type for a YANG enumeration.
func (E_Neighbor_SessionState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Neighbor_SessionState.
func (E_Neighbor_SessionState) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Neighbor_SessionState.
func (e E_Neighbor_SessionState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Neighbor_SessionState")
}

const (
	// Neighbor_SessionState_UNSET corresponds to the value UNSET of Neighbor_SessionState
	Neighbor_SessionState_UNSET E_Neighbor_SessionState = 0
	// Neighbor_SessionState_IDLE corresponds to the value IDLE of Neighbor_SessionState
	Neighbor_SessionState_IDLE E_Neighbor_SessionState = 1
	// Neighbor_SessionState_CONNECT corresponds to the value CONNECT of Neighbor_SessionState
	Neighbor_SessionState_CONNECT E_Neighbor_SessionState = 2
	// Neighbor_SessionState_ACTIVE corresponds to the value ACTIVE of Neighbor_SessionState
	Neighbor_SessionState_ACTIVE E_Neighbor_SessionState = 3
	// Neighbor_SessionState_OPENSENT corresponds to the value OPENSENT of Neighbor_SessionState
	Neighbor_SessionState_OPENSENT E_Neighbor_SessionState = 4
	// Neighbor_SessionState_OPENCONFIRM corresponds to the value OPENCONFIRM of Neighbor_SessionState
	Neighbor_SessionState_OPENCONFIRM E_Neighbor_SessionState = 5
	// Neighbor_SessionState_ESTABLISHED corresponds to the value ESTABLISHED of Neighbor_SessionState
	Neighbor_SessionState_ESTABLISHED E_Neighbor_SessionState = 6
)

// E_Nlpid_Nlpid is a derived int64 type which is used to represent
// the enumerated node Nlpid_Nlpid. An additional value named
// Nlpid_Nlpid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Nlpid_Nlpid int64

// IsYANGGoEnum ensures that Nlpid_Nlpid implements the yang.GoEnum
// interface. This ensures that Nlpid_Nlpid can be identified as a
// mapped type for a YANG enumeration.
func (E_Nlpid_Nlpid) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Nlpid_Nlpid.
func (E_Nlpid_Nlpid) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Nlpid_Nlpid.
func (e E_Nlpid_Nlpid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Nlpid_Nlpid")
}

const (
	// Nlpid_Nlpid_UNSET corresponds to the value UNSET of Nlpid_Nlpid
	Nlpid_Nlpid_UNSET E_Nlpid_Nlpid = 0
	// Nlpid_Nlpid_IPV4 corresponds to the value IPV4 of Nlpid_Nlpid
	Nlpid_Nlpid_IPV4 E_Nlpid_Nlpid = 1
	// Nlpid_Nlpid_IPV6 corresponds to the value IPV6 of Nlpid_Nlpid
	Nlpid_Nlpid_IPV6 E_Nlpid_Nlpid = 2
)

// E_NodeAttribute_SubTlv_Type_Enum is a derived int64 type which is used to represent
// the enumerated node NodeAttribute_SubTlv_Type_Enum. An additional value named
// NodeAttribute_SubTlv_Type_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_NodeAttribute_SubTlv_Type_Enum int64

// IsYANGGoEnum ensures that NodeAttribute_SubTlv_Type_Enum implements the yang.GoEnum
// interface. This ensures that NodeAttribute_SubTlv_Type_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_NodeAttribute_SubTlv_Type_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  NodeAttribute_SubTlv_Type_Enum.
func (E_NodeAttribute_SubTlv_Type_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_NodeAttribute_SubTlv_Type_Enum.
func (e E_NodeAttribute_SubTlv_Type_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_NodeAttribute_SubTlv_Type_Enum")
}

const (
	// NodeAttribute_SubTlv_Type_Enum_UNSET corresponds to the value UNSET of NodeAttribute_SubTlv_Type_Enum
	NodeAttribute_SubTlv_Type_Enum_UNSET E_NodeAttribute_SubTlv_Type_Enum = 0
	// NodeAttribute_SubTlv_Type_Enum_UNKNOWN corresponds to the value UNKNOWN of NodeAttribute_SubTlv_Type_Enum
	NodeAttribute_SubTlv_Type_Enum_UNKNOWN E_NodeAttribute_SubTlv_Type_Enum = 1
)

// E_OpaqueLsa_Scope is a derived int64 type which is used to represent
// the enumerated node OpaqueLsa_Scope. An additional value named
// OpaqueLsa_Scope_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpaqueLsa_Scope int64

// IsYANGGoEnum ensures that OpaqueLsa_Scope implements the yang.GoEnum
// interface. This ensures that OpaqueLsa_Scope can be identified as a
// mapped type for a YANG enumeration.
func (E_OpaqueLsa_Scope) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpaqueLsa_Scope.
func (E_OpaqueLsa_Scope) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpaqueLsa_Scope.
func (e E_OpaqueLsa_Scope) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpaqueLsa_Scope")
}

const (
	// OpaqueLsa_Scope_UNSET corresponds to the value UNSET of OpaqueLsa_Scope
	OpaqueLsa_Scope_UNSET E_OpaqueLsa_Scope = 0
	// OpaqueLsa_Scope_LINK corresponds to the value LINK of OpaqueLsa_Scope
	OpaqueLsa_Scope_LINK E_OpaqueLsa_Scope = 1
	// OpaqueLsa_Scope_AREA corresponds to the value AREA of OpaqueLsa_Scope
	OpaqueLsa_Scope_AREA E_OpaqueLsa_Scope = 2
	// OpaqueLsa_Scope_AS corresponds to the value AS of OpaqueLsa_Scope
	OpaqueLsa_Scope_AS E_OpaqueLsa_Scope = 3
)

// E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE.
func (E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE.
func (e E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE
	OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_UNSET E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE = 0
	// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_COMMAND corresponds to the value AAA_ACCOUNTING_EVENT_COMMAND of OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE
	OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_COMMAND E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE = 1
	// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_LOGIN corresponds to the value AAA_ACCOUNTING_EVENT_LOGIN of OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE
	OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_LOGIN E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE = 2
)

// E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE.
func (E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE.
func (e E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE
	OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_UNSET E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE = 0
	// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_COMMAND corresponds to the value AAA_AUTHORIZATION_EVENT_COMMAND of OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE
	OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_COMMAND E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE = 1
	// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_CONFIG corresponds to the value AAA_AUTHORIZATION_EVENT_CONFIG of OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE
	OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_CONFIG E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE = 2
)

// E_OpenconfigAaaTypes_AAA_METHOD_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_METHOD_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_METHOD_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_METHOD_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_METHOD_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_METHOD_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_METHOD_TYPE.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_METHOD_TYPE.
func (e E_OpenconfigAaaTypes_AAA_METHOD_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_METHOD_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_UNSET E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 0
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_LOCAL corresponds to the value LOCAL of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_LOCAL E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 1
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_RADIUS_ALL corresponds to the value RADIUS_ALL of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_RADIUS_ALL E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 2
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_TACACS_ALL corresponds to the value TACACS_ALL of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_TACACS_ALL E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 3
)

// E_OpenconfigAaaTypes_AAA_SERVER_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_SERVER_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_SERVER_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_SERVER_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_SERVER_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_SERVER_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_SERVER_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_SERVER_TYPE.
func (E_OpenconfigAaaTypes_AAA_SERVER_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_SERVER_TYPE.
func (e E_OpenconfigAaaTypes_AAA_SERVER_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_SERVER_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_SERVER_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_SERVER_TYPE
	OpenconfigAaaTypes_AAA_SERVER_TYPE_UNSET E_OpenconfigAaaTypes_AAA_SERVER_TYPE = 0
	// OpenconfigAaaTypes_AAA_SERVER_TYPE_RADIUS corresponds to the value RADIUS of OpenconfigAaaTypes_AAA_SERVER_TYPE
	OpenconfigAaaTypes_AAA_SERVER_TYPE_RADIUS E_OpenconfigAaaTypes_AAA_SERVER_TYPE = 1
	// OpenconfigAaaTypes_AAA_SERVER_TYPE_TACACS corresponds to the value TACACS of OpenconfigAaaTypes_AAA_SERVER_TYPE
	OpenconfigAaaTypes_AAA_SERVER_TYPE_TACACS E_OpenconfigAaaTypes_AAA_SERVER_TYPE = 2
)

// E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES. An additional value named
// OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES.
func (E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES.
func (e E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES")
}

const (
	// OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
	OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_UNSET E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES = 0
	// OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_SYSTEM_ROLE_ADMIN corresponds to the value SYSTEM_ROLE_ADMIN of OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
	OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_SYSTEM_ROLE_ADMIN E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES = 1
)

// E_OpenconfigAcl_ACL_COUNTER_CAPABILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_ACL_COUNTER_CAPABILITY. An additional value named
// OpenconfigAcl_ACL_COUNTER_CAPABILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_ACL_COUNTER_CAPABILITY int64

// IsYANGGoEnum ensures that OpenconfigAcl_ACL_COUNTER_CAPABILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_ACL_COUNTER_CAPABILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_ACL_COUNTER_CAPABILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_ACL_COUNTER_CAPABILITY.
func (E_OpenconfigAcl_ACL_COUNTER_CAPABILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAcl_ACL_COUNTER_CAPABILITY.
func (e E_OpenconfigAcl_ACL_COUNTER_CAPABILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_ACL_COUNTER_CAPABILITY")
}

const (
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_UNSET corresponds to the value UNSET of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_UNSET E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 0
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_AGGREGATE_ONLY corresponds to the value AGGREGATE_ONLY of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_AGGREGATE_ONLY E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 1
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_AGGREGATE corresponds to the value INTERFACE_AGGREGATE of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_AGGREGATE E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 2
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_ONLY corresponds to the value INTERFACE_ONLY of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_ONLY E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 3
)

// E_OpenconfigAcl_ACL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_ACL_TYPE. An additional value named
// OpenconfigAcl_ACL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_ACL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAcl_ACL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_ACL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_ACL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_ACL_TYPE.
func (E_OpenconfigAcl_ACL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigAcl_ACL_TYPE.
func (e E_OpenconfigAcl_ACL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_ACL_TYPE")
}

const (
	// OpenconfigAcl_ACL_TYPE_UNSET corresponds to the value UNSET of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_UNSET E_OpenconfigAcl_ACL_TYPE = 0
	// OpenconfigAcl_ACL_TYPE_ACL_IPV4 corresponds to the value ACL_IPV4 of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_IPV4 E_OpenconfigAcl_ACL_TYPE = 1
	// OpenconfigAcl_ACL_TYPE_ACL_IPV6 corresponds to the value ACL_IPV6 of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_IPV6 E_OpenconfigAcl_ACL_TYPE = 2
	// OpenconfigAcl_ACL_TYPE_ACL_L2 corresponds to the value ACL_L2 of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_L2 E_OpenconfigAcl_ACL_TYPE = 3
	// OpenconfigAcl_ACL_TYPE_ACL_MIXED corresponds to the value ACL_MIXED of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_MIXED E_OpenconfigAcl_ACL_TYPE = 4
)

// E_OpenconfigAcl_FORWARDING_ACTION is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_FORWARDING_ACTION. An additional value named
// OpenconfigAcl_FORWARDING_ACTION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_FORWARDING_ACTION int64

// IsYANGGoEnum ensures that OpenconfigAcl_FORWARDING_ACTION implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_FORWARDING_ACTION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_FORWARDING_ACTION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_FORWARDING_ACTION.
func (E_OpenconfigAcl_FORWARDING_ACTION) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAcl_FORWARDING_ACTION.
func (e E_OpenconfigAcl_FORWARDING_ACTION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_FORWARDING_ACTION")
}

const (
	// OpenconfigAcl_FORWARDING_ACTION_UNSET corresponds to the value UNSET of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_UNSET E_OpenconfigAcl_FORWARDING_ACTION = 0
	// OpenconfigAcl_FORWARDING_ACTION_ACCEPT corresponds to the value ACCEPT of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_ACCEPT E_OpenconfigAcl_FORWARDING_ACTION = 1
	// OpenconfigAcl_FORWARDING_ACTION_DROP corresponds to the value DROP of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_DROP E_OpenconfigAcl_FORWARDING_ACTION = 2
	// OpenconfigAcl_FORWARDING_ACTION_REJECT corresponds to the value REJECT of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_REJECT E_OpenconfigAcl_FORWARDING_ACTION = 3
)

// E_OpenconfigAcl_LOG_ACTION is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_LOG_ACTION. An additional value named
// OpenconfigAcl_LOG_ACTION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_LOG_ACTION int64

// IsYANGGoEnum ensures that OpenconfigAcl_LOG_ACTION implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_LOG_ACTION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_LOG_ACTION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_LOG_ACTION.
func (E_OpenconfigAcl_LOG_ACTION) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigAcl_LOG_ACTION.
func (e E_OpenconfigAcl_LOG_ACTION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_LOG_ACTION")
}

const (
	// OpenconfigAcl_LOG_ACTION_UNSET corresponds to the value UNSET of OpenconfigAcl_LOG_ACTION
	OpenconfigAcl_LOG_ACTION_UNSET E_OpenconfigAcl_LOG_ACTION = 0
	// OpenconfigAcl_LOG_ACTION_LOG_NONE corresponds to the value LOG_NONE of OpenconfigAcl_LOG_ACTION
	OpenconfigAcl_LOG_ACTION_LOG_NONE E_OpenconfigAcl_LOG_ACTION = 1
	// OpenconfigAcl_LOG_ACTION_LOG_SYSLOG corresponds to the value LOG_SYSLOG of OpenconfigAcl_LOG_ACTION
	OpenconfigAcl_LOG_ACTION_LOG_SYSLOG E_OpenconfigAcl_LOG_ACTION = 2
)

// E_OpenconfigAftTypes_EncapsulationHeaderType is a derived int64 type which is used to represent
// the enumerated node OpenconfigAftTypes_EncapsulationHeaderType. An additional value named
// OpenconfigAftTypes_EncapsulationHeaderType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAftTypes_EncapsulationHeaderType int64

// IsYANGGoEnum ensures that OpenconfigAftTypes_EncapsulationHeaderType implements the yang.GoEnum
// interface. This ensures that OpenconfigAftTypes_EncapsulationHeaderType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAftTypes_EncapsulationHeaderType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAftTypes_EncapsulationHeaderType.
func (E_OpenconfigAftTypes_EncapsulationHeaderType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAftTypes_EncapsulationHeaderType.
func (e E_OpenconfigAftTypes_EncapsulationHeaderType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAftTypes_EncapsulationHeaderType")
}

const (
	// OpenconfigAftTypes_EncapsulationHeaderType_UNSET corresponds to the value UNSET of OpenconfigAftTypes_EncapsulationHeaderType
	OpenconfigAftTypes_EncapsulationHeaderType_UNSET E_OpenconfigAftTypes_EncapsulationHeaderType = 0
	// OpenconfigAftTypes_EncapsulationHeaderType_GRE corresponds to the value GRE of OpenconfigAftTypes_EncapsulationHeaderType
	OpenconfigAftTypes_EncapsulationHeaderType_GRE E_OpenconfigAftTypes_EncapsulationHeaderType = 1
	// OpenconfigAftTypes_EncapsulationHeaderType_IPV4 corresponds to the value IPV4 of OpenconfigAftTypes_EncapsulationHeaderType
	OpenconfigAftTypes_EncapsulationHeaderType_IPV4 E_OpenconfigAftTypes_EncapsulationHeaderType = 2
	// OpenconfigAftTypes_EncapsulationHeaderType_IPV6 corresponds to the value IPV6 of OpenconfigAftTypes_EncapsulationHeaderType
	OpenconfigAftTypes_EncapsulationHeaderType_IPV6 E_OpenconfigAftTypes_EncapsulationHeaderType = 3
	// OpenconfigAftTypes_EncapsulationHeaderType_MPLS corresponds to the value MPLS of OpenconfigAftTypes_EncapsulationHeaderType
	OpenconfigAftTypes_EncapsulationHeaderType_MPLS E_OpenconfigAftTypes_EncapsulationHeaderType = 4
)

// E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY. An additional value named
// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY int64

// IsYANGGoEnum ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY implements the yang.GoEnum
// interface. This ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY.
func (e E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY")
}

const (
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNSET corresponds to the value UNSET of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNSET E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 0
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_CRITICAL corresponds to the value CRITICAL of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_CRITICAL E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 1
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MAJOR corresponds to the value MAJOR of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MAJOR E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 2
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MINOR corresponds to the value MINOR of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MINOR E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 3
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNKNOWN corresponds to the value UNKNOWN of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNKNOWN E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 4
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_WARNING corresponds to the value WARNING of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_WARNING E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 5
)

// E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID is a derived int64 type which is used to represent
// the enumerated node OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID. An additional value named
// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID int64

// IsYANGGoEnum ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID implements the yang.GoEnum
// interface. This ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID.
func (e E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID")
}

const (
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_UNSET corresponds to the value UNSET of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_UNSET E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 0
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_AIS corresponds to the value AIS of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_AIS E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 1
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_EQPT corresponds to the value EQPT of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_EQPT E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 2
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_LOS corresponds to the value LOS of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_LOS E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 3
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_OTS corresponds to the value OTS of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_OTS E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 4
)

// E_OpenconfigBgpTypes_AFI_SAFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_AFI_SAFI_TYPE. An additional value named
// OpenconfigBgpTypes_AFI_SAFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_AFI_SAFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_AFI_SAFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_AFI_SAFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_AFI_SAFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_AFI_SAFI_TYPE.
func (E_OpenconfigBgpTypes_AFI_SAFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_AFI_SAFI_TYPE.
func (e E_OpenconfigBgpTypes_AFI_SAFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_AFI_SAFI_TYPE")
}

const (
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_UNSET E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 0
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_FLOWSPEC corresponds to the value IPV4_FLOWSPEC of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_FLOWSPEC E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 1
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_LABELED_UNICAST corresponds to the value IPV4_LABELED_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_LABELED_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 2
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_UNICAST corresponds to the value IPV4_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 3
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_LABELED_UNICAST corresponds to the value IPV6_LABELED_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_LABELED_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 4
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_UNICAST corresponds to the value IPV6_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 5
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_EVPN corresponds to the value L2VPN_EVPN of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_EVPN E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 6
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_VPLS corresponds to the value L2VPN_VPLS of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_VPLS E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 7
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_MULTICAST corresponds to the value L3VPN_IPV4_MULTICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_MULTICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 8
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_UNICAST corresponds to the value L3VPN_IPV4_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 9
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_MULTICAST corresponds to the value L3VPN_IPV6_MULTICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_MULTICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 10
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_UNICAST corresponds to the value L3VPN_IPV6_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 11
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE corresponds to the value LINKSTATE of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 12
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_SPF corresponds to the value LINKSTATE_SPF of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_SPF E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 13
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_VPN corresponds to the value LINKSTATE_VPN of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_VPN E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 14
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV4 corresponds to the value SRTE_POLICY_IPV4 of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV4 E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 15
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV6 corresponds to the value SRTE_POLICY_IPV6 of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV6 E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 16
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_VPNV4_FLOWSPEC corresponds to the value VPNV4_FLOWSPEC of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_VPNV4_FLOWSPEC E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 17
)

// E_OpenconfigBgpTypes_AsPathSegmentType is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_AsPathSegmentType. An additional value named
// OpenconfigBgpTypes_AsPathSegmentType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_AsPathSegmentType int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_AsPathSegmentType implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_AsPathSegmentType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_AsPathSegmentType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_AsPathSegmentType.
func (E_OpenconfigBgpTypes_AsPathSegmentType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_AsPathSegmentType.
func (e E_OpenconfigBgpTypes_AsPathSegmentType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_AsPathSegmentType")
}

const (
	// OpenconfigBgpTypes_AsPathSegmentType_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_AsPathSegmentType
	OpenconfigBgpTypes_AsPathSegmentType_UNSET E_OpenconfigBgpTypes_AsPathSegmentType = 0
	// OpenconfigBgpTypes_AsPathSegmentType_AS_SEQ corresponds to the value AS_SEQ of OpenconfigBgpTypes_AsPathSegmentType
	OpenconfigBgpTypes_AsPathSegmentType_AS_SEQ E_OpenconfigBgpTypes_AsPathSegmentType = 1
	// OpenconfigBgpTypes_AsPathSegmentType_AS_SET corresponds to the value AS_SET of OpenconfigBgpTypes_AsPathSegmentType
	OpenconfigBgpTypes_AsPathSegmentType_AS_SET E_OpenconfigBgpTypes_AsPathSegmentType = 2
	// OpenconfigBgpTypes_AsPathSegmentType_AS_CONFED_SEQUENCE corresponds to the value AS_CONFED_SEQUENCE of OpenconfigBgpTypes_AsPathSegmentType
	OpenconfigBgpTypes_AsPathSegmentType_AS_CONFED_SEQUENCE E_OpenconfigBgpTypes_AsPathSegmentType = 3
	// OpenconfigBgpTypes_AsPathSegmentType_AS_CONFED_SET corresponds to the value AS_CONFED_SET of OpenconfigBgpTypes_AsPathSegmentType
	OpenconfigBgpTypes_AsPathSegmentType_AS_CONFED_SET E_OpenconfigBgpTypes_AsPathSegmentType = 4
)

// E_OpenconfigBgpTypes_BGP_CAPABILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_CAPABILITY. An additional value named
// OpenconfigBgpTypes_BGP_CAPABILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_CAPABILITY int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_CAPABILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_CAPABILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_CAPABILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_CAPABILITY.
func (E_OpenconfigBgpTypes_BGP_CAPABILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_CAPABILITY.
func (e E_OpenconfigBgpTypes_BGP_CAPABILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_CAPABILITY")
}

const (
	// OpenconfigBgpTypes_BGP_CAPABILITY_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_UNSET E_OpenconfigBgpTypes_BGP_CAPABILITY = 0
	// OpenconfigBgpTypes_BGP_CAPABILITY_ADD_PATHS corresponds to the value ADD_PATHS of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_ADD_PATHS E_OpenconfigBgpTypes_BGP_CAPABILITY = 1
	// OpenconfigBgpTypes_BGP_CAPABILITY_ASN32 corresponds to the value ASN32 of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_ASN32 E_OpenconfigBgpTypes_BGP_CAPABILITY = 2
	// OpenconfigBgpTypes_BGP_CAPABILITY_EXTENDED_NEXTHOP_ENCODING corresponds to the value EXTENDED_NEXTHOP_ENCODING of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_EXTENDED_NEXTHOP_ENCODING E_OpenconfigBgpTypes_BGP_CAPABILITY = 3
	// OpenconfigBgpTypes_BGP_CAPABILITY_GRACEFUL_RESTART corresponds to the value GRACEFUL_RESTART of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_GRACEFUL_RESTART E_OpenconfigBgpTypes_BGP_CAPABILITY = 4
	// OpenconfigBgpTypes_BGP_CAPABILITY_MPBGP corresponds to the value MPBGP of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_MPBGP E_OpenconfigBgpTypes_BGP_CAPABILITY = 5
	// OpenconfigBgpTypes_BGP_CAPABILITY_ROUTE_REFRESH corresponds to the value ROUTE_REFRESH of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_ROUTE_REFRESH E_OpenconfigBgpTypes_BGP_CAPABILITY = 6
)

// E_OpenconfigBgpTypes_BGP_ERROR_CODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_ERROR_CODE. An additional value named
// OpenconfigBgpTypes_BGP_ERROR_CODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_ERROR_CODE int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_ERROR_CODE implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_ERROR_CODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_ERROR_CODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_ERROR_CODE.
func (E_OpenconfigBgpTypes_BGP_ERROR_CODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_ERROR_CODE.
func (e E_OpenconfigBgpTypes_BGP_ERROR_CODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_ERROR_CODE")
}

const (
	// OpenconfigBgpTypes_BGP_ERROR_CODE_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_UNSET E_OpenconfigBgpTypes_BGP_ERROR_CODE = 0
	// OpenconfigBgpTypes_BGP_ERROR_CODE_CEASE corresponds to the value CEASE of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_CEASE E_OpenconfigBgpTypes_BGP_ERROR_CODE = 1
	// OpenconfigBgpTypes_BGP_ERROR_CODE_FINITE_STATE_MACHINE_ERROR corresponds to the value FINITE_STATE_MACHINE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_FINITE_STATE_MACHINE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 2
	// OpenconfigBgpTypes_BGP_ERROR_CODE_HOLD_TIMER_EXPIRED corresponds to the value HOLD_TIMER_EXPIRED of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_HOLD_TIMER_EXPIRED E_OpenconfigBgpTypes_BGP_ERROR_CODE = 3
	// OpenconfigBgpTypes_BGP_ERROR_CODE_MESSAGE_HEADER_ERROR corresponds to the value MESSAGE_HEADER_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_MESSAGE_HEADER_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 4
	// OpenconfigBgpTypes_BGP_ERROR_CODE_OPEN_MESSAGE_ERROR corresponds to the value OPEN_MESSAGE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_OPEN_MESSAGE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 5
	// OpenconfigBgpTypes_BGP_ERROR_CODE_ROUTE_REFRESH_MESSAGE_ERROR corresponds to the value ROUTE_REFRESH_MESSAGE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_ROUTE_REFRESH_MESSAGE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 6
	// OpenconfigBgpTypes_BGP_ERROR_CODE_UPDATE_MESSAGE_ERROR corresponds to the value UPDATE_MESSAGE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_UPDATE_MESSAGE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 7
)

// E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_ERROR_SUBCODE. An additional value named
// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_ERROR_SUBCODE implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_ERROR_SUBCODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_ERROR_SUBCODE.
func (E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE.
func (e E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE")
}

const (
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSET E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 0
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_RESET corresponds to the value ADMINISTRATIVE_RESET of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_RESET E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 1
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_SHUTDOWN corresponds to the value ADMINISTRATIVE_SHUTDOWN of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_SHUTDOWN E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 2
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_FLAGS_ERROR corresponds to the value ATTRIBUTE_FLAGS_ERROR of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_FLAGS_ERROR E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 3
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_LENGTH_ERROR corresponds to the value ATTRIBUTE_LENGTH_ERROR of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_LENGTH_ERROR E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 4
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_BGP_IDENTIFIER corresponds to the value BAD_BGP_IDENTIFIER of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_BGP_IDENTIFIER E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 5
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_LENGTH corresponds to the value BAD_MESSAGE_LENGTH of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_LENGTH E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 6
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_TYPE corresponds to the value BAD_MESSAGE_TYPE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_TYPE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 7
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_PEER_AS corresponds to the value BAD_PEER_AS of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_PEER_AS E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 8
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CEASE_SUBCODE corresponds to the value CEASE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CEASE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 9
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_NOT_SYNCHRONIZED corresponds to the value CONNECTION_NOT_SYNCHRONIZED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_NOT_SYNCHRONIZED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 10
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_REJECTED corresponds to the value CONNECTION_REJECTED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_REJECTED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 11
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONN_COLLISION_RESOLUTION corresponds to the value CONN_COLLISION_RESOLUTION of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONN_COLLISION_RESOLUTION E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 12
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_FINITE_STATE_MACHINE_SUBCODE corresponds to the value FINITE_STATE_MACHINE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_FINITE_STATE_MACHINE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 13
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_MESSAGE_LENGTH corresponds to the value INVALID_MESSAGE_LENGTH of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_MESSAGE_LENGTH E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 14
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NETWORK_FIELD corresponds to the value INVALID_NETWORK_FIELD of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NETWORK_FIELD E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 15
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NEXT_HOP_ATTRIBUTE corresponds to the value INVALID_NEXT_HOP_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NEXT_HOP_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 16
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_ORIGIN_ATTRIBUTE corresponds to the value INVALID_ORIGIN_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_ORIGIN_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 17
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_AS_PATH corresponds to the value MALFORMED_AS_PATH of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_AS_PATH E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 18
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_ATTRIBUTE_LIST corresponds to the value MALFORMED_ATTRIBUTE_LIST of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_ATTRIBUTE_LIST E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 19
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MAX_NUM_PREFIXES_REACHED corresponds to the value MAX_NUM_PREFIXES_REACHED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MAX_NUM_PREFIXES_REACHED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 20
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MESSAGE_HEADER_SUBCODE corresponds to the value MESSAGE_HEADER_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MESSAGE_HEADER_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 21
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MISSING_WELL_KNOWN_ATTRIBUTE corresponds to the value MISSING_WELL_KNOWN_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MISSING_WELL_KNOWN_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 22
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPEN_MESSAGE_SUBCODE corresponds to the value OPEN_MESSAGE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPEN_MESSAGE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 23
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPTIONAL_ATTRIBUTE_ERROR corresponds to the value OPTIONAL_ATTRIBUTE_ERROR of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPTIONAL_ATTRIBUTE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 24
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OTHER_CONFIG_CHANGE corresponds to the value OTHER_CONFIG_CHANGE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OTHER_CONFIG_CHANGE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 25
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OUT_OF_RESOURCES corresponds to the value OUT_OF_RESOURCES of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OUT_OF_RESOURCES E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 26
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_PEER_DE_CONFIGURED corresponds to the value PEER_DE_CONFIGURED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_PEER_DE_CONFIGURED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 27
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED corresponds to the value RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 28
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM corresponds to the value RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 29
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENSENT corresponds to the value RECEIVE_UNEXPECTED_MESSAGE_OPENSENT of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENSENT E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 30
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ROUTE_REFRESH_SUBCODE corresponds to the value ROUTE_REFRESH_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ROUTE_REFRESH_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 31
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNACCEPTABLE_HOLD_TIME corresponds to the value UNACCEPTABLE_HOLD_TIME of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNACCEPTABLE_HOLD_TIME E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 32
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE corresponds to the value UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 33
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSPECIFIC corresponds to the value UNSPECIFIC of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSPECIFIC E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 34
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_CAPABILITY corresponds to the value UNSUPPORTED_CAPABILITY of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_CAPABILITY E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 35
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_OPTIONAL_PARAMETER corresponds to the value UNSUPPORTED_OPTIONAL_PARAMETER of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_OPTIONAL_PARAMETER E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 36
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_VERSION_NUMBER corresponds to the value UNSUPPORTED_VERSION_NUMBER of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_VERSION_NUMBER E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 37
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UPDATE_MESSAGE_SUBCODE corresponds to the value UPDATE_MESSAGE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UPDATE_MESSAGE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 38
)

// E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY. An additional value named
// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY.
func (E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY.
func (e E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY")
}

const (
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_UNSET E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 0
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NOPEER corresponds to the value NOPEER of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NOPEER E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 1
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_ADVERTISE corresponds to the value NO_ADVERTISE of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_ADVERTISE E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 2
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT corresponds to the value NO_EXPORT of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 3
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT_SUBCONFED corresponds to the value NO_EXPORT_SUBCONFED of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT_SUBCONFED E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 4
)

// E_OpenconfigBgpTypes_BgpOriginAttrType is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BgpOriginAttrType. An additional value named
// OpenconfigBgpTypes_BgpOriginAttrType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BgpOriginAttrType int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BgpOriginAttrType implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BgpOriginAttrType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BgpOriginAttrType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BgpOriginAttrType.
func (E_OpenconfigBgpTypes_BgpOriginAttrType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BgpOriginAttrType.
func (e E_OpenconfigBgpTypes_BgpOriginAttrType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BgpOriginAttrType")
}

const (
	// OpenconfigBgpTypes_BgpOriginAttrType_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BgpOriginAttrType
	OpenconfigBgpTypes_BgpOriginAttrType_UNSET E_OpenconfigBgpTypes_BgpOriginAttrType = 0
	// OpenconfigBgpTypes_BgpOriginAttrType_IGP corresponds to the value IGP of OpenconfigBgpTypes_BgpOriginAttrType
	OpenconfigBgpTypes_BgpOriginAttrType_IGP E_OpenconfigBgpTypes_BgpOriginAttrType = 1
	// OpenconfigBgpTypes_BgpOriginAttrType_EGP corresponds to the value EGP of OpenconfigBgpTypes_BgpOriginAttrType
	OpenconfigBgpTypes_BgpOriginAttrType_EGP E_OpenconfigBgpTypes_BgpOriginAttrType = 2
	// OpenconfigBgpTypes_BgpOriginAttrType_INCOMPLETE corresponds to the value INCOMPLETE of OpenconfigBgpTypes_BgpOriginAttrType
	OpenconfigBgpTypes_BgpOriginAttrType_INCOMPLETE E_OpenconfigBgpTypes_BgpOriginAttrType = 3
)

// E_OpenconfigBgpTypes_CommunityType is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_CommunityType. An additional value named
// OpenconfigBgpTypes_CommunityType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_CommunityType int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_CommunityType implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_CommunityType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_CommunityType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_CommunityType.
func (E_OpenconfigBgpTypes_CommunityType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_CommunityType.
func (e E_OpenconfigBgpTypes_CommunityType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_CommunityType")
}

const (
	// OpenconfigBgpTypes_CommunityType_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_CommunityType
	OpenconfigBgpTypes_CommunityType_UNSET E_OpenconfigBgpTypes_CommunityType = 0
	// OpenconfigBgpTypes_CommunityType_STANDARD corresponds to the value STANDARD of OpenconfigBgpTypes_CommunityType
	OpenconfigBgpTypes_CommunityType_STANDARD E_OpenconfigBgpTypes_CommunityType = 1
	// OpenconfigBgpTypes_CommunityType_EXTENDED corresponds to the value EXTENDED of OpenconfigBgpTypes_CommunityType
	OpenconfigBgpTypes_CommunityType_EXTENDED E_OpenconfigBgpTypes_CommunityType = 2
	// OpenconfigBgpTypes_CommunityType_BOTH corresponds to the value BOTH of OpenconfigBgpTypes_CommunityType
	OpenconfigBgpTypes_CommunityType_BOTH E_OpenconfigBgpTypes_CommunityType = 3
	// OpenconfigBgpTypes_CommunityType_NONE corresponds to the value NONE of OpenconfigBgpTypes_CommunityType
	OpenconfigBgpTypes_CommunityType_NONE E_OpenconfigBgpTypes_CommunityType = 4
)

// E_OpenconfigBgpTypes_PeerType is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_PeerType. An additional value named
// OpenconfigBgpTypes_PeerType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_PeerType int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_PeerType implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_PeerType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_PeerType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_PeerType.
func (E_OpenconfigBgpTypes_PeerType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigBgpTypes_PeerType.
func (e E_OpenconfigBgpTypes_PeerType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_PeerType")
}

const (
	// OpenconfigBgpTypes_PeerType_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_PeerType
	OpenconfigBgpTypes_PeerType_UNSET E_OpenconfigBgpTypes_PeerType = 0
	// OpenconfigBgpTypes_PeerType_INTERNAL corresponds to the value INTERNAL of OpenconfigBgpTypes_PeerType
	OpenconfigBgpTypes_PeerType_INTERNAL E_OpenconfigBgpTypes_PeerType = 1
	// OpenconfigBgpTypes_PeerType_EXTERNAL corresponds to the value EXTERNAL of OpenconfigBgpTypes_PeerType
	OpenconfigBgpTypes_PeerType_EXTERNAL E_OpenconfigBgpTypes_PeerType = 2
)

// E_OpenconfigBgpTypes_RemovePrivateAsOption is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_RemovePrivateAsOption. An additional value named
// OpenconfigBgpTypes_RemovePrivateAsOption_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_RemovePrivateAsOption int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_RemovePrivateAsOption implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_RemovePrivateAsOption can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_RemovePrivateAsOption) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_RemovePrivateAsOption.
func (E_OpenconfigBgpTypes_RemovePrivateAsOption) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_RemovePrivateAsOption.
func (e E_OpenconfigBgpTypes_RemovePrivateAsOption) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_RemovePrivateAsOption")
}

const (
	// OpenconfigBgpTypes_RemovePrivateAsOption_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_RemovePrivateAsOption
	OpenconfigBgpTypes_RemovePrivateAsOption_UNSET E_OpenconfigBgpTypes_RemovePrivateAsOption = 0
	// OpenconfigBgpTypes_RemovePrivateAsOption_PRIVATE_AS_REMOVE_ALL corresponds to the value PRIVATE_AS_REMOVE_ALL of OpenconfigBgpTypes_RemovePrivateAsOption
	OpenconfigBgpTypes_RemovePrivateAsOption_PRIVATE_AS_REMOVE_ALL E_OpenconfigBgpTypes_RemovePrivateAsOption = 1
	// OpenconfigBgpTypes_RemovePrivateAsOption_PRIVATE_AS_REPLACE_ALL corresponds to the value PRIVATE_AS_REPLACE_ALL of OpenconfigBgpTypes_RemovePrivateAsOption
	OpenconfigBgpTypes_RemovePrivateAsOption_PRIVATE_AS_REPLACE_ALL E_OpenconfigBgpTypes_RemovePrivateAsOption = 2
)

// E_OpenconfigIfAggregate_AggregationType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIfAggregate_AggregationType. An additional value named
// OpenconfigIfAggregate_AggregationType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIfAggregate_AggregationType int64

// IsYANGGoEnum ensures that OpenconfigIfAggregate_AggregationType implements the yang.GoEnum
// interface. This ensures that OpenconfigIfAggregate_AggregationType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIfAggregate_AggregationType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIfAggregate_AggregationType.
func (E_OpenconfigIfAggregate_AggregationType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIfAggregate_AggregationType.
func (e E_OpenconfigIfAggregate_AggregationType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIfAggregate_AggregationType")
}

const (
	// OpenconfigIfAggregate_AggregationType_UNSET corresponds to the value UNSET of OpenconfigIfAggregate_AggregationType
	OpenconfigIfAggregate_AggregationType_UNSET E_OpenconfigIfAggregate_AggregationType = 0
	// OpenconfigIfAggregate_AggregationType_LACP corresponds to the value LACP of OpenconfigIfAggregate_AggregationType
	OpenconfigIfAggregate_AggregationType_LACP E_OpenconfigIfAggregate_AggregationType = 1
	// OpenconfigIfAggregate_AggregationType_STATIC corresponds to the value STATIC of OpenconfigIfAggregate_AggregationType
	OpenconfigIfAggregate_AggregationType_STATIC E_OpenconfigIfAggregate_AggregationType = 2
)

// E_OpenconfigIfEthernet_ETHERNET_SPEED is a derived int64 type which is used to represent
// the enumerated node OpenconfigIfEthernet_ETHERNET_SPEED. An additional value named
// OpenconfigIfEthernet_ETHERNET_SPEED_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIfEthernet_ETHERNET_SPEED int64

// IsYANGGoEnum ensures that OpenconfigIfEthernet_ETHERNET_SPEED implements the yang.GoEnum
// interface. This ensures that OpenconfigIfEthernet_ETHERNET_SPEED can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIfEthernet_ETHERNET_SPEED) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIfEthernet_ETHERNET_SPEED.
func (E_OpenconfigIfEthernet_ETHERNET_SPEED) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIfEthernet_ETHERNET_SPEED.
func (e E_OpenconfigIfEthernet_ETHERNET_SPEED) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIfEthernet_ETHERNET_SPEED")
}

const (
	// OpenconfigIfEthernet_ETHERNET_SPEED_UNSET corresponds to the value UNSET of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_UNSET E_OpenconfigIfEthernet_ETHERNET_SPEED = 0
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_100GB corresponds to the value SPEED_100GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_100GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 1
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_100MB corresponds to the value SPEED_100MB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_100MB E_OpenconfigIfEthernet_ETHERNET_SPEED = 2
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_10GB corresponds to the value SPEED_10GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_10GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 3
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_10MB corresponds to the value SPEED_10MB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_10MB E_OpenconfigIfEthernet_ETHERNET_SPEED = 4
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_1GB corresponds to the value SPEED_1GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_1GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 5
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_200GB corresponds to the value SPEED_200GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_200GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 6
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_2500MB corresponds to the value SPEED_2500MB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_2500MB E_OpenconfigIfEthernet_ETHERNET_SPEED = 7
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_25GB corresponds to the value SPEED_25GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_25GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 8
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_400GB corresponds to the value SPEED_400GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_400GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 9
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_40GB corresponds to the value SPEED_40GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_40GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 10
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_50GB corresponds to the value SPEED_50GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_50GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 11
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_5GB corresponds to the value SPEED_5GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_5GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 12
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_600GB corresponds to the value SPEED_600GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_600GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 13
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_800GB corresponds to the value SPEED_800GB of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_800GB E_OpenconfigIfEthernet_ETHERNET_SPEED = 14
	// OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_UNKNOWN corresponds to the value SPEED_UNKNOWN of OpenconfigIfEthernet_ETHERNET_SPEED
	OpenconfigIfEthernet_ETHERNET_SPEED_SPEED_UNKNOWN E_OpenconfigIfEthernet_ETHERNET_SPEED = 15
)

// E_OpenconfigIfIp_IpAddressOrigin is a derived int64 type which is used to represent
// the enumerated node OpenconfigIfIp_IpAddressOrigin. An additional value named
// OpenconfigIfIp_IpAddressOrigin_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIfIp_IpAddressOrigin int64

// IsYANGGoEnum ensures that OpenconfigIfIp_IpAddressOrigin implements the yang.GoEnum
// interface. This ensures that OpenconfigIfIp_IpAddressOrigin can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIfIp_IpAddressOrigin) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIfIp_IpAddressOrigin.
func (E_OpenconfigIfIp_IpAddressOrigin) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIfIp_IpAddressOrigin.
func (e E_OpenconfigIfIp_IpAddressOrigin) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIfIp_IpAddressOrigin")
}

const (
	// OpenconfigIfIp_IpAddressOrigin_UNSET corresponds to the value UNSET of OpenconfigIfIp_IpAddressOrigin
	OpenconfigIfIp_IpAddressOrigin_UNSET E_OpenconfigIfIp_IpAddressOrigin = 0
	// OpenconfigIfIp_IpAddressOrigin_OTHER corresponds to the value OTHER of OpenconfigIfIp_IpAddressOrigin
	OpenconfigIfIp_IpAddressOrigin_OTHER E_OpenconfigIfIp_IpAddressOrigin = 1
	// OpenconfigIfIp_IpAddressOrigin_STATIC corresponds to the value STATIC of OpenconfigIfIp_IpAddressOrigin
	OpenconfigIfIp_IpAddressOrigin_STATIC E_OpenconfigIfIp_IpAddressOrigin = 2
	// OpenconfigIfIp_IpAddressOrigin_DHCP corresponds to the value DHCP of OpenconfigIfIp_IpAddressOrigin
	OpenconfigIfIp_IpAddressOrigin_DHCP E_OpenconfigIfIp_IpAddressOrigin = 3
	// OpenconfigIfIp_IpAddressOrigin_LINK_LAYER corresponds to the value LINK_LAYER of OpenconfigIfIp_IpAddressOrigin
	OpenconfigIfIp_IpAddressOrigin_LINK_LAYER E_OpenconfigIfIp_IpAddressOrigin = 4
	// OpenconfigIfIp_IpAddressOrigin_RANDOM corresponds to the value RANDOM of OpenconfigIfIp_IpAddressOrigin
	OpenconfigIfIp_IpAddressOrigin_RANDOM E_OpenconfigIfIp_IpAddressOrigin = 5
)

// E_OpenconfigIfIp_NeighborOrigin is a derived int64 type which is used to represent
// the enumerated node OpenconfigIfIp_NeighborOrigin. An additional value named
// OpenconfigIfIp_NeighborOrigin_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIfIp_NeighborOrigin int64

// IsYANGGoEnum ensures that OpenconfigIfIp_NeighborOrigin implements the yang.GoEnum
// interface. This ensures that OpenconfigIfIp_NeighborOrigin can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIfIp_NeighborOrigin) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIfIp_NeighborOrigin.
func (E_OpenconfigIfIp_NeighborOrigin) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIfIp_NeighborOrigin.
func (e E_OpenconfigIfIp_NeighborOrigin) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIfIp_NeighborOrigin")
}

const (
	// OpenconfigIfIp_NeighborOrigin_UNSET corresponds to the value UNSET of OpenconfigIfIp_NeighborOrigin
	OpenconfigIfIp_NeighborOrigin_UNSET E_OpenconfigIfIp_NeighborOrigin = 0
	// OpenconfigIfIp_NeighborOrigin_OTHER corresponds to the value OTHER of OpenconfigIfIp_NeighborOrigin
	OpenconfigIfIp_NeighborOrigin_OTHER E_OpenconfigIfIp_NeighborOrigin = 1
	// OpenconfigIfIp_NeighborOrigin_STATIC corresponds to the value STATIC of OpenconfigIfIp_NeighborOrigin
	OpenconfigIfIp_NeighborOrigin_STATIC E_OpenconfigIfIp_NeighborOrigin = 2
	// OpenconfigIfIp_NeighborOrigin_DYNAMIC corresponds to the value DYNAMIC of OpenconfigIfIp_NeighborOrigin
	OpenconfigIfIp_NeighborOrigin_DYNAMIC E_OpenconfigIfIp_NeighborOrigin = 3
)

// E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE. An additional value named
// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE.
func (E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE.
func (e E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE")
}

const (
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_UNSET E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 0
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV4_ROUTER_ID corresponds to the value IP_REACHABILITY_IPV4_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV4_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 1
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV6_ROUTER_ID corresponds to the value IP_REACHABILITY_IPV6_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV6_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 2
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_FLAGS corresponds to the value IP_REACHABILITY_PREFIX_FLAGS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_FLAGS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 3
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_SID corresponds to the value IP_REACHABILITY_PREFIX_SID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_SID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 4
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_SUBTLVS_TYPE corresponds to the value IP_REACHABILITY_SUBTLVS_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_SUBTLVS_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 5
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG corresponds to the value IP_REACHABILITY_TAG of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 6
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG64 corresponds to the value IP_REACHABILITY_TAG64 of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG64 E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 7
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_LAN_SID corresponds to the value IS_REACHABILITY_ADJ_LAN_SID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_LAN_SID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 8
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_SID corresponds to the value IS_REACHABILITY_ADJ_SID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_SID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 9
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADMIN_GROUP corresponds to the value IS_REACHABILITY_ADMIN_GROUP of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADMIN_GROUP E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 10
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_AVAILABLE_BANDWIDTH corresponds to the value IS_REACHABILITY_AVAILABLE_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_AVAILABLE_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 11
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_BANDWIDTH_CONSTRAINTS corresponds to the value IS_REACHABILITY_BANDWIDTH_CONSTRAINTS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_BANDWIDTH_CONSTRAINTS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 12
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_EXTENDED_ADMIN_GROUP corresponds to the value IS_REACHABILITY_EXTENDED_ADMIN_GROUP of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_EXTENDED_ADMIN_GROUP E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 13
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_INTERFACE_ADDRESS corresponds to the value IS_REACHABILITY_IPV4_INTERFACE_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_INTERFACE_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 14
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS corresponds to the value IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 15
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_INTERFACE_ADDRESS corresponds to the value IS_REACHABILITY_IPV6_INTERFACE_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_INTERFACE_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 16
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS corresponds to the value IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 17
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ATTRIBUTES corresponds to the value IS_REACHABILITY_LINK_ATTRIBUTES of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ATTRIBUTES E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 18
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY corresponds to the value IS_REACHABILITY_LINK_DELAY of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 19
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY_VARIATION corresponds to the value IS_REACHABILITY_LINK_DELAY_VARIATION of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY_VARIATION E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 20
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ID corresponds to the value IS_REACHABILITY_LINK_ID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 21
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_LOSS corresponds to the value IS_REACHABILITY_LINK_LOSS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_LOSS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 22
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_PROTECTION_TYPE corresponds to the value IS_REACHABILITY_LINK_PROTECTION_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_PROTECTION_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 23
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_LINK_BANDWIDTH corresponds to the value IS_REACHABILITY_MAX_LINK_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_LINK_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 24
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH corresponds to the value IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 25
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MIN_MAX_LINK_DELAY corresponds to the value IS_REACHABILITY_MIN_MAX_LINK_DELAY of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MIN_MAX_LINK_DELAY E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 26
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_RESIDUAL_BANDWIDTH corresponds to the value IS_REACHABILITY_RESIDUAL_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_RESIDUAL_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 27
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_SUBTLVS_TYPE corresponds to the value IS_REACHABILITY_SUBTLVS_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_SUBTLVS_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 28
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_TE_DEFAULT_METRIC corresponds to the value IS_REACHABILITY_TE_DEFAULT_METRIC of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_TE_DEFAULT_METRIC E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 29
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNCONSTRAINED_LSP corresponds to the value IS_REACHABILITY_UNCONSTRAINED_LSP of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNCONSTRAINED_LSP E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 30
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNRESERVED_BANDWIDTH corresponds to the value IS_REACHABILITY_UNRESERVED_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNRESERVED_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 31
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UTILIZED_BANDWIDTH corresponds to the value IS_REACHABILITY_UTILIZED_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UTILIZED_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 32
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_ALGORITHM corresponds to the value ROUTER_CAPABILITY_SR_ALGORITHM of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_ALGORITHM E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 33
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_CAPABILITY corresponds to the value ROUTER_CAPABILITY_SR_CAPABILITY of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_CAPABILITY E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 34
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SUBTLVS_TYPE corresponds to the value ROUTER_CAPABILITY_SUBTLVS_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SUBTLVS_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 35
)

// E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE. An additional value named
// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE.
func (E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE.
func (e E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE")
}

const (
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_UNSET E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 0
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AREA_ADDRESSES corresponds to the value AREA_ADDRESSES of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AREA_ADDRESSES E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 1
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AUTHENTICATION corresponds to the value AUTHENTICATION of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AUTHENTICATION E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 2
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_DYNAMIC_NAME corresponds to the value DYNAMIC_NAME of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_DYNAMIC_NAME E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 3
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IPV4_REACHABILITY corresponds to the value EXTENDED_IPV4_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IPV4_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 4
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IS_REACHABILITY corresponds to the value EXTENDED_IS_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IS_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 5
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IIS_NEIGHBORS corresponds to the value IIS_NEIGHBORS of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IIS_NEIGHBORS E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 6
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_INSTANCE_ID corresponds to the value INSTANCE_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_INSTANCE_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 7
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_EXTERNAL_REACHABILITY corresponds to the value IPV4_EXTERNAL_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_EXTERNAL_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 8
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERFACE_ADDRESSES corresponds to the value IPV4_INTERFACE_ADDRESSES of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERFACE_ADDRESSES E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 9
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERNAL_REACHABILITY corresponds to the value IPV4_INTERNAL_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERNAL_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 10
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_SRLG corresponds to the value IPV4_SRLG of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_SRLG E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 11
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_TE_ROUTER_ID corresponds to the value IPV4_TE_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_TE_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 12
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_INTERFACE_ADDRESSES corresponds to the value IPV6_INTERFACE_ADDRESSES of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_INTERFACE_ADDRESSES E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 13
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_REACHABILITY corresponds to the value IPV6_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 14
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_SRLG corresponds to the value IPV6_SRLG of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_SRLG E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 15
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_TE_ROUTER_ID corresponds to the value IPV6_TE_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_TE_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 16
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ISIS_ALIAS_ID corresponds to the value ISIS_ALIAS_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ISIS_ALIAS_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 17
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IS_NEIGHBOR_ATTRIBUTE corresponds to the value IS_NEIGHBOR_ATTRIBUTE of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IS_NEIGHBOR_ATTRIBUTE E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 18
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_LSP_BUFFER_SIZE corresponds to the value LSP_BUFFER_SIZE of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_LSP_BUFFER_SIZE E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 19
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV4_REACHABILITY corresponds to the value MT_IPV4_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV4_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 20
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV6_REACHABILITY corresponds to the value MT_IPV6_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV6_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 21
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_ISN corresponds to the value MT_ISN of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_ISN E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 22
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IS_NEIGHBOR_ATTRIBUTE corresponds to the value MT_IS_NEIGHBOR_ATTRIBUTE of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IS_NEIGHBOR_ATTRIBUTE E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 23
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MULTI_TOPOLOGY corresponds to the value MULTI_TOPOLOGY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MULTI_TOPOLOGY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 24
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_NLPID corresponds to the value NLPID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_NLPID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 25
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_PURGE_OI corresponds to the value PURGE_OI of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_PURGE_OI E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 26
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ROUTER_CAPABILITY corresponds to the value ROUTER_CAPABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ROUTER_CAPABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 27
)

// E_OpenconfigIsisTypes_AFI_SAFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_AFI_SAFI_TYPE. An additional value named
// OpenconfigIsisTypes_AFI_SAFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_AFI_SAFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_AFI_SAFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_AFI_SAFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_AFI_SAFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_AFI_SAFI_TYPE.
func (E_OpenconfigIsisTypes_AFI_SAFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_AFI_SAFI_TYPE.
func (e E_OpenconfigIsisTypes_AFI_SAFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_AFI_SAFI_TYPE")
}

const (
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_UNSET E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 0
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_MULTICAST corresponds to the value IPV4_MULTICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_MULTICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 1
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_UNICAST corresponds to the value IPV4_UNICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_UNICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 2
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_MULTICAST corresponds to the value IPV6_MULTICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_MULTICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 3
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_UNICAST corresponds to the value IPV6_UNICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_UNICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 4
)

// E_OpenconfigIsisTypes_AFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_AFI_TYPE. An additional value named
// OpenconfigIsisTypes_AFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_AFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_AFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_AFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_AFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_AFI_TYPE.
func (E_OpenconfigIsisTypes_AFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigIsisTypes_AFI_TYPE.
func (e E_OpenconfigIsisTypes_AFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_AFI_TYPE")
}

const (
	// OpenconfigIsisTypes_AFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_AFI_TYPE
	OpenconfigIsisTypes_AFI_TYPE_UNSET E_OpenconfigIsisTypes_AFI_TYPE = 0
	// OpenconfigIsisTypes_AFI_TYPE_IPV4 corresponds to the value IPV4 of OpenconfigIsisTypes_AFI_TYPE
	OpenconfigIsisTypes_AFI_TYPE_IPV4 E_OpenconfigIsisTypes_AFI_TYPE = 1
	// OpenconfigIsisTypes_AFI_TYPE_IPV6 corresponds to the value IPV6 of OpenconfigIsisTypes_AFI_TYPE
	OpenconfigIsisTypes_AFI_TYPE_IPV6 E_OpenconfigIsisTypes_AFI_TYPE = 2
)

// E_OpenconfigIsisTypes_AdaptiveTimerType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_AdaptiveTimerType. An additional value named
// OpenconfigIsisTypes_AdaptiveTimerType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_AdaptiveTimerType int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_AdaptiveTimerType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_AdaptiveTimerType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_AdaptiveTimerType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_AdaptiveTimerType.
func (E_OpenconfigIsisTypes_AdaptiveTimerType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_AdaptiveTimerType.
func (e E_OpenconfigIsisTypes_AdaptiveTimerType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_AdaptiveTimerType")
}

const (
	// OpenconfigIsisTypes_AdaptiveTimerType_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_AdaptiveTimerType
	OpenconfigIsisTypes_AdaptiveTimerType_UNSET E_OpenconfigIsisTypes_AdaptiveTimerType = 0
	// OpenconfigIsisTypes_AdaptiveTimerType_LINEAR corresponds to the value LINEAR of OpenconfigIsisTypes_AdaptiveTimerType
	OpenconfigIsisTypes_AdaptiveTimerType_LINEAR E_OpenconfigIsisTypes_AdaptiveTimerType = 1
	// OpenconfigIsisTypes_AdaptiveTimerType_EXPONENTIAL corresponds to the value EXPONENTIAL of OpenconfigIsisTypes_AdaptiveTimerType
	OpenconfigIsisTypes_AdaptiveTimerType_EXPONENTIAL E_OpenconfigIsisTypes_AdaptiveTimerType = 2
)

// E_OpenconfigIsisTypes_CircuitType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_CircuitType. An additional value named
// OpenconfigIsisTypes_CircuitType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_CircuitType int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_CircuitType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_CircuitType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_CircuitType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_CircuitType.
func (E_OpenconfigIsisTypes_CircuitType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_CircuitType.
func (e E_OpenconfigIsisTypes_CircuitType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_CircuitType")
}

const (
	// OpenconfigIsisTypes_CircuitType_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_CircuitType
	OpenconfigIsisTypes_CircuitType_UNSET E_OpenconfigIsisTypes_CircuitType = 0
	// OpenconfigIsisTypes_CircuitType_POINT_TO_POINT corresponds to the value POINT_TO_POINT of OpenconfigIsisTypes_CircuitType
	OpenconfigIsisTypes_CircuitType_POINT_TO_POINT E_OpenconfigIsisTypes_CircuitType = 1
	// OpenconfigIsisTypes_CircuitType_BROADCAST corresponds to the value BROADCAST of OpenconfigIsisTypes_CircuitType
	OpenconfigIsisTypes_CircuitType_BROADCAST E_OpenconfigIsisTypes_CircuitType = 2
)

// E_OpenconfigIsisTypes_HelloPaddingType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_HelloPaddingType. An additional value named
// OpenconfigIsisTypes_HelloPaddingType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_HelloPaddingType int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_HelloPaddingType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_HelloPaddingType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_HelloPaddingType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_HelloPaddingType.
func (E_OpenconfigIsisTypes_HelloPaddingType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_HelloPaddingType.
func (e E_OpenconfigIsisTypes_HelloPaddingType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_HelloPaddingType")
}

const (
	// OpenconfigIsisTypes_HelloPaddingType_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_HelloPaddingType
	OpenconfigIsisTypes_HelloPaddingType_UNSET E_OpenconfigIsisTypes_HelloPaddingType = 0
	// OpenconfigIsisTypes_HelloPaddingType_STRICT corresponds to the value STRICT of OpenconfigIsisTypes_HelloPaddingType
	OpenconfigIsisTypes_HelloPaddingType_STRICT E_OpenconfigIsisTypes_HelloPaddingType = 1
	// OpenconfigIsisTypes_HelloPaddingType_LOOSE corresponds to the value LOOSE of OpenconfigIsisTypes_HelloPaddingType
	OpenconfigIsisTypes_HelloPaddingType_LOOSE E_OpenconfigIsisTypes_HelloPaddingType = 2
	// OpenconfigIsisTypes_HelloPaddingType_ADAPTIVE corresponds to the value ADAPTIVE of OpenconfigIsisTypes_HelloPaddingType
	OpenconfigIsisTypes_HelloPaddingType_ADAPTIVE E_OpenconfigIsisTypes_HelloPaddingType = 3
	// OpenconfigIsisTypes_HelloPaddingType_DISABLE corresponds to the value DISABLE of OpenconfigIsisTypes_HelloPaddingType
	OpenconfigIsisTypes_HelloPaddingType_DISABLE E_OpenconfigIsisTypes_HelloPaddingType = 4
)

// E_OpenconfigIsisTypes_IsisInterfaceAdjState is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_IsisInterfaceAdjState. An additional value named
// OpenconfigIsisTypes_IsisInterfaceAdjState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_IsisInterfaceAdjState int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_IsisInterfaceAdjState implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_IsisInterfaceAdjState can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_IsisInterfaceAdjState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_IsisInterfaceAdjState.
func (E_OpenconfigIsisTypes_IsisInterfaceAdjState) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_IsisInterfaceAdjState.
func (e E_OpenconfigIsisTypes_IsisInterfaceAdjState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_IsisInterfaceAdjState")
}

const (
	// OpenconfigIsisTypes_IsisInterfaceAdjState_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_IsisInterfaceAdjState
	OpenconfigIsisTypes_IsisInterfaceAdjState_UNSET E_OpenconfigIsisTypes_IsisInterfaceAdjState = 0
	// OpenconfigIsisTypes_IsisInterfaceAdjState_UP corresponds to the value UP of OpenconfigIsisTypes_IsisInterfaceAdjState
	OpenconfigIsisTypes_IsisInterfaceAdjState_UP E_OpenconfigIsisTypes_IsisInterfaceAdjState = 1
	// OpenconfigIsisTypes_IsisInterfaceAdjState_DOWN corresponds to the value DOWN of OpenconfigIsisTypes_IsisInterfaceAdjState
	OpenconfigIsisTypes_IsisInterfaceAdjState_DOWN E_OpenconfigIsisTypes_IsisInterfaceAdjState = 2
	// OpenconfigIsisTypes_IsisInterfaceAdjState_INIT corresponds to the value INIT of OpenconfigIsisTypes_IsisInterfaceAdjState
	OpenconfigIsisTypes_IsisInterfaceAdjState_INIT E_OpenconfigIsisTypes_IsisInterfaceAdjState = 3
	// OpenconfigIsisTypes_IsisInterfaceAdjState_FAILED corresponds to the value FAILED of OpenconfigIsisTypes_IsisInterfaceAdjState
	OpenconfigIsisTypes_IsisInterfaceAdjState_FAILED E_OpenconfigIsisTypes_IsisInterfaceAdjState = 4
)

// E_OpenconfigIsisTypes_LevelType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_LevelType. An additional value named
// OpenconfigIsisTypes_LevelType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_LevelType int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_LevelType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_LevelType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_LevelType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_LevelType.
func (E_OpenconfigIsisTypes_LevelType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_LevelType.
func (e E_OpenconfigIsisTypes_LevelType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_LevelType")
}

const (
	// OpenconfigIsisTypes_LevelType_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_LevelType
	OpenconfigIsisTypes_LevelType_UNSET E_OpenconfigIsisTypes_LevelType = 0
	// OpenconfigIsisTypes_LevelType_LEVEL_1 corresponds to the value LEVEL_1 of OpenconfigIsisTypes_LevelType
	OpenconfigIsisTypes_LevelType_LEVEL_1 E_OpenconfigIsisTypes_LevelType = 1
	// OpenconfigIsisTypes_LevelType_LEVEL_2 corresponds to the value LEVEL_2 of OpenconfigIsisTypes_LevelType
	OpenconfigIsisTypes_LevelType_LEVEL_2 E_OpenconfigIsisTypes_LevelType = 2
	// OpenconfigIsisTypes_LevelType_LEVEL_1_2 corresponds to the value LEVEL_1_2 of OpenconfigIsisTypes_LevelType
	OpenconfigIsisTypes_LevelType_LEVEL_1_2 E_OpenconfigIsisTypes_LevelType = 3
)

// E_OpenconfigIsisTypes_MetricStyle is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_MetricStyle. An additional value named
// OpenconfigIsisTypes_MetricStyle_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_MetricStyle int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_MetricStyle implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_MetricStyle can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_MetricStyle) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_MetricStyle.
func (E_OpenconfigIsisTypes_MetricStyle) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_MetricStyle.
func (e E_OpenconfigIsisTypes_MetricStyle) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_MetricStyle")
}

const (
	// OpenconfigIsisTypes_MetricStyle_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_MetricStyle
	OpenconfigIsisTypes_MetricStyle_UNSET E_OpenconfigIsisTypes_MetricStyle = 0
	// OpenconfigIsisTypes_MetricStyle_NARROW_METRIC corresponds to the value NARROW_METRIC of OpenconfigIsisTypes_MetricStyle
	OpenconfigIsisTypes_MetricStyle_NARROW_METRIC E_OpenconfigIsisTypes_MetricStyle = 1
	// OpenconfigIsisTypes_MetricStyle_WIDE_METRIC corresponds to the value WIDE_METRIC of OpenconfigIsisTypes_MetricStyle
	OpenconfigIsisTypes_MetricStyle_WIDE_METRIC E_OpenconfigIsisTypes_MetricStyle = 2
)

// E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE. An additional value named
// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE.
func (E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE.
func (e E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE")
}

const (
	// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE
	OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_UNSET E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE = 0
	// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_BGP corresponds to the value WAIT_FOR_BGP of OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE
	OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_BGP E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE = 1
	// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_SYSTEM corresponds to the value WAIT_FOR_SYSTEM of OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE
	OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_SYSTEM E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE = 2
)

// E_OpenconfigIsisTypes_SAFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_SAFI_TYPE. An additional value named
// OpenconfigIsisTypes_SAFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_SAFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_SAFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_SAFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_SAFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_SAFI_TYPE.
func (E_OpenconfigIsisTypes_SAFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_SAFI_TYPE.
func (e E_OpenconfigIsisTypes_SAFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_SAFI_TYPE")
}

const (
	// OpenconfigIsisTypes_SAFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_SAFI_TYPE
	OpenconfigIsisTypes_SAFI_TYPE_UNSET E_OpenconfigIsisTypes_SAFI_TYPE = 0
	// OpenconfigIsisTypes_SAFI_TYPE_MULTICAST corresponds to the value MULTICAST of OpenconfigIsisTypes_SAFI_TYPE
	OpenconfigIsisTypes_SAFI_TYPE_MULTICAST E_OpenconfigIsisTypes_SAFI_TYPE = 1
	// OpenconfigIsisTypes_SAFI_TYPE_UNICAST corresponds to the value UNICAST of OpenconfigIsisTypes_SAFI_TYPE
	OpenconfigIsisTypes_SAFI_TYPE_UNICAST E_OpenconfigIsisTypes_SAFI_TYPE = 2
)

// E_OpenconfigIsis_IsisMetricFlags is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_IsisMetricFlags. An additional value named
// OpenconfigIsis_IsisMetricFlags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_IsisMetricFlags int64

// IsYANGGoEnum ensures that OpenconfigIsis_IsisMetricFlags implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_IsisMetricFlags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_IsisMetricFlags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_IsisMetricFlags.
func (E_OpenconfigIsis_IsisMetricFlags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsis_IsisMetricFlags.
func (e E_OpenconfigIsis_IsisMetricFlags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_IsisMetricFlags")
}

const (
	// OpenconfigIsis_IsisMetricFlags_UNSET corresponds to the value UNSET of OpenconfigIsis_IsisMetricFlags
	OpenconfigIsis_IsisMetricFlags_UNSET E_OpenconfigIsis_IsisMetricFlags = 0
	// OpenconfigIsis_IsisMetricFlags_INTERNAL corresponds to the value INTERNAL of OpenconfigIsis_IsisMetricFlags
	OpenconfigIsis_IsisMetricFlags_INTERNAL E_OpenconfigIsis_IsisMetricFlags = 1
	// OpenconfigIsis_IsisMetricFlags_UNSUPPORTED corresponds to the value UNSUPPORTED of OpenconfigIsis_IsisMetricFlags
	OpenconfigIsis_IsisMetricFlags_UNSUPPORTED E_OpenconfigIsis_IsisMetricFlags = 2
)

// E_OpenconfigLacp_LacpActivityType is a derived int64 type which is used to represent
// the enumerated node OpenconfigLacp_LacpActivityType. An additional value named
// OpenconfigLacp_LacpActivityType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLacp_LacpActivityType int64

// IsYANGGoEnum ensures that OpenconfigLacp_LacpActivityType implements the yang.GoEnum
// interface. This ensures that OpenconfigLacp_LacpActivityType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLacp_LacpActivityType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLacp_LacpActivityType.
func (E_OpenconfigLacp_LacpActivityType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLacp_LacpActivityType.
func (e E_OpenconfigLacp_LacpActivityType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLacp_LacpActivityType")
}

const (
	// OpenconfigLacp_LacpActivityType_UNSET corresponds to the value UNSET of OpenconfigLacp_LacpActivityType
	OpenconfigLacp_LacpActivityType_UNSET E_OpenconfigLacp_LacpActivityType = 0
	// OpenconfigLacp_LacpActivityType_ACTIVE corresponds to the value ACTIVE of OpenconfigLacp_LacpActivityType
	OpenconfigLacp_LacpActivityType_ACTIVE E_OpenconfigLacp_LacpActivityType = 1
	// OpenconfigLacp_LacpActivityType_PASSIVE corresponds to the value PASSIVE of OpenconfigLacp_LacpActivityType
	OpenconfigLacp_LacpActivityType_PASSIVE E_OpenconfigLacp_LacpActivityType = 2
)

// E_OpenconfigLacp_LacpPeriodType is a derived int64 type which is used to represent
// the enumerated node OpenconfigLacp_LacpPeriodType. An additional value named
// OpenconfigLacp_LacpPeriodType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLacp_LacpPeriodType int64

// IsYANGGoEnum ensures that OpenconfigLacp_LacpPeriodType implements the yang.GoEnum
// interface. This ensures that OpenconfigLacp_LacpPeriodType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLacp_LacpPeriodType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLacp_LacpPeriodType.
func (E_OpenconfigLacp_LacpPeriodType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLacp_LacpPeriodType.
func (e E_OpenconfigLacp_LacpPeriodType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLacp_LacpPeriodType")
}

const (
	// OpenconfigLacp_LacpPeriodType_UNSET corresponds to the value UNSET of OpenconfigLacp_LacpPeriodType
	OpenconfigLacp_LacpPeriodType_UNSET E_OpenconfigLacp_LacpPeriodType = 0
	// OpenconfigLacp_LacpPeriodType_FAST corresponds to the value FAST of OpenconfigLacp_LacpPeriodType
	OpenconfigLacp_LacpPeriodType_FAST E_OpenconfigLacp_LacpPeriodType = 1
	// OpenconfigLacp_LacpPeriodType_SLOW corresponds to the value SLOW of OpenconfigLacp_LacpPeriodType
	OpenconfigLacp_LacpPeriodType_SLOW E_OpenconfigLacp_LacpPeriodType = 2
)

// E_OpenconfigLacp_LacpSynchronizationType is a derived int64 type which is used to represent
// the enumerated node OpenconfigLacp_LacpSynchronizationType. An additional value named
// OpenconfigLacp_LacpSynchronizationType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLacp_LacpSynchronizationType int64

// IsYANGGoEnum ensures that OpenconfigLacp_LacpSynchronizationType implements the yang.GoEnum
// interface. This ensures that OpenconfigLacp_LacpSynchronizationType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLacp_LacpSynchronizationType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLacp_LacpSynchronizationType.
func (E_OpenconfigLacp_LacpSynchronizationType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLacp_LacpSynchronizationType.
func (e E_OpenconfigLacp_LacpSynchronizationType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLacp_LacpSynchronizationType")
}

const (
	// OpenconfigLacp_LacpSynchronizationType_UNSET corresponds to the value UNSET of OpenconfigLacp_LacpSynchronizationType
	OpenconfigLacp_LacpSynchronizationType_UNSET E_OpenconfigLacp_LacpSynchronizationType = 0
	// OpenconfigLacp_LacpSynchronizationType_IN_SYNC corresponds to the value IN_SYNC of OpenconfigLacp_LacpSynchronizationType
	OpenconfigLacp_LacpSynchronizationType_IN_SYNC E_OpenconfigLacp_LacpSynchronizationType = 1
	// OpenconfigLacp_LacpSynchronizationType_OUT_SYNC corresponds to the value OUT_SYNC of OpenconfigLacp_LacpSynchronizationType
	OpenconfigLacp_LacpSynchronizationType_OUT_SYNC E_OpenconfigLacp_LacpSynchronizationType = 2
)

// E_OpenconfigLacp_LacpTimeoutType is a derived int64 type which is used to represent
// the enumerated node OpenconfigLacp_LacpTimeoutType. An additional value named
// OpenconfigLacp_LacpTimeoutType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLacp_LacpTimeoutType int64

// IsYANGGoEnum ensures that OpenconfigLacp_LacpTimeoutType implements the yang.GoEnum
// interface. This ensures that OpenconfigLacp_LacpTimeoutType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLacp_LacpTimeoutType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLacp_LacpTimeoutType.
func (E_OpenconfigLacp_LacpTimeoutType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLacp_LacpTimeoutType.
func (e E_OpenconfigLacp_LacpTimeoutType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLacp_LacpTimeoutType")
}

const (
	// OpenconfigLacp_LacpTimeoutType_UNSET corresponds to the value UNSET of OpenconfigLacp_LacpTimeoutType
	OpenconfigLacp_LacpTimeoutType_UNSET E_OpenconfigLacp_LacpTimeoutType = 0
	// OpenconfigLacp_LacpTimeoutType_LONG corresponds to the value LONG of OpenconfigLacp_LacpTimeoutType
	OpenconfigLacp_LacpTimeoutType_LONG E_OpenconfigLacp_LacpTimeoutType = 1
	// OpenconfigLacp_LacpTimeoutType_SHORT corresponds to the value SHORT of OpenconfigLacp_LacpTimeoutType
	OpenconfigLacp_LacpTimeoutType_SHORT E_OpenconfigLacp_LacpTimeoutType = 2
)

// E_OpenconfigLldpTypes_ChassisIdType is a derived int64 type which is used to represent
// the enumerated node OpenconfigLldpTypes_ChassisIdType. An additional value named
// OpenconfigLldpTypes_ChassisIdType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLldpTypes_ChassisIdType int64

// IsYANGGoEnum ensures that OpenconfigLldpTypes_ChassisIdType implements the yang.GoEnum
// interface. This ensures that OpenconfigLldpTypes_ChassisIdType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLldpTypes_ChassisIdType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLldpTypes_ChassisIdType.
func (E_OpenconfigLldpTypes_ChassisIdType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLldpTypes_ChassisIdType.
func (e E_OpenconfigLldpTypes_ChassisIdType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLldpTypes_ChassisIdType")
}

const (
	// OpenconfigLldpTypes_ChassisIdType_UNSET corresponds to the value UNSET of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_UNSET E_OpenconfigLldpTypes_ChassisIdType = 0
	// OpenconfigLldpTypes_ChassisIdType_CHASSIS_COMPONENT corresponds to the value CHASSIS_COMPONENT of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_CHASSIS_COMPONENT E_OpenconfigLldpTypes_ChassisIdType = 1
	// OpenconfigLldpTypes_ChassisIdType_INTERFACE_ALIAS corresponds to the value INTERFACE_ALIAS of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_INTERFACE_ALIAS E_OpenconfigLldpTypes_ChassisIdType = 2
	// OpenconfigLldpTypes_ChassisIdType_PORT_COMPONENT corresponds to the value PORT_COMPONENT of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_PORT_COMPONENT E_OpenconfigLldpTypes_ChassisIdType = 3
	// OpenconfigLldpTypes_ChassisIdType_MAC_ADDRESS corresponds to the value MAC_ADDRESS of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_MAC_ADDRESS E_OpenconfigLldpTypes_ChassisIdType = 4
	// OpenconfigLldpTypes_ChassisIdType_NETWORK_ADDRESS corresponds to the value NETWORK_ADDRESS of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_NETWORK_ADDRESS E_OpenconfigLldpTypes_ChassisIdType = 5
	// OpenconfigLldpTypes_ChassisIdType_INTERFACE_NAME corresponds to the value INTERFACE_NAME of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_INTERFACE_NAME E_OpenconfigLldpTypes_ChassisIdType = 6
	// OpenconfigLldpTypes_ChassisIdType_LOCAL corresponds to the value LOCAL of OpenconfigLldpTypes_ChassisIdType
	OpenconfigLldpTypes_ChassisIdType_LOCAL E_OpenconfigLldpTypes_ChassisIdType = 7
)

// E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY. An additional value named
// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY int64

// IsYANGGoEnum ensures that OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY.
func (E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY.
func (e E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY")
}

const (
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_UNSET corresponds to the value UNSET of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_UNSET E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 0
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_C_VLAN corresponds to the value C_VLAN of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_C_VLAN E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 1
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_DOCSIS_CABLE_DEVICE corresponds to the value DOCSIS_CABLE_DEVICE of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_DOCSIS_CABLE_DEVICE E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 2
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_MAC_BRIDGE corresponds to the value MAC_BRIDGE of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_MAC_BRIDGE E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 3
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_OTHER corresponds to the value OTHER of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_OTHER E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 4
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_REPEATER corresponds to the value REPEATER of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_REPEATER E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 5
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_ROUTER corresponds to the value ROUTER of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_ROUTER E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 6
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_STATION_ONLY corresponds to the value STATION_ONLY of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_STATION_ONLY E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 7
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_S_VLAN corresponds to the value S_VLAN of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_S_VLAN E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 8
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_TELEPHONE corresponds to the value TELEPHONE of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_TELEPHONE E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 9
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_TWO_PORT_MAC_RELAY corresponds to the value TWO_PORT_MAC_RELAY of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_TWO_PORT_MAC_RELAY E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 10
	// OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_WLAN_ACCESS_POINT corresponds to the value WLAN_ACCESS_POINT of OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY
	OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY_WLAN_ACCESS_POINT E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY = 11
)

// E_OpenconfigLldpTypes_LLDP_TLV is a derived int64 type which is used to represent
// the enumerated node OpenconfigLldpTypes_LLDP_TLV. An additional value named
// OpenconfigLldpTypes_LLDP_TLV_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLldpTypes_LLDP_TLV int64

// IsYANGGoEnum ensures that OpenconfigLldpTypes_LLDP_TLV implements the yang.GoEnum
// interface. This ensures that OpenconfigLldpTypes_LLDP_TLV can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLldpTypes_LLDP_TLV) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLldpTypes_LLDP_TLV.
func (E_OpenconfigLldpTypes_LLDP_TLV) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigLldpTypes_LLDP_TLV.
func (e E_OpenconfigLldpTypes_LLDP_TLV) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLldpTypes_LLDP_TLV")
}

const (
	// OpenconfigLldpTypes_LLDP_TLV_UNSET corresponds to the value UNSET of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_UNSET E_OpenconfigLldpTypes_LLDP_TLV = 0
	// OpenconfigLldpTypes_LLDP_TLV_CHASSIS_ID corresponds to the value CHASSIS_ID of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_CHASSIS_ID E_OpenconfigLldpTypes_LLDP_TLV = 1
	// OpenconfigLldpTypes_LLDP_TLV_MANAGEMENT_ADDRESS corresponds to the value MANAGEMENT_ADDRESS of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_MANAGEMENT_ADDRESS E_OpenconfigLldpTypes_LLDP_TLV = 2
	// OpenconfigLldpTypes_LLDP_TLV_PORT_DESCRIPTION corresponds to the value PORT_DESCRIPTION of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_PORT_DESCRIPTION E_OpenconfigLldpTypes_LLDP_TLV = 3
	// OpenconfigLldpTypes_LLDP_TLV_PORT_ID corresponds to the value PORT_ID of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_PORT_ID E_OpenconfigLldpTypes_LLDP_TLV = 4
	// OpenconfigLldpTypes_LLDP_TLV_SYSTEM_CAPABILITIES corresponds to the value SYSTEM_CAPABILITIES of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_SYSTEM_CAPABILITIES E_OpenconfigLldpTypes_LLDP_TLV = 5
	// OpenconfigLldpTypes_LLDP_TLV_SYSTEM_DESCRIPTION corresponds to the value SYSTEM_DESCRIPTION of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_SYSTEM_DESCRIPTION E_OpenconfigLldpTypes_LLDP_TLV = 6
	// OpenconfigLldpTypes_LLDP_TLV_SYSTEM_NAME corresponds to the value SYSTEM_NAME of OpenconfigLldpTypes_LLDP_TLV
	OpenconfigLldpTypes_LLDP_TLV_SYSTEM_NAME E_OpenconfigLldpTypes_LLDP_TLV = 7
)

// E_OpenconfigLldpTypes_PortIdType is a derived int64 type which is used to represent
// the enumerated node OpenconfigLldpTypes_PortIdType. An additional value named
// OpenconfigLldpTypes_PortIdType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLldpTypes_PortIdType int64

// IsYANGGoEnum ensures that OpenconfigLldpTypes_PortIdType implements the yang.GoEnum
// interface. This ensures that OpenconfigLldpTypes_PortIdType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLldpTypes_PortIdType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLldpTypes_PortIdType.
func (E_OpenconfigLldpTypes_PortIdType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLldpTypes_PortIdType.
func (e E_OpenconfigLldpTypes_PortIdType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLldpTypes_PortIdType")
}

const (
	// OpenconfigLldpTypes_PortIdType_UNSET corresponds to the value UNSET of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_UNSET E_OpenconfigLldpTypes_PortIdType = 0
	// OpenconfigLldpTypes_PortIdType_INTERFACE_ALIAS corresponds to the value INTERFACE_ALIAS of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_INTERFACE_ALIAS E_OpenconfigLldpTypes_PortIdType = 1
	// OpenconfigLldpTypes_PortIdType_PORT_COMPONENT corresponds to the value PORT_COMPONENT of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_PORT_COMPONENT E_OpenconfigLldpTypes_PortIdType = 2
	// OpenconfigLldpTypes_PortIdType_MAC_ADDRESS corresponds to the value MAC_ADDRESS of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_MAC_ADDRESS E_OpenconfigLldpTypes_PortIdType = 3
	// OpenconfigLldpTypes_PortIdType_NETWORK_ADDRESS corresponds to the value NETWORK_ADDRESS of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_NETWORK_ADDRESS E_OpenconfigLldpTypes_PortIdType = 4
	// OpenconfigLldpTypes_PortIdType_INTERFACE_NAME corresponds to the value INTERFACE_NAME of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_INTERFACE_NAME E_OpenconfigLldpTypes_PortIdType = 5
	// OpenconfigLldpTypes_PortIdType_AGENT_CIRCUIT_ID corresponds to the value AGENT_CIRCUIT_ID of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_AGENT_CIRCUIT_ID E_OpenconfigLldpTypes_PortIdType = 6
	// OpenconfigLldpTypes_PortIdType_LOCAL corresponds to the value LOCAL of OpenconfigLldpTypes_PortIdType
	OpenconfigLldpTypes_PortIdType_LOCAL E_OpenconfigLldpTypes_PortIdType = 7
)

// E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP is a derived int64 type which is used to represent
// the enumerated node OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP. An additional value named
// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP int64

// IsYANGGoEnum ensures that OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP implements the yang.GoEnum
// interface. This ensures that OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP.
func (E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP.
func (e E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP")
}

const (
	// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_UNSET corresponds to the value UNSET of OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
	OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_UNSET E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP = 0
	// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_DROP corresponds to the value DROP of OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
	OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_DROP E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP = 1
	// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_LOCAL_LINK corresponds to the value LOCAL_LINK of OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
	OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_LOCAL_LINK E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP = 2
)

// E_OpenconfigMessages_DEBUG_SERVICE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMessages_DEBUG_SERVICE. An additional value named
// OpenconfigMessages_DEBUG_SERVICE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMessages_DEBUG_SERVICE int64

// IsYANGGoEnum ensures that OpenconfigMessages_DEBUG_SERVICE implements the yang.GoEnum
// interface. This ensures that OpenconfigMessages_DEBUG_SERVICE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMessages_DEBUG_SERVICE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMessages_DEBUG_SERVICE.
func (E_OpenconfigMessages_DEBUG_SERVICE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMessages_DEBUG_SERVICE.
func (e E_OpenconfigMessages_DEBUG_SERVICE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMessages_DEBUG_SERVICE")
}

const (
	// OpenconfigMessages_DEBUG_SERVICE_UNSET corresponds to the value UNSET of OpenconfigMessages_DEBUG_SERVICE
	OpenconfigMessages_DEBUG_SERVICE_UNSET E_OpenconfigMessages_DEBUG_SERVICE = 0
)

// E_OpenconfigMplsLdp_MplsLdpAdjacencyType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsLdp_MplsLdpAdjacencyType. An additional value named
// OpenconfigMplsLdp_MplsLdpAdjacencyType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsLdp_MplsLdpAdjacencyType int64

// IsYANGGoEnum ensures that OpenconfigMplsLdp_MplsLdpAdjacencyType implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsLdp_MplsLdpAdjacencyType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsLdp_MplsLdpAdjacencyType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsLdp_MplsLdpAdjacencyType.
func (E_OpenconfigMplsLdp_MplsLdpAdjacencyType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsLdp_MplsLdpAdjacencyType.
func (e E_OpenconfigMplsLdp_MplsLdpAdjacencyType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsLdp_MplsLdpAdjacencyType")
}

const (
	// OpenconfigMplsLdp_MplsLdpAdjacencyType_UNSET corresponds to the value UNSET of OpenconfigMplsLdp_MplsLdpAdjacencyType
	OpenconfigMplsLdp_MplsLdpAdjacencyType_UNSET E_OpenconfigMplsLdp_MplsLdpAdjacencyType = 0
	// OpenconfigMplsLdp_MplsLdpAdjacencyType_LINK corresponds to the value LINK of OpenconfigMplsLdp_MplsLdpAdjacencyType
	OpenconfigMplsLdp_MplsLdpAdjacencyType_LINK E_OpenconfigMplsLdp_MplsLdpAdjacencyType = 1
	// OpenconfigMplsLdp_MplsLdpAdjacencyType_TARGETED corresponds to the value TARGETED of OpenconfigMplsLdp_MplsLdpAdjacencyType
	OpenconfigMplsLdp_MplsLdpAdjacencyType_TARGETED E_OpenconfigMplsLdp_MplsLdpAdjacencyType = 2
)

// E_OpenconfigMplsLdp_MplsLdpAfi is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsLdp_MplsLdpAfi. An additional value named
// OpenconfigMplsLdp_MplsLdpAfi_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsLdp_MplsLdpAfi int64

// IsYANGGoEnum ensures that OpenconfigMplsLdp_MplsLdpAfi implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsLdp_MplsLdpAfi can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsLdp_MplsLdpAfi) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsLdp_MplsLdpAfi.
func (E_OpenconfigMplsLdp_MplsLdpAfi) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigMplsLdp_MplsLdpAfi.
func (e E_OpenconfigMplsLdp_MplsLdpAfi) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsLdp_MplsLdpAfi")
}

const (
	// OpenconfigMplsLdp_MplsLdpAfi_UNSET corresponds to the value UNSET of OpenconfigMplsLdp_MplsLdpAfi
	OpenconfigMplsLdp_MplsLdpAfi_UNSET E_OpenconfigMplsLdp_MplsLdpAfi = 0
	// OpenconfigMplsLdp_MplsLdpAfi_IPV4 corresponds to the value IPV4 of OpenconfigMplsLdp_MplsLdpAfi
	OpenconfigMplsLdp_MplsLdpAfi_IPV4 E_OpenconfigMplsLdp_MplsLdpAfi = 1
	// OpenconfigMplsLdp_MplsLdpAfi_IPV6 corresponds to the value IPV6 of OpenconfigMplsLdp_MplsLdpAfi
	OpenconfigMplsLdp_MplsLdpAfi_IPV6 E_OpenconfigMplsLdp_MplsLdpAfi = 2
)

// E_OpenconfigMplsTypes_LSP_METRIC_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_LSP_METRIC_TYPE. An additional value named
// OpenconfigMplsTypes_LSP_METRIC_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_LSP_METRIC_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_LSP_METRIC_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_LSP_METRIC_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_LSP_METRIC_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_LSP_METRIC_TYPE.
func (E_OpenconfigMplsTypes_LSP_METRIC_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_LSP_METRIC_TYPE.
func (e E_OpenconfigMplsTypes_LSP_METRIC_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_LSP_METRIC_TYPE")
}

const (
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_UNSET E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 0
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_ABSOLUTE corresponds to the value LSP_METRIC_ABSOLUTE of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_ABSOLUTE E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 1
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_INHERITED corresponds to the value LSP_METRIC_INHERITED of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_INHERITED E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 2
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_RELATIVE corresponds to the value LSP_METRIC_RELATIVE of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_RELATIVE E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 3
)

// E_OpenconfigMplsTypes_LSP_OPER_STATUS is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_LSP_OPER_STATUS. An additional value named
// OpenconfigMplsTypes_LSP_OPER_STATUS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_LSP_OPER_STATUS int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_LSP_OPER_STATUS implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_LSP_OPER_STATUS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_LSP_OPER_STATUS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_LSP_OPER_STATUS.
func (E_OpenconfigMplsTypes_LSP_OPER_STATUS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_LSP_OPER_STATUS.
func (e E_OpenconfigMplsTypes_LSP_OPER_STATUS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_LSP_OPER_STATUS")
}

const (
	// OpenconfigMplsTypes_LSP_OPER_STATUS_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_LSP_OPER_STATUS
	OpenconfigMplsTypes_LSP_OPER_STATUS_UNSET E_OpenconfigMplsTypes_LSP_OPER_STATUS = 0
	// OpenconfigMplsTypes_LSP_OPER_STATUS_DOWN corresponds to the value DOWN of OpenconfigMplsTypes_LSP_OPER_STATUS
	OpenconfigMplsTypes_LSP_OPER_STATUS_DOWN E_OpenconfigMplsTypes_LSP_OPER_STATUS = 1
	// OpenconfigMplsTypes_LSP_OPER_STATUS_UP corresponds to the value UP of OpenconfigMplsTypes_LSP_OPER_STATUS
	OpenconfigMplsTypes_LSP_OPER_STATUS_UP E_OpenconfigMplsTypes_LSP_OPER_STATUS = 2
)

// E_OpenconfigMplsTypes_LSP_ROLE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_LSP_ROLE. An additional value named
// OpenconfigMplsTypes_LSP_ROLE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_LSP_ROLE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_LSP_ROLE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_LSP_ROLE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_LSP_ROLE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_LSP_ROLE.
func (E_OpenconfigMplsTypes_LSP_ROLE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigMplsTypes_LSP_ROLE.
func (e E_OpenconfigMplsTypes_LSP_ROLE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_LSP_ROLE")
}

const (
	// OpenconfigMplsTypes_LSP_ROLE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_UNSET E_OpenconfigMplsTypes_LSP_ROLE = 0
	// OpenconfigMplsTypes_LSP_ROLE_EGRESS corresponds to the value EGRESS of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_EGRESS E_OpenconfigMplsTypes_LSP_ROLE = 1
	// OpenconfigMplsTypes_LSP_ROLE_INGRESS corresponds to the value INGRESS of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_INGRESS E_OpenconfigMplsTypes_LSP_ROLE = 2
	// OpenconfigMplsTypes_LSP_ROLE_TRANSIT corresponds to the value TRANSIT of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_TRANSIT E_OpenconfigMplsTypes_LSP_ROLE = 3
)

// E_OpenconfigMplsTypes_MplsLabel_Enum is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_MplsLabel_Enum. An additional value named
// OpenconfigMplsTypes_MplsLabel_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_MplsLabel_Enum int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_MplsLabel_Enum implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_MplsLabel_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_MplsLabel_Enum.
func (E_OpenconfigMplsTypes_MplsLabel_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_MplsLabel_Enum.
func (e E_OpenconfigMplsTypes_MplsLabel_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_MplsLabel_Enum")
}

const (
	// OpenconfigMplsTypes_MplsLabel_Enum_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_UNSET E_OpenconfigMplsTypes_MplsLabel_Enum = 0
	// OpenconfigMplsTypes_MplsLabel_Enum_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_IPV4_EXPLICIT_NULL E_OpenconfigMplsTypes_MplsLabel_Enum = 1
	// OpenconfigMplsTypes_MplsLabel_Enum_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_ROUTER_ALERT E_OpenconfigMplsTypes_MplsLabel_Enum = 2
	// OpenconfigMplsTypes_MplsLabel_Enum_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_IPV6_EXPLICIT_NULL E_OpenconfigMplsTypes_MplsLabel_Enum = 3
	// OpenconfigMplsTypes_MplsLabel_Enum_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_IMPLICIT_NULL E_OpenconfigMplsTypes_MplsLabel_Enum = 4
	// OpenconfigMplsTypes_MplsLabel_Enum_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_ENTROPY_LABEL_INDICATOR E_OpenconfigMplsTypes_MplsLabel_Enum = 8
	// OpenconfigMplsTypes_MplsLabel_Enum_NO_LABEL corresponds to the value NO_LABEL of OpenconfigMplsTypes_MplsLabel_Enum
	OpenconfigMplsTypes_MplsLabel_Enum_NO_LABEL E_OpenconfigMplsTypes_MplsLabel_Enum = 9
)

// E_OpenconfigMplsTypes_NULL_LABEL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_NULL_LABEL_TYPE. An additional value named
// OpenconfigMplsTypes_NULL_LABEL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_NULL_LABEL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_NULL_LABEL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_NULL_LABEL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_NULL_LABEL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_NULL_LABEL_TYPE.
func (E_OpenconfigMplsTypes_NULL_LABEL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_NULL_LABEL_TYPE.
func (e E_OpenconfigMplsTypes_NULL_LABEL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_NULL_LABEL_TYPE")
}

const (
	// OpenconfigMplsTypes_NULL_LABEL_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_NULL_LABEL_TYPE
	OpenconfigMplsTypes_NULL_LABEL_TYPE_UNSET E_OpenconfigMplsTypes_NULL_LABEL_TYPE = 0
	// OpenconfigMplsTypes_NULL_LABEL_TYPE_EXPLICIT corresponds to the value EXPLICIT of OpenconfigMplsTypes_NULL_LABEL_TYPE
	OpenconfigMplsTypes_NULL_LABEL_TYPE_EXPLICIT E_OpenconfigMplsTypes_NULL_LABEL_TYPE = 1
	// OpenconfigMplsTypes_NULL_LABEL_TYPE_IMPLICIT corresponds to the value IMPLICIT of OpenconfigMplsTypes_NULL_LABEL_TYPE
	OpenconfigMplsTypes_NULL_LABEL_TYPE_IMPLICIT E_OpenconfigMplsTypes_NULL_LABEL_TYPE = 2
)

// E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PATH_COMPUTATION_METHOD. An additional value named
// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PATH_COMPUTATION_METHOD implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PATH_COMPUTATION_METHOD can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PATH_COMPUTATION_METHOD.
func (E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD.
func (e E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD")
}

const (
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_UNSET E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 0
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXPLICITLY_DEFINED corresponds to the value EXPLICITLY_DEFINED of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXPLICITLY_DEFINED E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 1
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXTERNALLY_QUERIED corresponds to the value EXTERNALLY_QUERIED of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXTERNALLY_QUERIED E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 2
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_LOCALLY_COMPUTED corresponds to the value LOCALLY_COMPUTED of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_LOCALLY_COMPUTED E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 3
)

// E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PATH_SETUP_PROTOCOL. An additional value named
// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PATH_SETUP_PROTOCOL implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PATH_SETUP_PROTOCOL can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PATH_SETUP_PROTOCOL.
func (E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL.
func (e E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL")
}

const (
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_UNSET E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 0
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_LDP corresponds to the value PATH_SETUP_LDP of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_LDP E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 1
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_RSVP corresponds to the value PATH_SETUP_RSVP of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_RSVP E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 2
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_SR corresponds to the value PATH_SETUP_SR of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_SR E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 3
)

// E_OpenconfigMplsTypes_PROTECTION_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PROTECTION_TYPE. An additional value named
// OpenconfigMplsTypes_PROTECTION_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PROTECTION_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PROTECTION_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PROTECTION_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PROTECTION_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PROTECTION_TYPE.
func (E_OpenconfigMplsTypes_PROTECTION_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PROTECTION_TYPE.
func (e E_OpenconfigMplsTypes_PROTECTION_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PROTECTION_TYPE")
}

const (
	// OpenconfigMplsTypes_PROTECTION_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_UNSET E_OpenconfigMplsTypes_PROTECTION_TYPE = 0
	// OpenconfigMplsTypes_PROTECTION_TYPE_LINK_NODE_PROTECTION_REQUESTED corresponds to the value LINK_NODE_PROTECTION_REQUESTED of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_LINK_NODE_PROTECTION_REQUESTED E_OpenconfigMplsTypes_PROTECTION_TYPE = 1
	// OpenconfigMplsTypes_PROTECTION_TYPE_LINK_PROTECTION_REQUIRED corresponds to the value LINK_PROTECTION_REQUIRED of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_LINK_PROTECTION_REQUIRED E_OpenconfigMplsTypes_PROTECTION_TYPE = 2
	// OpenconfigMplsTypes_PROTECTION_TYPE_UNPROTECTED corresponds to the value UNPROTECTED of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_UNPROTECTED E_OpenconfigMplsTypes_PROTECTION_TYPE = 3
)

// E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION. An additional value named
// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION.
func (E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION.
func (e E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION")
}

const (
	// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION
	OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_UNSET E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION = 0
	// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_RAW_MODE corresponds to the value PWE_ETHERNET_RAW_MODE of OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION
	OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_RAW_MODE E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION = 1
	// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_TAGGED_MODE corresponds to the value PWE_ETHERNET_TAGGED_MODE of OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION
	OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_TAGGED_MODE E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION = 2
)

// E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS. An additional value named
// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS.
func (E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS.
func (e E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS")
}

const (
	// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS
	OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_UNSET E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS = 0
	// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_DOWN corresponds to the value ADMIN_DOWN of OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS
	OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_DOWN E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS = 1
	// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_UP corresponds to the value ADMIN_UP of OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS
	OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_UP E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS = 2
)

// E_OpenconfigMplsTypes_TUNNEL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_TUNNEL_TYPE. An additional value named
// OpenconfigMplsTypes_TUNNEL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_TUNNEL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_TUNNEL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_TUNNEL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_TUNNEL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_TUNNEL_TYPE.
func (E_OpenconfigMplsTypes_TUNNEL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_TUNNEL_TYPE.
func (e E_OpenconfigMplsTypes_TUNNEL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_TUNNEL_TYPE")
}

const (
	// OpenconfigMplsTypes_TUNNEL_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_TUNNEL_TYPE
	OpenconfigMplsTypes_TUNNEL_TYPE_UNSET E_OpenconfigMplsTypes_TUNNEL_TYPE = 0
	// OpenconfigMplsTypes_TUNNEL_TYPE_P2MP corresponds to the value P2MP of OpenconfigMplsTypes_TUNNEL_TYPE
	OpenconfigMplsTypes_TUNNEL_TYPE_P2MP E_OpenconfigMplsTypes_TUNNEL_TYPE = 1
	// OpenconfigMplsTypes_TUNNEL_TYPE_P2P corresponds to the value P2P of OpenconfigMplsTypes_TUNNEL_TYPE
	OpenconfigMplsTypes_TUNNEL_TYPE_P2P E_OpenconfigMplsTypes_TUNNEL_TYPE = 2
)

// E_OpenconfigMpls_CspfTieBreaking is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_CspfTieBreaking. An additional value named
// OpenconfigMpls_CspfTieBreaking_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_CspfTieBreaking int64

// IsYANGGoEnum ensures that OpenconfigMpls_CspfTieBreaking implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_CspfTieBreaking can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_CspfTieBreaking) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_CspfTieBreaking.
func (E_OpenconfigMpls_CspfTieBreaking) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMpls_CspfTieBreaking.
func (e E_OpenconfigMpls_CspfTieBreaking) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_CspfTieBreaking")
}

const (
	// OpenconfigMpls_CspfTieBreaking_UNSET corresponds to the value UNSET of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_UNSET E_OpenconfigMpls_CspfTieBreaking = 0
	// OpenconfigMpls_CspfTieBreaking_RANDOM corresponds to the value RANDOM of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_RANDOM E_OpenconfigMpls_CspfTieBreaking = 1
	// OpenconfigMpls_CspfTieBreaking_LEAST_FILL corresponds to the value LEAST_FILL of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_LEAST_FILL E_OpenconfigMpls_CspfTieBreaking = 2
	// OpenconfigMpls_CspfTieBreaking_MOST_FILL corresponds to the value MOST_FILL of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_MOST_FILL E_OpenconfigMpls_CspfTieBreaking = 3
)

// E_OpenconfigMpls_MplsHopType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_MplsHopType. An additional value named
// OpenconfigMpls_MplsHopType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_MplsHopType int64

// IsYANGGoEnum ensures that OpenconfigMpls_MplsHopType implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_MplsHopType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_MplsHopType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_MplsHopType.
func (E_OpenconfigMpls_MplsHopType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigMpls_MplsHopType.
func (e E_OpenconfigMpls_MplsHopType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_MplsHopType")
}

const (
	// OpenconfigMpls_MplsHopType_UNSET corresponds to the value UNSET of OpenconfigMpls_MplsHopType
	OpenconfigMpls_MplsHopType_UNSET E_OpenconfigMpls_MplsHopType = 0
	// OpenconfigMpls_MplsHopType_LOOSE corresponds to the value LOOSE of OpenconfigMpls_MplsHopType
	OpenconfigMpls_MplsHopType_LOOSE E_OpenconfigMpls_MplsHopType = 1
	// OpenconfigMpls_MplsHopType_STRICT corresponds to the value STRICT of OpenconfigMpls_MplsHopType
	OpenconfigMpls_MplsHopType_STRICT E_OpenconfigMpls_MplsHopType = 2
)

// E_OpenconfigMpls_MplsSrlgFloodingType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_MplsSrlgFloodingType. An additional value named
// OpenconfigMpls_MplsSrlgFloodingType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_MplsSrlgFloodingType int64

// IsYANGGoEnum ensures that OpenconfigMpls_MplsSrlgFloodingType implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_MplsSrlgFloodingType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_MplsSrlgFloodingType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_MplsSrlgFloodingType.
func (E_OpenconfigMpls_MplsSrlgFloodingType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMpls_MplsSrlgFloodingType.
func (e E_OpenconfigMpls_MplsSrlgFloodingType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_MplsSrlgFloodingType")
}

const (
	// OpenconfigMpls_MplsSrlgFloodingType_UNSET corresponds to the value UNSET of OpenconfigMpls_MplsSrlgFloodingType
	OpenconfigMpls_MplsSrlgFloodingType_UNSET E_OpenconfigMpls_MplsSrlgFloodingType = 0
	// OpenconfigMpls_MplsSrlgFloodingType_FLOODED_SRLG corresponds to the value FLOODED_SRLG of OpenconfigMpls_MplsSrlgFloodingType
	OpenconfigMpls_MplsSrlgFloodingType_FLOODED_SRLG E_OpenconfigMpls_MplsSrlgFloodingType = 1
	// OpenconfigMpls_MplsSrlgFloodingType_STATIC_SRLG corresponds to the value STATIC_SRLG of OpenconfigMpls_MplsSrlgFloodingType
	OpenconfigMpls_MplsSrlgFloodingType_STATIC_SRLG E_OpenconfigMpls_MplsSrlgFloodingType = 2
)

// E_OpenconfigMpls_TeBandwidthType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_TeBandwidthType. An additional value named
// OpenconfigMpls_TeBandwidthType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_TeBandwidthType int64

// IsYANGGoEnum ensures that OpenconfigMpls_TeBandwidthType implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_TeBandwidthType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_TeBandwidthType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_TeBandwidthType.
func (E_OpenconfigMpls_TeBandwidthType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMpls_TeBandwidthType.
func (e E_OpenconfigMpls_TeBandwidthType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_TeBandwidthType")
}

const (
	// OpenconfigMpls_TeBandwidthType_UNSET corresponds to the value UNSET of OpenconfigMpls_TeBandwidthType
	OpenconfigMpls_TeBandwidthType_UNSET E_OpenconfigMpls_TeBandwidthType = 0
	// OpenconfigMpls_TeBandwidthType_SPECIFIED corresponds to the value SPECIFIED of OpenconfigMpls_TeBandwidthType
	OpenconfigMpls_TeBandwidthType_SPECIFIED E_OpenconfigMpls_TeBandwidthType = 1
	// OpenconfigMpls_TeBandwidthType_AUTO corresponds to the value AUTO of OpenconfigMpls_TeBandwidthType
	OpenconfigMpls_TeBandwidthType_AUTO E_OpenconfigMpls_TeBandwidthType = 2
)

// E_OpenconfigNetworkInstanceTypes_ENCAPSULATION is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_ENCAPSULATION. An additional value named
// OpenconfigNetworkInstanceTypes_ENCAPSULATION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_ENCAPSULATION int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_ENCAPSULATION implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_ENCAPSULATION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_ENCAPSULATION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_ENCAPSULATION.
func (E_OpenconfigNetworkInstanceTypes_ENCAPSULATION) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_ENCAPSULATION.
func (e E_OpenconfigNetworkInstanceTypes_ENCAPSULATION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_ENCAPSULATION")
}

const (
	// OpenconfigNetworkInstanceTypes_ENCAPSULATION_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_ENCAPSULATION
	OpenconfigNetworkInstanceTypes_ENCAPSULATION_UNSET E_OpenconfigNetworkInstanceTypes_ENCAPSULATION = 0
	// OpenconfigNetworkInstanceTypes_ENCAPSULATION_MPLS corresponds to the value MPLS of OpenconfigNetworkInstanceTypes_ENCAPSULATION
	OpenconfigNetworkInstanceTypes_ENCAPSULATION_MPLS E_OpenconfigNetworkInstanceTypes_ENCAPSULATION = 1
	// OpenconfigNetworkInstanceTypes_ENCAPSULATION_VXLAN corresponds to the value VXLAN of OpenconfigNetworkInstanceTypes_ENCAPSULATION
	OpenconfigNetworkInstanceTypes_ENCAPSULATION_VXLAN E_OpenconfigNetworkInstanceTypes_ENCAPSULATION = 2
)

// E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE. An additional value named
// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE.
func (E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE.
func (e E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE")
}

const (
	// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE
	OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_UNSET E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE = 0
	// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_LOCAL corresponds to the value LOCAL of OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE
	OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_LOCAL E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE = 1
	// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_REMOTE corresponds to the value REMOTE of OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE
	OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_REMOTE E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE = 2
)

// E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE. An additional value named
// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE.
func (E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE.
func (e E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE")
}

const (
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_UNSET E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 0
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_INSTANCE_LABEL corresponds to the value INSTANCE_LABEL of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_INSTANCE_LABEL E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 1
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_NEXTHOP corresponds to the value PER_NEXTHOP of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_NEXTHOP E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 2
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_PREFIX corresponds to the value PER_PREFIX of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_PREFIX E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 3
)

// E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE. An additional value named
// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE.
func (E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE.
func (e E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE")
}

const (
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_UNSET E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 0
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_DEFAULT_INSTANCE corresponds to the value DEFAULT_INSTANCE of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_DEFAULT_INSTANCE E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 1
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2L3 corresponds to the value L2L3 of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2L3 E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 2
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2P2P corresponds to the value L2P2P of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2P2P E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 3
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2VSI corresponds to the value L2VSI of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2VSI E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 4
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L3VRF corresponds to the value L3VRF of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L3VRF E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 5
)

// E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE. An additional value named
// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE int64

// IsYANGGoEnum ensures that OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE implements the yang.GoEnum
// interface. This ensures that OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE.
func (E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE.
func (e E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE")
}

const (
	// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_UNSET corresponds to the value UNSET of OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE
	OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_UNSET E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE = 0
	// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_DSF corresponds to the value DSF of OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE
	OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_DSF E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE = 1
	// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_LEAF corresponds to the value LEAF of OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE
	OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_LEAF E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE = 2
	// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_SSMF corresponds to the value SSMF of OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE
	OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_SSMF E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE = 3
	// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_TWC corresponds to the value TWC of OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE
	OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_TWC E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE = 4
	// OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_TWRS corresponds to the value TWRS of OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE
	OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE_TWRS E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE = 5
)

// E_OpenconfigOpticalAmplifier_GAIN_RANGE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOpticalAmplifier_GAIN_RANGE. An additional value named
// OpenconfigOpticalAmplifier_GAIN_RANGE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOpticalAmplifier_GAIN_RANGE int64

// IsYANGGoEnum ensures that OpenconfigOpticalAmplifier_GAIN_RANGE implements the yang.GoEnum
// interface. This ensures that OpenconfigOpticalAmplifier_GAIN_RANGE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOpticalAmplifier_GAIN_RANGE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOpticalAmplifier_GAIN_RANGE.
func (E_OpenconfigOpticalAmplifier_GAIN_RANGE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOpticalAmplifier_GAIN_RANGE.
func (e E_OpenconfigOpticalAmplifier_GAIN_RANGE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOpticalAmplifier_GAIN_RANGE")
}

const (
	// OpenconfigOpticalAmplifier_GAIN_RANGE_UNSET corresponds to the value UNSET of OpenconfigOpticalAmplifier_GAIN_RANGE
	OpenconfigOpticalAmplifier_GAIN_RANGE_UNSET E_OpenconfigOpticalAmplifier_GAIN_RANGE = 0
	// OpenconfigOpticalAmplifier_GAIN_RANGE_FIXED_GAIN_RANGE corresponds to the value FIXED_GAIN_RANGE of OpenconfigOpticalAmplifier_GAIN_RANGE
	OpenconfigOpticalAmplifier_GAIN_RANGE_FIXED_GAIN_RANGE E_OpenconfigOpticalAmplifier_GAIN_RANGE = 1
	// OpenconfigOpticalAmplifier_GAIN_RANGE_HIGH_GAIN_RANGE corresponds to the value HIGH_GAIN_RANGE of OpenconfigOpticalAmplifier_GAIN_RANGE
	OpenconfigOpticalAmplifier_GAIN_RANGE_HIGH_GAIN_RANGE E_OpenconfigOpticalAmplifier_GAIN_RANGE = 2
	// OpenconfigOpticalAmplifier_GAIN_RANGE_LOW_GAIN_RANGE corresponds to the value LOW_GAIN_RANGE of OpenconfigOpticalAmplifier_GAIN_RANGE
	OpenconfigOpticalAmplifier_GAIN_RANGE_LOW_GAIN_RANGE E_OpenconfigOpticalAmplifier_GAIN_RANGE = 3
	// OpenconfigOpticalAmplifier_GAIN_RANGE_MID_GAIN_RANGE corresponds to the value MID_GAIN_RANGE of OpenconfigOpticalAmplifier_GAIN_RANGE
	OpenconfigOpticalAmplifier_GAIN_RANGE_MID_GAIN_RANGE E_OpenconfigOpticalAmplifier_GAIN_RANGE = 4
)

// E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE. An additional value named
// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE int64

// IsYANGGoEnum ensures that OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE implements the yang.GoEnum
// interface. This ensures that OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE.
func (E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE.
func (e E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE")
}

const (
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_UNSET corresponds to the value UNSET of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_UNSET E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE = 0
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_CONSTANT_GAIN corresponds to the value CONSTANT_GAIN of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_CONSTANT_GAIN E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE = 1
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_CONSTANT_POWER corresponds to the value CONSTANT_POWER of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_CONSTANT_POWER E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE = 2
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_DYNAMIC_GAIN corresponds to the value DYNAMIC_GAIN of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE_DYNAMIC_GAIN E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE = 3
)

// E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE. An additional value named
// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE.
func (E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE.
func (e E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE")
}

const (
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_UNSET corresponds to the value UNSET of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_UNSET E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE = 0
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_BACKWARD_RAMAN corresponds to the value BACKWARD_RAMAN of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_BACKWARD_RAMAN E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE = 1
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_EDFA corresponds to the value EDFA of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_EDFA E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE = 2
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_FORWARD_RAMAN corresponds to the value FORWARD_RAMAN of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_FORWARD_RAMAN E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE = 3
	// OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_HYBRID corresponds to the value HYBRID of OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE
	OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE_HYBRID E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE = 4
)

// E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES. An additional value named
// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES.
func (E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES.
func (e E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES")
}

const (
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_UNSET E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 0
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_IP_INTERFACE_ADDRESS corresponds to the value GRACE_IP_INTERFACE_ADDRESS of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_IP_INTERFACE_ADDRESS E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 1
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_PERIOD corresponds to the value GRACE_PERIOD of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_PERIOD E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 2
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_RESTART_REASON corresponds to the value GRACE_RESTART_REASON of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_RESTART_REASON E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 3
)

// E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_MAX_METRIC_INCLUDE. An additional value named
// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_MAX_METRIC_INCLUDE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_MAX_METRIC_INCLUDE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_MAX_METRIC_INCLUDE.
func (E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE.
func (e E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE")
}

const (
	// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_MAX_METRIC_INCLUDE
	OpenconfigOspfTypes_MAX_METRIC_INCLUDE_UNSET E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE = 0
	// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_STUB corresponds to the value MAX_METRIC_INCLUDE_STUB of OpenconfigOspfTypes_MAX_METRIC_INCLUDE
	OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_STUB E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE = 1
	// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_TYPE2_EXTERNAL corresponds to the value MAX_METRIC_INCLUDE_TYPE2_EXTERNAL of OpenconfigOspfTypes_MAX_METRIC_INCLUDE
	OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_TYPE2_EXTERNAL E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE = 2
)

// E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_MAX_METRIC_TRIGGER. An additional value named
// OpenconfigOspfTypes_MAX_METRIC_TRIGGER_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_MAX_METRIC_TRIGGER implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_MAX_METRIC_TRIGGER can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_MAX_METRIC_TRIGGER.
func (E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER.
func (e E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER")
}

const (
	// OpenconfigOspfTypes_MAX_METRIC_TRIGGER_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_MAX_METRIC_TRIGGER
	OpenconfigOspfTypes_MAX_METRIC_TRIGGER_UNSET E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER = 0
	// OpenconfigOspfTypes_MAX_METRIC_TRIGGER_MAX_METRIC_ON_SYSTEM_BOOT corresponds to the value MAX_METRIC_ON_SYSTEM_BOOT of OpenconfigOspfTypes_MAX_METRIC_TRIGGER
	OpenconfigOspfTypes_MAX_METRIC_TRIGGER_MAX_METRIC_ON_SYSTEM_BOOT E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER = 1
)

// E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_ADJACENCY_SID corresponds to the value ADJACENCY_SID of OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_ADJACENCY_SID E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE = 1
)

// E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_METRIC corresponds to the value ERO_METRIC of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_METRIC E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_PATH corresponds to the value ERO_PATH of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_PATH E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 2
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_SID_MPLS_LABEL_BINDING corresponds to the value SID_MPLS_LABEL_BINDING of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_SID_MPLS_LABEL_BINDING E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 3
)

// E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_EXTENDED_PREFIX_RANGE corresponds to the value EXTENDED_PREFIX_RANGE of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_EXTENDED_PREFIX_RANGE E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_PREFIX_SID corresponds to the value PREFIX_SID of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_PREFIX_SID E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 2
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_SID_LABEL_BINDING corresponds to the value SID_LABEL_BINDING of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_SID_LABEL_BINDING E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 3
)

// E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_IPV4_SEGMENT corresponds to the value IPV4_SEGMENT of OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_IPV4_SEGMENT E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNNUMBERED_INTERFACE_SEGMENT corresponds to the value UNNUMBERED_INTERFACE_SEGMENT of OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNNUMBERED_INTERFACE_SEGMENT E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE = 2
)

// E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_POINT_TO_POINT_LINK corresponds to the value POINT_TO_POINT_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_POINT_TO_POINT_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_STUB_NETWORK_LINK corresponds to the value STUB_NETWORK_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_STUB_NETWORK_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 2
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_TRANSIT_NETWORK_LINK corresponds to the value TRANSIT_NETWORK_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_TRANSIT_NETWORK_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 3
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_VIRTUAL_LINK corresponds to the value VIRTUAL_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_VIRTUAL_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 4
)

// E_OpenconfigOspfTypes_OSPF_LSA_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_LSA_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_LSA_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_LSA_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_LSA_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_LSA_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_LSA_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_LSA_TYPE.
func (E_OpenconfigOspfTypes_OSPF_LSA_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_LSA_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_LSA_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_LSA_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 0
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_AS_EXTERNAL_LSA corresponds to the value AS_EXTERNAL_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_AS_EXTERNAL_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 1
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_NETWORK_LSA corresponds to the value NETWORK_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_NETWORK_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 2
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_NSSA_AS_EXTERNAL_LSA corresponds to the value NSSA_AS_EXTERNAL_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_NSSA_AS_EXTERNAL_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 3
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AREA_SCOPE_OPAQUE_LSA corresponds to the value OSPFV2_AREA_SCOPE_OPAQUE_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AREA_SCOPE_OPAQUE_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 4
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AS_SCOPE_OPAQUE_LSA corresponds to the value OSPFV2_AS_SCOPE_OPAQUE_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AS_SCOPE_OPAQUE_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 5
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_LINK_SCOPE_OPAQUE_LSA corresponds to the value OSPFV2_LINK_SCOPE_OPAQUE_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_LINK_SCOPE_OPAQUE_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 6
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_ROUTER_LSA corresponds to the value ROUTER_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_ROUTER_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 7
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_ASBR_LSA corresponds to the value SUMMARY_ASBR_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_ASBR_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 8
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_IP_NETWORK_LSA corresponds to the value SUMMARY_IP_NETWORK_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_IP_NETWORK_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 9
)

// E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE. An additional value named
// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE.
func (E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE.
func (e E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE")
}

const (
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_UNSET E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 0
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_ATTEMPT corresponds to the value ATTEMPT of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_ATTEMPT E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 1
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_DOWN corresponds to the value DOWN of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_DOWN E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 2
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXCHANGE corresponds to the value EXCHANGE of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXCHANGE E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 3
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXSTART corresponds to the value EXSTART of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXSTART E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 4
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_FULL corresponds to the value FULL of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_FULL E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 5
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_INIT corresponds to the value INIT of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_INIT E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 6
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_LOADING corresponds to the value LOADING of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_LOADING E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 7
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_TWO_WAY corresponds to the value TWO_WAY of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_TWO_WAY E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 8
)

// E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_NETWORK_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_NETWORK_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_NETWORK_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_NETWORK_TYPE.
func (E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 0
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_BROADCAST_NETWORK corresponds to the value BROADCAST_NETWORK of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_BROADCAST_NETWORK E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 1
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_NON_BROADCAST_NETWORK corresponds to the value NON_BROADCAST_NETWORK of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_NON_BROADCAST_NETWORK E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 2
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_POINT_TO_POINT_NETWORK corresponds to the value POINT_TO_POINT_NETWORK of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_POINT_TO_POINT_NETWORK E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 3
)

// E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE.
func (E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 0
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_GRACE_LSA corresponds to the value GRACE_LSA of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_GRACE_LSA E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 1
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_LINK corresponds to the value OSPFV2_EXTENDED_LINK of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_LINK E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 2
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_PREFIX corresponds to the value OSPFV2_EXTENDED_PREFIX of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_PREFIX E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 3
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_ROUTER_INFORMATION corresponds to the value ROUTER_INFORMATION of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_ROUTER_INFORMATION E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 4
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_TRAFFIC_ENGINEERING corresponds to the value TRAFFIC_ENGINEERING of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_TRAFFIC_ENGINEERING E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 5
)

// E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES. An additional value named
// OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES.
func (E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES.
func (e E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES")
}

const (
	// OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
	OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_UNSET E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES = 0
	// OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_SR_SID_LABEL_TLV corresponds to the value SR_SID_LABEL_TLV of OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
	OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_SR_SID_LABEL_TLV E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES = 1
)

// E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE.
func (E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 0
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ADMIN_GROUP corresponds to the value TE_LINK_ADMIN_GROUP of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ADMIN_GROUP E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 1
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ID corresponds to the value TE_LINK_ID of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ID E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 2
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_LOCAL_IP corresponds to the value TE_LINK_LOCAL_IP of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_LOCAL_IP E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 3
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_BANDWIDTH corresponds to the value TE_LINK_MAXIMUM_BANDWIDTH of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_BANDWIDTH E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 4
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH corresponds to the value TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 5
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_METRIC corresponds to the value TE_LINK_METRIC of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_METRIC E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 6
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_REMOTE_IP corresponds to the value TE_LINK_REMOTE_IP of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_REMOTE_IP E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 7
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_TYPE corresponds to the value TE_LINK_TYPE of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_TYPE E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 8
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_UNRESERVED_BANDWIDTH corresponds to the value TE_LINK_UNRESERVED_BANDWIDTH of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_UNRESERVED_BANDWIDTH E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 9
)

// E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE.
func (E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 0
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK corresponds to the value TE_LINK of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 1
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK_LOCAL corresponds to the value TE_LINK_LOCAL of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK_LOCAL E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 2
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_NODE_ATTRIBUTE corresponds to the value TE_NODE_ATTRIBUTE of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_NODE_ATTRIBUTE E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 3
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_OPTICAL_NODE_PROPERTY corresponds to the value TE_OPTICAL_NODE_PROPERTY of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_OPTICAL_NODE_PROPERTY E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 4
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_ADDRESS corresponds to the value TE_ROUTER_ADDRESS of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_ADDRESS E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 5
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_IPV6_ADDRESS corresponds to the value TE_ROUTER_IPV6_ADDRESS of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_IPV6_ADDRESS E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 6
)

// E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_RI_LSA_TLV_TYPES. An additional value named
// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_RI_LSA_TLV_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_RI_LSA_TLV_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_RI_LSA_TLV_TYPES.
func (E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES.
func (e E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES")
}

const (
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_UNSET E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 0
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_FUNCTIONAL_CAPABILITIES corresponds to the value RI_FUNCTIONAL_CAPABILITIES of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_FUNCTIONAL_CAPABILITIES E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 1
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_INFORMATIONAL_CAPABILITIES corresponds to the value RI_INFORMATIONAL_CAPABILITIES of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_INFORMATIONAL_CAPABILITIES E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 2
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_NODE_ADMIN_TAG corresponds to the value RI_NODE_ADMIN_TAG of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_NODE_ADMIN_TAG E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 3
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_ALGORITHM corresponds to the value RI_SR_ALGORITHM of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_ALGORITHM E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 4
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_SID_LABEL_RANGE corresponds to the value RI_SR_SID_LABEL_RANGE of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_SID_LABEL_RANGE E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 5
)

// E_OpenconfigOspfTypes_ROUTER_LSA_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_ROUTER_LSA_TYPES. An additional value named
// OpenconfigOspfTypes_ROUTER_LSA_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_ROUTER_LSA_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_ROUTER_LSA_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_ROUTER_LSA_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_ROUTER_LSA_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_ROUTER_LSA_TYPES.
func (E_OpenconfigOspfTypes_ROUTER_LSA_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_ROUTER_LSA_TYPES.
func (e E_OpenconfigOspfTypes_ROUTER_LSA_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_ROUTER_LSA_TYPES")
}

const (
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_UNSET E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 0
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_P2P corresponds to the value ROUTER_LSA_P2P of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_P2P E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 1
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_STUB_NETWORK corresponds to the value ROUTER_LSA_STUB_NETWORK of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_STUB_NETWORK E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 2
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_TRANSIT_NETWORK corresponds to the value ROUTER_LSA_TRANSIT_NETWORK of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_TRANSIT_NETWORK E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 3
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_VIRTUAL_LINK corresponds to the value ROUTER_LSA_VIRTUAL_LINK of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_VIRTUAL_LINK E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 4
)

// E_OpenconfigOspfTypes_SR_ALGORITHM is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_SR_ALGORITHM. An additional value named
// OpenconfigOspfTypes_SR_ALGORITHM_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_SR_ALGORITHM int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_SR_ALGORITHM implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_SR_ALGORITHM can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_SR_ALGORITHM) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_SR_ALGORITHM.
func (E_OpenconfigOspfTypes_SR_ALGORITHM) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_SR_ALGORITHM.
func (e E_OpenconfigOspfTypes_SR_ALGORITHM) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_SR_ALGORITHM")
}

const (
	// OpenconfigOspfTypes_SR_ALGORITHM_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_SR_ALGORITHM
	OpenconfigOspfTypes_SR_ALGORITHM_UNSET E_OpenconfigOspfTypes_SR_ALGORITHM = 0
	// OpenconfigOspfTypes_SR_ALGORITHM_SPF corresponds to the value SPF of OpenconfigOspfTypes_SR_ALGORITHM
	OpenconfigOspfTypes_SR_ALGORITHM_SPF E_OpenconfigOspfTypes_SR_ALGORITHM = 1
	// OpenconfigOspfTypes_SR_ALGORITHM_STRICT_SPF corresponds to the value STRICT_SPF of OpenconfigOspfTypes_SR_ALGORITHM
	OpenconfigOspfTypes_SR_ALGORITHM_STRICT_SPF E_OpenconfigOspfTypes_SR_ALGORITHM = 2
)

// E_OpenconfigOspfTypes_SrSidType is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_SrSidType. An additional value named
// OpenconfigOspfTypes_SrSidType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_SrSidType int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_SrSidType implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_SrSidType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_SrSidType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_SrSidType.
func (E_OpenconfigOspfTypes_SrSidType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_SrSidType.
func (e E_OpenconfigOspfTypes_SrSidType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_SrSidType")
}

const (
	// OpenconfigOspfTypes_SrSidType_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_SrSidType
	OpenconfigOspfTypes_SrSidType_UNSET E_OpenconfigOspfTypes_SrSidType = 0
	// OpenconfigOspfTypes_SrSidType_LABEL corresponds to the value LABEL of OpenconfigOspfTypes_SrSidType
	OpenconfigOspfTypes_SrSidType_LABEL E_OpenconfigOspfTypes_SrSidType = 1
	// OpenconfigOspfTypes_SrSidType_SID corresponds to the value SID of OpenconfigOspfTypes_SrSidType
	OpenconfigOspfTypes_SrSidType_SID E_OpenconfigOspfTypes_SrSidType = 2
)

// E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE. An additional value named
// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE.
func (E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE.
func (e E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE")
}

const (
	// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
	OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_UNSET E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE = 0
	// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV4_LOCAL_ADDRESS corresponds to the value NODE_IPV4_LOCAL_ADDRESS of OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
	OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV4_LOCAL_ADDRESS E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE = 1
	// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV6_LOCAL_ADDRESS corresponds to the value NODE_IPV6_LOCAL_ADDRESS of OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
	OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV6_LOCAL_ADDRESS E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE = 2
)

// E_OpenconfigPacketMatchTypes_ETHERTYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_ETHERTYPE. An additional value named
// OpenconfigPacketMatchTypes_ETHERTYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_ETHERTYPE int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_ETHERTYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_ETHERTYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_ETHERTYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_ETHERTYPE.
func (E_OpenconfigPacketMatchTypes_ETHERTYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_ETHERTYPE.
func (e E_OpenconfigPacketMatchTypes_ETHERTYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_ETHERTYPE")
}

const (
	// OpenconfigPacketMatchTypes_ETHERTYPE_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_UNSET E_OpenconfigPacketMatchTypes_ETHERTYPE = 0
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ARP corresponds to the value ETHERTYPE_ARP of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ARP E_OpenconfigPacketMatchTypes_ETHERTYPE = 1
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV4 corresponds to the value ETHERTYPE_IPV4 of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV4 E_OpenconfigPacketMatchTypes_ETHERTYPE = 2
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV6 corresponds to the value ETHERTYPE_IPV6 of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV6 E_OpenconfigPacketMatchTypes_ETHERTYPE = 3
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_LLDP corresponds to the value ETHERTYPE_LLDP of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_LLDP E_OpenconfigPacketMatchTypes_ETHERTYPE = 4
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_MPLS corresponds to the value ETHERTYPE_MPLS of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_MPLS E_OpenconfigPacketMatchTypes_ETHERTYPE = 5
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ROCE corresponds to the value ETHERTYPE_ROCE of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ROCE E_OpenconfigPacketMatchTypes_ETHERTYPE = 6
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_VLAN corresponds to the value ETHERTYPE_VLAN of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_VLAN E_OpenconfigPacketMatchTypes_ETHERTYPE = 7
)

// E_OpenconfigPacketMatchTypes_IP_PROTOCOL is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_IP_PROTOCOL. An additional value named
// OpenconfigPacketMatchTypes_IP_PROTOCOL_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_IP_PROTOCOL int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_IP_PROTOCOL implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_IP_PROTOCOL can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_IP_PROTOCOL.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_IP_PROTOCOL.
func (e E_OpenconfigPacketMatchTypes_IP_PROTOCOL) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_IP_PROTOCOL")
}

const (
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_UNSET E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 0
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_AUTH corresponds to the value IP_AUTH of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_AUTH E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 1
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_GRE corresponds to the value IP_GRE of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_GRE E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 2
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_ICMP corresponds to the value IP_ICMP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_ICMP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 3
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_IGMP corresponds to the value IP_IGMP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_IGMP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 4
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_L2TP corresponds to the value IP_L2TP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_L2TP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 5
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_PIM corresponds to the value IP_PIM of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_PIM E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 6
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_RSVP corresponds to the value IP_RSVP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_RSVP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 7
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_TCP corresponds to the value IP_TCP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_TCP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 8
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_UDP corresponds to the value IP_UDP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_UDP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 9
)

// E_OpenconfigPacketMatchTypes_PortNumRange_Enum is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_PortNumRange_Enum. An additional value named
// OpenconfigPacketMatchTypes_PortNumRange_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_PortNumRange_Enum int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_PortNumRange_Enum implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_PortNumRange_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_PortNumRange_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_PortNumRange_Enum.
func (E_OpenconfigPacketMatchTypes_PortNumRange_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_PortNumRange_Enum.
func (e E_OpenconfigPacketMatchTypes_PortNumRange_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_PortNumRange_Enum")
}

const (
	// OpenconfigPacketMatchTypes_PortNumRange_Enum_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_PortNumRange_Enum
	OpenconfigPacketMatchTypes_PortNumRange_Enum_UNSET E_OpenconfigPacketMatchTypes_PortNumRange_Enum = 0
	// OpenconfigPacketMatchTypes_PortNumRange_Enum_ANY corresponds to the value ANY of OpenconfigPacketMatchTypes_PortNumRange_Enum
	OpenconfigPacketMatchTypes_PortNumRange_Enum_ANY E_OpenconfigPacketMatchTypes_PortNumRange_Enum = 1
)

// E_OpenconfigPacketMatchTypes_TCP_FLAGS is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_TCP_FLAGS. An additional value named
// OpenconfigPacketMatchTypes_TCP_FLAGS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_TCP_FLAGS int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_TCP_FLAGS implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_TCP_FLAGS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_TCP_FLAGS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_TCP_FLAGS.
func (E_OpenconfigPacketMatchTypes_TCP_FLAGS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_TCP_FLAGS.
func (e E_OpenconfigPacketMatchTypes_TCP_FLAGS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_TCP_FLAGS")
}

const (
	// OpenconfigPacketMatchTypes_TCP_FLAGS_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_UNSET E_OpenconfigPacketMatchTypes_TCP_FLAGS = 0
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ACK corresponds to the value TCP_ACK of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ACK E_OpenconfigPacketMatchTypes_TCP_FLAGS = 1
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_CWR corresponds to the value TCP_CWR of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_CWR E_OpenconfigPacketMatchTypes_TCP_FLAGS = 2
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ECE corresponds to the value TCP_ECE of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ECE E_OpenconfigPacketMatchTypes_TCP_FLAGS = 3
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_FIN corresponds to the value TCP_FIN of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_FIN E_OpenconfigPacketMatchTypes_TCP_FLAGS = 4
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_PSH corresponds to the value TCP_PSH of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_PSH E_OpenconfigPacketMatchTypes_TCP_FLAGS = 5
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_RST corresponds to the value TCP_RST of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_RST E_OpenconfigPacketMatchTypes_TCP_FLAGS = 6
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_SYN corresponds to the value TCP_SYN of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_SYN E_OpenconfigPacketMatchTypes_TCP_FLAGS = 7
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_URG corresponds to the value TCP_URG of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_URG E_OpenconfigPacketMatchTypes_TCP_FLAGS = 8
)

// E_OpenconfigPimTypes_PIM_MODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPimTypes_PIM_MODE. An additional value named
// OpenconfigPimTypes_PIM_MODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPimTypes_PIM_MODE int64

// IsYANGGoEnum ensures that OpenconfigPimTypes_PIM_MODE implements the yang.GoEnum
// interface. This ensures that OpenconfigPimTypes_PIM_MODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPimTypes_PIM_MODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPimTypes_PIM_MODE.
func (E_OpenconfigPimTypes_PIM_MODE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigPimTypes_PIM_MODE.
func (e E_OpenconfigPimTypes_PIM_MODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPimTypes_PIM_MODE")
}

const (
	// OpenconfigPimTypes_PIM_MODE_UNSET corresponds to the value UNSET of OpenconfigPimTypes_PIM_MODE
	OpenconfigPimTypes_PIM_MODE_UNSET E_OpenconfigPimTypes_PIM_MODE = 0
	// OpenconfigPimTypes_PIM_MODE_PIM_MODE_DENSE corresponds to the value PIM_MODE_DENSE of OpenconfigPimTypes_PIM_MODE
	OpenconfigPimTypes_PIM_MODE_PIM_MODE_DENSE E_OpenconfigPimTypes_PIM_MODE = 1
	// OpenconfigPimTypes_PIM_MODE_PIM_MODE_SPARSE corresponds to the value PIM_MODE_SPARSE of OpenconfigPimTypes_PIM_MODE
	OpenconfigPimTypes_PIM_MODE_PIM_MODE_SPARSE E_OpenconfigPimTypes_PIM_MODE = 2
)

// E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_COMPONENT_OPER_STATUS. An additional value named
// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_COMPONENT_OPER_STATUS implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_COMPONENT_OPER_STATUS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_COMPONENT_OPER_STATUS.
func (E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS.
func (e E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS")
}

const (
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_UNSET E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 0
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_ACTIVE corresponds to the value ACTIVE of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_ACTIVE E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 1
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_DISABLED corresponds to the value DISABLED of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_DISABLED E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 2
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_INACTIVE corresponds to the value INACTIVE of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_INACTIVE E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 3
)

// E_OpenconfigPlatformTypes_FEC_MODE_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_FEC_MODE_TYPE. An additional value named
// OpenconfigPlatformTypes_FEC_MODE_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_FEC_MODE_TYPE int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_FEC_MODE_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_FEC_MODE_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_FEC_MODE_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_FEC_MODE_TYPE.
func (E_OpenconfigPlatformTypes_FEC_MODE_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_FEC_MODE_TYPE.
func (e E_OpenconfigPlatformTypes_FEC_MODE_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_FEC_MODE_TYPE")
}

const (
	// OpenconfigPlatformTypes_FEC_MODE_TYPE_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_FEC_MODE_TYPE
	OpenconfigPlatformTypes_FEC_MODE_TYPE_UNSET E_OpenconfigPlatformTypes_FEC_MODE_TYPE = 0
	// OpenconfigPlatformTypes_FEC_MODE_TYPE_FEC_AUTO corresponds to the value FEC_AUTO of OpenconfigPlatformTypes_FEC_MODE_TYPE
	OpenconfigPlatformTypes_FEC_MODE_TYPE_FEC_AUTO E_OpenconfigPlatformTypes_FEC_MODE_TYPE = 1
	// OpenconfigPlatformTypes_FEC_MODE_TYPE_FEC_DISABLED corresponds to the value FEC_DISABLED of OpenconfigPlatformTypes_FEC_MODE_TYPE
	OpenconfigPlatformTypes_FEC_MODE_TYPE_FEC_DISABLED E_OpenconfigPlatformTypes_FEC_MODE_TYPE = 2
	// OpenconfigPlatformTypes_FEC_MODE_TYPE_FEC_ENABLED corresponds to the value FEC_ENABLED of OpenconfigPlatformTypes_FEC_MODE_TYPE
	OpenconfigPlatformTypes_FEC_MODE_TYPE_FEC_ENABLED E_OpenconfigPlatformTypes_FEC_MODE_TYPE = 3
)

// E_OpenconfigPlatformTypes_FEC_STATUS_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_FEC_STATUS_TYPE. An additional value named
// OpenconfigPlatformTypes_FEC_STATUS_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_FEC_STATUS_TYPE int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_FEC_STATUS_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_FEC_STATUS_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_FEC_STATUS_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_FEC_STATUS_TYPE.
func (E_OpenconfigPlatformTypes_FEC_STATUS_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_FEC_STATUS_TYPE.
func (e E_OpenconfigPlatformTypes_FEC_STATUS_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_FEC_STATUS_TYPE")
}

const (
	// OpenconfigPlatformTypes_FEC_STATUS_TYPE_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_FEC_STATUS_TYPE
	OpenconfigPlatformTypes_FEC_STATUS_TYPE_UNSET E_OpenconfigPlatformTypes_FEC_STATUS_TYPE = 0
	// OpenconfigPlatformTypes_FEC_STATUS_TYPE_FEC_STATUS_LOCKED corresponds to the value FEC_STATUS_LOCKED of OpenconfigPlatformTypes_FEC_STATUS_TYPE
	OpenconfigPlatformTypes_FEC_STATUS_TYPE_FEC_STATUS_LOCKED E_OpenconfigPlatformTypes_FEC_STATUS_TYPE = 1
	// OpenconfigPlatformTypes_FEC_STATUS_TYPE_FEC_STATUS_UNLOCKED corresponds to the value FEC_STATUS_UNLOCKED of OpenconfigPlatformTypes_FEC_STATUS_TYPE
	OpenconfigPlatformTypes_FEC_STATUS_TYPE_FEC_STATUS_UNLOCKED E_OpenconfigPlatformTypes_FEC_STATUS_TYPE = 2
)

// E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT. An additional value named
// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT.
func (E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT.
func (e E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT")
}

const (
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_UNSET E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 0
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_BACKPLANE corresponds to the value BACKPLANE of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_BACKPLANE E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 1
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CHASSIS corresponds to the value CHASSIS of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CHASSIS E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 2
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CONTROLLER_CARD corresponds to the value CONTROLLER_CARD of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CONTROLLER_CARD E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 3
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CPU corresponds to the value CPU of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CPU E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 4
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FABRIC corresponds to the value FABRIC of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FABRIC E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 5
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FAN corresponds to the value FAN of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FAN E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 6
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FRU corresponds to the value FRU of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FRU E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 7
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_INTEGRATED_CIRCUIT corresponds to the value INTEGRATED_CIRCUIT of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_INTEGRATED_CIRCUIT E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 8
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_LINECARD corresponds to the value LINECARD of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_LINECARD E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 9
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_OPTICAL_CHANNEL corresponds to the value OPTICAL_CHANNEL of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_OPTICAL_CHANNEL E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 10
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_PORT corresponds to the value PORT of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_PORT E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 11
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_POWER_SUPPLY corresponds to the value POWER_SUPPLY of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_POWER_SUPPLY E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 12
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_SENSOR corresponds to the value SENSOR of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_SENSOR E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 13
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_STORAGE corresponds to the value STORAGE of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_STORAGE E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 14
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_TRANSCEIVER corresponds to the value TRANSCEIVER of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_TRANSCEIVER E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 15
)

// E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT. An additional value named
// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT.
func (E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT.
func (e E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT")
}

const (
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_UNSET E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 0
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM corresponds to the value OPERATING_SYSTEM of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 1
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM_UPDATE corresponds to the value OPERATING_SYSTEM_UPDATE of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM_UPDATE E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 2
)

// E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE. An additional value named
// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE.
func (e E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE")
}

const (
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_UNSET corresponds to the value UNSET of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_UNSET E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 0
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_BGP corresponds to the value BGP of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_BGP E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 1
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_DIRECTLY_CONNECTED corresponds to the value DIRECTLY_CONNECTED of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_DIRECTLY_CONNECTED E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 2
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_IGMP corresponds to the value IGMP of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_IGMP E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 3
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_ISIS corresponds to the value ISIS of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_ISIS E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 4
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_LOCAL_AGGREGATE corresponds to the value LOCAL_AGGREGATE of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_LOCAL_AGGREGATE E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 5
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF corresponds to the value OSPF of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 6
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF3 corresponds to the value OSPF3 of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF3 E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 7
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_PIM corresponds to the value PIM of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_PIM E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 8
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_STATIC corresponds to the value STATIC of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_STATIC E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 9
)

// E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType is a derived int64 type which is used to represent
// the enumerated node OpenconfigPolicyTypes_MatchSetOptionsRestrictedType. An additional value named
// OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType int64

// IsYANGGoEnum ensures that OpenconfigPolicyTypes_MatchSetOptionsRestrictedType implements the yang.GoEnum
// interface. This ensures that OpenconfigPolicyTypes_MatchSetOptionsRestrictedType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPolicyTypes_MatchSetOptionsRestrictedType.
func (E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType.
func (e E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType")
}

const (
	// OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_UNSET corresponds to the value UNSET of OpenconfigPolicyTypes_MatchSetOptionsRestrictedType
	OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_UNSET E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType = 0
	// OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_ANY corresponds to the value ANY of OpenconfigPolicyTypes_MatchSetOptionsRestrictedType
	OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_ANY E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType = 1
	// OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_INVERT corresponds to the value INVERT of OpenconfigPolicyTypes_MatchSetOptionsRestrictedType
	OpenconfigPolicyTypes_MatchSetOptionsRestrictedType_INVERT E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType = 2
)

// E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgpTypes_INVALID_ROUTE_REASON. An additional value named
// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON int64

// IsYANGGoEnum ensures that OpenconfigRibBgpTypes_INVALID_ROUTE_REASON implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgpTypes_INVALID_ROUTE_REASON can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgpTypes_INVALID_ROUTE_REASON.
func (E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON.
func (e E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON")
}

const (
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_UNSET corresponds to the value UNSET of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_UNSET E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 0
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_AS_LOOP corresponds to the value INVALID_AS_LOOP of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_AS_LOOP E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 1
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CLUSTER_LOOP corresponds to the value INVALID_CLUSTER_LOOP of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CLUSTER_LOOP E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 2
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CONFED corresponds to the value INVALID_CONFED of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CONFED E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 3
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_ORIGINATOR corresponds to the value INVALID_ORIGINATOR of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_ORIGINATOR E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 4
)

// E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE. An additional value named
// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE.
func (e E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE")
}

const (
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_UNSET E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 0
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_BINDING_SID corresponds to the value SRTE_BINDING_SID of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_BINDING_SID E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 1
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_PREFERENCE corresponds to the value SRTE_PREFERENCE of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_PREFERENCE E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 2
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_SEGMENT_LIST corresponds to the value SRTE_SEGMENT_LIST of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_SEGMENT_LIST E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 3
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_COLOR corresponds to the value TUNNEL_COLOR of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_COLOR E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 4
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_REMOTE_ENDPOINT corresponds to the value TUNNEL_REMOTE_ENDPOINT of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_REMOTE_ENDPOINT E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 5
)

// E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE. An additional value named
// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE int64

// IsYANGGoEnum ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE.
func (e E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE")
}

const (
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_UNSET corresponds to the value UNSET of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_UNSET E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE = 0
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_SRTE_POLICY_TUNNEL corresponds to the value SRTE_POLICY_TUNNEL of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_SRTE_POLICY_TUNNEL E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE = 1
)

// E_OpenconfigRoutingPolicy_DefaultPolicyType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_DefaultPolicyType. An additional value named
// OpenconfigRoutingPolicy_DefaultPolicyType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_DefaultPolicyType int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_DefaultPolicyType implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_DefaultPolicyType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_DefaultPolicyType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_DefaultPolicyType.
func (E_OpenconfigRoutingPolicy_DefaultPolicyType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_DefaultPolicyType.
func (e E_OpenconfigRoutingPolicy_DefaultPolicyType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_DefaultPolicyType")
}

const (
	// OpenconfigRoutingPolicy_DefaultPolicyType_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_DefaultPolicyType
	OpenconfigRoutingPolicy_DefaultPolicyType_UNSET E_OpenconfigRoutingPolicy_DefaultPolicyType = 0
	// OpenconfigRoutingPolicy_DefaultPolicyType_ACCEPT_ROUTE corresponds to the value ACCEPT_ROUTE of OpenconfigRoutingPolicy_DefaultPolicyType
	OpenconfigRoutingPolicy_DefaultPolicyType_ACCEPT_ROUTE E_OpenconfigRoutingPolicy_DefaultPolicyType = 1
	// OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE corresponds to the value REJECT_ROUTE of OpenconfigRoutingPolicy_DefaultPolicyType
	OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE E_OpenconfigRoutingPolicy_DefaultPolicyType = 2
)

// E_OpenconfigRoutingPolicy_PolicyResultType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_PolicyResultType. An additional value named
// OpenconfigRoutingPolicy_PolicyResultType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_PolicyResultType int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_PolicyResultType implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_PolicyResultType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_PolicyResultType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_PolicyResultType.
func (E_OpenconfigRoutingPolicy_PolicyResultType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_PolicyResultType.
func (e E_OpenconfigRoutingPolicy_PolicyResultType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_PolicyResultType")
}

const (
	// OpenconfigRoutingPolicy_PolicyResultType_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_PolicyResultType
	OpenconfigRoutingPolicy_PolicyResultType_UNSET E_OpenconfigRoutingPolicy_PolicyResultType = 0
	// OpenconfigRoutingPolicy_PolicyResultType_ACCEPT_ROUTE corresponds to the value ACCEPT_ROUTE of OpenconfigRoutingPolicy_PolicyResultType
	OpenconfigRoutingPolicy_PolicyResultType_ACCEPT_ROUTE E_OpenconfigRoutingPolicy_PolicyResultType = 1
	// OpenconfigRoutingPolicy_PolicyResultType_REJECT_ROUTE corresponds to the value REJECT_ROUTE of OpenconfigRoutingPolicy_PolicyResultType
	OpenconfigRoutingPolicy_PolicyResultType_REJECT_ROUTE E_OpenconfigRoutingPolicy_PolicyResultType = 2
)

// E_OpenconfigSegmentRoutingTypes_EnlpType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSegmentRoutingTypes_EnlpType. An additional value named
// OpenconfigSegmentRoutingTypes_EnlpType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSegmentRoutingTypes_EnlpType int64

// IsYANGGoEnum ensures that OpenconfigSegmentRoutingTypes_EnlpType implements the yang.GoEnum
// interface. This ensures that OpenconfigSegmentRoutingTypes_EnlpType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSegmentRoutingTypes_EnlpType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSegmentRoutingTypes_EnlpType.
func (E_OpenconfigSegmentRoutingTypes_EnlpType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSegmentRoutingTypes_EnlpType.
func (e E_OpenconfigSegmentRoutingTypes_EnlpType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSegmentRoutingTypes_EnlpType")
}

const (
	// OpenconfigSegmentRoutingTypes_EnlpType_UNSET corresponds to the value UNSET of OpenconfigSegmentRoutingTypes_EnlpType
	OpenconfigSegmentRoutingTypes_EnlpType_UNSET E_OpenconfigSegmentRoutingTypes_EnlpType = 0
	// OpenconfigSegmentRoutingTypes_EnlpType_PUSH_IPV4_EXPLICIT_NULL corresponds to the value PUSH_IPV4_EXPLICIT_NULL of OpenconfigSegmentRoutingTypes_EnlpType
	OpenconfigSegmentRoutingTypes_EnlpType_PUSH_IPV4_EXPLICIT_NULL E_OpenconfigSegmentRoutingTypes_EnlpType = 1
	// OpenconfigSegmentRoutingTypes_EnlpType_PUSH_IPV6_EXPLICIT_NULL corresponds to the value PUSH_IPV6_EXPLICIT_NULL of OpenconfigSegmentRoutingTypes_EnlpType
	OpenconfigSegmentRoutingTypes_EnlpType_PUSH_IPV6_EXPLICIT_NULL E_OpenconfigSegmentRoutingTypes_EnlpType = 2
	// OpenconfigSegmentRoutingTypes_EnlpType_PUSH_IPV46_EXPLICIT_NULL corresponds to the value PUSH_IPV46_EXPLICIT_NULL of OpenconfigSegmentRoutingTypes_EnlpType
	OpenconfigSegmentRoutingTypes_EnlpType_PUSH_IPV46_EXPLICIT_NULL E_OpenconfigSegmentRoutingTypes_EnlpType = 3
	// OpenconfigSegmentRoutingTypes_EnlpType_NO_EXPLICIT_NULL corresponds to the value NO_EXPLICIT_NULL of OpenconfigSegmentRoutingTypes_EnlpType
	OpenconfigSegmentRoutingTypes_EnlpType_NO_EXPLICIT_NULL E_OpenconfigSegmentRoutingTypes_EnlpType = 4
)

// E_OpenconfigSegmentRoutingTypes_SrDataplaneType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSegmentRoutingTypes_SrDataplaneType. An additional value named
// OpenconfigSegmentRoutingTypes_SrDataplaneType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSegmentRoutingTypes_SrDataplaneType int64

// IsYANGGoEnum ensures that OpenconfigSegmentRoutingTypes_SrDataplaneType implements the yang.GoEnum
// interface. This ensures that OpenconfigSegmentRoutingTypes_SrDataplaneType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSegmentRoutingTypes_SrDataplaneType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSegmentRoutingTypes_SrDataplaneType.
func (E_OpenconfigSegmentRoutingTypes_SrDataplaneType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSegmentRoutingTypes_SrDataplaneType.
func (e E_OpenconfigSegmentRoutingTypes_SrDataplaneType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSegmentRoutingTypes_SrDataplaneType")
}

const (
	// OpenconfigSegmentRoutingTypes_SrDataplaneType_UNSET corresponds to the value UNSET of OpenconfigSegmentRoutingTypes_SrDataplaneType
	OpenconfigSegmentRoutingTypes_SrDataplaneType_UNSET E_OpenconfigSegmentRoutingTypes_SrDataplaneType = 0
	// OpenconfigSegmentRoutingTypes_SrDataplaneType_MPLS corresponds to the value MPLS of OpenconfigSegmentRoutingTypes_SrDataplaneType
	OpenconfigSegmentRoutingTypes_SrDataplaneType_MPLS E_OpenconfigSegmentRoutingTypes_SrDataplaneType = 1
	// OpenconfigSegmentRoutingTypes_SrDataplaneType_IPV6 corresponds to the value IPV6 of OpenconfigSegmentRoutingTypes_SrDataplaneType
	OpenconfigSegmentRoutingTypes_SrDataplaneType_IPV6 E_OpenconfigSegmentRoutingTypes_SrDataplaneType = 2
)

// E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason is a derived int64 type which is used to represent
// the enumerated node OpenconfigSegmentRoutingTypes_SrteInvalidSlReason. An additional value named
// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason int64

// IsYANGGoEnum ensures that OpenconfigSegmentRoutingTypes_SrteInvalidSlReason implements the yang.GoEnum
// interface. This ensures that OpenconfigSegmentRoutingTypes_SrteInvalidSlReason can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSegmentRoutingTypes_SrteInvalidSlReason.
func (E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason.
func (e E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason")
}

const (
	// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_UNSET corresponds to the value UNSET of OpenconfigSegmentRoutingTypes_SrteInvalidSlReason
	OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_UNSET E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason = 0
	// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_EMPTY_SL corresponds to the value EMPTY_SL of OpenconfigSegmentRoutingTypes_SrteInvalidSlReason
	OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_EMPTY_SL E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason = 1
	// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_ZERO_WEIGHT corresponds to the value ZERO_WEIGHT of OpenconfigSegmentRoutingTypes_SrteInvalidSlReason
	OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_ZERO_WEIGHT E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason = 2
	// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_FIRST_SID_UNRESOLVABLE corresponds to the value FIRST_SID_UNRESOLVABLE of OpenconfigSegmentRoutingTypes_SrteInvalidSlReason
	OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_FIRST_SID_UNRESOLVABLE E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason = 3
	// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_OTHER_SID_UNRESOLVABLE corresponds to the value OTHER_SID_UNRESOLVABLE of OpenconfigSegmentRoutingTypes_SrteInvalidSlReason
	OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_OTHER_SID_UNRESOLVABLE E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason = 4
	// OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_VERIFICATION_FAIL corresponds to the value VERIFICATION_FAIL of OpenconfigSegmentRoutingTypes_SrteInvalidSlReason
	OpenconfigSegmentRoutingTypes_SrteInvalidSlReason_VERIFICATION_FAIL E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason = 5
)

// E_OpenconfigSegmentRoutingTypes_SrteProtocolType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSegmentRoutingTypes_SrteProtocolType. An additional value named
// OpenconfigSegmentRoutingTypes_SrteProtocolType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSegmentRoutingTypes_SrteProtocolType int64

// IsYANGGoEnum ensures that OpenconfigSegmentRoutingTypes_SrteProtocolType implements the yang.GoEnum
// interface. This ensures that OpenconfigSegmentRoutingTypes_SrteProtocolType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSegmentRoutingTypes_SrteProtocolType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSegmentRoutingTypes_SrteProtocolType.
func (E_OpenconfigSegmentRoutingTypes_SrteProtocolType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSegmentRoutingTypes_SrteProtocolType.
func (e E_OpenconfigSegmentRoutingTypes_SrteProtocolType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSegmentRoutingTypes_SrteProtocolType")
}

const (
	// OpenconfigSegmentRoutingTypes_SrteProtocolType_UNSET corresponds to the value UNSET of OpenconfigSegmentRoutingTypes_SrteProtocolType
	OpenconfigSegmentRoutingTypes_SrteProtocolType_UNSET E_OpenconfigSegmentRoutingTypes_SrteProtocolType = 0
	// OpenconfigSegmentRoutingTypes_SrteProtocolType_PCEP corresponds to the value PCEP of OpenconfigSegmentRoutingTypes_SrteProtocolType
	OpenconfigSegmentRoutingTypes_SrteProtocolType_PCEP E_OpenconfigSegmentRoutingTypes_SrteProtocolType = 11
	// OpenconfigSegmentRoutingTypes_SrteProtocolType_BGP corresponds to the value BGP of OpenconfigSegmentRoutingTypes_SrteProtocolType
	OpenconfigSegmentRoutingTypes_SrteProtocolType_BGP E_OpenconfigSegmentRoutingTypes_SrteProtocolType = 21
	// OpenconfigSegmentRoutingTypes_SrteProtocolType_CONFIG corresponds to the value CONFIG of OpenconfigSegmentRoutingTypes_SrteProtocolType
	OpenconfigSegmentRoutingTypes_SrteProtocolType_CONFIG E_OpenconfigSegmentRoutingTypes_SrteProtocolType = 31
)

// E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT is a derived int64 type which is used to represent
// the enumerated node OpenconfigSpanningTreeTypes_STP_EDGE_PORT. An additional value named
// OpenconfigSpanningTreeTypes_STP_EDGE_PORT_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT int64

// IsYANGGoEnum ensures that OpenconfigSpanningTreeTypes_STP_EDGE_PORT implements the yang.GoEnum
// interface. This ensures that OpenconfigSpanningTreeTypes_STP_EDGE_PORT can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSpanningTreeTypes_STP_EDGE_PORT.
func (E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT.
func (e E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT")
}

const (
	// OpenconfigSpanningTreeTypes_STP_EDGE_PORT_UNSET corresponds to the value UNSET of OpenconfigSpanningTreeTypes_STP_EDGE_PORT
	OpenconfigSpanningTreeTypes_STP_EDGE_PORT_UNSET E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT = 0
	// OpenconfigSpanningTreeTypes_STP_EDGE_PORT_EDGE_AUTO corresponds to the value EDGE_AUTO of OpenconfigSpanningTreeTypes_STP_EDGE_PORT
	OpenconfigSpanningTreeTypes_STP_EDGE_PORT_EDGE_AUTO E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT = 1
	// OpenconfigSpanningTreeTypes_STP_EDGE_PORT_EDGE_DISABLE corresponds to the value EDGE_DISABLE of OpenconfigSpanningTreeTypes_STP_EDGE_PORT
	OpenconfigSpanningTreeTypes_STP_EDGE_PORT_EDGE_DISABLE E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT = 2
	// OpenconfigSpanningTreeTypes_STP_EDGE_PORT_EDGE_ENABLE corresponds to the value EDGE_ENABLE of OpenconfigSpanningTreeTypes_STP_EDGE_PORT
	OpenconfigSpanningTreeTypes_STP_EDGE_PORT_EDGE_ENABLE E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT = 3
)

// E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE is a derived int64 type which is used to represent
// the enumerated node OpenconfigSpanningTreeTypes_STP_PORT_ROLE. An additional value named
// OpenconfigSpanningTreeTypes_STP_PORT_ROLE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE int64

// IsYANGGoEnum ensures that OpenconfigSpanningTreeTypes_STP_PORT_ROLE implements the yang.GoEnum
// interface. This ensures that OpenconfigSpanningTreeTypes_STP_PORT_ROLE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSpanningTreeTypes_STP_PORT_ROLE.
func (E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE.
func (e E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE")
}

const (
	// OpenconfigSpanningTreeTypes_STP_PORT_ROLE_UNSET corresponds to the value UNSET of OpenconfigSpanningTreeTypes_STP_PORT_ROLE
	OpenconfigSpanningTreeTypes_STP_PORT_ROLE_UNSET E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE = 0
	// OpenconfigSpanningTreeTypes_STP_PORT_ROLE_ALTERNATE corresponds to the value ALTERNATE of OpenconfigSpanningTreeTypes_STP_PORT_ROLE
	OpenconfigSpanningTreeTypes_STP_PORT_ROLE_ALTERNATE E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE = 1
	// OpenconfigSpanningTreeTypes_STP_PORT_ROLE_BACKUP corresponds to the value BACKUP of OpenconfigSpanningTreeTypes_STP_PORT_ROLE
	OpenconfigSpanningTreeTypes_STP_PORT_ROLE_BACKUP E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE = 2
	// OpenconfigSpanningTreeTypes_STP_PORT_ROLE_DESIGNATED corresponds to the value DESIGNATED of OpenconfigSpanningTreeTypes_STP_PORT_ROLE
	OpenconfigSpanningTreeTypes_STP_PORT_ROLE_DESIGNATED E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE = 3
	// OpenconfigSpanningTreeTypes_STP_PORT_ROLE_ROOT corresponds to the value ROOT of OpenconfigSpanningTreeTypes_STP_PORT_ROLE
	OpenconfigSpanningTreeTypes_STP_PORT_ROLE_ROOT E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE = 4
)

// E_OpenconfigSpanningTreeTypes_STP_PORT_STATE is a derived int64 type which is used to represent
// the enumerated node OpenconfigSpanningTreeTypes_STP_PORT_STATE. An additional value named
// OpenconfigSpanningTreeTypes_STP_PORT_STATE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSpanningTreeTypes_STP_PORT_STATE int64

// IsYANGGoEnum ensures that OpenconfigSpanningTreeTypes_STP_PORT_STATE implements the yang.GoEnum
// interface. This ensures that OpenconfigSpanningTreeTypes_STP_PORT_STATE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSpanningTreeTypes_STP_PORT_STATE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSpanningTreeTypes_STP_PORT_STATE.
func (E_OpenconfigSpanningTreeTypes_STP_PORT_STATE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSpanningTreeTypes_STP_PORT_STATE.
func (e E_OpenconfigSpanningTreeTypes_STP_PORT_STATE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSpanningTreeTypes_STP_PORT_STATE")
}

const (
	// OpenconfigSpanningTreeTypes_STP_PORT_STATE_UNSET corresponds to the value UNSET of OpenconfigSpanningTreeTypes_STP_PORT_STATE
	OpenconfigSpanningTreeTypes_STP_PORT_STATE_UNSET E_OpenconfigSpanningTreeTypes_STP_PORT_STATE = 0
	// OpenconfigSpanningTreeTypes_STP_PORT_STATE_BLOCKING corresponds to the value BLOCKING of OpenconfigSpanningTreeTypes_STP_PORT_STATE
	OpenconfigSpanningTreeTypes_STP_PORT_STATE_BLOCKING E_OpenconfigSpanningTreeTypes_STP_PORT_STATE = 1
	// OpenconfigSpanningTreeTypes_STP_PORT_STATE_DISABLED corresponds to the value DISABLED of OpenconfigSpanningTreeTypes_STP_PORT_STATE
	OpenconfigSpanningTreeTypes_STP_PORT_STATE_DISABLED E_OpenconfigSpanningTreeTypes_STP_PORT_STATE = 2
	// OpenconfigSpanningTreeTypes_STP_PORT_STATE_FORWARDING corresponds to the value FORWARDING of OpenconfigSpanningTreeTypes_STP_PORT_STATE
	OpenconfigSpanningTreeTypes_STP_PORT_STATE_FORWARDING E_OpenconfigSpanningTreeTypes_STP_PORT_STATE = 3
	// OpenconfigSpanningTreeTypes_STP_PORT_STATE_LEARNING corresponds to the value LEARNING of OpenconfigSpanningTreeTypes_STP_PORT_STATE
	OpenconfigSpanningTreeTypes_STP_PORT_STATE_LEARNING E_OpenconfigSpanningTreeTypes_STP_PORT_STATE = 4
	// OpenconfigSpanningTreeTypes_STP_PORT_STATE_LISTENING corresponds to the value LISTENING of OpenconfigSpanningTreeTypes_STP_PORT_STATE
	OpenconfigSpanningTreeTypes_STP_PORT_STATE_LISTENING E_OpenconfigSpanningTreeTypes_STP_PORT_STATE = 5
)

// E_OpenconfigSpanningTreeTypes_STP_PROTOCOL is a derived int64 type which is used to represent
// the enumerated node OpenconfigSpanningTreeTypes_STP_PROTOCOL. An additional value named
// OpenconfigSpanningTreeTypes_STP_PROTOCOL_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSpanningTreeTypes_STP_PROTOCOL int64

// IsYANGGoEnum ensures that OpenconfigSpanningTreeTypes_STP_PROTOCOL implements the yang.GoEnum
// interface. This ensures that OpenconfigSpanningTreeTypes_STP_PROTOCOL can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSpanningTreeTypes_STP_PROTOCOL) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSpanningTreeTypes_STP_PROTOCOL.
func (E_OpenconfigSpanningTreeTypes_STP_PROTOCOL) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSpanningTreeTypes_STP_PROTOCOL.
func (e E_OpenconfigSpanningTreeTypes_STP_PROTOCOL) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSpanningTreeTypes_STP_PROTOCOL")
}

const (
	// OpenconfigSpanningTreeTypes_STP_PROTOCOL_UNSET corresponds to the value UNSET of OpenconfigSpanningTreeTypes_STP_PROTOCOL
	OpenconfigSpanningTreeTypes_STP_PROTOCOL_UNSET E_OpenconfigSpanningTreeTypes_STP_PROTOCOL = 0
	// OpenconfigSpanningTreeTypes_STP_PROTOCOL_MSTP corresponds to the value MSTP of OpenconfigSpanningTreeTypes_STP_PROTOCOL
	OpenconfigSpanningTreeTypes_STP_PROTOCOL_MSTP E_OpenconfigSpanningTreeTypes_STP_PROTOCOL = 1
	// OpenconfigSpanningTreeTypes_STP_PROTOCOL_RAPID_PVST corresponds to the value RAPID_PVST of OpenconfigSpanningTreeTypes_STP_PROTOCOL
	OpenconfigSpanningTreeTypes_STP_PROTOCOL_RAPID_PVST E_OpenconfigSpanningTreeTypes_STP_PROTOCOL = 2
	// OpenconfigSpanningTreeTypes_STP_PROTOCOL_RSTP corresponds to the value RSTP of OpenconfigSpanningTreeTypes_STP_PROTOCOL
	OpenconfigSpanningTreeTypes_STP_PROTOCOL_RSTP E_OpenconfigSpanningTreeTypes_STP_PROTOCOL = 3
)

// E_OpenconfigSpanningTreeTypes_StpGuardType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSpanningTreeTypes_StpGuardType. An additional value named
// OpenconfigSpanningTreeTypes_StpGuardType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSpanningTreeTypes_StpGuardType int64

// IsYANGGoEnum ensures that OpenconfigSpanningTreeTypes_StpGuardType implements the yang.GoEnum
// interface. This ensures that OpenconfigSpanningTreeTypes_StpGuardType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSpanningTreeTypes_StpGuardType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSpanningTreeTypes_StpGuardType.
func (E_OpenconfigSpanningTreeTypes_StpGuardType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSpanningTreeTypes_StpGuardType.
func (e E_OpenconfigSpanningTreeTypes_StpGuardType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSpanningTreeTypes_StpGuardType")
}

const (
	// OpenconfigSpanningTreeTypes_StpGuardType_UNSET corresponds to the value UNSET of OpenconfigSpanningTreeTypes_StpGuardType
	OpenconfigSpanningTreeTypes_StpGuardType_UNSET E_OpenconfigSpanningTreeTypes_StpGuardType = 0
	// OpenconfigSpanningTreeTypes_StpGuardType_ROOT corresponds to the value ROOT of OpenconfigSpanningTreeTypes_StpGuardType
	OpenconfigSpanningTreeTypes_StpGuardType_ROOT E_OpenconfigSpanningTreeTypes_StpGuardType = 1
	// OpenconfigSpanningTreeTypes_StpGuardType_LOOP corresponds to the value LOOP of OpenconfigSpanningTreeTypes_StpGuardType
	OpenconfigSpanningTreeTypes_StpGuardType_LOOP E_OpenconfigSpanningTreeTypes_StpGuardType = 2
	// OpenconfigSpanningTreeTypes_StpGuardType_NONE corresponds to the value NONE of OpenconfigSpanningTreeTypes_StpGuardType
	OpenconfigSpanningTreeTypes_StpGuardType_NONE E_OpenconfigSpanningTreeTypes_StpGuardType = 3
)

// E_OpenconfigSpanningTreeTypes_StpLinkType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSpanningTreeTypes_StpLinkType. An additional value named
// OpenconfigSpanningTreeTypes_StpLinkType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSpanningTreeTypes_StpLinkType int64

// IsYANGGoEnum ensures that OpenconfigSpanningTreeTypes_StpLinkType implements the yang.GoEnum
// interface. This ensures that OpenconfigSpanningTreeTypes_StpLinkType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSpanningTreeTypes_StpLinkType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSpanningTreeTypes_StpLinkType.
func (E_OpenconfigSpanningTreeTypes_StpLinkType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSpanningTreeTypes_StpLinkType.
func (e E_OpenconfigSpanningTreeTypes_StpLinkType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSpanningTreeTypes_StpLinkType")
}

const (
	// OpenconfigSpanningTreeTypes_StpLinkType_UNSET corresponds to the value UNSET of OpenconfigSpanningTreeTypes_StpLinkType
	OpenconfigSpanningTreeTypes_StpLinkType_UNSET E_OpenconfigSpanningTreeTypes_StpLinkType = 0
	// OpenconfigSpanningTreeTypes_StpLinkType_P2P corresponds to the value P2P of OpenconfigSpanningTreeTypes_StpLinkType
	OpenconfigSpanningTreeTypes_StpLinkType_P2P E_OpenconfigSpanningTreeTypes_StpLinkType = 1
	// OpenconfigSpanningTreeTypes_StpLinkType_SHARED corresponds to the value SHARED of OpenconfigSpanningTreeTypes_StpLinkType
	OpenconfigSpanningTreeTypes_StpLinkType_SHARED E_OpenconfigSpanningTreeTypes_StpLinkType = 2
)

// E_OpenconfigSystemLogging_SYSLOG_FACILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystemLogging_SYSLOG_FACILITY. An additional value named
// OpenconfigSystemLogging_SYSLOG_FACILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystemLogging_SYSLOG_FACILITY int64

// IsYANGGoEnum ensures that OpenconfigSystemLogging_SYSLOG_FACILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigSystemLogging_SYSLOG_FACILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystemLogging_SYSLOG_FACILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystemLogging_SYSLOG_FACILITY.
func (E_OpenconfigSystemLogging_SYSLOG_FACILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystemLogging_SYSLOG_FACILITY.
func (e E_OpenconfigSystemLogging_SYSLOG_FACILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystemLogging_SYSLOG_FACILITY")
}

const (
	// OpenconfigSystemLogging_SYSLOG_FACILITY_UNSET corresponds to the value UNSET of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_UNSET E_OpenconfigSystemLogging_SYSLOG_FACILITY = 0
	// OpenconfigSystemLogging_SYSLOG_FACILITY_ALL corresponds to the value ALL of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_ALL E_OpenconfigSystemLogging_SYSLOG_FACILITY = 1
	// OpenconfigSystemLogging_SYSLOG_FACILITY_AUDIT corresponds to the value AUDIT of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_AUDIT E_OpenconfigSystemLogging_SYSLOG_FACILITY = 2
	// OpenconfigSystemLogging_SYSLOG_FACILITY_AUTH corresponds to the value AUTH of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_AUTH E_OpenconfigSystemLogging_SYSLOG_FACILITY = 3
	// OpenconfigSystemLogging_SYSLOG_FACILITY_AUTHPRIV corresponds to the value AUTHPRIV of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_AUTHPRIV E_OpenconfigSystemLogging_SYSLOG_FACILITY = 4
	// OpenconfigSystemLogging_SYSLOG_FACILITY_CONSOLE corresponds to the value CONSOLE of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_CONSOLE E_OpenconfigSystemLogging_SYSLOG_FACILITY = 5
	// OpenconfigSystemLogging_SYSLOG_FACILITY_KERNEL corresponds to the value KERNEL of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_KERNEL E_OpenconfigSystemLogging_SYSLOG_FACILITY = 6
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL0 corresponds to the value LOCAL0 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL0 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 7
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL1 corresponds to the value LOCAL1 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL1 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 8
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL2 corresponds to the value LOCAL2 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL2 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 9
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL3 corresponds to the value LOCAL3 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL3 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 10
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL4 corresponds to the value LOCAL4 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL4 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 11
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL5 corresponds to the value LOCAL5 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL5 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 12
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL6 corresponds to the value LOCAL6 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL6 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 13
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL7 corresponds to the value LOCAL7 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL7 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 14
	// OpenconfigSystemLogging_SYSLOG_FACILITY_MAIL corresponds to the value MAIL of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_MAIL E_OpenconfigSystemLogging_SYSLOG_FACILITY = 15
	// OpenconfigSystemLogging_SYSLOG_FACILITY_NTP corresponds to the value NTP of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_NTP E_OpenconfigSystemLogging_SYSLOG_FACILITY = 16
	// OpenconfigSystemLogging_SYSLOG_FACILITY_SYSLOG corresponds to the value SYSLOG of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_SYSLOG E_OpenconfigSystemLogging_SYSLOG_FACILITY = 17
	// OpenconfigSystemLogging_SYSLOG_FACILITY_SYSTEM_DAEMON corresponds to the value SYSTEM_DAEMON of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_SYSTEM_DAEMON E_OpenconfigSystemLogging_SYSLOG_FACILITY = 18
	// OpenconfigSystemLogging_SYSLOG_FACILITY_USER corresponds to the value USER of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_USER E_OpenconfigSystemLogging_SYSLOG_FACILITY = 19
)

// E_OpenconfigSystemLogging_SyslogSeverity is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystemLogging_SyslogSeverity. An additional value named
// OpenconfigSystemLogging_SyslogSeverity_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystemLogging_SyslogSeverity int64

// IsYANGGoEnum ensures that OpenconfigSystemLogging_SyslogSeverity implements the yang.GoEnum
// interface. This ensures that OpenconfigSystemLogging_SyslogSeverity can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystemLogging_SyslogSeverity) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystemLogging_SyslogSeverity.
func (E_OpenconfigSystemLogging_SyslogSeverity) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystemLogging_SyslogSeverity.
func (e E_OpenconfigSystemLogging_SyslogSeverity) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystemLogging_SyslogSeverity")
}

const (
	// OpenconfigSystemLogging_SyslogSeverity_UNSET corresponds to the value UNSET of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_UNSET E_OpenconfigSystemLogging_SyslogSeverity = 0
	// OpenconfigSystemLogging_SyslogSeverity_EMERGENCY corresponds to the value EMERGENCY of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_EMERGENCY E_OpenconfigSystemLogging_SyslogSeverity = 1
	// OpenconfigSystemLogging_SyslogSeverity_ALERT corresponds to the value ALERT of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_ALERT E_OpenconfigSystemLogging_SyslogSeverity = 2
	// OpenconfigSystemLogging_SyslogSeverity_CRITICAL corresponds to the value CRITICAL of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_CRITICAL E_OpenconfigSystemLogging_SyslogSeverity = 3
	// OpenconfigSystemLogging_SyslogSeverity_ERROR corresponds to the value ERROR of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_ERROR E_OpenconfigSystemLogging_SyslogSeverity = 4
	// OpenconfigSystemLogging_SyslogSeverity_WARNING corresponds to the value WARNING of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_WARNING E_OpenconfigSystemLogging_SyslogSeverity = 5
	// OpenconfigSystemLogging_SyslogSeverity_NOTICE corresponds to the value NOTICE of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_NOTICE E_OpenconfigSystemLogging_SyslogSeverity = 6
	// OpenconfigSystemLogging_SyslogSeverity_INFORMATIONAL corresponds to the value INFORMATIONAL of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_INFORMATIONAL E_OpenconfigSystemLogging_SyslogSeverity = 7
	// OpenconfigSystemLogging_SyslogSeverity_DEBUG corresponds to the value DEBUG of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_DEBUG E_OpenconfigSystemLogging_SyslogSeverity = 8
)

// E_OpenconfigSystem_NTP_AUTH_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_NTP_AUTH_TYPE. An additional value named
// OpenconfigSystem_NTP_AUTH_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_NTP_AUTH_TYPE int64

// IsYANGGoEnum ensures that OpenconfigSystem_NTP_AUTH_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_NTP_AUTH_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_NTP_AUTH_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_NTP_AUTH_TYPE.
func (E_OpenconfigSystem_NTP_AUTH_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_NTP_AUTH_TYPE.
func (e E_OpenconfigSystem_NTP_AUTH_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_NTP_AUTH_TYPE")
}

const (
	// OpenconfigSystem_NTP_AUTH_TYPE_UNSET corresponds to the value UNSET of OpenconfigSystem_NTP_AUTH_TYPE
	OpenconfigSystem_NTP_AUTH_TYPE_UNSET E_OpenconfigSystem_NTP_AUTH_TYPE = 0
	// OpenconfigSystem_NTP_AUTH_TYPE_NTP_AUTH_MD5 corresponds to the value NTP_AUTH_MD5 of OpenconfigSystem_NTP_AUTH_TYPE
	OpenconfigSystem_NTP_AUTH_TYPE_NTP_AUTH_MD5 E_OpenconfigSystem_NTP_AUTH_TYPE = 1
)

// E_OpenconfigTransportLineProtection_APS_PATHS is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportLineProtection_APS_PATHS. An additional value named
// OpenconfigTransportLineProtection_APS_PATHS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportLineProtection_APS_PATHS int64

// IsYANGGoEnum ensures that OpenconfigTransportLineProtection_APS_PATHS implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportLineProtection_APS_PATHS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportLineProtection_APS_PATHS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportLineProtection_APS_PATHS.
func (E_OpenconfigTransportLineProtection_APS_PATHS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportLineProtection_APS_PATHS.
func (e E_OpenconfigTransportLineProtection_APS_PATHS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportLineProtection_APS_PATHS")
}

const (
	// OpenconfigTransportLineProtection_APS_PATHS_UNSET corresponds to the value UNSET of OpenconfigTransportLineProtection_APS_PATHS
	OpenconfigTransportLineProtection_APS_PATHS_UNSET E_OpenconfigTransportLineProtection_APS_PATHS = 0
	// OpenconfigTransportLineProtection_APS_PATHS_PRIMARY corresponds to the value PRIMARY of OpenconfigTransportLineProtection_APS_PATHS
	OpenconfigTransportLineProtection_APS_PATHS_PRIMARY E_OpenconfigTransportLineProtection_APS_PATHS = 1
	// OpenconfigTransportLineProtection_APS_PATHS_SECONDARY corresponds to the value SECONDARY of OpenconfigTransportLineProtection_APS_PATHS
	OpenconfigTransportLineProtection_APS_PATHS_SECONDARY E_OpenconfigTransportLineProtection_APS_PATHS = 2
)

// E_OpenconfigTransportTypes_AdminStateType is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_AdminStateType. An additional value named
// OpenconfigTransportTypes_AdminStateType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_AdminStateType int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_AdminStateType implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_AdminStateType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_AdminStateType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_AdminStateType.
func (E_OpenconfigTransportTypes_AdminStateType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_AdminStateType.
func (e E_OpenconfigTransportTypes_AdminStateType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_AdminStateType")
}

const (
	// OpenconfigTransportTypes_AdminStateType_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_AdminStateType
	OpenconfigTransportTypes_AdminStateType_UNSET E_OpenconfigTransportTypes_AdminStateType = 0
	// OpenconfigTransportTypes_AdminStateType_ENABLED corresponds to the value ENABLED of OpenconfigTransportTypes_AdminStateType
	OpenconfigTransportTypes_AdminStateType_ENABLED E_OpenconfigTransportTypes_AdminStateType = 1
	// OpenconfigTransportTypes_AdminStateType_DISABLED corresponds to the value DISABLED of OpenconfigTransportTypes_AdminStateType
	OpenconfigTransportTypes_AdminStateType_DISABLED E_OpenconfigTransportTypes_AdminStateType = 2
	// OpenconfigTransportTypes_AdminStateType_MAINT corresponds to the value MAINT of OpenconfigTransportTypes_AdminStateType
	OpenconfigTransportTypes_AdminStateType_MAINT E_OpenconfigTransportTypes_AdminStateType = 3
)

// E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_ETHERNET_PMD_TYPE. An additional value named
// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_ETHERNET_PMD_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_ETHERNET_PMD_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_ETHERNET_PMD_TYPE.
func (E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE.
func (e E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE")
}

const (
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_UNSET E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 0
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_CLR4 corresponds to the value ETH_100GBASE_CLR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_CLR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 1
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_CR4 corresponds to the value ETH_100GBASE_CR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_CR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 2
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_CWDM4 corresponds to the value ETH_100GBASE_CWDM4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_CWDM4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 3
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_ER4 corresponds to the value ETH_100GBASE_ER4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_ER4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 4
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_LR4 corresponds to the value ETH_100GBASE_LR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_LR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 5
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_PSM4 corresponds to the value ETH_100GBASE_PSM4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_PSM4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 6
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_SR10 corresponds to the value ETH_100GBASE_SR10 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_SR10 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 7
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_SR4 corresponds to the value ETH_100GBASE_SR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100GBASE_SR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 8
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100G_ACC corresponds to the value ETH_100G_ACC of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100G_ACC E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 9
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100G_AOC corresponds to the value ETH_100G_AOC of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_100G_AOC E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 10
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_ER corresponds to the value ETH_10GBASE_ER of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_ER E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 11
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_LR corresponds to the value ETH_10GBASE_LR of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_LR E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 12
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_LRM corresponds to the value ETH_10GBASE_LRM of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_LRM E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 13
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_SR corresponds to the value ETH_10GBASE_SR of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_SR E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 14
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_ZR corresponds to the value ETH_10GBASE_ZR of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_10GBASE_ZR E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 15
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_CR4 corresponds to the value ETH_40GBASE_CR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_CR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 16
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_ER4 corresponds to the value ETH_40GBASE_ER4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_ER4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 17
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_LR4 corresponds to the value ETH_40GBASE_LR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_LR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 18
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_PSM4 corresponds to the value ETH_40GBASE_PSM4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_PSM4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 19
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_SR4 corresponds to the value ETH_40GBASE_SR4 of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_40GBASE_SR4 E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 20
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_4X10GBASE_LR corresponds to the value ETH_4X10GBASE_LR of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_4X10GBASE_LR E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 21
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_4X10GBASE_SR corresponds to the value ETH_4X10GBASE_SR of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_4X10GBASE_SR E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 22
	// OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_UNDEFINED corresponds to the value ETH_UNDEFINED of OpenconfigTransportTypes_ETHERNET_PMD_TYPE
	OpenconfigTransportTypes_ETHERNET_PMD_TYPE_ETH_UNDEFINED E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE = 23
)

// E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE. An additional value named
// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE.
func (E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE.
func (e E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE")
}

const (
	// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE
	OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_UNSET E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE = 0
	// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_AOC_CONNECTOR corresponds to the value AOC_CONNECTOR of OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE
	OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_AOC_CONNECTOR E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE = 1
	// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_DAC_CONNECTOR corresponds to the value DAC_CONNECTOR of OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE
	OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_DAC_CONNECTOR E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE = 2
	// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_LC_CONNECTOR corresponds to the value LC_CONNECTOR of OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE
	OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_LC_CONNECTOR E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE = 3
	// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_MPO_CONNECTOR corresponds to the value MPO_CONNECTOR of OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE
	OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_MPO_CONNECTOR E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE = 4
	// OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_SC_CONNECTOR corresponds to the value SC_CONNECTOR of OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE
	OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE_SC_CONNECTOR E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE = 5
)

// E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL. An additional value named
// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL.
func (E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL.
func (e E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL")
}

const (
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_UNSET E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 0
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_AMP corresponds to the value AMP of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_AMP E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 1
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_BMP corresponds to the value BMP of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_BMP E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 2
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_CBR corresponds to the value CBR of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_CBR E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 3
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_GFP_F corresponds to the value GFP_F of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_GFP_F E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 4
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_GFP_T corresponds to the value GFP_T of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_GFP_T E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 5
	// OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_GMP corresponds to the value GMP of OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL
	OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL_GMP E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL = 6
)

// E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE. An additional value named
// OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE.
func (E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE.
func (e E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE")
}

const (
	// OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE
	OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_UNSET E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE = 0
	// OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_PROT_ETHERNET corresponds to the value PROT_ETHERNET of OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE
	OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_PROT_ETHERNET E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE = 1
	// OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_PROT_OTN corresponds to the value PROT_OTN of OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE
	OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE_PROT_OTN E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE = 2
)

// E_OpenconfigTransportTypes_LoopbackModeType is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_LoopbackModeType. An additional value named
// OpenconfigTransportTypes_LoopbackModeType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_LoopbackModeType int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_LoopbackModeType implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_LoopbackModeType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_LoopbackModeType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_LoopbackModeType.
func (E_OpenconfigTransportTypes_LoopbackModeType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_LoopbackModeType.
func (e E_OpenconfigTransportTypes_LoopbackModeType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_LoopbackModeType")
}

const (
	// OpenconfigTransportTypes_LoopbackModeType_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_LoopbackModeType
	OpenconfigTransportTypes_LoopbackModeType_UNSET E_OpenconfigTransportTypes_LoopbackModeType = 0
	// OpenconfigTransportTypes_LoopbackModeType_NONE corresponds to the value NONE of OpenconfigTransportTypes_LoopbackModeType
	OpenconfigTransportTypes_LoopbackModeType_NONE E_OpenconfigTransportTypes_LoopbackModeType = 1
	// OpenconfigTransportTypes_LoopbackModeType_FACILITY corresponds to the value FACILITY of OpenconfigTransportTypes_LoopbackModeType
	OpenconfigTransportTypes_LoopbackModeType_FACILITY E_OpenconfigTransportTypes_LoopbackModeType = 2
	// OpenconfigTransportTypes_LoopbackModeType_TERMINAL corresponds to the value TERMINAL of OpenconfigTransportTypes_LoopbackModeType
	OpenconfigTransportTypes_LoopbackModeType_TERMINAL E_OpenconfigTransportTypes_LoopbackModeType = 3
)

// E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_OPTICAL_PORT_TYPE. An additional value named
// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_OPTICAL_PORT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_OPTICAL_PORT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_OPTICAL_PORT_TYPE.
func (E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE.
func (e E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE")
}

const (
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_UNSET E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 0
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_ADD corresponds to the value ADD of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_ADD E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 1
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_DROP corresponds to the value DROP of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_DROP E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 2
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_EGRESS corresponds to the value EGRESS of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_EGRESS E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 3
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_INGRESS corresponds to the value INGRESS of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_INGRESS E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 4
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_MONITOR corresponds to the value MONITOR of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_MONITOR E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 5
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_TERMINAL_CLIENT corresponds to the value TERMINAL_CLIENT of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_TERMINAL_CLIENT E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 6
	// OpenconfigTransportTypes_OPTICAL_PORT_TYPE_TERMINAL_LINE corresponds to the value TERMINAL_LINE of OpenconfigTransportTypes_OPTICAL_PORT_TYPE
	OpenconfigTransportTypes_OPTICAL_PORT_TYPE_TERMINAL_LINE E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE = 7
)

// E_OpenconfigTransportTypes_OTN_APPLICATION_CODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_OTN_APPLICATION_CODE. An additional value named
// OpenconfigTransportTypes_OTN_APPLICATION_CODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_OTN_APPLICATION_CODE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_OTN_APPLICATION_CODE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_OTN_APPLICATION_CODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_OTN_APPLICATION_CODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_OTN_APPLICATION_CODE.
func (E_OpenconfigTransportTypes_OTN_APPLICATION_CODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_OTN_APPLICATION_CODE.
func (e E_OpenconfigTransportTypes_OTN_APPLICATION_CODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_OTN_APPLICATION_CODE")
}

const (
	// OpenconfigTransportTypes_OTN_APPLICATION_CODE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_OTN_APPLICATION_CODE
	OpenconfigTransportTypes_OTN_APPLICATION_CODE_UNSET E_OpenconfigTransportTypes_OTN_APPLICATION_CODE = 0
	// OpenconfigTransportTypes_OTN_APPLICATION_CODE_OTN_UNDEFINED corresponds to the value OTN_UNDEFINED of OpenconfigTransportTypes_OTN_APPLICATION_CODE
	OpenconfigTransportTypes_OTN_APPLICATION_CODE_OTN_UNDEFINED E_OpenconfigTransportTypes_OTN_APPLICATION_CODE = 1
	// OpenconfigTransportTypes_OTN_APPLICATION_CODE_P1L1_2D1 corresponds to the value P1L1_2D1 of OpenconfigTransportTypes_OTN_APPLICATION_CODE
	OpenconfigTransportTypes_OTN_APPLICATION_CODE_P1L1_2D1 E_OpenconfigTransportTypes_OTN_APPLICATION_CODE = 2
	// OpenconfigTransportTypes_OTN_APPLICATION_CODE_P1L1_2D2 corresponds to the value P1L1_2D2 of OpenconfigTransportTypes_OTN_APPLICATION_CODE
	OpenconfigTransportTypes_OTN_APPLICATION_CODE_P1L1_2D2 E_OpenconfigTransportTypes_OTN_APPLICATION_CODE = 3
	// OpenconfigTransportTypes_OTN_APPLICATION_CODE_P1S1_2D2 corresponds to the value P1S1_2D2 of OpenconfigTransportTypes_OTN_APPLICATION_CODE
	OpenconfigTransportTypes_OTN_APPLICATION_CODE_P1S1_2D2 E_OpenconfigTransportTypes_OTN_APPLICATION_CODE = 4
)

// E_OpenconfigTransportTypes_SONET_APPLICATION_CODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_SONET_APPLICATION_CODE. An additional value named
// OpenconfigTransportTypes_SONET_APPLICATION_CODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_SONET_APPLICATION_CODE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_SONET_APPLICATION_CODE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_SONET_APPLICATION_CODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_SONET_APPLICATION_CODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_SONET_APPLICATION_CODE.
func (E_OpenconfigTransportTypes_SONET_APPLICATION_CODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_SONET_APPLICATION_CODE.
func (e E_OpenconfigTransportTypes_SONET_APPLICATION_CODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_SONET_APPLICATION_CODE")
}

const (
	// OpenconfigTransportTypes_SONET_APPLICATION_CODE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_SONET_APPLICATION_CODE
	OpenconfigTransportTypes_SONET_APPLICATION_CODE_UNSET E_OpenconfigTransportTypes_SONET_APPLICATION_CODE = 0
	// OpenconfigTransportTypes_SONET_APPLICATION_CODE_SONET_UNDEFINED corresponds to the value SONET_UNDEFINED of OpenconfigTransportTypes_SONET_APPLICATION_CODE
	OpenconfigTransportTypes_SONET_APPLICATION_CODE_SONET_UNDEFINED E_OpenconfigTransportTypes_SONET_APPLICATION_CODE = 1
	// OpenconfigTransportTypes_SONET_APPLICATION_CODE_VSR2000_3R2 corresponds to the value VSR2000_3R2 of OpenconfigTransportTypes_SONET_APPLICATION_CODE
	OpenconfigTransportTypes_SONET_APPLICATION_CODE_VSR2000_3R2 E_OpenconfigTransportTypes_SONET_APPLICATION_CODE = 2
	// OpenconfigTransportTypes_SONET_APPLICATION_CODE_VSR2000_3R3 corresponds to the value VSR2000_3R3 of OpenconfigTransportTypes_SONET_APPLICATION_CODE
	OpenconfigTransportTypes_SONET_APPLICATION_CODE_VSR2000_3R3 E_OpenconfigTransportTypes_SONET_APPLICATION_CODE = 3
	// OpenconfigTransportTypes_SONET_APPLICATION_CODE_VSR2000_3R5 corresponds to the value VSR2000_3R5 of OpenconfigTransportTypes_SONET_APPLICATION_CODE
	OpenconfigTransportTypes_SONET_APPLICATION_CODE_VSR2000_3R5 E_OpenconfigTransportTypes_SONET_APPLICATION_CODE = 4
)

// E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE. An additional value named
// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE.
func (E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE.
func (e E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE")
}

const (
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_UNSET E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 0
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP corresponds to the value CFP of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 1
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP2 corresponds to the value CFP2 of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP2 E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 2
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP2_ACO corresponds to the value CFP2_ACO of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP2_ACO E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 3
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP4 corresponds to the value CFP4 of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CFP4 E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 4
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CPAK corresponds to the value CPAK of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_CPAK E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 5
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_NON_PLUGGABLE corresponds to the value NON_PLUGGABLE of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_NON_PLUGGABLE E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 6
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_OTHER corresponds to the value OTHER of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_OTHER E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 7
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_QSFP corresponds to the value QSFP of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_QSFP E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 8
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_QSFP28 corresponds to the value QSFP28 of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_QSFP28 E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 9
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_QSFP_PLUS corresponds to the value QSFP_PLUS of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_QSFP_PLUS E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 10
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_SFP corresponds to the value SFP of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_SFP E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 11
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_SFP_PLUS corresponds to the value SFP_PLUS of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_SFP_PLUS E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 12
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_X2 corresponds to the value X2 of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_X2 E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 13
	// OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_XFP corresponds to the value XFP of OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE
	OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE_XFP E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE = 14
)

// E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE. An additional value named
// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE.
func (E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE.
func (e E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE")
}

const (
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_UNSET E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 0
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_100GE corresponds to the value PROT_100GE of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_100GE E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 1
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_100G_MLG corresponds to the value PROT_100G_MLG of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_100G_MLG E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 2
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_10GE_LAN corresponds to the value PROT_10GE_LAN of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_10GE_LAN E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 3
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_10GE_WAN corresponds to the value PROT_10GE_WAN of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_10GE_WAN E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 4
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_1GE corresponds to the value PROT_1GE of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_1GE E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 5
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_400GE corresponds to the value PROT_400GE of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_400GE E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 6
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_40GE corresponds to the value PROT_40GE of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_40GE E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 7
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OC192 corresponds to the value PROT_OC192 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OC192 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 8
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OC48 corresponds to the value PROT_OC48 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OC48 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 9
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OC768 corresponds to the value PROT_OC768 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OC768 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 10
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU2 corresponds to the value PROT_ODU2 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU2 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 11
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU2E corresponds to the value PROT_ODU2E of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU2E E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 12
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU3 corresponds to the value PROT_ODU3 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU3 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 13
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU4 corresponds to the value PROT_ODU4 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODU4 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 14
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODUCN corresponds to the value PROT_ODUCN of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_ODUCN E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 15
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU1E corresponds to the value PROT_OTU1E of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU1E E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 16
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU2 corresponds to the value PROT_OTU2 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU2 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 17
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU2E corresponds to the value PROT_OTU2E of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU2E E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 18
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU3 corresponds to the value PROT_OTU3 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU3 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 19
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU4 corresponds to the value PROT_OTU4 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTU4 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 20
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTUCN corresponds to the value PROT_OTUCN of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_OTUCN E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 21
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_STM16 corresponds to the value PROT_STM16 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_STM16 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 22
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_STM256 corresponds to the value PROT_STM256 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_STM256 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 23
	// OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_STM64 corresponds to the value PROT_STM64 of OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE
	OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE_PROT_STM64 E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE = 24
)

// E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE. An additional value named
// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE.
func (E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE.
func (e E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE")
}

const (
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_UNSET E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 0
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1000G corresponds to the value TRIB_RATE_1000G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1000G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 1
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_100G corresponds to the value TRIB_RATE_100G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_100G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 2
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1050G corresponds to the value TRIB_RATE_1050G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1050G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 3
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_10G corresponds to the value TRIB_RATE_10G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_10G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 4
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1100G corresponds to the value TRIB_RATE_1100G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1100G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 5
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1150G corresponds to the value TRIB_RATE_1150G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1150G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 6
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1200G corresponds to the value TRIB_RATE_1200G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1200G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 7
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1250G corresponds to the value TRIB_RATE_1250G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1250G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 8
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1300G corresponds to the value TRIB_RATE_1300G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1300G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 9
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1350G corresponds to the value TRIB_RATE_1350G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1350G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 10
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1400G corresponds to the value TRIB_RATE_1400G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1400G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 11
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1450G corresponds to the value TRIB_RATE_1450G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1450G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 12
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1500G corresponds to the value TRIB_RATE_1500G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1500G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 13
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_150G corresponds to the value TRIB_RATE_150G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_150G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 14
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1550G corresponds to the value TRIB_RATE_1550G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1550G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 15
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1600G corresponds to the value TRIB_RATE_1600G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1600G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 16
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1G corresponds to the value TRIB_RATE_1G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_1G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 17
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_2_5G corresponds to the value TRIB_RATE_2_5G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_2_5G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 18
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_200G corresponds to the value TRIB_RATE_200G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_200G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 19
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_250G corresponds to the value TRIB_RATE_250G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_250G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 20
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_300G corresponds to the value TRIB_RATE_300G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_300G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 21
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_350G corresponds to the value TRIB_RATE_350G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_350G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 22
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_400G corresponds to the value TRIB_RATE_400G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_400G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 23
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_40G corresponds to the value TRIB_RATE_40G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_40G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 24
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_450G corresponds to the value TRIB_RATE_450G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_450G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 25
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_500G corresponds to the value TRIB_RATE_500G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_500G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 26
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_550G corresponds to the value TRIB_RATE_550G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_550G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 27
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_600G corresponds to the value TRIB_RATE_600G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_600G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 28
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_650G corresponds to the value TRIB_RATE_650G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_650G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 29
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_700G corresponds to the value TRIB_RATE_700G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_700G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 30
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_750G corresponds to the value TRIB_RATE_750G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_750G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 31
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_800G corresponds to the value TRIB_RATE_800G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_800G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 32
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_850G corresponds to the value TRIB_RATE_850G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_850G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 33
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_900G corresponds to the value TRIB_RATE_900G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_900G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 34
	// OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_950G corresponds to the value TRIB_RATE_950G of OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE
	OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE_TRIB_RATE_950G E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE = 35
)

// E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY. An additional value named
// OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY int64

// IsYANGGoEnum ensures that OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY implements the yang.GoEnum
// interface. This ensures that OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY.
func (E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY.
func (e E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY")
}

const (
	// OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_UNSET corresponds to the value UNSET of OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY
	OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_UNSET E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY = 0
	// OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_TRIB_SLOT_1_25G corresponds to the value TRIB_SLOT_1_25G of OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY
	OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_TRIB_SLOT_1_25G E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY = 1
	// OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_TRIB_SLOT_2_5G corresponds to the value TRIB_SLOT_2_5G of OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY
	OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_TRIB_SLOT_2_5G E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY = 2
	// OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_TRIB_SLOT_5G corresponds to the value TRIB_SLOT_5G of OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY
	OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY_TRIB_SLOT_5G E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY = 3
)

// E_OpenconfigTypes_ADDRESS_FAMILY is a derived int64 type which is used to represent
// the enumerated node OpenconfigTypes_ADDRESS_FAMILY. An additional value named
// OpenconfigTypes_ADDRESS_FAMILY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTypes_ADDRESS_FAMILY int64

// IsYANGGoEnum ensures that OpenconfigTypes_ADDRESS_FAMILY implements the yang.GoEnum
// interface. This ensures that OpenconfigTypes_ADDRESS_FAMILY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTypes_ADDRESS_FAMILY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTypes_ADDRESS_FAMILY.
func (E_OpenconfigTypes_ADDRESS_FAMILY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTypes_ADDRESS_FAMILY.
func (e E_OpenconfigTypes_ADDRESS_FAMILY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTypes_ADDRESS_FAMILY")
}

const (
	// OpenconfigTypes_ADDRESS_FAMILY_UNSET corresponds to the value UNSET of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_UNSET E_OpenconfigTypes_ADDRESS_FAMILY = 0
	// OpenconfigTypes_ADDRESS_FAMILY_IPV4 corresponds to the value IPV4 of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_IPV4 E_OpenconfigTypes_ADDRESS_FAMILY = 1
	// OpenconfigTypes_ADDRESS_FAMILY_IPV6 corresponds to the value IPV6 of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_IPV6 E_OpenconfigTypes_ADDRESS_FAMILY = 2
	// OpenconfigTypes_ADDRESS_FAMILY_L2_ETHERNET corresponds to the value L2_ETHERNET of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_L2_ETHERNET E_OpenconfigTypes_ADDRESS_FAMILY = 3
	// OpenconfigTypes_ADDRESS_FAMILY_MPLS corresponds to the value MPLS of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_MPLS E_OpenconfigTypes_ADDRESS_FAMILY = 4
)

// E_OpenconfigVlanTypes_TPID_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigVlanTypes_TPID_TYPES. An additional value named
// OpenconfigVlanTypes_TPID_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigVlanTypes_TPID_TYPES int64

// IsYANGGoEnum ensures that OpenconfigVlanTypes_TPID_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigVlanTypes_TPID_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigVlanTypes_TPID_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigVlanTypes_TPID_TYPES.
func (E_OpenconfigVlanTypes_TPID_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigVlanTypes_TPID_TYPES.
func (e E_OpenconfigVlanTypes_TPID_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigVlanTypes_TPID_TYPES")
}

const (
	// OpenconfigVlanTypes_TPID_TYPES_UNSET corresponds to the value UNSET of OpenconfigVlanTypes_TPID_TYPES
	OpenconfigVlanTypes_TPID_TYPES_UNSET E_OpenconfigVlanTypes_TPID_TYPES = 0
	// OpenconfigVlanTypes_TPID_TYPES_TPID_0X8100 corresponds to the value TPID_0X8100 of OpenconfigVlanTypes_TPID_TYPES
	OpenconfigVlanTypes_TPID_TYPES_TPID_0X8100 E_OpenconfigVlanTypes_TPID_TYPES = 1
	// OpenconfigVlanTypes_TPID_TYPES_TPID_0X88A8 corresponds to the value TPID_0X88A8 of OpenconfigVlanTypes_TPID_TYPES
	OpenconfigVlanTypes_TPID_TYPES_TPID_0X88A8 E_OpenconfigVlanTypes_TPID_TYPES = 2
	// OpenconfigVlanTypes_TPID_TYPES_TPID_0X9100 corresponds to the value TPID_0X9100 of OpenconfigVlanTypes_TPID_TYPES
	OpenconfigVlanTypes_TPID_TYPES_TPID_0X9100 E_OpenconfigVlanTypes_TPID_TYPES = 3
	// OpenconfigVlanTypes_TPID_TYPES_TPID_0X9200 corresponds to the value TPID_0X9200 of OpenconfigVlanTypes_TPID_TYPES
	OpenconfigVlanTypes_TPID_TYPES_TPID_0X9200 E_OpenconfigVlanTypes_TPID_TYPES = 4
	// OpenconfigVlanTypes_TPID_TYPES_TPID_ANY corresponds to the value TPID_ANY of OpenconfigVlanTypes_TPID_TYPES
	OpenconfigVlanTypes_TPID_TYPES_TPID_ANY E_OpenconfigVlanTypes_TPID_TYPES = 5
)

// E_OpenconfigVlanTypes_VlanModeType is a derived int64 type which is used to represent
// the enumerated node OpenconfigVlanTypes_VlanModeType. An additional value named
// OpenconfigVlanTypes_VlanModeType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigVlanTypes_VlanModeType int64

// IsYANGGoEnum ensures that OpenconfigVlanTypes_VlanModeType implements the yang.GoEnum
// interface. This ensures that OpenconfigVlanTypes_VlanModeType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigVlanTypes_VlanModeType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigVlanTypes_VlanModeType.
func (E_OpenconfigVlanTypes_VlanModeType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigVlanTypes_VlanModeType.
func (e E_OpenconfigVlanTypes_VlanModeType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigVlanTypes_VlanModeType")
}

const (
	// OpenconfigVlanTypes_VlanModeType_UNSET corresponds to the value UNSET of OpenconfigVlanTypes_VlanModeType
	OpenconfigVlanTypes_VlanModeType_UNSET E_OpenconfigVlanTypes_VlanModeType = 0
	// OpenconfigVlanTypes_VlanModeType_ACCESS corresponds to the value ACCESS of OpenconfigVlanTypes_VlanModeType
	OpenconfigVlanTypes_VlanModeType_ACCESS E_OpenconfigVlanTypes_VlanModeType = 1
	// OpenconfigVlanTypes_VlanModeType_TRUNK corresponds to the value TRUNK of OpenconfigVlanTypes_VlanModeType
	OpenconfigVlanTypes_VlanModeType_TRUNK E_OpenconfigVlanTypes_VlanModeType = 2
)

// E_OpenconfigVlanTypes_VlanStackAction is a derived int64 type which is used to represent
// the enumerated node OpenconfigVlanTypes_VlanStackAction. An additional value named
// OpenconfigVlanTypes_VlanStackAction_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigVlanTypes_VlanStackAction int64

// IsYANGGoEnum ensures that OpenconfigVlanTypes_VlanStackAction implements the yang.GoEnum
// interface. This ensures that OpenconfigVlanTypes_VlanStackAction can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigVlanTypes_VlanStackAction) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigVlanTypes_VlanStackAction.
func (E_OpenconfigVlanTypes_VlanStackAction) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigVlanTypes_VlanStackAction.
func (e E_OpenconfigVlanTypes_VlanStackAction) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigVlanTypes_VlanStackAction")
}

const (
	// OpenconfigVlanTypes_VlanStackAction_UNSET corresponds to the value UNSET of OpenconfigVlanTypes_VlanStackAction
	OpenconfigVlanTypes_VlanStackAction_UNSET E_OpenconfigVlanTypes_VlanStackAction = 0
	// OpenconfigVlanTypes_VlanStackAction_PUSH corresponds to the value PUSH of OpenconfigVlanTypes_VlanStackAction
	OpenconfigVlanTypes_VlanStackAction_PUSH E_OpenconfigVlanTypes_VlanStackAction = 1
	// OpenconfigVlanTypes_VlanStackAction_POP corresponds to the value POP of OpenconfigVlanTypes_VlanStackAction
	OpenconfigVlanTypes_VlanStackAction_POP E_OpenconfigVlanTypes_VlanStackAction = 2
	// OpenconfigVlanTypes_VlanStackAction_SWAP corresponds to the value SWAP of OpenconfigVlanTypes_VlanStackAction
	OpenconfigVlanTypes_VlanStackAction_SWAP E_OpenconfigVlanTypes_VlanStackAction = 3
)

// E_PrefixSet_Mode is a derived int64 type which is used to represent
// the enumerated node PrefixSet_Mode. An additional value named
// PrefixSet_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_PrefixSet_Mode int64

// IsYANGGoEnum ensures that PrefixSet_Mode implements the yang.GoEnum
// interface. This ensures that PrefixSet_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_PrefixSet_Mode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  PrefixSet_Mode.
func (E_PrefixSet_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_PrefixSet_Mode.
func (e E_PrefixSet_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_PrefixSet_Mode")
}

const (
	// PrefixSet_Mode_UNSET corresponds to the value UNSET of PrefixSet_Mode
	PrefixSet_Mode_UNSET E_PrefixSet_Mode = 0
	// PrefixSet_Mode_IPV4 corresponds to the value IPV4 of PrefixSet_Mode
	PrefixSet_Mode_IPV4 E_PrefixSet_Mode = 1
	// PrefixSet_Mode_IPV6 corresponds to the value IPV6 of PrefixSet_Mode
	PrefixSet_Mode_IPV6 E_PrefixSet_Mode = 2
	// PrefixSet_Mode_MIXED corresponds to the value MIXED of PrefixSet_Mode
	PrefixSet_Mode_MIXED E_PrefixSet_Mode = 3
)

// E_PrefixSid_Flags is a derived int64 type which is used to represent
// the enumerated node PrefixSid_Flags. An additional value named
// PrefixSid_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_PrefixSid_Flags int64

// IsYANGGoEnum ensures that PrefixSid_Flags implements the yang.GoEnum
// interface. This ensures that PrefixSid_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_PrefixSid_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  PrefixSid_Flags.
func (E_PrefixSid_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_PrefixSid_Flags.
func (e E_PrefixSid_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_PrefixSid_Flags")
}

const (
	// PrefixSid_Flags_UNSET corresponds to the value UNSET of PrefixSid_Flags
	PrefixSid_Flags_UNSET E_PrefixSid_Flags = 0
	// PrefixSid_Flags_READVERTISEMENT corresponds to the value READVERTISEMENT of PrefixSid_Flags
	PrefixSid_Flags_READVERTISEMENT E_PrefixSid_Flags = 1
	// PrefixSid_Flags_NODE corresponds to the value NODE of PrefixSid_Flags
	PrefixSid_Flags_NODE E_PrefixSid_Flags = 2
	// PrefixSid_Flags_NO_PHP corresponds to the value NO_PHP of PrefixSid_Flags
	PrefixSid_Flags_NO_PHP E_PrefixSid_Flags = 3
	// PrefixSid_Flags_EXPLICIT_NULL corresponds to the value EXPLICIT_NULL of PrefixSid_Flags
	PrefixSid_Flags_EXPLICIT_NULL E_PrefixSid_Flags = 4
	// PrefixSid_Flags_VALUE corresponds to the value VALUE of PrefixSid_Flags
	PrefixSid_Flags_VALUE E_PrefixSid_Flags = 5
	// PrefixSid_Flags_LOCAL corresponds to the value LOCAL of PrefixSid_Flags
	PrefixSid_Flags_LOCAL E_PrefixSid_Flags = 6
)

// E_PrefixSid_LabelOptions is a derived int64 type which is used to represent
// the enumerated node PrefixSid_LabelOptions. An additional value named
// PrefixSid_LabelOptions_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_PrefixSid_LabelOptions int64

// IsYANGGoEnum ensures that PrefixSid_LabelOptions implements the yang.GoEnum
// interface. This ensures that PrefixSid_LabelOptions can be identified as a
// mapped type for a YANG enumeration.
func (E_PrefixSid_LabelOptions) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  PrefixSid_LabelOptions.
func (E_PrefixSid_LabelOptions) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_PrefixSid_LabelOptions.
func (e E_PrefixSid_LabelOptions) String() string {
	return ygot.EnumLogString(e, int64(e), "E_PrefixSid_LabelOptions")
}

const (
	// PrefixSid_LabelOptions_UNSET corresponds to the value UNSET of PrefixSid_LabelOptions
	PrefixSid_LabelOptions_UNSET E_PrefixSid_LabelOptions = 0
	// PrefixSid_LabelOptions_NO_PHP corresponds to the value NO_PHP of PrefixSid_LabelOptions
	PrefixSid_LabelOptions_NO_PHP E_PrefixSid_LabelOptions = 1
	// PrefixSid_LabelOptions_EXPLICIT_NULL corresponds to the value EXPLICIT_NULL of PrefixSid_LabelOptions
	PrefixSid_LabelOptions_EXPLICIT_NULL E_PrefixSid_LabelOptions = 2
)

// E_PrefixSid_SidScope is a derived int64 type which is used to represent
// the enumerated node PrefixSid_SidScope. An additional value named
// PrefixSid_SidScope_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_PrefixSid_SidScope int64

// IsYANGGoEnum ensures that PrefixSid_SidScope implements the yang.GoEnum
// interface. This ensures that PrefixSid_SidScope can be identified as a
// mapped type for a YANG enumeration.
func (E_PrefixSid_SidScope) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  PrefixSid_SidScope.
func (E_PrefixSid_SidScope) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_PrefixSid_SidScope.
func (e E_PrefixSid_SidScope) String() string {
	return ygot.EnumLogString(e, int64(e), "E_PrefixSid_SidScope")
}

const (
	// PrefixSid_SidScope_UNSET corresponds to the value UNSET of PrefixSid_SidScope
	PrefixSid_SidScope_UNSET E_PrefixSid_SidScope = 0
	// PrefixSid_SidScope_LOCAL corresponds to the value LOCAL of PrefixSid_SidScope
	PrefixSid_SidScope_LOCAL E_PrefixSid_SidScope = 1
	// PrefixSid_SidScope_GLOBAL corresponds to the value GLOBAL of PrefixSid_SidScope
	PrefixSid_SidScope_GLOBAL E_PrefixSid_SidScope = 2
)

// E_PrefixSid_SidValueType is a derived int64 type which is used to represent
// the enumerated node PrefixSid_SidValueType. An additional value named
// PrefixSid_SidValueType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_PrefixSid_SidValueType int64

// IsYANGGoEnum ensures that PrefixSid_SidValueType implements the yang.GoEnum
// interface. This ensures that PrefixSid_SidValueType can be identified as a
// mapped type for a YANG enumeration.
func (E_PrefixSid_SidValueType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  PrefixSid_SidValueType.
func (E_PrefixSid_SidValueType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_PrefixSid_SidValueType.
func (e E_PrefixSid_SidValueType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_PrefixSid_SidValueType")
}

const (
	// PrefixSid_SidValueType_UNSET corresponds to the value UNSET of PrefixSid_SidValueType
	PrefixSid_SidValueType_UNSET E_PrefixSid_SidValueType = 0
	// PrefixSid_SidValueType_ABSOLUTE corresponds to the value ABSOLUTE of PrefixSid_SidValueType
	PrefixSid_SidValueType_ABSOLUTE E_PrefixSid_SidValueType = 1
	// PrefixSid_SidValueType_INDEX corresponds to the value INDEX of PrefixSid_SidValueType
	PrefixSid_SidValueType_INDEX E_PrefixSid_SidValueType = 2
)

// E_ProxyArp_Mode is a derived int64 type which is used to represent
// the enumerated node ProxyArp_Mode. An additional value named
// ProxyArp_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_ProxyArp_Mode int64

// IsYANGGoEnum ensures that ProxyArp_Mode implements the yang.GoEnum
// interface. This ensures that ProxyArp_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_ProxyArp_Mode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  ProxyArp_Mode.
func (E_ProxyArp_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_ProxyArp_Mode.
func (e E_ProxyArp_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_ProxyArp_Mode")
}

const (
	// ProxyArp_Mode_UNSET corresponds to the value UNSET of ProxyArp_Mode
	ProxyArp_Mode_UNSET E_ProxyArp_Mode = 0
	// ProxyArp_Mode_DISABLE corresponds to the value DISABLE of ProxyArp_Mode
	ProxyArp_Mode_DISABLE E_ProxyArp_Mode = 1
	// ProxyArp_Mode_REMOTE_ONLY corresponds to the value REMOTE_ONLY of ProxyArp_Mode
	ProxyArp_Mode_REMOTE_ONLY E_ProxyArp_Mode = 2
	// ProxyArp_Mode_ALL corresponds to the value ALL of ProxyArp_Mode
	ProxyArp_Mode_ALL E_ProxyArp_Mode = 3
)

// E_RouterInformation_Tlv_Type_Enum is a derived int64 type which is used to represent
// the enumerated node RouterInformation_Tlv_Type_Enum. An additional value named
// RouterInformation_Tlv_Type_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_RouterInformation_Tlv_Type_Enum int64

// IsYANGGoEnum ensures that RouterInformation_Tlv_Type_Enum implements the yang.GoEnum
// interface. This ensures that RouterInformation_Tlv_Type_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_RouterInformation_Tlv_Type_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  RouterInformation_Tlv_Type_Enum.
func (E_RouterInformation_Tlv_Type_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_RouterInformation_Tlv_Type_Enum.
func (e E_RouterInformation_Tlv_Type_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_RouterInformation_Tlv_Type_Enum")
}

const (
	// RouterInformation_Tlv_Type_Enum_UNSET corresponds to the value UNSET of RouterInformation_Tlv_Type_Enum
	RouterInformation_Tlv_Type_Enum_UNSET E_RouterInformation_Tlv_Type_Enum = 0
	// RouterInformation_Tlv_Type_Enum_UNKNOWN corresponds to the value UNKNOWN of RouterInformation_Tlv_Type_Enum
	RouterInformation_Tlv_Type_Enum_UNKNOWN E_RouterInformation_Tlv_Type_Enum = 1
)

// E_SegmentRoutingAlgorithms_Algorithm is a derived int64 type which is used to represent
// the enumerated node SegmentRoutingAlgorithms_Algorithm. An additional value named
// SegmentRoutingAlgorithms_Algorithm_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_SegmentRoutingAlgorithms_Algorithm int64

// IsYANGGoEnum ensures that SegmentRoutingAlgorithms_Algorithm implements the yang.GoEnum
// interface. This ensures that SegmentRoutingAlgorithms_Algorithm can be identified as a
// mapped type for a YANG enumeration.
func (E_SegmentRoutingAlgorithms_Algorithm) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  SegmentRoutingAlgorithms_Algorithm.
func (E_SegmentRoutingAlgorithms_Algorithm) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_SegmentRoutingAlgorithms_Algorithm.
func (e E_SegmentRoutingAlgorithms_Algorithm) String() string {
	return ygot.EnumLogString(e, int64(e), "E_SegmentRoutingAlgorithms_Algorithm")
}

const (
	// SegmentRoutingAlgorithms_Algorithm_UNSET corresponds to the value UNSET of SegmentRoutingAlgorithms_Algorithm
	SegmentRoutingAlgorithms_Algorithm_UNSET E_SegmentRoutingAlgorithms_Algorithm = 0
	// SegmentRoutingAlgorithms_Algorithm_SPF corresponds to the value SPF of SegmentRoutingAlgorithms_Algorithm
	SegmentRoutingAlgorithms_Algorithm_SPF E_SegmentRoutingAlgorithms_Algorithm = 1
	// SegmentRoutingAlgorithms_Algorithm_STRICT_SPF corresponds to the value STRICT_SPF of SegmentRoutingAlgorithms_Algorithm
	SegmentRoutingAlgorithms_Algorithm_STRICT_SPF E_SegmentRoutingAlgorithms_Algorithm = 2
)

// E_SegmentRoutingCapability_Flags is a derived int64 type which is used to represent
// the enumerated node SegmentRoutingCapability_Flags. An additional value named
// SegmentRoutingCapability_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_SegmentRoutingCapability_Flags int64

// IsYANGGoEnum ensures that SegmentRoutingCapability_Flags implements the yang.GoEnum
// interface. This ensures that SegmentRoutingCapability_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_SegmentRoutingCapability_Flags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  SegmentRoutingCapability_Flags.
func (E_SegmentRoutingCapability_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_SegmentRoutingCapability_Flags.
func (e E_SegmentRoutingCapability_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_SegmentRoutingCapability_Flags")
}

const (
	// SegmentRoutingCapability_Flags_UNSET corresponds to the value UNSET of SegmentRoutingCapability_Flags
	SegmentRoutingCapability_Flags_UNSET E_SegmentRoutingCapability_Flags = 0
	// SegmentRoutingCapability_Flags_IPV4_MPLS corresponds to the value IPV4_MPLS of SegmentRoutingCapability_Flags
	SegmentRoutingCapability_Flags_IPV4_MPLS E_SegmentRoutingCapability_Flags = 1
	// SegmentRoutingCapability_Flags_IPV6_MPLS corresponds to the value IPV6_MPLS of SegmentRoutingCapability_Flags
	SegmentRoutingCapability_Flags_IPV6_MPLS E_SegmentRoutingCapability_Flags = 2
	// SegmentRoutingCapability_Flags_IPV6_SR corresponds to the value IPV6_SR of SegmentRoutingCapability_Flags
	SegmentRoutingCapability_Flags_IPV6_SR E_SegmentRoutingCapability_Flags = 3
)

// E_SegmentRoutingSidLabelRange_Tlv_Type_Enum is a derived int64 type which is used to represent
// the enumerated node SegmentRoutingSidLabelRange_Tlv_Type_Enum. An additional value named
// SegmentRoutingSidLabelRange_Tlv_Type_Enum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_SegmentRoutingSidLabelRange_Tlv_Type_Enum int64

// IsYANGGoEnum ensures that SegmentRoutingSidLabelRange_Tlv_Type_Enum implements the yang.GoEnum
// interface. This ensures that SegmentRoutingSidLabelRange_Tlv_Type_Enum can be identified as a
// mapped type for a YANG enumeration.
func (E_SegmentRoutingSidLabelRange_Tlv_Type_Enum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  SegmentRoutingSidLabelRange_Tlv_Type_Enum.
func (E_SegmentRoutingSidLabelRange_Tlv_Type_Enum) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_SegmentRoutingSidLabelRange_Tlv_Type_Enum.
func (e E_SegmentRoutingSidLabelRange_Tlv_Type_Enum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_SegmentRoutingSidLabelRange_Tlv_Type_Enum")
}

const (
	// SegmentRoutingSidLabelRange_Tlv_Type_Enum_UNSET corresponds to the value UNSET of SegmentRoutingSidLabelRange_Tlv_Type_Enum
	SegmentRoutingSidLabelRange_Tlv_Type_Enum_UNSET E_SegmentRoutingSidLabelRange_Tlv_Type_Enum = 0
	// SegmentRoutingSidLabelRange_Tlv_Type_Enum_UNKNOWN corresponds to the value UNKNOWN of SegmentRoutingSidLabelRange_Tlv_Type_Enum
	SegmentRoutingSidLabelRange_Tlv_Type_Enum_UNKNOWN E_SegmentRoutingSidLabelRange_Tlv_Type_Enum = 1
)

// E_Segment_Type is a derived int64 type which is used to represent
// the enumerated node Segment_Type. An additional value named
// Segment_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Segment_Type int64

// IsYANGGoEnum ensures that Segment_Type implements the yang.GoEnum
// interface. This ensures that Segment_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_Segment_Type) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Segment_Type.
func (E_Segment_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Segment_Type.
func (e E_Segment_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Segment_Type")
}

const (
	// Segment_Type_UNSET corresponds to the value UNSET of Segment_Type
	Segment_Type_UNSET E_Segment_Type = 0
	// Segment_Type_MPLS_SID corresponds to the value MPLS_SID of Segment_Type
	Segment_Type_MPLS_SID E_Segment_Type = 2
	// Segment_Type_IPV6_SID corresponds to the value IPV6_SID of Segment_Type
	Segment_Type_IPV6_SID E_Segment_Type = 3
	// Segment_Type_IPV4_NODE_ADDRESS corresponds to the value IPV4_NODE_ADDRESS of Segment_Type
	Segment_Type_IPV4_NODE_ADDRESS E_Segment_Type = 4
	// Segment_Type_IPV6_NODE_ADDRESS corresponds to the value IPV6_NODE_ADDRESS of Segment_Type
	Segment_Type_IPV6_NODE_ADDRESS E_Segment_Type = 5
	// Segment_Type_IPV4_LOCAL_INTF_ID corresponds to the value IPV4_LOCAL_INTF_ID of Segment_Type
	Segment_Type_IPV4_LOCAL_INTF_ID E_Segment_Type = 6
	// Segment_Type_IPV4_LOCAL_REMOTE_ADDR corresponds to the value IPV4_LOCAL_REMOTE_ADDR of Segment_Type
	Segment_Type_IPV4_LOCAL_REMOTE_ADDR E_Segment_Type = 7
	// Segment_Type_IPV6_LOCAL_INTF_ID corresponds to the value IPV6_LOCAL_INTF_ID of Segment_Type
	Segment_Type_IPV6_LOCAL_INTF_ID E_Segment_Type = 8
	// Segment_Type_IPV6_LOCAL_REMOTE_ADDR corresponds to the value IPV6_LOCAL_REMOTE_ADDR of Segment_Type
	Segment_Type_IPV6_LOCAL_REMOTE_ADDR E_Segment_Type = 9
)

// E_Server_AssociationType is a derived int64 type which is used to represent
// the enumerated node Server_AssociationType. An additional value named
// Server_AssociationType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Server_AssociationType int64

// IsYANGGoEnum ensures that Server_AssociationType implements the yang.GoEnum
// interface. This ensures that Server_AssociationType can be identified as a
// mapped type for a YANG enumeration.
func (E_Server_AssociationType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Server_AssociationType.
func (E_Server_AssociationType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Server_AssociationType.
func (e E_Server_AssociationType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Server_AssociationType")
}

const (
	// Server_AssociationType_UNSET corresponds to the value UNSET of Server_AssociationType
	Server_AssociationType_UNSET E_Server_AssociationType = 0
	// Server_AssociationType_SERVER corresponds to the value SERVER of Server_AssociationType
	Server_AssociationType_SERVER E_Server_AssociationType = 1
	// Server_AssociationType_PEER corresponds to the value PEER of Server_AssociationType
	Server_AssociationType_PEER E_Server_AssociationType = 2
	// Server_AssociationType_POOL corresponds to the value POOL of Server_AssociationType
	Server_AssociationType_POOL E_Server_AssociationType = 3
)

// E_Session_Status is a derived int64 type which is used to represent
// the enumerated node Session_Status. An additional value named
// Session_Status_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Session_Status int64

// IsYANGGoEnum ensures that Session_Status implements the yang.GoEnum
// interface. This ensures that Session_Status can be identified as a
// mapped type for a YANG enumeration.
func (E_Session_Status) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Session_Status.
func (E_Session_Status) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Session_Status.
func (e E_Session_Status) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Session_Status")
}

const (
	// Session_Status_UNSET corresponds to the value UNSET of Session_Status
	Session_Status_UNSET E_Session_Status = 0
	// Session_Status_UP corresponds to the value UP of Session_Status
	Session_Status_UP E_Session_Status = 1
	// Session_Status_DOWN corresponds to the value DOWN of Session_Status
	Session_Status_DOWN E_Session_Status = 2
)

// E_SetTag_Mode is a derived int64 type which is used to represent
// the enumerated node SetTag_Mode. An additional value named
// SetTag_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_SetTag_Mode int64

// IsYANGGoEnum ensures that SetTag_Mode implements the yang.GoEnum
// interface. This ensures that SetTag_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_SetTag_Mode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  SetTag_Mode.
func (E_SetTag_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_SetTag_Mode.
func (e E_SetTag_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_SetTag_Mode")
}

const (
	// SetTag_Mode_UNSET corresponds to the value UNSET of SetTag_Mode
	SetTag_Mode_UNSET E_SetTag_Mode = 0
	// SetTag_Mode_INLINE corresponds to the value INLINE of SetTag_Mode
	SetTag_Mode_INLINE E_SetTag_Mode = 1
	// SetTag_Mode_REFERENCE corresponds to the value REFERENCE of SetTag_Mode
	SetTag_Mode_REFERENCE E_SetTag_Mode = 2
)

// E_SshServer_ProtocolVersion is a derived int64 type which is used to represent
// the enumerated node SshServer_ProtocolVersion. An additional value named
// SshServer_ProtocolVersion_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_SshServer_ProtocolVersion int64

// IsYANGGoEnum ensures that SshServer_ProtocolVersion implements the yang.GoEnum
// interface. This ensures that SshServer_ProtocolVersion can be identified as a
// mapped type for a YANG enumeration.
func (E_SshServer_ProtocolVersion) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  SshServer_ProtocolVersion.
func (E_SshServer_ProtocolVersion) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_SshServer_ProtocolVersion.
func (e E_SshServer_ProtocolVersion) String() string {
	return ygot.EnumLogString(e, int64(e), "E_SshServer_ProtocolVersion")
}

const (
	// SshServer_ProtocolVersion_UNSET corresponds to the value UNSET of SshServer_ProtocolVersion
	SshServer_ProtocolVersion_UNSET E_SshServer_ProtocolVersion = 0
	// SshServer_ProtocolVersion_V2 corresponds to the value V2 of SshServer_ProtocolVersion
	SshServer_ProtocolVersion_V2 E_SshServer_ProtocolVersion = 1
	// SshServer_ProtocolVersion_V1 corresponds to the value V1 of SshServer_ProtocolVersion
	SshServer_ProtocolVersion_V1 E_SshServer_ProtocolVersion = 2
	// SshServer_ProtocolVersion_V1_V2 corresponds to the value V1_V2 of SshServer_ProtocolVersion
	SshServer_ProtocolVersion_V1_V2 E_SshServer_ProtocolVersion = 3
)

// E_SubTlv_LinkType is a derived int64 type which is used to represent
// the enumerated node SubTlv_LinkType. An additional value named
// SubTlv_LinkType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_SubTlv_LinkType int64

// IsYANGGoEnum ensures that SubTlv_LinkType implements the yang.GoEnum
// interface. This ensures that SubTlv_LinkType can be identified as a
// mapped type for a YANG enumeration.
func (E_SubTlv_LinkType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  SubTlv_LinkType.
func (E_SubTlv_LinkType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_SubTlv_LinkType.
func (e E_SubTlv_LinkType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_SubTlv_LinkType")
}

const (
	// SubTlv_LinkType_UNSET corresponds to the value UNSET of SubTlv_LinkType
	SubTlv_LinkType_UNSET E_SubTlv_LinkType = 0
	// SubTlv_LinkType_POINT_TO_POINT corresponds to the value POINT_TO_POINT of SubTlv_LinkType
	SubTlv_LinkType_POINT_TO_POINT E_SubTlv_LinkType = 1
	// SubTlv_LinkType_MULTI_ACCESS corresponds to the value MULTI_ACCESS of SubTlv_LinkType
	SubTlv_LinkType_MULTI_ACCESS E_SubTlv_LinkType = 2
	// SubTlv_LinkType_UNKNOWN corresponds to the value UNKNOWN of SubTlv_LinkType
	SubTlv_LinkType_UNKNOWN E_SubTlv_LinkType = 3
)

// E_Tlv_Reason is a derived int64 type which is used to represent
// the enumerated node Tlv_Reason. An additional value named
// Tlv_Reason_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Tlv_Reason int64

// IsYANGGoEnum ensures that Tlv_Reason implements the yang.GoEnum
// interface. This ensures that Tlv_Reason can be identified as a
// mapped type for a YANG enumeration.
func (E_Tlv_Reason) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Tlv_Reason.
func (E_Tlv_Reason) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Tlv_Reason.
func (e E_Tlv_Reason) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Tlv_Reason")
}

const (
	// Tlv_Reason_UNSET corresponds to the value UNSET of Tlv_Reason
	Tlv_Reason_UNSET E_Tlv_Reason = 0
	// Tlv_Reason_UNKNOWN corresponds to the value UNKNOWN of Tlv_Reason
	Tlv_Reason_UNKNOWN E_Tlv_Reason = 1
	// Tlv_Reason_SOFTWARE_RESTART corresponds to the value SOFTWARE_RESTART of Tlv_Reason
	Tlv_Reason_SOFTWARE_RESTART E_Tlv_Reason = 2
	// Tlv_Reason_SOFTWARE_RELOAD_UPGRADE corresponds to the value SOFTWARE_RELOAD_UPGRADE of Tlv_Reason
	Tlv_Reason_SOFTWARE_RELOAD_UPGRADE E_Tlv_Reason = 3
	// Tlv_Reason_CONTROL_PROCESSOR_SWITCH corresponds to the value CONTROL_PROCESSOR_SWITCH of Tlv_Reason
	Tlv_Reason_CONTROL_PROCESSOR_SWITCH E_Tlv_Reason = 4
)

// E_Topology_Attributes is a derived int64 type which is used to represent
// the enumerated node Topology_Attributes. An additional value named
// Topology_Attributes_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Topology_Attributes int64

// IsYANGGoEnum ensures that Topology_Attributes implements the yang.GoEnum
// interface. This ensures that Topology_Attributes can be identified as a
// mapped type for a YANG enumeration.
func (E_Topology_Attributes) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Topology_Attributes.
func (E_Topology_Attributes) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Topology_Attributes.
func (e E_Topology_Attributes) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Topology_Attributes")
}

const (
	// Topology_Attributes_UNSET corresponds to the value UNSET of Topology_Attributes
	Topology_Attributes_UNSET E_Topology_Attributes = 0
	// Topology_Attributes_OVERLOAD corresponds to the value OVERLOAD of Topology_Attributes
	Topology_Attributes_OVERLOAD E_Topology_Attributes = 1
	// Topology_Attributes_ATTACHED corresponds to the value ATTACHED of Topology_Attributes
	Topology_Attributes_ATTACHED E_Topology_Attributes = 2
)

// E_Transceiver_Present is a derived int64 type which is used to represent
// the enumerated node Transceiver_Present. An additional value named
// Transceiver_Present_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Transceiver_Present int64

// IsYANGGoEnum ensures that Transceiver_Present implements the yang.GoEnum
// interface. This ensures that Transceiver_Present can be identified as a
// mapped type for a YANG enumeration.
func (E_Transceiver_Present) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Transceiver_Present.
func (E_Transceiver_Present) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Transceiver_Present.
func (e E_Transceiver_Present) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Transceiver_Present")
}

const (
	// Transceiver_Present_UNSET corresponds to the value UNSET of Transceiver_Present
	Transceiver_Present_UNSET E_Transceiver_Present = 0
	// Transceiver_Present_PRESENT corresponds to the value PRESENT of Transceiver_Present
	Transceiver_Present_PRESENT E_Transceiver_Present = 1
	// Transceiver_Present_NOT_PRESENT corresponds to the value NOT_PRESENT of Transceiver_Present
	Transceiver_Present_NOT_PRESENT E_Transceiver_Present = 2
)

// E_Vlan_Status is a derived int64 type which is used to represent
// the enumerated node Vlan_Status. An additional value named
// Vlan_Status_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_Vlan_Status int64

// IsYANGGoEnum ensures that Vlan_Status implements the yang.GoEnum
// interface. This ensures that Vlan_Status can be identified as a
// mapped type for a YANG enumeration.
func (E_Vlan_Status) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  Vlan_Status.
func (E_Vlan_Status) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_Vlan_Status.
func (e E_Vlan_Status) String() string {
	return ygot.EnumLogString(e, int64(e), "E_Vlan_Status")
}

const (
	// Vlan_Status_UNSET corresponds to the value UNSET of Vlan_Status
	Vlan_Status_UNSET E_Vlan_Status = 0
	// Vlan_Status_ACTIVE corresponds to the value ACTIVE of Vlan_Status
	Vlan_Status_ACTIVE E_Vlan_Status = 1
	// Vlan_Status_SUSPENDED corresponds to the value SUSPENDED of Vlan_Status
	Vlan_Status_SUSPENDED E_Vlan_Status = 2
)

// ΛEnum is a map, keyed by the name of the type defined for each enum in the
// generated Go code, which provides a mapping between the constant int64 value
// of each value of the enumeration, and the string that is used to represent it
// in the YANG schema. The map is named ΛEnum in order to avoid clash with any
// valid YANG identifier.
var ΛEnum = map[string]map[int64]ygot.EnumDefinition{
	"E_Address_Status": {
		1: {Name: "PREFERRED"},
		2: {Name: "DEPRECATED"},
		3: {Name: "INVALID"},
		4: {Name: "INACCESSIBLE"},
		5: {Name: "UNKNOWN"},
		6: {Name: "TENTATIVE"},
		7: {Name: "DUPLICATE"},
		8: {Name: "OPTIMISTIC"},
	},
	"E_AdjacencySid_Flags": {
		1: {Name: "ADDRESS_FAMILY"},
		2: {Name: "BACKUP"},
		3: {Name: "VALUE"},
		4: {Name: "LOCAL"},
		5: {Name: "SET"},
	},
	"E_AdjacencySid_SidId_Enum": {
		1: {Name: "DYNAMIC"},
	},
	"E_Adjacency_Nlpid": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
	},
	"E_ApsModule_ForceToPort": {
		1: {Name: "NONE"},
		2: {Name: "PRIMARY"},
		3: {Name: "SECONDARY"},
	},
	"E_AsExternalLsa_MetricType": {
		1: {Name: "TYPE_1"},
		2: {Name: "TYPE_2"},
	},
	"E_Assignment_AssignmentType": {
		1: {Name: "LOGICAL_CHANNEL"},
		2: {Name: "OPTICAL_CHANNEL"},
	},
	"E_Authentication_CryptoType": {
		1: {Name: "HMAC_MD5"},
		2: {Name: "CLEARTEXT"},
	},
	"E_BandwidthReservation_Priority_Enum": {
		1: {Name: "ALL"},
	},
	"E_Capability_Flags": {
		1: {Name: "FLOOD"},
		2: {Name: "DOWN"},
	},
	"E_Channel_LinkState": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
		3: {Name: "TESTING"},
	},
	"E_Cpu_Index_Enum": {
		1: {Name: "ALL"},
	},
	"E_DefaultMetric_Flags": {
		1: {Name: "INTERNAL"},
	},
	"E_Entry_EntryType": {
		1: {Name: "STATIC"},
		2: {Name: "DYNAMIC"},
	},
	"E_Ethernet_ClientAls": {
		1: {Name: "NONE"},
		2: {Name: "LASER_SHUTDOWN"},
		3: {Name: "ETHERNET"},
	},
	"E_Ethernet_DuplexMode": {
		1: {Name: "FULL"},
		2: {Name: "HALF"},
	},
	"E_Ethernet_NegotiatedDuplexMode": {
		1: {Name: "FULL"},
		2: {Name: "HALF"},
	},
	"E_Event_Record": {
		1: {Name: "START_STOP"},
		2: {Name: "STOP"},
	},
	"E_ExplicitRouteObject_Type": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
		3: {Name: "ASN"},
		4: {Name: "ASN4"},
		5: {Name: "LABEL"},
		6: {Name: "UNNUMBERED_INTERFACE"},
	},
	"E_ExtendedPrefix_AddressFamily": {
		1: {Name: "IPV4_UNICAST"},
	},
	"E_ExtendedPrefix_RouteType": {
		1: {Name: "UNSPECIFIED"},
		2: {Name: "INTRA_AREA"},
		4: {Name: "INTER_AREA"},
		6: {Name: "AS_EXTERNAL"},
		8: {Name: "NSSA_EXTERNAL"},
	},
	"E_Flags_Flags": {
		1: {Name: "EXTERNAL_FLAG"},
		2: {Name: "READVERTISEMENT_FLAG"},
		3: {Name: "NODE_FLAG"},
	},
	"E_Global_SummaryRouteCostMode": {
		1: {Name: "RFC1583_COMPATIBLE"},
		2: {Name: "RFC2328_COMPATIBLE"},
	},
	"E_GracefulRestart_Mode": {
		1: {Name: "HELPER_ONLY"},
		2: {Name: "BILATERAL"},
		3: {Name: "REMOTE_HELPER"},
	},
	"E_GrpcServer_ListenAddresses_Enum": {
		1: {Name: "ANY"},
	},
	"E_IETFInterfaces_InterfaceType": {
		1:   {Name: "a12MppSwitch", DefiningModule: "iana-if-type"},
		2:   {Name: "aal2", DefiningModule: "iana-if-type"},
		3:   {Name: "aal5", DefiningModule: "iana-if-type"},
		4:   {Name: "actelisMetaLOOP", DefiningModule: "iana-if-type"},
		5:   {Name: "adsl", DefiningModule: "iana-if-type"},
		6:   {Name: "adsl2", DefiningModule: "iana-if-type"},
		7:   {Name: "adsl2plus", DefiningModule: "iana-if-type"},
		8:   {Name: "aflane8023", DefiningModule: "iana-if-type"},
		9:   {Name: "aflane8025", DefiningModule: "iana-if-type"},
		10:  {Name: "aluELP", DefiningModule: "iana-if-type"},
		11:  {Name: "aluEpon", DefiningModule: "iana-if-type"},
		12:  {Name: "aluEponLogicalLink", DefiningModule: "iana-if-type"},
		13:  {Name: "aluEponOnu", DefiningModule: "iana-if-type"},
		14:  {Name: "aluEponPhysicalUni", DefiningModule: "iana-if-type"},
		15:  {Name: "aluGponOnu", DefiningModule: "iana-if-type"},
		16:  {Name: "aluGponPhysicalUni", DefiningModule: "iana-if-type"},
		17:  {Name: "arap", DefiningModule: "iana-if-type"},
		18:  {Name: "arcnet", DefiningModule: "iana-if-type"},
		19:  {Name: "arcnetPlus", DefiningModule: "iana-if-type"},
		20:  {Name: "async", DefiningModule: "iana-if-type"},
		21:  {Name: "atm", DefiningModule: "iana-if-type"},
		22:  {Name: "atmDxi", DefiningModule: "iana-if-type"},
		23:  {Name: "atmFuni", DefiningModule: "iana-if-type"},
		24:  {Name: "atmIma", DefiningModule: "iana-if-type"},
		25:  {Name: "atmLogical", DefiningModule: "iana-if-type"},
		26:  {Name: "atmRadio", DefiningModule: "iana-if-type"},
		27:  {Name: "atmSubInterface", DefiningModule: "iana-if-type"},
		28:  {Name: "atmVciEndPt", DefiningModule: "iana-if-type"},
		29:  {Name: "atmVirtual", DefiningModule: "iana-if-type"},
		30:  {Name: "atmbond", DefiningModule: "iana-if-type"},
		31:  {Name: "aviciOpticalEther", DefiningModule: "iana-if-type"},
		32:  {Name: "basicISDN", DefiningModule: "iana-if-type"},
		33:  {Name: "bgppolicyaccounting", DefiningModule: "iana-if-type"},
		34:  {Name: "bits", DefiningModule: "iana-if-type"},
		35:  {Name: "bridge", DefiningModule: "iana-if-type"},
		36:  {Name: "bsc", DefiningModule: "iana-if-type"},
		37:  {Name: "cableDownstreamRfPort", DefiningModule: "iana-if-type"},
		38:  {Name: "capwapDot11Bss", DefiningModule: "iana-if-type"},
		39:  {Name: "capwapDot11Profile", DefiningModule: "iana-if-type"},
		40:  {Name: "capwapWtpVirtualRadio", DefiningModule: "iana-if-type"},
		41:  {Name: "cblVectaStar", DefiningModule: "iana-if-type"},
		42:  {Name: "cctEmul", DefiningModule: "iana-if-type"},
		43:  {Name: "ces", DefiningModule: "iana-if-type"},
		44:  {Name: "channel", DefiningModule: "iana-if-type"},
		45:  {Name: "ciscoISLvlan", DefiningModule: "iana-if-type"},
		46:  {Name: "cnr", DefiningModule: "iana-if-type"},
		47:  {Name: "coffee", DefiningModule: "iana-if-type"},
		48:  {Name: "compositeLink", DefiningModule: "iana-if-type"},
		49:  {Name: "dcn", DefiningModule: "iana-if-type"},
		50:  {Name: "ddnX25", DefiningModule: "iana-if-type"},
		51:  {Name: "digitalPowerline", DefiningModule: "iana-if-type"},
		52:  {Name: "digitalWrapperOverheadChannel", DefiningModule: "iana-if-type"},
		53:  {Name: "dlsw", DefiningModule: "iana-if-type"},
		54:  {Name: "docsCableDownstream", DefiningModule: "iana-if-type"},
		55:  {Name: "docsCableMCmtsDownstream", DefiningModule: "iana-if-type"},
		56:  {Name: "docsCableMaclayer", DefiningModule: "iana-if-type"},
		57:  {Name: "docsCableNdf", DefiningModule: "iana-if-type"},
		58:  {Name: "docsCableNdr", DefiningModule: "iana-if-type"},
		59:  {Name: "docsCableScte55d1FwdOob", DefiningModule: "iana-if-type"},
		60:  {Name: "docsCableScte55d1RetOob", DefiningModule: "iana-if-type"},
		61:  {Name: "docsCableScte55d2DsOob", DefiningModule: "iana-if-type"},
		62:  {Name: "docsCableScte55d2UsOob", DefiningModule: "iana-if-type"},
		63:  {Name: "docsCableUpstream", DefiningModule: "iana-if-type"},
		64:  {Name: "docsCableUpstreamChannel", DefiningModule: "iana-if-type"},
		65:  {Name: "docsCableUpstreamRfPort", DefiningModule: "iana-if-type"},
		66:  {Name: "docsOfdmDownstream", DefiningModule: "iana-if-type"},
		67:  {Name: "docsOfdmaUpstream", DefiningModule: "iana-if-type"},
		68:  {Name: "ds0", DefiningModule: "iana-if-type"},
		69:  {Name: "ds0Bundle", DefiningModule: "iana-if-type"},
		70:  {Name: "ds1", DefiningModule: "iana-if-type"},
		71:  {Name: "ds1FDL", DefiningModule: "iana-if-type"},
		72:  {Name: "ds3", DefiningModule: "iana-if-type"},
		73:  {Name: "dtm", DefiningModule: "iana-if-type"},
		74:  {Name: "dvbAsiIn", DefiningModule: "iana-if-type"},
		75:  {Name: "dvbAsiOut", DefiningModule: "iana-if-type"},
		76:  {Name: "dvbRccDownstream", DefiningModule: "iana-if-type"},
		77:  {Name: "dvbRccMacLayer", DefiningModule: "iana-if-type"},
		78:  {Name: "dvbRccUpstream", DefiningModule: "iana-if-type"},
		79:  {Name: "dvbRcsMacLayer", DefiningModule: "iana-if-type"},
		80:  {Name: "dvbRcsTdma", DefiningModule: "iana-if-type"},
		81:  {Name: "dvbTdm", DefiningModule: "iana-if-type"},
		82:  {Name: "e1", DefiningModule: "iana-if-type"},
		83:  {Name: "econet", DefiningModule: "iana-if-type"},
		84:  {Name: "eon", DefiningModule: "iana-if-type"},
		85:  {Name: "eplrs", DefiningModule: "iana-if-type"},
		86:  {Name: "escon", DefiningModule: "iana-if-type"},
		87:  {Name: "ethernet3Mbit", DefiningModule: "iana-if-type"},
		88:  {Name: "ethernetCsmacd", DefiningModule: "iana-if-type"},
		89:  {Name: "fast", DefiningModule: "iana-if-type"},
		90:  {Name: "fastEther", DefiningModule: "iana-if-type"},
		91:  {Name: "fastEtherFX", DefiningModule: "iana-if-type"},
		92:  {Name: "fastdsl", DefiningModule: "iana-if-type"},
		93:  {Name: "fcipLink", DefiningModule: "iana-if-type"},
		94:  {Name: "fddi", DefiningModule: "iana-if-type"},
		95:  {Name: "fibreChannel", DefiningModule: "iana-if-type"},
		96:  {Name: "frDlciEndPt", DefiningModule: "iana-if-type"},
		97:  {Name: "frForward", DefiningModule: "iana-if-type"},
		98:  {Name: "frameRelay", DefiningModule: "iana-if-type"},
		99:  {Name: "frameRelayInterconnect", DefiningModule: "iana-if-type"},
		100: {Name: "frameRelayMPI", DefiningModule: "iana-if-type"},
		101: {Name: "frameRelayService", DefiningModule: "iana-if-type"},
		102: {Name: "frf16MfrBundle", DefiningModule: "iana-if-type"},
		103: {Name: "g703at2mb", DefiningModule: "iana-if-type"},
		104: {Name: "g703at64k", DefiningModule: "iana-if-type"},
		105: {Name: "g9981", DefiningModule: "iana-if-type"},
		106: {Name: "g9982", DefiningModule: "iana-if-type"},
		107: {Name: "g9983", DefiningModule: "iana-if-type"},
		108: {Name: "gfast", DefiningModule: "iana-if-type"},
		109: {Name: "gfp", DefiningModule: "iana-if-type"},
		110: {Name: "gigabitEthernet", DefiningModule: "iana-if-type"},
		111: {Name: "gpon", DefiningModule: "iana-if-type"},
		112: {Name: "gr303IDT", DefiningModule: "iana-if-type"},
		113: {Name: "gr303RDT", DefiningModule: "iana-if-type"},
		114: {Name: "gtp", DefiningModule: "iana-if-type"},
		115: {Name: "h323Gatekeeper", DefiningModule: "iana-if-type"},
		116: {Name: "h323Proxy", DefiningModule: "iana-if-type"},
		117: {Name: "hdh1822", DefiningModule: "iana-if-type"},
		118: {Name: "hdlc", DefiningModule: "iana-if-type"},
		119: {Name: "hdsl2", DefiningModule: "iana-if-type"},
		120: {Name: "hiperlan2", DefiningModule: "iana-if-type"},
		121: {Name: "hippi", DefiningModule: "iana-if-type"},
		122: {Name: "hippiInterface", DefiningModule: "iana-if-type"},
		123: {Name: "homepna", DefiningModule: "iana-if-type"},
		124: {Name: "hostPad", DefiningModule: "iana-if-type"},
		125: {Name: "hssi", DefiningModule: "iana-if-type"},
		126: {Name: "hyperchannel", DefiningModule: "iana-if-type"},
		127: {Name: "iana-interface-type", DefiningModule: "iana-if-type"},
		128: {Name: "ibm370parChan", DefiningModule: "iana-if-type"},
		129: {Name: "idsl", DefiningModule: "iana-if-type"},
		130: {Name: "ieee1394", DefiningModule: "iana-if-type"},
		131: {Name: "ieee80211", DefiningModule: "iana-if-type"},
		132: {Name: "ieee80212", DefiningModule: "iana-if-type"},
		133: {Name: "ieee802154", DefiningModule: "iana-if-type"},
		134: {Name: "ieee80216WMAN", DefiningModule: "iana-if-type"},
		135: {Name: "ieee8023adLag", DefiningModule: "iana-if-type"},
		136: {Name: "if-gsn", DefiningModule: "iana-if-type"},
		137: {Name: "ifPwType", DefiningModule: "iana-if-type"},
		138: {Name: "ifVfiType", DefiningModule: "iana-if-type"},
		139: {Name: "ilan", DefiningModule: "iana-if-type"},
		140: {Name: "imt", DefiningModule: "iana-if-type"},
		141: {Name: "infiniband", DefiningModule: "iana-if-type"},
		142: {Name: "interleave", DefiningModule: "iana-if-type"},
		143: {Name: "ip", DefiningModule: "iana-if-type"},
		144: {Name: "ipForward", DefiningModule: "iana-if-type"},
		145: {Name: "ipOverAtm", DefiningModule: "iana-if-type"},
		146: {Name: "ipOverCdlc", DefiningModule: "iana-if-type"},
		147: {Name: "ipOverClaw", DefiningModule: "iana-if-type"},
		148: {Name: "ipSwitch", DefiningModule: "iana-if-type"},
		149: {Name: "isdn", DefiningModule: "iana-if-type"},
		150: {Name: "isdns", DefiningModule: "iana-if-type"},
		151: {Name: "isdnu", DefiningModule: "iana-if-type"},
		152: {Name: "iso88022llc", DefiningModule: "iana-if-type"},
		153: {Name: "iso88023Csmacd", DefiningModule: "iana-if-type"},
		154: {Name: "iso88024TokenBus", DefiningModule: "iana-if-type"},
		155: {Name: "iso88025CRFPInt", DefiningModule: "iana-if-type"},
		156: {Name: "iso88025Dtr", DefiningModule: "iana-if-type"},
		157: {Name: "iso88025Fiber", DefiningModule: "iana-if-type"},
		158: {Name: "iso88025TokenRing", DefiningModule: "iana-if-type"},
		159: {Name: "iso88026Man", DefiningModule: "iana-if-type"},
		160: {Name: "isup", DefiningModule: "iana-if-type"},
		161: {Name: "l2vlan", DefiningModule: "iana-if-type"},
		162: {Name: "l3ipvlan", DefiningModule: "iana-if-type"},
		163: {Name: "l3ipxvlan", DefiningModule: "iana-if-type"},
		164: {Name: "lapb", DefiningModule: "iana-if-type"},
		165: {Name: "lapd", DefiningModule: "iana-if-type"},
		166: {Name: "lapf", DefiningModule: "iana-if-type"},
		167: {Name: "linegroup", DefiningModule: "iana-if-type"},
		168: {Name: "lmp", DefiningModule: "iana-if-type"},
		169: {Name: "localTalk", DefiningModule: "iana-if-type"},
		170: {Name: "macSecControlledIF", DefiningModule: "iana-if-type"},
		171: {Name: "macSecUncontrolledIF", DefiningModule: "iana-if-type"},
		172: {Name: "mediaMailOverIp", DefiningModule: "iana-if-type"},
		173: {Name: "mfSigLink", DefiningModule: "iana-if-type"},
		174: {Name: "miox25", DefiningModule: "iana-if-type"},
		175: {Name: "mocaVersion1", DefiningModule: "iana-if-type"},
		176: {Name: "modem", DefiningModule: "iana-if-type"},
		177: {Name: "mpc", DefiningModule: "iana-if-type"},
		178: {Name: "mpegTransport", DefiningModule: "iana-if-type"},
		179: {Name: "mpls", DefiningModule: "iana-if-type"},
		180: {Name: "mplsTunnel", DefiningModule: "iana-if-type"},
		181: {Name: "msdsl", DefiningModule: "iana-if-type"},
		182: {Name: "mvl", DefiningModule: "iana-if-type"},
		183: {Name: "myrinet", DefiningModule: "iana-if-type"},
		184: {Name: "nfas", DefiningModule: "iana-if-type"},
		185: {Name: "nsip", DefiningModule: "iana-if-type"},
		186: {Name: "opticalChannel", DefiningModule: "iana-if-type"},
		187: {Name: "opticalChannelGroup", DefiningModule: "iana-if-type"},
		188: {Name: "opticalTransport", DefiningModule: "iana-if-type"},
		189: {Name: "other", DefiningModule: "iana-if-type"},
		190: {Name: "otnOdu", DefiningModule: "iana-if-type"},
		191: {Name: "otnOtu", DefiningModule: "iana-if-type"},
		192: {Name: "para", DefiningModule: "iana-if-type"},
		193: {Name: "pdnEtherLoop1", DefiningModule: "iana-if-type"},
		194: {Name: "pdnEtherLoop2", DefiningModule: "iana-if-type"},
		195: {Name: "pip", DefiningModule: "iana-if-type"},
		196: {Name: "plc", DefiningModule: "iana-if-type"},
		197: {Name: "pon155", DefiningModule: "iana-if-type"},
		198: {Name: "pon622", DefiningModule: "iana-if-type"},
		199: {Name: "pos", DefiningModule: "iana-if-type"},
		200: {Name: "ppp", DefiningModule: "iana-if-type"},
		201: {Name: "pppMultilinkBundle", DefiningModule: "iana-if-type"},
		202: {Name: "primaryISDN", DefiningModule: "iana-if-type"},
		203: {Name: "propAtm", DefiningModule: "iana-if-type"},
		204: {Name: "propBWAp2Mp", DefiningModule: "iana-if-type"},
		205: {Name: "propCnls", DefiningModule: "iana-if-type"},
		206: {Name: "propDocsWirelessDownstream", DefiningModule: "iana-if-type"},
		207: {Name: "propDocsWirelessMaclayer", DefiningModule: "iana-if-type"},
		208: {Name: "propDocsWirelessUpstream", DefiningModule: "iana-if-type"},
		209: {Name: "propMultiplexor", DefiningModule: "iana-if-type"},
		210: {Name: "propPointToPointSerial", DefiningModule: "iana-if-type"},
		211: {Name: "propVirtual", DefiningModule: "iana-if-type"},
		212: {Name: "propWirelessP2P", DefiningModule: "iana-if-type"},
		213: {Name: "proteon10Mbit", DefiningModule: "iana-if-type"},
		214: {Name: "proteon80Mbit", DefiningModule: "iana-if-type"},
		215: {Name: "ptm", DefiningModule: "iana-if-type"},
		216: {Name: "q2931", DefiningModule: "iana-if-type"},
		217: {Name: "qam", DefiningModule: "iana-if-type"},
		218: {Name: "qllc", DefiningModule: "iana-if-type"},
		219: {Name: "radioMAC", DefiningModule: "iana-if-type"},
		220: {Name: "radsl", DefiningModule: "iana-if-type"},
		221: {Name: "reachDSL", DefiningModule: "iana-if-type"},
		222: {Name: "regular1822", DefiningModule: "iana-if-type"},
		223: {Name: "rfc1483", DefiningModule: "iana-if-type"},
		224: {Name: "rfc877x25", DefiningModule: "iana-if-type"},
		225: {Name: "rpr", DefiningModule: "iana-if-type"},
		226: {Name: "rs232", DefiningModule: "iana-if-type"},
		227: {Name: "rsrb", DefiningModule: "iana-if-type"},
		228: {Name: "sdci", DefiningModule: "iana-if-type"},
		229: {Name: "sdlc", DefiningModule: "iana-if-type"},
		230: {Name: "sdsl", DefiningModule: "iana-if-type"},
		231: {Name: "shdsl", DefiningModule: "iana-if-type"},
		232: {Name: "sip", DefiningModule: "iana-if-type"},
		233: {Name: "sipSig", DefiningModule: "iana-if-type"},
		234: {Name: "sipTg", DefiningModule: "iana-if-type"},
		235: {Name: "sixToFour", DefiningModule: "iana-if-type"},
		236: {Name: "slip", DefiningModule: "iana-if-type"},
		237: {Name: "smdsDxi", DefiningModule: "iana-if-type"},
		238: {Name: "smdsIcip", DefiningModule: "iana-if-type"},
		239: {Name: "softwareLoopback", DefiningModule: "iana-if-type"},
		240: {Name: "sonet", DefiningModule: "iana-if-type"},
		241: {Name: "sonetOverheadChannel", DefiningModule: "iana-if-type"},
		242: {Name: "sonetPath", DefiningModule: "iana-if-type"},
		243: {Name: "sonetVT", DefiningModule: "iana-if-type"},
		244: {Name: "srp", DefiningModule: "iana-if-type"},
		245: {Name: "ss7SigLink", DefiningModule: "iana-if-type"},
		246: {Name: "stackToStack", DefiningModule: "iana-if-type"},
		247: {Name: "starLan", DefiningModule: "iana-if-type"},
		248: {Name: "tdlc", DefiningModule: "iana-if-type"},
		249: {Name: "teLink", DefiningModule: "iana-if-type"},
		250: {Name: "termPad", DefiningModule: "iana-if-type"},
		251: {Name: "tr008", DefiningModule: "iana-if-type"},
		252: {Name: "transpHdlc", DefiningModule: "iana-if-type"},
		253: {Name: "tunnel", DefiningModule: "iana-if-type"},
		254: {Name: "ultra", DefiningModule: "iana-if-type"},
		255: {Name: "usb", DefiningModule: "iana-if-type"},
		256: {Name: "v11", DefiningModule: "iana-if-type"},
		257: {Name: "v35", DefiningModule: "iana-if-type"},
		258: {Name: "v36", DefiningModule: "iana-if-type"},
		259: {Name: "v37", DefiningModule: "iana-if-type"},
		260: {Name: "vdsl", DefiningModule: "iana-if-type"},
		261: {Name: "vdsl2", DefiningModule: "iana-if-type"},
		262: {Name: "virtualIpAddress", DefiningModule: "iana-if-type"},
		263: {Name: "virtualTg", DefiningModule: "iana-if-type"},
		264: {Name: "vmwareNicTeam", DefiningModule: "iana-if-type"},
		265: {Name: "vmwareVirtualNic", DefiningModule: "iana-if-type"},
		266: {Name: "voiceDID", DefiningModule: "iana-if-type"},
		267: {Name: "voiceEBS", DefiningModule: "iana-if-type"},
		268: {Name: "voiceEM", DefiningModule: "iana-if-type"},
		269: {Name: "voiceEMFGD", DefiningModule: "iana-if-type"},
		270: {Name: "voiceEncap", DefiningModule: "iana-if-type"},
		271: {Name: "voiceFGDEANA", DefiningModule: "iana-if-type"},
		272: {Name: "voiceFGDOS", DefiningModule: "iana-if-type"},
		273: {Name: "voiceFXO", DefiningModule: "iana-if-type"},
		274: {Name: "voiceFXS", DefiningModule: "iana-if-type"},
		275: {Name: "voiceOverAtm", DefiningModule: "iana-if-type"},
		276: {Name: "voiceOverCable", DefiningModule: "iana-if-type"},
		277: {Name: "voiceOverFrameRelay", DefiningModule: "iana-if-type"},
		278: {Name: "voiceOverIp", DefiningModule: "iana-if-type"},
		279: {Name: "wwanPP", DefiningModule: "iana-if-type"},
		280: {Name: "wwanPP2", DefiningModule: "iana-if-type"},
		281: {Name: "x213", DefiningModule: "iana-if-type"},
		282: {Name: "x25huntGroup", DefiningModule: "iana-if-type"},
		283: {Name: "x25mlp", DefiningModule: "iana-if-type"},
		284: {Name: "x25ple", DefiningModule: "iana-if-type"},
		285: {Name: "x86Laps", DefiningModule: "iana-if-type"},
		286: {Name: "xboxWireless", DefiningModule: "iana-if-type"},
	},
	"E_IgpFloodingBandwidth_ThresholdSpecification": {
		1: {Name: "MIRRORED_UP_DOWN"},
		2: {Name: "SEPARATE_UP_DOWN"},
	},
	"E_IgpFloodingBandwidth_ThresholdType": {
		1: {Name: "DELTA"},
		2: {Name: "THRESHOLD_CROSSED"},
	},
	"E_Interface_AdminStatus": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
		3: {Name: "TESTING"},
	},
	"E_Interface_OperStatus": {
		2: {Name: "UP"},
		3: {Name: "DOWN"},
		4: {Name: "TESTING"},
		5: {Name: "UNKNOWN"},
		6: {Name: "DORMANT"},
		7: {Name: "NOT_PRESENT"},
		8: {Name: "LOWER_LAYER_DOWN"},
	},
	"E_Ipv4Srlg_Flags": {
		1: {Name: "NUMBERED"},
	},
	"E_Ipv6Srlg_Flags": {
		1: {Name: "NA"},
	},
	"E_LanAdjacencySid_Flags": {
		1: {Name: "ADDRESS_FAMILY"},
		2: {Name: "BACKUP"},
		3: {Name: "VALUE"},
		4: {Name: "LOCAL"},
		5: {Name: "SET"},
	},
	"E_LinkAttributes_LocalProtection": {
		1: {Name: "LOCAL_PROTECTION"},
		2: {Name: "LINK_EXCLUDED"},
	},
	"E_LinkProtectionType_Type": {
		1: {Name: "EXTRA_TRAFFIC"},
		2: {Name: "UNPROTECTED"},
		3: {Name: "SHARED"},
		4: {Name: "ONE_ONE"},
		5: {Name: "PLUS_ONE"},
		6: {Name: "ENHANCED"},
	},
	"E_Link_SubTlv_Type_Enum": {
		1: {Name: "UNKNOWN"},
	},
	"E_LsaGeneration_TimerType": {
		1: {Name: "LINEAR_BACKOFF"},
		2: {Name: "EXPONENTIAL_BACKOFF"},
	},
	"E_Lsp_Flags": {
		1: {Name: "PARTITION_REPAIR"},
		2: {Name: "ATTACHED_ERROR"},
		3: {Name: "ATTACHED_EXPENSE"},
		4: {Name: "ATTACHED_DELAY"},
		5: {Name: "ATTACHED_DEFAULT"},
		6: {Name: "OVERLOAD"},
	},
	"E_Lsp_PduType": {
		1: {Name: "LEVEL_1"},
		2: {Name: "LEVEL_2"},
	},
	"E_NamedExplicitPath_SidSelectionMode": {
		1: {Name: "ADJ_SID_ONLY"},
		2: {Name: "MIXED_MODE"},
	},
	"E_Neighbor_NeighborState": {
		1: {Name: "INCOMPLETE"},
		2: {Name: "REACHABLE"},
		3: {Name: "STALE"},
		4: {Name: "DELAY"},
		5: {Name: "PROBE"},
	},
	"E_Neighbor_NeighborStatus": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
	},
	"E_Neighbor_SessionState": {
		1: {Name: "IDLE"},
		2: {Name: "CONNECT"},
		3: {Name: "ACTIVE"},
		4: {Name: "OPENSENT"},
		5: {Name: "OPENCONFIRM"},
		6: {Name: "ESTABLISHED"},
	},
	"E_Nlpid_Nlpid": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
	},
	"E_NodeAttribute_SubTlv_Type_Enum": {
		1: {Name: "UNKNOWN"},
	},
	"E_OpaqueLsa_Scope": {
		1: {Name: "LINK"},
		2: {Name: "AREA"},
		3: {Name: "AS"},
	},
	"E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE": {
		1: {Name: "AAA_ACCOUNTING_EVENT_COMMAND", DefiningModule: "openconfig-aaa-types"},
		2: {Name: "AAA_ACCOUNTING_EVENT_LOGIN", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE": {
		1: {Name: "AAA_AUTHORIZATION_EVENT_COMMAND", DefiningModule: "openconfig-aaa-types"},
		2: {Name: "AAA_AUTHORIZATION_EVENT_CONFIG", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAaaTypes_AAA_METHOD_TYPE": {
		1: {Name: "LOCAL", DefiningModule: "openconfig-aaa-types"},
		2: {Name: "RADIUS_ALL", DefiningModule: "openconfig-aaa-types"},
		3: {Name: "TACACS_ALL", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAaaTypes_AAA_SERVER_TYPE": {
		1: {Name: "RADIUS", DefiningModule: "openconfig-aaa"},
		2: {Name: "TACACS", DefiningModule: "openconfig-aaa"},
	},
	"E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES": {
		1: {Name: "SYSTEM_ROLE_ADMIN", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAcl_ACL_COUNTER_CAPABILITY": {
		1: {Name: "AGGREGATE_ONLY", DefiningModule: "openconfig-acl"},
		2: {Name: "INTERFACE_AGGREGATE", DefiningModule: "openconfig-acl"},
		3: {Name: "INTERFACE_ONLY", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAcl_ACL_TYPE": {
		1: {Name: "ACL_IPV4", DefiningModule: "openconfig-acl"},
		2: {Name: "ACL_IPV6", DefiningModule: "openconfig-acl"},
		3: {Name: "ACL_L2", DefiningModule: "openconfig-acl"},
		4: {Name: "ACL_MIXED", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAcl_FORWARDING_ACTION": {
		1: {Name: "ACCEPT", DefiningModule: "openconfig-acl"},
		2: {Name: "DROP", DefiningModule: "openconfig-acl"},
		3: {Name: "REJECT", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAcl_LOG_ACTION": {
		1: {Name: "LOG_NONE", DefiningModule: "openconfig-acl"},
		2: {Name: "LOG_SYSLOG", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAftTypes_EncapsulationHeaderType": {
		1: {Name: "GRE"},
		2: {Name: "IPV4"},
		3: {Name: "IPV6"},
		4: {Name: "MPLS"},
	},
	"E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY": {
		1: {Name: "CRITICAL", DefiningModule: "openconfig-alarm-types"},
		2: {Name: "MAJOR", DefiningModule: "openconfig-alarm-types"},
		3: {Name: "MINOR", DefiningModule: "openconfig-alarm-types"},
		4: {Name: "UNKNOWN", DefiningModule: "openconfig-alarm-types"},
		5: {Name: "WARNING", DefiningModule: "openconfig-alarm-types"},
	},
	"E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID": {
		1: {Name: "AIS", DefiningModule: "openconfig-alarm-types"},
		2: {Name: "EQPT", DefiningModule: "openconfig-alarm-types"},
		3: {Name: "LOS", DefiningModule: "openconfig-alarm-types"},
		4: {Name: "OTS", DefiningModule: "openconfig-alarm-types"},
	},
	"E_OpenconfigBgpTypes_AFI_SAFI_TYPE": {
		1:  {Name: "IPV4_FLOWSPEC", DefiningModule: "openconfig-bgp-types"},
		2:  {Name: "IPV4_LABELED_UNICAST", DefiningModule: "openconfig-bgp-types"},
		3:  {Name: "IPV4_UNICAST", DefiningModule: "openconfig-bgp-types"},
		4:  {Name: "IPV6_LABELED_UNICAST", DefiningModule: "openconfig-bgp-types"},
		5:  {Name: "IPV6_UNICAST", DefiningModule: "openconfig-bgp-types"},
		6:  {Name: "L2VPN_EVPN", DefiningModule: "openconfig-bgp-types"},
		7:  {Name: "L2VPN_VPLS", DefiningModule: "openconfig-bgp-types"},
		8:  {Name: "L3VPN_IPV4_MULTICAST", DefiningModule: "openconfig-bgp-types"},
		9:  {Name: "L3VPN_IPV4_UNICAST", DefiningModule: "openconfig-bgp-types"},
		10: {Name: "L3VPN_IPV6_MULTICAST", DefiningModule: "openconfig-bgp-types"},
		11: {Name: "L3VPN_IPV6_UNICAST", DefiningModule: "openconfig-bgp-types"},
		12: {Name: "LINKSTATE", DefiningModule: "openconfig-bgp-types"},
		13: {Name: "LINKSTATE_SPF", DefiningModule: "openconfig-bgp-types"},
		14: {Name: "LINKSTATE_VPN", DefiningModule: "openconfig-bgp-types"},
		15: {Name: "SRTE_POLICY_IPV4", DefiningModule: "openconfig-bgp-types"},
		16: {Name: "SRTE_POLICY_IPV6", DefiningModule: "openconfig-bgp-types"},
		17: {Name: "VPNV4_FLOWSPEC", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_AsPathSegmentType": {
		1: {Name: "AS_SEQ"},
		2: {Name: "AS_SET"},
		3: {Name: "AS_CONFED_SEQUENCE"},
		4: {Name: "AS_CONFED_SET"},
	},
	"E_OpenconfigBgpTypes_BGP_CAPABILITY": {
		1: {Name: "ADD_PATHS", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "ASN32", DefiningModule: "openconfig-bgp-types"},
		3: {Name: "EXTENDED_NEXTHOP_ENCODING", DefiningModule: "openconfig-bgp-types"},
		4: {Name: "GRACEFUL_RESTART", DefiningModule: "openconfig-bgp-types"},
		5: {Name: "MPBGP", DefiningModule: "openconfig-bgp-types"},
		6: {Name: "ROUTE_REFRESH", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_ERROR_CODE": {
		1: {Name: "CEASE", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "FINITE_STATE_MACHINE_ERROR", DefiningModule: "openconfig-bgp-types"},
		3: {Name: "HOLD_TIMER_EXPIRED", DefiningModule: "openconfig-bgp-types"},
		4: {Name: "MESSAGE_HEADER_ERROR", DefiningModule: "openconfig-bgp-types"},
		5: {Name: "OPEN_MESSAGE_ERROR", DefiningModule: "openconfig-bgp-types"},
		6: {Name: "ROUTE_REFRESH_MESSAGE_ERROR", DefiningModule: "openconfig-bgp-types"},
		7: {Name: "UPDATE_MESSAGE_ERROR", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE": {
		1:  {Name: "ADMINISTRATIVE_RESET", DefiningModule: "openconfig-bgp-types"},
		2:  {Name: "ADMINISTRATIVE_SHUTDOWN", DefiningModule: "openconfig-bgp-types"},
		3:  {Name: "ATTRIBUTE_FLAGS_ERROR", DefiningModule: "openconfig-bgp-types"},
		4:  {Name: "ATTRIBUTE_LENGTH_ERROR", DefiningModule: "openconfig-bgp-types"},
		5:  {Name: "BAD_BGP_IDENTIFIER", DefiningModule: "openconfig-bgp-types"},
		6:  {Name: "BAD_MESSAGE_LENGTH", DefiningModule: "openconfig-bgp-types"},
		7:  {Name: "BAD_MESSAGE_TYPE", DefiningModule: "openconfig-bgp-types"},
		8:  {Name: "BAD_PEER_AS", DefiningModule: "openconfig-bgp-types"},
		9:  {Name: "CEASE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		10: {Name: "CONNECTION_NOT_SYNCHRONIZED", DefiningModule: "openconfig-bgp-types"},
		11: {Name: "CONNECTION_REJECTED", DefiningModule: "openconfig-bgp-types"},
		12: {Name: "CONN_COLLISION_RESOLUTION", DefiningModule: "openconfig-bgp-types"},
		13: {Name: "FINITE_STATE_MACHINE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		14: {Name: "INVALID_MESSAGE_LENGTH", DefiningModule: "openconfig-bgp-types"},
		15: {Name: "INVALID_NETWORK_FIELD", DefiningModule: "openconfig-bgp-types"},
		16: {Name: "INVALID_NEXT_HOP_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		17: {Name: "INVALID_ORIGIN_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		18: {Name: "MALFORMED_AS_PATH", DefiningModule: "openconfig-bgp-types"},
		19: {Name: "MALFORMED_ATTRIBUTE_LIST", DefiningModule: "openconfig-bgp-types"},
		20: {Name: "MAX_NUM_PREFIXES_REACHED", DefiningModule: "openconfig-bgp-types"},
		21: {Name: "MESSAGE_HEADER_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		22: {Name: "MISSING_WELL_KNOWN_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		23: {Name: "OPEN_MESSAGE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		24: {Name: "OPTIONAL_ATTRIBUTE_ERROR", DefiningModule: "openconfig-bgp-types"},
		25: {Name: "OTHER_CONFIG_CHANGE", DefiningModule: "openconfig-bgp-types"},
		26: {Name: "OUT_OF_RESOURCES", DefiningModule: "openconfig-bgp-types"},
		27: {Name: "PEER_DE_CONFIGURED", DefiningModule: "openconfig-bgp-types"},
		28: {Name: "RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED", DefiningModule: "openconfig-bgp-types"},
		29: {Name: "RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM", DefiningModule: "openconfig-bgp-types"},
		30: {Name: "RECEIVE_UNEXPECTED_MESSAGE_OPENSENT", DefiningModule: "openconfig-bgp-types"},
		31: {Name: "ROUTE_REFRESH_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		32: {Name: "UNACCEPTABLE_HOLD_TIME", DefiningModule: "openconfig-bgp-types"},
		33: {Name: "UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		34: {Name: "UNSPECIFIC", DefiningModule: "openconfig-bgp-types"},
		35: {Name: "UNSUPPORTED_CAPABILITY", DefiningModule: "openconfig-bgp-types"},
		36: {Name: "UNSUPPORTED_OPTIONAL_PARAMETER", DefiningModule: "openconfig-bgp-types"},
		37: {Name: "UNSUPPORTED_VERSION_NUMBER", DefiningModule: "openconfig-bgp-types"},
		38: {Name: "UPDATE_MESSAGE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY": {
		1: {Name: "NOPEER", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "NO_ADVERTISE", DefiningModule: "openconfig-bgp-types"},
		3: {Name: "NO_EXPORT", DefiningModule: "openconfig-bgp-types"},
		4: {Name: "NO_EXPORT_SUBCONFED", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BgpOriginAttrType": {
		1: {Name: "IGP"},
		2: {Name: "EGP"},
		3: {Name: "INCOMPLETE"},
	},
	"E_OpenconfigBgpTypes_CommunityType": {
		1: {Name: "STANDARD"},
		2: {Name: "EXTENDED"},
		3: {Name: "BOTH"},
		4: {Name: "NONE"},
	},
	"E_OpenconfigBgpTypes_PeerType": {
		1: {Name: "INTERNAL"},
		2: {Name: "EXTERNAL"},
	},
	"E_OpenconfigBgpTypes_RemovePrivateAsOption": {
		1: {Name: "PRIVATE_AS_REMOVE_ALL", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "PRIVATE_AS_REPLACE_ALL", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigIfAggregate_AggregationType": {
		1: {Name: "LACP"},
		2: {Name: "STATIC"},
	},
	"E_OpenconfigIfEthernet_ETHERNET_SPEED": {
		1:  {Name: "SPEED_100GB", DefiningModule: "openconfig-if-ethernet"},
		2:  {Name: "SPEED_100MB", DefiningModule: "openconfig-if-ethernet"},
		3:  {Name: "SPEED_10GB", DefiningModule: "openconfig-if-ethernet"},
		4:  {Name: "SPEED_10MB", DefiningModule: "openconfig-if-ethernet"},
		5:  {Name: "SPEED_1GB", DefiningModule: "openconfig-if-ethernet"},
		6:  {Name: "SPEED_200GB", DefiningModule: "openconfig-if-ethernet"},
		7:  {Name: "SPEED_2500MB", DefiningModule: "openconfig-if-ethernet"},
		8:  {Name: "SPEED_25GB", DefiningModule: "openconfig-if-ethernet"},
		9:  {Name: "SPEED_400GB", DefiningModule: "openconfig-if-ethernet"},
		10: {Name: "SPEED_40GB", DefiningModule: "openconfig-if-ethernet"},
		11: {Name: "SPEED_50GB", DefiningModule: "openconfig-if-ethernet"},
		12: {Name: "SPEED_5GB", DefiningModule: "openconfig-if-ethernet"},
		13: {Name: "SPEED_600GB", DefiningModule: "openconfig-if-ethernet"},
		14: {Name: "SPEED_800GB", DefiningModule: "openconfig-if-ethernet"},
		15: {Name: "SPEED_UNKNOWN", DefiningModule: "openconfig-if-ethernet"},
	},
	"E_OpenconfigIfIp_IpAddressOrigin": {
		1: {Name: "OTHER"},
		2: {Name: "STATIC"},
		3: {Name: "DHCP"},
		4: {Name: "LINK_LAYER"},
		5: {Name: "RANDOM"},
	},
	"E_OpenconfigIfIp_NeighborOrigin": {
		1: {Name: "OTHER"},
		2: {Name: "STATIC"},
		3: {Name: "DYNAMIC"},
	},
	"E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE": {
		1:  {Name: "IP_REACHABILITY_IPV4_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		2:  {Name: "IP_REACHABILITY_IPV6_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		3:  {Name: "IP_REACHABILITY_PREFIX_FLAGS", DefiningModule: "openconfig-isis-lsdb-types"},
		4:  {Name: "IP_REACHABILITY_PREFIX_SID", DefiningModule: "openconfig-isis-lsdb-types"},
		5:  {Name: "IP_REACHABILITY_SUBTLVS_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
		6:  {Name: "IP_REACHABILITY_TAG", DefiningModule: "openconfig-isis-lsdb-types"},
		7:  {Name: "IP_REACHABILITY_TAG64", DefiningModule: "openconfig-isis-lsdb-types"},
		8:  {Name: "IS_REACHABILITY_ADJ_LAN_SID", DefiningModule: "openconfig-isis-lsdb-types"},
		9:  {Name: "IS_REACHABILITY_ADJ_SID", DefiningModule: "openconfig-isis-lsdb-types"},
		10: {Name: "IS_REACHABILITY_ADMIN_GROUP", DefiningModule: "openconfig-isis-lsdb-types"},
		11: {Name: "IS_REACHABILITY_AVAILABLE_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		12: {Name: "IS_REACHABILITY_BANDWIDTH_CONSTRAINTS", DefiningModule: "openconfig-isis-lsdb-types"},
		13: {Name: "IS_REACHABILITY_EXTENDED_ADMIN_GROUP", DefiningModule: "openconfig-isis-lsdb-types"},
		14: {Name: "IS_REACHABILITY_IPV4_INTERFACE_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		15: {Name: "IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		16: {Name: "IS_REACHABILITY_IPV6_INTERFACE_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		17: {Name: "IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		18: {Name: "IS_REACHABILITY_LINK_ATTRIBUTES", DefiningModule: "openconfig-isis-lsdb-types"},
		19: {Name: "IS_REACHABILITY_LINK_DELAY", DefiningModule: "openconfig-isis-lsdb-types"},
		20: {Name: "IS_REACHABILITY_LINK_DELAY_VARIATION", DefiningModule: "openconfig-isis-lsdb-types"},
		21: {Name: "IS_REACHABILITY_LINK_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		22: {Name: "IS_REACHABILITY_LINK_LOSS", DefiningModule: "openconfig-isis-lsdb-types"},
		23: {Name: "IS_REACHABILITY_LINK_PROTECTION_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
		24: {Name: "IS_REACHABILITY_MAX_LINK_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		25: {Name: "IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		26: {Name: "IS_REACHABILITY_MIN_MAX_LINK_DELAY", DefiningModule: "openconfig-isis-lsdb-types"},
		27: {Name: "IS_REACHABILITY_RESIDUAL_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		28: {Name: "IS_REACHABILITY_SUBTLVS_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
		29: {Name: "IS_REACHABILITY_TE_DEFAULT_METRIC", DefiningModule: "openconfig-isis-lsdb-types"},
		30: {Name: "IS_REACHABILITY_UNCONSTRAINED_LSP", DefiningModule: "openconfig-isis-lsdb-types"},
		31: {Name: "IS_REACHABILITY_UNRESERVED_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		32: {Name: "IS_REACHABILITY_UTILIZED_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		33: {Name: "ROUTER_CAPABILITY_SR_ALGORITHM", DefiningModule: "openconfig-isis-lsdb-types"},
		34: {Name: "ROUTER_CAPABILITY_SR_CAPABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		35: {Name: "ROUTER_CAPABILITY_SUBTLVS_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
	},
	"E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE": {
		1:  {Name: "AREA_ADDRESSES", DefiningModule: "openconfig-isis-lsdb-types"},
		2:  {Name: "AUTHENTICATION", DefiningModule: "openconfig-isis-lsdb-types"},
		3:  {Name: "DYNAMIC_NAME", DefiningModule: "openconfig-isis-lsdb-types"},
		4:  {Name: "EXTENDED_IPV4_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		5:  {Name: "EXTENDED_IS_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		6:  {Name: "IIS_NEIGHBORS", DefiningModule: "openconfig-isis-lsdb-types"},
		7:  {Name: "INSTANCE_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		8:  {Name: "IPV4_EXTERNAL_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		9:  {Name: "IPV4_INTERFACE_ADDRESSES", DefiningModule: "openconfig-isis-lsdb-types"},
		10: {Name: "IPV4_INTERNAL_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		11: {Name: "IPV4_SRLG", DefiningModule: "openconfig-isis-lsdb-types"},
		12: {Name: "IPV4_TE_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		13: {Name: "IPV6_INTERFACE_ADDRESSES", DefiningModule: "openconfig-isis-lsdb-types"},
		14: {Name: "IPV6_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		15: {Name: "IPV6_SRLG", DefiningModule: "openconfig-isis-lsdb-types"},
		16: {Name: "IPV6_TE_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		17: {Name: "ISIS_ALIAS_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		18: {Name: "IS_NEIGHBOR_ATTRIBUTE", DefiningModule: "openconfig-isis-lsdb-types"},
		19: {Name: "LSP_BUFFER_SIZE", DefiningModule: "openconfig-isis-lsdb-types"},
		20: {Name: "MT_IPV4_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		21: {Name: "MT_IPV6_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		22: {Name: "MT_ISN", DefiningModule: "openconfig-isis-lsdb-types"},
		23: {Name: "MT_IS_NEIGHBOR_ATTRIBUTE", DefiningModule: "openconfig-isis-lsdb-types"},
		24: {Name: "MULTI_TOPOLOGY", DefiningModule: "openconfig-isis-lsdb-types"},
		25: {Name: "NLPID", DefiningModule: "openconfig-isis-lsdb-types"},
		26: {Name: "PURGE_OI", DefiningModule: "openconfig-isis-lsdb-types"},
		27: {Name: "ROUTER_CAPABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
	},
	"E_OpenconfigIsisTypes_AFI_SAFI_TYPE": {
		1: {Name: "IPV4_MULTICAST", DefiningModule: "openconfig-isis-types"},
		2: {Name: "IPV4_UNICAST", DefiningModule: "openconfig-isis-types"},
		3: {Name: "IPV6_MULTICAST", DefiningModule: "openconfig-isis-types"},
		4: {Name: "IPV6_UNICAST", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsisTypes_AFI_TYPE": {
		1: {Name: "IPV4", DefiningModule: "openconfig-isis-types"},
		2: {Name: "IPV6", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsisTypes_AdaptiveTimerType": {
		1: {Name: "LINEAR"},
		2: {Name: "EXPONENTIAL"},
	},
	"E_OpenconfigIsisTypes_CircuitType": {
		1: {Name: "POINT_TO_POINT"},
		2: {Name: "BROADCAST"},
	},
	"E_OpenconfigIsisTypes_HelloPaddingType": {
		1: {Name: "STRICT"},
		2: {Name: "LOOSE"},
		3: {Name: "ADAPTIVE"},
		4: {Name: "DISABLE"},
	},
	"E_OpenconfigIsisTypes_IsisInterfaceAdjState": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
		3: {Name: "INIT"},
		4: {Name: "FAILED"},
	},
	"E_OpenconfigIsisTypes_LevelType": {
		1: {Name: "LEVEL_1"},
		2: {Name: "LEVEL_2"},
		3: {Name: "LEVEL_1_2"},
	},
	"E_OpenconfigIsisTypes_MetricStyle": {
		1: {Name: "NARROW_METRIC"},
		2: {Name: "WIDE_METRIC"},
	},
	"E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE": {
		1: {Name: "WAIT_FOR_BGP", DefiningModule: "openconfig-isis-types"},
		2: {Name: "WAIT_FOR_SYSTEM", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsisTypes_SAFI_TYPE": {
		1: {Name: "MULTICAST", DefiningModule: "openconfig-isis-types"},
		2: {Name: "UNICAST", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsis_IsisMetricFlags": {
		1: {Name: "INTERNAL"},
		2: {Name: "UNSUPPORTED"},
	},
	"E_OpenconfigLacp_LacpActivityType": {
		1: {Name: "ACTIVE"},
		2: {Name: "PASSIVE"},
	},
	"E_OpenconfigLacp_LacpPeriodType": {
		1: {Name: "FAST"},
		2: {Name: "SLOW"},
	},
	"E_OpenconfigLacp_LacpSynchronizationType": {
		1: {Name: "IN_SYNC"},
		2: {Name: "OUT_SYNC"},
	},
	"E_OpenconfigLacp_LacpTimeoutType": {
		1: {Name: "LONG"},
		2: {Name: "SHORT"},
	},
	"E_OpenconfigLldpTypes_ChassisIdType": {
		1: {Name: "CHASSIS_COMPONENT"},
		2: {Name: "INTERFACE_ALIAS"},
		3: {Name: "PORT_COMPONENT"},
		4: {Name: "MAC_ADDRESS"},
		5: {Name: "NETWORK_ADDRESS"},
		6: {Name: "INTERFACE_NAME"},
		7: {Name: "LOCAL"},
	},
	"E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY": {
		1:  {Name: "C_VLAN", DefiningModule: "openconfig-lldp-types"},
		2:  {Name: "DOCSIS_CABLE_DEVICE", DefiningModule: "openconfig-lldp-types"},
		3:  {Name: "MAC_BRIDGE", DefiningModule: "openconfig-lldp-types"},
		4:  {Name: "OTHER", DefiningModule: "openconfig-lldp-types"},
		5:  {Name: "REPEATER", DefiningModule: "openconfig-lldp-types"},
		6:  {Name: "ROUTER", DefiningModule: "openconfig-lldp-types"},
		7:  {Name: "STATION_ONLY", DefiningModule: "openconfig-lldp-types"},
		8:  {Name: "S_VLAN", DefiningModule: "openconfig-lldp-types"},
		9:  {Name: "TELEPHONE", DefiningModule: "openconfig-lldp-types"},
		10: {Name: "TWO_PORT_MAC_RELAY", DefiningModule: "openconfig-lldp-types"},
		11: {Name: "WLAN_ACCESS_POINT", DefiningModule: "openconfig-lldp-types"},
	},
	"E_OpenconfigLldpTypes_LLDP_TLV": {
		1: {Name: "CHASSIS_ID", DefiningModule: "openconfig-lldp-types"},
		2: {Name: "MANAGEMENT_ADDRESS", DefiningModule: "openconfig-lldp-types"},
		3: {Name: "PORT_DESCRIPTION", DefiningModule: "openconfig-lldp-types"},
		4: {Name: "PORT_ID", DefiningModule: "openconfig-lldp-types"},
		5: {Name: "SYSTEM_CAPABILITIES", DefiningModule: "openconfig-lldp-types"},
		6: {Name: "SYSTEM_DESCRIPTION", DefiningModule: "openconfig-lldp-types"},
		7: {Name: "SYSTEM_NAME", DefiningModule: "openconfig-lldp-types"},
	},
	"E_OpenconfigLldpTypes_PortIdType": {
		1: {Name: "INTERFACE_ALIAS"},
		2: {Name: "PORT_COMPONENT"},
		3: {Name: "MAC_ADDRESS"},
		4: {Name: "NETWORK_ADDRESS"},
		5: {Name: "INTERFACE_NAME"},
		6: {Name: "AGENT_CIRCUIT_ID"},
		7: {Name: "LOCAL"},
	},
	"E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP": {
		1: {Name: "DROP", DefiningModule: "openconfig-local-routing"},
		2: {Name: "LOCAL_LINK", DefiningModule: "openconfig-local-routing"},
	},
	"E_OpenconfigMessages_DEBUG_SERVICE": {},
	"E_OpenconfigMplsLdp_MplsLdpAdjacencyType": {
		1: {Name: "LINK"},
		2: {Name: "TARGETED"},
	},
	"E_OpenconfigMplsLdp_MplsLdpAfi": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
	},
	"E_OpenconfigMplsTypes_LSP_METRIC_TYPE": {
		1: {Name: "LSP_METRIC_ABSOLUTE", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "LSP_METRIC_INHERITED", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "LSP_METRIC_RELATIVE", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_LSP_OPER_STATUS": {
		1: {Name: "DOWN", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "UP", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_LSP_ROLE": {
		1: {Name: "EGRESS", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "INGRESS", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "TRANSIT", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_MplsLabel_Enum": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigMplsTypes_NULL_LABEL_TYPE": {
		1: {Name: "EXPLICIT", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "IMPLICIT", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD": {
		1: {Name: "EXPLICITLY_DEFINED", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "EXTERNALLY_QUERIED", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "LOCALLY_COMPUTED", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL": {
		1: {Name: "PATH_SETUP_LDP", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "PATH_SETUP_RSVP", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "PATH_SETUP_SR", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PROTECTION_TYPE": {
		1: {Name: "LINK_NODE_PROTECTION_REQUESTED", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "LINK_PROTECTION_REQUIRED", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "UNPROTECTED", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION": {
		1: {Name: "PWE_ETHERNET_RAW_MODE", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "PWE_ETHERNET_TAGGED_MODE", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS": {
		1: {Name: "ADMIN_DOWN", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "ADMIN_UP", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_TUNNEL_TYPE": {
		1: {Name: "P2MP", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "P2P", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMpls_CspfTieBreaking": {
		1: {Name: "RANDOM"},
		2: {Name: "LEAST_FILL"},
		3: {Name: "MOST_FILL"},
	},
	"E_OpenconfigMpls_MplsHopType": {
		1: {Name: "LOOSE"},
		2: {Name: "STRICT"},
	},
	"E_OpenconfigMpls_MplsSrlgFloodingType": {
		1: {Name: "FLOODED_SRLG"},
		2: {Name: "STATIC_SRLG"},
	},
	"E_OpenconfigMpls_TeBandwidthType": {
		1: {Name: "SPECIFIED"},
		2: {Name: "AUTO"},
	},
	"E_OpenconfigNetworkInstanceTypes_ENCAPSULATION": {
		1: {Name: "MPLS", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "VXLAN", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE": {
		1: {Name: "LOCAL", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "REMOTE", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE": {
		1: {Name: "INSTANCE_LABEL", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "PER_NEXTHOP", DefiningModule: "openconfig-network-instance-types"},
		3: {Name: "PER_PREFIX", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE": {
		1: {Name: "DEFAULT_INSTANCE", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "L2L3", DefiningModule: "openconfig-network-instance-types"},
		3: {Name: "L2P2P", DefiningModule: "openconfig-network-instance-types"},
		4: {Name: "L2VSI", DefiningModule: "openconfig-network-instance-types"},
		5: {Name: "L3VRF", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE": {
		1: {Name: "DSF", DefiningModule: "openconfig-optical-amplifier"},
		2: {Name: "LEAF", DefiningModule: "openconfig-optical-amplifier"},
		3: {Name: "SSMF", DefiningModule: "openconfig-optical-amplifier"},
		4: {Name: "TWC", DefiningModule: "openconfig-optical-amplifier"},
		5: {Name: "TWRS", DefiningModule: "openconfig-optical-amplifier"},
	},
	"E_OpenconfigOpticalAmplifier_GAIN_RANGE": {
		1: {Name: "FIXED_GAIN_RANGE", DefiningModule: "openconfig-optical-amplifier"},
		2: {Name: "HIGH_GAIN_RANGE", DefiningModule: "openconfig-optical-amplifier"},
		3: {Name: "LOW_GAIN_RANGE", DefiningModule: "openconfig-optical-amplifier"},
		4: {Name: "MID_GAIN_RANGE", DefiningModule: "openconfig-optical-amplifier"},
	},
	"E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE": {
		1: {Name: "CONSTANT_GAIN", DefiningModule: "openconfig-optical-amplifier"},
		2: {Name: "CONSTANT_POWER", DefiningModule: "openconfig-optical-amplifier"},
		3: {Name: "DYNAMIC_GAIN", DefiningModule: "openconfig-optical-amplifier"},
	},
	"E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE": {
		1: {Name: "BACKWARD_RAMAN", DefiningModule: "openconfig-optical-amplifier"},
		2: {Name: "EDFA", DefiningModule: "openconfig-optical-amplifier"},
		3: {Name: "FORWARD_RAMAN", DefiningModule: "openconfig-optical-amplifier"},
		4: {Name: "HYBRID", DefiningModule: "openconfig-optical-amplifier"},
	},
	"E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES": {
		1: {Name: "GRACE_IP_INTERFACE_ADDRESS", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "GRACE_PERIOD", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "GRACE_RESTART_REASON", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE": {
		1: {Name: "MAX_METRIC_INCLUDE_STUB", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "MAX_METRIC_INCLUDE_TYPE2_EXTERNAL", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER": {
		1: {Name: "MAX_METRIC_ON_SYSTEM_BOOT", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE": {
		1: {Name: "ADJACENCY_SID", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE": {
		1: {Name: "ERO_METRIC", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "ERO_PATH", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "SID_MPLS_LABEL_BINDING", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE": {
		1: {Name: "EXTENDED_PREFIX_RANGE", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "PREFIX_SID", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "SID_LABEL_BINDING", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE": {
		1: {Name: "IPV4_SEGMENT", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "UNNUMBERED_INTERFACE_SEGMENT", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE": {
		1: {Name: "POINT_TO_POINT_LINK", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "STUB_NETWORK_LINK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "TRANSIT_NETWORK_LINK", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "VIRTUAL_LINK", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_LSA_TYPE": {
		1: {Name: "AS_EXTERNAL_LSA", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "NETWORK_LSA", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "NSSA_AS_EXTERNAL_LSA", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "OSPFV2_AREA_SCOPE_OPAQUE_LSA", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "OSPFV2_AS_SCOPE_OPAQUE_LSA", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "OSPFV2_LINK_SCOPE_OPAQUE_LSA", DefiningModule: "openconfig-ospf-types"},
		7: {Name: "ROUTER_LSA", DefiningModule: "openconfig-ospf-types"},
		8: {Name: "SUMMARY_ASBR_LSA", DefiningModule: "openconfig-ospf-types"},
		9: {Name: "SUMMARY_IP_NETWORK_LSA", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE": {
		1: {Name: "ATTEMPT", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "DOWN", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "EXCHANGE", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "EXSTART", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "FULL", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "INIT", DefiningModule: "openconfig-ospf-types"},
		7: {Name: "LOADING", DefiningModule: "openconfig-ospf-types"},
		8: {Name: "TWO_WAY", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE": {
		1: {Name: "BROADCAST_NETWORK", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "NON_BROADCAST_NETWORK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "POINT_TO_POINT_NETWORK", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE": {
		1: {Name: "GRACE_LSA", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "OSPFV2_EXTENDED_LINK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "OSPFV2_EXTENDED_PREFIX", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "ROUTER_INFORMATION", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "TRAFFIC_ENGINEERING", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES": {
		1: {Name: "SR_SID_LABEL_TLV", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE": {
		1: {Name: "TE_LINK_ADMIN_GROUP", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "TE_LINK_ID", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "TE_LINK_LOCAL_IP", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "TE_LINK_MAXIMUM_BANDWIDTH", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "TE_LINK_METRIC", DefiningModule: "openconfig-ospf-types"},
		7: {Name: "TE_LINK_REMOTE_IP", DefiningModule: "openconfig-ospf-types"},
		8: {Name: "TE_LINK_TYPE", DefiningModule: "openconfig-ospf-types"},
		9: {Name: "TE_LINK_UNRESERVED_BANDWIDTH", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE": {
		1: {Name: "TE_LINK", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "TE_LINK_LOCAL", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "TE_NODE_ATTRIBUTE", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "TE_OPTICAL_NODE_PROPERTY", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "TE_ROUTER_ADDRESS", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "TE_ROUTER_IPV6_ADDRESS", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES": {
		1: {Name: "RI_FUNCTIONAL_CAPABILITIES", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "RI_INFORMATIONAL_CAPABILITIES", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "RI_NODE_ADMIN_TAG", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "RI_SR_ALGORITHM", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "RI_SR_SID_LABEL_RANGE", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_ROUTER_LSA_TYPES": {
		1: {Name: "ROUTER_LSA_P2P", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "ROUTER_LSA_STUB_NETWORK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "ROUTER_LSA_TRANSIT_NETWORK", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "ROUTER_LSA_VIRTUAL_LINK", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_SR_ALGORITHM": {
		1: {Name: "SPF", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "STRICT_SPF", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_SrSidType": {
		1: {Name: "LABEL"},
		2: {Name: "SID"},
	},
	"E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE": {
		1: {Name: "NODE_IPV4_LOCAL_ADDRESS", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "NODE_IPV6_LOCAL_ADDRESS", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigPacketMatchTypes_ETHERTYPE": {
		1: {Name: "ETHERTYPE_ARP", DefiningModule: "openconfig-packet-match-types"},
		2: {Name: "ETHERTYPE_IPV4", DefiningModule: "openconfig-packet-match-types"},
		3: {Name: "ETHERTYPE_IPV6", DefiningModule: "openconfig-packet-match-types"},
		4: {Name: "ETHERTYPE_LLDP", DefiningModule: "openconfig-packet-match-types"},
		5: {Name: "ETHERTYPE_MPLS", DefiningModule: "openconfig-packet-match-types"},
		6: {Name: "ETHERTYPE_ROCE", DefiningModule: "openconfig-packet-match-types"},
		7: {Name: "ETHERTYPE_VLAN", DefiningModule: "openconfig-packet-match-types"},
	},
	"E_OpenconfigPacketMatchTypes_IP_PROTOCOL": {
		1: {Name: "IP_AUTH", DefiningModule: "openconfig-packet-match-types"},
		2: {Name: "IP_GRE", DefiningModule: "openconfig-packet-match-types"},
		3: {Name: "IP_ICMP", DefiningModule: "openconfig-packet-match-types"},
		4: {Name: "IP_IGMP", DefiningModule: "openconfig-packet-match-types"},
		5: {Name: "IP_L2TP", DefiningModule: "openconfig-packet-match-types"},
		6: {Name: "IP_PIM", DefiningModule: "openconfig-packet-match-types"},
		7: {Name: "IP_RSVP", DefiningModule: "openconfig-packet-match-types"},
		8: {Name: "IP_TCP", DefiningModule: "openconfig-packet-match-types"},
		9: {Name: "IP_UDP", DefiningModule: "openconfig-packet-match-types"},
	},
	"E_OpenconfigPacketMatchTypes_PortNumRange_Enum": {
		1: {Name: "ANY"},
	},
	"E_OpenconfigPacketMatchTypes_TCP_FLAGS": {
		1: {Name: "TCP_ACK", DefiningModule: "openconfig-packet-match-types"},
		2: {Name: "TCP_CWR", DefiningModule: "openconfig-packet-match-types"},
		3: {Name: "TCP_ECE", DefiningModule: "openconfig-packet-match-types"},
		4: {Name: "TCP_FIN", DefiningModule: "openconfig-packet-match-types"},
		5: {Name: "TCP_PSH", DefiningModule: "openconfig-packet-match-types"},
		6: {Name: "TCP_RST", DefiningModule: "openconfig-packet-match-types"},
		7: {Name: "TCP_SYN", DefiningModule: "openconfig-packet-match-types"},
		8: {Name: "TCP_URG", DefiningModule: "openconfig-packet-match-types"},
	},
	"E_OpenconfigPimTypes_PIM_MODE": {
		1: {Name: "PIM_MODE_DENSE", DefiningModule: "openconfig-pim-types"},
		2: {Name: "PIM_MODE_SPARSE", DefiningModule: "openconfig-pim-types"},
	},
	"E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS": {
		1: {Name: "ACTIVE", DefiningModule: "openconfig-platform-types"},
		2: {Name: "DISABLED", DefiningModule: "openconfig-platform-types"},
		3: {Name: "INACTIVE", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPlatformTypes_FEC_MODE_TYPE": {
		1: {Name: "FEC_AUTO", DefiningModule: "openconfig-platform-types"},
		2: {Name: "FEC_DISABLED", DefiningModule: "openconfig-platform-types"},
		3: {Name: "FEC_ENABLED", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPlatformTypes_FEC_STATUS_TYPE": {
		1: {Name: "FEC_STATUS_LOCKED", DefiningModule: "openconfig-platform-types"},
		2: {Name: "FEC_STATUS_UNLOCKED", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT": {
		1:  {Name: "BACKPLANE", DefiningModule: "openconfig-platform-types"},
		2:  {Name: "CHASSIS", DefiningModule: "openconfig-platform-types"},
		3:  {Name: "CONTROLLER_CARD", DefiningModule: "openconfig-platform-types"},
		4:  {Name: "CPU", DefiningModule: "openconfig-platform-types"},
		5:  {Name: "FABRIC", DefiningModule: "openconfig-platform-types"},
		6:  {Name: "FAN", DefiningModule: "openconfig-platform-types"},
		7:  {Name: "FRU", DefiningModule: "openconfig-platform-types"},
		8:  {Name: "INTEGRATED_CIRCUIT", DefiningModule: "openconfig-platform-types"},
		9:  {Name: "LINECARD", DefiningModule: "openconfig-platform-types"},
		10: {Name: "OPTICAL_CHANNEL", DefiningModule: "openconfig-transport-types"},
		11: {Name: "PORT", DefiningModule: "openconfig-platform-types"},
		12: {Name: "POWER_SUPPLY", DefiningModule: "openconfig-platform-types"},
		13: {Name: "SENSOR", DefiningModule: "openconfig-platform-types"},
		14: {Name: "STORAGE", DefiningModule: "openconfig-platform-types"},
		15: {Name: "TRANSCEIVER", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT": {
		1: {Name: "OPERATING_SYSTEM", DefiningModule: "openconfig-platform-types"},
		2: {Name: "OPERATING_SYSTEM_UPDATE", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE": {
		1: {Name: "BGP", DefiningModule: "openconfig-policy-types"},
		2: {Name: "DIRECTLY_CONNECTED", DefiningModule: "openconfig-policy-types"},
		3: {Name: "IGMP", DefiningModule: "openconfig-policy-types"},
		4: {Name: "ISIS", DefiningModule: "openconfig-policy-types"},
		5: {Name: "LOCAL_AGGREGATE", DefiningModule: "openconfig-policy-types"},
		6: {Name: "OSPF", DefiningModule: "openconfig-policy-types"},
		7: {Name: "OSPF3", DefiningModule: "openconfig-policy-types"},
		8: {Name: "PIM", DefiningModule: "openconfig-policy-types"},
		9: {Name: "STATIC", DefiningModule: "openconfig-policy-types"},
	},
	"E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType": {
		1: {Name: "ANY"},
		2: {Name: "INVERT"},
	},
	"E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON": {
		1: {Name: "INVALID_AS_LOOP", DefiningModule: "openconfig-rib-bgp-types"},
		2: {Name: "INVALID_CLUSTER_LOOP", DefiningModule: "openconfig-rib-bgp-types"},
		3: {Name: "INVALID_CONFED", DefiningModule: "openconfig-rib-bgp-types"},
		4: {Name: "INVALID_ORIGINATOR", DefiningModule: "openconfig-rib-bgp-types"},
	},
	"E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE": {
		1: {Name: "SRTE_BINDING_SID", DefiningModule: "openconfig-rib-bgp-types"},
		2: {Name: "SRTE_PREFERENCE", DefiningModule: "openconfig-rib-bgp-types"},
		3: {Name: "SRTE_SEGMENT_LIST", DefiningModule: "openconfig-rib-bgp-types"},
		4: {Name: "TUNNEL_COLOR", DefiningModule: "openconfig-rib-bgp-types"},
		5: {Name: "TUNNEL_REMOTE_ENDPOINT", DefiningModule: "openconfig-rib-bgp-types"},
	},
	"E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE": {
		1: {Name: "SRTE_POLICY_TUNNEL", DefiningModule: "openconfig-rib-bgp-types"},
	},
	"E_OpenconfigRoutingPolicy_DefaultPolicyType": {
		1: {Name: "ACCEPT_ROUTE"},
		2: {Name: "REJECT_ROUTE"},
	},
	"E_OpenconfigRoutingPolicy_PolicyResultType": {
		1: {Name: "ACCEPT_ROUTE"},
		2: {Name: "REJECT_ROUTE"},
	},
	"E_OpenconfigSegmentRoutingTypes_EnlpType": {
		1: {Name: "PUSH_IPV4_EXPLICIT_NULL"},
		2: {Name: "PUSH_IPV6_EXPLICIT_NULL"},
		3: {Name: "PUSH_IPV46_EXPLICIT_NULL"},
		4: {Name: "NO_EXPLICIT_NULL"},
	},
	"E_OpenconfigSegmentRoutingTypes_SrDataplaneType": {
		1: {Name: "MPLS"},
		2: {Name: "IPV6"},
	},
	"E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason": {
		1: {Name: "EMPTY_SL"},
		2: {Name: "ZERO_WEIGHT"},
		3: {Name: "FIRST_SID_UNRESOLVABLE"},
		4: {Name: "OTHER_SID_UNRESOLVABLE"},
		5: {Name: "VERIFICATION_FAIL"},
	},
	"E_OpenconfigSegmentRoutingTypes_SrteProtocolType": {
		11: {Name: "PCEP"},
		21: {Name: "BGP"},
		31: {Name: "CONFIG"},
	},
	"E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT": {
		1: {Name: "EDGE_AUTO", DefiningModule: "openconfig-spanning-tree-types"},
		2: {Name: "EDGE_DISABLE", DefiningModule: "openconfig-spanning-tree-types"},
		3: {Name: "EDGE_ENABLE", DefiningModule: "openconfig-spanning-tree-types"},
	},
	"E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE": {
		1: {Name: "ALTERNATE", DefiningModule: "openconfig-spanning-tree-types"},
		2: {Name: "BACKUP", DefiningModule: "openconfig-spanning-tree-types"},
		3: {Name: "DESIGNATED", DefiningModule: "openconfig-spanning-tree-types"},
		4: {Name: "ROOT", DefiningModule: "openconfig-spanning-tree-types"},
	},
	"E_OpenconfigSpanningTreeTypes_STP_PORT_STATE": {
		1: {Name: "BLOCKING", DefiningModule: "openconfig-spanning-tree-types"},
		2: {Name: "DISABLED", DefiningModule: "openconfig-spanning-tree-types"},
		3: {Name: "FORWARDING", DefiningModule: "openconfig-spanning-tree-types"},
		4: {Name: "LEARNING", DefiningModule: "openconfig-spanning-tree-types"},
		5: {Name: "LISTENING", DefiningModule: "openconfig-spanning-tree-types"},
	},
	"E_OpenconfigSpanningTreeTypes_STP_PROTOCOL": {
		1: {Name: "MSTP", DefiningModule: "openconfig-spanning-tree-types"},
		2: {Name: "RAPID_PVST", DefiningModule: "openconfig-spanning-tree-types"},
		3: {Name: "RSTP", DefiningModule: "openconfig-spanning-tree-types"},
	},
	"E_OpenconfigSpanningTreeTypes_StpGuardType": {
		1: {Name: "ROOT"},
		2: {Name: "LOOP"},
		3: {Name: "NONE"},
	},
	"E_OpenconfigSpanningTreeTypes_StpLinkType": {
		1: {Name: "P2P"},
		2: {Name: "SHARED"},
	},
	"E_OpenconfigSystemLogging_SYSLOG_FACILITY": {
		1:  {Name: "ALL", DefiningModule: "openconfig-system-logging"},
		2:  {Name: "AUDIT", DefiningModule: "openconfig-system-logging"},
		3:  {Name: "AUTH", DefiningModule: "openconfig-system-logging"},
		4:  {Name: "AUTHPRIV", DefiningModule: "openconfig-system-logging"},
		5:  {Name: "CONSOLE", DefiningModule: "openconfig-system-logging"},
		6:  {Name: "KERNEL", DefiningModule: "openconfig-system-logging"},
		7:  {Name: "LOCAL0", DefiningModule: "openconfig-system-logging"},
		8:  {Name: "LOCAL1", DefiningModule: "openconfig-system-logging"},
		9:  {Name: "LOCAL2", DefiningModule: "openconfig-system-logging"},
		10: {Name: "LOCAL3", DefiningModule: "openconfig-system-logging"},
		11: {Name: "LOCAL4", DefiningModule: "openconfig-system-logging"},
		12: {Name: "LOCAL5", DefiningModule: "openconfig-system-logging"},
		13: {Name: "LOCAL6", DefiningModule: "openconfig-system-logging"},
		14: {Name: "LOCAL7", DefiningModule: "openconfig-system-logging"},
		15: {Name: "MAIL", DefiningModule: "openconfig-system-logging"},
		16: {Name: "NTP", DefiningModule: "openconfig-system-logging"},
		17: {Name: "SYSLOG", DefiningModule: "openconfig-system-logging"},
		18: {Name: "SYSTEM_DAEMON", DefiningModule: "openconfig-system-logging"},
		19: {Name: "USER", DefiningModule: "openconfig-system-logging"},
	},
	"E_OpenconfigSystemLogging_SyslogSeverity": {
		1: {Name: "EMERGENCY"},
		2: {Name: "ALERT"},
		3: {Name: "CRITICAL"},
		4: {Name: "ERROR"},
		5: {Name: "WARNING"},
		6: {Name: "NOTICE"},
		7: {Name: "INFORMATIONAL"},
		8: {Name: "DEBUG"},
	},
	"E_OpenconfigSystem_NTP_AUTH_TYPE": {
		1: {Name: "NTP_AUTH_MD5", DefiningModule: "openconfig-system"},
	},
	"E_OpenconfigTransportLineProtection_APS_PATHS": {
		1: {Name: "PRIMARY", DefiningModule: "openconfig-transport-line-protection"},
		2: {Name: "SECONDARY", DefiningModule: "openconfig-transport-line-protection"},
	},
	"E_OpenconfigTransportTypes_AdminStateType": {
		1: {Name: "ENABLED"},
		2: {Name: "DISABLED"},
		3: {Name: "MAINT"},
	},
	"E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE": {
		1:  {Name: "ETH_100GBASE_CLR4", DefiningModule: "openconfig-transport-types"},
		2:  {Name: "ETH_100GBASE_CR4", DefiningModule: "openconfig-transport-types"},
		3:  {Name: "ETH_100GBASE_CWDM4", DefiningModule: "openconfig-transport-types"},
		4:  {Name: "ETH_100GBASE_ER4", DefiningModule: "openconfig-transport-types"},
		5:  {Name: "ETH_100GBASE_LR4", DefiningModule: "openconfig-transport-types"},
		6:  {Name: "ETH_100GBASE_PSM4", DefiningModule: "openconfig-transport-types"},
		7:  {Name: "ETH_100GBASE_SR10", DefiningModule: "openconfig-transport-types"},
		8:  {Name: "ETH_100GBASE_SR4", DefiningModule: "openconfig-transport-types"},
		9:  {Name: "ETH_100G_ACC", DefiningModule: "openconfig-transport-types"},
		10: {Name: "ETH_100G_AOC", DefiningModule: "openconfig-transport-types"},
		11: {Name: "ETH_10GBASE_ER", DefiningModule: "openconfig-transport-types"},
		12: {Name: "ETH_10GBASE_LR", DefiningModule: "openconfig-transport-types"},
		13: {Name: "ETH_10GBASE_LRM", DefiningModule: "openconfig-transport-types"},
		14: {Name: "ETH_10GBASE_SR", DefiningModule: "openconfig-transport-types"},
		15: {Name: "ETH_10GBASE_ZR", DefiningModule: "openconfig-transport-types"},
		16: {Name: "ETH_40GBASE_CR4", DefiningModule: "openconfig-transport-types"},
		17: {Name: "ETH_40GBASE_ER4", DefiningModule: "openconfig-transport-types"},
		18: {Name: "ETH_40GBASE_LR4", DefiningModule: "openconfig-transport-types"},
		19: {Name: "ETH_40GBASE_PSM4", DefiningModule: "openconfig-transport-types"},
		20: {Name: "ETH_40GBASE_SR4", DefiningModule: "openconfig-transport-types"},
		21: {Name: "ETH_4X10GBASE_LR", DefiningModule: "openconfig-transport-types"},
		22: {Name: "ETH_4X10GBASE_SR", DefiningModule: "openconfig-transport-types"},
		23: {Name: "ETH_UNDEFINED", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE": {
		1: {Name: "AOC_CONNECTOR", DefiningModule: "openconfig-transport-types"},
		2: {Name: "DAC_CONNECTOR", DefiningModule: "openconfig-transport-types"},
		3: {Name: "LC_CONNECTOR", DefiningModule: "openconfig-transport-types"},
		4: {Name: "MPO_CONNECTOR", DefiningModule: "openconfig-transport-types"},
		5: {Name: "SC_CONNECTOR", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL": {
		1: {Name: "AMP", DefiningModule: "openconfig-transport-types"},
		2: {Name: "BMP", DefiningModule: "openconfig-transport-types"},
		3: {Name: "CBR", DefiningModule: "openconfig-transport-types"},
		4: {Name: "GFP_F", DefiningModule: "openconfig-transport-types"},
		5: {Name: "GFP_T", DefiningModule: "openconfig-transport-types"},
		6: {Name: "GMP", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE": {
		1: {Name: "PROT_ETHERNET", DefiningModule: "openconfig-transport-types"},
		2: {Name: "PROT_OTN", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_LoopbackModeType": {
		1: {Name: "NONE"},
		2: {Name: "FACILITY"},
		3: {Name: "TERMINAL"},
	},
	"E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE": {
		1: {Name: "ADD", DefiningModule: "openconfig-transport-types"},
		2: {Name: "DROP", DefiningModule: "openconfig-transport-types"},
		3: {Name: "EGRESS", DefiningModule: "openconfig-transport-types"},
		4: {Name: "INGRESS", DefiningModule: "openconfig-transport-types"},
		5: {Name: "MONITOR", DefiningModule: "openconfig-transport-types"},
		6: {Name: "TERMINAL_CLIENT", DefiningModule: "openconfig-transport-types"},
		7: {Name: "TERMINAL_LINE", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_OTN_APPLICATION_CODE": {
		1: {Name: "OTN_UNDEFINED", DefiningModule: "openconfig-transport-types"},
		2: {Name: "P1L1_2D1", DefiningModule: "openconfig-transport-types"},
		3: {Name: "P1L1_2D2", DefiningModule: "openconfig-transport-types"},
		4: {Name: "P1S1_2D2", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_SONET_APPLICATION_CODE": {
		1: {Name: "SONET_UNDEFINED", DefiningModule: "openconfig-transport-types"},
		2: {Name: "VSR2000_3R2", DefiningModule: "openconfig-transport-types"},
		3: {Name: "VSR2000_3R3", DefiningModule: "openconfig-transport-types"},
		4: {Name: "VSR2000_3R5", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE": {
		1:  {Name: "CFP", DefiningModule: "openconfig-transport-types"},
		2:  {Name: "CFP2", DefiningModule: "openconfig-transport-types"},
		3:  {Name: "CFP2_ACO", DefiningModule: "openconfig-transport-types"},
		4:  {Name: "CFP4", DefiningModule: "openconfig-transport-types"},
		5:  {Name: "CPAK", DefiningModule: "openconfig-transport-types"},
		6:  {Name: "NON_PLUGGABLE", DefiningModule: "openconfig-transport-types"},
		7:  {Name: "OTHER", DefiningModule: "openconfig-transport-types"},
		8:  {Name: "QSFP", DefiningModule: "openconfig-transport-types"},
		9:  {Name: "QSFP28", DefiningModule: "openconfig-transport-types"},
		10: {Name: "QSFP_PLUS", DefiningModule: "openconfig-transport-types"},
		11: {Name: "SFP", DefiningModule: "openconfig-transport-types"},
		12: {Name: "SFP_PLUS", DefiningModule: "openconfig-transport-types"},
		13: {Name: "X2", DefiningModule: "openconfig-transport-types"},
		14: {Name: "XFP", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE": {
		1:  {Name: "PROT_100GE", DefiningModule: "openconfig-transport-types"},
		2:  {Name: "PROT_100G_MLG", DefiningModule: "openconfig-transport-types"},
		3:  {Name: "PROT_10GE_LAN", DefiningModule: "openconfig-transport-types"},
		4:  {Name: "PROT_10GE_WAN", DefiningModule: "openconfig-transport-types"},
		5:  {Name: "PROT_1GE", DefiningModule: "openconfig-transport-types"},
		6:  {Name: "PROT_400GE", DefiningModule: "openconfig-transport-types"},
		7:  {Name: "PROT_40GE", DefiningModule: "openconfig-transport-types"},
		8:  {Name: "PROT_OC192", DefiningModule: "openconfig-transport-types"},
		9:  {Name: "PROT_OC48", DefiningModule: "openconfig-transport-types"},
		10: {Name: "PROT_OC768", DefiningModule: "openconfig-transport-types"},
		11: {Name: "PROT_ODU2", DefiningModule: "openconfig-transport-types"},
		12: {Name: "PROT_ODU2E", DefiningModule: "openconfig-transport-types"},
		13: {Name: "PROT_ODU3", DefiningModule: "openconfig-transport-types"},
		14: {Name: "PROT_ODU4", DefiningModule: "openconfig-transport-types"},
		15: {Name: "PROT_ODUCN", DefiningModule: "openconfig-transport-types"},
		16: {Name: "PROT_OTU1E", DefiningModule: "openconfig-transport-types"},
		17: {Name: "PROT_OTU2", DefiningModule: "openconfig-transport-types"},
		18: {Name: "PROT_OTU2E", DefiningModule: "openconfig-transport-types"},
		19: {Name: "PROT_OTU3", DefiningModule: "openconfig-transport-types"},
		20: {Name: "PROT_OTU4", DefiningModule: "openconfig-transport-types"},
		21: {Name: "PROT_OTUCN", DefiningModule: "openconfig-transport-types"},
		22: {Name: "PROT_STM16", DefiningModule: "openconfig-transport-types"},
		23: {Name: "PROT_STM256", DefiningModule: "openconfig-transport-types"},
		24: {Name: "PROT_STM64", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE": {
		1:  {Name: "TRIB_RATE_1000G", DefiningModule: "openconfig-transport-types"},
		2:  {Name: "TRIB_RATE_100G", DefiningModule: "openconfig-transport-types"},
		3:  {Name: "TRIB_RATE_1050G", DefiningModule: "openconfig-transport-types"},
		4:  {Name: "TRIB_RATE_10G", DefiningModule: "openconfig-transport-types"},
		5:  {Name: "TRIB_RATE_1100G", DefiningModule: "openconfig-transport-types"},
		6:  {Name: "TRIB_RATE_1150G", DefiningModule: "openconfig-transport-types"},
		7:  {Name: "TRIB_RATE_1200G", DefiningModule: "openconfig-transport-types"},
		8:  {Name: "TRIB_RATE_1250G", DefiningModule: "openconfig-transport-types"},
		9:  {Name: "TRIB_RATE_1300G", DefiningModule: "openconfig-transport-types"},
		10: {Name: "TRIB_RATE_1350G", DefiningModule: "openconfig-transport-types"},
		11: {Name: "TRIB_RATE_1400G", DefiningModule: "openconfig-transport-types"},
		12: {Name: "TRIB_RATE_1450G", DefiningModule: "openconfig-transport-types"},
		13: {Name: "TRIB_RATE_1500G", DefiningModule: "openconfig-transport-types"},
		14: {Name: "TRIB_RATE_150G", DefiningModule: "openconfig-transport-types"},
		15: {Name: "TRIB_RATE_1550G", DefiningModule: "openconfig-transport-types"},
		16: {Name: "TRIB_RATE_1600G", DefiningModule: "openconfig-transport-types"},
		17: {Name: "TRIB_RATE_1G", DefiningModule: "openconfig-transport-types"},
		18: {Name: "TRIB_RATE_2.5G", DefiningModule: "openconfig-transport-types"},
		19: {Name: "TRIB_RATE_200G", DefiningModule: "openconfig-transport-types"},
		20: {Name: "TRIB_RATE_250G", DefiningModule: "openconfig-transport-types"},
		21: {Name: "TRIB_RATE_300G", DefiningModule: "openconfig-transport-types"},
		22: {Name: "TRIB_RATE_350G", DefiningModule: "openconfig-transport-types"},
		23: {Name: "TRIB_RATE_400G", DefiningModule: "openconfig-transport-types"},
		24: {Name: "TRIB_RATE_40G", DefiningModule: "openconfig-transport-types"},
		25: {Name: "TRIB_RATE_450G", DefiningModule: "openconfig-transport-types"},
		26: {Name: "TRIB_RATE_500G", DefiningModule: "openconfig-transport-types"},
		27: {Name: "TRIB_RATE_550G", DefiningModule: "openconfig-transport-types"},
		28: {Name: "TRIB_RATE_600G", DefiningModule: "openconfig-transport-types"},
		29: {Name: "TRIB_RATE_650G", DefiningModule: "openconfig-transport-types"},
		30: {Name: "TRIB_RATE_700G", DefiningModule: "openconfig-transport-types"},
		31: {Name: "TRIB_RATE_750G", DefiningModule: "openconfig-transport-types"},
		32: {Name: "TRIB_RATE_800G", DefiningModule: "openconfig-transport-types"},
		33: {Name: "TRIB_RATE_850G", DefiningModule: "openconfig-transport-types"},
		34: {Name: "TRIB_RATE_900G", DefiningModule: "openconfig-transport-types"},
		35: {Name: "TRIB_RATE_950G", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY": {
		1: {Name: "TRIB_SLOT_1.25G", DefiningModule: "openconfig-transport-types"},
		2: {Name: "TRIB_SLOT_2.5G", DefiningModule: "openconfig-transport-types"},
		3: {Name: "TRIB_SLOT_5G", DefiningModule: "openconfig-transport-types"},
	},
	"E_OpenconfigTypes_ADDRESS_FAMILY": {
		1: {Name: "IPV4", DefiningModule: "openconfig-types"},
		2: {Name: "IPV6", DefiningModule: "openconfig-types"},
		3: {Name: "L2_ETHERNET", DefiningModule: "openconfig-types"},
		4: {Name: "MPLS", DefiningModule: "openconfig-types"},
	},
	"E_OpenconfigVlanTypes_TPID_TYPES": {
		1: {Name: "TPID_0X8100", DefiningModule: "openconfig-vlan-types"},
		2: {Name: "TPID_0X88A8", DefiningModule: "openconfig-vlan-types"},
		3: {Name: "TPID_0X9100", DefiningModule: "openconfig-vlan-types"},
		4: {Name: "TPID_0X9200", DefiningModule: "openconfig-vlan-types"},
		5: {Name: "TPID_ANY", DefiningModule: "openconfig-vlan-types"},
	},
	"E_OpenconfigVlanTypes_VlanModeType": {
		1: {Name: "ACCESS"},
		2: {Name: "TRUNK"},
	},
	"E_OpenconfigVlanTypes_VlanStackAction": {
		1: {Name: "PUSH"},
		2: {Name: "POP"},
		3: {Name: "SWAP"},
	},
	"E_PrefixSet_Mode": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
		3: {Name: "MIXED"},
	},
	"E_PrefixSid_Flags": {
		1: {Name: "READVERTISEMENT"},
		2: {Name: "NODE"},
		3: {Name: "NO_PHP"},
		4: {Name: "EXPLICIT_NULL"},
		5: {Name: "VALUE"},
		6: {Name: "LOCAL"},
	},
	"E_PrefixSid_LabelOptions": {
		1: {Name: "NO_PHP"},
		2: {Name: "EXPLICIT_NULL"},
	},
	"E_PrefixSid_SidScope": {
		1: {Name: "LOCAL"},
		2: {Name: "GLOBAL"},
	},
	"E_PrefixSid_SidValueType": {
		1: {Name: "ABSOLUTE"},
		2: {Name: "INDEX"},
	},
	"E_ProxyArp_Mode": {
		1: {Name: "DISABLE"},
		2: {Name: "REMOTE_ONLY"},
		3: {Name: "ALL"},
	},
	"E_RouterInformation_Tlv_Type_Enum": {
		1: {Name: "UNKNOWN"},
	},
	"E_SegmentRoutingAlgorithms_Algorithm": {
		1: {Name: "SPF"},
		2: {Name: "STRICT_SPF"},
	},
	"E_SegmentRoutingCapability_Flags": {
		1: {Name: "IPV4_MPLS"},
		2: {Name: "IPV6_MPLS"},
		3: {Name: "IPV6_SR"},
	},
	"E_SegmentRoutingSidLabelRange_Tlv_Type_Enum": {
		1: {Name: "UNKNOWN"},
	},
	"E_Segment_Type": {
		2: {Name: "MPLS_SID"},
		3: {Name: "IPV6_SID"},
		4: {Name: "IPV4_NODE_ADDRESS"},
		5: {Name: "IPV6_NODE_ADDRESS"},
		6: {Name: "IPV4_LOCAL_INTF_ID"},
		7: {Name: "IPV4_LOCAL_REMOTE_ADDR"},
		8: {Name: "IPV6_LOCAL_INTF_ID"},
		9: {Name: "IPV6_LOCAL_REMOTE_ADDR"},
	},
	"E_Server_AssociationType": {
		1: {Name: "SERVER"},
		2: {Name: "PEER"},
		3: {Name: "POOL"},
	},
	"E_Session_Status": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
	},
	"E_SetTag_Mode": {
		1: {Name: "INLINE"},
		2: {Name: "REFERENCE"},
	},
	"E_SshServer_ProtocolVersion": {
		1: {Name: "V2"},
		2: {Name: "V1"},
		3: {Name: "V1_V2"},
	},
	"E_SubTlv_LinkType": {
		1: {Name: "POINT_TO_POINT"},
		2: {Name: "MULTI_ACCESS"},
		3: {Name: "UNKNOWN"},
	},
	"E_Tlv_Reason": {
		1: {Name: "UNKNOWN"},
		2: {Name: "SOFTWARE_RESTART"},
		3: {Name: "SOFTWARE_RELOAD_UPGRADE"},
		4: {Name: "CONTROL_PROCESSOR_SWITCH"},
	},
	"E_Topology_Attributes": {
		1: {Name: "OVERLOAD"},
		2: {Name: "ATTACHED"},
	},
	"E_Transceiver_Present": {
		1: {Name: "PRESENT"},
		2: {Name: "NOT_PRESENT"},
	},
	"E_Vlan_Status": {
		1: {Name: "ACTIVE"},
		2: {Name: "SUSPENDED"},
	},
}

var (
	// ySchema is a byte slice contain a gzip compressed representation of the
	// YANG schema from which the Go code was generated. When uncompressed the
	// contents of the byte slice is a JSON document containing an object, keyed
	// on the name of the generated struct, and containing the JSON marshalled
	// contents of a goyang yang.Entry struct, which defines the schema for the
	// fields within the struct.
	ySchema = []byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xec, 0xbd, 0x6b, 0x53, 0xdb, 0x58,
		0xd6, 0xfe, 0xfd, 0x3e, 0x9f, 0x82, 0x72, 0xcd, 0x8b, 0xa4, 0x2a, 0x4a, 0xc0, 0x18, 0x08, 0xa9,
		0x7a, 0x5e, 0xd0, 0x69, 0xd2, 0xc3, 0x7f, 0x48, 0xa0, 0x02, 0xc9, 0x4c, 0x57, 0x9a, 0xa1, 0x14,
		0x5b, 0x10, 0xd5, 0x08, 0xd9, 0xb7, 0x24, 0xd3, 0x49, 0x75, 0xf3, 0xdd, 0x9f, 0xf2, 0x11, 0x1f,
		0xb1, 0xb4, 0xf7, 0xda, 0x5b, 0xa7, 0x5f, 0xea, 0xbe, 0xa7, 0x73, 0xc0, 0x5b, 0xd6, 0x3e, 0x5c,
		0xeb, 0x5a, 0xd7, 0x5e, 0x87, 0xbf, 0x9e, 0x6d, 0x6d, 0x6d, 0x6d, 0x35, 0x3e, 0xba, 0x77, 0x5e,
		0xe3, 0xed, 0x56, 0xa3, 0xe3, 0xdd, 0xfb, 0x6d, 0xaf, 0xf1, 0x72, 0xf4, 0xb7, 0xff, 0xf2, 0xc3,
		0x4e, 0xe3, 0xed, 0xd6, 0xce, 0xf8, 0x8f, 0xef, 0xba, 0xe1, 0x8d, 0x7f, 0xdb, 0x78, 0xbb, 0xb5,
		0x3d, 0xfe, 0x8b, 0x5f, 0xfd, 0xa8, 0xf1, 0x76, 0x6b, 0x34, 0xc4, 0xf0, 0x2f, 0xdc, 0x76, 0x30,
		0xf7, 0x17, 0x73, 0x63, 0x0f, 0xfe, 0xf1, 0xe5, 0xfc, 0x3f, 0xcd, 0x3f, 0x60, 0xfa, 0xd7, 0x8b,
		0x0f, 0x9a, 0xfe, 0xc3, 0x79, 0xe4, 0xdd, 0xf8, 0x3f, 0x96, 0x1e, 0x31, 0xf7, 0x98, 0x6e, 0xdb,
		0x59, 0x7e, 0xd2, 0xf0, 0x27, 0x2e, 0xba, 0xfd, 0xa8, 0xed, 0xad, 0xfc, 0xf4, 0xe8, 0xdb, 0x78,
		0x3f, 0xff, 0xec, 0x46, 0x83, 0x2f, 0xd4, 0xe8, 0x8d, 0x1e, 0xf4, 0x72, 0xf5, 0x0f, 0xfe, 0xd3,
		0x8d, 0x8f, 0xa2, 0xdb, 0xfe, 0x9d, 0x17, 0x26, 0x8d, 0xb7, 0x5b, 0x49, 0xd4, 0xf7, 0xd6, 0xfc,
		0xe0, 0xcc, 0x4f, 0x4d, 0xbe, 0xd7, 0xd2, 0x0f, 0x3e, 0xcc, 0xfd, 0xcd, 0xc3, 0xc2, 0x1b, 0x2f,
		0x4e, 0xf1, 0xec, 0x54, 0x3b, 0xb1, 0x97, 0xc4, 0xeb, 0x5f, 0x67, 0x66, 0xde, 0x47, 0x3f, 0xb9,
		0xe6, 0x4b, 0xae, 0x5e, 0x84, 0x8d, 0x8b, 0x91, 0x66, 0x51, 0xd2, 0x2f, 0x4e, 0xda, 0x45, 0xca,
		0xbc, 0x58, 0x99, 0x17, 0x2d, 0xd3, 0xe2, 0xad, 0x5e, 0xc4, 0x35, 0x8b, 0xb9, 0x71, 0x51, 0x17,
		0x17, 0x77, 0xf3, 0x2c, 0x2c, 0xac, 0xf1, 0xa6, 0x39, 0x78, 0x7a, 0xa9, 0x53, 0x2f, 0x79, 0x96,
		0xa5, 0xcf, 0xbe, 0x05, 0xb2, 0x6e, 0x05, 0xe5, 0x2d, 0xa1, 0xbc, 0x35, 0x94, 0xb6, 0xc8, 0xd3,
		0x5b, 0x65, 0xc3, 0x96, 0x49, 0xbd, 0x75, 0xe6, 0xb6, 0x90, 0x17, 0x26, 0x91, 0xef, 0xc5, 0xe9,
		0x67, 0x70, 0x76, 0x3b, 0x4d, 0x3e, 0x9c, 0x72, 0x2a, 0xd2, 0x6d, 0xad, 0xcc, 0x5b, 0x4c, 0x65,
		0xab, 0xa9, 0x6f, 0x39, 0xd5, 0xad, 0xa7, 0xbd, 0x05, 0xb5, 0xb7, 0xa2, 0xd6, 0x96, 0x4c, 0xb7,
		0x35, 0x53, 0x6e, 0xd1, 0xcc, 0x5b, 0x75, 0x69, 0xcb, 0xfe, 0xcc, 0x3e, 0xef, 0x8b, 0x1b, 0xf7,
		0x67, 0xd6, 0x79, 0xcf, 0xb6, 0x7d, 0x95, 0xb7, 0xb1, 0xce, 0x76, 0xd6, 0xdf, 0xd6, 0xba, 0xdb,
		0x5b, 0x6c, 0x9b, 0x8b, 0x6d, 0x77, 0x91, 0x6d, 0x9f, 0x6d, 0xfb, 0x67, 0x3c, 0x06, 0xca, 0xc7,
		0x61, 0xe6, 0x58, 0x24, 0x7e, 0x37, 0x8c, 0xd5, 0x57, 0xeb, 0xf1, 0x70, 0x8c, 0x06, 0x52, 0x9c,
		0x62, 0xb5, 0x23, 0xa2, 0x7d, 0x54, 0x24, 0x8e, 0x8c, 0xdc, 0xd1, 0x91, 0x3a, 0x42, 0xe2, 0x47,
		0x49, 0xfc, 0x48, 0x89, 0x1e, 0x2d, 0xb5, 0x23, 0xa6, 0x78, 0xd4, 0xb4, 0x8f, 0xdc, 0x74, 0x80,
		0xf6, 0x64, 0xcf, 0x6a, 0x2e, 0xf2, 0x64, 0xdb, 0x8d, 0xc7, 0xd3, 0x5c, 0x10, 0xbd, 0x83, 0x28,
		0x76, 0x20, 0x25, 0x0f, 0xa6, 0xfc, 0x01, 0x95, 0x3e, 0xa8, 0xc6, 0x0e, 0xac, 0xb1, 0x83, 0x6b,
		0xe4, 0x00, 0xeb, 0x1d, 0x64, 0xcd, 0x03, 0x2d, 0x76, 0xb0, 0xa7, 0x03, 0xdd, 0x74, 0xa3, 0x3f,
		0xdd, 0xa8, 0xe3, 0x87, 0xb7, 0xce, 0xc8, 0x3a, 0xca, 0xed, 0x93, 0xc9, 0x4e, 0x5e, 0x7e, 0x84,
		0xd0, 0xb2, 0x8e, 0x61, 0x60, 0x5b, 0x68, 0x38, 0x29, 0x38, 0x30, 0x01, 0x0b, 0xe6, 0xe0, 0xc1,
		0x14, 0x4c, 0x18, 0x87, 0x0b, 0xe3, 0xb0, 0x61, 0x14, 0x3e, 0x64, 0x60, 0x44, 0x08, 0x4e, 0xa6,
		0x6f, 0x7a, 0xf9, 0xb3, 0xe7, 0x99, 0xd9, 0xaf, 0x7e, 0xc7, 0x0b, 0x13, 0x3f, 0xf9, 0x19, 0x79,
		0x37, 0x92, 0x9b, 0x76, 0xc2, 0x04, 0xf6, 0x04, 0xc7, 0x3c, 0x19, 0x7f, 0xd5, 0x5f, 0xdc, 0xd8,
		0xc0, 0x71, 0x98, 0x4c, 0xc8, 0xfb, 0xb3, 0x4f, 0xff, 0x3e, 0xfa, 0xf4, 0xeb, 0xc9, 0xc7, 0xdf,
		0xae, 0x8f, 0xde, 0x5d, 0x9e, 0x9c, 0x7d, 0x94, 0x3e, 0x16, 0x5f, 0xdc, 0xa0, 0x3f, 0x94, 0xbe,
		0xbe, 0x8a, 0x8e, 0x3b, 0xf8, 0xf5, 0x97, 0xf8, 0x88, 0x73, 0x53, 0x73, 0xf4, 0xee, 0xdd, 0xf1,
		0xf9, 0x65, 0x43, 0xfc, 0x21, 0x0f, 0x2f, 0xcb, 0x36, 0x13, 0xbf, 0x7e, 0x3a, 0x3b, 0x67, 0x1e,
		0xb6, 0x1a, 0x9f, 0x8e, 0xff, 0xdf, 0xf1, 0x3b, 0x13, 0x3b, 0x42, 0x74, 0xc4, 0xab, 0xa2, 0x59,
		0x85, 0x67, 0x05, 0xd8, 0x29, 0x8d, 0xa0, 0x6b, 0x8e, 0x5a, 0xce, 0x8c, 0x2d, 0x64, 0x01, 0x7f,
		0xf5, 0x6e, 0xdc, 0x7e, 0x30, 0x34, 0xf5, 0xa7, 0x67, 0xbf, 0x5d, 0x7f, 0x3c, 0xfb, 0x78, 0x0c,
		0x5d, 0x85, 0xae, 0x42, 0x57, 0xa1, 0xab, 0xb5, 0xa6, 0xab, 0x03, 0x30, 0x84, 0xa7, 0x2e, 0xcf,
		0xc9, 0xc5, 0xef, 0x17, 0xa7, 0x67, 0xbf, 0xc1, 0xd1, 0x66, 0xcc, 0x25, 0x2c, 0xcd, 0x36, 0x4b,
		0xcb, 0x55, 0x8a, 0x3c, 0x0a, 0xc3, 0x6e, 0xe2, 0x8a, 0xf1, 0xbb, 0x46, 0xdc, 0xfe, 0xee, 0xdd,
		0xb9, 0x3d, 0x37, 0xf9, 0x3e, 0xd8, 0x55, 0xaf, 0xbb, 0x3d, 0x2f, 0x1c, 0xdd, 0x1a, 0x0c, 0x2c,
		0xd9, 0xeb, 0xf1, 0xff, 0x0f, 0xe3, 0xb9, 0x26, 0xbf, 0x79, 0x3d, 0x13, 0xad, 0x31, 0xfd, 0xfd,
		0xcf, 0xd7, 0xe3, 0xdb, 0xbe, 0xd7, 0xe3, 0x3b, 0x87, 0x67, 0xf9, 0x4c, 0xb1, 0xc6, 0xf4, 0x36,
		0xe2, 0xc4, 0x4d, 0x3c, 0xb9, 0xcb, 0x97, 0xd1, 0x70, 0x05, 0xbb, 0x7b, 0x69, 0x72, 0xf7, 0x52,
		0x00, 0x76, 0xca, 0xdd, 0x4b, 0x06, 0x17, 0x91, 0xbb, 0x17, 0x9c, 0x59, 0x9c, 0x59, 0x9c, 0x59,
		0x9c, 0x59, 0xee, 0x5e, 0xaa, 0xe6, 0xd3, 0x72, 0xf7, 0xc2, 0xdd, 0xcb, 0xfc, 0x3c, 0x70, 0xf7,
		0x92, 0x93, 0x57, 0xcf, 0xdd, 0x0b, 0x77, 0x2f, 0xd0, 0x55, 0xe8, 0x2a, 0x74, 0xb5, 0xe6, 0x74,
		0x95, 0xbb, 0x97, 0xd5, 0x73, 0xc2, 0xdd, 0x0b, 0x77, 0x2f, 0xb9, 0xb3, 0x34, 0xee, 0x5e, 0x9e,
		0xba, 0x7b, 0x19, 0x5d, 0x39, 0xe4, 0x75, 0xf5, 0x62, 0x35, 0xd7, 0x46, 0x68, 0x2d, 0xc4, 0xd7,
		0xa0, 0xa1, 0x75, 0x01, 0x15, 0xf5, 0xdb, 0x49, 0x38, 0xd1, 0x06, 0xda, 0xc1, 0xf5, 0x51, 0x3b,
		0xb8, 0xf0, 0x92, 0xc1, 0x7f, 0x8e, 0x07, 0x0f, 0xb9, 0x3e, 0x1a, 0x3f, 0xe4, 0x99, 0x9d, 0x05,
		0x52, 0x58, 0x1c, 0xdd, 0x1c, 0x26, 0x99, 0xdc, 0x25, 0x92, 0x07, 0x4d, 0x78, 0x10, 0x24, 0x0f,
		0x1a, 0x04, 0x34, 0xed, 0xe4, 0xc1, 0x8e, 0x17, 0xb7, 0x23, 0xbf, 0x27, 0x62, 0x9e, 0x66, 0x0a,
		0xf4, 0x3c, 0x0e, 0x2a, 0x73, 0x95, 0xbd, 0x4d, 0x1a, 0x61, 0x0e, 0x4e, 0x3f, 0x57, 0xd9, 0x05,
		0xe0, 0x8f, 0x62, 0x4e, 0xfc, 0x4c, 0x8c, 0x49, 0xe4, 0x87, 0xb7, 0x12, 0xfb, 0x6d, 0x62, 0x30,
		0xdf, 0x94, 0x31, 0x70, 0xc7, 0xfb, 0xbf, 0xbe, 0x17, 0xb6, 0x3d, 0xc7, 0xef, 0x08, 0x86, 0xef,
		0xcc, 0x0c, 0x0a, 0xf2, 0x81, 0x7c, 0x20, 0x5f, 0xa1, 0x90, 0xaf, 0xef, 0x87, 0xc9, 0x6e, 0x53,
		0x10, 0xf9, 0x0e, 0x04, 0x86, 0xfa, 0xe4, 0x86, 0xb7, 0x9e, 0x98, 0xbe, 0x27, 0x28, 0xf6, 0x7e,
		0xf0, 0x43, 0x03, 0xf7, 0x07, 0xa2, 0xb7, 0x3c, 0xd3, 0x61, 0x87, 0x2a, 0xa9, 0x81, 0x71, 0xdf,
		0x47, 0x23, 0x17, 0xfd, 0x57, 0xff, 0xd6, 0x1f, 0xd6, 0x31, 0xdc, 0x96, 0x93, 0xc7, 0x04, 0x45,
		0xee, 0x0f, 0xee, 0x8f, 0xd2, 0x2d, 0x55, 0xab, 0x79, 0xd8, 0x3a, 0xdc, 0x3f, 0x68, 0x1e, 0xee,
		0x95, 0x68, 0xcd, 0x0a, 0x22, 0x69, 0x5e, 0x21, 0xd7, 0xe5, 0x21, 0xd7, 0xe9, 0x84, 0xa9, 0xdb,
		0x11, 0xd2, 0xfc, 0xb0, 0xd7, 0x4f, 0x1c, 0x3f, 0x4c, 0xbc, 0xe8, 0xc6, 0xd5, 0xa9, 0x9e, 0x36,
		0xbd, 0xe9, 0x5b, 0x18, 0x10, 0x69, 0x0d, 0x69, 0x0d, 0x69, 0x2d, 0xcd, 0x00, 0xd4, 0xe5, 0xc2,
		0xad, 0xc4, 0xad, 0x2c, 0x9e, 0x5b, 0x59, 0xd8, 0x0b, 0xd9, 0x05, 0x53, 0x5b, 0xe2, 0xa4, 0xb8,
		0xe9, 0x3b, 0x38, 0x91, 0x77, 0x23, 0x87, 0x80, 0xf3, 0xc3, 0x02, 0x84, 0x69, 0x80, 0xd0, 0xbf,
		0x01, 0x07, 0x0d, 0xe0, 0xa0, 0x7f, 0x43, 0x8a, 0x9c, 0x2c, 0xcf, 0x31, 0xc3, 0x77, 0x84, 0x8f,
		0xbb, 0xf8, 0xb1, 0x37, 0x71, 0xfc, 0x8d, 0xc1, 0x80, 0x29, 0x38, 0x30, 0x0e, 0x0b, 0xc6, 0xe1,
		0xc1, 0x24, 0x4c, 0x08, 0x6b, 0x4f, 0x52, 0x89, 0x00, 0x42, 0xf0, 0xb1, 0xcc, 0x19, 0xcc, 0x05,
		0xe9, 0xea, 0xaa, 0x18, 0x9b, 0xc0, 0x45, 0x5a, 0x29, 0x95, 0x06, 0x19, 0x93, 0x60, 0x63, 0x1c,
		0x74, 0x4c, 0x83, 0x8f, 0x35, 0x10, 0xb2, 0x06, 0x46, 0x36, 0x40, 0x49, 0x16, 0x9c, 0x84, 0x41,
		0x6a, 0x3a, 0x01, 0xe2, 0x89, 0x10, 0x4b, 0xbb, 0x3d, 0xf0, 0xdc, 0x1b, 0xd9, 0x64, 0x88, 0x25,
		0xe6, 0x72, 0x60, 0x60, 0xec, 0xf3, 0xa9, 0xd7, 0x3a, 0xd8, 0x16, 0x6f, 0xa7, 0x00, 0x19, 0x2f,
		0xfe, 0xc5, 0xf8, 0xcf, 0xc3, 0x30, 0xd3, 0x67, 0xc5, 0xdc, 0x38, 0x92, 0xf7, 0x69, 0x71, 0xff,
		0x9b, 0x05, 0x7b, 0x34, 0xf7, 0x14, 0x4c, 0x12, 0x26, 0x09, 0x93, 0x84, 0x49, 0xc2, 0x24, 0xa5,
		0x34, 0x49, 0x5f, 0x1f, 0x4d, 0xd2, 0xff, 0xd7, 0xee, 0x47, 0x91, 0x17, 0x26, 0xcf, 0x5f, 0xbc,
		0x7e, 0xf5, 0xea, 0xf5, 0xf4, 0x27, 0xae, 0xc6, 0x1f, 0x99, 0xc5, 0xd9, 0x78, 0xc5, 0xdf, 0x4d,
		0x47, 0xee, 0x78, 0x3f, 0x0a, 0x6b, 0xdd, 0x0a, 0xe5, 0xfd, 0x1d, 0xff, 0x48, 0x64, 0x53, 0x12,
		0xcd, 0x09, 0x09, 0xdd, 0xb6, 0xe3, 0xfd, 0x48, 0xde, 0x26, 0x5e, 0xe0, 0xdd, 0x79, 0x49, 0xf4,
		0xd3, 0xe9, 0x86, 0x4e, 0xfb, 0xfb, 0x30, 0xe6, 0xca, 0xa8, 0xb8, 0x70, 0xe3, 0x06, 0xb1, 0x49,
		0x75, 0xa1, 0x68, 0xc2, 0xc2, 0x95, 0x94, 0xd0, 0x2a, 0x7b, 0x3d, 0xf3, 0x48, 0xe9, 0x4c, 0x5d,
		0xd3, 0xcc, 0xdd, 0x4a, 0x88, 0x5c, 0xda, 0xc8, 0x2d, 0x8c, 0x44, 0x81, 0x0a, 0x99, 0x0a, 0x87,
		0xcb, 0xe4, 0x57, 0xa0, 0xd2, 0xe1, 0x92, 0x41, 0x92, 0x56, 0x77, 0x9b, 0xa8, 0xbb, 0xe5, 0x61,
		0xb1, 0xa8, 0xbb, 0xa8, 0xbb, 0xb8, 0xd2, 0xb8, 0xd2, 0xb8, 0xd2, 0xb8, 0xd2, 0xb8, 0xd2, 0xa8,
		0xbb, 0xeb, 0x19, 0x2d, 0xea, 0x2e, 0x26, 0x09, 0x93, 0x84, 0x49, 0xc2, 0x24, 0x15, 0xd6, 0x24,
		0xa1, 0xee, 0xe6, 0xe7, 0xfd, 0x95, 0x5c, 0x82, 0x13, 0x28, 0x68, 0x25, 0xa8, 0xc0, 0x11, 0xeb,
		0x9e, 0x79, 0x05, 0x1b, 0x22, 0xaa, 0xe5, 0xa6, 0xb2, 0x58, 0x27, 0x83, 0xaf, 0x70, 0x32, 0x79,
		0xee, 0xf5, 0xf4, 0x77, 0x9f, 0xbc, 0x1b, 0x1a, 0xd1, 0xd0, 0x88, 0x26, 0x03, 0xed, 0x24, 0xd9,
		0x88, 0x64, 0xa3, 0xb2, 0x03, 0x30, 0x55, 0x20, 0x0b, 0xb3, 0x16, 0x66, 0xab, 0x41, 0xce, 0x9b,
		0xbd, 0x42, 0xe7, 0xb2, 0xf7, 0xee, 0x5b, 0x02, 0x09, 0xec, 0x83, 0x51, 0xc8, 0x5a, 0x1f, 0xe0,
		0x69, 0xef, 0x7f, 0x89, 0x73, 0xe7, 0x26, 0xed, 0xef, 0xe4, 0xae, 0x2b, 0x58, 0xa3, 0xc7, 0xd9,
		0x23, 0x83, 0x5d, 0x6d, 0x0b, 0x92, 0xc1, 0x6e, 0xf9, 0xb0, 0x42, 0x2d, 0x0d, 0x1e, 0xe6, 0x62,
		0x10, 0x4c, 0xb1, 0x34, 0xce, 0x8e, 0x17, 0x27, 0x7e, 0x38, 0xa4, 0x45, 0x8e, 0xdb, 0xe9, 0x44,
		0x5e, 0x1c, 0xcb, 0x07, 0xfd, 0xac, 0x7a, 0x08, 0xed, 0x63, 0x8a, 0x06, 0x17, 0xa6, 0x60, 0xc3,
		0x38, 0x7c, 0x18, 0x87, 0x11, 0x0b, 0x70, 0x22, 0x27, 0x3d, 0x6e, 0x95, 0xa3, 0x95, 0x4c, 0xef,
		0xbe, 0xe5, 0x88, 0xef, 0x82, 0xc7, 0xd2, 0xb4, 0x82, 0x63, 0x9e, 0xbb, 0x49, 0xe2, 0x45, 0xa1,
		0x78, 0x2f, 0x96, 0xc6, 0x7f, 0x9f, 0x3f, 0xff, 0xba, 0xed, 0x1c, 0x5e, 0xfd, 0xfd, 0x75, 0xc7,
		0x39, 0xbc, 0x1a, 0xfd, 0x76, 0x67, 0xf8, 0x9f, 0xd1, 0xef, 0x9b, 0x5f, 0xb7, 0x9d, 0xd6, 0xe4,
		0xf7, 0x7b, 0x5f, 0xb7, 0x9d, 0xbd, 0xab, 0x17, 0x7f, 0xfc, 0xf1, 0xea, 0xc5, 0x5f, 0xbb, 0x0f,
		0xd9, 0x3f, 0xf8, 0x7a, 0xfc, 0xb0, 0x17, 0x7f, 0x3f, 0xff, 0xba, 0xe3, 0x34, 0xaf, 0x26, 0x7f,
		0xd8, 0xfd, 0xba, 0xed, 0x34, 0xaf, 0x5e, 0xbc, 0xf8, 0x87, 0xdc, 0x1e, 0xbe, 0x92, 0x9c, 0xfc,
		0xb3, 0x8b, 0x93, 0xff, 0xb0, 0x02, 0x59, 0x57, 0xa0, 0x42, 0x81, 0xc8, 0x9d, 0xb8, 0xdd, 0x33,
		0x40, 0x49, 0x06, 0xa3, 0xc2, 0x41, 0xe0, 0x20, 0x70, 0x90, 0xda, 0x72, 0x10, 0x41, 0x0c, 0x98,
		0xc5, 0x01, 0xc9, 0x36, 0x76, 0xb2, 0x55, 0xa2, 0x27, 0xbf, 0x0c, 0x04, 0xa8, 0x98, 0xa8, 0x1a,
		0x6d, 0x08, 0x60, 0x97, 0x86, 0x37, 0x54, 0x45, 0x7a, 0x3a, 0xbe, 0xc1, 0xca, 0xc4, 0xc2, 0x87,
		0x6d, 0x7e, 0x49, 0xdd, 0x1f, 0xa5, 0x5f, 0xd2, 0xfd, 0xdd, 0x12, 0xaf, 0x69, 0x41, 0xa3, 0x96,
		0xaa, 0x44, 0x2e, 0xbf, 0x77, 0x7b, 0x4e, 0xe0, 0xdf, 0xf9, 0x89, 0x3c, 0xc3, 0x7c, 0x1c, 0x1a,
		0x9a, 0x09, 0xcd, 0x84, 0x66, 0xd6, 0x96, 0x66, 0xf6, 0xfd, 0x30, 0x79, 0x03, 0xcf, 0x84, 0x67,
		0xc2, 0x33, 0x2b, 0xcb, 0x33, 0x9b, 0x7b, 0x7b, 0x10, 0x4d, 0x88, 0xe6, 0xfa, 0x65, 0xec, 0x45,
		0xdd, 0xa4, 0xdb, 0xee, 0x06, 0xf2, 0x3c, 0x73, 0x3a, 0x32, 0x34, 0x13, 0x9a, 0x09, 0xcd, 0xac,
		0x2d, 0xcd, 0xf4, 0x7b, 0xce, 0x04, 0x0a, 0x9c, 0x64, 0xf0, 0x14, 0x03, 0xd7, 0xaa, 0x87, 0x82,
		0x63, 0x8e, 0x67, 0xa2, 0xf0, 0x8c, 0xd3, 0x14, 0x8d, 0x37, 0x48, 0xe7, 0x0d, 0xd3, 0x7a, 0x73,
		0x93, 0x6d, 0x85, 0xe6, 0x5b, 0xe2, 0x86, 0xb6, 0x68, 0xbf, 0x4d, 0xa6, 0x68, 0xd0, 0x0d, 0xb0,
		0xe2, 0x0e, 0xe4, 0xb5, 0xf4, 0xcd, 0xbd, 0x56, 0x85, 0x16, 0xff, 0x59, 0x39, 0x46, 0xbd, 0x2a,
		0x72, 0xae, 0xb8, 0x41, 0x43, 0xe5, 0x77, 0xbc, 0x30, 0xf1, 0x93, 0x9f, 0x86, 0xf3, 0xc4, 0x4d,
		0xd8, 0xab, 0x93, 0xf1, 0x57, 0xff, 0xc5, 0x8d, 0x0d, 0x56, 0x5e, 0x98, 0x4c, 0xd4, 0xc9, 0xf9,
		0xf5, 0xf9, 0xa7, 0xb3, 0xcb, 0xb3, 0x77, 0x67, 0xa7, 0x0d, 0x93, 0xfa, 0x40, 0x6c, 0xcc, 0x02,
		0x9b, 0xb5, 0xc2, 0x8b, 0x93, 0xf5, 0xf9, 0xd7, 0xf3, 0x46, 0x19, 0x4d, 0x8a, 0xbd, 0x19, 0x3a,
		0x6d, 0x5e, 0x32, 0x45, 0x4f, 0x4f, 0xd1, 0xd1, 0xe7, 0xcb, 0x7f, 0x32, 0x45, 0x4f, 0x4e, 0xd1,
		0xa7, 0x8b, 0x2f, 0xec, 0xa2, 0xa7, 0xa7, 0xe8, 0xe4, 0xb7, 0x0f, 0x4c, 0xd1, 0x86, 0x29, 0x7a,
		0xc7, 0x14, 0x6d, 0xb2, 0xfe, 0x27, 0x1f, 0x98, 0xa1, 0x27, 0x67, 0xe8, 0xb7, 0x4f, 0xc7, 0xcc,
		0xd0, 0x93, 0x33, 0x74, 0xf9, 0xce, 0xe4, 0x29, 0x33, 0x32, 0xf2, 0x15, 0x37, 0x48, 0x96, 0xbf,
		0x8f, 0x48, 0x41, 0xee, 0xe1, 0x1d, 0x82, 0xb9, 0x24, 0xbd, 0x85, 0xf1, 0xb9, 0x4d, 0xd2, 0x9e,
		0x51, 0x6e, 0x93, 0x16, 0x1e, 0xc0, 0x6d, 0x92, 0xac, 0xe5, 0x23, 0x3f, 0x8f, 0xfc, 0x3c, 0x15,
		0xab, 0x48, 0x7e, 0x1e, 0xf9, 0x79, 0x02, 0x23, 0x54, 0xb7, 0x4a, 0x56, 0xef, 0xbe, 0x55, 0xe2,
		0x3e, 0xfc, 0xd4, 0x04, 0xb4, 0xca, 0xfb, 0x28, 0xdf, 0x42, 0xf9, 0x96, 0x8c, 0xef, 0x45, 0xf9,
		0x16, 0xdc, 0x43, 0xdc, 0x43, 0xdc, 0x43, 0xdc, 0x43, 0xdc, 0x43, 0xdc, 0x43, 0x56, 0xa0, 0xa8,
		0xee, 0x21, 0xe5, 0x5b, 0xe0, 0x20, 0x70, 0x10, 0x38, 0x48, 0x21, 0x39, 0x08, 0xe5, 0x5b, 0xe4,
		0x76, 0x25, 0x69, 0xb5, 0xeb, 0xc7, 0x27, 0xad, 0x36, 0xb7, 0x25, 0xa5, 0x7c, 0x8b, 0xfc, 0x68,
		0x94, 0x6f, 0x49, 0x65, 0x5d, 0x28, 0xdf, 0x02, 0xcd, 0x84, 0x66, 0x42, 0x33, 0x29, 0xdf, 0x02,
		0xcf, 0x84, 0x67, 0x56, 0x9c, 0x67, 0x52, 0xbe, 0x05, 0xa2, 0xf9, 0xe4, 0x32, 0x52, 0xbe, 0x05,
		0x9a, 0x09, 0xcd, 0x84, 0x66, 0x52, 0xbe, 0x65, 0x61, 0x26, 0x28, 0xdf, 0x42, 0xf9, 0x16, 0xbb,
		0x34, 0xdf, 0x12, 0x37, 0xb4, 0x45, 0xfb, 0x6d, 0x32, 0x45, 0x83, 0x6e, 0x80, 0x15, 0x77, 0x20,
		0xaf, 0xa5, 0xa7, 0x7c, 0x4b, 0x0e, 0xa3, 0x52, 0xbe, 0x85, 0xf2, 0x2d, 0x4f, 0x4e, 0x14, 0xe5,
		0x5b, 0xb2, 0x4d, 0x16, 0xe5, 0x5b, 0x36, 0xcd, 0x10, 0xe5, 0x5b, 0x36, 0x4e, 0x11, 0xe5, 0x5b,
		0x36, 0x4e, 0x11, 0xe5, 0x5b, 0x36, 0x4e, 0x11, 0xe5, 0x5b, 0x36, 0x4f, 0x11, 0xe5, 0x5b, 0x36,
		0x5a, 0x7f, 0xca, 0xb7, 0x6c, 0x98, 0x21, 0xca, 0xb7, 0x6c, 0x9a, 0x21, 0xca, 0xb7, 0x70, 0x83,
		0x64, 0x63, 0xa7, 0x53, 0xbe, 0x85, 0xdb, 0xa4, 0xf1, 0xf8, 0xdc, 0x26, 0xad, 0x7b, 0x00, 0xb7,
		0x49, 0x62, 0x22, 0x12, 0xf9, 0x79, 0xe4, 0xe7, 0xa5, 0x99, 0x7c, 0xf2, 0xf3, 0xca, 0xcc, 0x4b,
		0x28, 0xdf, 0xb2, 0xb6, 0x7c, 0xcb, 0xa8, 0x6a, 0x49, 0x5e, 0xd5, 0x5b, 0x9e, 0x59, 0x5c, 0x10,
		0xa9, 0x85, 0x90, 0x5d, 0x80, 0x86, 0x56, 0x01, 0x9b, 0xa8, 0xdf, 0x4e, 0xc2, 0xb1, 0x2d, 0x3b,
		0x6a, 0x07, 0xd7, 0x47, 0xed, 0xe0, 0xc2, 0x4b, 0x06, 0xff, 0x39, 0x1e, 0x3c, 0xe1, 0xfa, 0x64,
		0xf0, 0x84, 0x67, 0x76, 0x96, 0x46, 0x61, 0x59, 0x06, 0xf6, 0x77, 0x5f, 0x79, 0x31, 0x66, 0xad,
		0xf8, 0xbe, 0xe2, 0x3c, 0x6a, 0x16, 0xdc, 0xd1, 0x66, 0xea, 0x12, 0xcc, 0x5c, 0x9a, 0x89, 0x4b,
		0x31, 0x6f, 0x71, 0xa6, 0x2d, 0xce, 0xac, 0x0d, 0x30, 0x69, 0xbb, 0x90, 0xa6, 0x5b, 0x20, 0xa7,
		0xd1, 0x9e, 0xec, 0x5f, 0xa1, 0x22, 0x58, 0xe3, 0xf1, 0x0a, 0x56, 0x05, 0x6b, 0x9b, 0x2a, 0x58,
		0x85, 0x71, 0x93, 0xa9, 0x82, 0x65, 0xfb, 0x90, 0x4f, 0x07, 0xa2, 0x0a, 0x16, 0x2a, 0x1b, 0x2a,
		0x1b, 0x2a, 0x5b, 0x0e, 0x2a, 0xdb, 0x3e, 0x2a, 0xdb, 0x50, 0x76, 0x71, 0x9d, 0x9b, 0x23, 0xe7,
		0xfd, 0xd5, 0x5f, 0x3b, 0x2f, 0x5b, 0x0f, 0x6f, 0x5f, 0xfc, 0x75, 0xf0, 0xb0, 0xf8, 0x97, 0x7f,
		0xaf, 0xfa, 0xb1, 0x9d, 0x97, 0x07, 0x0f, 0x6f, 0xd7, 0xfc, 0xcb, 0xfe, 0xc3, 0xdb, 0x94, 0x63,
		0xec, 0x3d, 0x3c, 0x5f, 0xfa, 0xd1, 0xc1, 0xdf, 0x37, 0xd7, 0x7d, 0xa0, 0xb5, 0xe6, 0x03, 0xbb,
		0xeb, 0x3e, 0xb0, 0xbb, 0xe6, 0x03, 0x6b, 0xbf, 0x52, 0x73, 0xcd, 0x07, 0xf6, 0x1e, 0xfe, 0x5e,
		0xfa, 0xf9, 0xe7, 0xab, 0x7f, 0x74, 0xff, 0xe1, 0xc5, 0xdf, 0xeb, 0xfe, 0xed, 0xe0, 0xe1, 0xef,
		0xb7, 0x2f, 0x5e, 0xbc, 0x7e, 0xbe, 0xd3, 0xfc, 0xba, 0xed, 0xbc, 0x19, 0x69, 0x63, 0x3b, 0x57,
		0x4b, 0x92, 0xd9, 0x48, 0x02, 0xab, 0xb3, 0xf4, 0xc8, 0xb6, 0xac, 0xc5, 0xb6, 0xac, 0x52, 0xbd,
		0xb4, 0x19, 0x9a, 0x79, 0x13, 0x74, 0xff, 0x74, 0x02, 0xf7, 0x9b, 0x17, 0x98, 0xa5, 0xb3, 0x33,
		0xcf, 0x81, 0xd1, 0xc2, 0x68, 0x61, 0xb4, 0xf5, 0x66, 0xb4, 0xe2, 0x70, 0x30, 0x0b, 0x09, 0x07,
		0x94, 0xbd, 0x10, 0x1e, 0x9c, 0xb2, 0x17, 0x96, 0xce, 0xdd, 0xfc, 0x92, 0x56, 0xa0, 0xec, 0xc5,
		0xce, 0x76, 0xeb, 0xcd, 0xde, 0x01, 0xa5, 0x2f, 0xc4, 0x47, 0xa3, 0x80, 0xef, 0x46, 0xfa, 0x49,
		0x01, 0x5f, 0xc8, 0x26, 0x64, 0xb3, 0xd6, 0x64, 0x93, 0x02, 0xbe, 0x30, 0x4c, 0x18, 0x66, 0xa5,
		0x19, 0x26, 0x05, 0x7c, 0x21, 0x97, 0x4f, 0x2d, 0x23, 0x05, 0x7c, 0xa1, 0x99, 0xd0, 0x4c, 0x68,
		0x26, 0x05, 0x7c, 0xe1, 0x99, 0xf0, 0x4c, 0x78, 0xa6, 0xea, 0x92, 0x52, 0xc0, 0x17, 0xa2, 0xf9,
		0xe4, 0x32, 0x52, 0xc0, 0x17, 0x9a, 0x09, 0xcd, 0x84, 0x66, 0x52, 0xc0, 0x77, 0x61, 0x26, 0x28,
		0xe0, 0x4b, 0x01, 0x5f, 0xbb, 0x34, 0xdf, 0x12, 0x37, 0xb4, 0x45, 0xfb, 0x6d, 0x32, 0x45, 0x83,
		0x6e, 0x80, 0x15, 0x77, 0x20, 0xaf, 0xa5, 0xa7, 0x80, 0x6f, 0x0e, 0xa3, 0x52, 0xc0, 0x97, 0x02,
		0xbe, 0x4f, 0x4e, 0x14, 0x05, 0x7c, 0xb3, 0x4d, 0x16, 0x05, 0x7c, 0x37, 0xcd, 0x10, 0x05, 0x7c,
		0x37, 0x4e, 0x11, 0x05, 0x7c, 0x37, 0x4e, 0x11, 0x05, 0x7c, 0x37, 0x4e, 0x11, 0x05, 0x7c, 0x37,
		0x4f, 0x11, 0x05, 0x7c, 0x37, 0x5a, 0x7f, 0x0a, 0xf8, 0x6e, 0x98, 0x21, 0x0a, 0xf8, 0x6e, 0x9a,
		0x21, 0x0a, 0xf8, 0x72, 0x83, 0x64, 0x63, 0xa7, 0x53, 0xc0, 0x97, 0xdb, 0xa4, 0xf1, 0xf8, 0xdc,
		0x26, 0xad, 0x7b, 0x00, 0xb7, 0x49, 0x62, 0x22, 0x12, 0xa5, 0x45, 0xa8, 0xe1, 0x40, 0x69, 0x11,
		0xc5, 0x1d, 0x49, 0x69, 0x11, 0xb6, 0x25, 0x0c, 0x76, 0x0d, 0x83, 0x35, 0x59, 0x55, 0x64, 0xf9,
		0x11, 0xf0, 0x58, 0x78, 0x2c, 0x3c, 0xb6, 0xde, 0x3c, 0x96, 0x82, 0x22, 0xd2, 0x02, 0x18, 0x61,
		0xf8, 0xeb, 0xc7, 0x27, 0x0c, 0x3f, 0xb7, 0x25, 0xa5, 0xa0, 0x48, 0xd5, 0x85, 0x54, 0x3a, 0x8e,
		0xac, 0x69, 0x78, 0xb1, 0xff, 0x7a, 0x5c, 0x22, 0x3e, 0xaf, 0x96, 0x23, 0x5a, 0xfd, 0x36, 0xdc,
		0xc4, 0x93, 0xab, 0x95, 0x3f, 0x1a, 0xae, 0x60, 0xa5, 0xf2, 0x9b, 0x94, 0xca, 0x2f, 0x0c, 0x91,
		0xa7, 0x54, 0x7e, 0xd6, 0xf7, 0xa2, 0x54, 0x3e, 0x3a, 0x00, 0x3a, 0x00, 0x3a, 0x40, 0xb9, 0x75,
		0x00, 0xee, 0xb3, 0xb8, 0x38, 0xe0, 0x3e, 0x4b, 0x61, 0x47, 0x72, 0x9f, 0xc5, 0xb6, 0xac, 0x98,
		0x90, 0x40, 0xa9, 0x7c, 0x18, 0x2d, 0x8c, 0x16, 0x46, 0x5b, 0x6e, 0x46, 0xcb, 0xcd, 0x96, 0xf0,
		0x2f, 0x6e, 0xb6, 0x9e, 0x18, 0x9f, 0x9b, 0xad, 0xdc, 0x96, 0x94, 0x9b, 0x2d, 0x43, 0xa3, 0x51,
		0x2a, 0x7f, 0x23, 0xfd, 0xa4, 0x54, 0x3e, 0x64, 0x13, 0xb2, 0x59, 0x6b, 0xb2, 0x49, 0xa9, 0x7c,
		0x18, 0x26, 0x0c, 0xb3, 0xd2, 0x0c, 0x93, 0x52, 0xf9, 0x90, 0xcb, 0xa7, 0x96, 0x91, 0x52, 0xf9,
		0xd0, 0x4c, 0x68, 0x26, 0x34, 0x93, 0x52, 0xf9, 0xf0, 0x4c, 0x78, 0x26, 0x3c, 0x53, 0x75, 0x49,
		0x29, 0x95, 0x0f, 0xd1, 0x7c, 0x72, 0x19, 0x29, 0x95, 0x0f, 0xcd, 0x84, 0x66, 0x42, 0x33, 0x29,
		0x95, 0xbf, 0x30, 0x13, 0x94, 0xca, 0xa7, 0x54, 0xbe, 0x5d, 0x9a, 0x6f, 0x89, 0x1b, 0xda, 0xa2,
		0xfd, 0x36, 0x99, 0xa2, 0x41, 0x37, 0xc0, 0x8a, 0x3b, 0x90, 0xd7, 0xd2, 0x53, 0x2a, 0x3f, 0x87,
		0x51, 0x29, 0x95, 0x4f, 0xa9, 0xfc, 0x27, 0x27, 0x8a, 0x52, 0xf9, 0xd9, 0x26, 0x8b, 0x52, 0xf9,
		0x9b, 0x66, 0x88, 0x52, 0xf9, 0x1b, 0xa7, 0x88, 0x52, 0xf9, 0x1b, 0xa7, 0x88, 0x52, 0xf9, 0x1b,
		0xa7, 0x88, 0x52, 0xf9, 0x9b, 0xa7, 0x88, 0x52, 0xf9, 0x1b, 0xad, 0x3f, 0xa5, 0xf2, 0x37, 0xcc,
		0x10, 0xa5, 0xf2, 0x37, 0xcd, 0x10, 0xa5, 0xf2, 0xb9, 0x41, 0xb2, 0xb1, 0xd3, 0x29, 0x95, 0xcf,
		0x6d, 0xd2, 0x78, 0x7c, 0x6e, 0x93, 0xd6, 0x3d, 0x80, 0xdb, 0x24, 0x31, 0x11, 0x89, 0xd2, 0x22,
		0xd4, 0x70, 0xa0, 0xb4, 0x88, 0xe2, 0x8e, 0xa4, 0xb4, 0x08, 0xdb, 0x12, 0x06, 0xbb, 0x86, 0xc1,
		0x52, 0x2a, 0x1f, 0x1e, 0x0b, 0x8f, 0x85, 0xc7, 0xda, 0xe3, 0xb1, 0x14, 0x14, 0x91, 0x16, 0xc0,
		0x08, 0xc3, 0x5f, 0x3f, 0x3e, 0x61, 0xf8, 0xb9, 0x2d, 0x29, 0x05, 0x45, 0xaa, 0x2e, 0xa4, 0x52,
		0x2a, 0x7f, 0x6d, 0xa9, 0xfc, 0x51, 0x85, 0xf8, 0xbc, 0x2a, 0xe5, 0x3f, 0xb3, 0xb8, 0x20, 0x52,
		0x0b, 0x21, 0xbb, 0x00, 0x0d, 0xad, 0x66, 0x01, 0x51, 0xbf, 0x9d, 0x84, 0x63, 0xd2, 0x72, 0xd4,
		0x0e, 0xae, 0x8f, 0xda, 0xc1, 0x85, 0x97, 0x0c, 0xfe, 0x73, 0x3c, 0x78, 0xc2, 0xf5, 0xc9, 0xe0,
		0x09, 0xcf, 0xec, 0x2c, 0x8d, 0xc2, 0xb2, 0x34, 0x82, 0xa6, 0xf2, 0x52, 0x4c, 0xc9, 0x5a, 0xd0,
		0x54, 0x9c, 0x43, 0xcd, 0xc6, 0x06, 0xda, 0xee, 0x98, 0x84, 0xfb, 0x25, 0xed, 0x6e, 0x49, 0xb9,
		0x57, 0xe2, 0xee, 0x94, 0xb8, 0xfb, 0x64, 0xc0, 0x5d, 0xb2, 0x0b, 0x67, 0xba, 0x8d, 0x08, 0x1a,
		0xed, 0xc9, 0xfe, 0x15, 0x6a, 0x36, 0x32, 0x1e, 0xaf, 0x60, 0xdd, 0x46, 0xb6, 0xe9, 0x36, 0x52,
		0x18, 0x2d, 0x84, 0x6e, 0x23, 0xb6, 0x0f, 0xf9, 0x74, 0xa0, 0xd9, 0xca, 0xc9, 0x77, 0x6e, 0xdb,
		0x6c, 0x69, 0xe6, 0xc1, 0x03, 0x90, 0x50, 0x8b, 0x06, 0x13, 0xa6, 0xe0, 0xc2, 0x38, 0x6c, 0x18,
		0x87, 0x0f, 0x0b, 0x30, 0x22, 0xeb, 0x5d, 0x17, 0x5f, 0x42, 0xbd, 0x73, 0xdb, 0xc2, 0x51, 0x41,
		0x5b, 0xe5, 0x0b, 0x05, 0x98, 0xbd, 0x13, 0x5c, 0xbc, 0x6a, 0x6c, 0x3e, 0xbc, 0xf8, 0x6b, 0xef,
		0xa1, 0x9e, 0x77, 0xd1, 0x76, 0xe7, 0xa5, 0xa2, 0x7d, 0x16, 0x06, 0x27, 0xec, 0xce, 0x8d, 0xff,
		0x67, 0xdc, 0x94, 0x8f, 0x9e, 0x82, 0x3d, 0xc7, 0x9e, 0x63, 0xcf, 0xb1, 0xe7, 0xd8, 0x73, 0xec,
		0x39, 0xf6, 0x5c, 0xc8, 0x9e, 0x7b, 0xc9, 0x77, 0x2f, 0x4a, 0x24, 0x0f, 0xed, 0xf4, 0xc0, 0x3e,
		0x0e, 0x8d, 0xe5, 0xc6, 0x72, 0x63, 0xb9, 0x6b, 0x6b, 0xb9, 0xa7, 0x40, 0x40, 0x81, 0x27, 0xc1,
		0xfd, 0x39, 0x5b, 0xe0, 0x69, 0x67, 0xdf, 0x60, 0xc9, 0x8c, 0x7d, 0x2a, 0x3c, 0x3d, 0x7e, 0xf1,
		0x2a, 0x56, 0x78, 0xda, 0xd9, 0xdb, 0xdd, 0xa7, 0xc8, 0x53, 0xaa, 0xd5, 0xaf, 0x60, 0x91, 0xa7,
		0xfd, 0xbd, 0xbd, 0xdd, 0x3d, 0xca, 0x3c, 0xd9, 0x1e, 0x95, 0x32, 0x4f, 0x94, 0x79, 0x7a, 0x72,
		0xa2, 0x8e, 0x2f, 0xff, 0x79, 0xfc, 0xe9, 0xf2, 0xf7, 0xf3, 0x63, 0x8a, 0x3c, 0xa5, 0x9e, 0xaa,
		0xeb, 0x93, 0xf3, 0x2f, 0x2d, 0x2a, 0x3f, 0xa4, 0x99, 0xa9, 0x4f, 0x67, 0xef, 0xa8, 0x91, 0x91,
		0x6a, 0xa6, 0x4e, 0x4f, 0x29, 0x20, 0x96, 0x6e, 0xa6, 0x8e, 0x3e, 0x31, 0x51, 0xa9, 0x26, 0xea,
		0xcb, 0xe9, 0xd1, 0x47, 0x66, 0x2a, 0xcd, 0x4c, 0x7d, 0x38, 0x3f, 0xbd, 0x60, 0xa6, 0x52, 0x9a,
		0xbe, 0x7d, 0x4a, 0xfa, 0x90, 0x89, 0x62, 0x7c, 0xc7, 0x4f, 0xb2, 0x95, 0x8d, 0x04, 0xf1, 0xcd,
		0x8c, 0xcd, 0xad, 0x81, 0xf6, 0x6c, 0x72, 0x6b, 0xb0, 0xf0, 0x00, 0x6e, 0x0d, 0x64, 0x2d, 0x1f,
		0xf7, 0xfd, 0xdc, 0xf7, 0xaf, 0x9e, 0x12, 0xee, 0xfb, 0x0b, 0x6e, 0xbb, 0x0d, 0x85, 0xee, 0x2d,
		0x3e, 0x00, 0x2b, 0x8e, 0x15, 0xc7, 0x8a, 0x63, 0xc5, 0xb1, 0xe2, 0x58, 0x71, 0xac, 0x38, 0xb5,
		0x20, 0xd6, 0x95, 0x22, 0x08, 0x9a, 0xaf, 0xc7, 0xe9, 0xbb, 0x79, 0x95, 0x82, 0xd0, 0xaa, 0x83,
		0xe0, 0x26, 0x9e, 0x5c, 0x1e, 0xf3, 0x68, 0xb8, 0x82, 0xa5, 0x31, 0x37, 0x49, 0x63, 0x2e, 0x0c,
		0x13, 0x22, 0x8d, 0x39, 0xeb, 0x7b, 0x91, 0xc6, 0x8c, 0x03, 0x85, 0x03, 0x85, 0x03, 0x85, 0x03,
		0x85, 0x03, 0x85, 0x03, 0x55, 0x6e, 0x07, 0x8a, 0x34, 0x66, 0xec, 0x39, 0xf6, 0x1c, 0x7b, 0x8e,
		0x3d, 0xc7, 0x9e, 0x63, 0xcf, 0xb1, 0xe7, 0xa4, 0x31, 0x63, 0xb9, 0xb1, 0xdc, 0x58, 0xee, 0x2d,
		0xd2, 0x98, 0x97, 0xe6, 0x81, 0x34, 0x66, 0xd2, 0x98, 0x57, 0x7c, 0x71, 0xd2, 0x98, 0x95, 0x1e,
		0x45, 0x1a, 0x73, 0x61, 0x57, 0x9f, 0x34, 0xe6, 0x5c, 0x46, 0x25, 0x8d, 0x99, 0x34, 0xe6, 0x27,
		0x27, 0x8a, 0x34, 0xe6, 0xec, 0x53, 0x45, 0x1a, 0x73, 0xea, 0x99, 0x22, 0x8d, 0x39, 0xed, 0x4c,
		0x91, 0xc6, 0x9c, 0x76, 0xa6, 0x48, 0x63, 0x4e, 0x39, 0x51, 0xa4, 0x31, 0xa7, 0x9d, 0x29, 0xd2,
		0x98, 0x33, 0x98, 0x3e, 0xd2, 0x98, 0x49, 0x63, 0x36, 0xbf, 0xe3, 0x49, 0x63, 0xe6, 0xd6, 0x80,
		0x5b, 0x83, 0x35, 0x0f, 0xe0, 0xd6, 0x40, 0x6a, 0xef, 0x72, 0xdf, 0xcf, 0x7d, 0x7f, 0x41, 0xe6,
		0x85, 0x34, 0x66, 0x15, 0x03, 0x4e, 0xd4, 0x1e, 0x56, 0x1c, 0x2b, 0x8e, 0x15, 0xc7, 0x8a, 0x63,
		0xc5, 0xb1, 0xe2, 0x42, 0x23, 0x54, 0x39, 0x8d, 0x99, 0x86, 0xf6, 0x79, 0x4e, 0xbf, 0xd9, 0x76,
		0xf6, 0xa7, 0xcd, 0x22, 0x37, 0xb3, 0x8f, 0xbd, 0xff, 0xeb, 0x7b, 0x61, 0xdb, 0x73, 0xfc, 0x8e,
		0x7e, 0x57, 0xfb, 0xd9, 0xc1, 0xf4, 0xda, 0xdb, 0x6f, 0x57, 0xa4, 0xbd, 0xbd, 0xdb, 0x0e, 0x68,
		0x6c, 0xaf, 0xc0, 0x3b, 0x07, 0xf3, 0x56, 0x12, 0x40, 0xd3, 0x66, 0x90, 0xd3, 0xfd, 0x12, 0x78,
		0xee, 0x8d, 0x5e, 0x70, 0xc8, 0x94, 0x1d, 0x1e, 0x68, 0x8c, 0x71, 0x3e, 0xc6, 0xd4, 0x57, 0xaf,
		0x46, 0x76, 0xe9, 0xf5, 0xec, 0xb1, 0x2e, 0x32, 0x94, 0x69, 0x55, 0xd4, 0x10, 0xa9, 0xa4, 0xa1,
		0x59, 0x41, 0x43, 0xbb, 0x72, 0x06, 0xf0, 0x05, 0x7c, 0x65, 0xfc, 0xe6, 0xba, 0x55, 0x2e, 0x1a,
		0x1d, 0x2f, 0x6e, 0x47, 0x7e, 0x4f, 0x84, 0x58, 0xcf, 0xa6, 0xc1, 0x4e, 0x07, 0x95, 0x29, 0x6a,
		0xb3, 0x2d, 0x55, 0xd4, 0x66, 0xbb, 0x98, 0x45, 0x6d, 0xf4, 0x8e, 0xaa, 0x29, 0x65, 0xac, 0xfc,
		0xe5, 0x6c, 0xb4, 0x8e, 0x72, 0x31, 0x3c, 0x5f, 0x31, 0x8d, 0x6b, 0xc6, 0x46, 0x46, 0x7e, 0x78,
		0x2b, 0xb1, 0xdf, 0xa6, 0x72, 0x56, 0x09, 0x4b, 0x78, 0x0d, 0x85, 0x51, 0xaf, 0xe3, 0x74, 0xdb,
		0x89, 0x37, 0x8c, 0xed, 0x16, 0x02, 0xbf, 0x85, 0x71, 0xc1, 0x3f, 0xf0, 0x0f, 0xfc, 0x2b, 0x14,
		0xfe, 0xb5, 0xbb, 0xfd, 0x30, 0xf1, 0xa2, 0xfd, 0x96, 0x20, 0x04, 0x0a, 0x08, 0xfa, 0xc2, 0xc9,
		0x65, 0x82, 0x97, 0x22, 0x26, 0x92, 0xc7, 0x0c, 0xa5, 0x0b, 0x4d, 0xd3, 0x83, 0xa4, 0xc7, 0x35,
		0x98, 0x0a, 0x24, 0x18, 0xcd, 0x69, 0x24, 0xd3, 0xcb, 0xf4, 0x52, 0xed, 0xbc, 0x69, 0xb5, 0xf6,
		0x0f, 0x5a, 0xad, 0xed, 0x83, 0xdd, 0x83, 0xed, 0xc3, 0xbd, 0xbd, 0x9d, 0x7d, 0xe9, 0x34, 0x18,
		0xa3, 0xab, 0x57, 0x90, 0xfb, 0x99, 0xab, 0x12, 0x73, 0xb0, 0x9e, 0xdb, 0xfe, 0x9f, 0x11, 0x12,
		0x36, 0x19, 0x18, 0x16, 0x06, 0x0b, 0x83, 0x85, 0xc1, 0xc2, 0x60, 0x61, 0xb0, 0x30, 0x58, 0x18,
		0x2c, 0x0c, 0x16, 0x36, 0xb3, 0x2c, 0x12, 0x51, 0x04, 0x4b, 0xf0, 0xae, 0x1f, 0x4d, 0x00, 0xfb,
		0x82, 0x7d, 0xc1, 0xbe, 0x0c, 0xb1, 0xaf, 0xbe, 0x1f, 0x26, 0xbb, 0x4d, 0x41, 0xea, 0x75, 0x00,
		0xf5, 0x82, 0x7a, 0x41, 0xbd, 0x94, 0x96, 0xaa, 0xd5, 0x3c, 0x6c, 0x1d, 0xee, 0x1f, 0x34, 0x0f,
		0x21, 0x5c, 0xe5, 0x21, 0x5c, 0xf5, 0x8e, 0xbb, 0xd5, 0x88, 0x79, 0xb6, 0x13, 0x4f, 0x96, 0x44,
		0x6e, 0x18, 0xf7, 0xba, 0x51, 0xa2, 0x1f, 0x53, 0xf6, 0x38, 0x54, 0xce, 0x71, 0x65, 0x05, 0x09,
		0x8b, 0x95, 0x48, 0xea, 0xaa, 0x6f, 0x74, 0x99, 0x40, 0x52, 0x56, 0xc9, 0x62, 0xcc, 0xda, 0x93,
		0xfd, 0x2b, 0xe4, 0x5a, 0x8e, 0xc7, 0x2b, 0x58, 0xbb, 0xb4, 0x6d, 0xda, 0xa5, 0xd5, 0xcf, 0xb7,
		0xa4, 0x5d, 0xda, 0xe2, 0x40, 0xb3, 0x2d, 0x50, 0xb4, 0xcc, 0xef, 0xda, 0x4d, 0xbd, 0xf4, 0x04,
		0x52, 0xb5, 0x8b, 0x06, 0x14, 0xa6, 0x00, 0xc3, 0x38, 0x70, 0x18, 0x07, 0x10, 0x0b, 0x40, 0x22,
		0xec, 0xa1, 0x15, 0x3e, 0x55, 0x7b, 0x80, 0x01, 0x4e, 0xd8, 0xbf, 0x73, 0xa2, 0xa1, 0x7c, 0x44,
		0x99, 0x76, 0xd1, 0xd9, 0x15, 0x0b, 0x16, 0x5e, 0x3b, 0xbb, 0x6f, 0x0c, 0x8c, 0x6d, 0x2a, 0xf7,
		0x7b, 0xfa, 0x80, 0xff, 0x3e, 0xdf, 0xdf, 0xdb, 0xdb, 0xfd, 0xba, 0xed, 0xec, 0x5d, 0xfd, 0xbd,
		0xbf, 0xb7, 0xf7, 0x75, 0xdb, 0x69, 0x5e, 0x7d, 0xdd, 0x76, 0x0e, 0x07, 0x7f, 0xfa, 0xba, 0xed,
		0xb4, 0x46, 0x7f, 0xf8, 0xab, 0xf9, 0xf0, 0xf7, 0xfe, 0xcc, 0x1f, 0x77, 0x1f, 0xfe, 0x1e, 0x7e,
		0x64, 0xf4, 0xa7, 0xd6, 0xf0, 0x4f, 0x87, 0x57, 0x7f, 0xed, 0xbc, 0x6c, 0x3d, 0xbc, 0xf8, 0xe3,
		0x8f, 0x57, 0x7f, 0xfc, 0xf1, 0x4a, 0x7c, 0xd8, 0x7f, 0xc8, 0xd7, 0xd6, 0xbb, 0x32, 0xb1, 0x60,
		0x26, 0x33, 0xf6, 0x59, 0xb5, 0x1a, 0x17, 0xee, 0x9e, 0x98, 0x87, 0x6f, 0x5e, 0x44, 0xb3, 0x09,
		0xa3, 0x53, 0x3e, 0xfd, 0xe2, 0x55, 0x6c, 0x36, 0xb1, 0x4d, 0xa7, 0x89, 0x54, 0x4b, 0x4f, 0xa7,
		0x89, 0xc2, 0x2f, 0x3f, 0x9d, 0x26, 0x0a, 0x6d, 0xb0, 0xbc, 0xb0, 0x7f, 0xe7, 0x45, 0xae, 0x40,
		0xf6, 0xec, 0x93, 0xb4, 0xbb, 0x65, 0x60, 0xec, 0xe3, 0xb0, 0x7f, 0x37, 0x38, 0xfe, 0x54, 0x33,
		0x36, 0xbe, 0x19, 0x27, 0x05, 0x0b, 0xcd, 0x68, 0x6c, 0xb3, 0x83, 0x23, 0xaf, 0x21, 0xaf, 0x21,
		0xaf, 0x21, 0xaf, 0x21, 0xaf, 0x21, 0xaf, 0x21, 0xaf, 0x21, 0xaf, 0xb1, 0x6a, 0x78, 0x2b, 0xc8,
		0x6b, 0xc8, 0x6b, 0xc8, 0x6b, 0xc8, 0x6b, 0xc8, 0x6b, 0xc8, 0x6b, 0xc8, 0x6b, 0xc8, 0x6b, 0xd5,
		0x93, 0xd7, 0x92, 0x76, 0xcf, 0xb9, 0x09, 0xdc, 0xdb, 0x58, 0x5e, 0x5c, 0x7b, 0x1c, 0x1a, 0x69,
		0x0d, 0x69, 0x0d, 0x69, 0xad, 0xb6, 0xd2, 0x9a, 0x99, 0x9e, 0xe2, 0x26, 0x7a, 0x89, 0x9b, 0xed,
		0x21, 0x3e, 0x9d, 0x90, 0xcb, 0x77, 0xe7, 0xd7, 0xef, 0x4f, 0x8f, 0x7e, 0xbb, 0x68, 0x98, 0xc8,
		0xb4, 0x33, 0xd3, 0x33, 0xdc, 0x70, 0x3b, 0xf5, 0xc1, 0x94, 0x1c, 0xbd, 0xfb, 0x97, 0xbc, 0x60,
		0x61, 0xc0, 0x4d, 0xb1, 0x30, 0x15, 0x9f, 0x3f, 0xfd, 0xc6, 0x54, 0x8c, 0xa6, 0xe2, 0xdd, 0xbf,
		0x3f, 0x31, 0x15, 0xa3, 0xa9, 0xb8, 0xf8, 0xfd, 0x23, 0x53, 0x31, 0x9a, 0x8a, 0x63, 0x13, 0xed,
		0xf1, 0xcb, 0x39, 0x15, 0xe7, 0x17, 0xff, 0x64, 0x2a, 0x46, 0x53, 0xf1, 0xe9, 0xe2, 0x92, 0xa9,
		0x18, 0xf3, 0x8b, 0x13, 0x13, 0x58, 0xf1, 0xac, 0x98, 0xd2, 0x4c, 0xb1, 0x98, 0xf4, 0xa9, 0x1f,
		0x27, 0x47, 0x49, 0x12, 0xc9, 0xb2, 0xe9, 0x0f, 0x7e, 0x78, 0x1c, 0x78, 0x03, 0x8f, 0x24, 0x96,
		0x55, 0x2d, 0x1b, 0x1f, 0xdc, 0x1f, 0x33, 0x23, 0x9b, 0x2d, 0x90, 0xd5, 0x38, 0x8b, 0x3a, 0x5e,
		0xe4, 0x75, 0x7e, 0xf9, 0xd9, 0x78, 0xbb, 0x15, 0xf6, 0x83, 0x80, 0xb6, 0x6f, 0x45, 0x6e, 0xfb,
		0x36, 0xad, 0x09, 0xf0, 0x7a, 0x9c, 0x8d, 0x5c, 0xc6, 0xba, 0x5f, 0x5a, 0x2d, 0x77, 0x96, 0xc0,
		0x55, 0xa7, 0xf5, 0xce, 0x92, 0xef, 0x2a, 0x95, 0x95, 0xdd, 0x24, 0x2b, 0xbb, 0x30, 0x12, 0x15,
		0x59, 0xd9, 0x59, 0xdf, 0x8b, 0xac, 0x6c, 0xb4, 0x6d, 0xb4, 0x6d, 0xf3, 0x00, 0x62, 0x01, 0x48,
		0x8a, 0xc9, 0xc8, 0x09, 0x1b, 0x9d, 0x9b, 0x07, 0xc2, 0x46, 0x09, 0x1b, 0x25, 0x6c, 0x74, 0x66,
		0xc1, 0x08, 0x1b, 0x25, 0x6c, 0xd4, 0x08, 0x80, 0x11, 0x36, 0x6a, 0x53, 0x00, 0xdd, 0x22, 0x6c,
		0x54, 0xed, 0x39, 0x84, 0x8d, 0x16, 0x76, 0xe9, 0x09, 0x1b, 0xcd, 0x65, 0x54, 0xc2, 0x46, 0x09,
		0x1b, 0x15, 0xde, 0x5a, 0x64, 0x65, 0xa7, 0xf5, 0xfa, 0xc8, 0xca, 0x46, 0x5e, 0x43, 0x5e, 0x43,
		0x5e, 0x43, 0x5e, 0x43, 0x5e, 0x43, 0x5e, 0x43, 0x5e, 0x63, 0xd5, 0xf0, 0x56, 0x90, 0xd7, 0x90,
		0xd7, 0x90, 0xd7, 0x90, 0xd7, 0x90, 0xd7, 0x90, 0xd7, 0x90, 0xd7, 0x90, 0xd7, 0x2a, 0x2d, 0xaf,
		0x91, 0x95, 0x8d, 0xb4, 0x86, 0xb4, 0x86, 0xb4, 0x46, 0x56, 0xf6, 0x16, 0x59, 0xd9, 0xf6, 0x1d,
		0x3d, 0xb2, 0xb2, 0x57, 0x4f, 0x05, 0x59, 0xd9, 0x64, 0x65, 0x2f, 0x4f, 0x05, 0x59, 0xd9, 0x64,
		0x65, 0x2f, 0x4f, 0x05, 0x59, 0xd9, 0x64, 0x65, 0xaf, 0xe0, 0x17, 0x64, 0x65, 0xe7, 0xc5, 0xa4,
		0xc9, 0xca, 0x7e, 0xe2, 0x61, 0x64, 0x65, 0xaf, 0xf2, 0x35, 0x8b, 0x9f, 0x95, 0xad, 0xd1, 0x9f,
		0x5e, 0x7f, 0x8e, 0xed, 0xf6, 0xe7, 0x16, 0x5a, 0x0d, 0x03, 0xab, 0xd0, 0xd0, 0x4a, 0x4e, 0x8f,
		0xfa, 0xed, 0x24, 0x1c, 0x9b, 0x88, 0xa3, 0x76, 0x70, 0x7d, 0xd4, 0x0e, 0x2e, 0xbc, 0x64, 0xf0,
		0x9f, 0xe3, 0xc1, 0x63, 0xae, 0x2f, 0xa7, 0x8f, 0x79, 0x66, 0x67, 0x91, 0xb2, 0x7d, 0x22, 0xe3,
		0x72, 0x36, 0xfe, 0xe5, 0xfd, 0x1c, 0x86, 0x9e, 0x78, 0xff, 0xd7, 0xf7, 0xc2, 0xb6, 0xe7, 0xf8,
		0x9d, 0x8c, 0xd3, 0xa7, 0x07, 0xe4, 0xfa, 0x80, 0x6d, 0x04, 0x98, 0xf5, 0x00, 0x38, 0xeb, 0x1a,
		0x68, 0x1e, 0x25, 0xb1, 0x23, 0xa4, 0x70, 0x70, 0x36, 0x1f, 0x98, 0x6c, 0xc7, 0x24, 0xfd, 0x66,
		0x4f, 0xf7, 0x93, 0x29, 0x97, 0x42, 0x75, 0x09, 0x34, 0xa7, 0x3e, 0xdd, 0xdc, 0x6c, 0x7e, 0xd3,
		0x14, 0x6f, 0xd9, 0x68, 0x4f, 0x84, 0xfc, 0x74, 0x6f, 0x37, 0xa5, 0xc9, 0xe3, 0xcf, 0xa5, 0x9c,
		0xc7, 0x6c, 0x85, 0x34, 0x32, 0xdf, 0x2e, 0xa8, 0xdc, 0x1e, 0xcc, 0xde, 0x0e, 0xb8, 0xed, 0x20,
		0xc3, 0x26, 0x57, 0xd5, 0xfd, 0xb5, 0x75, 0x7d, 0x6d, 0xdd, 0x7e, 0x51, 0x97, 0x1f, 0xbc, 0x77,
		0x4e, 0x27, 0x2b, 0x6b, 0x31, 0x89, 0x46, 0xc7, 0x8b, 0xdb, 0x91, 0xdf, 0x53, 0x82, 0xc3, 0xd9,
		0xba, 0x10, 0xd3, 0x41, 0xb2, 0x5a, 0x44, 0xa5, 0x0b, 0x34, 0xe5, 0x8b, 0x32, 0x9d, 0x0b, 0x31,
		0xf5, 0xad, 0xad, 0xbb, 0xc5, 0xc5, 0xb6, 0xba, 0xd8, 0x96, 0x17, 0xd9, 0xfa, 0x76, 0x38, 0x97,
		0xf2, 0x25, 0x92, 0x7e, 0xa4, 0xf0, 0x63, 0x24, 0xb0, 0x29, 0xb3, 0x9c, 0x01, 0x5e, 0xc7, 0xac,
		0x41, 0xf1, 0x88, 0x0f, 0x3f, 0xcd, 0xd9, 0xe6, 0x6c, 0x73, 0xb6, 0x0b, 0x78, 0xb6, 0x13, 0x95,
		0x79, 0x78, 0x8c, 0x8a, 0x19, 0x7c, 0x9a, 0xb3, 0xcd, 0xd9, 0xae, 0xd8, 0xd9, 0xd6, 0x0b, 0xf2,
		0xd0, 0x09, 0xe6, 0x90, 0x09, 0xda, 0x98, 0xbe, 0xc8, 0xd1, 0xbb, 0xd3, 0xeb, 0xcb, 0xdf, 0xcf,
		0x8f, 0x55, 0x77, 0x8d, 0x40, 0x0c, 0x86, 0x50, 0xfd, 0xc8, 0xc1, 0x9b, 0x9c, 0x9c, 0x7f, 0x69,
		0x35, 0xf2, 0x28, 0x86, 0x29, 0xfb, 0x0e, 0xfb, 0x65, 0x7f, 0x87, 0xd3, 0x66, 0xd9, 0xdf, 0xe0,
		0xc3, 0xc9, 0x7f, 0x8e, 0x7f, 0x6d, 0x58, 0x96, 0xf0, 0xaf, 0x4c, 0xe3, 0x64, 0xf5, 0x45, 0xb9,
		0x2c, 0xe5, 0x74, 0x65, 0xf4, 0xb8, 0x4c, 0xce, 0x8f, 0x8a, 0xd3, 0x93, 0x91, 0x10, 0xa1, 0xc5,
		0x55, 0x5f, 0x8b, 0xcb, 0x4c, 0x60, 0xa6, 0xeb, 0x15, 0x78, 0xee, 0x4d, 0x36, 0xd2, 0x32, 0x25,
		0x2b, 0x07, 0x19, 0x3e, 0x73, 0x3e, 0x3e, 0xb3, 0xaf, 0x5e, 0x8d, 0xae, 0x52, 0x5f, 0x0f, 0xf7,
		0xbb, 0xc5, 0x53, 0x99, 0xad, 0x38, 0xb5, 0x52, 0x11, 0x6a, 0x65, 0x8d, 0xbc, 0xc9, 0xb9, 0xac,
		0xe8, 0xb9, 0x44, 0x23, 0xc7, 0xd7, 0xc6, 0xd7, 0x46, 0x47, 0xd3, 0xa5, 0x89, 0x3a, 0x74, 0x91,
		0xb3, 0xcd, 0xd9, 0xe6, 0x6c, 0x5b, 0x3d, 0xdb, 0x68, 0xe4, 0x9c, 0x6d, 0xce, 0xf6, 0xe2, 0x7a,
		0xa3, 0x91, 0x8f, 0xc7, 0x41, 0x23, 0x37, 0xf0, 0x0e, 0x68, 0xe4, 0xb9, 0xbf, 0x01, 0x1a, 0xb9,
		0xa0, 0x74, 0x60, 0x51, 0x23, 0xcf, 0x90, 0xdc, 0x20, 0x23, 0xc6, 0x65, 0xe2, 0x47, 0x2a, 0xbc,
		0x08, 0x89, 0x1c, 0x29, 0x4e, 0x97, 0xbf, 0xe4, 0x2e, 0x91, 0x0f, 0xf7, 0xbb, 0xd4, 0xa9, 0x7c,
		0xa6, 0x31, 0x87, 0x93, 0x5c, 0x92, 0xd0, 0xbd, 0xf3, 0xb6, 0x52, 0x9c, 0xc2, 0x6c, 0x99, 0x23,
		0xd9, 0x33, 0x45, 0x44, 0x32, 0x43, 0xb2, 0x65, 0x82, 0x6c, 0x9a, 0xa1, 0x8c, 0x68, 0xad, 0x80,
		0xd2, 0x8d, 0x54, 0x97, 0x1c, 0xab, 0x73, 0x36, 0x9e, 0xde, 0x45, 0xeb, 0xf7, 0xc6, 0xea, 0x7f,
		0x59, 0x33, 0x17, 0x69, 0xe7, 0x20, 0xc3, 0xbb, 0xaf, 0xfe, 0xde, 0xcb, 0xdf, 0x6a, 0xc5, 0x37,
		0xda, 0x94, 0x16, 0x91, 0x2e, 0x0d, 0x62, 0xc3, 0x95, 0xce, 0x46, 0xbb, 0x91, 0xc6, 0x4e, 0xa4,
		0xb7, 0x0b, 0x69, 0xed, 0x40, 0x66, 0xdc, 0xcf, 0x8c, 0xf3, 0x99, 0x70, 0x3d, 0xaf, 0x5d, 0xf4,
		0xd4, 0xd5, 0x7f, 0xba, 0x3d, 0xe4, 0x87, 0x89, 0x17, 0xdd, 0xb8, 0x6d, 0x2f, 0xde, 0xbc, 0x8f,
		0x66, 0x7e, 0x96, 0xbd, 0x54, 0x90, 0xbd, 0xb4, 0xe9, 0xfa, 0xed, 0x71, 0xd1, 0x36, 0xcf, 0xc3,
		0xd2, 0x3a, 0x6f, 0x9a, 0x87, 0x74, 0xb7, 0xc1, 0xa9, 0xa9, 0x67, 0x16, 0xca, 0x99, 0x9d, 0x6a,
		0x66, 0xa5, 0x98, 0xca, 0xd4, 0x52, 0x99, 0x52, 0x2a, 0x51, 0x49, 0x3d, 0xda, 0x93, 0xf6, 0xf6,
		0x96, 0x14, 0x3c, 0x7c, 0x9a, 0x5c, 0x7c, 0x9a, 0xcc, 0xe1, 0x05, 0x7e, 0x47, 0xfd, 0x5a, 0x22,
		0x7b, 0x02, 0x39, 0x97, 0x12, 0x36, 0x37, 0xb6, 0xd8, 0x06, 0x17, 0xd9, 0xe8, 0x8a, 0x62, 0x9b,
		0xfd, 0x4b, 0x89, 0x89, 0x39, 0xcf, 0x5e, 0x20, 0x61, 0xcb, 0xca, 0xb5, 0x63, 0x49, 0x44, 0xc5,
		0x47, 0xfa, 0xfb, 0xf8, 0xdb, 0x1c, 0x82, 0x6f, 0xbd, 0xdb, 0xc8, 0x8b, 0x63, 0x67, 0xea, 0x40,
		0x66, 0x36, 0xc9, 0x8b, 0x03, 0x60, 0x9b, 0xb1, 0xcd, 0x76, 0x6c, 0xf3, 0xfc, 0xce, 0x53, 0xb7,
		0xd3, 0x0b, 0xe3, 0xa8, 0xd9, 0xec, 0x1d, 0x6c, 0x36, 0x36, 0xdb, 0x8c, 0xcd, 0xce, 0x7a, 0x30,
		0xa6, 0x1f, 0x9c, 0xad, 0xaf, 0xa2, 0x7d, 0x87, 0x3f, 0x3b, 0x98, 0xe2, 0x54, 0xab, 0x1d, 0x95,
		0xe5, 0x23, 0xd3, 0x54, 0x1c, 0x40, 0xa0, 0xe0, 0xba, 0xfe, 0x11, 0x92, 0x3a, 0x4a, 0xe2, 0x47,
		0x4a, 0xfc, 0x68, 0x89, 0x1e, 0x31, 0xb5, 0xa3, 0xa6, 0x78, 0xe4, 0xb4, 0x8f, 0xde, 0xd2, 0x11,
		0xfc, 0xa9, 0xbf, 0xce, 0x8b, 0x07, 0xf1, 0xa7, 0xee, 0x3a, 0xeb, 0x1d, 0x47, 0x6d, 0x4b, 0x66,
		0xe2, 0x78, 0xca, 0x1f, 0x53, 0xe9, 0xe3, 0x6a, 0xec, 0xd8, 0x1a, 0x3b, 0xbe, 0x46, 0x8e, 0xb1,
		0xde, 0x71, 0xd6, 0x3c, 0xd6, 0x62, 0xc7, 0xfb, 0xd1, 0xdd, 0x9b, 0x29, 0x1a, 0x28, 0xdf, 0x75,
		0x58, 0xb9, 0x22, 0xa1, 0xb0, 0xd0, 0x64, 0x1c, 0x02, 0x4c, 0x40, 0x81, 0x39, 0x48, 0x30, 0x05,
		0x0d, 0xc6, 0x21, 0xc2, 0x38, 0x54, 0x18, 0x85, 0x0c, 0x19, 0xe8, 0x10, 0x82, 0x10, 0x7d, 0x61,
		0x6d, 0xe3, 0x7e, 0xcd, 0x1e, 0x4d, 0x93, 0xda, 0xf2, 0x1f, 0x08, 0x8e, 0xb9, 0x14, 0x8d, 0x33,
		0x0b, 0x5b, 0x55, 0x6a, 0x30, 0x9f, 0x29, 0x2f, 0x36, 0x3d, 0xc8, 0x67, 0xc8, 0x9b, 0xb5, 0xc4,
		0xec, 0xc4, 0x1c, 0x2f, 0xe0, 0x1d, 0x78, 0x2f, 0x39, 0xbc, 0x4b, 0x31, 0xc5, 0xe9, 0x80, 0xc3,
		0xde, 0x60, 0x5e, 0xc7, 0xe9, 0xb6, 0x93, 0x2c, 0xb2, 0x7b, 0xe6, 0xe3, 0xb0, 0xf0, 0x1c, 0xe1,
		0x0d, 0x60, 0xa6, 0x27, 0xaa, 0x38, 0x9f, 0x34, 0x09, 0x3c, 0xe6, 0x01, 0xc8, 0x34, 0x10, 0x59,
		0x03, 0x24, 0x6b, 0xc0, 0x64, 0x05, 0xa0, 0x64, 0x81, 0x4a, 0x18, 0xb0, 0xcc, 0xf1, 0xd2, 0xa5,
		0xfd, 0xde, 0xee, 0xf6, 0xc3, 0xc4, 0x8b, 0xf6, 0x5b, 0x06, 0xfb, 0xc6, 0xbe, 0xa1, 0xd1, 0xf9,
		0xe3, 0x17, 0xa7, 0xd1, 0x79, 0xf6, 0xe7, 0xd0, 0xe8, 0xbc, 0xb0, 0x4b, 0x6f, 0xb6, 0x81, 0x50,
		0xee, 0xbb, 0xa1, 0x9e, 0x7d, 0xcf, 0x9f, 0x15, 0xf0, 0x34, 0x4d, 0xb9, 0x70, 0xcf, 0x6d, 0xff,
		0xcf, 0x0a, 0xe9, 0x9e, 0x3c, 0x08, 0xd6, 0x0d, 0xeb, 0x86, 0x75, 0xc3, 0xba, 0x61, 0xdd, 0xb0,
		0x6e, 0x58, 0x37, 0xac, 0x1b, 0xd6, 0x0d, 0xeb, 0xae, 0x0d, 0xeb, 0x36, 0x11, 0x1b, 0xb1, 0x64,
		0x0e, 0xe5, 0x63, 0x24, 0x60, 0xdb, 0xb0, 0x6d, 0xd8, 0x36, 0x6c, 0xdb, 0x50, 0x0c, 0xc6, 0x22,
		0xbc, 0x48, 0xc6, 0x62, 0x3c, 0x42, 0xc1, 0x24, 0xff, 0x68, 0x55, 0x7d, 0x8c, 0xaf, 0xa1, 0x7b,
		0xe7, 0xfd, 0x7f, 0xed, 0x7e, 0x14, 0x79, 0x61, 0xf2, 0xfc, 0xc5, 0xeb, 0x57, 0xaf, 0x1e, 0xff,
		0x2f, 0xf6, 0x12, 0x67, 0xf0, 0xcf, 0x57, 0x5f, 0x93, 0x9f, 0xbd, 0x75, 0x3f, 0x34, 0xf8, 0xa7,
		0xab, 0x35, 0x2d, 0x88, 0xc5, 0x83, 0x3f, 0x0c, 0xd8, 0xb8, 0x42, 0x5d, 0x30, 0x0b, 0xb7, 0xf4,
		0x7e, 0xb4, 0xbe, 0x6a, 0x89, 0x68, 0x0b, 0x59, 0x5d, 0x0b, 0x7f, 0x5e, 0xb7, 0xe8, 0xfa, 0x3d,
		0xbf, 0xe5, 0x16, 0x27, 0xdf, 0xc8, 0x52, 0xed, 0x66, 0xd2, 0x4b, 0x23, 0x6a, 0x35, 0x97, 0x5e,
		0xe5, 0xcd, 0xea, 0x35, 0x9b, 0x5e, 0xe5, 0x24, 0x89, 0x37, 0x9f, 0x5e, 0x7a, 0x88, 0x56, 0x33,
		0x6a, 0xe9, 0x35, 0xb6, 0xdf, 0x85, 0x5f, 0xec, 0xa8, 0x36, 0x44, 0x02, 0xe1, 0x16, 0x6b, 0x27,
		0x9d, 0x4c, 0xbe, 0xd3, 0xf5, 0xf1, 0xf0, 0x3b, 0x68, 0xf5, 0xbf, 0x96, 0x3b, 0xcf, 0x76, 0x53,
		0x46, 0x84, 0x76, 0x85, 0xf9, 0xdd, 0x60, 0xad, 0x6b, 0xbf, 0x42, 0x9a, 0x61, 0xc6, 0xfa, 0x20,
		0x6b, 0x79, 0x5b, 0xa6, 0x7a, 0x21, 0x6b, 0xa9, 0x99, 0x6e, 0xbe, 0xda, 0x36, 0xf9, 0x6a, 0x06,
		0x3d, 0x30, 0xf2, 0xd5, 0x1e, 0xbf, 0xb9, 0x76, 0xbe, 0xda, 0x84, 0xf8, 0xcb, 0xa5, 0xab, 0x4d,
		0x47, 0x94, 0xc9, 0x56, 0xdb, 0x26, 0x5b, 0x2d, 0x07, 0x19, 0x85, 0x6c, 0xb5, 0x02, 0xf8, 0x14,
		0x62, 0x32, 0x87, 0x01, 0x59, 0x43, 0x52, 0xc6, 0x98, 0x4d, 0x25, 0x59, 0xf8, 0xbf, 0xd5, 0x95,
		0x98, 0x33, 0xf4, 0x46, 0x33, 0xc0, 0x2e, 0x35, 0x4c, 0x6a, 0x22, 0xb1, 0xa2, 0x3a, 0x6d, 0x30,
		0x40, 0x59, 0x50, 0x16, 0x94, 0x05, 0x65, 0x9f, 0x46, 0xd9, 0x15, 0x4a, 0xf1, 0x54, 0x20, 0xce,
		0x5c, 0x7a, 0x1b, 0xff, 0xde, 0xa4, 0x7f, 0x9f, 0xa5, 0x80, 0x58, 0x3e, 0xae, 0xbd, 0xb6, 0x87,
		0x21, 0xe5, 0x59, 0x68, 0xda, 0x3a, 0xdc, 0x7b, 0xdc, 0x7b, 0xdb, 0xd8, 0xa3, 0x6d, 0x9b, 0x04,
		0x6d, 0x92, 0x84, 0x2d, 0x5a, 0x95, 0x34, 0x3e, 0x3e, 0xd3, 0x45, 0x46, 0x30, 0xad, 0x0c, 0x70,
		0x91, 0x8c, 0x6f, 0x4a, 0x69, 0x81, 0x5d, 0x48, 0x93, 0x48, 0x93, 0x38, 0xcd, 0x38, 0xcd, 0x38,
		0xcd, 0x48, 0x93, 0x48, 0x93, 0xa0, 0x2c, 0x28, 0x0b, 0xca, 0x22, 0x4d, 0x22, 0x4d, 0x16, 0x55,
		0x9a, 0xd4, 0x88, 0x0e, 0xb5, 0xe3, 0xd7, 0x6b, 0x99, 0x3c, 0x09, 0x53, 0x87, 0x22, 0x89, 0x57,
		0x8f, 0x22, 0x59, 0x30, 0x45, 0x52, 0xdd, 0x7c, 0x3c, 0x14, 0xac, 0x8f, 0xc0, 0x34, 0x26, 0x7d,
		0x64, 0x1f, 0xb7, 0x14, 0x90, 0x4a, 0x2f, 0x0a, 0x5d, 0x3f, 0xea, 0xdc, 0x48, 0x94, 0xb9, 0x5e,
		0x54, 0x79, 0xd6, 0x55, 0xd0, 0x34, 0xd2, 0x66, 0x8c, 0x73, 0x43, 0x49, 0x06, 0x4f, 0x17, 0xff,
		0xdd, 0xa0, 0xd1, 0xd3, 0xc6, 0xe5, 0xb0, 0xd9, 0xf1, 0x29, 0x43, 0x1a, 0x6e, 0xf6, 0x56, 0x76,
		0xf4, 0x91, 0xdf, 0xa2, 0xaf, 0x93, 0x26, 0x45, 0xc8, 0xbd, 0x8f, 0x7c, 0xda, 0x9c, 0x45, 0xa1,
		0xf3, 0x18, 0xea, 0xb6, 0x60, 0x5b, 0x1a, 0x81, 0x1e, 0x6c, 0x9c, 0x55, 0xa5, 0xb3, 0x9a, 0xbd,
		0x3f, 0x6a, 0x28, 0xd4, 0x84, 0x6d, 0x71, 0x20, 0xba, 0xb0, 0x99, 0xf3, 0x8c, 0xe9, 0xc2, 0x46,
		0x17, 0x36, 0x42, 0x47, 0x10, 0x99, 0xe8, 0xc2, 0xa6, 0x7f, 0x10, 0xe9, 0xc2, 0x66, 0xe3, 0x98,
		0x4a, 0x1f, 0x57, 0x63, 0xc7, 0xd6, 0xd8, 0xf1, 0x35, 0x72, 0x8c, 0xf5, 0x8e, 0xb3, 0xe6, 0xb1,
		0x16, 0x3b, 0xde, 0x8f, 0x5a, 0x0c, 0x5d, 0xd8, 0xe8, 0xc2, 0x46, 0x9b, 0x1e, 0x2b, 0x90, 0x21,
		0x03, 0x1d, 0x42, 0x10, 0xa2, 0xae, 0x35, 0x19, 0xd4, 0xa2, 0x4c, 0x68, 0x55, 0xd9, 0xb5, 0x2c,
		0xba, 0xb0, 0x65, 0x02, 0x79, 0xba, 0xb0, 0x01, 0xef, 0xc0, 0x7b, 0x51, 0xe1, 0x9d, 0x2e, 0x6c,
		0x16, 0x78, 0xa4, 0x31, 0x3e, 0x69, 0x12, 0x78, 0xcc, 0x03, 0x90, 0x69, 0x20, 0xb2, 0x06, 0x48,
		0xd6, 0x80, 0xc9, 0x0a, 0x40, 0xc9, 0x02, 0x95, 0x30, 0x60, 0x99, 0xe3, 0xa5, 0x4b, 0xfb, 0x9d,
		0x7e, 0x10, 0xab, 0x7e, 0xd1, 0x0f, 0x22, 0xd5, 0x63, 0xe8, 0x07, 0x91, 0x6d, 0xe9, 0xe9, 0x07,
		0x51, 0xb6, 0xdd, 0x40, 0x3f, 0x88, 0xa2, 0x9c, 0x26, 0xba, 0xb0, 0xc1, 0xba, 0x61, 0xdd, 0xb0,
		0x6e, 0x58, 0x37, 0xac, 0x1b, 0xd6, 0x0d, 0xeb, 0x86, 0x75, 0xc3, 0xba, 0x61, 0xdd, 0xc6, 0x59,
		0x37, 0x5d, 0xd8, 0x60, 0xdb, 0xb0, 0x6d, 0xd8, 0x76, 0x99, 0xd9, 0x36, 0x5d, 0xd8, 0xe8, 0xc2,
		0x66, 0x74, 0x2f, 0x17, 0xad, 0x0b, 0xdb, 0x62, 0x62, 0xd7, 0xe2, 0x5f, 0xd0, 0x87, 0x2d, 0x85,
		0xa1, 0xa1, 0x0f, 0x1b, 0x7d, 0xd8, 0x8a, 0x7b, 0x58, 0x4d, 0x77, 0x62, 0x3b, 0x09, 0x69, 0xc5,
		0x96, 0x53, 0x3d, 0xa4, 0x2c, 0x1b, 0x82, 0x66, 0x6c, 0x69, 0x19, 0x1a, 0xb5, 0x91, 0x48, 0x5b,
		0x2b, 0x07, 0xfc, 0x50, 0xf1, 0xd8, 0x96, 0xfa, 0x42, 0xd2, 0x1a, 0x49, 0x6b, 0x96, 0x49, 0x27,
		0xb5, 0x38, 0xa9, 0x78, 0xfc, 0xd4, 0x6a, 0x52, 0xf1, 0x18, 0x94, 0x05, 0x65, 0x41, 0x59, 0x71,
		0x94, 0xa5, 0xe2, 0x71, 0x89, 0x3c, 0x7c, 0xda, 0xb1, 0xd9, 0xb2, 0x76, 0x38, 0xf8, 0x38, 0xf8,
		0x14, 0x3f, 0xa6, 0x1d, 0x9b, 0x3a, 0x7c, 0xd1, 0x8e, 0x0d, 0xec, 0x42, 0x9c, 0x44, 0x9c, 0xc4,
		0x6d, 0xc6, 0x6d, 0xc6, 0x6d, 0x46, 0x9c, 0x44, 0x9c, 0x04, 0x65, 0x41, 0x59, 0x50, 0x16, 0x94,
		0x45, 0x9c, 0xac, 0xa4, 0x38, 0x49, 0x43, 0x36, 0x34, 0x49, 0xfc, 0x7a, 0x34, 0xc9, 0x92, 0x69,
		0x92, 0x34, 0x64, 0x9b, 0x1d, 0x83, 0x86, 0x6c, 0xba, 0xab, 0x90, 0x53, 0x43, 0xb6, 0x4d, 0xe6,
		0x59, 0xba, 0x25, 0xdb, 0x5c, 0x20, 0x38, 0x3d, 0xd9, 0x52, 0xac, 0x88, 0xdd, 0x26, 0x50, 0xe3,
		0x6f, 0xe1, 0x0c, 0x20, 0x57, 0xa1, 0x03, 0xd4, 0xec, 0xc7, 0xab, 0xd1, 0xfe, 0xc9, 0xbf, 0xa9,
		0x65, 0xf7, 0x27, 0xff, 0xa6, 0x34, 0xcd, 0x9f, 0x14, 0x13, 0x03, 0xf4, 0x12, 0x02, 0xca, 0xda,
		0xea, 0xc9, 0xbf, 0xa1, 0xd3, 0x93, 0xe6, 0x76, 0xb7, 0xc3, 0xca, 0x94, 0x1b, 0x3d, 0x4d, 0x41,
		0x58, 0xdf, 0x67, 0x7d, 0x1c, 0x0a, 0xc7, 0x55, 0xf9, 0xf0, 0xe0, 0xb7, 0xaa, 0x1c, 0x2e, 0xdc,
		0x56, 0x51, 0xb7, 0xf5, 0xf5, 0x70, 0x19, 0xde, 0xce, 0x10, 0xce, 0x85, 0xbf, 0x18, 0xff, 0xb9,
		0xf0, 0x51, 0x36, 0xfd, 0x6f, 0x82, 0xf8, 0x36, 0x37, 0x1a, 0x10, 0x07, 0xc4, 0x01, 0x71, 0x15,
		0x86, 0xb8, 0xaf, 0x8f, 0x10, 0x37, 0x7f, 0x37, 0x34, 0xfd, 0x89, 0xab, 0xf1, 0x47, 0x66, 0x71,
		0x21, 0x5e, 0xf1, 0x77, 0xd3, 0x91, 0x3b, 0xde, 0x8f, 0x6a, 0x68, 0x80, 0xc7, 0x3f, 0x86, 0xc2,
		0x59, 0xf6, 0x42, 0x8c, 0xfa, 0x0e, 0x41, 0xb7, 0xed, 0x78, 0x3f, 0x92, 0xb7, 0x89, 0x17, 0x78,
		0x77, 0x5e, 0x12, 0xfd, 0x74, 0xba, 0xa1, 0xd3, 0xfe, 0x3e, 0xac, 0x0c, 0x29, 0xe2, 0x24, 0xdc,
		0xb8, 0x41, 0x2c, 0xe1, 0x25, 0x98, 0x76, 0x10, 0xae, 0xca, 0x22, 0x18, 0xce, 0x68, 0x3c, 0x4a,
		0x99, 0x05, 0x19, 0x74, 0xbc, 0x0c, 0xca, 0x8b, 0x5a, 0xfc, 0xad, 0x56, 0xdc, 0xad, 0xb6, 0x06,
		0xd0, 0x44, 0x03, 0x40, 0x03, 0x40, 0x03, 0x80, 0x20, 0x43, 0x90, 0x21, 0xc8, 0x68, 0x00, 0x68,
		0x00, 0x40, 0x1c, 0x10, 0x07, 0xc4, 0xa1, 0x01, 0xe4, 0xc2, 0x36, 0x0b, 0xe1, 0x50, 0x2a, 0x44,
		0x83, 0xd6, 0x26, 0x2e, 0x24, 0x7b, 0x70, 0xc5, 0xd6, 0xe6, 0x70, 0x9c, 0xf1, 0xef, 0x3e, 0x79,
		0x37, 0x36, 0x03, 0x4d, 0xb2, 0x79, 0xeb, 0x4a, 0x5e, 0xba, 0x72, 0x60, 0x49, 0xd3, 0x4e, 0x60,
		0x49, 0xb6, 0x28, 0xd8, 0xea, 0x44, 0x96, 0x64, 0x8a, 0x62, 0xcd, 0x39, 0xb4, 0x44, 0xa1, 0x4b,
		0xc1, 0xa3, 0xe3, 0xdc, 0x51, 0x94, 0x93, 0xb6, 0x4b, 0x16, 0x52, 0xa2, 0x16, 0xce, 0x5d, 0x7d,
		0x3d, 0x49, 0x29, 0x5c, 0xdb, 0xac, 0x89, 0x57, 0x26, 0x7e, 0x2b, 0x42, 0xfc, 0x94, 0x6a, 0x58,
		0x4f, 0x41, 0xf9, 0x0d, 0x26, 0x7e, 0xd9, 0xc4, 0x67, 0x20, 0x3f, 0x29, 0xcc, 0xf0, 0x33, 0x8d,
		0x19, 0x98, 0x04, 0x85, 0x6f, 0x5c, 0xe4, 0x6c, 0x91, 0xdf, 0xd9, 0x23, 0xbd, 0x45, 0x22, 0xbb,
		0xb3, 0x45, 0x72, 0x6f, 0x9a, 0x9a, 0x8c, 0x9b, 0x42, 0x71, 0x33, 0x34, 0x52, 0xb1, 0xa8, 0xb5,
		0xcc, 0xee, 0xe9, 0x5d, 0xb4, 0x7e, 0x6f, 0xac, 0xfe, 0x97, 0x35, 0x53, 0x92, 0x76, 0x2a, 0x32,
		0x4d, 0xc1, 0xea, 0x6f, 0xbe, 0xfc, 0xbd, 0x56, 0x7c, 0xa7, 0x0d, 0xb4, 0x32, 0x15, 0x8d, 0xdc,
		0x40, 0x1b, 0x37, 0xd2, 0xc4, 0x34, 0x56, 0x35, 0xbd, 0xf5, 0x4c, 0x6b, 0x25, 0x33, 0x5b, 0xc3,
		0xcc, 0x56, 0x2f, 0x93, 0x75, 0xcb, 0xb6, 0x8b, 0x36, 0xd1, 0xb2, 0x49, 0x7f, 0x43, 0xa7, 0xed,
		0xf6, 0xdc, 0x6f, 0x7e, 0xe0, 0x27, 0x3f, 0x37, 0x4f, 0xc8, 0x42, 0x6f, 0xc4, 0xd9, 0xcf, 0x6e,
		0x82, 0xbe, 0x54, 0x34, 0x2c, 0x35, 0xed, 0xca, 0x42, 0xb3, 0xb2, 0xd3, 0xaa, 0xac, 0x34, 0x4a,
		0x99, 0x36, 0x29, 0xd3, 0x24, 0x25, 0x5a, 0xa4, 0x67, 0xbc, 0x52, 0xd3, 0x9c, 0x19, 0xb2, 0xee,
		0x85, 0x89, 0x9f, 0xfc, 0x4c, 0xe7, 0x5a, 0x4f, 0x31, 0x22, 0x8d, 0xed, 0x39, 0x19, 0x0f, 0xfd,
		0x8b, 0x1b, 0x2b, 0x78, 0xbc, 0x47, 0xef, 0x4e, 0xaf, 0xdf, 0x9d, 0x7d, 0xfe, 0x78, 0x79, 0xfc,
		0xe9, 0xfa, 0xdd, 0xd1, 0xf9, 0xd1, 0x2f, 0x27, 0xa7, 0x27, 0x97, 0xbf, 0xa7, 0x5d, 0xb3, 0x61,
		0x83, 0xbf, 0x6c, 0x81, 0x1d, 0x8a, 0xde, 0xce, 0xd1, 0x6f, 0xbf, 0x7d, 0x3a, 0xfe, 0xed, 0xe8,
		0xf2, 0xf8, 0xfa, 0xec, 0xe3, 0xe9, 0xef, 0x0d, 0x13, 0x57, 0xfc, 0x8a, 0xdf, 0xec, 0x64, 0x30,
		0x77, 0xef, 0x8f, 0xde, 0x1d, 0x5f, 0x4f, 0xbf, 0x63, 0x31, 0xbf, 0x5e, 0xc6, 0x89, 0x4b, 0xf5,
		0x93, 0x57, 0xba, 0x27, 0xad, 0x70, 0x44, 0xe1, 0x09, 0x8e, 0xbc, 0x82, 0x23, 0x3c, 0x7b, 0xe2,
		0xcb, 0x6d, 0xfa, 0x52, 0x9b, 0xbf, 0x4c, 0x63, 0x25, 0x05, 0x59, 0xe0, 0x64, 0xf3, 0xdf, 0xf5,
		0xf1, 0x1b, 0xcd, 0x7c, 0x9b, 0x86, 0xdb, 0x5b, 0x6e, 0x40, 0x3e, 0xdd, 0x21, 0x83, 0x7f, 0x5c,
		0xf8, 0xe6, 0xab, 0x39, 0xca, 0x5a, 0x93, 0xf4, 0x94, 0x09, 0x9a, 0x35, 0x39, 0x81, 0x1f, 0x7a,
		0x4e, 0x2f, 0xea, 0x26, 0x5e, 0x7b, 0x55, 0xe2, 0xdf, 0x26, 0x5b, 0x93, 0xda, 0xb6, 0xa4, 0xb6,
		0x25, 0x8b, 0xb6, 0x63, 0xee, 0x0b, 0x66, 0x5c, 0xed, 0x75, 0x2c, 0x63, 0x30, 0xbf, 0xce, 0x5d,
		0xb7, 0xd3, 0x0f, 0xbc, 0x78, 0x33, 0x75, 0x9c, 0xfd, 0x61, 0x4d, 0x02, 0xb9, 0x2d, 0x43, 0x20,
		0x37, 0x2c, 0x5a, 0xf1, 0x99, 0xe4, 0xd3, 0x8b, 0x6a, 0x88, 0x52, 0x3e, 0xae, 0x63, 0x7a, 0x2a,
		0x39, 0xf3, 0x99, 0x74, 0x14, 0x72, 0x27, 0x67, 0x0a, 0x99, 0x72, 0x6b, 0x94, 0x97, 0x4b, 0xa6,
		0xdb, 0x3a, 0x32, 0xa4, 0x32, 0xad, 0x78, 0x9c, 0x35, 0x1f, 0x51, 0x2d, 0x0f, 0xb1, 0xe8, 0x69,
		0xb3, 0x19, 0xb7, 0x5e, 0xf5, 0xae, 0x39, 0xb2, 0x6d, 0xcd, 0x82, 0xdc, 0x77, 0xdc, 0x74, 0xa3,
		0xb6, 0xe7, 0x24, 0x5d, 0xa7, 0xd7, 0x8d, 0x12, 0xf5, 0xab, 0x8f, 0xf9, 0x61, 0xb2, 0x06, 0x3d,
		0x7a, 0x37, 0x6e, 0x3f, 0x18, 0x4e, 0xe3, 0xc7, 0xb3, 0x8f, 0xc7, 0x35, 0xb9, 0x44, 0x51, 0x3c,
		0x2f, 0xf5, 0xb9, 0x4d, 0x51, 0x3b, 0x4f, 0x65, 0xb9, 0x56, 0xf1, 0xc2, 0xfe, 0x9d, 0x17, 0x8d,
		0x7c, 0x11, 0x8d, 0x5b, 0x95, 0x96, 0xc2, 0x67, 0x8f, 0xc3, 0xfe, 0xdd, 0xe0, 0xcb, 0x3f, 0x14,
		0x20, 0x88, 0xff, 0x7b, 0x37, 0xe8, 0x38, 0xdd, 0x9b, 0x1b, 0x27, 0xf1, 0xef, 0x34, 0x82, 0xf9,
		0xe7, 0x87, 0x01, 0x40, 0x00, 0x90, 0xca, 0x03, 0x48, 0xdf, 0x0f, 0x93, 0xdd, 0xa6, 0x06, 0x76,
		0x28, 0x84, 0xdf, 0x35, 0x3e, 0x0d, 0xb3, 0xb4, 0x54, 0xd2, 0xc6, 0xb6, 0x94, 0x53, 0xc7, 0xb6,
		0xc6, 0xd7, 0x88, 0x02, 0x01, 0xa6, 0x32, 0xa5, 0x63, 0x87, 0x1a, 0xab, 0xc0, 0x38, 0xef, 0x23,
		0xb7, 0x3d, 0xc0, 0xff, 0x5f, 0xfd, 0x5b, 0x7f, 0x74, 0x3b, 0x9a, 0x4b, 0x89, 0xdf, 0x0f, 0xee,
		0x8f, 0xc2, 0x4d, 0x6d, 0xab, 0x79, 0xd8, 0x3a, 0xdc, 0x3f, 0x68, 0x1e, 0xee, 0x15, 0x68, 0x8e,
		0x2d, 0xc5, 0x7c, 0x5e, 0x15, 0xc0, 0x2c, 0x2b, 0x15, 0xd8, 0x9f, 0x42, 0x93, 0x42, 0x31, 0x7d,
		0x8c, 0x30, 0x46, 0xb8, 0x84, 0x46, 0x58, 0x3d, 0x1a, 0x5e, 0x27, 0x0a, 0x7e, 0x2e, 0xfa, 0xbd,
		0x17, 0xb8, 0xc9, 0x4d, 0x37, 0xba, 0x7b, 0xdb, 0xee, 0xde, 0xf5, 0xba, 0xa1, 0x17, 0x26, 0xf1,
		0xea, 0xbf, 0x9e, 0xfb, 0xdb, 0xec, 0x29, 0x3f, 0x66, 0x80, 0xa6, 0x17, 0xf9, 0x77, 0x6e, 0xf4,
		0xd3, 0x89, 0xff, 0xf4, 0x93, 0xf6, 0x77, 0xe7, 0xfb, 0xcf, 0x38, 0xf1, 0x22, 0x2f, 0xf6, 0x63,
		0x75, 0xf4, 0x59, 0x3f, 0xa4, 0xba, 0x2e, 0xb1, 0x0d, 0x9c, 0x01, 0x67, 0xd5, 0x87, 0xb3, 0x8e,
		0xd7, 0xf6, 0xef, 0xdc, 0x60, 0xbf, 0xa5, 0x03, 0x68, 0x0a, 0xbd, 0xa4, 0x96, 0x69, 0x5a, 0xb3,
		0xae, 0xce, 0x49, 0x13, 0xe7, 0xc4, 0x94, 0x73, 0xb2, 0x5b, 0xc1, 0xa9, 0xad, 0x91, 0x4f, 0xb2,
		0x60, 0xd7, 0x93, 0xef, 0x91, 0x17, 0x7f, 0xef, 0x06, 0x1d, 0x31, 0xa6, 0xf0, 0x38, 0x22, 0xc6,
		0x1e, 0x63, 0x8f, 0xb1, 0xc7, 0xd8, 0x63, 0xec, 0x31, 0xf6, 0x18, 0xfb, 0x3c, 0x8c, 0x7d, 0xe4,
		0x05, 0x6e, 0xe2, 0xdf, 0x7b, 0x82, 0xd6, 0x7e, 0xfd, 0x90, 0xe8, 0x02, 0x50, 0x05, 0xa8, 0x02,
		0x54, 0x01, 0xaa, 0x00, 0x55, 0x80, 0x2a, 0x54, 0x86, 0x2a, 0x38, 0xdd, 0x9b, 0x9b, 0xd8, 0x4b,
		0x0c, 0x30, 0x86, 0xc9, 0xc8, 0x10, 0x07, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0x00, 0x71, 0x80, 0x38,
		0x40, 0x1c, 0xca, 0x47, 0x1c, 0xee, 0xbd, 0x68, 0x60, 0xdf, 0x75, 0x18, 0xc2, 0x64, 0x08, 0xcc,
		0x39, 0xe6, 0xbc, 0xf2, 0xe6, 0xfc, 0x5b, 0xb7, 0x1b, 0x78, 0xae, 0x56, 0xc2, 0xc2, 0x4e, 0x11,
		0x3a, 0x07, 0x78, 0xed, 0x6e, 0xd8, 0x91, 0xbd, 0x4b, 0x7c, 0x62, 0x4c, 0xa0, 0x01, 0x68, 0x80,
		0xe9, 0xc3, 0xf4, 0x61, 0xfa, 0x30, 0x7d, 0x98, 0x7e, 0x1e, 0x06, 0xff, 0x4f, 0xd7, 0x4f, 0x9c,
		0xa4, 0xeb, 0x44, 0x5e, 0x9c, 0x74, 0x23, 0x4f, 0x33, 0xd9, 0x70, 0xe5, 0x68, 0x18, 0x79, 0x8c,
		0x3c, 0x39, 0x87, 0x9b, 0xf6, 0x3b, 0x39, 0x87, 0xd8, 0x66, 0x72, 0x0e, 0x6b, 0x64, 0xa4, 0x0b,
		0x5e, 0x9c, 0x39, 0x89, 0xdc, 0x30, 0xee, 0x75, 0xa3, 0x64, 0x0e, 0xb8, 0xfd, 0x6e, 0xf8, 0xda,
		0xed, 0xc5, 0xaf, 0x67, 0x4a, 0x7f, 0xcd, 0xfc, 0x3e, 0x53, 0x0b, 0x44, 0x99, 0xe6, 0x09, 0x99,
		0xd2, 0x31, 0x55, 0xd2, 0x30, 0x33, 0x9e, 0x25, 0x8a, 0x0b, 0x99, 0xe6, 0x17, 0x45, 0x2c, 0x2e,
		0x94, 0x99, 0x3f, 0x68, 0xa4, 0x49, 0xaa, 0xa4, 0x47, 0x4e, 0xd3, 0x22, 0x5f, 0xbd, 0x1a, 0x15,
		0x8d, 0x7c, 0x9d, 0x3e, 0xcb, 0x51, 0xe6, 0x9c, 0x0e, 0x90, 0x24, 0xce, 0x7e, 0x50, 0x47, 0x1f,
		0xa3, 0x0c, 0x18, 0x27, 0x55, 0xe8, 0xa4, 0x66, 0x2e, 0x03, 0xd6, 0xee, 0xde, 0xdd, 0x75, 0x43,
		0x47, 0x81, 0xf0, 0xce, 0x14, 0xb3, 0x9b, 0x0c, 0x61, 0xb9, 0xa7, 0x2e, 0xae, 0x30, 0xae, 0xb0,
		0xb5, 0x3e, 0xbb, 0x19, 0x4b, 0x3d, 0x3e, 0x71, 0x5a, 0x32, 0x94, 0x7e, 0x14, 0x3a, 0x32, 0xda,
		0x47, 0x47, 0xe2, 0x08, 0x19, 0x38, 0x4a, 0x52, 0x47, 0x4a, 0xfc, 0x68, 0x89, 0x1f, 0x31, 0x33,
		0x47, 0x4d, 0xd3, 0xd9, 0x54, 0xdc, 0x43, 0xaa, 0x47, 0x70, 0x3a, 0x80, 0x17, 0xba, 0xdf, 0x02,
		0xaf, 0xa3, 0xbf, 0xdc, 0x8f, 0x25, 0xf9, 0x46, 0x03, 0x6a, 0xae, 0xcd, 0x4c, 0x94, 0xe7, 0x60,
		0xa5, 0x75, 0x87, 0x13, 0x52, 0x39, 0x74, 0xcf, 0xbc, 0xe4, 0xd9, 0x37, 0x88, 0x01, 0xd2, 0x58,
		0x60, 0x0c, 0x13, 0x8c, 0x61, 0x83, 0x59, 0x8c, 0xd0, 0xc3, 0x0a, 0x01, 0xe9, 0x70, 0x4b, 0xa4,
		0x9d, 0xed, 0xd2, 0x0e, 0x54, 0x8f, 0x6c, 0x59, 0x6b, 0x9c, 0x77, 0x9e, 0xe5, 0x33, 0xc1, 0x3a,
		0xba, 0x6c, 0xe2, 0x46, 0xb7, 0x5e, 0xe2, 0xb8, 0x49, 0xe2, 0x85, 0x7d, 0xf5, 0xce, 0xb0, 0x2b,
		0xa7, 0x78, 0xc5, 0xd8, 0x40, 0x23, 0xd0, 0x08, 0x34, 0x16, 0x1c, 0x1a, 0x75, 0x22, 0x7b, 0xd6,
		0x82, 0x63, 0x53, 0x60, 0x2c, 0x89, 0xc8, 0x9f, 0xa5, 0x41, 0xf5, 0x6e, 0x1b, 0x17, 0x7f, 0xc9,
		0x9c, 0xb0, 0x2d, 0xa9, 0xdb, 0xc8, 0x75, 0xcb, 0xd1, 0x7c, 0x29, 0x3b, 0xac, 0xd0, 0x6d, 0xe5,
		0xe6, 0x15, 0xdf, 0x16, 0x1b, 0xff, 0xe1, 0xa5, 0xe0, 0x52, 0xb9, 0x3f, 0x8c, 0x2d, 0xd5, 0x2e,
		0x4b, 0xf5, 0xf0, 0xac, 0x18, 0xa3, 0x5c, 0xe5, 0x45, 0xf0, 0xac, 0xfa, 0xe9, 0x8a, 0x97, 0xae,
		0x4b, 0xe3, 0x08, 0x5f, 0xc2, 0x0e, 0xef, 0x4c, 0x5e, 0x4f, 0x45, 0xe7, 0x4c, 0x97, 0xb2, 0xfa,
		0x13, 0xaa, 0x30, 0x99, 0x19, 0x3b, 0xe0, 0xaf, 0x35, 0xc7, 0x59, 0x3a, 0xe2, 0x1b, 0x13, 0x0e,
		0x9b, 0x08, 0x87, 0x08, 0x87, 0x65, 0x15, 0x0e, 0x8d, 0x78, 0xb7, 0xb8, 0xb5, 0xb8, 0xb5, 0xb8,
		0xb5, 0xb8, 0xb5, 0xb8, 0xb5, 0xb8, 0xb5, 0xb8, 0xb5, 0xb8, 0xb5, 0xb8, 0xb5, 0x16, 0xb7, 0x2a,
		0x77, 0xc1, 0x30, 0x43, 0x98, 0x21, 0xcc, 0x50, 0x66, 0x07, 0x72, 0x17, 0x3c, 0xfc, 0xee, 0xdd,
		0x5e, 0xe2, 0xb7, 0xdd, 0xc0, 0xe9, 0x75, 0xff, 0xf4, 0x22, 0x39, 0x64, 0x9d, 0x1f, 0x56, 0x06,
		0x10, 0x77, 0x00, 0x44, 0x00, 0x11, 0x40, 0x94, 0xd1, 0xc7, 0x1e, 0x75, 0xb2, 0xfb, 0x5b, 0xb9,
		0x2d, 0x32, 0xd5, 0xc9, 0xee, 0x6f, 0xa5, 0x36, 0x87, 0x0c, 0x1b, 0x12, 0x07, 0x01, 0x13, 0x60,
		0xb0, 0x0a, 0x14, 0x92, 0x9f, 0x3d, 0x2f, 0x6e, 0x08, 0xfa, 0x77, 0xc2, 0xa8, 0x60, 0x1c, 0x1d,
		0x8c, 0xa3, 0xc4, 0x3a, 0xb4, 0x18, 0xcd, 0x7c, 0xd1, 0x1c, 0x3f, 0xa1, 0x5d, 0x2b, 0xc6, 0xa7,
		0x8c, 0x2a, 0x6e, 0x26, 0x94, 0x37, 0xa3, 0x0a, 0x9c, 0x21, 0x25, 0x4e, 0x5e, 0x91, 0x33, 0xaa,
		0xcc, 0x19, 0x56, 0xe8, 0x4c, 0xcb, 0x3f, 0x36, 0x64, 0x20, 0x03, 0xca, 0x9d, 0x51, 0x05, 0xcf,
		0xb0, 0x92, 0x57, 0xa9, 0x25, 0x7d, 0x56, 0xcc, 0xd1, 0xae, 0x0a, 0xa2, 0x3c, 0x0a, 0x6c, 0xf9,
		0x86, 0x1f, 0xc6, 0x89, 0x1b, 0x26, 0xf2, 0xc4, 0x75, 0x32, 0x30, 0xe4, 0x15, 0xf2, 0x0a, 0x79,
		0x85, 0xbc, 0x42, 0x5e, 0x21, 0xaf, 0x30, 0x1d, 0xc8, 0x2b, 0xe4, 0x15, 0xf2, 0x2a, 0x47, 0x5e,
		0x13, 0x2f, 0xba, 0x77, 0x03, 0x13, 0xec, 0x75, 0x3c, 0x32, 0xf4, 0x15, 0xfa, 0x0a, 0x7d, 0xad,
		0x1d, 0x7d, 0x8d, 0x13, 0x37, 0x71, 0x84, 0x41, 0x60, 0x16, 0x08, 0xde, 0x08, 0x0e, 0xf9, 0x39,
		0x1c, 0xd9, 0xb0, 0x46, 0xe8, 0x86, 0xdd, 0x51, 0x5d, 0x7d, 0xd1, 0xb3, 0x06, 0x89, 0x95, 0x47,
		0x70, 0x48, 0x6c, 0x71, 0x48, 0xac, 0xe9, 0x25, 0xdd, 0x79, 0xd3, 0x6a, 0xed, 0x1f, 0xb4, 0x5a,
		0xdb, 0x07, 0xbb, 0x07, 0xdb, 0x87, 0x7b, 0x7b, 0x3b, 0xfb, 0x3b, 0x7b, 0xf0, 0x5a, 0x78, 0xed,
		0xfa, 0x65, 0xbc, 0x13, 0xdc, 0xf5, 0x53, 0x93, 0x36, 0x18, 0x14, 0x36, 0x0b, 0x9b, 0x85, 0xcd,
		0xd6, 0x8e, 0xcd, 0x22, 0xc6, 0xc2, 0x63, 0x17, 0x96, 0x0d, 0x31, 0xb6, 0x72, 0x3c, 0x16, 0x31,
		0x16, 0xd2, 0x9a, 0x2f, 0x69, 0x55, 0x6b, 0x14, 0x94, 0x86, 0xb9, 0xaa, 0x34, 0x0d, 0x82, 0xbe,
		0x42, 0x5f, 0xa1, 0xaf, 0x15, 0xa0, 0xaf, 0x83, 0xb3, 0x9f, 0xf8, 0xed, 0xff, 0xc5, 0x46, 0x08,
		0x2c, 0x52, 0x2c, 0x52, 0x2c, 0x14, 0xb6, 0x18, 0x14, 0x16, 0x29, 0x16, 0x56, 0x5b, 0x30, 0x56,
		0x2b, 0x08, 0x64, 0x8f, 0x84, 0xd6, 0x0f, 0xe1, 0xb2, 0x70, 0x59, 0xb8, 0x6c, 0xfd, 0xb8, 0x2c,
		0x52, 0x2c, 0x3c, 0x76, 0x61, 0xd9, 0x90, 0x62, 0x2b, 0xc7, 0x63, 0x91, 0x62, 0x21, 0xad, 0xf9,
		0x92, 0x56, 0x53, 0x52, 0xec, 0x64, 0x64, 0xe8, 0x2b, 0xf4, 0x15, 0xfa, 0x5a, 0x3b, 0xfa, 0x8a,
		0x14, 0x0b, 0x85, 0x35, 0x87, 0xdf, 0x50, 0xd8, 0xe2, 0x50, 0x58, 0xa4, 0x58, 0x58, 0xad, 0x20,
		0xab, 0xcd, 0xb5, 0xc4, 0x97, 0x50, 0x4f, 0x8e, 0xe9, 0x78, 0x86, 0x7b, 0x73, 0x8c, 0x9a, 0xb1,
		0x4b, 0x16, 0xfe, 0x1b, 0x7d, 0xeb, 0x24, 0xea, 0xb7, 0x93, 0x70, 0x6c, 0xc9, 0x8f, 0x7a, 0xf1,
		0xf5, 0x51, 0x2f, 0xfe, 0x30, 0xfc, 0x0a, 0xd7, 0xe7, 0x83, 0xaf, 0x70, 0xfd, 0x6e, 0xf8, 0x15,
		0x4e, 0xc2, 0xeb, 0xb3, 0xd1, 0xb3, 0xcf, 0x87, 0x8f, 0xa6, 0x2f, 0xdf, 0x16, 0x7d, 0xf9, 0x04,
		0x9c, 0x1d, 0xaa, 0x32, 0x52, 0x95, 0xd1, 0xbe, 0x0b, 0x43, 0x03, 0x83, 0x42, 0xb9, 0x25, 0x34,
		0x30, 0xa0, 0x81, 0x01, 0x0d, 0x0c, 0x24, 0x35, 0x23, 0xfa, 0xf2, 0xd9, 0xf4, 0x01, 0xac, 0x70,
		0x7f, 0x6b, 0x6d, 0xf9, 0x9e, 0x19, 0x9c, 0x79, 0xdd, 0x19, 0x37, 0x3c, 0xd3, 0x0d, 0xa5, 0x96,
		0x84, 0x69, 0x3d, 0xa8, 0x6c, 0x2b, 0x98, 0x7e, 0x1d, 0x32, 0xac, 0x41, 0x63, 0xfc, 0xaa, 0xdd,
		0x7e, 0xd2, 0xeb, 0x67, 0x2f, 0xf0, 0x37, 0xe5, 0x4d, 0xf3, 0xc3, 0x64, 0xdc, 0x03, 0x6a, 0x05,
		0xe7, 0x95, 0x5d, 0x19, 0x1d, 0xd7, 0x45, 0xd0, 0x55, 0xd1, 0x75, 0x4d, 0xc4, 0x5c, 0x11, 0x31,
		0xd7, 0x43, 0xd6, 0xd5, 0x30, 0x8b, 0x3b, 0xaa, 0x05, 0xdd, 0x1b, 0xed, 0xc9, 0xae, 0xd3, 0x6c,
		0x39, 0x3a, 0x1e, 0x27, 0xe7, 0x9e, 0xa3, 0xdb, 0xf4, 0x1c, 0xb5, 0xe1, 0xe5, 0xd3, 0x73, 0x54,
		0xf0, 0x08, 0x22, 0xe0, 0x21, 0xe0, 0x21, 0xe0, 0x21, 0xe0, 0x21, 0xe0, 0x21, 0xe0, 0x21, 0xe0,
		0x21, 0xe0, 0x21, 0xe0, 0x21, 0xe0, 0x95, 0x49, 0xc0, 0x1b, 0x89, 0x24, 0xaf, 0xc7, 0x0e, 0xa0,
		0x2d, 0x15, 0x4f, 0x49, 0xc9, 0x72, 0x13, 0x4f, 0xdf, 0xd3, 0x1d, 0x0d, 0x93, 0xb3, 0xa3, 0xdb,
		0xc4, 0xd1, 0xc5, 0xd1, 0x2d, 0xab, 0xa3, 0x6b, 0xc4, 0xc3, 0xc5, 0xb5, 0xc5, 0xb5, 0xc5, 0xb5,
		0xc5, 0xb5, 0xc5, 0xb5, 0xc5, 0xb5, 0xc5, 0xb5, 0xc5, 0xb5, 0xc5, 0xb5, 0xb5, 0xb8, 0x55, 0x69,
		0x04, 0x0f, 0xad, 0x83, 0xd6, 0x95, 0x90, 0xd6, 0xd1, 0x08, 0x3e, 0x5f, 0x10, 0x30, 0x01, 0x06,
		0xab, 0x40, 0x81, 0xa4, 0x6b, 0xd3, 0x28, 0xb1, 0x0e, 0x2d, 0x48, 0xba, 0xce, 0xdd, 0x3b, 0x34,
		0xe1, 0x25, 0x1a, 0xf5, 0x16, 0x0d, 0x79, 0x8d, 0xf2, 0xde, 0xa3, 0x51, 0x2f, 0xd2, 0xb0, 0x37,
		0x69, 0xda, 0x55, 0xb1, 0xe1, 0xb2, 0x18, 0xf0, 0x32, 0x8d, 0x7a, 0x9b, 0x86, 0xbd, 0xce, 0x4a,
		0x2d, 0x29, 0xd9, 0xd5, 0xa6, 0xb7, 0x3c, 0x8d, 0xe0, 0x21, 0xaf, 0x90, 0x57, 0xc8, 0x2b, 0xe4,
		0x15, 0xf2, 0x0a, 0x79, 0x85, 0xbc, 0x42, 0x5e, 0x21, 0xaf, 0x65, 0x22, 0xaf, 0x34, 0x82, 0x87,
		0xbe, 0x42, 0x5f, 0xa1, 0xaf, 0xd2, 0x7b, 0x96, 0x46, 0xf0, 0x90, 0x58, 0x93, 0x08, 0x0e, 0x89,
		0x2d, 0x0e, 0x89, 0xa5, 0xe4, 0x25, 0xbc, 0xb6, 0x58, 0xbc, 0x96, 0x46, 0xf0, 0xb0, 0x59, 0xd8,
		0x2c, 0x6c, 0x56, 0x6a, 0xcf, 0x22, 0xc6, 0xc2, 0x63, 0x17, 0x96, 0x0d, 0x31, 0xb6, 0x72, 0x3c,
		0x16, 0x31, 0x16, 0xd2, 0x9a, 0x2f, 0x69, 0xa5, 0x11, 0x3c, 0xf4, 0x15, 0xfa, 0x0a, 0x7d, 0x15,
		0xde, 0xb3, 0x74, 0x1f, 0x82, 0xc2, 0x9a, 0xc3, 0x6f, 0x28, 0x6c, 0x71, 0x28, 0x2c, 0x52, 0x2c,
		0xac, 0xb6, 0x60, 0xac, 0x96, 0x46, 0xf0, 0x70, 0x59, 0xb8, 0x2c, 0x5c, 0x56, 0x68, 0xcf, 0x22,
		0xc5, 0xc2, 0x63, 0x17, 0x96, 0x0d, 0x29, 0xb6, 0x72, 0x3c, 0x16, 0x29, 0x16, 0xd2, 0x9a, 0x2f,
		0x69, 0xa5, 0x11, 0x3c, 0xf4, 0x15, 0xfa, 0x0a, 0x7d, 0x15, 0xde, 0xb3, 0x48, 0xb1, 0x50, 0x58,
		0x73, 0xf8, 0x0d, 0x85, 0x2d, 0x0e, 0x85, 0x45, 0x8a, 0x85, 0xd5, 0x0a, 0xb2, 0x5a, 0x1a, 0xc1,
		0x67, 0xab, 0x25, 0x9f, 0x73, 0x33, 0xf8, 0xb3, 0xe1, 0xb7, 0xa0, 0x21, 0xfc, 0x53, 0x54, 0x88,
		0x7e, 0x52, 0x6a, 0x4e, 0x0f, 0xd5, 0x19, 0xa9, 0xce, 0x68, 0xdf, 0x95, 0xa1, 0xe8, 0x76, 0xa1,
		0xdc, 0x13, 0x8a, 0x6e, 0x53, 0x74, 0x9b, 0xa2, 0xdb, 0x92, 0xda, 0x11, 0xfd, 0xa4, 0x6c, 0xfa,
		0x02, 0xd6, 0x7c, 0x00, 0x9a, 0xc2, 0xdb, 0x99, 0x6d, 0x93, 0x8d, 0xe1, 0x47, 0xde, 0x54, 0x11,
		0x9a, 0xc3, 0x8f, 0xe7, 0xc8, 0xbf, 0x73, 0xa3, 0x9f, 0x8e, 0x82, 0x05, 0x9e, 0xb2, 0xa8, 0xc5,
		0x81, 0x68, 0x10, 0x6f, 0xc1, 0x55, 0xa1, 0x41, 0xbc, 0x0e, 0x06, 0xd1, 0x20, 0x9e, 0x06, 0xf1,
		0xf6, 0xbc, 0x7e, 0xfa, 0xe6, 0x09, 0x1e, 0xc1, 0xe9, 0x00, 0x5e, 0xe8, 0x7e, 0x0b, 0xbc, 0x8e,
		0x9c, 0x8a, 0x37, 0x19, 0x50, 0xb7, 0x89, 0x84, 0x77, 0xe3, 0xf6, 0x83, 0xe1, 0xd2, 0x0c, 0x56,
		0x1a, 0x25, 0x10, 0x25, 0x10, 0x25, 0xb0, 0xe8, 0x4a, 0xe0, 0xb7, 0x6e, 0x37, 0xf0, 0xdc, 0x50,
		0x52, 0x07, 0xdc, 0xe1, 0x92, 0x64, 0x8b, 0x4b, 0x12, 0xa0, 0x11, 0x68, 0x2c, 0x37, 0x34, 0x72,
		0x49, 0xa2, 0xfe, 0x8b, 0x4b, 0x12, 0xd1, 0x71, 0xb9, 0x24, 0xe1, 0x92, 0x84, 0x4b, 0x12, 0x2e,
		0x49, 0xa6, 0xb2, 0xfd, 0x82, 0xf4, 0xfc, 0x7a, 0x2c, 0xab, 0xd9, 0xba, 0x27, 0x51, 0xba, 0x27,
		0x70, 0x13, 0x4f, 0x5f, 0x3f, 0x1c, 0x0d, 0x93, 0xb3, 0x7c, 0xd8, 0x44, 0x3e, 0x44, 0x3e, 0x2c,
		0xab, 0x7c, 0x68, 0xc4, 0xc7, 0xc5, 0xb9, 0xc5, 0xb9, 0xc5, 0xb9, 0xc5, 0xb9, 0xc5, 0xb9, 0xc5,
		0xb9, 0xc5, 0xb9, 0xc5, 0xb9, 0xc5, 0xb9, 0xb5, 0xb8, 0x55, 0xb9, 0x11, 0x86, 0x19, 0xc2, 0x0c,
		0x61, 0x86, 0x32, 0x3b, 0x90, 0x1b, 0xe1, 0xe1, 0x77, 0x9f, 0x4f, 0x3b, 0x14, 0x43, 0x56, 0xc9,
		0x6c, 0x46, 0x4d, 0x3d, 0x0b, 0x40, 0x04, 0x10, 0xab, 0x07, 0x88, 0xba, 0xfa, 0xd8, 0xa3, 0x4e,
		0x76, 0x7f, 0x2b, 0x5f, 0x3b, 0x68, 0x30, 0x28, 0x65, 0x83, 0x24, 0x40, 0x81, 0xb2, 0x41, 0xa6,
		0x51, 0x62, 0x1d, 0x5a, 0x50, 0x36, 0x28, 0x77, 0xc5, 0xcd, 0x84, 0xf2, 0x66, 0x54, 0x81, 0x33,
		0xa4, 0xc4, 0xc9, 0x2b, 0x72, 0x46, 0x95, 0x39, 0xc3, 0x0a, 0x9d, 0x69, 0xf9, 0xc7, 0x86, 0x0c,
		0x64, 0x40, 0xb9, 0x33, 0xaa, 0xe0, 0x19, 0x56, 0xf2, 0x2a, 0xb5, 0xa4, 0xd4, 0x07, 0x32, 0xbd,
		0xe5, 0x1b, 0x7e, 0x18, 0x27, 0xee, 0xd0, 0x52, 0x8b, 0x37, 0x83, 0x1f, 0x0d, 0x0c, 0x79, 0x85,
		0xbc, 0x42, 0x5e, 0x21, 0xaf, 0x90, 0x57, 0xc8, 0x2b, 0x4c, 0x07, 0xf2, 0x0a, 0x79, 0x85, 0xbc,
		0xca, 0x91, 0xd7, 0xc4, 0x8b, 0xee, 0xdd, 0xc0, 0x04, 0x7b, 0x1d, 0x8f, 0x0c, 0x7d, 0x85, 0xbe,
		0x42, 0x5f, 0x6b, 0x47, 0x5f, 0xe3, 0xc4, 0x4d, 0x1c, 0x61, 0x10, 0xd8, 0xa2, 0x68, 0x7b, 0xf9,
		0x49, 0x2c, 0x45, 0xdb, 0x2b, 0x47, 0x62, 0x29, 0xda, 0x0e, 0xaf, 0x2d, 0x16, 0xaf, 0xbd, 0x13,
		0xdc, 0xf5, 0xb3, 0x0d, 0xe1, 0x61, 0xb3, 0xb0, 0x59, 0xd8, 0x6c, 0xfd, 0xd8, 0x2c, 0x62, 0x2c,
		0x3c, 0x76, 0x61, 0xd9, 0x10, 0x63, 0x2b, 0xc7, 0x63, 0x11, 0x63, 0x21, 0xad, 0xf9, 0x92, 0x56,
		0x53, 0xfd, 0x33, 0x27, 0x23, 0x43, 0x5f, 0xa1, 0xaf, 0xd0, 0xd7, 0xda, 0xd1, 0x57, 0xfa, 0x67,
		0x42, 0x61, 0xcd, 0xe1, 0x37, 0x14, 0xb6, 0x38, 0x14, 0x16, 0x29, 0x16, 0x56, 0x5b, 0x30, 0x56,
		0x2b, 0x08, 0x64, 0xb3, 0x0d, 0xe1, 0xe1, 0xb2, 0x70, 0x59, 0xb8, 0x6c, 0xfd, 0xb8, 0x2c, 0x52,
		0x2c, 0x3c, 0x76, 0x61, 0xd9, 0x90, 0x62, 0x2b, 0xc7, 0x63, 0x91, 0x62, 0x21, 0xad, 0xf9, 0x92,
		0x56, 0x53, 0x52, 0xec, 0x64, 0x64, 0xe8, 0x2b, 0xf4, 0x15, 0xfa, 0x5a, 0x3b, 0xfa, 0x8a, 0x14,
		0x0b, 0x85, 0x35, 0x87, 0xdf, 0x50, 0xd8, 0xe2, 0x50, 0x58, 0xa4, 0x58, 0x58, 0xad, 0x20, 0xab,
		0xcd, 0xb5, 0xc4, 0x97, 0x50, 0x67, 0x8e, 0xe9, 0x78, 0x56, 0x3a, 0x74, 0x0c, 0x1b, 0x57, 0xbc,
		0x96, 0x2c, 0xff, 0xb7, 0x95, 0xae, 0xfd, 0xf6, 0xa9, 0x1f, 0x7a, 0xe7, 0xa3, 0xef, 0x71, 0x12,
		0x5e, 0x9f, 0x8d, 0xbe, 0xc0, 0xf9, 0xf0, 0xf9, 0x34, 0xea, 0xdb, 0xa2, 0x51, 0x9f, 0x80, 0xdf,
		0x43, 0x81, 0x46, 0x0a, 0x34, 0xda, 0xf7, 0x66, 0xe8, 0x65, 0x50, 0x28, 0x0f, 0x85, 0x5e, 0x06,
		0xf4, 0x32, 0xa0, 0x97, 0x81, 0xa4, 0x7c, 0x44, 0xa3, 0x3e, 0x9b, 0xee, 0x80, 0x45, 0x37, 0xc0,
		0x5a, 0x9f, 0xbe, 0x67, 0x06, 0xe7, 0x5f, 0x77, 0xde, 0xad, 0xcc, 0x77, 0x43, 0xa9, 0x53, 0x61,
		0x26, 0x97, 0x2a, 0xdb, 0x62, 0xa6, 0x5f, 0x92, 0x0c, 0xcb, 0xd1, 0x98, 0x7b, 0xeb, 0x6e, 0x3f,
		0x7b, 0xfd, 0xbf, 0x29, 0x97, 0x5a, 0x1a, 0x29, 0xe3, 0xa6, 0x50, 0x2b, 0x49, 0xaf, 0xec, 0xe1,
		0xe8, 0x78, 0x34, 0x82, 0x1e, 0x8c, 0xae, 0xc7, 0x22, 0xe6, 0xa1, 0x88, 0x79, 0x24, 0xb2, 0x1e,
		0x88, 0x59, 0x20, 0x52, 0x2d, 0xf9, 0xde, 0x68, 0x4f, 0x76, 0x9d, 0x66, 0x53, 0xd2, 0xf1, 0x38,
		0x39, 0x77, 0x25, 0xdd, 0xa6, 0x2b, 0xa9, 0x0d, 0xe7, 0x9f, 0xae, 0xa4, 0x82, 0x47, 0x10, 0x5d,
		0x0f, 0x5d, 0x0f, 0x5d, 0x0f, 0x5d, 0x0f, 0x5d, 0x0f, 0x5d, 0x0f, 0x5d, 0x0f, 0x5d, 0x0f, 0x5d,
		0x0f, 0x5d, 0xaf, 0x7c, 0xba, 0x5e, 0xb7, 0x9f, 0xbc, 0x1e, 0xfb, 0x80, 0xb6, 0x94, 0x3d, 0x25,
		0x5d, 0xcb, 0x4d, 0x3c, 0x7d, 0x67, 0x77, 0x34, 0x4c, 0xce, 0xbe, 0x6e, 0x13, 0x5f, 0x17, 0x5f,
		0xb7, 0xac, 0xbe, 0xae, 0x11, 0x27, 0x17, 0xef, 0x16, 0xef, 0x16, 0xef, 0x16, 0xef, 0x16, 0xef,
		0x16, 0xef, 0x16, 0xef, 0x16, 0xef, 0x16, 0xef, 0xd6, 0xe2, 0x56, 0xa5, 0x5b, 0x3c, 0xb4, 0x0e,
		0x5a, 0x57, 0x42, 0x5a, 0x47, 0xb7, 0xf8, 0x7c, 0x41, 0xc0, 0x04, 0x18, 0xac, 0x02, 0x05, 0x32,
		0xb3, 0x4d, 0xa3, 0xc4, 0x3a, 0xb4, 0x20, 0x33, 0x3b, 0x77, 0xef, 0xd0, 0x84, 0x97, 0x68, 0xd4,
		0x5b, 0x34, 0xe4, 0x35, 0xca, 0x7b, 0x8f, 0x46, 0xbd, 0x48, 0xc3, 0xde, 0xa4, 0x69, 0x57, 0xc5,
		0x86, 0xcb, 0x62, 0xc0, 0xcb, 0x34, 0xea, 0x6d, 0x1a, 0xf6, 0x3a, 0x2b, 0xb5, 0xa4, 0xa4, 0x60,
		0x9b, 0xde, 0xf2, 0x74, 0x8b, 0x87, 0xbc, 0x42, 0x5e, 0x21, 0xaf, 0x90, 0x57, 0xc8, 0x2b, 0xe4,
		0x15, 0xf2, 0x0a, 0x79, 0x85, 0xbc, 0x96, 0x89, 0xbc, 0xd2, 0x2d, 0x1e, 0xfa, 0x0a, 0x7d, 0x85,
		0xbe, 0x4a, 0xef, 0x59, 0xba, 0xc5, 0x43, 0x62, 0x4d, 0x22, 0x38, 0x24, 0xb6, 0x38, 0x24, 0x96,
		0xba, 0x98, 0xf0, 0xda, 0x62, 0xf1, 0x5a, 0xba, 0xc5, 0xc3, 0x66, 0x61, 0xb3, 0xb0, 0x59, 0xa9,
		0x3d, 0x8b, 0x18, 0x0b, 0x8f, 0x5d, 0x58, 0x36, 0xc4, 0xd8, 0xca, 0xf1, 0x58, 0xc4, 0x58, 0x48,
		0x6b, 0xbe, 0xa4, 0x95, 0x6e, 0xf1, 0xd0, 0x57, 0xe8, 0x2b, 0xf4, 0x55, 0x78, 0xcf, 0xd2, 0xa2,
		0x08, 0x0a, 0x6b, 0x0e, 0xbf, 0xa1, 0xb0, 0xc5, 0xa1, 0xb0, 0x48, 0xb1, 0xb0, 0xda, 0x82, 0xb1,
		0x5a, 0xba, 0xc5, 0xc3, 0x65, 0xe1, 0xb2, 0x70, 0x59, 0xa1, 0x3d, 0x8b, 0x14, 0x0b, 0x8f, 0x5d,
		0x58, 0x36, 0xa4, 0xd8, 0xca, 0xf1, 0x58, 0xa4, 0x58, 0x48, 0x6b, 0xbe, 0xa4, 0x95, 0x6e, 0xf1,
		0xd0, 0x57, 0xe8, 0x2b, 0xf4, 0x55, 0x78, 0xcf, 0x22, 0xc5, 0x42, 0x61, 0xcd, 0xe1, 0x37, 0x14,
		0xb6, 0x38, 0x14, 0x16, 0x29, 0x16, 0x56, 0x2b, 0xc8, 0x6a, 0xe9, 0x16, 0x9f, 0xb9, 0x9c, 0x7c,
		0x11, 0xda, 0xc5, 0x9f, 0xf5, 0x13, 0xfa, 0xc5, 0x3f, 0xc5, 0x87, 0xe8, 0x2b, 0xa5, 0xe6, 0xf9,
		0x50, 0xa2, 0x91, 0x12, 0x8d, 0xf6, 0xfd, 0x19, 0x2a, 0x6f, 0x17, 0xca, 0x47, 0xa1, 0xf2, 0x36,
		0x95, 0xb7, 0xa9, 0xbc, 0x2d, 0x29, 0x20, 0xd1, 0x57, 0xca, 0xa6, 0x43, 0x60, 0xd3, 0x11, 0xa0,
		0x61, 0xbc, 0xb5, 0x09, 0x37, 0xde, 0x31, 0xfe, 0xac, 0x9f, 0x14, 0xa6, 0x65, 0xfc, 0x48, 0x1a,
		0x1d, 0xb7, 0xca, 0xd7, 0xeb, 0x19, 0x3f, 0x37, 0x14, 0x4d, 0xe3, 0x2d, 0xb8, 0x2d, 0x34, 0x8d,
		0xd7, 0x01, 0x23, 0x9a, 0xc6, 0xd3, 0x34, 0xde, 0x9e, 0x02, 0x40, 0x23, 0x3d, 0xc1, 0x23, 0x38,
		0x1d, 0xc0, 0x0b, 0xdd, 0x6f, 0x81, 0xd7, 0x91, 0x53, 0xf4, 0x26, 0x03, 0xea, 0x76, 0x95, 0xf0,
		0x6e, 0xdc, 0x7e, 0x30, 0x5c, 0x9a, 0xc1, 0x4a, 0xa3, 0x0a, 0xa2, 0x0a, 0xa2, 0x0a, 0x16, 0x5d,
		0x15, 0xfc, 0xd6, 0xed, 0x06, 0x9e, 0x1b, 0x4a, 0x6a, 0x82, 0x3b, 0x5c, 0x98, 0x6c, 0x71, 0x61,
		0x02, 0x34, 0x02, 0x8d, 0xe5, 0x86, 0x46, 0x2e, 0x4c, 0xd4, 0x7f, 0x71, 0x61, 0x22, 0x3a, 0x2e,
		0x17, 0x26, 0x5c, 0x98, 0x70, 0x61, 0xc2, 0x85, 0xc9, 0xbc, 0x7e, 0x3f, 0x2b, 0x3e, 0xbf, 0x1e,
		0x0b, 0x6b, 0xb6, 0xae, 0x4c, 0x94, 0xee, 0x0b, 0xdc, 0xc4, 0xd3, 0x57, 0x10, 0x47, 0xc3, 0xe4,
		0x2c, 0x20, 0x36, 0x11, 0x10, 0x11, 0x10, 0xcb, 0x2a, 0x20, 0x1a, 0xf1, 0x72, 0x71, 0x6f, 0x71,
		0x6f, 0x71, 0x6f, 0x71, 0x6f, 0x71, 0x6f, 0x71, 0x6f, 0x71, 0x6f, 0x71, 0x6f, 0x71, 0x6f, 0x2d,
		0x6e, 0x55, 0xee, 0x84, 0x61, 0x86, 0x30, 0x43, 0x98, 0xa1, 0xcc, 0x0e, 0xe4, 0x4e, 0x78, 0xf8,
		0xdd, 0xe7, 0xd3, 0x10, 0xc5, 0x90, 0x55, 0x32, 0xbb, 0x51, 0x53, 0xcf, 0x02, 0x10, 0x01, 0xc4,
		0xea, 0x01, 0xa2, 0xae, 0x3e, 0xf6, 0xa8, 0x93, 0xdd, 0xdf, 0xca, 0x97, 0x13, 0x1a, 0x0c, 0x4a,
		0x25, 0x21, 0x09, 0x50, 0xa0, 0x92, 0x90, 0x69, 0x94, 0x58, 0x87, 0x16, 0x54, 0x12, 0xca, 0x5d,
		0x71, 0x33, 0xa1, 0xbc, 0x19, 0x55, 0xe0, 0x0c, 0x29, 0x71, 0xf2, 0x8a, 0x9c, 0x51, 0x65, 0xce,
		0xb0, 0x42, 0x67, 0x5a, 0xfe, 0xb1, 0x21, 0x03, 0x19, 0x50, 0xee, 0x8c, 0x2a, 0x78, 0x86, 0x95,
		0xbc, 0x4a, 0x2d, 0x29, 0x25, 0x83, 0x4c, 0x6f, 0xf9, 0x86, 0x1f, 0xc6, 0x89, 0x3b, 0xb4, 0xd4,
		0xe2, 0xfd, 0xe1, 0x47, 0x03, 0x43, 0x5e, 0x21, 0xaf, 0x90, 0x57, 0xc8, 0x2b, 0xe4, 0x15, 0xf2,
		0x0a, 0xd3, 0x81, 0xbc, 0x42, 0x5e, 0x21, 0xaf, 0x72, 0xe4, 0x35, 0xf1, 0xa2, 0x7b, 0x37, 0x30,
		0xc1, 0x5e, 0xc7, 0x23, 0x43, 0x5f, 0xa1, 0xaf, 0xd0, 0xd7, 0xda, 0xd1, 0xd7, 0x38, 0x71, 0x13,
		0x47, 0x18, 0x04, 0xb6, 0xa8, 0xe3, 0x5e, 0x7e, 0x12, 0x4b, 0x1d, 0xf7, 0xca, 0x91, 0x58, 0xea,
		0xb8, 0xc3, 0x6b, 0x8b, 0xc5, 0x6b, 0xef, 0x04, 0x77, 0xfd, 0x6c, 0x8f, 0x78, 0xd8, 0x2c, 0x6c,
		0x16, 0x36, 0x5b, 0x3f, 0x36, 0x8b, 0x18, 0x0b, 0x8f, 0x5d, 0x58, 0x36, 0xc4, 0xd8, 0xca, 0xf1,
		0x58, 0xc4, 0x58, 0x48, 0x6b, 0xbe, 0xa4, 0xd5, 0x54, 0x4b, 0xcd, 0xc9, 0xc8, 0xd0, 0x57, 0xe8,
		0x2b, 0xf4, 0xb5, 0x76, 0xf4, 0x95, 0x96, 0x9a, 0x50, 0x58, 0x73, 0xf8, 0x0d, 0x85, 0x2d, 0x0e,
		0x85, 0x45, 0x8a, 0x85, 0xd5, 0x16, 0x8c, 0xd5, 0x0a, 0x02, 0xd9, 0x6c, 0x8f, 0x78, 0xb8, 0x2c,
		0x5c, 0x16, 0x2e, 0x5b, 0x3f, 0x2e, 0x8b, 0x14, 0x0b, 0x8f, 0x5d, 0x58, 0x36, 0xa4, 0xd8, 0xca,
		0xf1, 0x58, 0xa4, 0x58, 0x48, 0x6b, 0xbe, 0xa4, 0xd5, 0x94, 0x14, 0x3b, 0x19, 0x19, 0xfa, 0x0a,
		0x7d, 0x85, 0xbe, 0xd6, 0x8e, 0xbe, 0x22, 0xc5, 0x42, 0x61, 0xcd, 0xe1, 0x37, 0x14, 0xb6, 0x38,
		0x14, 0x16, 0x29, 0x16, 0x56, 0x2b, 0xc8, 0x6a, 0x73, 0x2d, 0xf1, 0x25, 0xd4, 0x9b, 0x63, 0x3a,
		0x9e, 0xa5, 0x1e, 0x1d, 0xc3, 0xd6, 0x15, 0xaf, 0x25, 0x0b, 0x00, 0x6e, 0xa5, 0x6f, 0xc4, 0x7d,
		0x31, 0xf9, 0x26, 0x27, 0xe1, 0xf5, 0xd9, 0xe8, 0x2b, 0x9c, 0x0f, 0xbf, 0x01, 0xed, 0xfa, 0xb6,
		0x68, 0xd7, 0x27, 0xe0, 0xfb, 0x50, 0xa4, 0x91, 0x22, 0x8d, 0xf6, 0x3d, 0x1a, 0xfa, 0x19, 0x14,
		0xca, 0x4b, 0xa1, 0x9f, 0x01, 0xfd, 0x0c, 0xe8, 0x67, 0x20, 0x29, 0x21, 0xd1, 0xae, 0xcf, 0xa6,
		0x4b, 0x60, 0xd5, 0x15, 0xb0, 0xd6, 0xad, 0xef, 0x99, 0xc1, 0x15, 0xd0, 0x9d, 0x79, 0x4b, 0x33,
		0xde, 0x50, 0xea, 0x58, 0x98, 0xd1, 0xb1, 0xca, 0xb6, 0xa0, 0xe9, 0x97, 0x25, 0xc3, 0x92, 0x34,
		0x16, 0xde, 0xbc, 0xdb, 0xcf, 0x5e, 0x0b, 0x70, 0xca, 0xa9, 0x56, 0x8c, 0x95, 0x71, 0x73, 0xa8,
		0x15, 0xa8, 0x57, 0xf6, 0x75, 0x74, 0x7c, 0x1b, 0x41, 0x5f, 0x46, 0xd7, 0x77, 0x11, 0xf3, 0x55,
		0xc4, 0x7c, 0x13, 0x59, 0x5f, 0xc4, 0x2c, 0x20, 0xa9, 0x16, 0x80, 0x6f, 0xb4, 0x27, 0xbb, 0x4e,
		0xb3, 0x45, 0xe9, 0x78, 0x9c, 0x9c, 0x7b, 0x94, 0x6e, 0xd3, 0xa3, 0xd4, 0x86, 0x0c, 0x40, 0x8f,
		0x52, 0xc1, 0x23, 0x88, 0xc2, 0x87, 0xc2, 0x87, 0xc2, 0x87, 0xc2, 0x87, 0xc2, 0x87, 0xc2, 0x87,
		0xc2, 0x87, 0xc2, 0x87, 0xc2, 0x87, 0xc2, 0x57, 0x46, 0x85, 0xaf, 0xdb, 0x4f, 0x5e, 0x8f, 0xbd,
		0x40, 0x5b, 0x1a, 0x9f, 0x92, 0xbe, 0xe5, 0x26, 0x9e, 0xbe, 0xbb, 0x3b, 0x1a, 0x26, 0x67, 0x6f,
		0xb7, 0x89, 0xb7, 0x8b, 0xb7, 0x5b, 0x56, 0x6f, 0xd7, 0x88, 0x9b, 0x8b, 0x7f, 0x8b, 0x7f, 0x8b,
		0x7f, 0x8b, 0x7f, 0x8b, 0x7f, 0x8b, 0x7f, 0x8b, 0x7f, 0x8b, 0x7f, 0x8b, 0x7f, 0x6b, 0x71, 0xab,
		0xd2, 0x3d, 0x1e, 0x5a, 0x07, 0xad, 0x2b, 0x21, 0xad, 0xa3, 0x7b, 0x7c, 0xbe, 0x20, 0x60, 0x02,
		0x0c, 0x56, 0x81, 0x02, 0x99, 0xda, 0xa6, 0x51, 0x62, 0x1d, 0x5a, 0x90, 0xa9, 0x9d, 0xbb, 0x77,
		0x68, 0xc2, 0x4b, 0x34, 0xea, 0x2d, 0x1a, 0xf2, 0x1a, 0xe5, 0xbd, 0x47, 0xa3, 0x5e, 0xa4, 0x61,
		0x6f, 0xd2, 0xb4, 0xab, 0x62, 0xc3, 0x65, 0x31, 0xe0, 0x65, 0x1a, 0xf5, 0x36, 0x0d, 0x7b, 0x9d,
		0x95, 0x5a, 0x52, 0x52, 0xb2, 0x4d, 0x6f, 0x79, 0xba, 0xc7, 0x43, 0x5e, 0x21, 0xaf, 0x90, 0x57,
		0xc8, 0x2b, 0xe4, 0x15, 0xf2, 0x0a, 0x79, 0x85, 0xbc, 0x42, 0x5e, 0xcb, 0x44, 0x5e, 0xe9, 0x1e,
		0x0f, 0x7d, 0x85, 0xbe, 0x42, 0x5f, 0xa5, 0xf7, 0x2c, 0xdd, 0xe3, 0x21, 0xb1, 0x26, 0x11, 0x1c,
		0x12, 0x5b, 0x1c, 0x12, 0x4b, 0x9d, 0x4c, 0x78, 0x6d, 0xb1, 0x78, 0x2d, 0xdd, 0xe3, 0x61, 0xb3,
		0xb0, 0x59, 0xd8, 0xac, 0xd4, 0x9e, 0x45, 0x8c, 0x85, 0xc7, 0x2e, 0x2c, 0x1b, 0x62, 0x6c, 0xe5,
		0x78, 0x2c, 0x62, 0x2c, 0xa4, 0x35, 0x5f, 0xd2, 0x4a, 0xf7, 0x78, 0xe8, 0x2b, 0xf4, 0x15, 0xfa,
		0x2a, 0xbc, 0x67, 0x69, 0x59, 0x04, 0x85, 0x35, 0x87, 0xdf, 0x50, 0xd8, 0xe2, 0x50, 0x58, 0xa4,
		0x58, 0x58, 0x6d, 0xc1, 0x58, 0x2d, 0xdd, 0xe3, 0xe1, 0xb2, 0x70, 0x59, 0xb8, 0xac, 0xd0, 0x9e,
		0x45, 0x8a, 0x85, 0xc7, 0x2e, 0x2c, 0x1b, 0x52, 0x6c, 0xe5, 0x78, 0x2c, 0x52, 0x2c, 0xa4, 0x35,
		0x5f, 0xd2, 0x4a, 0xf7, 0x78, 0xe8, 0x2b, 0xf4, 0x15, 0xfa, 0x2a, 0xbc, 0x67, 0x91, 0x62, 0xa1,
		0xb0, 0xe6, 0xf0, 0x1b, 0x0a, 0x5b, 0x1c, 0x0a, 0x8b, 0x14, 0x0b, 0xab, 0x15, 0x64, 0xb5, 0x74,
		0x8f, 0x57, 0x28, 0x28, 0x5f, 0x8c, 0xf6, 0xf1, 0x67, 0xfd, 0x84, 0xfe, 0xf1, 0x4f, 0x71, 0x22,
		0xba, 0x4b, 0xa9, 0x79, 0x3f, 0x94, 0x69, 0xa4, 0x4c, 0xa3, 0x7d, 0x9f, 0x86, 0xea, 0xdb, 0x85,
		0xf2, 0x53, 0xa8, 0xbe, 0x4d, 0xf5, 0x6d, 0xaa, 0x6f, 0x4b, 0x8a, 0x48, 0x74, 0x97, 0xb2, 0xe9,
		0x14, 0xd8, 0x75, 0x06, 0x68, 0x20, 0x6f, 0x71, 0xca, 0x2d, 0x74, 0x90, 0x3f, 0xeb, 0x27, 0xc6,
		0x5a, 0xc8, 0x3f, 0x13, 0x5c, 0x3a, 0xd5, 0x25, 0x33, 0xb2, 0x54, 0x19, 0xd6, 0x65, 0xf3, 0x7a,
		0xa4, 0x9b, 0xfe, 0xcd, 0x93, 0x99, 0x62, 0x22, 0x33, 0xb6, 0x5f, 0x53, 0x6a, 0xb7, 0x96, 0xb1,
		0xc4, 0x7f, 0xe6, 0x76, 0x6a, 0x2a, 0xbe, 0xa0, 0x80, 0xcf, 0xa7, 0xea, 0xdb, 0x69, 0xfb, 0x70,
		0xda, 0xbe, 0x9a, 0x8c, 0x4f, 0x26, 0x7b, 0x98, 0xb3, 0x96, 0xbc, 0x6f, 0x0c, 0x28, 0xcf, 0xbd,
		0xe7, 0x8c, 0x8f, 0x71, 0xc6, 0x25, 0x98, 0x96, 0xb2, 0x9f, 0x19, 0x24, 0xe3, 0x1c, 0xaa, 0x09,
		0x22, 0xca, 0x02, 0x88, 0x8e, 0xe0, 0x21, 0x28, 0x70, 0xe8, 0x0a, 0x1a, 0x62, 0x02, 0x86, 0x98,
		0x60, 0x21, 0x2b, 0x50, 0x98, 0x25, 0x29, 0xca, 0x82, 0xc3, 0x63, 0x11, 0xb1, 0x8e, 0x17, 0x26,
		0x7e, 0xf2, 0x33, 0xf2, 0x6e, 0x54, 0x56, 0x7f, 0x82, 0xe4, 0x0a, 0xd7, 0x22, 0x8d, 0x93, 0xf1,
		0xa3, 0x7f, 0x71, 0x63, 0x81, 0x7e, 0x9f, 0x47, 0xe7, 0x17, 0xd7, 0xe7, 0x47, 0x97, 0xff, 0xbc,
		0x50, 0xdd, 0x3f, 0x43, 0x67, 0x2c, 0xd6, 0x52, 0x1f, 0x84, 0xc4, 0xda, 0xf3, 0x4f, 0x27, 0x1f,
		0x8e, 0x3e, 0xfd, 0xde, 0xc8, 0x43, 0x85, 0x16, 0x7a, 0x85, 0x8b, 0xe3, 0x77, 0x67, 0x1f, 0x7f,
		0xd5, 0x7b, 0x89, 0x67, 0x76, 0xfc, 0xc2, 0x07, 0x53, 0xdc, 0x36, 0x03, 0x73, 0xb8, 0xe9, 0x46,
		0x6d, 0xcf, 0x49, 0xba, 0xce, 0x80, 0x3b, 0xaa, 0x5b, 0xaf, 0xf9, 0x61, 0x32, 0x62, 0xc9, 0xaf,
		0xde, 0x8d, 0xdb, 0x0f, 0x86, 0xa8, 0xf7, 0xf1, 0xec, 0xe3, 0x31, 0xe6, 0x0f, 0xf3, 0x57, 0x7d,
		0xf3, 0xe7, 0x85, 0xfd, 0x3b, 0x2f, 0x52, 0xbd, 0x10, 0x9b, 0x9a, 0xbf, 0x96, 0xc2, 0x67, 0x8f,
		0xc3, 0xfe, 0xdd, 0xe0, 0xcb, 0x17, 0x01, 0x7f, 0xbe, 0x77, 0x83, 0x8e, 0xd3, 0xbd, 0xb9, 0x51,
		0x8b, 0xc8, 0x9c, 0xce, 0xe6, 0xfc, 0x30, 0x00, 0x08, 0x00, 0x52, 0x79, 0x00, 0xe9, 0xfb, 0x61,
		0xb2, 0xdb, 0xd4, 0xc0, 0x8e, 0x03, 0x85, 0x8f, 0xea, 0xdd, 0x93, 0x69, 0xe8, 0xc8, 0x12, 0xf7,
		0x60, 0x52, 0x91, 0x03, 0x42, 0x97, 0x27, 0x92, 0x97, 0x25, 0x3a, 0xd1, 0x1f, 0x12, 0xf7, 0x56,
		0xd2, 0x53, 0xdb, 0x6a, 0x1e, 0xb6, 0x0e, 0xf7, 0x0f, 0x9a, 0x87, 0x7b, 0x05, 0x9a, 0x63, 0x4b,
		0xb7, 0x0b, 0x57, 0x05, 0x30, 0xcb, 0x63, 0x49, 0x58, 0xd1, 0x1a, 0x0f, 0x3f, 0x8d, 0x11, 0xc6,
		0x08, 0x57, 0xde, 0x08, 0x07, 0x9e, 0x7b, 0xa3, 0x29, 0x60, 0xa9, 0x98, 0xe1, 0xf3, 0xe9, 0x8d,
		0x51, 0xdb, 0xe9, 0x05, 0x6e, 0x72, 0xd3, 0x8d, 0xee, 0xde, 0xb6, 0xbb, 0x77, 0xbd, 0x6e, 0xe8,
		0x85, 0x49, 0xbc, 0xfa, 0xaf, 0xe7, 0xfe, 0x76, 0x78, 0x44, 0x0b, 0x00, 0x34, 0xbd, 0xc8, 0xbf,
		0x73, 0xa3, 0x9f, 0x4e, 0xfc, 0xa7, 0x9f, 0xb4, 0xbf, 0x3b, 0xdf, 0x7f, 0xc6, 0x89, 0x17, 0x79,
		0xb1, 0x1f, 0xab, 0xa3, 0xcf, 0xfa, 0x21, 0xd5, 0x75, 0x89, 0x6d, 0xe0, 0x0c, 0x38, 0xab, 0x3e,
		0x9c, 0xe9, 0x04, 0xfd, 0xe9, 0x04, 0xf9, 0x89, 0x04, 0xf5, 0x55, 0xc3, 0x39, 0x69, 0xe2, 0x9c,
		0x98, 0x72, 0x4e, 0x76, 0x2b, 0x38, 0xb5, 0x35, 0xf2, 0x49, 0x16, 0xec, 0x7a, 0xf2, 0x3d, 0xf2,
		0xe2, 0xef, 0xdd, 0xa0, 0x23, 0xc6, 0x14, 0x1e, 0x47, 0xc4, 0xd8, 0x63, 0xec, 0x31, 0xf6, 0x18,
		0x7b, 0x8c, 0x3d, 0xc6, 0x1e, 0x63, 0x9f, 0x87, 0xb1, 0x8f, 0xbc, 0xc0, 0x1d, 0x06, 0xc4, 0xc9,
		0x59, 0xfb, 0xf5, 0x43, 0xa2, 0x0b, 0x40, 0x15, 0xa0, 0x0a, 0x50, 0x05, 0xa8, 0x02, 0x54, 0x01,
		0xaa, 0x50, 0x19, 0xaa, 0xe0, 0x74, 0x6f, 0x6e, 0x62, 0x2f, 0x31, 0xc0, 0x18, 0x26, 0x23, 0x43,
		0x1c, 0x20, 0x0e, 0x10, 0x07, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0x00, 0x71, 0x28, 0x1f, 0x71, 0xb8,
		0xf7, 0xa2, 0x81, 0x7d, 0xd7, 0x61, 0x08, 0x93, 0x21, 0x30, 0xe7, 0x98, 0xf3, 0xca, 0x9b, 0xf3,
		0x6f, 0xdd, 0x6e, 0xe0, 0xb9, 0x5a, 0x09, 0x0b, 0x3b, 0x05, 0x38, 0xf8, 0x8f, 0x75, 0x0c, 0xe4,
		0xd4, 0xc5, 0x27, 0xc6, 0x04, 0x1a, 0x80, 0x06, 0x98, 0x3e, 0x4c, 0x1f, 0xa6, 0x0f, 0xd3, 0x87,
		0xe9, 0xe7, 0x61, 0xf0, 0xff, 0x74, 0xfd, 0xc4, 0x49, 0xba, 0x4e, 0xe4, 0xc5, 0x49, 0x37, 0xf2,
		0x34, 0x93, 0x0d, 0x57, 0x8e, 0x86, 0x91, 0xc7, 0xc8, 0x93, 0x73, 0xb8, 0x69, 0xbf, 0x93, 0x73,
		0x88, 0x6d, 0x26, 0xe7, 0xb0, 0x46, 0x46, 0xba, 0x8a, 0x65, 0xf6, 0x32, 0xd4, 0x9a, 0x4c, 0x51,
		0x19, 0xef, 0x99, 0xc6, 0xcc, 0x0c, 0xec, 0x61, 0xca, 0x84, 0xcb, 0xc6, 0xa9, 0x1f, 0x27, 0x47,
		0x49, 0x92, 0xae, 0xb6, 0xd9, 0x00, 0xfb, 0x8e, 0x03, 0x6f, 0x60, 0xd8, 0xe2, 0x74, 0x47, 0x6c,
		0x70, 0xa4, 0x67, 0x3e, 0xa1, 0xd6, 0xc0, 0xa2, 0x71, 0x16, 0x75, 0xbc, 0xc8, 0xeb, 0xfc, 0x32,
		0x78, 0xab, 0xb0, 0x1f, 0x04, 0x5a, 0x93, 0x93, 0x71, 0xbb, 0x08, 0x6f, 0x93, 0x46, 0xaa, 0x92,
		0x87, 0x6b, 0xeb, 0x2f, 0x3e, 0xbd, 0xbf, 0xd6, 0xef, 0x9a, 0xd5, 0xff, 0xb2, 0x66, 0xaa, 0xd2,
		0x4e, 0x91, 0xc4, 0xd4, 0xac, 0x7e, 0xa1, 0xe5, 0xaf, 0x3b, 0xff, 0x37, 0x0b, 0x5f, 0x7c, 0xd3,
		0x17, 0x56, 0xfd, 0xa2, 0x2b, 0x16, 0x6b, 0x79, 0x71, 0xe6, 0xdf, 0xe0, 0xf1, 0x7b, 0xce, 0x7c,
		0xc7, 0xc6, 0xb7, 0xdb, 0xde, 0xd2, 0x17, 0x7b, 0x94, 0x4f, 0x6f, 0x7b, 0x0b, 0x0f, 0x5a, 0x53,
		0x90, 0x72, 0x2d, 0xcf, 0x7f, 0x8a, 0xc7, 0xcf, 0xf2, 0xf4, 0xe5, 0x27, 0xa5, 0xa1, 0xdf, 0xa9,
		0xe9, 0x75, 0x6a, 0xfa, 0xbc, 0x48, 0x8f, 0x07, 0xdf, 0x2b, 0xe3, 0x8a, 0xaf, 0x2b, 0xc7, 0xd8,
		0xb8, 0x0d, 0xba, 0xdf, 0xdc, 0x60, 0xfd, 0xcb, 0x4c, 0xa6, 0x63, 0xfc, 0x73, 0x6b, 0xbe, 0xe0,
		0xd3, 0x15, 0x41, 0x37, 0x3a, 0x5c, 0x69, 0x1c, 0xab, 0xcd, 0x0b, 0x93, 0xd5, 0x3f, 0xca, 0xec,
		0x07, 0x65, 0xf6, 0x77, 0x52, 0x2d, 0x9c, 0x1a, 0xe6, 0x6c, 0xaa, 0xaf, 0xd9, 0x70, 0x6f, 0x7c,
		0x27, 0x76, 0x6f, 0x52, 0xe4, 0x00, 0x3f, 0x56, 0xcf, 0x9c, 0x7e, 0x64, 0x93, 0xc1, 0x4c, 0x55,
		0x00, 0x36, 0xb5, 0x9f, 0x9d, 0xc5, 0xaf, 0x4e, 0xbf, 0x0d, 0x54, 0xdd, 0x65, 0x65, 0xf7, 0x58,
		0xd9, 0x1d, 0xce, 0xb4, 0x4d, 0x64, 0x28, 0x4f, 0xda, 0xf2, 0xac, 0xd3, 0x3d, 0x91, 0xbd, 0xa4,
		0xf0, 0xf4, 0x93, 0x86, 0xab, 0x0a, 0x6f, 0xdb, 0xa9, 0x2a, 0x9c, 0x6e, 0xb3, 0xe9, 0x6a, 0x34,
		0xc5, 0x2b, 0x26, 0x9c, 0x6a, 0x33, 0x9a, 0xf1, 0x54, 0xb2, 0xd7, 0x10, 0xee, 0x74, 0x86, 0xb5,
		0x7f, 0x35, 0xea, 0x1e, 0x3c, 0x0e, 0xa1, 0xa6, 0x45, 0xee, 0x94, 0x4c, 0x8b, 0xcc, 0xb6, 0xad,
		0xeb, 0x23, 0x41, 0x66, 0xda, 0xf6, 0x76, 0x94, 0xc7, 0xac, 0xc7, 0x61, 0xfa, 0xc1, 0xf6, 0x64,
		0x8f, 0x69, 0xd6, 0xe8, 0x1d, 0x8f, 0xa3, 0x38, 0xc1, 0x6a, 0x07, 0x44, 0xfb, 0xa0, 0x48, 0x1c,
		0x18, 0xb9, 0x83, 0x23, 0x75, 0x80, 0xc4, 0x0f, 0x92, 0xf8, 0x81, 0x12, 0x3d, 0x58, 0x9a, 0x4a,
		0x9e, 0xe2, 0x8e, 0x51, 0x3d, 0x70, 0xd3, 0x01, 0xbc, 0xc0, 0xbf, 0xf5, 0xbf, 0x05, 0x03, 0x3f,
		0x79, 0xb0, 0x34, 0x4e, 0xaf, 0x1b, 0xf8, 0xed, 0x9f, 0x72, 0x6d, 0x01, 0xd7, 0x8c, 0x4f, 0x6b,
		0x40, 0xf3, 0x07, 0x58, 0xfa, 0x20, 0x1b, 0x3b, 0xd0, 0xc6, 0x0e, 0xb6, 0x91, 0x03, 0xae, 0x77,
		0xd0, 0x35, 0x0f, 0xfc, 0xf4, 0x8d, 0xe4, 0x1b, 0x01, 0xaa, 0x97, 0x38, 0x5b, 0x6b, 0x47, 0x0f,
		0x04, 0xc6, 0x9a, 0x2d, 0x81, 0x16, 0xf5, 0xba, 0xc1, 0xdb, 0xa8, 0xdb, 0x4f, 0xfc, 0xf0, 0x76,
		0x8c, 0x24, 0xd3, 0xbf, 0x1e, 0xfd, 0xd1, 0xe9, 0x78, 0x37, 0x7e, 0xe8, 0x27, 0x7e, 0x37, 0x8c,
		0xd7, 0xff, 0xd3, 0xf4, 0x5f, 0xb2, 0x57, 0x47, 0x93, 0xdb, 0x05, 0x3a, 0xd7, 0x6a, 0x91, 0xd7,
		0xf6, 0x54, 0xe2, 0x99, 0xd7, 0x2e, 0xfe, 0x64, 0x40, 0xcd, 0x5d, 0x39, 0x93, 0xf8, 0x74, 0xe3,
		0x06, 0xb1, 0x07, 0xce, 0x83, 0xf3, 0xe0, 0x7c, 0xb1, 0x70, 0x5e, 0x3d, 0xb6, 0x7b, 0x2d, 0xce,
		0xef, 0x94, 0x10, 0x42, 0x63, 0x2f, 0xec, 0xc8, 0xe1, 0xe7, 0x70, 0x34, 0xc0, 0x13, 0xf0, 0x04,
		0x3c, 0x01, 0xcf, 0x7a, 0x80, 0xa7, 0x73, 0x27, 0x11, 0xdb, 0x35, 0x0b, 0xa0, 0xc3, 0x11, 0x01,
		0x3d, 0x40, 0x0f, 0xd0, 0x2b, 0x14, 0xe8, 0xf5, 0xfd, 0x30, 0x79, 0x23, 0x08, 0x79, 0x7b, 0x34,
		0xf2, 0xcf, 0x05, 0xd5, 0x96, 0x86, 0xa5, 0x91, 0x7f, 0xe9, 0x96, 0xaa, 0xb9, 0xb7, 0x47, 0x2b,
		0xff, 0xac, 0xbf, 0x68, 0xe5, 0x9f, 0x89, 0xdc, 0xad, 0x0d, 0xad, 0xfc, 0x76, 0xdb, 0x7b, 0x3d,
		0xf8, 0xff, 0x51, 0xa4, 0xdd, 0xeb, 0x69, 0x30, 0xd6, 0xf4, 0x77, 0xaf, 0xa7, 0xb1, 0x09, 0xaf,
		0xc7, 0x37, 0xb1, 0xb6, 0x3a, 0xf5, 0x2b, 0x35, 0xa9, 0xcf, 0xd2, 0x87, 0x7c, 0x3d, 0x73, 0xcd,
		0xd0, 0x97, 0x7c, 0xad, 0x13, 0xa0, 0x7b, 0xe3, 0xdc, 0xe4, 0xc6, 0xd9, 0x20, 0x0d, 0xe5, 0xc6,
		0x79, 0x46, 0xa5, 0xe2, 0xc6, 0x19, 0xbf, 0x12, 0xbf, 0x12, 0xbf, 0x52, 0x7f, 0xbf, 0x71, 0xe3,
		0x5c, 0x1e, 0xc5, 0x8f, 0x1b, 0x67, 0x70, 0x1e, 0x9c, 0x07, 0xe7, 0x55, 0xf6, 0x1b, 0x97, 0x26,
		0x5b, 0xdc, 0x38, 0x03, 0x9e, 0x80, 0x27, 0xe0, 0x09, 0x78, 0x6a, 0x80, 0x27, 0x37, 0xce, 0x80,
		0x1e, 0xa0, 0x57, 0x07, 0xd0, 0xe3, 0xc6, 0x39, 0xc3, 0x17, 0xe3, 0xc6, 0x99, 0x1b, 0x67, 0x6e,
		0x9c, 0x25, 0x80, 0x50, 0x6e, 0x14, 0x6e, 0x9c, 0x33, 0x91, 0x3b, 0x91, 0x1b, 0xe7, 0x0c, 0xe5,
		0xba, 0xf4, 0xa7, 0xcd, 0x6c, 0x1e, 0xb5, 0xe6, 0xc4, 0xca, 0x4c, 0x68, 0x43, 0xe9, 0x4e, 0x7d,
		0xb6, 0x96, 0xd2, 0x2f, 0xb7, 0xbd, 0xeb, 0xdf, 0x86, 0x0f, 0xba, 0x3e, 0xba, 0xf1, 0x2f, 0xdc,
		0x1b, 0xff, 0xfa, 0xa8, 0xd3, 0x39, 0x1f, 0x0e, 0x5e, 0x80, 0x6a, 0xb1, 0x93, 0x57, 0x76, 0xc6,
		0xdf, 0x57, 0xb5, 0x1e, 0xc3, 0xdc, 0x30, 0xf5, 0xa8, 0x0f, 0x4b, 0x4d, 0x06, 0x41, 0x36, 0x5f,
		0xf4, 0x6a, 0xb0, 0xea, 0xf7, 0x74, 0x3a, 0xf7, 0x72, 0xd3, 0x7b, 0xb8, 0x57, 0xaf, 0x46, 0xd0,
		0xfe, 0x7a, 0xfe, 0xa0, 0x15, 0x00, 0x40, 0x14, 0xab, 0x56, 0xe8, 0x55, 0xab, 0xa0, 0x8c, 0x0b,
		0x90, 0x51, 0xd4, 0x32, 0x2e, 0x7a, 0x16, 0x55, 0xd4, 0xb2, 0x0a, 0xb9, 0x47, 0x14, 0x75, 0xb1,
		0xa3, 0xbb, 0x11, 0x62, 0x27, 0xa8, 0xa7, 0x4d, 0xf7, 0x8b, 0xdf, 0xf1, 0xc2, 0xc4, 0x4f, 0x7e,
		0xea, 0x45, 0xd9, 0x4c, 0x2d, 0x8e, 0x86, 0x10, 0xd0, 0x38, 0x19, 0x7f, 0x95, 0x5f, 0xdc, 0x58,
		0x30, 0x8a, 0xe4, 0xe8, 0xfd, 0xc9, 0xf5, 0xc5, 0xe0, 0x7f, 0x2e, 0x7f, 0x3f, 0x3f, 0x6e, 0x48,
		0x14, 0x08, 0x8f, 0x45, 0x24, 0x3e, 0x21, 0x75, 0x7b, 0xf2, 0x9a, 0xa7, 0xbb, 0x5f, 0xce, 0x3f,
		0x5e, 0x9f, 0x9c, 0x7f, 0x69, 0x5d, 0x7f, 0xfe, 0x78, 0xf2, 0xee, 0xe8, 0xe2, 0x52, 0x40, 0x33,
		0x7e, 0x59, 0xb8, 0xb7, 0x3c, 0xf9, 0xf8, 0xaf, 0x8b, 0xcb, 0xa3, 0xcb, 0xe3, 0x2a, 0xbe, 0xdc,
		0x70, 0xf1, 0x4e, 0x8f, 0x7e, 0x39, 0x3e, 0x3d, 0xfe, 0xb5, 0xd2, 0x8b, 0xd8, 0x1c, 0x6c, 0xd5,
		0x2f, 0xe7, 0xa7, 0x17, 0x95, 0xde, 0xa2, 0xd7, 0x17, 0xe7, 0xef, 0x2b, 0xf9, 0x82, 0x13, 0xa4,
		0xd9, 0xaf, 0xf2, 0x26, 0x1d, 0xbe, 0x5f, 0x6d, 0x0e, 0xe3, 0xf1, 0x97, 0xf3, 0x8f, 0x95, 0x5d,
		0xc5, 0x0a, 0xaf, 0xde, 0xc5, 0xa7, 0xcb, 0xe3, 0xeb, 0xf3, 0xb3, 0xd3, 0x93, 0x77, 0xbf, 0x0f,
		0x6d, 0x7f, 0xa5, 0xf1, 0xa6, 0x75, 0xfd, 0xe1, 0xf3, 0xe9, 0x65, 0x95, 0x11, 0xa7, 0x75, 0xfd,
		0xfe, 0xf4, 0xec, 0xdf, 0x17, 0xe7, 0xc7, 0xef, 0xaa, 0x6d, 0x19, 0x2b, 0x8a, 0x36, 0x5f, 0xce,
		0x3f, 0x56, 0x7c, 0x09, 0x17, 0xf0, 0x66, 0xbf, 0xb2, 0xe7, 0xb0, 0xca, 0x16, 0xff, 0x91, 0xbf,
		0x49, 0xe2, 0xa9, 0xd6, 0x08, 0x57, 0x85, 0x6f, 0x8b, 0xa5, 0x92, 0x3e, 0xec, 0x85, 0xee, 0xb7,
		0xc0, 0xeb, 0xe8, 0xab, 0x9c, 0x93, 0x81, 0x54, 0x13, 0x32, 0x65, 0x82, 0xb8, 0xd1, 0x49, 0xe7,
		0x46, 0x42, 0x27, 0xb5, 0x78, 0x5e, 0x73, 0xd7, 0x49, 0xf5, 0x83, 0xac, 0x35, 0x83, 0xab, 0x09,
		0x40, 0x79, 0x0c, 0x40, 0x51, 0xa9, 0x1c, 0x61, 0xe6, 0x7e, 0xf7, 0x36, 0x72, 0xdb, 0xde, 0x4d,
		0x3f, 0x18, 0x76, 0x00, 0x76, 0xa3, 0x44, 0xfd, 0xa6, 0x77, 0x69, 0x24, 0xee, 0x7c, 0xcd, 0x81,
		0x2f, 0x77, 0xbe, 0xb4, 0xee, 0x80, 0xbd, 0xc0, 0x5e, 0x8a, 0xcd, 0x5e, 0xf4, 0x0b, 0xa9, 0x68,
		0x3a, 0x20, 0xc2, 0x8e, 0x88, 0xb4, 0x43, 0x22, 0xe4, 0x98, 0x88, 0x1d, 0x71, 0xc9, 0xa3, 0x2e,
		0x7f, 0xe4, 0xa5, 0x8f, 0xbe, 0x31, 0x08, 0x30, 0x06, 0x05, 0x46, 0x20, 0x41, 0x46, 0x00, 0x21,
		0xab, 0xd4, 0xe0, 0x04, 0xd7, 0x2f, 0xe5, 0x61, 0xd1, 0x99, 0xa0, 0xd6, 0x9e, 0x55, 0x8a, 0x48,
		0xad, 0x3d, 0x28, 0x22, 0x14, 0x11, 0x8a, 0x08, 0x45, 0x84, 0x22, 0x42, 0x11, 0xa1, 0x88, 0xa5,
		0xa0, 0x88, 0x24, 0xc7, 0x1a, 0x99, 0x57, 0x23, 0x39, 0xb2, 0xbf, 0x8d, 0x1f, 0xf2, 0x69, 0xfc,
		0x8c, 0x02, 0xdc, 0x84, 0xf8, 0xbd, 0xfb, 0x96, 0x13, 0xb8, 0xdf, 0xbc, 0xc0, 0xeb, 0x38, 0xfd,
		0xd0, 0x6f, 0xbb, 0xb1, 0xc6, 0x6d, 0xc8, 0xca, 0xd1, 0xb8, 0x11, 0x31, 0x67, 0xb2, 0xb9, 0x11,
		0xb1, 0x79, 0x23, 0x32, 0x2e, 0x3c, 0x1d, 0xf8, 0x77, 0x7e, 0xa2, 0xef, 0xf3, 0xce, 0x8d, 0xc6,
		0xed, 0x08, 0xae, 0x2f, 0xae, 0x6f, 0x9a, 0x01, 0x34, 0xaf, 0x25, 0x97, 0xb6, 0x9d, 0xd6, 0xf5,
		0xa4, 0xd0, 0x41, 0xc4, 0x51, 0xc5, 0x51, 0x2d, 0xbb, 0xa3, 0xaa, 0x7b, 0xb0, 0xa7, 0x03, 0xdd,
		0xb9, 0x3f, 0xc6, 0x2d, 0x1e, 0x86, 0x39, 0x9b, 0xc2, 0x71, 0xb4, 0x73, 0xa3, 0x0b, 0x2d, 0xa6,
		0x6c, 0xa1, 0x2e, 0x31, 0x10, 0x30, 0x01, 0x06, 0xe6, 0x40, 0xc1, 0x14, 0x38, 0x18, 0x07, 0x09,
		0xe3, 0x60, 0x61, 0x14, 0x34, 0x64, 0xc0, 0x43, 0x08, 0x44, 0xe4, 0x55, 0xaf, 0xa5, 0xfd, 0xda,
		0xf7, 0xc3, 0x64, 0xb7, 0x29, 0xb9, 0x5f, 0xc7, 0xa7, 0xff, 0x40, 0x70, 0x48, 0xd9, 0x92, 0x94,
		0x93, 0x5f, 0xb2, 0xe7, 0x69, 0xcb, 0x54, 0x89, 0x4a, 0x43, 0xb0, 0xba, 0x34, 0xbc, 0xa1, 0x92,
		0x95, 0xd3, 0xf1, 0x0d, 0x56, 0x43, 0x14, 0x3e, 0x6e, 0xf3, 0x4b, 0x6a, 0xa0, 0x94, 0xa5, 0xed,
		0x25, 0x6d, 0x35, 0x0f, 0x5b, 0x87, 0xfb, 0x07, 0xcd, 0xc3, 0xbd, 0x12, 0xaf, 0xed, 0xb3, 0x62,
		0x8e, 0x76, 0x55, 0x90, 0x4a, 0x9c, 0x02, 0x7b, 0x7f, 0xc0, 0x03, 0xee, 0xbd, 0x30, 0x71, 0x12,
		0xcf, 0x8d, 0x3a, 0xdd, 0x3f, 0x43, 0x79, 0xba, 0xb9, 0xf4, 0x04, 0x21, 0x03, 0x29, 0x7c, 0xd1,
		0x0a, 0x95, 0x85, 0xca, 0x42, 0x65, 0x4b, 0x46, 0x65, 0xe5, 0x2e, 0x72, 0x97, 0x64, 0xac, 0x9d,
		0x0a, 0x81, 0xfc, 0xf8, 0x46, 0xcf, 0x49, 0xfc, 0x3b, 0x2f, 0x92, 0x47, 0xf8, 0xf9, 0xe1, 0x81,
		0x61, 0x60, 0x18, 0x18, 0xae, 0x15, 0x0c, 0x77, 0xbc, 0xb6, 0x7f, 0xe7, 0x06, 0xfb, 0x2d, 0x13,
		0x40, 0xdc, 0x14, 0x1c, 0x73, 0xc9, 0x69, 0x69, 0x22, 0x59, 0x98, 0xf1, 0x6f, 0x9b, 0x48, 0x16,
		0x55, 0x93, 0x2c, 0x76, 0x59, 0x52, 0x94, 0x8a, 0xfc, 0x48, 0xec, 0x9f, 0x6e, 0x14, 0xfa, 0xe1,
		0xad, 0x93, 0x7c, 0x8f, 0xbc, 0xf8, 0x7b, 0x37, 0xe8, 0x38, 0xbd, 0x76, 0x22, 0x4f, 0x66, 0x57,
		0x3f, 0x06, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xd6, 0x8a, 0xd4, 0xf6, 0xbc, 0xa8, 0xed, 0x85, 0x89,
		0x7b, 0xeb, 0x19, 0x60, 0xb5, 0x7b, 0xf0, 0x4e, 0x33, 0x24, 0x85, 0xab, 0xb2, 0xca, 0xf1, 0x4e,
		0xd3, 0x4b, 0xba, 0xb3, 0x0d, 0xf3, 0xac, 0x2e, 0xf3, 0xcc, 0x35, 0x22, 0x4c, 0x28, 0x5f, 0x66,
		0x3a, 0x9e, 0x4e, 0x7e, 0xc7, 0xaa, 0xcc, 0x84, 0xd7, 0xb3, 0x11, 0xd8, 0x5a, 0xb9, 0xd6, 0xfa,
		0xf3, 0xad, 0xd5, 0x42, 0x59, 0x2b, 0x07, 0x7b, 0xc9, 0xf4, 0xeb, 0xe4, 0x62, 0x2f, 0xe9, 0x57,
		0x52, 0xf1, 0xb0, 0x4d, 0xe2, 0x61, 0x0b, 0xc0, 0xe1, 0x89, 0x87, 0x4d, 0xff, 0x46, 0xc4, 0xc3,
		0xe2, 0xe8, 0xe3, 0xe8, 0xe3, 0xe8, 0x17, 0xdc, 0xd1, 0x27, 0x1e, 0x16, 0x27, 0x1f, 0x27, 0xbf,
		0xe2, 0x4e, 0x3e, 0xf1, 0xb0, 0x35, 0xf0, 0xf5, 0x89, 0x87, 0x25, 0x1e, 0x16, 0x2a, 0x0b, 0x95,
		0xad, 0x2d, 0x95, 0x25, 0x1e, 0x36, 0xd5, 0x3b, 0x11, 0x0f, 0x0b, 0x0c, 0x03, 0xc3, 0xc0, 0x30,
		0xf1, 0xb0, 0xc4, 0xc3, 0x12, 0x0f, 0x8b, 0x64, 0xa1, 0xb6, 0xa4, 0xc4, 0xc3, 0xa2, 0x54, 0xe4,
		0x48, 0x62, 0x89, 0x87, 0x85, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0xb6, 0x48, 0x2d, 0xf1, 0xb0, 0x65,
		0xe4, 0x9d, 0x5c, 0x95, 0x55, 0x8e, 0x77, 0x12, 0x0f, 0x0b, 0xf3, 0xcc, 0x69, 0x84, 0x7a, 0xc5,
		0xc3, 0x6a, 0x14, 0x96, 0xd7, 0x9f, 0xee, 0xfa, 0x15, 0xf6, 0xdf, 0xb8, 0x20, 0x0d, 0xad, 0x08,
		0xe1, 0x0d, 0x95, 0xe9, 0x4f, 0x7a, 0xf7, 0xad, 0xd3, 0xd1, 0xc3, 0x3f, 0x8f, 0x9e, 0x7d, 0x3d,
		0x62, 0xff, 0xa7, 0xc3, 0x47, 0xd3, 0x5e, 0xc0, 0xc0, 0xea, 0x1a, 0x69, 0x31, 0xb0, 0xbc, 0x90,
		0x85, 0xe9, 0x32, 0x20, 0xd3, 0x5d, 0x80, 0xae, 0x02, 0xe6, 0x7d, 0x61, 0xba, 0x0a, 0xd0, 0x67,
		0xd9, 0xb2, 0xf8, 0x44, 0x27, 0x81, 0x7c, 0xc4, 0xa2, 0x3a, 0x77, 0x12, 0x88, 0xbd, 0xb0, 0xe3,
		0x74, 0x46, 0x81, 0x63, 0x4e, 0xd4, 0xed, 0x8b, 0x26, 0x51, 0x2d, 0x8f, 0x4d, 0x6b, 0x3d, 0xd3,
		0x00, 0x20, 0x0f, 0x04, 0xd2, 0x80, 0x60, 0x0c, 0x18, 0x8c, 0x01, 0x84, 0x11, 0xa0, 0x28, 0x86,
		0x3f, 0x4e, 0x6b, 0x3d, 0x3c, 0xf0, 0x45, 0x1f, 0x6d, 0xe2, 0x79, 0x17, 0xbf, 0xf3, 0x32, 0xcd,
		0xa8, 0xa0, 0x90, 0x50, 0xc8, 0x9c, 0x29, 0x24, 0xcd, 0xa8, 0xa0, 0x76, 0x50, 0xbb, 0xe2, 0x51,
		0x3b, 0x92, 0xef, 0x89, 0x2a, 0x12, 0x19, 0x99, 0xa8, 0x22, 0x9b, 0xa0, 0x21, 0x03, 0x1e, 0x42,
		0x20, 0x22, 0xef, 0x27, 0x2e, 0xed, 0x57, 0x92, 0xef, 0x25, 0x77, 0x24, 0x11, 0x45, 0xeb, 0xc7,
		0x27, 0xa2, 0x28, 0xb7, 0x25, 0x25, 0xf9, 0xde, 0xdc, 0x68, 0x24, 0xdf, 0x67, 0x14, 0x79, 0x48,
		0xbe, 0x87, 0xca, 0x42, 0x65, 0xa1, 0xb2, 0xe2, 0xfb, 0x95, 0xe4, 0xfb, 0x54, 0xef, 0x44, 0xf2,
		0x3d, 0x30, 0x0c, 0x0c, 0x03, 0xc3, 0x24, 0xdf, 0x93, 0x7c, 0x4f, 0xf2, 0x3d, 0x92, 0x85, 0xda,
		0x92, 0x92, 0x7c, 0x8f, 0x52, 0x91, 0x23, 0x89, 0x25, 0xf9, 0x1e, 0x52, 0x0b, 0xa9, 0x85, 0xd4,
		0xda, 0x22, 0xb5, 0x24, 0xdf, 0x97, 0x91, 0x77, 0x72, 0x55, 0x56, 0x39, 0xde, 0x49, 0xf2, 0x3d,
		0xcc, 0x33, 0xa7, 0x11, 0x2a, 0x97, 0x7c, 0x4f, 0x13, 0xaa, 0xa7, 0x4c, 0x3e, 0x4d, 0xa8, 0x6c,
		0x73, 0x79, 0xe2, 0x60, 0x89, 0x83, 0x5d, 0x3f, 0x10, 0x71, 0xb0, 0x38, 0xf8, 0x38, 0xf8, 0x38,
		0xf8, 0xc4, 0xc1, 0xe2, 0xdc, 0xe3, 0xdc, 0xe3, 0xdc, 0x2b, 0x2c, 0x29, 0x71, 0xb0, 0x35, 0xf0,
		0xf1, 0x89, 0x83, 0x25, 0x0e, 0x16, 0x2a, 0x0b, 0x95, 0xad, 0x2d, 0x95, 0x25, 0x0e, 0x36, 0xd5,
		0x3b, 0x11, 0x07, 0x0b, 0x0c, 0x03, 0xc3, 0xc0, 0x30, 0x71, 0xb0, 0xc4, 0xc1, 0x12, 0x07, 0x8b,
		0x64, 0xa1, 0xb6, 0xa4, 0xc4, 0xc1, 0xa2, 0x54, 0xe4, 0x48, 0x62, 0x89, 0x83, 0x85, 0xd4, 0x42,
		0x6a, 0x21, 0xb5, 0xb6, 0x48, 0x2d, 0x71, 0xb0, 0x65, 0xe4, 0x9d, 0x5c, 0x95, 0x55, 0x8e, 0x77,
		0x12, 0x07, 0x0b, 0xf3, 0xcc, 0x69, 0x84, 0x7a, 0xc4, 0xc1, 0xd2, 0x7c, 0xaa, 0x18, 0x0b, 0x61,
		0xbc, 0xe9, 0x54, 0x9e, 0xdd, 0xa6, 0x94, 0xfa, 0x2f, 0xe9, 0x44, 0x39, 0x8b, 0x44, 0x37, 0x8b,
		0x95, 0xd9, 0x6e, 0x52, 0x66, 0xdb, 0xa0, 0x87, 0x45, 0x99, 0xed, 0xc7, 0x6f, 0x4e, 0xa7, 0x96,
		0x02, 0x90, 0x4e, 0xca, 0x79, 0x17, 0x4b, 0x7a, 0x21, 0x8d, 0x21, 0x07, 0x49, 0x85, 0x4e, 0x2d,
		0x95, 0xa3, 0xab, 0x1a, 0xae, 0x02, 0x1d, 0x4a, 0x57, 0xcf, 0xa9, 0xb1, 0xce, 0xa4, 0xc5, 0x6a,
		0x49, 0xba, 0xbf, 0xd4, 0x91, 0x55, 0xa7, 0x35, 0xe9, 0xbe, 0x66, 0x7f, 0x57, 0x5a, 0x94, 0xe6,
		0x62, 0x96, 0x69, 0x51, 0x9a, 0xe2, 0x83, 0xf4, 0x9a, 0xc2, 0x09, 0xc6, 0x09, 0xce, 0xd9, 0x09,
		0xa6, 0xd7, 0x14, 0xce, 0x29, 0xce, 0x69, 0xf1, 0x9c, 0x53, 0x72, 0xec, 0x09, 0x1e, 0x12, 0x19,
		0x99, 0xe0, 0x21, 0x9b, 0xa0, 0x21, 0x03, 0x1e, 0x42, 0x20, 0x22, 0xaf, 0x74, 0x2d, 0xed, 0x57,
		0x72, 0xec, 0x25, 0x77, 0x24, 0x81, 0x43, 0xeb, 0xc7, 0x27, 0x70, 0x28, 0xb7, 0x25, 0x25, 0xc7,
		0xde, 0xdc, 0x68, 0xe4, 0xd8, 0x67, 0x14, 0x79, 0xc8, 0xb1, 0x87, 0xca, 0x42, 0x65, 0xa1, 0xb2,
		0xe2, 0xfb, 0x95, 0x1c, 0xfb, 0x54, 0xef, 0x44, 0x8e, 0x3d, 0x30, 0x0c, 0x0c, 0x03, 0xc3, 0xe4,
		0xd8, 0x93, 0x63, 0x4f, 0x8e, 0x3d, 0x92, 0x85, 0xda, 0x92, 0x92, 0x63, 0x8f, 0x52, 0x91, 0x23,
		0x89, 0x25, 0xc7, 0x1e, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xda, 0x22, 0xb5, 0xe4, 0xd8, 0x97, 0x91,
		0x77, 0x72, 0x55, 0x56, 0x39, 0xde, 0x49, 0x8e, 0x3d, 0xcc, 0x33, 0xa7, 0x11, 0x2a, 0x96, 0x63,
		0xbf, 0x94, 0x99, 0x40, 0xcf, 0xa9, 0x95, 0xa6, 0x9f, 0x9e, 0x53, 0xb6, 0x39, 0x3d, 0xf1, 0xb0,
		0xc4, 0xc3, 0xae, 0x1f, 0x88, 0x78, 0x58, 0x1c, 0x7d, 0x1c, 0x7d, 0x1c, 0x7d, 0xe2, 0x61, 0x71,
		0xf2, 0x71, 0xf2, 0x71, 0xf2, 0x15, 0x96, 0x94, 0x78, 0xd8, 0x1a, 0xf8, 0xfa, 0xc4, 0xc3, 0x12,
		0x0f, 0x0b, 0x95, 0x85, 0xca, 0xd6, 0x96, 0xca, 0x12, 0x0f, 0x9b, 0xea, 0x9d, 0x88, 0x87, 0x05,
		0x86, 0x81, 0x61, 0x60, 0x98, 0x78, 0x58, 0xe2, 0x61, 0x89, 0x87, 0x45, 0xb2, 0x50, 0x5b, 0x52,
		0xe2, 0x61, 0x51, 0x2a, 0x72, 0x24, 0xb1, 0xc4, 0xc3, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x5b,
		0xa4, 0x96, 0x78, 0xd8, 0x32, 0xf2, 0x4e, 0xae, 0xca, 0x2a, 0xc7, 0x3b, 0x89, 0x87, 0x85, 0x79,
		0xe6, 0x34, 0x42, 0xbd, 0xe2, 0x61, 0xe9, 0x3d, 0x55, 0xac, 0x05, 0x31, 0xdd, 0x83, 0x6a, 0xff,
		0x74, 0xf4, 0xf0, 0x3c, 0x5b, 0x51, 0x55, 0xb9, 0xad, 0x80, 0x6e, 0x61, 0x7c, 0xd5, 0x85, 0x2c,
		0x4c, 0x97, 0x01, 0x99, 0xee, 0x02, 0x74, 0x15, 0x30, 0xef, 0x0b, 0xd3, 0x55, 0xc0, 0x66, 0x57,
		0x01, 0xcd, 0x82, 0xe6, 0x32, 0x85, 0xcc, 0xe9, 0x24, 0x60, 0x42, 0x4c, 0xa2, 0x93, 0x80, 0x41,
		0xd6, 0x46, 0x3b, 0xbd, 0x02, 0xf8, 0xd3, 0x74, 0x2c, 0x28, 0x06, 0x30, 0x18, 0x03, 0x08, 0x23,
		0x40, 0x51, 0x0c, 0x7f, 0x9c, 0x76, 0x7a, 0x78, 0xe0, 0x8b, 0x3e, 0xda, 0xc4, 0xf3, 0xd6, 0xc9,
		0x06, 0xb6, 0xd3, 0x83, 0x99, 0x66, 0x54, 0x50, 0x48, 0x28, 0x64, 0xce, 0x14, 0x92, 0x66, 0x54,
		0x50, 0x3b, 0xa8, 0x5d, 0xf1, 0xa8, 0x1d, 0xc9, 0xf7, 0x44, 0x15, 0x89, 0x8c, 0x4c, 0x54, 0x91,
		0x4d, 0xd0, 0x90, 0x01, 0x0f, 0x21, 0x10, 0x91, 0xf7, 0x13, 0x97, 0xf6, 0x2b, 0xc9, 0xf7, 0x92,
		0x3b, 0x92, 0x88, 0xa2, 0xf5, 0xe3, 0x13, 0x51, 0x94, 0xdb, 0x92, 0x92, 0x7c, 0x6f, 0x6e, 0x34,
		0x92, 0xef, 0x33, 0x8a, 0x3c, 0x24, 0xdf, 0x43, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0xf1, 0xfd, 0x4a,
		0xf2, 0x7d, 0xaa, 0x77, 0x22, 0xf9, 0x1e, 0x18, 0x06, 0x86, 0x81, 0x61, 0x92, 0xef, 0x49, 0xbe,
		0x27, 0xf9, 0x1e, 0xc9, 0x42, 0x6d, 0x49, 0x49, 0xbe, 0x47, 0xa9, 0xc8, 0x91, 0xc4, 0x92, 0x7c,
		0x0f, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x6d, 0x91, 0x5a, 0x92, 0xef, 0xcb, 0xc8, 0x3b, 0xb9, 0x2a,
		0xab, 0x1c, 0xef, 0x24, 0xf9, 0x1e, 0xe6, 0x99, 0xd3, 0x08, 0x95, 0x4b, 0xbe, 0xa7, 0x09, 0xd5,
		0x53, 0x26, 0x9f, 0x26, 0x54, 0xb6, 0xb9, 0x3c, 0x71, 0xb0, 0xc4, 0xc1, 0xae, 0x1f, 0x88, 0x38,
		0x58, 0x1c, 0x7c, 0x1c, 0x7c, 0x1c, 0x7c, 0xe2, 0x60, 0x71, 0xee, 0x71, 0xee, 0x71, 0xee, 0x15,
		0x96, 0x94, 0x38, 0xd8, 0x1a, 0xf8, 0xf8, 0xc4, 0xc1, 0x12, 0x07, 0x0b, 0x95, 0x85, 0xca, 0xd6,
		0x96, 0xca, 0x12, 0x07, 0x9b, 0xea, 0x9d, 0x88, 0x83, 0x05, 0x86, 0x81, 0x61, 0x60, 0x98, 0x38,
		0x58, 0xe2, 0x60, 0x89, 0x83, 0x45, 0xb2, 0x50, 0x5b, 0x52, 0xe2, 0x60, 0x51, 0x2a, 0x72, 0x24,
		0xb1, 0xc4, 0xc1, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x5b, 0xa4, 0x96, 0x38, 0xd8, 0x32, 0xf2,
		0x4e, 0xae, 0xca, 0x2a, 0xc7, 0x3b, 0x89, 0x83, 0x85, 0x79, 0xe6, 0x34, 0x42, 0x3d, 0xe2, 0x60,
		0x69, 0x3e, 0x55, 0x8c, 0x85, 0x30, 0xde, 0x74, 0x2a, 0xcf, 0x6e, 0x53, 0x4a, 0xfd, 0x97, 0x74,
		0xa2, 0x9c, 0x45, 0xa2, 0x9b, 0xc5, 0xca, 0x6c, 0x37, 0x29, 0xb3, 0x6d, 0xd0, 0xc3, 0xa2, 0xcc,
		0xf6, 0xe3, 0x37, 0xa7, 0x53, 0x4b, 0x01, 0x48, 0x27, 0xe5, 0xbc, 0x8b, 0x25, 0xbd, 0x90, 0xc6,
		0x90, 0x83, 0xa4, 0x42, 0xa7, 0x96, 0xca, 0xd1, 0x55, 0x0d, 0x57, 0x81, 0x0e, 0xa5, 0xab, 0xe7,
		0xd4, 0x58, 0x67, 0xd2, 0x02, 0xb5, 0x24, 0x0d, 0x9a, 0xf7, 0xbd, 0xd0, 0xf1, 0xee, 0x7b, 0xa1,
		0x7a, 0x43, 0xd2, 0x99, 0x31, 0x68, 0x47, 0x6a, 0xce, 0x24, 0xd3, 0x8e, 0xd4, 0x66, 0x3b, 0x52,
		0xfa, 0x4a, 0xe1, 0xf0, 0xe2, 0xf0, 0xe6, 0xec, 0xf0, 0xd2, 0x57, 0x0a, 0x47, 0x14, 0x47, 0xb4,
		0x78, 0x8e, 0x28, 0xf9, 0xf4, 0x04, 0x0a, 0x89, 0x8c, 0x4c, 0xa0, 0x90, 0x4d, 0xd0, 0x90, 0x01,
		0x0f, 0x21, 0x10, 0x91, 0x57, 0xb5, 0x96, 0xf6, 0x2b, 0xf9, 0xf4, 0x92, 0x3b, 0x92, 0x20, 0xa1,
		0xf5, 0xe3, 0x13, 0x24, 0x94, 0xdb, 0x92, 0x92, 0x4f, 0x6f, 0x6e, 0x34, 0xf2, 0xe9, 0x33, 0x8a,
		0x3c, 0xe4, 0xd3, 0x43, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0xf1, 0xfd, 0x4a, 0x3e, 0x7d, 0xaa, 0x77,
		0x22, 0x9f, 0x1e, 0x18, 0x06, 0x86, 0x81, 0x61, 0xf2, 0xe9, 0xc9, 0xa7, 0x27, 0x9f, 0x1e, 0xc9,
		0x42, 0x6d, 0x49, 0xc9, 0xa7, 0x47, 0xa9, 0xc8, 0x91, 0xc4, 0x92, 0x4f, 0x0f, 0xa9, 0x85, 0xd4,
		0x42, 0x6a, 0x6d, 0x91, 0x5a, 0xf2, 0xe9, 0xcb, 0xc8, 0x3b, 0xb9, 0x2a, 0xab, 0x1c, 0xef, 0x24,
		0x9f, 0x1e, 0xe6, 0x99, 0xd3, 0x08, 0x55, 0xca, 0xa7, 0x7f, 0xcc, 0x47, 0xa0, 0xab, 0xd4, 0x4a,
		0x83, 0x4f, 0x57, 0x29, 0xdb, 0x4c, 0x9e, 0x28, 0x58, 0xa2, 0x60, 0xd7, 0x0f, 0x44, 0x14, 0x2c,
		0xee, 0x3d, 0xee, 0x3d, 0xee, 0x3d, 0x51, 0xb0, 0xb8, 0xf6, 0xb8, 0xf6, 0xb8, 0xf6, 0x0a, 0x4b,
		0x4a, 0x14, 0x6c, 0x0d, 0x3c, 0x7c, 0xa2, 0x60, 0x89, 0x82, 0x85, 0xca, 0x42, 0x65, 0x6b, 0x4b,
		0x65, 0x89, 0x82, 0x4d, 0xf5, 0x4e, 0x44, 0xc1, 0x02, 0xc3, 0xc0, 0x30, 0x30, 0x4c, 0x14, 0x2c,
		0x51, 0xb0, 0x44, 0xc1, 0x22, 0x59, 0xa8, 0x2d, 0x29, 0x51, 0xb0, 0x28, 0x15, 0x39, 0x92, 0x58,
		0xa2, 0x60, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0xad, 0x2d, 0x52, 0x4b, 0x14, 0x6c, 0x19, 0x79, 0x27,
		0x57, 0x65, 0x95, 0xe3, 0x9d, 0x44, 0xc1, 0xc2, 0x3c, 0x73, 0x1a, 0xa1, 0x0e, 0x51, 0xb0, 0xf4,
		0x94, 0x2a, 0xc2, 0x32, 0x18, 0xed, 0x28, 0x75, 0xda, 0xfc, 0xd2, 0x0b, 0x8f, 0xef, 0x7b, 0x61,
		0x2e, 0xfd, 0xa4, 0x2a, 0xdb, 0x1b, 0x40, 0xb9, 0xce, 0x7d, 0xc6, 0x55, 0x2b, 0x4e, 0x5f, 0x80,
		0xfb, 0x5e, 0x10, 0xeb, 0xf6, 0x05, 0x18, 0x8e, 0x41, 0x5f, 0x00, 0x73, 0x7e, 0x2d, 0x7d, 0x01,
		0xe8, 0x0b, 0x40, 0x5f, 0x00, 0x61, 0x91, 0x88, 0xbe, 0x00, 0x06, 0x79, 0x19, 0x7d, 0x01, 0x4c,
		0x1e, 0x48, 0xc9, 0x83, 0x29, 0x7f, 0x40, 0xa5, 0x0f, 0xaa, 0xb1, 0x03, 0x6b, 0xec, 0xe0, 0x1a,
		0x39, 0xc0, 0xc5, 0xf0, 0x7f, 0xc9, 0x88, 0xe2, 0xaa, 0x47, 0x64, 0x64, 0xae, 0x7a, 0x6c, 0x82,
		0x86, 0xac, 0x1c, 0x48, 0x46, 0x94, 0xc8, 0x90, 0x5c, 0xf3, 0x70, 0xcd, 0x63, 0xf1, 0xb8, 0xcd,
		0x2f, 0x29, 0x19, 0x51, 0xc5, 0x58, 0x5b, 0x6e, 0x7b, 0x4c, 0xef, 0x7d, 0x32, 0xa2, 0xa0, 0xb2,
		0x50, 0x59, 0xa8, 0x6c, 0x49, 0xa9, 0x2c, 0x19, 0x51, 0xa9, 0xde, 0x89, 0x8c, 0x28, 0x60, 0x18,
		0x18, 0x06, 0x86, 0xc9, 0x88, 0x22, 0x23, 0x8a, 0x8c, 0x28, 0x24, 0x0b, 0xb5, 0x25, 0x25, 0x23,
		0x0a, 0xa5, 0x22, 0x47, 0x12, 0x4b, 0x46, 0x14, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0xb5, 0x45, 0x6a,
		0xc9, 0x88, 0x2a, 0x23, 0xef, 0xe4, 0xaa, 0xac, 0x72, 0xbc, 0x93, 0x8c, 0x28, 0x98, 0x67, 0x4e,
		0x23, 0x54, 0x2f, 0x23, 0xea, 0xbe, 0x17, 0xc4, 0xf4, 0x05, 0x58, 0x69, 0xf0, 0xe9, 0x0b, 0x60,
		0x9b, 0xc9, 0x13, 0x05, 0x4b, 0x14, 0xec, 0xfa, 0x81, 0x88, 0x82, 0xc5, 0xbd, 0xc7, 0xbd, 0xc7,
		0xbd, 0x27, 0x0a, 0x16, 0xd7, 0x1e, 0xd7, 0x1e, 0xd7, 0x5e, 0x61, 0x49, 0x89, 0x82, 0xad, 0x81,
		0x87, 0x4f, 0x14, 0x2c, 0x51, 0xb0, 0x50, 0x59, 0xa8, 0x6c, 0x6d, 0xa9, 0x2c, 0x51, 0xb0, 0xa9,
		0xde, 0x89, 0x28, 0x58, 0x60, 0x18, 0x18, 0x06, 0x86, 0x89, 0x82, 0x25, 0x0a, 0x96, 0x28, 0x58,
		0x24, 0x0b, 0xb5, 0x25, 0x25, 0x0a, 0x16, 0xa5, 0x22, 0x47, 0x12, 0x4b, 0x14, 0x2c, 0xa4, 0x16,
		0x52, 0x0b, 0xa9, 0xb5, 0x45, 0x6a, 0x89, 0x82, 0x2d, 0x23, 0xef, 0xe4, 0xaa, 0xac, 0x72, 0xbc,
		0x93, 0x28, 0x58, 0x98, 0x67, 0x4e, 0x23, 0xd4, 0x21, 0x0a, 0x96, 0xbe, 0x00, 0x45, 0x58, 0x06,
		0xf3, 0x7d, 0x01, 0xbe, 0xf4, 0x82, 0x98, 0xbe, 0x00, 0x66, 0x96, 0xd2, 0x5c, 0x5f, 0x80, 0xc1,
		0xaa, 0x15, 0xa2, 0x2f, 0xc0, 0xee, 0xe0, 0x5d, 0xfd, 0xde, 0x7d, 0xcb, 0xb9, 0xeb, 0x07, 0x89,
		0xdf, 0x76, 0xe3, 0x44, 0xa3, 0x43, 0xc0, 0xaa, 0xd1, 0xe8, 0x15, 0x60, 0xce, 0xd7, 0xa5, 0x57,
		0x00, 0xbd, 0x02, 0xe8, 0x15, 0x20, 0x2c, 0x1c, 0xd1, 0x2b, 0xc0, 0x20, 0x57, 0xa3, 0x57, 0x80,
		0xc9, 0x03, 0x29, 0x79, 0x30, 0xe5, 0x0f, 0xa8, 0xf4, 0x41, 0x35, 0x76, 0x60, 0x8d, 0x1d, 0x5c,
		0x23, 0x07, 0xb8, 0x18, 0x3e, 0x31, 0x59, 0x52, 0x5c, 0xff, 0x88, 0x8c, 0xcc, 0xf5, 0x8f, 0x4d,
		0xd0, 0x90, 0x95, 0x08, 0xc9, 0x92, 0x12, 0x19, 0x92, 0xab, 0x1f, 0xae, 0x7e, 0x2c, 0x1e, 0xb7,
		0xf9, 0x25, 0x25, 0x4b, 0xaa, 0x18, 0x6b, 0xcb, 0x0d, 0x90, 0xe9, 0xbd, 0x4f, 0x96, 0x14, 0x54,
		0x16, 0x2a, 0x0b, 0x95, 0x2d, 0x29, 0x95, 0x25, 0x4b, 0x2a, 0xd5, 0x3b, 0x91, 0x25, 0x05, 0x0c,
		0x03, 0xc3, 0xc0, 0x30, 0x59, 0x52, 0x64, 0x49, 0x91, 0x25, 0x85, 0x64, 0xa1, 0xb6, 0xa4, 0x64,
		0x49, 0xa1, 0x54, 0xe4, 0x48, 0x62, 0xc9, 0x92, 0x82, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0xb6, 0x48,
		0x2d, 0x59, 0x52, 0x65, 0xe4, 0x9d, 0x5c, 0x95, 0x55, 0x8e, 0x77, 0x92, 0x25, 0x05, 0xf3, 0xcc,
		0x69, 0x84, 0x4a, 0x65, 0x49, 0xad, 0xc8, 0x4c, 0xa0, 0x6b, 0xc0, 0x4a, 0xd3, 0x4f, 0xd7, 0x00,
		0xdb, 0x9c, 0x9e, 0x78, 0x58, 0xe2, 0x61, 0xd7, 0x0f, 0x44, 0x3c, 0x2c, 0x8e, 0x3e, 0x8e, 0x3e,
		0x8e, 0x3e, 0xf1, 0xb0, 0x38, 0xf9, 0x38, 0xf9, 0x38, 0xf9, 0x0a, 0x4b, 0x4a, 0x3c, 0x6c, 0x0d,
		0x7c, 0x7d, 0xe2, 0x61, 0x89, 0x87, 0x85, 0xca, 0x42, 0x65, 0x6b, 0x4b, 0x65, 0x89, 0x87, 0x4d,
		0xf5, 0x4e, 0xc4, 0xc3, 0x02, 0xc3, 0xc0, 0x30, 0x30, 0x4c, 0x3c, 0x2c, 0xf1, 0xb0, 0xc4, 0xc3,
		0x22, 0x59, 0xa8, 0x2d, 0x29, 0xf1, 0xb0, 0x28, 0x15, 0x39, 0x92, 0x58, 0xe2, 0x61, 0x21, 0xb5,
		0x90, 0x5a, 0x48, 0xad, 0x2d, 0x52, 0x4b, 0x3c, 0x6c, 0x19, 0x79, 0x27, 0x57, 0x65, 0x95, 0xe3,
		0x9d, 0xc4, 0xc3, 0xc2, 0x3c, 0x73, 0x1a, 0xa1, 0x5e, 0xf1, 0xb0, 0xf4, 0x0f, 0x28, 0xd6, 0x82,
		0x98, 0xed, 0x24, 0xb0, 0xfb, 0xa5, 0x17, 0x9e, 0xf4, 0xee, 0x5b, 0x1f, 0x26, 0xcf, 0xa6, 0xa5,
		0x80, 0xe9, 0xd5, 0x35, 0xd3, 0x5c, 0x60, 0x69, 0x21, 0x0b, 0xd6, 0x65, 0xa0, 0x1f, 0xca, 0xf5,
		0x18, 0x98, 0x8c, 0x45, 0x87, 0x01, 0x73, 0x7e, 0x31, 0x1d, 0x06, 0xe8, 0x30, 0x40, 0x87, 0x01,
		0x61, 0x91, 0x89, 0x0e, 0x03, 0x06, 0xd9, 0x1c, 0x1d, 0x06, 0x4c, 0x1e, 0x48, 0xc9, 0x83, 0x29,
		0x7f, 0x40, 0xa5, 0x0f, 0xaa, 0xb1, 0x03, 0x6b, 0xec, 0xe0, 0x1a, 0x39, 0xc0, 0xc5, 0xf0, 0x9f,
		0xc9, 0xa8, 0xe2, 0xaa, 0x48, 0x64, 0x64, 0xae, 0x8a, 0x6c, 0x82, 0x86, 0xac, 0x9c, 0x48, 0x46,
		0x95, 0xc8, 0x90, 0x5c, 0x13, 0x71, 0x4d, 0x64, 0xf1, 0xb8, 0xcd, 0x2f, 0x29, 0x19, 0x55, 0xc5,
		0x58, 0x5b, 0x6e, 0x8b, 0x4c, 0xef, 0x7d, 0x32, 0xaa, 0xa0, 0xb2, 0x50, 0x59, 0xa8, 0x6c, 0x49,
		0xa9, 0x2c, 0x19, 0x55, 0xa9, 0xde, 0x89, 0x8c, 0x2a, 0x60, 0x18, 0x18, 0x06, 0x86, 0xc9, 0xa8,
		0x22, 0xa3, 0x8a, 0x8c, 0x2a, 0x24, 0x0b, 0xb5, 0x25, 0x25, 0xa3, 0x0a, 0xa5, 0x22, 0x47, 0x12,
		0x4b, 0x46, 0x15, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0xb5, 0x45, 0x6a, 0xc9, 0xa8, 0x2a, 0x23, 0xef,
		0xe4, 0xaa, 0xac, 0x72, 0xbc, 0x93, 0x8c, 0x2a, 0x98, 0x67, 0x4e, 0x23, 0x54, 0x34, 0xa3, 0x6a,
		0x9c, 0x97, 0x40, 0x7f, 0x81, 0x95, 0x86, 0x9f, 0xfe, 0x02, 0xb6, 0x19, 0x3d, 0xd1, 0xb0, 0x44,
		0xc3, 0xae, 0x1f, 0x88, 0x68, 0x58, 0xdc, 0x7c, 0xdc, 0x7c, 0xdc, 0x7c, 0xa2, 0x61, 0x71, 0xf1,
		0x71, 0xf1, 0x71, 0xf1, 0x15, 0x96, 0x94, 0x68, 0xd8, 0x1a, 0x78, 0xfa, 0x44, 0xc3, 0x12, 0x0d,
		0x0b, 0x95, 0x85, 0xca, 0xd6, 0x96, 0xca, 0x12, 0x0d, 0x9b, 0xea, 0x9d, 0x88, 0x86, 0x05, 0x86,
		0x81, 0x61, 0x60, 0x98, 0x68, 0x58, 0xa2, 0x61, 0x89, 0x86, 0x45, 0xb2, 0x50, 0x5b, 0x52, 0xa2,
		0x61, 0x51, 0x2a, 0x72, 0x24, 0xb1, 0x44, 0xc3, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x5b, 0xa4,
		0x96, 0x68, 0xd8, 0x32, 0xf2, 0x4e, 0xae, 0xca, 0x2a, 0xc7, 0x3b, 0x89, 0x86, 0x85, 0x79, 0xe6,
		0x34, 0x42, 0x9d, 0xa2, 0x61, 0xe9, 0x2e, 0x50, 0xa4, 0xe5, 0xb0, 0xd3, 0x5b, 0xe0, 0x73, 0x48,
		0x67, 0x01, 0x0b, 0x2b, 0x6b, 0xb6, 0xaf, 0xc0, 0x78, 0x11, 0x0b, 0xd5, 0x55, 0x60, 0x7f, 0xa6,
		0xa9, 0x82, 0x7e, 0x5f, 0x81, 0x7d, 0xe5, 0x16, 0x0d, 0x74, 0x16, 0xc8, 0xc5, 0xf3, 0xa5, 0xb3,
		0x40, 0x8a, 0x0f, 0xd2, 0x59, 0xc0, 0x80, 0xfc, 0x44, 0x67, 0x81, 0x9c, 0xe5, 0x22, 0x3a, 0x0b,
		0xd0, 0x59, 0xc0, 0xce, 0x01, 0x95, 0x3e, 0xa8, 0xc6, 0x0e, 0xac, 0xb1, 0x83, 0x6b, 0xe4, 0x00,
		0x17, 0xc3, 0x73, 0x26, 0x97, 0x8a, 0x4b, 0x22, 0x91, 0x91, 0xb9, 0x24, 0xb2, 0x09, 0x1a, 0xb2,
		0x42, 0x22, 0xb9, 0x54, 0x22, 0x43, 0x72, 0x41, 0xc4, 0x05, 0x91, 0xc5, 0xe3, 0x36, 0xbf, 0xa4,
		0xe4, 0x52, 0x15, 0x63, 0x6d, 0xb9, 0x27, 0x32, 0xbd, 0xf7, 0xc9, 0xa5, 0x82, 0xca, 0x42, 0x65,
		0xa1, 0xb2, 0x25, 0xa5, 0xb2, 0xe4, 0x52, 0xa5, 0x7a, 0x27, 0x72, 0xa9, 0x80, 0x61, 0x60, 0x18,
		0x18, 0x26, 0x97, 0x8a, 0x5c, 0x2a, 0x72, 0xa9, 0x90, 0x2c, 0xd4, 0x96, 0x94, 0x5c, 0x2a, 0x94,
		0x8a, 0x1c, 0x49, 0x2c, 0xb9, 0x54, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0xd6, 0x16, 0xa9, 0x25, 0x97,
		0xaa, 0x8c, 0xbc, 0x93, 0xab, 0xb2, 0xca, 0xf1, 0x4e, 0x72, 0xa9, 0x60, 0x9e, 0x39, 0x8d, 0x50,
		0xc9, 0x5c, 0xaa, 0x99, 0xcc, 0x04, 0x7a, 0x0b, 0xac, 0x34, 0xfd, 0xf4, 0x16, 0xb0, 0xcd, 0xe9,
		0x89, 0x87, 0x25, 0x1e, 0x76, 0xfd, 0x40, 0xc4, 0xc3, 0xe2, 0xe8, 0xe3, 0xe8, 0xe3, 0xe8, 0x13,
		0x0f, 0x8b, 0x93, 0x8f, 0x93, 0x8f, 0x93, 0xaf, 0xb0, 0xa4, 0xc4, 0xc3, 0xd6, 0xc0, 0xd7, 0x27,
		0x1e, 0x96, 0x78, 0x58, 0xa8, 0x2c, 0x54, 0xb6, 0xb6, 0x54, 0x96, 0x78, 0xd8, 0x54, 0xef, 0x44,
		0x3c, 0x2c, 0x30, 0x0c, 0x0c, 0x03, 0xc3, 0xc4, 0xc3, 0x12, 0x0f, 0x4b, 0x3c, 0x2c, 0x92, 0x85,
		0xda, 0x92, 0x12, 0x0f, 0x8b, 0x52, 0x91, 0x23, 0x89, 0x25, 0x1e, 0x16, 0x52, 0x0b, 0xa9, 0x85,
		0xd4, 0xda, 0x22, 0xb5, 0xc4, 0xc3, 0x96, 0x91, 0x77, 0x72, 0x55, 0x56, 0x39, 0xde, 0x49, 0x3c,
		0x2c, 0xcc, 0x33, 0xa7, 0x11, 0xea, 0x15, 0x0f, 0x4b, 0x77, 0x81, 0x62, 0x2d, 0x88, 0x95, 0xfe,
		0x02, 0xfb, 0x1f, 0x26, 0xcf, 0xa6, 0xc3, 0x80, 0xe9, 0xd5, 0x35, 0xda, 0x63, 0xe0, 0x71, 0x21,
		0x0b, 0xd6, 0x65, 0x60, 0xd2, 0x60, 0x41, 0xa2, 0xc7, 0x80, 0x5a, 0xb3, 0x06, 0x3a, 0x0c, 0xe4,
		0xe2, 0xff, 0xd2, 0x61, 0x20, 0xc5, 0x07, 0xe9, 0x30, 0x60, 0x40, 0x84, 0xa2, 0xc3, 0x40, 0xce,
		0xa2, 0x11, 0x1d, 0x06, 0xe8, 0x30, 0x60, 0xe7, 0x80, 0x4a, 0x1f, 0x54, 0x63, 0x07, 0xd6, 0xd8,
		0xc1, 0x35, 0x72, 0x80, 0x8b, 0xe1, 0x3f, 0x93, 0x51, 0xc5, 0x55, 0x91, 0xc8, 0xc8, 0x5c, 0x15,
		0xd9, 0x04, 0x0d, 0x59, 0x39, 0x91, 0x8c, 0x2a, 0x91, 0x21, 0xb9, 0x26, 0xe2, 0x9a, 0xc8, 0xe2,
		0x71, 0x9b, 0x5f, 0x52, 0x32, 0xaa, 0x8a, 0xb1, 0xb6, 0xdc, 0x16, 0x99, 0xde, 0xfb, 0x64, 0x54,
		0x41, 0x65, 0xa1, 0xb2, 0x50, 0xd9, 0x92, 0x52, 0x59, 0x32, 0xaa, 0x52, 0xbd, 0x13, 0x19, 0x55,
		0xc0, 0x30, 0x30, 0x0c, 0x0c, 0x93, 0x51, 0x45, 0x46, 0x15, 0x19, 0x55, 0x48, 0x16, 0x6a, 0x4b,
		0x4a, 0x46, 0x15, 0x4a, 0x45, 0x8e, 0x24, 0x96, 0x8c, 0x2a, 0x48, 0x2d, 0xa4, 0x16, 0x52, 0x6b,
		0x8b, 0xd4, 0x92, 0x51, 0x55, 0x46, 0xde, 0xc9, 0x55, 0x59, 0xe5, 0x78, 0x27, 0x19, 0x55, 0x30,
		0xcf, 0x9c, 0x46, 0xa8, 0x68, 0x46, 0xd5, 0x38, 0x2f, 0x81, 0xfe, 0x02, 0x2b, 0x0d, 0x3f, 0xfd,
		0x05, 0x6c, 0x33, 0x7a, 0xa2, 0x61, 0x89, 0x86, 0x5d, 0x3f, 0x10, 0xd1, 0xb0, 0xb8, 0xf9, 0xb8,
		0xf9, 0xb8, 0xf9, 0x44, 0xc3, 0xe2, 0xe2, 0xe3, 0xe2, 0xe3, 0xe2, 0x2b, 0x2c, 0x29, 0xd1, 0xb0,
		0x35, 0xf0, 0xf4, 0x89, 0x86, 0x25, 0x1a, 0x16, 0x2a, 0x0b, 0x95, 0xad, 0x2d, 0x95, 0x25, 0x1a,
		0x36, 0xd5, 0x3b, 0x11, 0x0d, 0x0b, 0x0c, 0x03, 0xc3, 0xc0, 0x30, 0xd1, 0xb0, 0x44, 0xc3, 0x12,
		0x0d, 0x8b, 0x64, 0xa1, 0xb6, 0xa4, 0x44, 0xc3, 0xa2, 0x54, 0xe4, 0x48, 0x62, 0x89, 0x86, 0x85,
		0xd4, 0x42, 0x6a, 0x21, 0xb5, 0xb6, 0x48, 0x2d, 0xd1, 0xb0, 0x65, 0xe4, 0x9d, 0x5c, 0x95, 0x55,
		0x8e, 0x77, 0x12, 0x0d, 0x0b, 0xf3, 0xcc, 0x69, 0x84, 0x3a, 0x45, 0xc3, 0xd2, 0x5d, 0xa0, 0x48,
		0xcb, 0x61, 0xa7, 0xb7, 0xc0, 0xe7, 0x90, 0xce, 0x02, 0x16, 0x56, 0xd6, 0x6c, 0x5f, 0x81, 0xf1,
		0x22, 0x16, 0xa1, 0xab, 0x40, 0xd4, 0xed, 0x27, 0x9e, 0x13, 0x7b, 0x81, 0x37, 0xb4, 0x7b, 0x4e,
		0xb7, 0x37, 0xf8, 0x4f, 0xac, 0xde, 0x5a, 0x60, 0xdd, 0x80, 0xf4, 0x17, 0x30, 0xe7, 0x17, 0xd3,
		0x5f, 0xc0, 0x66, 0x7f, 0x01, 0xcd, 0xd2, 0xe6, 0x32, 0x25, 0xcd, 0xe9, 0x29, 0x60, 0x42, 0x58,
		0xa2, 0xa7, 0x80, 0x41, 0x0e, 0xa7, 0xdd, 0x53, 0xc0, 0xed, 0xdc, 0x7b, 0x51, 0xe2, 0xc7, 0x9e,
		0xe3, 0x87, 0x03, 0x37, 0xed, 0xde, 0x73, 0x86, 0xd6, 0x26, 0x96, 0xcb, 0xab, 0x5a, 0xff, 0x08,
		0xdd, 0x4c, 0x13, 0xd9, 0xd8, 0x37, 0x21, 0x4f, 0x9b, 0x4e, 0x06, 0xc5, 0x80, 0x09, 0x63, 0x70,
		0x61, 0x04, 0x36, 0x8a, 0xe1, 0xa9, 0x8b, 0xe9, 0xc8, 0x06, 0x62, 0xd3, 0x84, 0x62, 0xd2, 0xf2,
		0x49, 0x55, 0x75, 0x83, 0x3f, 0xdd, 0x9f, 0xb1, 0xd3, 0xee, 0xde, 0xf5, 0xdc, 0xc8, 0x73, 0xee,
		0xbc, 0x8e, 0x20, 0xbe, 0x2e, 0x8f, 0x0d, 0xb0, 0x02, 0xac, 0x00, 0x2b, 0xc0, 0x5a, 0x7d, 0x60,
		0xf5, 0x42, 0xf7, 0x5b, 0xe0, 0x39, 0xae, 0x7f, 0xdb, 0x93, 0x43, 0xd4, 0xd9, 0x41, 0x81, 0x52,
		0xa0, 0x14, 0x28, 0x05, 0x4a, 0x6b, 0x00, 0xa5, 0x3f, 0x12, 0x2f, 0x0a, 0xdd, 0x60, 0xca, 0x24,
		0x87, 0x5e, 0x7a, 0xe4, 0xf8, 0x82, 0x5c, 0xf5, 0x89, 0x67, 0xc8, 0x01, 0xed, 0xe0, 0xf8, 0x80,
		0xb3, 0xe0, 0x2c, 0x38, 0x0b, 0xce, 0x16, 0x10, 0x67, 0xfd, 0xdb, 0xb0, 0x1b, 0x79, 0x8e, 0x1b,
		0x3b, 0x3d, 0x37, 0xf9, 0xee, 0x04, 0x5e, 0x78, 0x3b, 0xbc, 0x60, 0x15, 0x82, 0xd8, 0xd5, 0xc3,
		0x43, 0x63, 0x81, 0x57, 0xe0, 0x15, 0x78, 0xad, 0x0d, 0xbc, 0x86, 0xde, 0x8f, 0xc4, 0xf9, 0xde,
		0xed, 0x39, 0xfe, 0x6d, 0xcf, 0xb9, 0xf3, 0x92, 0xc8, 0x6f, 0x8b, 0x63, 0xec, 0xaa, 0x67, 0x00,
		0xb4, 0x00, 0x2d, 0x40, 0x0b, 0xd0, 0x96, 0x04, 0x68, 0x6b, 0x17, 0x71, 0xba, 0x26, 0x96, 0x4e,
		0xab, 0x0c, 0xae, 0x42, 0xdc, 0xa7, 0x52, 0x2c, 0xa4, 0x4e, 0xb9, 0x5b, 0x91, 0x32, 0xb7, 0x62,
		0x11, 0x52, 0x4d, 0x22, 0xa4, 0x0c, 0x9a, 0x09, 0x22, 0xa4, 0x66, 0x08, 0x15, 0x11, 0x52, 0xb0,
		0x49, 0xd8, 0x24, 0x6c, 0x12, 0x36, 0x59, 0x68, 0xb7, 0x9d, 0x08, 0x29, 0x80, 0x15, 0x60, 0x05,
		0x58, 0x01, 0x56, 0x61, 0x60, 0x25, 0x42, 0x0a, 0x28, 0x05, 0x4a, 0x81, 0x52, 0xa0, 0x54, 0x1f,
		0x4a, 0x89, 0x90, 0x02, 0x67, 0xc1, 0x59, 0x70, 0x16, 0x9c, 0x35, 0x8a, 0xb3, 0x44, 0x48, 0x01,
		0xaf, 0xc0, 0x2b, 0xf0, 0x0a, 0xbc, 0x9a, 0x84, 0x57, 0x22, 0xa4, 0x00, 0x5a, 0x80, 0x16, 0xa0,
		0x05, 0x68, 0xe5, 0x3f, 0x59, 0xc5, 0x08, 0x29, 0x8d, 0xd2, 0x88, 0x14, 0xc6, 0xdb, 0x38, 0xbd,
		0x46, 0xaa, 0xe3, 0x7d, 0x1a, 0x3c, 0xeb, 0x62, 0xf2, 0xa8, 0xb3, 0xf1, 0x93, 0x0a, 0x50, 0x22,
		0x2f, 0x8e, 0x12, 0xcf, 0xe9, 0x75, 0x03, 0xbf, 0xfd, 0xd3, 0xf1, 0x7b, 0xf7, 0x2d, 0xf5, 0xda,
		0x78, 0x4b, 0x23, 0x51, 0x14, 0xcf, 0x9c, 0xf9, 0xa6, 0x28, 0x9e, 0xcd, 0xa2, 0x78, 0x73, 0x95,
		0x50, 0xb5, 0xe3, 0x3e, 0x05, 0xea, 0xaa, 0x52, 0x20, 0xcf, 0x04, 0x17, 0x26, 0xfc, 0xd3, 0x20,
		0xa1, 0xd2, 0x0e, 0xff, 0xd4, 0xac, 0x4c, 0xb9, 0xb4, 0xed, 0xb4, 0x2a, 0x54, 0x0a, 0x1d, 0x44,
		0x9c, 0x56, 0x9c, 0xd6, 0xb2, 0x3b, 0xad, 0xba, 0x07, 0x7b, 0x3a, 0xd0, 0x9d, 0xfb, 0xc3, 0x19,
		0xad, 0xa2, 0x40, 0x48, 0xf7, 0xd2, 0x26, 0x9e, 0x1b, 0x9d, 0xfe, 0x49, 0xc5, 0x01, 0x05, 0x53,
		0xe0, 0x60, 0x1c, 0x24, 0x8c, 0x83, 0x85, 0x51, 0xd0, 0x90, 0x01, 0x0f, 0x21, 0x10, 0x91, 0x57,
		0xc0, 0x96, 0xf6, 0x6b, 0xdf, 0x0f, 0x93, 0xdd, 0xa6, 0x81, 0xde, 0x49, 0x07, 0xf4, 0x4e, 0x12,
		0x1e, 0x9c, 0xde, 0x49, 0x96, 0x8e, 0xdb, 0xfc, 0x92, 0x56, 0xa0, 0x77, 0x52, 0xab, 0x79, 0xd8,
		0x3a, 0xdc, 0x3f, 0x68, 0x1e, 0xee, 0xd1, 0x42, 0x49, 0x7a, 0xb4, 0x2a, 0x35, 0xef, 0xec, 0x45,
		0xde, 0xbd, 0x17, 0x26, 0x4e, 0xe2, 0xb9, 0x51, 0xa7, 0xfb, 0x67, 0x28, 0x4f, 0x37, 0x97, 0x9e,
		0x20, 0x64, 0x20, 0x85, 0x2f, 0x5d, 0xa1, 0xb2, 0x50, 0x59, 0xa8, 0x6c, 0xc9, 0xa8, 0xac, 0xdc,
		0xa5, 0xee, 0x92, 0x8c, 0xb5, 0x53, 0x21, 0x90, 0x8f, 0xbc, 0x38, 0x71, 0xa3, 0xc4, 0x49, 0xfc,
		0x3b, 0x2f, 0x92, 0x47, 0xf8, 0xf9, 0xe1, 0x81, 0x61, 0x60, 0x18, 0x18, 0xae, 0x15, 0x0c, 0x77,
		0xbc, 0xb6, 0x7f, 0xe7, 0x06, 0xfb, 0x2d, 0x13, 0x40, 0xdc, 0x14, 0x1c, 0x73, 0xc9, 0x69, 0x69,
		0x22, 0x59, 0x98, 0xf1, 0x6f, 0x9b, 0x48, 0x16, 0x55, 0x93, 0x2c, 0x76, 0x59, 0x52, 0x94, 0x8a,
		0xfc, 0x48, 0xec, 0x9f, 0x6e, 0x14, 0xfa, 0xe1, 0xad, 0x93, 0x7c, 0x8f, 0xbc, 0xf8, 0x7b, 0x37,
		0xe8, 0x38, 0xbd, 0x76, 0x22, 0x4f, 0x66, 0x57, 0x3f, 0x06, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xd6,
		0x8a, 0xd4, 0xf6, 0xbc, 0xa8, 0xed, 0x85, 0x89, 0x7b, 0xeb, 0x19, 0x60, 0xb5, 0x7b, 0xf0, 0x4e,
		0x33, 0x24, 0x85, 0xab, 0xb2, 0xca, 0xf1, 0x4e, 0xd3, 0x4b, 0xba, 0xb3, 0x0d, 0xf3, 0xac, 0x2e,
		0xf3, 0xcc, 0x35, 0x22, 0x4c, 0x28, 0x77, 0x66, 0x3a, 0x9e, 0x4e, 0x92, 0xc7, 0x62, 0x56, 0xc2,
		0xeb, 0xd9, 0xe8, 0x6b, 0xad, 0x5a, 0xc3, 0xfa, 0x73, 0xad, 0x93, 0x3a, 0xaa, 0x57, 0x83, 0x78,
		0xc9, 0xec, 0xeb, 0xd4, 0x22, 0x5e, 0xd2, 0xae, 0xa4, 0x62, 0x61, 0x9b, 0xc4, 0xc2, 0x16, 0x80,
		0xbf, 0x13, 0x0b, 0x9b, 0xfe, 0x8d, 0x88, 0x85, 0xc5, 0xc9, 0xc7, 0xc9, 0xc7, 0xc9, 0x2f, 0xb8,
		0x93, 0x4f, 0x2c, 0x2c, 0x0e, 0x3e, 0x0e, 0x7e, 0xc5, 0x1d, 0x7c, 0x62, 0x61, 0x6b, 0xe0, 0xe7,
		0x13, 0x0b, 0x4b, 0x2c, 0x2c, 0x54, 0x16, 0x2a, 0x5b, 0x5b, 0x2a, 0x4b, 0x2c, 0x6c, 0xaa, 0x77,
		0x22, 0x16, 0x16, 0x18, 0x06, 0x86, 0x81, 0x61, 0x62, 0x61, 0x89, 0x85, 0x25, 0x16, 0x16, 0xc9,
		0x42, 0x6d, 0x49, 0x89, 0x85, 0x45, 0xa9, 0xc8, 0x91, 0xc4, 0x12, 0x0b, 0x0b, 0xa9, 0x85, 0xd4,
		0x42, 0x6a, 0x6d, 0x91, 0x5a, 0x62, 0x61, 0xcb, 0xc8, 0x3b, 0xb9, 0x2a, 0xab, 0x1c, 0xef, 0x24,
		0x16, 0x16, 0xe6, 0x99, 0xd3, 0x08, 0xf5, 0x89, 0x85, 0xd5, 0xa8, 0x2a, 0xaf, 0x3f, 0xd5, 0xf5,
		0x2b, 0xee, 0xff, 0xe4, 0x62, 0x34, 0xb4, 0x22, 0x83, 0x37, 0xd4, 0xa2, 0xbf, 0x88, 0x12, 0xef,
		0x7c, 0xf8, 0xe0, 0x93, 0xde, 0x7d, 0xeb, 0x7a, 0xc4, 0xf8, 0x4f, 0x87, 0x8f, 0xa5, 0xa7, 0x80,
		0xf0, 0xaa, 0x1a, 0x69, 0x26, 0x30, 0xbf, 0x80, 0x05, 0xec, 0x22, 0xb0, 0x2f, 0xd6, 0x45, 0x60,
		0x9f, 0x2e, 0x02, 0x06, 0xfd, 0x5f, 0xba, 0x08, 0xd0, 0x45, 0x80, 0x2e, 0x02, 0xc2, 0x62, 0x12,
		0x5d, 0x04, 0x0c, 0x32, 0x37, 0xba, 0x08, 0x98, 0x3c, 0x90, 0x92, 0x07, 0x53, 0xfe, 0x80, 0x4a,
		0x1f, 0x54, 0x63, 0x07, 0xd6, 0xd8, 0xc1, 0x35, 0x72, 0x80, 0x8b, 0xe1, 0x27, 0x93, 0x39, 0xc5,
		0x95, 0x90, 0xc8, 0xc8, 0x5c, 0x09, 0xd9, 0x04, 0x0d, 0x59, 0xd9, 0x90, 0xcc, 0x29, 0x91, 0x21,
		0xb9, 0x0e, 0xe2, 0x3a, 0xc8, 0xe2, 0x71, 0x9b, 0x5f, 0x52, 0x32, 0xa7, 0x8a, 0xb1, 0xb6, 0xdc,
		0x0a, 0x99, 0xde, 0xfb, 0x64, 0x4e, 0x41, 0x65, 0xa1, 0xb2, 0x50, 0xd9, 0x92, 0x52, 0x59, 0x32,
		0xa7, 0x52, 0xbd, 0x13, 0x99, 0x53, 0xc0, 0x30, 0x30, 0x0c, 0x0c, 0x93, 0x39, 0x45, 0xe6, 0x14,
		0x99, 0x53, 0x48, 0x16, 0x6a, 0x4b, 0x4a, 0xe6, 0x14, 0x4a, 0x45, 0x8e, 0x24, 0x96, 0xcc, 0x29,
		0x48, 0x2d, 0xa4, 0x16, 0x52, 0x6b, 0x8b, 0xd4, 0x92, 0x39, 0x55, 0x46, 0xde, 0xc9, 0x55, 0x59,
		0xe5, 0x78, 0x27, 0x99, 0x53, 0x30, 0xcf, 0x9c, 0x46, 0xa8, 0x70, 0xe6, 0xd4, 0x3e, 0x5d, 0x04,
		0x56, 0x9a, 0x7d, 0xba, 0x08, 0xd8, 0xe6, 0xf3, 0xc4, 0xc2, 0x12, 0x0b, 0xbb, 0x7e, 0x20, 0x62,
		0x61, 0x71, 0xf2, 0x71, 0xf2, 0x71, 0xf2, 0x89, 0x85, 0xc5, 0xc1, 0xc7, 0xc1, 0xc7, 0xc1, 0x57,
		0x58, 0x52, 0x62, 0x61, 0x6b, 0xe0, 0xe7, 0x13, 0x0b, 0x4b, 0x2c, 0x2c, 0x54, 0x16, 0x2a, 0x5b,
		0x5b, 0x2a, 0x4b, 0x2c, 0x6c, 0xaa, 0x77, 0x22, 0x16, 0x16, 0x18, 0x06, 0x86, 0x81, 0x61, 0x62,
		0x61, 0x89, 0x85, 0x25, 0x16, 0x16, 0xc9, 0x42, 0x6d, 0x49, 0x89, 0x85, 0x45, 0xa9, 0xc8, 0x91,
		0xc4, 0x12, 0x0b, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x6d, 0x91, 0x5a, 0x62, 0x61, 0xcb, 0xc8,
		0x3b, 0xb9, 0x2a, 0xab, 0x1c, 0xef, 0x24, 0x16, 0x16, 0xe6, 0x99, 0xd3, 0x08, 0xf5, 0x89, 0x85,
		0xa5, 0x8b, 0x40, 0x71, 0x16, 0xc3, 0x5e, 0x17, 0x81, 0x7d, 0xba, 0x08, 0x98, 0x5c, 0x55, 0xf3,
		0x5d, 0x04, 0xf6, 0x0b, 0xd1, 0x45, 0x40, 0x29, 0x1a, 0x5d, 0x2b, 0xfa, 0x5c, 0xbb, 0x5f, 0x40,
		0x93, 0x7e, 0x01, 0x79, 0x7a, 0xae, 0x55, 0xee, 0x17, 0x30, 0x81, 0x03, 0x67, 0x7c, 0x88, 0x35,
		0x1b, 0x06, 0xcc, 0x0f, 0xa7, 0xd7, 0x31, 0x60, 0x9b, 0x8e, 0x01, 0x74, 0x0c, 0x28, 0x07, 0x4b,
		0xd3, 0x16, 0x76, 0xa6, 0xfb, 0xc5, 0xef, 0x78, 0x61, 0xe2, 0x27, 0x3f, 0x23, 0xef, 0x46, 0x67,
		0xd3, 0x4c, 0x2c, 0x8e, 0x86, 0x74, 0xd3, 0x38, 0x19, 0x7f, 0x95, 0x5f, 0xdc, 0x58, 0x30, 0x7d,
		0xeb, 0xe8, 0xfd, 0xc9, 0xf5, 0xc5, 0xe0, 0x7f, 0x2e, 0x7f, 0x3f, 0x3f, 0xd6, 0xdd, 0x82, 0x43,
		0xaf, 0x38, 0x16, 0x91, 0x93, 0x84, 0x95, 0xf9, 0xd3, 0xdd, 0x2f, 0xe7, 0x1f, 0xaf, 0x4f, 0xce,
		0xbf, 0xb4, 0xae, 0x3f, 0x7f, 0x3c, 0x79, 0x77, 0x74, 0x71, 0xd9, 0x28, 0xc2, 0xc5, 0x84, 0xf4,
		0x5b, 0x9e, 0x7c, 0xfc, 0xd7, 0xc5, 0xe5, 0xd1, 0xe5, 0x71, 0x15, 0x5f, 0x6e, 0xb8, 0x78, 0xa7,
		0x47, 0xbf, 0x1c, 0x9f, 0x1e, 0xff, 0x5a, 0xe9, 0x45, 0x6c, 0x0e, 0xb6, 0xea, 0x97, 0xf3, 0xd3,
		0x8b, 0x4a, 0x6f, 0xd1, 0xeb, 0x8b, 0xf3, 0xf7, 0x95, 0x7c, 0xc1, 0x09, 0xd2, 0xec, 0x57, 0x79,
		0x93, 0x0e, 0xdf, 0xaf, 0x36, 0x87, 0xf1, 0xf8, 0xcb, 0xf9, 0xc7, 0xca, 0xae, 0x62, 0x85, 0x57,
		0xef, 0xe2, 0xd3, 0xe5, 0xf1, 0xf5, 0xf9, 0xd9, 0xe9, 0xc9, 0xbb, 0xdf, 0x87, 0xb6, 0xbf, 0xd2,
		0x78, 0xd3, 0xba, 0xfe, 0xf0, 0xf9, 0xf4, 0xb2, 0xca, 0x88, 0xd3, 0xba, 0x7e, 0x7f, 0x7a, 0xf6,
		0xef, 0x8b, 0xf3, 0xe3, 0x77, 0xd5, 0xb6, 0x8c, 0x15, 0x45, 0x9b, 0x2f, 0xe7, 0x1f, 0x2b, 0xbe,
		0x84, 0x0b, 0x78, 0xb3, 0x5f, 0xd9, 0x73, 0x58, 0x65, 0x8b, 0xff, 0xc8, 0xdf, 0x24, 0xf1, 0x54,
		0x6b, 0x84, 0x2b, 0xdb, 0xba, 0xcb, 0x33, 0x0b, 0xeb, 0xd8, 0xf0, 0x42, 0xf7, 0x5b, 0xe0, 0x75,
		0xf4, 0x55, 0xce, 0xc9, 0x40, 0xaa, 0xfd, 0x25, 0x65, 0x92, 0x01, 0xd1, 0x49, 0xe7, 0x46, 0x42,
		0x27, 0xb5, 0x78, 0x5e, 0x73, 0xd7, 0x49, 0xf5, 0x93, 0xe9, 0x34, 0x93, 0xe7, 0xec, 0x40, 0x56,
		0xd2, 0x4d, 0xdc, 0xc0, 0xe9, 0xb9, 0xc9, 0xf7, 0x58, 0x1f, 0xb6, 0x66, 0x07, 0x03, 0x72, 0x80,
		0x1c, 0x20, 0x27, 0xd3, 0x7e, 0xd1, 0x2e, 0x45, 0x23, 0x50, 0x7a, 0x46, 0x28, 0x7e, 0x56, 0x20,
		0xba, 0x4b, 0x32, 0x3e, 0x56, 0x3a, 0xd5, 0x40, 0x38, 0xfe, 0xd5, 0x44, 0x68, 0xa4, 0x44, 0x92,
		0x89, 0x64, 0x3c, 0xab, 0xa9, 0x25, 0x90, 0x2e, 0xed, 0x62, 0x64, 0x2d, 0x72, 0x8a, 0x24, 0xbc,
		0x2a, 0x3e, 0xf1, 0xd0, 0xad, 0xeb, 0xb7, 0xc8, 0x3d, 0xf4, 0x2a, 0xf9, 0x41, 0x3f, 0xa0, 0x1f,
		0xd0, 0x0f, 0xe8, 0x07, 0xf4, 0x03, 0xfa, 0x01, 0xfd, 0x28, 0x0d, 0xfd, 0xa8, 0x6e, 0x08, 0x7d,
		0xf6, 0x3c, 0x14, 0x33, 0x41, 0xed, 0xfd, 0xd8, 0x73, 0xee, 0xfa, 0x41, 0xe2, 0xf7, 0x02, 0x4f,
		0x51, 0x2d, 0x7a, 0xb4, 0x33, 0xcb, 0x63, 0x59, 0x0e, 0x77, 0xdf, 0x26, 0xdc, 0x3d, 0x4f, 0xd6,
		0x55, 0xe5, 0x70, 0xf7, 0xf6, 0x64, 0x8f, 0x69, 0xba, 0x33, 0xe3, 0x71, 0xf4, 0xdc, 0x98, 0x1d,
		0xdc, 0x18, 0xdc, 0x98, 0x72, 0xb8, 0x31, 0xba, 0xdd, 0x02, 0xb4, 0xef, 0x5e, 0x97, 0xf6, 0x9d,
		0xde, 0x1d, 0xec, 0xe3, 0x8b, 0xc9, 0x16, 0x66, 0x15, 0xe2, 0xb1, 0x62, 0xc5, 0x52, 0x68, 0x2c,
		0x42, 0x63, 0x11, 0xbb, 0xae, 0xa1, 0x5c, 0x91, 0x13, 0x03, 0x85, 0x53, 0x85, 0x0a, 0xa6, 0x92,
		0x3c, 0x9e, 0xde, 0x47, 0x5a, 0x76, 0x27, 0xb4, 0x5a, 0x59, 0x59, 0x8a, 0x14, 0x1a, 0x9c, 0x43,
		0xfd, 0x30, 0x21, 0x75, 0x94, 0x84, 0x22, 0x42, 0x11, 0xeb, 0x46, 0x11, 0x35, 0x7d, 0x33, 0x59,
		0x1f, 0x4d, 0xe8, 0x20, 0x42, 0xe8, 0x20, 0x74, 0x74, 0x8a, 0x1b, 0x0f, 0xe4, 0x06, 0x41, 0xf7,
		0xcf, 0x47, 0x32, 0xe0, 0x1a, 0x68, 0x17, 0xb7, 0xfc, 0x08, 0x1a, 0x78, 0x14, 0x05, 0x6e, 0xcc,
		0xc1, 0x8e, 0x29, 0xf8, 0x31, 0x0e, 0x43, 0xc6, 0xe1, 0xc8, 0x28, 0x2c, 0xc9, 0xc0, 0x93, 0x10,
		0x4c, 0xc9, 0xfb, 0x9f, 0x06, 0xfd, 0x50, 0x61, 0x7f, 0x54, 0x6e, 0x21, 0x24, 0xee, 0x85, 0xef,
		0xdc, 0x1f, 0xfe, 0x5d, 0xff, 0x4e, 0x33, 0x6a, 0x79, 0xed, 0x2a, 0xcc, 0x0f, 0x2f, 0x0f, 0xef,
		0x3b, 0x40, 0x3b, 0xd0, 0x0e, 0xb4, 0xd7, 0x0b, 0xda, 0x69, 0x33, 0x2a, 0xb9, 0x23, 0xa9, 0x9d,
		0xbc, 0x7e, 0x7c, 0x6a, 0x27, 0xe7, 0xb6, 0xa4, 0xb4, 0x19, 0x35, 0x37, 0x1a, 0x25, 0x94, 0x8b,
		0x56, 0x42, 0x79, 0xc5, 0xc5, 0x8b, 0x37, 0xf8, 0x84, 0xce, 0xed, 0x8b, 0xfe, 0x2c, 0x3f, 0x68,
		0x95, 0x0b, 0x56, 0x29, 0xdd, 0xba, 0xd6, 0xe6, 0xab, 0x94, 0x72, 0x5d, 0xeb, 0xc0, 0x49, 0xc9,
		0xc3, 0x4d, 0xe4, 0xe1, 0x02, 0x90, 0x77, 0xe4, 0xe1, 0x0c, 0xae, 0x33, 0xf2, 0x30, 0xf2, 0x30,
		0x1a, 0x02, 0x1a, 0x42, 0xdd, 0x35, 0x04, 0xe4, 0xe1, 0x54, 0xef, 0x84, 0x3c, 0x0c, 0xb4, 0x03,
		0xed, 0x40, 0x7b, 0x99, 0xa0, 0x1d, 0x79, 0x58, 0x72, 0x47, 0x22, 0x0f, 0xaf, 0x1f, 0x1f, 0x79,
		0x38, 0xb7, 0x25, 0x45, 0x1e, 0x36, 0x37, 0x1a, 0xf2, 0x70, 0x59, 0xe4, 0x61, 0x7a, 0xeb, 0x15,
		0x61, 0x19, 0x8c, 0x76, 0xd5, 0xfb, 0x1c, 0x7b, 0x1f, 0xc6, 0x8f, 0x3c, 0x1f, 0x3c, 0xf1, 0xfa,
		0x58, 0x99, 0x14, 0xda, 0x49, 0xc7, 0xf0, 0x45, 0xd2, 0x31, 0x7c, 0xd2, 0x31, 0x48, 0xc7, 0xc8,
		0xd1, 0x79, 0x22, 0x1d, 0x83, 0x74, 0x0c, 0xbb, 0xea, 0x08, 0xf7, 0x6d, 0xdc, 0xb7, 0xad, 0x1f,
		0x08, 0x21, 0xd6, 0x84, 0x7b, 0x89, 0x10, 0x8b, 0x10, 0x6b, 0x0f, 0x8a, 0x64, 0x3d, 0x75, 0x84,
		0x58, 0x91, 0x21, 0x11, 0x62, 0x11, 0x62, 0x2d, 0x1e, 0xb7, 0xf9, 0x25, 0x45, 0x88, 0x2d, 0xc6,
		0xda, 0x22, 0xc4, 0x16, 0x98, 0x43, 0x17, 0x5c, 0x88, 0xf5, 0x89, 0xd3, 0x25, 0x4e, 0x17, 0xdd,
		0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd,
		0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0x00, 0xdd, 0xe0, 0x29, 0xdd, 0x80, 0x00, 0xae,
		0x22, 0x2c, 0x83, 0xdd, 0x00, 0xae, 0x93, 0x82, 0x07, 0x70, 0xe9, 0x29, 0x42, 0x22, 0x4a, 0x90,
		0x58, 0x08, 0x57, 0x93, 0x10, 0x2e, 0x83, 0xee, 0x15, 0x21, 0x5c, 0x72, 0x8a, 0x0d, 0x4d, 0x17,
		0xf2, 0x51, 0x60, 0x10, 0x77, 0x11, 0x77, 0x2d, 0x13, 0x53, 0x9a, 0x2e, 0x40, 0x4a, 0x9f, 0x26,
		0xa5, 0x1a, 0x6e, 0x01, 0x2d, 0xff, 0x9e, 0x9a, 0xd9, 0x86, 0x12, 0x1f, 0xce, 0xc8, 0xf0, 0x8d,
		0x35, 0x19, 0x7c, 0x26, 0xb8, 0x40, 0x03, 0x4b, 0x30, 0xac, 0xb2, 0x32, 0x9e, 0x2c, 0x67, 0xf8,
		0x82, 0x29, 0x3f, 0x7b, 0xea, 0xc7, 0xc9, 0x51, 0x92, 0x64, 0x63, 0x3c, 0x8d, 0x0f, 0x7e, 0x78,
		0x1c, 0x78, 0x03, 0x2c, 0x8f, 0xb3, 0xd9, 0xed, 0xc6, 0x07, 0xf7, 0xc7, 0xcc, 0x27, 0x77, 0xde,
		0xb4, 0x5a, 0xfb, 0x07, 0xad, 0xd6, 0xf6, 0xc1, 0xee, 0xc1, 0xf6, 0xe1, 0xde, 0xde, 0xce, 0xfe,
		0x4e, 0x06, 0x11, 0xa9, 0x71, 0x16, 0x75, 0xbc, 0xc8, 0xeb, 0xfc, 0x32, 0x78, 0xfd, 0xb0, 0x1f,
		0x04, 0xa2, 0xb3, 0xaa, 0xb8, 0xdd, 0x75, 0xb6, 0x79, 0x86, 0x3d, 0xbd, 0x71, 0x2f, 0xa7, 0xdb,
		0xba, 0x9b, 0x37, 0xe2, 0xd3, 0x3f, 0xb1, 0x61, 0x32, 0xb3, 0x4e, 0xa2, 0xc2, 0xe4, 0x3d, 0xfd,
		0x9e, 0xeb, 0xbf, 0xfd, 0x13, 0xdf, 0x7c, 0x98, 0x33, 0xe1, 0x75, 0xbc, 0x28, 0xdd, 0x17, 0x9f,
		0x4b, 0xb5, 0x78, 0xfc, 0xd8, 0x86, 0x99, 0x49, 0xe7, 0x17, 0xa7, 0x26, 0xc7, 0x59, 0xc8, 0x6f,
		0x76, 0x72, 0x9b, 0x95, 0xbc, 0x2a, 0x93, 0x53, 0x65, 0xf2, 0xa9, 0x44, 0x2e, 0xf5, 0xf6, 0x76,
		0x5a, 0x3f, 0x31, 0x6b, 0x4a, 0x8f, 0x5a, 0xea, 0x4e, 0x46, 0xa1, 0x25, 0xb3, 0xd7, 0xa5, 0xe2,
		0x5d, 0xa9, 0x7b, 0x51, 0xaa, 0xde, 0x92, 0xb6, 0x57, 0xa4, 0xed, 0xfd, 0x68, 0x79, 0x39, 0xb2,
		0xbc, 0x20, 0xab, 0x90, 0xd1, 0xf0, 0x3b, 0x5e, 0x98, 0xf8, 0x37, 0xbe, 0x17, 0xa9, 0xf7, 0x31,
		0x9e, 0x19, 0x43, 0xad, 0x7f, 0xf1, 0x36, 0xfd, 0x8b, 0x6d, 0xba, 0xff, 0x75, 0xea, 0x5f, 0xac,
		0xec, 0xae, 0x3f, 0x56, 0x32, 0x8c, 0x9d, 0xb0, 0x7f, 0xf7, 0x2d, 0xf3, 0xe6, 0xde, 0xd2, 0x8b,
		0x5d, 0xd0, 0x8c, 0x51, 0xd0, 0x70, 0x87, 0x25, 0x62, 0x0e, 0xa4, 0x84, 0x42, 0xa1, 0x18, 0x02,
		0xc9, 0xfb, 0x64, 0x9d, 0x78, 0x5d, 0x89, 0xbb, 0x7f, 0xe9, 0xa9, 0x95, 0xba, 0xcb, 0x17, 0x9d,
		0x63, 0x4b, 0xea, 0xc9, 0x95, 0x29, 0x67, 0x3f, 0x03, 0xed, 0xb9, 0xf3, 0x06, 0xe0, 0xa2, 0x52,
		0x84, 0xf5, 0x31, 0x90, 0x73, 0x3a, 0x04, 0xf6, 0x17, 0xfb, 0x8b, 0xfd, 0xc5, 0xfe, 0x62, 0x7f,
		0xb1, 0xbf, 0xd5, 0xb3, 0xbf, 0x19, 0xb1, 0x47, 0x49, 0xe8, 0x9e, 0x3d, 0x86, 0x6a, 0x82, 0xf7,
		0xec, 0x6e, 0x13, 0x13, 0xbe, 0xa7, 0x83, 0x2a, 0x09, 0xe0, 0x0a, 0x0c, 0xa6, 0x5c, 0xc2, 0xfa,
		0x9c, 0x0e, 0x9b, 0x29, 0xa1, 0x2f, 0x85, 0x1c, 0x9e, 0x42, 0x2c, 0xcd, 0x16, 0x76, 0xa5, 0x14,
		0x66, 0xa5, 0xac, 0xf6, 0x35, 0x51, 0xfb, 0x50, 0xfb, 0x50, 0xfb, 0xf0, 0x36, 0xf0, 0x36, 0xf0,
		0x36, 0xf0, 0x36, 0xf0, 0x36, 0xf0, 0x36, 0x50, 0xfb, 0xb0, 0xbf, 0xd8, 0x5f, 0xec, 0x2f, 0xf6,
		0x17, 0xfb, 0x8b, 0xfd, 0x45, 0xed, 0x43, 0xed, 0x2b, 0xb1, 0xda, 0x97, 0x21, 0xde, 0xbe, 0xb4,
		0xb1, 0xaf, 0x59, 0xe2, 0x4c, 0xb7, 0x9e, 0x8c, 0x15, 0x7e, 0x37, 0x37, 0x92, 0xa1, 0x48, 0xda,
		0x14, 0xa1, 0x8f, 0xd9, 0x42, 0x1e, 0x89, 0x9d, 0x95, 0xe5, 0x96, 0x45, 0x8e, 0x9d, 0xcd, 0xe0,
		0x1b, 0xcd, 0xd0, 0xc6, 0x8c, 0x2a, 0xfa, 0x36, 0x31, 0xb3, 0xa8, 0xe8, 0x8a, 0x4e, 0x8b, 0x96,
		0xb3, 0xa2, 0xe0, 0xa4, 0x28, 0x3a, 0x27, 0x6a, 0x2c, 0x48, 0xc3, 0x61, 0xd6, 0x62, 0xca, 0xba,
		0xce, 0x87, 0x04, 0x21, 0x7e, 0x50, 0xa3, 0x7d, 0xb9, 0x4f, 0x99, 0xae, 0x53, 0x21, 0x32, 0x77,
		0x86, 0xa8, 0xe9, 0x95, 0xc5, 0x5b, 0xdc, 0xa8, 0xdb, 0x4f, 0xbc, 0xc8, 0xf1, 0x3b, 0xd9, 0x0d,
		0xd0, 0xe3, 0x47, 0xb1, 0x43, 0xd8, 0x21, 0xcb, 0x76, 0xa8, 0xd3, 0x4d, 0x12, 0xaf, 0xe3, 0xfc,
		0x5f, 0xdf, 0xed, 0x28, 0x58, 0xa2, 0x9d, 0x37, 0x19, 0x3e, 0x73, 0xee, 0x26, 0x89, 0x17, 0x85,
		0x99, 0x8d, 0x51, 0xe3, 0xbf, 0xcf, 0x9f, 0x7f, 0xdd, 0x76, 0x0e, 0xaf, 0xfe, 0xfe, 0xba, 0xe3,
		0x1c, 0x5e, 0x8d, 0x7e, 0xbb, 0x33, 0xfc, 0xcf, 0xe8, 0xf7, 0xcd, 0xaf, 0xdb, 0x4e, 0x6b, 0xf2,
		0xfb, 0xbd, 0xaf, 0xdb, 0xce, 0xde, 0xd5, 0x8b, 0x3f, 0xfe, 0x78, 0xf5, 0xe2, 0xaf, 0xdd, 0x87,
		0xec, 0x1f, 0xfc, 0x47, 0xfa, 0x35, 0xbc, 0xca, 0xf2, 0xf2, 0x67, 0x17, 0x27, 0xff, 0xa9, 0xde,
		0x0c, 0x54, 0xdf, 0x75, 0xde, 0x14, 0x0c, 0xa4, 0xe6, 0xe9, 0x76, 0x46, 0xc5, 0x55, 0x9c, 0x21,
		0xf6, 0x3b, 0x1d, 0x3f, 0x4e, 0xdc, 0x30, 0x05, 0x08, 0x3e, 0x1e, 0xdb, 0xd5, 0x9f, 0xc7, 0x13,
		0xc6, 0x13, 0xce, 0x24, 0xa5, 0xa8, 0x49, 0x2a, 0x19, 0x37, 0x14, 0x4c, 0xa4, 0x3e, 0x4c, 0x24,
		0x73, 0x5c, 0x99, 0xf7, 0x63, 0x60, 0x12, 0xdd, 0x20, 0x2b, 0x14, 0xae, 0x5d, 0xf7, 0x75, 0x03,
		0x72, 0xe3, 0x2d, 0xbf, 0xf5, 0xc5, 0x8e, 0x80, 0xd8, 0x51, 0x10, 0x39, 0x12, 0x8a, 0x8e, 0xa9,
		0xf5, 0x1b, 0xef, 0xbe, 0x1f, 0x26, 0x6f, 0x34, 0x6e, 0xbb, 0xf7, 0xb8, 0xed, 0xde, 0xd2, 0x52,
		0x4f, 0x76, 0xb8, 0xed, 0x36, 0x35, 0xb5, 0xcd, 0x3d, 0xae, 0xb9, 0xc5, 0xc6, 0xcf, 0x12, 0x66,
		0xe6, 0x87, 0xc2, 0x06, 0x79, 0xdd, 0x80, 0x18, 0x64, 0x0c, 0x32, 0x06, 0x19, 0x83, 0x8c, 0x41,
		0xc6, 0x20, 0xd7, 0xce, 0x20, 0x97, 0x2b, 0x6a, 0x6a, 0xb5, 0xdc, 0x48, 0xb2, 0x24, 0xc9, 0x92,
		0x88, 0x5a, 0x88, 0x5a, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0x23,
		0x6a, 0x61, 0x90, 0x31, 0xc8, 0x18, 0x64, 0x0c, 0x32, 0x06, 0x19, 0x83, 0x8c, 0xa8, 0x55, 0x3e,
		0x51, 0xab, 0x0e, 0x39, 0x81, 0x4a, 0xe1, 0x83, 0x5b, 0x4f, 0x26, 0x07, 0x8e, 0xdb, 0xc5, 0x7d,
		0x1a, 0x8c, 0xf8, 0xeb, 0x64, 0x40, 0x13, 0x91, 0x93, 0x3f, 0x43, 0xf7, 0xce, 0x6f, 0x3b, 0xa1,
		0xe7, 0xdf, 0x7e, 0xff, 0xd6, 0x8d, 0x9c, 0x11, 0x13, 0xf0, 0xe2, 0x0c, 0xc1, 0x93, 0x6b, 0x87,
		0x20, 0x7e, 0x92, 0xf8, 0xc9, 0x27, 0xb7, 0x59, 0x76, 0xe9, 0x79, 0xdd, 0x40, 0x44, 0x58, 0x22,
		0x46, 0xdb, 0x11, 0xa3, 0x33, 0x86, 0x02, 0x2f, 0x2d, 0x73, 0xa6, 0x90, 0x60, 0xc5, 0x8d, 0x8b,
		0x67, 0x8b, 0x67, 0x9b, 0xd5, 0xb3, 0x55, 0xed, 0xbc, 0xdb, 0xe8, 0x79, 0x5e, 0xe4, 0xdc, 0x46,
		0xdd, 0x7e, 0x4f, 0xbf, 0xdb, 0xf5, 0xcc, 0x58, 0x2f, 0x73, 0x49, 0xe4, 0xd4, 0xed, 0x87, 0x4b,
		0xcb, 0x6b, 0xbb, 0x07, 0x4b, 0xf4, 0x80, 0x69, 0x7a, 0x8e, 0x8a, 0x3b, 0x46, 0xbb, 0x8f, 0xed,
		0x74, 0xbf, 0x04, 0x9e, 0x7b, 0x13, 0x79, 0x37, 0x3a, 0x1b, 0x66, 0x62, 0x67, 0x0e, 0x34, 0xc6,
		0x38, 0x1f, 0x7b, 0x4c, 0xaf, 0x5e, 0xbd, 0x9e, 0xfd, 0xbf, 0xc7, 0xb3, 0x1d, 0xcf, 0xfc, 0x7e,
		0xe4, 0x20, 0xce, 0xfc, 0xc5, 0xa8, 0x83, 0x66, 0x81, 0x1b, 0xfb, 0xf7, 0xf4, 0x4e, 0xf8, 0x23,
		0xd6, 0x69, 0x59, 0x26, 0x70, 0x0e, 0x9c, 0xab, 0x2b, 0xce, 0xf9, 0x3d, 0x47, 0x7b, 0x75, 0xa6,
		0x48, 0x77, 0xa8, 0x31, 0xc6, 0xf8, 0x95, 0xbe, 0x6a, 0x2d, 0xa9, 0x60, 0x03, 0x73, 0xbf, 0x77,
		0xdf, 0x72, 0xc4, 0x1a, 0xd2, 0xab, 0xa4, 0xa5, 0x3f, 0x65, 0x14, 0x94, 0x92, 0xb5, 0xd7, 0x0e,
		0x68, 0x35, 0x89, 0xfb, 0xf5, 0xf8, 0x61, 0x2f, 0xfe, 0x7e, 0xfe, 0x75, 0xc7, 0x69, 0x5e, 0x4d,
		0xfe, 0xb0, 0xfb, 0x75, 0xdb, 0x69, 0x5e, 0xbd, 0xc8, 0x92, 0xe4, 0xbd, 0x56, 0x46, 0x96, 0x98,
		0x64, 0x9d, 0xb4, 0xf8, 0xfa, 0xcc, 0xb4, 0x5e, 0x4f, 0xfe, 0x97, 0x05, 0x3a, 0xed, 0xfb, 0x35,
		0x3b, 0xed, 0xae, 0x73, 0x73, 0xe4, 0xbc, 0xbf, 0xfa, 0x6b, 0xe7, 0x65, 0xeb, 0xe1, 0xed, 0x8b,
		0xbf, 0x0e, 0x1e, 0x16, 0xff, 0xf2, 0xef, 0x55, 0x3f, 0xb6, 0xf3, 0xf2, 0xe0, 0xe1, 0xed, 0x9a,
		0x7f, 0xd9, 0x7f, 0x78, 0x9b, 0x72, 0x8c, 0xbd, 0x87, 0xe7, 0x4b, 0x3f, 0x3a, 0xf8, 0xfb, 0xe6,
		0xba, 0x0f, 0xb4, 0xd6, 0x7c, 0x60, 0x77, 0xdd, 0x07, 0x76, 0xd7, 0x7c, 0x60, 0xed, 0x57, 0x6a,
		0xae, 0xf9, 0xc0, 0xde, 0xc3, 0xdf, 0x4b, 0x3f, 0xff, 0x7c, 0xf5, 0x8f, 0xee, 0x3f, 0xbc, 0xf8,
		0x7b, 0xdd, 0xbf, 0x1d, 0x3c, 0xfc, 0xfd, 0xf6, 0xc5, 0x8b, 0xd7, 0xcf, 0x77, 0x06, 0x07, 0xf5,
		0xcd, 0xe8, 0xec, 0xee, 0x5c, 0x2d, 0x1d, 0xe9, 0xd1, 0x11, 0xad, 0x03, 0x04, 0xb2, 0xfd, 0x2a,
		0xbd, 0xfd, 0xf4, 0xec, 0xc2, 0x33, 0xbb, 0xcf, 0x7d, 0x28, 0x98, 0x7e, 0xa8, 0x78, 0xc1, 0x3c,
		0xfd, 0x7c, 0xfa, 0xdb, 0xd6, 0x75, 0xf7, 0x8d, 0xeb, 0xfe, 0x25, 0x53, 0x62, 0x45, 0xf6, 0xc9,
		0xca, 0x12, 0x38, 0xa7, 0xa8, 0x1d, 0xe8, 0x69, 0x06, 0x84, 0xc5, 0x71, 0x79, 0x50, 0xf8, 0xb0,
		0x38, 0x75, 0xed, 0x52, 0x47, 0xb3, 0x9c, 0xd5, 0x2a, 0xc7, 0x42, 0xe4, 0x68, 0xc9, 0x0b, 0x80,
		0x15, 0xd9, 0x92, 0xb3, 0x96, 0x26, 0x34, 0x4b, 0x92, 0xd6, 0xd2, 0x54, 0xaa, 0x22, 0x45, 0x13,
		0xa4, 0x00, 0x29, 0x9e, 0xfc, 0x86, 0x5c, 0x33, 0x22, 0xbf, 0x23, 0xbf, 0x97, 0x5a, 0x7e, 0xe7,
		0x9a, 0xd1, 0xc2, 0x9a, 0x71, 0xcd, 0x08, 0xce, 0x81, 0x73, 0xb9, 0xe2, 0x1c, 0xd7, 0x8c, 0xeb,
		0x2f, 0x1e, 0xb8, 0x66, 0xe4, 0x9a, 0x91, 0x99, 0x36, 0x29, 0x27, 0x73, 0xcd, 0x98, 0xdf, 0x69,
		0xe7, 0x9e, 0x87, 0x6b, 0xc6, 0x1c, 0x21, 0x90, 0xed, 0xc7, 0x35, 0xa3, 0x2c, 0x99, 0xde, 0xe2,
		0x9a, 0x71, 0xa2, 0xaa, 0x9b, 0xbb, 0x66, 0xcc, 0x90, 0xea, 0xaa, 0x70, 0x73, 0x20, 0x9a, 0xf5,
		0xf4, 0x2f, 0xef, 0x67, 0xf6, 0xc4, 0x44, 0xa5, 0xbe, 0xae, 0xea, 0xfd, 0x5c, 0x45, 0xfb, 0xb8,
		0xaa, 0xf5, 0x6f, 0x2d, 0x4e, 0x72, 0x75, 0xd6, 0xcd, 0xd8, 0xc8, 0x74, 0xd1, 0xb4, 0x2e, 0x09,
		0x79, 0x34, 0xf6, 0xc7, 0xf1, 0xd0, 0xe7, 0x19, 0xae, 0xc6, 0xca, 0x9b, 0xcb, 0xbd, 0x36, 0x9b,
		0xd9, 0x40, 0xf6, 0xf5, 0x6d, 0xe4, 0xb6, 0xbd, 0x9b, 0x7e, 0xe0, 0x44, 0x5e, 0x9c, 0xb8, 0x51,
		0x92, 0x3e, 0xe9, 0x7a, 0xe9, 0x93, 0xe4, 0x5a, 0x93, 0x6b, 0x3d, 0xfa, 0x41, 0x7a, 0xd5, 0x90,
		0x49, 0x9d, 0x07, 0xa7, 0xc8, 0x5e, 0xd6, 0x33, 0x74, 0xbf, 0x05, 0x5e, 0x47, 0xa3, 0x8c, 0xe7,
		0x78, 0x00, 0xc2, 0xa1, 0xcc, 0xdd, 0x59, 0x10, 0xe4, 0x90, 0x4b, 0x38, 0xd4, 0xb7, 0x6e, 0x37,
		0xf0, 0xdc, 0x50, 0x27, 0x1c, 0x6a, 0xa7, 0x00, 0x31, 0x4c, 0xdf, 0xbd, 0xa0, 0xe7, 0x45, 0x4e,
		0x37, 0x0c, 0x7e, 0xaa, 0x1f, 0xf3, 0xd9, 0x41, 0x38, 0xea, 0x1c, 0x75, 0x8e, 0x7a, 0x11, 0x8f,
		0xfa, 0xd8, 0x11, 0x71, 0x12, 0xff, 0x4e, 0x23, 0x6a, 0x71, 0x6e, 0x14, 0x0e, 0x3b, 0x87, 0xbd,
		0x62, 0x87, 0xbd, 0xef, 0x87, 0xc9, 0xce, 0xbe, 0xc6, 0x59, 0xdf, 0xa7, 0xfc, 0xa7, 0xda, 0x30,
		0x93, 0x1a, 0x95, 0xdb, 0x94, 0xff, 0x34, 0x35, 0xb5, 0xad, 0xed, 0xc3, 0x7d, 0xea, 0x7f, 0xe6,
		0x61, 0x7c, 0xe3, 0xc4, 0x0d, 0xbc, 0x51, 0xfd, 0xc9, 0x58, 0xd3, 0x02, 0x2f, 0x0f, 0x85, 0x19,
		0xc6, 0x0c, 0x57, 0xcc, 0x0c, 0x77, 0xbc, 0xb6, 0x7f, 0xe7, 0x06, 0xfb, 0x2d, 0x1d, 0xd6, 0xdd,
		0x54, 0xf8, 0xec, 0x12, 0xbe, 0x35, 0xeb, 0x6a, 0xcf, 0x9b, 0xd8, 0x73, 0x53, 0xf6, 0x7c, 0xb7,
		0x82, 0x53, 0x4b, 0x31, 0xef, 0x59, 0x88, 0x36, 0x7d, 0xdf, 0xbc, 0x78, 0xbd, 0x48, 0x6f, 0x3a,
		0x7a, 0xd3, 0x99, 0xa3, 0x1e, 0x5c, 0x62, 0x71, 0x89, 0x05, 0xcb, 0x46, 0xd9, 0x5e, 0x81, 0xcc,
		0x5c, 0x62, 0x71, 0xd4, 0x39, 0xea, 0x1c, 0x75, 0x4b, 0x47, 0x9d, 0x4b, 0x2c, 0x0e, 0x3b, 0x87,
		0x7d, 0xd3, 0x7a, 0x73, 0x89, 0xa5, 0xfa, 0xe2, 0x5c, 0x62, 0x19, 0x13, 0xbd, 0xb8, 0xc4, 0x2a,
		0xa4, 0xee, 0xc5, 0x25, 0x16, 0x66, 0x18, 0x33, 0x6c, 0xc4, 0x0c, 0x73, 0x89, 0x95, 0xbb, 0x3d,
		0xe7, 0x12, 0xcb, 0x98, 0x3d, 0xe7, 0x12, 0xab, 0x78, 0xc6, 0xbc, 0xe4, 0x97, 0x58, 0x75, 0xe8,
		0x45, 0x9b, 0x31, 0x31, 0x70, 0xeb, 0xc9, 0x04, 0xd0, 0xdf, 0xc6, 0x83, 0x7d, 0x1a, 0x8f, 0x65,
		0x20, 0x05, 0x72, 0xd4, 0x33, 0x37, 0xf6, 0x02, 0x6f, 0x78, 0xca, 0x9c, 0x6e, 0x6f, 0xf0, 0x9f,
		0x0c, 0xed, 0x67, 0xd7, 0x0d, 0x40, 0x42, 0x24, 0x09, 0x91, 0xa3, 0x1f, 0x24, 0x21, 0x92, 0xbb,
		0xe4, 0x3c, 0x0c, 0x5c, 0xe6, 0xbb, 0x64, 0xb7, 0x73, 0xef, 0x45, 0x89, 0x1f, 0x7b, 0x8e, 0x1f,
		0x0e, 0x48, 0xc7, 0xfd, 0xc4, 0x85, 0x55, 0x77, 0x84, 0xd7, 0x0f, 0x99, 0xb5, 0x6e, 0xef, 0xa8,
		0x21, 0xf9, 0x60, 0xcc, 0x1b, 0x37, 0x88, 0x71, 0xa8, 0x71, 0xa8, 0xb9, 0xc4, 0x5a, 0x46, 0xff,
		0x22, 0x5c, 0x62, 0xb9, 0xc1, 0x9f, 0xee, 0xcf, 0xd8, 0x69, 0x77, 0xef, 0x7a, 0x6e, 0xe4, 0x39,
		0x77, 0x3a, 0xd1, 0x29, 0x2b, 0xc6, 0x02, 0x38, 0x00, 0x0e, 0x80, 0xa3, 0x8a, 0xc0, 0x31, 0x0a,
		0x45, 0x73, 0x5c, 0xff, 0xb6, 0xa7, 0x1b, 0xcf, 0x36, 0x1a, 0x04, 0xa8, 0x00, 0x2a, 0x80, 0x8a,
		0x4a, 0x42, 0xc5, 0x8f, 0xc4, 0x8b, 0x42, 0x37, 0x98, 0x32, 0x83, 0xa1, 0x57, 0x11, 0x39, 0xbe,
		0x4e, 0x24, 0xec, 0xfa, 0x31, 0xd5, 0x81, 0x64, 0xb0, 0x1d, 0xc1, 0x11, 0x70, 0x04, 0x1c, 0x29,
		0x24, 0x8e, 0xf8, 0xb7, 0x61, 0x37, 0xf2, 0x1c, 0x37, 0x76, 0x7a, 0x6e, 0xf2, 0xdd, 0x09, 0xbc,
		0xf0, 0x76, 0x28, 0x71, 0x2b, 0x42, 0xc8, 0xea, 0xe1, 0xa0, 0x21, 0xc0, 0x07, 0xf0, 0x51, 0x61,
		0xf8, 0x08, 0xbd, 0x1f, 0x89, 0xf3, 0xbd, 0xdb, 0x73, 0xfc, 0xdb, 0x9e, 0x73, 0xe7, 0x25, 0x91,
		0xdf, 0xd6, 0xc6, 0x90, 0x55, 0x63, 0x02, 0x24, 0x00, 0x09, 0x40, 0x52, 0x1a, 0x20, 0x29, 0x57,
		0xb8, 0xc2, 0x9a, 0x8b, 0x6c, 0x52, 0x6f, 0x49, 0xbd, 0x35, 0x87, 0x55, 0x5c, 0x97, 0x6e, 0x71,
		0x5d, 0x8a, 0xe9, 0xc7, 0xf4, 0xd7, 0xd7, 0x87, 0xe0, 0xba, 0x14, 0xe0, 0x00, 0x38, 0x00, 0x8e,
		0xcc, 0xc0, 0xc1, 0x75, 0x29, 0x50, 0x01, 0x54, 0x00, 0x15, 0x69, 0xa0, 0x82, 0xeb, 0x52, 0x70,
		0x04, 0x1c, 0x01, 0x47, 0x34, 0x71, 0x84, 0xeb, 0x52, 0xe0, 0x03, 0xf8, 0x00, 0x3e, 0xf4, 0xe0,
		0x83, 0xeb, 0x52, 0x80, 0x04, 0x20, 0x01, 0x48, 0x54, 0x7e, 0xb2, 0xf0, 0xd7, 0xa5, 0x75, 0x48,
		0xf2, 0x56, 0xcb, 0x79, 0xde, 0x7a, 0x32, 0xd7, 0xfb, 0xd3, 0x60, 0xcc, 0x8b, 0xc9, 0x90, 0x67,
		0xe3, 0x11, 0x0d, 0x64, 0x7c, 0xa7, 0xbb, 0x5d, 0xce, 0x74, 0xab, 0x9c, 0x39, 0x9b, 0xbb, 0x49,
		0x36, 0xb7, 0x38, 0x14, 0x5b, 0xca, 0xe6, 0x76, 0xe3, 0xec, 0x91, 0x09, 0x6e, 0x9c, 0x31, 0x2c,
		0x61, 0x9b, 0x2c, 0x6e, 0xc2, 0x12, 0x14, 0x6d, 0xfe, 0xcc, 0xae, 0x73, 0xc2, 0xfe, 0xdd, 0x37,
		0x2f, 0xca, 0xb2, 0x64, 0xe3, 0x0d, 0x78, 0x90, 0xe1, 0x23, 0x6a, 0x95, 0x94, 0x14, 0x48, 0x8c,
		0x4e, 0xe5, 0x24, 0xcd, 0x32, 0x7d, 0xba, 0xe5, 0x7c, 0x24, 0xca, 0xf8, 0x28, 0x54, 0x46, 0xd2,
		0xaa, 0x88, 0x24, 0x35, 0x65, 0xad, 0xe6, 0x61, 0xeb, 0x70, 0xff, 0xa0, 0x79, 0xb8, 0x97, 0xe3,
		0xdc, 0x19, 0x22, 0xad, 0x57, 0x16, 0xc3, 0xe2, 0xb2, 0x6b, 0xf6, 0xf3, 0x45, 0x6a, 0x32, 0x48,
		0xf3, 0xd8, 0x21, 0xec, 0x90, 0x98, 0x1d, 0xea, 0x74, 0x93, 0xc4, 0xeb, 0x38, 0xff, 0xd7, 0x77,
		0x3b, 0x0a, 0x96, 0x68, 0xe7, 0x4d, 0x86, 0xcf, 0x9c, 0xbb, 0x49, 0xe2, 0x45, 0x61, 0x66, 0x63,
		0xd4, 0xf8, 0xef, 0xf3, 0xe7, 0x5f, 0xb7, 0x9d, 0xc3, 0xab, 0xbf, 0xbf, 0xee, 0x38, 0x87, 0x57,
		0xa3, 0xdf, 0xee, 0x0c, 0xff, 0x33, 0xfa, 0x7d, 0xf3, 0xeb, 0xb6, 0xd3, 0x9a, 0xfc, 0x7e, 0xef,
		0xeb, 0xb6, 0xb3, 0x77, 0xf5, 0xe2, 0x8f, 0x3f, 0x5e, 0xbd, 0xf8, 0x6b, 0xf7, 0x21, 0xfb, 0x07,
		0xff, 0x91, 0x7e, 0x0d, 0xaf, 0xb2, 0xbc, 0xfc, 0xd9, 0xc5, 0xc9, 0x7f, 0xaa, 0x37, 0x03, 0x16,
		0x11, 0x36, 0xe9, 0x26, 0x6e, 0x30, 0xbc, 0x8b, 0x50, 0x20, 0xf9, 0xb3, 0x1f, 0x06, 0x65, 0x41,
		0x59, 0xcb, 0x28, 0xdb, 0xf7, 0xc3, 0x64, 0xb7, 0x09, 0xd5, 0x87, 0xea, 0x43, 0xf5, 0x4b, 0x4f,
		0xf5, 0xc7, 0xb6, 0x64, 0x88, 0x86, 0x9e, 0xba, 0x2d, 0x9a, 0x7c, 0x1e, 0x73, 0x84, 0x39, 0xc2,
		0x1c, 0x61, 0x8e, 0x30, 0x47, 0x98, 0xa3, 0x6c, 0x3f, 0x91, 0xdb, 0x15, 0x63, 0x8a, 0x6b, 0x54,
		0xb5, 0xeb, 0xbf, 0x7e, 0xec, 0x39, 0x77, 0xfd, 0x20, 0xf1, 0x7b, 0x81, 0x97, 0xd2, 0xd5, 0x7b,
		0x04, 0xb5, 0xe5, 0xcf, 0x52, 0xe6, 0x99, 0x8b, 0xc1, 0xd1, 0x0f, 0x52, 0xe6, 0x19, 0x8e, 0x96,
		0x07, 0x47, 0x2b, 0x4d, 0xcb, 0x60, 0xe2, 0xeb, 0xb2, 0x8c, 0x40, 0x7c, 0x9d, 0x00, 0x9b, 0x22,
		0xbe, 0xce, 0x14, 0xea, 0x18, 0x8f, 0xaf, 0x5b, 0xe6, 0x5a, 0x39, 0x54, 0x22, 0xf1, 0xbe, 0x65,
		0xc8, 0xad, 0x7c, 0xc4, 0xc7, 0xf4, 0x47, 0x1e, 0x7b, 0x8e, 0x3d, 0xd7, 0xb5, 0xe7, 0x19, 0x89,
		0xa7, 0x1e, 0x01, 0x55, 0xdc, 0xb8, 0x58, 0x63, 0xac, 0x71, 0x56, 0x6b, 0x9c, 0xf5, 0x20, 0x4c,
		0x3f, 0xe8, 0x06, 0x41, 0xf7, 0xcf, 0x47, 0xe3, 0xe1, 0xc6, 0xea, 0xeb, 0xf6, 0x58, 0x58, 0x63,
		0x71, 0x48, 0xc5, 0x69, 0xd7, 0x24, 0xc1, 0x52, 0x0a, 0x99, 0xea, 0x31, 0x94, 0x38, 0x8e, 0x72,
		0xc7, 0x52, 0xea, 0x78, 0x8a, 0x1f, 0x53, 0xf1, 0xe3, 0x2a, 0x7a, 0x6c, 0xd5, 0x8e, 0xaf, 0x86,
		0x18, 0xac, 0x47, 0xae, 0x05, 0x49, 0xb6, 0x26, 0xd9, 0x56, 0x9f, 0x38, 0x15, 0x05, 0xfd, 0xce,
		0xfd, 0xe1, 0xdf, 0xf5, 0xef, 0x32, 0xc6, 0xa3, 0xac, 0x9d, 0xb5, 0xf9, 0xe1, 0xf4, 0xe1, 0x6b,
		0x07, 0xe8, 0x02, 0xba, 0x80, 0xae, 0x6c, 0xfb, 0x25, 0xf3, 0xb5, 0xe8, 0xba, 0xd3, 0x73, 0xa0,
		0x31, 0x84, 0x5e, 0xeb, 0xe3, 0xc9, 0x2f, 0xbd, 0xfd, 0xba, 0x25, 0xd5, 0x0a, 0x59, 0x08, 0x56,
		0x96, 0x86, 0x13, 0xea, 0xdf, 0x3b, 0x1d, 0x4f, 0xb0, 0x8f, 0xaf, 0xe6, 0x76, 0x9e, 0x5f, 0x02,
		0x81, 0x96, 0xc9, 0xa6, 0x97, 0x40, 0xf7, 0x1a, 0xd7, 0xca, 0x5a, 0x3c, 0xcb, 0xe7, 0xd3, 0x57,
		0xb6, 0x08, 0x8c, 0x51, 0x57, 0x4f, 0x51, 0x4d, 0x14, 0x51, 0x15, 0xbd, 0xc1, 0x3f, 0x67, 0x91,
		0x16, 0x15, 0xa4, 0xd7, 0x0c, 0x12, 0x5a, 0xb6, 0xe2, 0xc7, 0x4b, 0x06, 0x26, 0x4b, 0x11, 0x64,
		0x31, 0x2d, 0xa7, 0x89, 0x96, 0x83, 0x96, 0x83, 0x96, 0x83, 0x43, 0x84, 0x43, 0x84, 0x43, 0x84,
		0x96, 0x83, 0x96, 0x03, 0x74, 0x01, 0x5d, 0x68, 0x39, 0x68, 0x39, 0x68, 0x39, 0x68, 0x39, 0x68,
		0x39, 0x68, 0x39, 0x56, 0xb5, 0x9c, 0x0c, 0x15, 0xd8, 0x14, 0xa4, 0x9c, 0xd2, 0x47, 0xd1, 0x79,
		0x19, 0x63, 0xba, 0xd6, 0x56, 0x6c, 0xfb, 0x1c, 0x7b, 0x1f, 0xc6, 0x43, 0x9f, 0x0f, 0x46, 0xbe,
		0x3e, 0x4e, 0x4d, 0x03, 0x64, 0xa2, 0xf3, 0x7c, 0xa5, 0xe8, 0x3c, 0x9f, 0xe8, 0x3c, 0xa2, 0xf3,
		0x94, 0x4f, 0x2c, 0xd1, 0x79, 0xd2, 0x7e, 0x18, 0x8a, 0xae, 0x21, 0xff, 0xaa, 0xa0, 0x8a, 0x2e,
		0x52, 0x08, 0x52, 0x08, 0x52, 0x08, 0x52, 0x08, 0x52, 0x08, 0x52, 0x08, 0x52, 0x08, 0x52, 0x08,
		0x52, 0x88, 0x11, 0x37, 0xdf, 0x27, 0xac, 0x85, 0xb0, 0x16, 0x9c, 0x20, 0x9c, 0x20, 0x9c, 0x20,
		0x9c, 0x20, 0x9c, 0x20, 0x9c, 0x20, 0x9c, 0x20, 0x9c, 0x20, 0x9c, 0x20, 0x9c, 0xa0, 0xda, 0x39,
		0x41, 0xdc, 0x07, 0x6f, 0x9c, 0x23, 0x33, 0xf7, 0xc1, 0x27, 0x96, 0xef, 0x83, 0xb3, 0xf9, 0x98,
		0x4a, 0xbe, 0xa5, 0xf2, 0x8d, 0x70, 0x93, 0x1b, 0x61, 0x49, 0x02, 0x4a, 0xfd, 0x35, 0xea, 0xaf,
		0x21, 0xa7, 0x54, 0x4d, 0x4e, 0xa1, 0xfe, 0x5a, 0xa1, 0x99, 0x42, 0x1d, 0x5a, 0x9b, 0x66, 0x2e,
		0xf1, 0x9b, 0x8d, 0x13, 0x29, 0x57, 0x34, 0x7e, 0x96, 0x61, 0x96, 0xd2, 0xce, 0x4e, 0xea, 0x59,
		0x69, 0x3c, 0xd9, 0x4e, 0x75, 0xf5, 0xab, 0xaf, 0x7e, 0xd3, 0xe5, 0xf7, 0x58, 0xf1, 0x0e, 0x8d,
		0xd0, 0xf3, 0x6f, 0xbf, 0x7f, 0xeb, 0x46, 0xeb, 0x95, 0xd1, 0xe9, 0x81, 0x7f, 0xfc, 0xd1, 0x35,
		0x73, 0xf1, 0x34, 0x61, 0xdb, 0x68, 0x9d, 0xd2, 0x58, 0xa1, 0xf4, 0xd6, 0x26, 0xad, 0x55, 0xc9,
		0x6c, 0x3d, 0x32, 0x5b, 0x89, 0x4c, 0xd6, 0x20, 0xdb, 0xee, 0xdb, 0x44, 0x88, 0xa6, 0x6b, 0x96,
		0xbe, 0xf0, 0xf6, 0xf4, 0x13, 0x94, 0xdb, 0xa6, 0xdc, 0xf6, 0xe8, 0x07, 0xdd, 0x1b, 0xdf, 0x89,
		0xdd, 0x1b, 0x5f, 0xa5, 0x1d, 0xef, 0xf4, 0xa3, 0x84, 0x01, 0xe3, 0xf4, 0xd9, 0x71, 0xfa, 0x26,
		0x7b, 0x4e, 0xdd, 0xeb, 0x9b, 0x8e, 0x40, 0x28, 0x30, 0x6e, 0x5b, 0xa1, 0xdc, 0x36, 0xf5, 0xe2,
		0x0e, 0x9d, 0x8e, 0xd4, 0x0d, 0xf8, 0xe3, 0x50, 0x7a, 0x37, 0xd7, 0x3b, 0xdc, 0x5c, 0x73, 0x73,
		0xad, 0x3a, 0x98, 0xdd, 0x9b, 0x6b, 0xd5, 0x63, 0x37, 0x1d, 0x40, 0x31, 0x35, 0x65, 0xed, 0xb6,
		0x53, 0x4a, 0x55, 0x11, 0x3e, 0x88, 0x62, 0x07, 0x52, 0xf2, 0x60, 0xca, 0x1f, 0x50, 0xe9, 0x83,
		0x6a, 0xec, 0xc0, 0x1a, 0x3b, 0xb8, 0x46, 0x0e, 0xb0, 0xde, 0x41, 0xd6, 0x3c, 0xd0, 0x62, 0x07,
		0x7b, 0x3a, 0x90, 0x17, 0xf8, 0xb7, 0xfe, 0xb7, 0xc0, 0x1b, 0x77, 0x82, 0x74, 0x7a, 0xdd, 0xc0,
		0x6f, 0xff, 0x94, 0xdb, 0x2c, 0xd3, 0x0b, 0x89, 0xd5, 0xcf, 0x79, 0x59, 0xc8, 0xc8, 0x03, 0x29,
		0x60, 0x30, 0x01, 0x10, 0xe6, 0x80, 0xc2, 0x14, 0x60, 0x18, 0x07, 0x0e, 0xe3, 0x00, 0x62, 0x14,
		0x48, 0x64, 0x00, 0x45, 0x08, 0x58, 0xa6, 0x6f, 0xaa, 0x1d, 0xf3, 0xb6, 0x76, 0xbf, 0x06, 0x9e,
		0x7b, 0x13, 0x79, 0x37, 0x92, 0x1b, 0x76, 0xc2, 0x07, 0x0e, 0x04, 0xc7, 0x3c, 0x9f, 0x4a, 0xde,
		0x6d, 0x27, 0xea, 0x75, 0x83, 0xb7, 0x51, 0xb7, 0x9f, 0xf8, 0xe1, 0xed, 0x18, 0xb9, 0xa6, 0x7f,
		0x3d, 0xfa, 0xa3, 0xd3, 0xf1, 0x6e, 0xfc, 0xd0, 0x4f, 0xfc, 0x6e, 0x18, 0xaf, 0xff, 0xa7, 0xe9,
		0xbf, 0x0c, 0xb5, 0xf0, 0x67, 0xc5, 0xd8, 0x35, 0x12, 0x61, 0x64, 0x91, 0xd7, 0xf6, 0xfc, 0x7b,
		0x4f, 0xde, 0x6c, 0x4c, 0x06, 0x16, 0xda, 0xd5, 0x42, 0xe5, 0xf8, 0xb0, 0x3f, 0xd8, 0x1f, 0xec,
		0x4f, 0x49, 0xed, 0x8f, 0x7e, 0x39, 0xc1, 0xb5, 0xf6, 0x67, 0xa7, 0x42, 0x90, 0x1e, 0x7b, 0x61,
		0x47, 0x1e, 0xcf, 0x87, 0xa3, 0x02, 0xe6, 0x80, 0x39, 0x60, 0x0e, 0x98, 0x03, 0xe6, 0x36, 0xc1,
		0xdc, 0xb9, 0x93, 0xcc, 0xf5, 0x98, 0x05, 0xf4, 0xe1, 0xc8, 0x80, 0x2f, 0xe0, 0x0b, 0xf8, 0xd6,
		0x0a, 0x7c, 0xfb, 0x7e, 0x98, 0xbc, 0x31, 0x00, 0xbd, 0x7b, 0x82, 0x43, 0xca, 0x24, 0x3b, 0x2e,
		0xfe, 0x92, 0x3d, 0x4e, 0x5b, 0xd2, 0xc9, 0x90, 0x86, 0x51, 0x75, 0x69, 0x78, 0xe1, 0x64, 0xc9,
		0xa5, 0xf1, 0x0d, 0x24, 0xec, 0x19, 0x3a, 0x6d, 0xf3, 0x4b, 0xea, 0xfe, 0x28, 0xfd, 0x92, 0x36,
		0xf7, 0xf6, 0x4a, 0xbc, 0xa8, 0xcf, 0x8a, 0x39, 0xda, 0x55, 0x51, 0xa8, 0x65, 0xae, 0x77, 0x98,
		0x9a, 0x59, 0x9f, 0xcb, 0x24, 0x77, 0x63, 0xa8, 0xfa, 0x34, 0x12, 0x7c, 0xfa, 0xbb, 0xd7, 0xd3,
		0x40, 0xcf, 0xe9, 0xef, 0x5e, 0x4f, 0xe3, 0x84, 0x94, 0x6a, 0xe3, 0xc8, 0xcd, 0xb1, 0xc6, 0xfc,
		0x2a, 0xd6, 0xd2, 0x59, 0xcf, 0xf2, 0x15, 0x6a, 0xeb, 0xac, 0x75, 0xac, 0xa4, 0xa2, 0x36, 0x9a,
		0x44, 0x6d, 0x14, 0x80, 0xb2, 0x13, 0xb5, 0x91, 0xfe, 0x8d, 0x88, 0xda, 0xc0, 0xd7, 0xc7, 0xd7,
		0xc7, 0xd7, 0x2f, 0xa1, 0xaf, 0x4f, 0xd4, 0x06, 0x51, 0x1b, 0xa9, 0x37, 0x0b, 0x51, 0x1b, 0xd8,
		0x1f, 0xec, 0x0f, 0xf6, 0x47, 0x70, 0xbf, 0x72, 0xd1, 0x97, 0xce, 0xef, 0x27, 0x6a, 0x03, 0x30,
		0x07, 0xcc, 0x01, 0x73, 0xc0, 0xbc, 0x1a, 0x60, 0x4e, 0xd4, 0x06, 0xe0, 0x0b, 0xf8, 0x02, 0xbe,
		0x72, 0xfb, 0x95, 0xa8, 0x0d, 0xc1, 0x0d, 0x49, 0xd4, 0xc6, 0xfa, 0xf1, 0x89, 0xda, 0xc8, 0x6d,
		0x49, 0x89, 0xda, 0x30, 0x30, 0x1a, 0x51, 0x1b, 0xe5, 0x88, 0xda, 0x50, 0x28, 0xe6, 0x2d, 0x37,
		0xc5, 0x76, 0xeb, 0x7b, 0x08, 0x2d, 0x86, 0xfc, 0x22, 0x34, 0xb4, 0x62, 0x57, 0x16, 0xcb, 0x45,
		0x7e, 0x1c, 0x3f, 0xf2, 0xfa, 0xe8, 0xc6, 0xbf, 0x70, 0x6f, 0xfc, 0xeb, 0xa3, 0x4e, 0x27, 0x45,
		0xad, 0x4c, 0xb9, 0x35, 0x52, 0x58, 0x9f, 0x69, 0x31, 0x2e, 0x67, 0xfc, 0x26, 0xba, 0xd5, 0x8b,
		0xe6, 0x86, 0xa3, 0xf7, 0x0e, 0x15, 0x8c, 0x72, 0xf2, 0x9b, 0xca, 0xda, 0x7b, 0x47, 0xff, 0x06,
		0x5b, 0xe2, 0xc6, 0x7a, 0x7a, 0x43, 0xfd, 0xea, 0xd5, 0xc8, 0x50, 0xbd, 0x9e, 0x3f, 0xd8, 0x45,
		0x06, 0xb4, 0x5e, 0x2f, 0xf8, 0xa9, 0x1b, 0x6a, 0xf4, 0x88, 0x67, 0xb3, 0xa3, 0x51, 0x90, 0xad,
		0x31, 0x0e, 0x32, 0x00, 0xcf, 0x14, 0xf0, 0x6c, 0x38, 0x71, 0x94, 0x64, 0x53, 0xdb, 0x78, 0x94,
		0x64, 0xb3, 0x77, 0x44, 0xa5, 0x8f, 0xaa, 0xb1, 0x23, 0x6b, 0xec, 0xe8, 0x9a, 0x39, 0xc2, 0xc5,
		0x70, 0x8d, 0xc5, 0xc2, 0x7b, 0x3b, 0xa3, 0x3b, 0x72, 0xc7, 0xfb, 0xd1, 0xeb, 0x46, 0x89, 0xb1,
		0xe8, 0xde, 0xd5, 0x8f, 0x91, 0xbf, 0xe7, 0xff, 0x74, 0xfc, 0xff, 0x8e, 0xdf, 0x5d, 0x5e, 0x7f,
		0x3a, 0xfb, 0x7c, 0x79, 0xcc, 0x8d, 0x53, 0x91, 0x70, 0xc8, 0x14, 0x1e, 0x19, 0xc7, 0x25, 0xe3,
		0xf8, 0x64, 0x16, 0xa7, 0x64, 0xc5, 0xc9, 0xe2, 0xdf, 0x39, 0x4d, 0x90, 0x66, 0x1c, 0x5b, 0x9b,
		0x0c, 0x1e, 0x64, 0xe0, 0xf2, 0xbf, 0x25, 0x38, 0xe6, 0x71, 0xd8, 0xbf, 0x1b, 0x4c, 0xc6, 0x43,
		0x85, 0x02, 0x0a, 0x26, 0xcb, 0xe0, 0xdf, 0x59, 0xb1, 0x2b, 0xf3, 0x8f, 0xc1, 0xae, 0x60, 0x57,
		0xb0, 0x2b, 0xd8, 0x15, 0xec, 0x4a, 0xe5, 0xec, 0x8a, 0x61, 0x3f, 0xc5, 0x88, 0x7f, 0x02, 0xd0,
		0x03, 0xf4, 0x00, 0x7d, 0x59, 0x80, 0x9e, 0xf4, 0x43, 0xd1, 0xf4, 0x43, 0xa1, 0xf5, 0x3e, 0xf5,
		0xe3, 0xe4, 0x28, 0x49, 0x22, 0xd9, 0x35, 0xff, 0xe0, 0x87, 0xc7, 0x81, 0x37, 0x38, 0x32, 0xb1,
		0x6c, 0xa8, 0x54, 0xe3, 0x83, 0xfb, 0x63, 0x66, 0xe4, 0x9d, 0x37, 0xad, 0xd6, 0xfe, 0x41, 0xab,
		0xb5, 0x7d, 0xb0, 0x7b, 0xb0, 0x7d, 0xb8, 0xb7, 0xb7, 0xb3, 0xbf, 0x23, 0x19, 0xc3, 0x78, 0x16,
		0x75, 0xbc, 0xc8, 0xeb, 0xfc, 0xf2, 0x53, 0x1e, 0x14, 0xa7, 0xa1, 0x9c, 0xb1, 0x17, 0x49, 0xe3,
		0xa1, 0x21, 0x20, 0x5f, 0x04, 0xf3, 0xee, 0x68, 0x76, 0x9c, 0x6f, 0x3f, 0x1b, 0x06, 0x62, 0xf8,
		0x4c, 0x83, 0xfa, 0x12, 0xb0, 0x0f, 0x57, 0xa2, 0xa0, 0x71, 0x6b, 0x55, 0x62, 0x9a, 0x86, 0x95,
		0x0b, 0x23, 0x8a, 0x05, 0x4c, 0x13, 0xa6, 0x09, 0xd3, 0x84, 0x69, 0xc2, 0x34, 0x61, 0x9a, 0x30,
		0x4d, 0x98, 0x26, 0x4c, 0xd3, 0x38, 0xd3, 0x24, 0x43, 0x62, 0x55, 0x70, 0xfe, 0x4c, 0xc4, 0x25,
		0xa5, 0x2d, 0x29, 0x6d, 0x99, 0x1b, 0x95, 0x27, 0xfa, 0x8d, 0xe8, 0xb7, 0x27, 0x06, 0x22, 0xfa,
		0x0d, 0x49, 0x01, 0x49, 0x01, 0x49, 0xa1, 0x32, 0x92, 0x02, 0x51, 0x0a, 0x44, 0xbf, 0x61, 0x57,
		0xb0, 0x2b, 0xd8, 0x15, 0xec, 0x0a, 0x76, 0x85, 0xe8, 0xb7, 0x6c, 0xab, 0x4c, 0xf4, 0x1b, 0x40,
		0x0f, 0xd0, 0xd7, 0x1a, 0xe8, 0xb9, 0x93, 0xe4, 0x4e, 0x52, 0x60, 0x64, 0xee, 0x24, 0xf3, 0x02,
		0xf2, 0x2d, 0xee, 0x24, 0xf3, 0x40, 0xf6, 0x2d, 0xa2, 0xdf, 0xb2, 0x1c, 0x28, 0xa2, 0xdf, 0x60,
		0x9a, 0x30, 0x4d, 0x98, 0x26, 0x4c, 0x13, 0xa6, 0x09, 0xd3, 0x84, 0x69, 0xc2, 0x34, 0xcb, 0xc9,
		0x34, 0x89, 0x7e, 0xdb, 0x14, 0xfd, 0x46, 0x89, 0xe0, 0x42, 0xac, 0x83, 0xe9, 0x2a, 0xc1, 0x83,
		0x47, 0x9d, 0x8f, 0x9e, 0x54, 0xe0, 0xba, 0x9a, 0x9a, 0x05, 0xfd, 0x64, 0x0a, 0xf9, 0x55, 0xad,
		0x96, 0x26, 0xa5, 0x81, 0xd5, 0xdc, 0xa6, 0x12, 0x95, 0x06, 0xd6, 0xae, 0xa4, 0x29, 0x53, 0xa1,
		0x7b, 0x69, 0xf7, 0x49, 0x54, 0xea, 0x16, 0x96, 0x4f, 0x0a, 0x5f, 0x57, 0x93, 0xa6, 0xf9, 0x34,
		0xcd, 0x37, 0x2d, 0x76, 0x3c, 0xea, 0x9c, 0x1d, 0x2f, 0x4c, 0xfc, 0xe4, 0xa7, 0x8c, 0xd0, 0x31,
		0xb5, 0x9c, 0x02, 0x4e, 0x6d, 0xe3, 0x64, 0xfc, 0xd5, 0x7e, 0x71, 0x63, 0x03, 0x7d, 0x99, 0x8f,
		0xde, 0x9f, 0x5c, 0x5f, 0x0c, 0xfe, 0xe7, 0xf2, 0xf7, 0x73, 0xb1, 0x98, 0xb1, 0x61, 0xcf, 0x99,
		0x58, 0xb4, 0x59, 0x93, 0x21, 0x37, 0xfe, 0x74, 0xf7, 0xcb, 0xf9, 0xc7, 0xeb, 0x93, 0xf3, 0x2f,
		0xad, 0xeb, 0xcf, 0x1f, 0x4f, 0xde, 0x1d, 0x5d, 0x5c, 0x0a, 0x0a, 0x84, 0x2f, 0x0b, 0xff, 0xf6,
		0x27, 0x1f, 0xff, 0x75, 0x71, 0x79, 0x74, 0x79, 0x5c, 0xa7, 0x97, 0x1e, 0x2e, 0xf6, 0xe9, 0xd1,
		0x2f, 0xc7, 0xa7, 0xc7, 0xbf, 0xd6, 0x72, 0xd1, 0x9b, 0x83, 0x2d, 0xff, 0xe5, 0xfc, 0xf4, 0xa2,
		0x96, 0x5b, 0xfd, 0xfa, 0xe2, 0xfc, 0x7d, 0xad, 0x5e, 0x7c, 0x82, 0x70, 0xfb, 0x75, 0xdc, 0xec,
		0xc3, 0xf7, 0xae, 0xfd, 0x61, 0x3f, 0xfe, 0x72, 0xfe, 0xb1, 0x76, 0xab, 0x5e, 0xc3, 0xd5, 0xbe,
		0xf8, 0x74, 0x79, 0x7c, 0x7d, 0x7e, 0x76, 0x7a, 0xf2, 0xee, 0xf7, 0x21, 0xa7, 0xa9, 0x25, 0xce,
		0xb5, 0xae, 0x3f, 0x7c, 0x3e, 0xbd, 0xac, 0x23, 0xd2, 0xb5, 0xae, 0xdf, 0x9f, 0x9e, 0xfd, 0xfb,
		0xe2, 0xfc, 0xf8, 0x5d, 0x3d, 0x2d, 0x7b, 0xcd, 0x50, 0xee, 0xcb, 0xf9, 0xc7, 0x9a, 0x2e, 0xf9,
		0x02, 0xce, 0xed, 0xd7, 0xee, 0x9c, 0xd7, 0x91, 0xc9, 0x3c, 0xf2, 0x58, 0x13, 0xf8, 0x2e, 0x32,
		0xd2, 0x55, 0xde, 0xba, 0x5a, 0x2e, 0xd5, 0x37, 0xbc, 0xd0, 0xfd, 0x16, 0x78, 0x1d, 0x39, 0xb5,
		0x7c, 0x32, 0xa0, 0x6e, 0xf5, 0x81, 0xc7, 0xc4, 0xc8, 0x1b, 0x37, 0x88, 0xd1, 0xdd, 0x53, 0x4c,
		0x3d, 0xba, 0x3b, 0xba, 0xfb, 0xfa, 0x37, 0x92, 0xd7, 0xdd, 0xbf, 0x75, 0xbb, 0x81, 0xe7, 0x86,
		0x92, 0x9a, 0xfb, 0x0e, 0x31, 0x1c, 0x19, 0xc6, 0x91, 0x8a, 0xe1, 0xd0, 0x29, 0x1e, 0x65, 0x27,
		0xa6, 0xe2, 0x36, 0x72, 0xdb, 0xde, 0x4d, 0x3f, 0x70, 0x22, 0x2f, 0x4e, 0xdc, 0x28, 0xd1, 0x8f,
		0xae, 0x58, 0x1a, 0x91, 0x38, 0x0b, 0xe2, 0x2c, 0x72, 0x32, 0x10, 0x74, 0x2c, 0xa5, 0x63, 0x29,
		0x0c, 0x0f, 0x86, 0x57, 0x94, 0x8a, 0x6d, 0x52, 0x4e, 0xa1, 0x21, 0xe7, 0xd0, 0x94, 0x93, 0x28,
		0xec, 0x2c, 0x8a, 0x43, 0x8a, 0x09, 0x68, 0x31, 0x07, 0x31, 0xa6, 0xa0, 0xc6, 0x38, 0xe4, 0x18,
		0x87, 0x1e, 0xa3, 0x10, 0x24, 0x2b, 0x8a, 0x15, 0x3f, 0xc3, 0x4d, 0xce, 0x09, 0x15, 0x76, 0x46,
		0xe5, 0x16, 0x82, 0x04, 0x90, 0x55, 0x4e, 0xeb, 0xa2, 0x03, 0x47, 0x09, 0x64, 0x4a, 0x20, 0x43,
		0xa7, 0xa1, 0xd3, 0xc5, 0xa3, 0xd3, 0x6e, 0xe7, 0xde, 0x8b, 0x12, 0x3f, 0x36, 0xc1, 0xa8, 0x67,
		0xc6, 0x86, 0xfc, 0x42, 0x7e, 0x21, 0xbf, 0x90, 0xdf, 0x8a, 0x91, 0xdf, 0x97, 0xe8, 0x19, 0x40,
		0x3a, 0x90, 0x0e, 0xa4, 0x03, 0xe9, 0x40, 0xfa, 0xf4, 0x9d, 0x22, 0xaf, 0xed, 0xf9, 0xf7, 0x26,
		0x30, 0x7d, 0x3a, 0x32, 0xe0, 0x0b, 0xf8, 0x02, 0xbe, 0x80, 0x6f, 0xc5, 0xc0, 0x17, 0x31, 0x39,
		0x8d, 0x98, 0x4c, 0x45, 0xa1, 0xc2, 0xac, 0x85, 0xe1, 0xaa, 0x42, 0xbf, 0x8d, 0x1f, 0xf7, 0x69,
		0xfc, 0xb4, 0x02, 0x47, 0xc1, 0xf9, 0xbd, 0xfb, 0x96, 0x13, 0xb8, 0xdf, 0xbc, 0xc0, 0xeb, 0x38,
		0xfd, 0xd0, 0x6f, 0xbb, 0xb1, 0x40, 0x24, 0xdc, 0xca, 0x51, 0x89, 0x86, 0x23, 0x1a, 0x2e, 0x27,
		0xf2, 0x51, 0xb2, 0x68, 0xb8, 0xd1, 0x8a, 0x38, 0x81, 0x7f, 0xe7, 0x27, 0x72, 0x77, 0x78, 0x73,
		0xa3, 0x12, 0x19, 0x67, 0xcf, 0xd3, 0xe0, 0x2a, 0x8f, 0xab, 0xbc, 0xf5, 0x03, 0x09, 0x85, 0xbe,
		0x2e, 0x6d, 0x5f, 0x91, 0x10, 0x58, 0xe1, 0x03, 0x8f, 0xe4, 0x80, 0xe4, 0x80, 0xe4, 0x20, 0x0b,
		0x20, 0xd3, 0x01, 0xef, 0xdc, 0x1f, 0xce, 0x68, 0xd5, 0x87, 0xb5, 0xb6, 0x0c, 0xe5, 0xdd, 0xce,
		0x3d, 0x45, 0x78, 0xf1, 0x65, 0x75, 0x4d, 0x63, 0x60, 0x63, 0x12, 0x74, 0xcc, 0x83, 0x8f, 0x69,
		0x10, 0xb2, 0x06, 0x46, 0xd6, 0x40, 0xc9, 0x0a, 0x38, 0xc9, 0x82, 0x94, 0x30, 0x58, 0x4d, 0x67,
		0x40, 0x5c, 0x27, 0x5d, 0xda, 0xef, 0x7d, 0x3f, 0x4c, 0x76, 0x9b, 0x26, 0xf6, 0xfb, 0x18, 0x5d,
		0x0e, 0x0c, 0x0c, 0xfd, 0xc9, 0x0d, 0x6f, 0x3d, 0xd1, 0xfa, 0x86, 0xb3, 0xbf, 0xcc, 0x9c, 0xcf,
		0xad, 0x71, 0x83, 0x07, 0x63, 0x00, 0x60, 0x18, 0xd6, 0x97, 0x1e, 0x33, 0xac, 0x32, 0x69, 0xe1,
		0x39, 0xef, 0x23, 0xb7, 0x9d, 0xf8, 0xdd, 0xf0, 0x57, 0xff, 0xd6, 0x1f, 0xf5, 0xc5, 0x30, 0xf6,
		0xbc, 0x87, 0x97, 0x06, 0x97, 0xde, 0xfd, 0x51, 0xb9, 0xa5, 0x6f, 0x35, 0x0f, 0x5b, 0x87, 0xfb,
		0x07, 0xcd, 0xc3, 0xbd, 0x0a, 0xed, 0x81, 0x67, 0xe5, 0x18, 0xf5, 0xaa, 0xa8, 0x3d, 0x37, 0x04,
		0xfd, 0xb6, 0x5e, 0xe4, 0xdd, 0x7b, 0x61, 0xe2, 0x24, 0x9e, 0x1b, 0x75, 0xba, 0x7f, 0x86, 0xe6,
		0x68, 0xf6, 0xd2, 0x93, 0x84, 0x0d, 0xb9, 0xa1, 0xb8, 0x30, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f,
		0x95, 0x37, 0x14, 0xfa, 0xb0, 0x08, 0x2f, 0x42, 0x21, 0x10, 0xc5, 0x36, 0x3a, 0xe3, 0x3b, 0x6b,
		0x27, 0xf1, 0xef, 0xbc, 0xc8, 0x9c, 0xc5, 0x99, 0x7f, 0x0c, 0xe6, 0x00, 0x73, 0x80, 0x39, 0xc0,
		0x1c, 0x08, 0xee, 0xf7, 0x8e, 0xd7, 0xf6, 0xef, 0xdc, 0x60, 0xbf, 0x65, 0xd2, 0x20, 0x34, 0x0d,
		0x8c, 0xbd, 0xe4, 0xec, 0x35, 0x91, 0x90, 0xf2, 0x91, 0x90, 0x9a, 0x48, 0x48, 0x75, 0x95, 0x90,
		0x76, 0x59, 0x7a, 0x94, 0xa3, 0xf2, 0x92, 0xf8, 0x3f, 0xdd, 0x28, 0xf4, 0xc3, 0x5b, 0x27, 0xf9,
		0x1e, 0x79, 0xf1, 0xf7, 0x6e, 0xd0, 0x71, 0x7a, 0xed, 0xc4, 0x1c, 0x99, 0x5f, 0xfd, 0x38, 0x48,
		0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x17, 0xdc, 0xef, 0x3d, 0x2f, 0x6a, 0x7b, 0x61, 0xe2, 0xde,
		0x7a, 0x06, 0x59, 0xfd, 0x1e, 0x7c, 0x3b, 0x1f, 0xbe, 0xcd, 0x95, 0x6d, 0x6d, 0xf9, 0xb6, 0xad,
		0xa5, 0xdf, 0xd9, 0x86, 0x71, 0xc3, 0xb8, 0x45, 0x47, 0x92, 0x8a, 0xd0, 0x14, 0xce, 0x2c, 0x9c,
		0x8e, 0x2b, 0x95, 0xd5, 0xb6, 0x2a, 0xcb, 0xea, 0xf5, 0x6c, 0x96, 0x87, 0x48, 0xfd, 0x3a, 0xb9,
		0xb5, 0x91, 0x48, 0xd2, 0x97, 0xa9, 0x6b, 0xb7, 0x44, 0x63, 0x24, 0xea, 0xdb, 0x2d, 0x22, 0xa8,
		0x78, 0xac, 0x7c, 0x93, 0x58, 0xf9, 0x12, 0xf9, 0x3b, 0xc4, 0xca, 0x13, 0x2b, 0x4f, 0xac, 0x3c,
		0xe2, 0x0b, 0xe2, 0x0b, 0xe2, 0x8b, 0xa1, 0xfd, 0x4e, 0xac, 0x3c, 0xc2, 0x0b, 0xc2, 0x0b, 0xc2,
		0x8b, 0xd2, 0xd2, 0x13, 0x2b, 0x8f, 0xfe, 0x62, 0xf0, 0x0c, 0x11, 0x2b, 0x0f, 0x95, 0x87, 0xca,
		0x43, 0xe5, 0xa1, 0xf2, 0xa9, 0xf6, 0x3b, 0xb1, 0xf2, 0x22, 0xef, 0x4a, 0xac, 0x3c, 0xe6, 0x00,
		0x73, 0x80, 0x39, 0x28, 0xbb, 0x39, 0x20, 0x56, 0x1e, 0x09, 0x49, 0x73, 0x79, 0x89, 0x95, 0xaf,
		0xad, 0x84, 0x44, 0xac, 0x3c, 0xca, 0x51, 0x89, 0x49, 0x3c, 0xb1, 0xf2, 0x90, 0x7a, 0x48, 0x3d,
		0xa4, 0xbe, 0x6a, 0xa4, 0x9e, 0x58, 0xf9, 0x2a, 0xf3, 0x6d, 0xae, 0x6c, 0x6b, 0xcb, 0xb7, 0x89,
		0x95, 0x87, 0x71, 0xdb, 0x67, 0xdc, 0xc4, 0xca, 0x8b, 0xc6, 0xca, 0x0b, 0xb4, 0xe7, 0x91, 0x5b,
		0x1a, 0x5a, 0x2a, 0x29, 0x2d, 0x62, 0x43, 0x24, 0xc3, 0x60, 0x63, 0x7f, 0x9f, 0x93, 0xde, 0x7d,
		0xeb, 0x74, 0xf4, 0x35, 0x3e, 0x8f, 0xbe, 0xc5, 0xf5, 0xc8, 0x5f, 0x3a, 0x1d, 0x7e, 0x09, 0x5a,
		0x3c, 0x15, 0x64, 0x6f, 0x18, 0x6e, 0xf3, 0xb4, 0xbc, 0x0d, 0x0a, 0xdf, 0xe9, 0x49, 0xb6, 0xc3,
		0x13, 0x9d, 0x9d, 0xe8, 0xec, 0x94, 0xb3, 0xd6, 0x50, 0xb2, 0xce, 0x4e, 0x42, 0xcd, 0x5e, 0x64,
		0x9b, 0xbc, 0xd0, 0xcd, 0x29, 0x4f, 0x71, 0x91, 0x6e, 0x4e, 0x05, 0x60, 0xbc, 0x62, 0xdd, 0x9c,
		0x62, 0x2f, 0xec, 0x38, 0x9d, 0x51, 0xc0, 0xa8, 0x13, 0x75, 0xfb, 0x46, 0x92, 0x55, 0x97, 0x9f,
		0x21, 0x95, 0x67, 0x67, 0x26, 0xd2, 0x95, 0x86, 0xd5, 0x64, 0xc4, 0x92, 0x11, 0x2b, 0xaa, 0xb7,
		0xd0, 0xb0, 0x1a, 0x75, 0xc5, 0x84, 0x07, 0x3d, 0x51, 0x55, 0x24, 0x2a, 0x47, 0x68, 0x48, 0x19,
		0x2f, 0x69, 0x9e, 0x0a, 0xdd, 0x86, 0x6e, 0x43, 0xb7, 0xed, 0xf8, 0xd3, 0x66, 0xfc, 0x6a, 0xe1,
		0x03, 0x0f, 0xfd, 0x85, 0xfe, 0x42, 0x7f, 0x65, 0x01, 0x64, 0x3a, 0x20, 0x05, 0x61, 0x2c, 0x81,
		0x8d, 0x49, 0xd0, 0x31, 0x0f, 0x3e, 0xa6, 0x41, 0xc8, 0x1a, 0x18, 0x59, 0x03, 0x25, 0x2b, 0xe0,
		0x24, 0x0b, 0x52, 0xc2, 0x60, 0x65, 0xce, 0x67, 0x5f, 0xda, 0xef, 0x14, 0x84, 0x59, 0xfa, 0x45,
		0x74, 0x61, 0xaa, 0xc7, 0x10, 0x5d, 0x98, 0x6d, 0xe9, 0x29, 0x08, 0x53, 0x8e, 0x3d, 0x40, 0x90,
		0x61, 0x51, 0xce, 0x10, 0x05, 0x61, 0xa0, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x3e, 0xd5, 0x7e,
		0xa7, 0x20, 0x8c, 0xc8, 0xbb, 0x52, 0x10, 0x06, 0x73, 0x80, 0x39, 0xc0, 0x1c, 0x94, 0xdd, 0x1c,
		0x50, 0x10, 0x06, 0x09, 0x49, 0x73, 0x79, 0x29, 0x08, 0x53, 0x5b, 0x09, 0x89, 0x82, 0x30, 0x28,
		0x47, 0x25, 0x26, 0xf1, 0x14, 0x84, 0x81, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x55, 0x23, 0xf5, 0x14,
		0x84, 0xa9, 0x32, 0xdf, 0xe6, 0xca, 0xb6, 0xb6, 0x7c, 0x9b, 0x82, 0x30, 0x30, 0x6e, 0xfb, 0x8c,
		0x9b, 0x82, 0x30, 0xaa, 0xd9, 0x2e, 0x34, 0x4d, 0x55, 0xa1, 0x2f, 0x34, 0x4d, 0x2d, 0xaa, 0xdf,
		0x43, 0x8c, 0x7c, 0x2e, 0x7e, 0x0d, 0x31, 0xf2, 0x02, 0x87, 0x81, 0x18, 0x79, 0x44, 0x17, 0x44,
		0x17, 0x44, 0x17, 0x53, 0xfb, 0x9d, 0x18, 0x79, 0x04, 0x17, 0x04, 0x17, 0x04, 0x17, 0xa5, 0xa5,
		0x27, 0x46, 0x1e, 0xdd, 0xc5, 0xe0, 0x19, 0x22, 0x46, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43,
		0xe5, 0x53, 0xed, 0x77, 0x62, 0xe4, 0x45, 0xde, 0x95, 0x18, 0x79, 0xcc, 0x01, 0xe6, 0x00, 0x73,
		0x50, 0x76, 0x73, 0x40, 0x8c, 0x3c, 0x12, 0x92, 0xe6, 0xf2, 0x12, 0x23, 0x5f, 0x5b, 0x09, 0x89,
		0x18, 0x79, 0x94, 0xa3, 0x12, 0x93, 0x78, 0x62, 0xe4, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x7d, 0xd5,
		0x48, 0x3d, 0x31, 0xf2, 0x55, 0xe6, 0xdb, 0x5c, 0xd9, 0xd6, 0x96, 0x6f, 0x13, 0x23, 0x0f, 0xe3,
		0xb6, 0xcf, 0xb8, 0x89, 0x91, 0x17, 0x89, 0x91, 0xa7, 0x59, 0xaa, 0xa9, 0x45, 0x34, 0xbf, 0x78,
		0x16, 0x9b, 0xa4, 0x16, 0xa9, 0x3b, 0xaa, 0x56, 0x2f, 0x50, 0x89, 0xfc, 0x09, 0xd1, 0xbc, 0x09,
		0xf1, 0x26, 0x22, 0x4d, 0x9a, 0x88, 0x14, 0xc0, 0x97, 0xa5, 0x89, 0x48, 0xfa, 0x37, 0xa2, 0x67,
		0xdf, 0x16, 0x3d, 0xfb, 0x48, 0xc8, 0x22, 0x21, 0xab, 0x2c, 0x74, 0x9f, 0x9e, 0x7d, 0x90, 0x7c,
		0x93, 0x24, 0x5f, 0xc0, 0x29, 0x7b, 0x28, 0x49, 0x23, 0x6e, 0xa1, 0xf5, 0x30, 0xb2, 0x0e, 0x0d,
		0x2d, 0x4f, 0x23, 0x8b, 0x5f, 0xa5, 0xb6, 0xd6, 0xd9, 0x57, 0x4a, 0x61, 0x95, 0x1a, 0x7e, 0xef,
		0x7e, 0xdf, 0x09, 0xdc, 0x6f, 0x5e, 0xe0, 0x75, 0xa6, 0x33, 0xa3, 0xba, 0x56, 0x53, 0xa0, 0x5b,
		0x39, 0xaa, 0xe2, 0x1e, 0xd2, 0xf3, 0xa0, 0xb4, 0x09, 0x8d, 0x04, 0x81, 0x91, 0x23, 0x2c, 0x52,
		0x04, 0x45, 0x9c, 0x90, 0x88, 0x13, 0x10, 0x51, 0xc2, 0x61, 0x17, 0xf5, 0x74, 0x3d, 0x1e, 0x7a,
		0xa3, 0x22, 0x6b, 0x20, 0x6b, 0xd4, 0x45, 0xd6, 0xa0, 0x37, 0x2a, 0x32, 0x03, 0x32, 0x43, 0xfd,
		0x64, 0x06, 0xea, 0xbe, 0x18, 0xd6, 0x32, 0x8d, 0x81, 0x8d, 0x49, 0xd0, 0x31, 0x0f, 0x3e, 0xa6,
		0x41, 0xc8, 0x1a, 0x18, 0x59, 0x03, 0x25, 0x2b, 0xe0, 0x24, 0x0b, 0x52, 0xc2, 0x60, 0x35, 0x9d,
		0x01, 0xea, 0xbe, 0xac, 0x1c, 0x9a, 0x20, 0x42, 0xfb, 0xb0, 0xbe, 0xf4, 0x18, 0x82, 0x08, 0xb3,
		0x2d, 0x3d, 0x75, 0x5f, 0xca, 0xb1, 0x07, 0x88, 0x25, 0x2c, 0xca, 0x19, 0xa2, 0xee, 0x0b, 0x54,
		0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0xa7, 0xda, 0xef, 0xd4, 0x7d, 0x11, 0x79, 0x57, 0xea, 0xbe,
		0x60, 0x0e, 0x30, 0x07, 0x98, 0x83, 0xb2, 0x9b, 0x03, 0xea, 0xbe, 0x20, 0x21, 0x69, 0x2e, 0x2f,
		0x75, 0x5f, 0x6a, 0x2b, 0x21, 0x51, 0xf7, 0x05, 0xe5, 0xa8, 0xc4, 0x24, 0x9e, 0xba, 0x2f, 0x90,
		0x7a, 0x48, 0x3d, 0xa4, 0xbe, 0x6a, 0xa4, 0x9e, 0xba, 0x2f, 0x55, 0xe6, 0xdb, 0x5c, 0xd9, 0xd6,
		0x96, 0x6f, 0x53, 0xf7, 0x05, 0xc6, 0x6d, 0x9f, 0x71, 0x53, 0xf7, 0x25, 0x5b, 0x36, 0xdb, 0x52,
		0x96, 0x15, 0x3d, 0x52, 0x95, 0x68, 0x0c, 0x3d, 0x52, 0x8b, 0xea, 0xff, 0x10, 0x2b, 0x9f, 0x8b,
		0x7f, 0x43, 0xac, 0xbc, 0xc0, 0x61, 0x20, 0x56, 0x1e, 0xf1, 0x05, 0xf1, 0x05, 0xf1, 0xc5, 0xd4,
		0x7e, 0x27, 0x56, 0x1e, 0xe1, 0x05, 0xe1, 0x05, 0xe1, 0x45, 0x69, 0xe9, 0x89, 0x95, 0x47, 0x7f,
		0x31, 0x78, 0x86, 0x88, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x54, 0xfb, 0x9d,
		0x58, 0x79, 0x91, 0x77, 0x25, 0x56, 0x1e, 0x73, 0x80, 0x39, 0xc0, 0x1c, 0x94, 0xdd, 0x1c, 0x10,
		0x2b, 0x8f, 0x84, 0xa4, 0xb9, 0xbc, 0xc4, 0xca, 0xd7, 0x56, 0x42, 0x22, 0x56, 0x1e, 0xe5, 0xa8,
		0xc4, 0x24, 0x9e, 0x58, 0x79, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x5f, 0x35, 0x52, 0x4f, 0xac, 0x7c,
		0x95, 0xf9, 0x36, 0x57, 0xb6, 0xb5, 0xe5, 0xdb, 0xc4, 0xca, 0xc3, 0xb8, 0xed, 0x33, 0x6e, 0x62,
		0xe5, 0x45, 0x63, 0xe5, 0xe9, 0x95, 0x6a, 0x6a, 0x31, 0xed, 0x2d, 0xa2, 0xbd, 0x9e, 0xa9, 0xfb,
		0xa7, 0xa3, 0xaf, 0x51, 0xa4, 0xd6, 0xa9, 0x75, 0x6f, 0xed, 0x24, 0xd5, 0x72, 0x48, 0x7d, 0x1b,
		0x14, 0xbe, 0xd3, 0x93, 0x6c, 0x87, 0x27, 0x3a, 0x3b, 0xd1, 0xd9, 0x29, 0x67, 0xad, 0xa1, 0x64,
		0x9d, 0x9d, 0x84, 0x9a, 0xbd, 0xc8, 0x36, 0x79, 0xa1, 0x9b, 0x53, 0x9e, 0xe2, 0x22, 0xdd, 0x9c,
		0x0a, 0xc0, 0x78, 0x69, 0x52, 0xbd, 0x45, 0x93, 0x6a, 0x32, 0x62, 0xc9, 0x88, 0x2d, 0x8b, 0xde,
		0x42, 0x93, 0x6a, 0xd4, 0x15, 0x13, 0x1e, 0xf4, 0x44, 0x55, 0x91, 0xa8, 0x1c, 0xa1, 0x21, 0x65,
		0xbc, 0xa4, 0x79, 0x2a, 0x74, 0x1b, 0xba, 0x0d, 0xdd, 0xb6, 0xe3, 0x4f, 0x9b, 0xf1, 0xab, 0x85,
		0x0f, 0x3c, 0xf4, 0x17, 0xfa, 0x0b, 0xfd, 0x95, 0x05, 0x90, 0xe9, 0x80, 0x14, 0x84, 0xb1, 0x04,
		0x36, 0x26, 0x41, 0xc7, 0x3c, 0xf8, 0x98, 0x06, 0x21, 0x6b, 0x60, 0x64, 0x0d, 0x94, 0xac, 0x80,
		0x93, 0x2c, 0x48, 0x09, 0x83, 0x95, 0x39, 0x9f, 0x7d, 0x69, 0xbf, 0x53, 0x10, 0x66, 0xe9, 0x17,
		0xd1, 0x85, 0xa9, 0x1e, 0x43, 0x74, 0x61, 0xb6, 0xa5, 0xa7, 0x20, 0x4c, 0x39, 0xf6, 0x00, 0x41,
		0x86, 0x45, 0x39, 0x43, 0x14, 0x84, 0x81, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x54, 0xfb,
		0x9d, 0x82, 0x30, 0x22, 0xef, 0x4a, 0x41, 0x18, 0xcc, 0x01, 0xe6, 0x00, 0x73, 0x50, 0x76, 0x73,
		0x40, 0x41, 0x18, 0x24, 0x24, 0xcd, 0xe5, 0xa5, 0x20, 0x4c, 0x6d, 0x25, 0x24, 0x0a, 0xc2, 0xa0,
		0x1c, 0x95, 0x98, 0xc4, 0x53, 0x10, 0x06, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x57, 0x8d, 0xd4, 0x53,
		0x10, 0xa6, 0xca, 0x7c, 0x9b, 0x2b, 0xdb, 0xda, 0xf2, 0x6d, 0x0a, 0xc2, 0xc0, 0xb8, 0xed, 0x33,
		0x6e, 0x0a, 0xc2, 0xa8, 0x66, 0xbb, 0xd0, 0x34, 0x55, 0x85, 0xbe, 0xd0, 0x34, 0xb5, 0xa8, 0x7e,
		0x0f, 0x31, 0xf2, 0xb9, 0xf8, 0x35, 0xc4, 0xc8, 0x0b, 0x1c, 0x06, 0x62, 0xe4, 0x11, 0x5d, 0x10,
		0x5d, 0x10, 0x5d, 0x4c, 0xed, 0x77, 0x62, 0xe4, 0x11, 0x5c, 0x10, 0x5c, 0x10, 0x5c, 0x94, 0x96,
		0x9e, 0x18, 0x79, 0x74, 0x17, 0x83, 0x67, 0x88, 0x18, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f,
		0x95, 0x4f, 0xb5, 0xdf, 0x89, 0x91, 0x17, 0x79, 0x57, 0x62, 0xe4, 0x31, 0x07, 0x98, 0x03, 0xcc,
		0x41, 0xd9, 0xcd, 0x01, 0x31, 0xf2, 0x48, 0x48, 0x9a, 0xcb, 0x4b, 0x8c, 0x7c, 0x6d, 0x25, 0x24,
		0x62, 0xe4, 0x51, 0x8e, 0x4a, 0x4c, 0xe2, 0x89, 0x91, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x55,
		0x23, 0xf5, 0xc4, 0xc8, 0x57, 0x99, 0x6f, 0x73, 0x65, 0x5b, 0x5b, 0xbe, 0x4d, 0x8c, 0x3c, 0x8c,
		0xdb, 0x3e, 0xe3, 0x26, 0x46, 0x5e, 0x24, 0x46, 0x9e, 0x66, 0xa9, 0xa6, 0x16, 0xd1, 0xfc, 0xe2,
		0x59, 0x6c, 0x92, 0x5a, 0xa4, 0xee, 0xa8, 0x5a, 0xbd, 0x40, 0x25, 0xf2, 0x27, 0x44, 0xf3, 0x26,
		0xc4, 0x9b, 0x88, 0x34, 0x69, 0x22, 0x52, 0x00, 0x5f, 0x96, 0x26, 0x22, 0xe9, 0xdf, 0x88, 0x9e,
		0x7d, 0x5b, 0xf4, 0xec, 0x23, 0x21, 0x8b, 0x84, 0xac, 0xb2, 0xd0, 0x7d, 0x7a, 0xf6, 0x41, 0xf2,
		0x4d, 0x92, 0x7c, 0x01, 0xa7, 0xec, 0xa1, 0x24, 0x8d, 0xb8, 0x85, 0xd6, 0xc3, 0xc8, 0x3a, 0x34,
		0xb4, 0x3c, 0x8d, 0x2c, 0x7e, 0x95, 0xda, 0x5a, 0x67, 0x5f, 0x29, 0x85, 0x55, 0x6a, 0x04, 0xcd,
		0xfb, 0x5e, 0xe8, 0x78, 0xf7, 0x3d, 0xf5, 0x15, 0x9a, 0xc2, 0xdb, 0xcc, 0x58, 0x8a, 0xfb, 0x45,
		0xcf, 0x5b, 0xd2, 0x26, 0x2f, 0x12, 0x64, 0x45, 0x8e, 0x9c, 0x48, 0x91, 0x11, 0x71, 0xf2, 0x21,
		0x4e, 0x36, 0x44, 0xc9, 0x85, 0x5d, 0x84, 0xd3, 0xf5, 0x6e, 0xe8, 0x83, 0x8a, 0x84, 0x81, 0x84,
		0x51, 0x17, 0x09, 0x83, 0x3e, 0xa8, 0x48, 0x0a, 0x48, 0x0a, 0xf5, 0x93, 0x14, 0xa8, 0xf1, 0x62,
		0x58, 0xb7, 0x34, 0x06, 0x36, 0x26, 0x41, 0xc7, 0x3c, 0xf8, 0x98, 0x06, 0x21, 0x6b, 0x60, 0x64,
		0x0d, 0x94, 0xac, 0x80, 0x93, 0x2c, 0x48, 0x09, 0x83, 0xd5, 0x74, 0x06, 0xa8, 0xf1, 0xb2, 0x72,
		0x68, 0x02, 0x06, 0xed, 0xc3, 0xfa, 0xd2, 0x63, 0x08, 0x18, 0xcc, 0xb6, 0xf4, 0xd4, 0x78, 0x29,
		0xc7, 0x1e, 0x20, 0x6e, 0xb0, 0x28, 0x67, 0x88, 0x1a, 0x2f, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e,
		0x2a, 0x9f, 0x6a, 0xbf, 0x53, 0xe3, 0x45, 0xe4, 0x5d, 0xa9, 0xf1, 0x82, 0x39, 0xc0, 0x1c, 0x60,
		0x0e, 0xca, 0x6e, 0x0e, 0xa8, 0xf1, 0x82, 0x84, 0xa4, 0xb9, 0xbc, 0xd4, 0x78, 0xa9, 0xad, 0x84,
		0x44, 0x8d, 0x17, 0x94, 0xa3, 0x12, 0x93, 0x78, 0x6a, 0xbc, 0x40, 0xea, 0x21, 0xf5, 0x90, 0xfa,
		0xaa, 0x91, 0x7a, 0x6a, 0xbc, 0x54, 0x99, 0x6f, 0x73, 0x65, 0x5b, 0x5b, 0xbe, 0x4d, 0x8d, 0x17,
		0x18, 0xb7, 0x7d, 0xc6, 0x4d, 0x8d, 0x97, 0x0c, 0x99, 0x6b, 0x8f, 0xb9, 0x55, 0x74, 0x41, 0x55,
		0x22, 0x2f, 0x74, 0x41, 0x2d, 0xaa, 0xd7, 0x43, 0x84, 0x7c, 0x2e, 0x5e, 0x0d, 0x11, 0xf2, 0x02,
		0x87, 0x81, 0x08, 0x79, 0x24, 0x17, 0x24, 0x17, 0x24, 0x17, 0x53, 0xfb, 0x9d, 0x08, 0x79, 0xe4,
		0x16, 0xe4, 0x16, 0xe4, 0x16, 0xa5, 0xa5, 0x27, 0x42, 0x1e, 0xd5, 0xc5, 0xe0, 0x19, 0x22, 0x42,
		0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x53, 0xed, 0x77, 0x22, 0xe4, 0x45, 0xde, 0x95,
		0x08, 0x79, 0xcc, 0x01, 0xe6, 0x00, 0x73, 0x50, 0x76, 0x73, 0x40, 0x84, 0x3c, 0x12, 0x92, 0xe6,
		0xf2, 0x12, 0x21, 0x5f, 0x5b, 0x09, 0x89, 0x08, 0x79, 0x94, 0xa3, 0x12, 0x93, 0x78, 0x22, 0xe4,
		0x21, 0xf5, 0x90, 0x7a, 0x48, 0x7d, 0xd5, 0x48, 0x3d, 0x11, 0xf2, 0x55, 0xe6, 0xdb, 0x5c, 0xd9,
		0xd6, 0x96, 0x6f, 0x13, 0x21, 0x0f, 0xe3, 0xb6, 0xcf, 0xb8, 0x89, 0x90, 0x17, 0x88, 0x90, 0xa7,
		0x07, 0xaa, 0xa9, 0x25, 0x34, 0xbd, 0x74, 0x96, 0x3a, 0xa0, 0x9e, 0x36, 0xbf, 0xf4, 0xc2, 0xe3,
		0xfb, 0x5e, 0x58, 0x88, 0xfe, 0xa7, 0xb5, 0xee, 0xcf, 0xa4, 0xdd, 0x41, 0x28, 0xf3, 0x9a, 0x17,
		0xbf, 0x37, 0xd3, 0x7d, 0x2f, 0x88, 0xa5, 0x7a, 0x33, 0x0d, 0xc7, 0xa2, 0x37, 0x13, 0xbd, 0x99,
		0x72, 0xd2, 0x0d, 0xe8, 0xcd, 0x44, 0x6f, 0xa6, 0xfc, 0x44, 0x44, 0x7a, 0x33, 0xd1, 0x9b, 0x69,
		0xfd, 0x40, 0xf4, 0x66, 0x92, 0x18, 0x90, 0xcc, 0x53, 0x32, 0x4f, 0xcb, 0xa5, 0x6b, 0x90, 0x79,
		0x6a, 0x49, 0xf4, 0xe4, 0x2a, 0xd3, 0x2a, 0x08, 0x59, 0x03, 0x23, 0x6b, 0xa0, 0x64, 0x05, 0x9c,
		0x64, 0x41, 0x4a, 0x18, 0xac, 0xa6, 0x33, 0x40, 0xe6, 0xe9, 0xca, 0xa1, 0xb9, 0xc6, 0xb4, 0x0f,
		0xeb, 0x4b, 0x8f, 0xe1, 0x1a, 0x33, 0xdb, 0xd2, 0x93, 0x79, 0x5a, 0x8e, 0x3d, 0xc0, 0x6d, 0x66,
		0x51, 0xce, 0x10, 0x99, 0xa7, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x9f, 0x6a, 0xbf, 0x93,
		0x79, 0x2a, 0xf2, 0xae, 0x64, 0x9e, 0x62, 0x0e, 0x30, 0x07, 0x98, 0x83, 0xb2, 0x9b, 0x03, 0x32,
		0x4f, 0x91, 0x90, 0x34, 0x97, 0x97, 0xcc, 0xd3, 0xda, 0x4a, 0x48, 0x64, 0x9e, 0xa2, 0x1c, 0x95,
		0x98, 0xc4, 0x93, 0x79, 0x0a, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0xab, 0x46, 0xea, 0xc9, 0x3c, 0xad,
		0x32, 0xdf, 0xe6, 0xca, 0xb6, 0xb6, 0x7c, 0x9b, 0xcc, 0x53, 0x18, 0xb7, 0x7d, 0xc6, 0x4d, 0xe6,
		0x69, 0xe6, 0xac, 0xb5, 0xfb, 0x5e, 0x10, 0xd3, 0x9b, 0x49, 0x89, 0xbc, 0xd0, 0x9b, 0xa9, 0xa8,
		0x5e, 0x0f, 0x11, 0xf2, 0xb9, 0x78, 0x35, 0x44, 0xc8, 0x0b, 0x1c, 0x06, 0x22, 0xe4, 0x91, 0x5c,
		0x90, 0x5c, 0x90, 0x5c, 0x4c, 0xed, 0x77, 0x22, 0xe4, 0x91, 0x5b, 0x90, 0x5b, 0x90, 0x5b, 0x94,
		0x96, 0x9e, 0x08, 0x79, 0x54, 0x17, 0x83, 0x67, 0x88, 0x08, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a,
		0x0f, 0x95, 0x4f, 0xb5, 0xdf, 0x89, 0x90, 0x17, 0x79, 0x57, 0x22, 0xe4, 0x31, 0x07, 0x98, 0x03,
		0xcc, 0x41, 0xd9, 0xcd, 0x01, 0x11, 0xf2, 0x48, 0x48, 0x9a, 0xcb, 0x4b, 0x84, 0x7c, 0x6d, 0x25,
		0x24, 0x22, 0xe4, 0x51, 0x8e, 0x4a, 0x4c, 0xe2, 0x89, 0x90, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5,
		0x55, 0x23, 0xf5, 0x44, 0xc8, 0x57, 0x99, 0x6f, 0x73, 0x65, 0x5b, 0x5b, 0xbe, 0x4d, 0x84, 0x3c,
		0x8c, 0xdb, 0x3e, 0xe3, 0x26, 0x42, 0x5e, 0x20, 0x42, 0x9e, 0xde, 0x4c, 0xa6, 0x96, 0xd0, 0xf4,
		0xd2, 0xd9, 0xec, 0xcd, 0xf4, 0xa5, 0x17, 0xc4, 0xf4, 0x66, 0x2a, 0xce, 0x46, 0xb0, 0xd1, 0x9b,
		0x69, 0xb0, 0xe6, 0x85, 0xee, 0xcd, 0xb4, 0x3b, 0x98, 0x0d, 0xbf, 0x77, 0xdf, 0x72, 0xee, 0xfa,
		0x41, 0xe2, 0xb7, 0xdd, 0x38, 0x11, 0xe8, 0xd2, 0xb4, 0x6a, 0x54, 0xfa, 0x35, 0xd1, 0xaf, 0x29,
		0x27, 0x2d, 0x81, 0x7e, 0x4d, 0xf4, 0x6b, 0xca, 0x4f, 0x58, 0xa4, 0x5f, 0x13, 0xfd, 0x9a, 0xd6,
		0x0f, 0x44, 0xbf, 0x26, 0x89, 0x01, 0xc9, 0x46, 0x25, 0x1b, 0xb5, 0x5c, 0x5a, 0x07, 0xd9, 0xa8,
		0x96, 0x84, 0x50, 0xae, 0x37, 0xad, 0x82, 0x90, 0x35, 0x30, 0xb2, 0x06, 0x4a, 0x56, 0xc0, 0x49,
		0x16, 0xa4, 0x84, 0xc1, 0x6a, 0x3a, 0x03, 0x64, 0xa3, 0xae, 0x1c, 0x9a, 0xab, 0x4d, 0xfb, 0xb0,
		0xbe, 0xf4, 0x18, 0xae, 0x36, 0xb3, 0x2d, 0x3d, 0xd9, 0xa8, 0xe5, 0xd8, 0x03, 0xdc, 0x70, 0x16,
		0xe5, 0x0c, 0x91, 0x8d, 0x0a, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0xa9, 0xf6, 0x3b, 0xd9,
		0xa8, 0x22, 0xef, 0x4a, 0x36, 0x2a, 0xe6, 0x00, 0x73, 0x80, 0x39, 0x28, 0xbb, 0x39, 0x20, 0x1b,
		0x15, 0x09, 0x49, 0x73, 0x79, 0xc9, 0x46, 0xad, 0xad, 0x84, 0x44, 0x36, 0x2a, 0xca, 0x51, 0x89,
		0x49, 0x3c, 0xd9, 0xa8, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0xbe, 0x6a, 0xa4, 0x9e, 0x6c, 0xd4, 0x2a,
		0xf3, 0x6d, 0xae, 0x6c, 0x6b, 0xcb, 0xb7, 0xc9, 0x46, 0x85, 0x71, 0xdb, 0x67, 0xdc, 0x64, 0xa3,
		0x66, 0xc9, 0x64, 0x5b, 0x91, 0x65, 0x45, 0xe7, 0x26, 0x25, 0x1a, 0x43, 0xe7, 0xa6, 0xa2, 0xfa,
		0x3f, 0xc4, 0xca, 0xe7, 0xe2, 0xdf, 0x10, 0x2b, 0x2f, 0x70, 0x18, 0x88, 0x95, 0x47, 0x7c, 0x41,
		0x7c, 0x41, 0x7c, 0x31, 0xb5, 0xdf, 0x89, 0x95, 0x47, 0x78, 0x41, 0x78, 0x41, 0x78, 0x51, 0x5a,
		0x7a, 0x62, 0xe5, 0xd1, 0x5f, 0x0c, 0x9e, 0x21, 0x62, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c,
		0x54, 0x3e, 0xd5, 0x7e, 0x27, 0x56, 0x5e, 0xe4, 0x5d, 0x89, 0x95, 0xc7, 0x1c, 0x60, 0x0e, 0x30,
		0x07, 0x65, 0x37, 0x07, 0xc4, 0xca, 0x23, 0x21, 0x69, 0x2e, 0x2f, 0xb1, 0xf2, 0xb5, 0x95, 0x90,
		0x88, 0x95, 0x47, 0x39, 0x2a, 0x31, 0x89, 0x27, 0x56, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x57,
		0x8d, 0xd4, 0x13, 0x2b, 0x5f, 0x65, 0xbe, 0xcd, 0x95, 0x6d, 0x6d, 0xf9, 0x36, 0xb1, 0xf2, 0x30,
		0x6e, 0xfb, 0x8c, 0x9b, 0x58, 0x79, 0xd1, 0x58, 0x79, 0x7a, 0x38, 0x99, 0x5a, 0x4c, 0x7b, 0x8b,
		0x68, 0xab, 0x9b, 0xd3, 0xee, 0x97, 0x5e, 0x78, 0xd2, 0xbb, 0x6f, 0x7d, 0x98, 0x7c, 0x0b, 0xda,
		0x3a, 0x15, 0x71, 0x6f, 0x98, 0x6e, 0xf0, 0xb4, 0xb4, 0x0d, 0x4a, 0xd2, 0xe9, 0xa9, 0x1f, 0xca,
		0xf7, 0x79, 0x9a, 0x8c, 0x49, 0x97, 0x27, 0xba, 0x3c, 0xe5, 0xa4, 0x3b, 0xd0, 0xe5, 0x89, 0x2e,
		0x4f, 0xf9, 0x89, 0x90, 0x74, 0x79, 0xa2, 0xcb, 0xd3, 0xfa, 0x81, 0xe8, 0xf2, 0x24, 0x31, 0x20,
		0x99, 0xab, 0x64, 0xae, 0x96, 0x4b, 0x17, 0x21, 0x73, 0xd5, 0x92, 0x68, 0xca, 0x55, 0xa8, 0x55,
		0x10, 0xb2, 0x06, 0x46, 0xd6, 0x40, 0xc9, 0x0a, 0x38, 0xc9, 0x82, 0x94, 0x30, 0x58, 0x4d, 0x67,
		0x80, 0xcc, 0xd5, 0x95, 0x43, 0x73, 0x0d, 0x6a, 0x1f, 0xd6, 0x97, 0x1e, 0xc3, 0x35, 0x68, 0xb6,
		0xa5, 0x27, 0x73, 0xb5, 0x1c, 0x7b, 0x80, 0xdb, 0xd0, 0xa2, 0x9c, 0x21, 0x32, 0x57, 0xa1, 0xf2,
		0x50, 0x79, 0xa8, 0x3c, 0x54, 0x3e, 0xd5, 0x7e, 0x27, 0x73, 0x55, 0xe4, 0x5d, 0xc9, 0x5c, 0xc5,
		0x1c, 0x60, 0x0e, 0x30, 0x07, 0x65, 0x37, 0x07, 0x64, 0xae, 0x22, 0x21, 0x69, 0x2e, 0x2f, 0x99,
		0xab, 0xb5, 0x95, 0x90, 0xc8, 0x5c, 0x45, 0x39, 0x2a, 0x31, 0x89, 0x27, 0x73, 0x15, 0x52, 0x0f,
		0xa9, 0x87, 0xd4, 0x57, 0x8d, 0xd4, 0x93, 0xb9, 0x5a, 0x65, 0xbe, 0xcd, 0x95, 0x6d, 0x6d, 0xf9,
		0x36, 0x99, 0xab, 0x30, 0x6e, 0xfb, 0x8c, 0x9b, 0xcc, 0x55, 0xb5, 0xc4, 0xb6, 0x71, 0x8e, 0x15,
		0x3d, 0x9e, 0x94, 0x48, 0x0c, 0x3d, 0x9e, 0x8a, 0xea, 0xfd, 0x10, 0x29, 0x9f, 0x8b, 0x77, 0x43,
		0xa4, 0xbc, 0xc0, 0x61, 0x20, 0x52, 0x1e, 0xe9, 0x05, 0xe9, 0x05, 0xe9, 0xc5, 0xd4, 0x7e, 0x27,
		0x52, 0x1e, 0xd9, 0x05, 0xd9, 0x05, 0xd9, 0x45, 0x69, 0xe9, 0x89, 0x94, 0x47, 0x7d, 0x31, 0x78,
		0x86, 0x88, 0x94, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x54, 0xfb, 0x9d, 0x48, 0x79,
		0x91, 0x77, 0x25, 0x52, 0x1e, 0x73, 0x80, 0x39, 0xc0, 0x1c, 0x94, 0xdd, 0x1c, 0x10, 0x29, 0x8f,
		0x84, 0xa4, 0xb9, 0xbc, 0x44, 0xca, 0xd7, 0x56, 0x42, 0x22, 0x52, 0x1e, 0xe5, 0xa8, 0xc4, 0x24,
		0x9e, 0x48, 0x79, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x5f, 0x35, 0x52, 0x4f, 0xa4, 0x7c, 0x95, 0xf9,
		0x36, 0x57, 0xb6, 0xb5, 0xe5, 0xdb, 0x44, 0xca, 0xc3, 0xb8, 0xed, 0x33, 0x6e, 0x22, 0xe5, 0x05,
		0x23, 0xe5, 0xe9, 0xf0, 0x64, 0x6a, 0x29, 0x6d, 0x2d, 0xa1, 0xed, 0xfe, 0x4e, 0x9f, 0x43, 0xba,
		0x3b, 0x15, 0xad, 0xbb, 0x93, 0x5e, 0xa3, 0x21, 0xd5, 0x2d, 0x50, 0x8a, 0xce, 0x4e, 0xfb, 0x33,
		0xad, 0xaf, 0xe4, 0x7a, 0x3b, 0xed, 0x6b, 0x37, 0xd4, 0xa2, 0xbb, 0x93, 0x09, 0xe5, 0x82, 0xee,
		0x4e, 0x06, 0x01, 0x90, 0xee, 0x4e, 0xb6, 0xe5, 0x49, 0xba, 0x3b, 0xd1, 0xdd, 0xc9, 0x32, 0x0b,
		0xa6, 0xbb, 0x53, 0x11, 0x0e, 0xbe, 0x09, 0x00, 0x30, 0x07, 0x04, 0xa6, 0x00, 0xc1, 0x38, 0x30,
		0x18, 0x07, 0x08, 0xa3, 0x40, 0x51, 0x4c, 0x45, 0x84, 0x9c, 0x55, 0x4b, 0x72, 0x29, 0x97, 0xa0,
		0x56, 0x41, 0xc8, 0x1a, 0x18, 0x59, 0x03, 0x25, 0x2b, 0xe0, 0x24, 0x0b, 0x52, 0xc2, 0x60, 0x35,
		0x9d, 0x01, 0x72, 0x56, 0x57, 0x0e, 0xcd, 0x05, 0xa8, 0x7d, 0x58, 0x5f, 0x7a, 0x0c, 0x17, 0xa0,
		0xd9, 0x96, 0x9e, 0x9c, 0xd5, 0x72, 0xec, 0x01, 0xee, 0x41, 0x8b, 0x72, 0x86, 0xc8, 0x59, 0x85,
		0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x54, 0xfb, 0x9d, 0x9c, 0x55, 0x91, 0x77, 0x25, 0x67,
		0x15, 0x73, 0x80, 0x39, 0xc0, 0x1c, 0x94, 0xdd, 0x1c, 0x90, 0xb3, 0x8a, 0x84, 0xa4, 0xb9, 0xbc,
		0xe4, 0xac, 0xd6, 0x56, 0x42, 0x22, 0x67, 0x15, 0xe5, 0xa8, 0xc4, 0x24, 0x9e, 0x9c, 0x55, 0x48,
		0x3d, 0xa4, 0x1e, 0x52, 0x5f, 0x35, 0x52, 0x4f, 0xce, 0x6a, 0x95, 0xf9, 0x36, 0x57, 0xb6, 0xb5,
		0xe5, 0xdb, 0xe4, 0xac, 0xc2, 0xb8, 0xed, 0x33, 0x6e, 0x72, 0x56, 0x55, 0x12, 0xdb, 0x66, 0xb2,
		0xac, 0xe8, 0xef, 0xa4, 0x44, 0x63, 0xe8, 0xef, 0x54, 0x54, 0xff, 0x87, 0x58, 0xf9, 0x5c, 0xfc,
		0x1b, 0x62, 0xe5, 0x05, 0x0e, 0x03, 0xb1, 0xf2, 0x88, 0x2f, 0x88, 0x2f, 0x88, 0x2f, 0xa6, 0xf6,
		0x3b, 0xb1, 0xf2, 0x08, 0x2f, 0x08, 0x2f, 0x08, 0x2f, 0x4a, 0x4b, 0x4f, 0xac, 0x3c, 0xfa, 0x8b,
		0xc1, 0x33, 0x44, 0xac, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0xa7, 0xda, 0xef, 0xc4,
		0xca, 0x8b, 0xbc, 0x2b, 0xb1, 0xf2, 0x98, 0x03, 0xcc, 0x01, 0xe6, 0xa0, 0xec, 0xe6, 0x80, 0x58,
		0x79, 0x24, 0x24, 0xcd, 0xe5, 0x25, 0x56, 0xbe, 0xb6, 0x12, 0x12, 0xb1, 0xf2, 0x28, 0x47, 0x25,
		0x26, 0xf1, 0xc4, 0xca, 0x43, 0xea, 0x21, 0xf5, 0x90, 0xfa, 0xaa, 0x91, 0x7a, 0x62, 0xe5, 0xab,
		0xcc, 0xb7, 0xb9, 0xb2, 0xad, 0x2d, 0xdf, 0x26, 0x56, 0x1e, 0xc6, 0x6d, 0x9f, 0x71, 0x13, 0x2b,
		0x2f, 0x1a, 0x2b, 0x4f, 0x87, 0x27, 0x53, 0x8b, 0x69, 0x6f, 0x11, 0x2d, 0xf7, 0x78, 0xda, 0xff,
		0x30, 0xf9, 0x16, 0x74, 0x79, 0x2a, 0xe2, 0xde, 0xb0, 0xd4, 0xe7, 0xe9, 0x71, 0x1b, 0x94, 0xa4,
		0xd3, 0xd3, 0xa4, 0x0d, 0x96, 0x64, 0x9f, 0x27, 0xbd, 0xd6, 0x5a, 0x74, 0x79, 0x32, 0xa1, 0x5f,
		0xd0, 0xe5, 0xc9, 0x20, 0x00, 0xd2, 0xe5, 0xc9, 0xb6, 0x48, 0x49, 0x97, 0x27, 0xba, 0x3c, 0x59,
		0x66, 0xc2, 0x74, 0x79, 0x2a, 0xc2, 0xc1, 0x37, 0x01, 0x00, 0xe6, 0x80, 0xc0, 0x14, 0x20, 0x18,
		0x07, 0x06, 0xe3, 0x00, 0x61, 0x14, 0x28, 0x8a, 0xa9, 0x8b, 0x90, 0xb9, 0x6a, 0x49, 0x34, 0xe5,
		0x2a, 0xd4, 0x2a, 0x08, 0x59, 0x03, 0x23, 0x6b, 0xa0, 0x64, 0x05, 0x9c, 0x64, 0x41, 0x4a, 0x18,
		0xac, 0xa6, 0x33, 0x40, 0xe6, 0xea, 0xca, 0xa1, 0xb9, 0x06, 0xb5, 0x0f, 0xeb, 0x4b, 0x8f, 0xe1,
		0x1a, 0x34, 0xdb, 0xd2, 0x93, 0xb9, 0x5a, 0x8e, 0x3d, 0xc0, 0x6d, 0x68, 0x51, 0xce, 0x10, 0x99,
		0xab, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x9f, 0x6a, 0xbf, 0x93, 0xb9, 0x2a, 0xf2, 0xae,
		0x64, 0xae, 0x62, 0x0e, 0x30, 0x07, 0x98, 0x83, 0xb2, 0x9b, 0x03, 0x32, 0x57, 0x91, 0x90, 0x34,
		0x97, 0x97, 0xcc, 0xd5, 0xda, 0x4a, 0x48, 0x64, 0xae, 0xa2, 0x1c, 0x95, 0x98, 0xc4, 0x93, 0xb9,
		0x0a, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0xab, 0x46, 0xea, 0xc9, 0x5c, 0xad, 0x32, 0xdf, 0xe6, 0xca,
		0xb6, 0xb6, 0x7c, 0x9b, 0xcc, 0x55, 0x18, 0xb7, 0x7d, 0xc6, 0x4d, 0xe6, 0xaa, 0x5a, 0x62, 0xdb,
		0x38, 0xc7, 0x8a, 0x1e, 0x4f, 0x4a, 0x24, 0x86, 0x1e, 0x4f, 0x45, 0xf5, 0x7e, 0x88, 0x94, 0xcf,
		0xc5, 0xbb, 0x21, 0x52, 0x5e, 0xe0, 0x30, 0x10, 0x29, 0x8f, 0xf4, 0x82, 0xf4, 0x82, 0xf4, 0x62,
		0x6a, 0xbf, 0x13, 0x29, 0x8f, 0xec, 0x82, 0xec, 0x82, 0xec, 0xa2, 0xb4, 0xf4, 0x44, 0xca, 0xa3,
		0xbe, 0x18, 0x3c, 0x43, 0x44, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0xaa, 0xfd,
		0x4e, 0xa4, 0xbc, 0xc8, 0xbb, 0x12, 0x29, 0x8f, 0x39, 0xc0, 0x1c, 0x60, 0x0e, 0xca, 0x6e, 0x0e,
		0x88, 0x94, 0x47, 0x42, 0xd2, 0x5c, 0x5e, 0x22, 0xe5, 0x6b, 0x2b, 0x21, 0x11, 0x29, 0x8f, 0x72,
		0x54, 0x62, 0x12, 0x4f, 0xa4, 0x3c, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xaf, 0x1a, 0xa9, 0x27, 0x52,
		0xbe, 0xca, 0x7c, 0x9b, 0x2b, 0xdb, 0xda, 0xf2, 0x6d, 0x22, 0xe5, 0x61, 0xdc, 0xf6, 0x19, 0x37,
		0x91, 0xf2, 0x82, 0x91, 0xf2, 0x74, 0x78, 0x32, 0xb5, 0x94, 0xb6, 0x96, 0xd0, 0x76, 0x7f, 0xa7,
		0xcf, 0x21, 0xdd, 0x9d, 0x8a, 0xd6, 0xdd, 0x49, 0xaf, 0xd1, 0x90, 0xea, 0x16, 0x28, 0x72, 0x67,
		0xa7, 0x38, 0x4a, 0x3c, 0xa7, 0xd7, 0x0d, 0xfc, 0xf6, 0xcf, 0xc1, 0x14, 0xb5, 0xf4, 0xfb, 0x3a,
		0x2d, 0x8d, 0x48, 0x57, 0x27, 0xba, 0x3a, 0xe5, 0xa4, 0x34, 0xd0, 0xd5, 0x89, 0xae, 0x4e, 0xf9,
		0xc9, 0x8e, 0x74, 0x75, 0xa2, 0xab, 0xd3, 0xfa, 0x81, 0xe8, 0xea, 0x24, 0x31, 0x20, 0xb9, 0xaa,
		0xe4, 0xaa, 0x96, 0x4b, 0x09, 0x21, 0x57, 0xd5, 0x92, 0x4c, 0xca, 0xe5, 0xa7, 0x55, 0x10, 0xb2,
		0x06, 0x46, 0xd6, 0x40, 0xc9, 0x0a, 0x38, 0xc9, 0x82, 0x94, 0x30, 0x58, 0x4d, 0x67, 0x80, 0x5c,
		0xd5, 0x95, 0x43, 0x73, 0xf1, 0x69, 0x1f, 0xd6, 0x97, 0x1e, 0xc3, 0xc5, 0x67, 0xb6, 0xa5, 0x27,
		0x57, 0xb5, 0x1c, 0x7b, 0x80, 0xfb, 0xcf, 0xa2, 0x9c, 0x21, 0x72, 0x55, 0xa1, 0xf2, 0x50, 0x79,
		0xa8, 0x3c, 0x54, 0x3e, 0xd5, 0x7e, 0x27, 0x57, 0x55, 0xe4, 0x5d, 0xc9, 0x55, 0xc5, 0x1c, 0x60,
		0x0e, 0x30, 0x07, 0x65, 0x37, 0x07, 0xe4, 0xaa, 0x22, 0x21, 0x69, 0x2e, 0x2f, 0xb9, 0xaa, 0xb5,
		0x95, 0x90, 0xc8, 0x55, 0x45, 0x39, 0x2a, 0x31, 0x89, 0x27, 0x57, 0x15, 0x52, 0x0f, 0xa9, 0x87,
		0xd4, 0x57, 0x8d, 0xd4, 0x93, 0xab, 0x5a, 0x65, 0xbe, 0xcd, 0x95, 0x6d, 0x6d, 0xf9, 0x36, 0xb9,
		0xaa, 0x30, 0x6e, 0xfb, 0x8c, 0x9b, 0x5c, 0xd5, 0x0c, 0x09, 0x6d, 0x8b, 0x19, 0x56, 0xf4, 0x74,
		0x52, 0xa2, 0x30, 0xf4, 0x74, 0x2a, 0xaa, 0xef, 0x43, 0x9c, 0x7c, 0x2e, 0xbe, 0x0d, 0x71, 0xf2,
		0x02, 0x87, 0x81, 0x38, 0x79, 0x84, 0x17, 0x84, 0x17, 0x84, 0x17, 0x53, 0xfb, 0x9d, 0x38, 0x79,
		0x44, 0x17, 0x44, 0x17, 0x44, 0x17, 0xa5, 0xa5, 0x27, 0x4e, 0x1e, 0xed, 0xc5, 0xe0, 0x19, 0x22,
		0x4e, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x53, 0xed, 0x77, 0xe2, 0xe4, 0x45, 0xde,
		0x95, 0x38, 0x79, 0xcc, 0x01, 0xe6, 0x00, 0x73, 0x50, 0x76, 0x73, 0x40, 0x9c, 0x3c, 0x12, 0x92,
		0xe6, 0xf2, 0x12, 0x27, 0x5f, 0x5b, 0x09, 0x89, 0x38, 0x79, 0x94, 0xa3, 0x12, 0x93, 0x78, 0xe2,
		0xe4, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x7d, 0xd5, 0x48, 0x3d, 0x71, 0xf2, 0x55, 0xe6, 0xdb, 0x5c,
		0xd9, 0xd6, 0x96, 0x6f, 0x13, 0x27, 0x0f, 0xe3, 0xb6, 0xcf, 0xb8, 0x89, 0x93, 0x17, 0x8b, 0x93,
		0xa7, 0xa3, 0x93, 0xa9, 0x85, 0xb4, 0xb3, 0x80, 0x96, 0xfa, 0x39, 0x5d, 0x44, 0x89, 0x77, 0x3e,
		0xfc, 0x0a, 0x27, 0xbd, 0xfb, 0x16, 0xdd, 0x9c, 0x8a, 0xb6, 0x27, 0x0c, 0xf7, 0x72, 0x9a, 0x5f,
		0xfe, 0x12, 0x75, 0x72, 0xda, 0x17, 0xef, 0xe4, 0xb4, 0x4f, 0x27, 0x27, 0x3a, 0x39, 0xe5, 0xa5,
		0x2f, 0xd0, 0xc9, 0x89, 0x4e, 0x4e, 0xf9, 0x89, 0x8d, 0x74, 0x72, 0xa2, 0x93, 0xd3, 0xfa, 0x81,
		0xe8, 0xe4, 0x24, 0x31, 0x20, 0x19, 0xaa, 0x64, 0xa8, 0x96, 0x4b, 0xff, 0x20, 0x43, 0xd5, 0x92,
		0x38, 0xca, 0x95, 0xa7, 0x55, 0x10, 0xb2, 0x06, 0x46, 0xd6, 0x40, 0xc9, 0x0a, 0x38, 0xc9, 0x82,
		0x94, 0x30, 0x58, 0x4d, 0x67, 0x80, 0x0c, 0xd5, 0x95, 0x43, 0x73, 0xdd, 0x69, 0x1f, 0xd6, 0x97,
		0x1e, 0xc3, 0x75, 0x67, 0xb6, 0xa5, 0x27, 0x43, 0xb5, 0x1c, 0x7b, 0x80, 0x5b, 0xcf, 0xa2, 0x9c,
		0x21, 0x32, 0x54, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x3e, 0xd5, 0x7e, 0x27, 0x43, 0x55,
		0xe4, 0x5d, 0xc9, 0x50, 0xc5, 0x1c, 0x60, 0x0e, 0x30, 0x07, 0x65, 0x37, 0x07, 0x64, 0xa8, 0x22,
		0x21, 0x69, 0x2e, 0x2f, 0x19, 0xaa, 0xb5, 0x95, 0x90, 0xc8, 0x50, 0x45, 0x39, 0x2a, 0x31, 0x89,
		0x27, 0x43, 0x15, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x57, 0x8d, 0xd4, 0x93, 0xa1, 0x5a, 0x65, 0xbe,
		0xcd, 0x95, 0x6d, 0x6d, 0xf9, 0x36, 0x19, 0xaa, 0x30, 0x6e, 0xfb, 0x8c, 0x9b, 0x0c, 0x55, 0xf5,
		0x64, 0xb6, 0x7d, 0x3a, 0x39, 0x29, 0x51, 0x18, 0x3a, 0x39, 0x15, 0xd5, 0xf7, 0x21, 0x4e, 0x3e,
		0x17, 0xdf, 0x86, 0x38, 0x79, 0x81, 0xc3, 0x40, 0x9c, 0x3c, 0xc2, 0x0b, 0xc2, 0x0b, 0xc2, 0x8b,
		0xa9, 0xfd, 0x4e, 0x9c, 0x3c, 0xa2, 0x0b, 0xa2, 0x0b, 0xa2, 0x8b, 0xd2, 0xd2, 0x13, 0x27, 0x8f,
		0xf6, 0x62, 0xf0, 0x0c, 0x11, 0x27, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0xa9, 0xf6,
		0x3b, 0x71, 0xf2, 0x22, 0xef, 0x4a, 0x9c, 0x3c, 0xe6, 0x00, 0x73, 0x80, 0x39, 0x28, 0xbb, 0x39,
		0x20, 0x4e, 0x1e, 0x09, 0x49, 0x73, 0x79, 0x89, 0x93, 0xaf, 0xad, 0x84, 0x44, 0x9c, 0x3c, 0xca,
		0x51, 0x89, 0x49, 0x3c, 0x71, 0xf2, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0xbe, 0x6a, 0xa4, 0x9e, 0x38,
		0xf9, 0x2a, 0xf3, 0x6d, 0xae, 0x6c, 0x6b, 0xcb, 0xb7, 0x89, 0x93, 0x87, 0x71, 0xdb, 0x67, 0xdc,
		0xc4, 0xc9, 0x8b, 0xc5, 0xc9, 0xd3, 0xc9, 0xc9, 0xd4, 0x42, 0xda, 0x59, 0xc0, 0x3c, 0x3a, 0x39,
		0xed, 0xd3, 0xc9, 0xa9, 0x68, 0x7b, 0xc2, 0x66, 0x27, 0xa7, 0xfd, 0x42, 0x77, 0x72, 0xd2, 0xca,
		0x92, 0x11, 0xc9, 0x8a, 0x11, 0xeb, 0xd9, 0xd4, 0xa4, 0x67, 0x93, 0x41, 0xe5, 0x81, 0x9e, 0x4d,
		0x8f, 0xdf, 0x5c, 0xbb, 0x67, 0xd3, 0x80, 0x3b, 0xdf, 0x7b, 0x72, 0xdd, 0x9a, 0xc6, 0xe3, 0xc9,
		0xf4, 0x69, 0xda, 0xa6, 0x4f, 0x53, 0x0e, 0xd2, 0x21, 0x7d, 0x9a, 0x0a, 0xc0, 0x69, 0xc5, 0xa4,
		0x3d, 0x03, 0xe1, 0x5a, 0x42, 0xe1, 0x59, 0x1a, 0x14, 0x52, 0xc3, 0xaa, 0x4d, 0x98, 0x98, 0x33,
		0xe6, 0x4d, 0x52, 0xb8, 0x37, 0x37, 0x2c, 0xf0, 0x07, 0xfc, 0x01, 0x7f, 0x85, 0x82, 0x3f, 0xbf,
		0xe3, 0x85, 0x89, 0x9f, 0xfc, 0x8c, 0xbc, 0x1b, 0x49, 0x08, 0x14, 0xb8, 0xbb, 0x68, 0x9c, 0x8c,
		0xbf, 0xda, 0x2f, 0x6e, 0x6c, 0xa0, 0x4e, 0xc0, 0xd1, 0xfb, 0x93, 0xeb, 0x8b, 0xc1, 0xff, 0x5c,
		0xfe, 0x7e, 0x7e, 0x2c, 0xb5, 0x95, 0x87, 0xf2, 0x6e, 0x2c, 0x7a, 0xbf, 0x62, 0xe8, 0xaa, 0xfc,
		0x74, 0xf7, 0xcb, 0xf9, 0xc7, 0xeb, 0x93, 0xf3, 0x2f, 0xad, 0xeb, 0xcf, 0x1f, 0x4f, 0xde, 0x1d,
		0x5d, 0x5c, 0x36, 0x8a, 0x18, 0x41, 0x60, 0xea, 0xed, 0x4f, 0x3e, 0xfe, 0xeb, 0xe2, 0xf2, 0xe8,
		0xf2, 0xb8, 0x4e, 0x2f, 0x3d, 0x5c, 0xec, 0xd3, 0xa3, 0x5f, 0x8e, 0x4f, 0x8f, 0x7f, 0xad, 0xe5,
		0xa2, 0x37, 0x07, 0x5b, 0xfe, 0xcb, 0xf9, 0xe9, 0x45, 0x2d, 0xb7, 0xfa, 0xf5, 0xc5, 0xf9, 0xfb,
		0x5a, 0xbd, 0xf8, 0x04, 0xe1, 0xf6, 0xeb, 0xb8, 0xd9, 0x87, 0xef, 0x5d, 0xfb, 0xc3, 0x7e, 0xfc,
		0xe5, 0xfc, 0x63, 0xed, 0x56, 0xbd, 0x86, 0xab, 0x7d, 0xf1, 0xe9, 0xf2, 0xf8, 0xfa, 0xfc, 0xec,
		0xf4, 0xe4, 0xdd, 0xef, 0x43, 0x4e, 0x53, 0x4b, 0x9c, 0x6b, 0x5d, 0x7f, 0xf8, 0x7c, 0x7a, 0x59,
		0x47, 0xa4, 0x6b, 0x5d, 0xbf, 0x3f, 0x3d, 0xfb, 0xf7, 0xc5, 0xf9, 0xf1, 0xbb, 0x7a, 0x5a, 0xf6,
		0x9a, 0xa1, 0xdc, 0x97, 0xf3, 0x8f, 0x35, 0x5d, 0xf2, 0x05, 0x9c, 0xdb, 0xaf, 0xdd, 0x39, 0xaf,
		0x23, 0x93, 0x79, 0xe4, 0xb1, 0x26, 0xf0, 0x5d, 0x64, 0xa4, 0xab, 0xbc, 0x75, 0xb5, 0x5c, 0x34,
		0x73, 0x2f, 0x74, 0xbf, 0x05, 0x5e, 0x47, 0x4e, 0x2d, 0x9f, 0x0c, 0xa8, 0xa9, 0x12, 0x0a, 0x57,
		0xb9, 0x40, 0x77, 0xcf, 0x34, 0x22, 0xba, 0x3b, 0xba, 0xfb, 0xe6, 0xfd, 0xc6, 0xb5, 0xe3, 0xd6,
		0xb8, 0xb4, 0x90, 0x4c, 0xe5, 0xce, 0xd9, 0x12, 0x42, 0x12, 0x55, 0x3a, 0x85, 0x4a, 0xff, 0x02,
		0x7a, 0x80, 0x5e, 0x59, 0x41, 0x4f, 0xaa, 0x54, 0x6f, 0xc3, 0x0f, 0xe3, 0xc4, 0x0d, 0x24, 0x98,
		0xd2, 0xd2, 0x0e, 0x7e, 0x1c, 0x5a, 0xb6, 0xe2, 0xf7, 0xb6, 0x74, 0xc5, 0xef, 0x6d, 0x2a, 0x7e,
		0x0b, 0xfa, 0x46, 0x54, 0xfc, 0x36, 0xef, 0xd3, 0x49, 0xe5, 0x93, 0x88, 0x67, 0x63, 0x9a, 0x2b,
		0x9a, 0x6b, 0xa0, 0x58, 0xae, 0xa1, 0x8c, 0x4b, 0x03, 0xb9, 0xad, 0x26, 0x33, 0x2c, 0x0d, 0xa7,
		0xd7, 0x99, 0xce, 0xa8, 0xb4, 0x91, 0x4c, 0x67, 0x20, 0x83, 0xd2, 0x68, 0xe6, 0xa4, 0xad, 0x25,
		0x35, 0x5d, 0xdc, 0xd6, 0xca, 0xda, 0x16, 0x34, 0xf1, 0xf0, 0xaa, 0x42, 0xed, 0x64, 0x22, 0xaf,
		0xed, 0xf9, 0xf7, 0x26, 0x38, 0xe6, 0x74, 0x64, 0x28, 0x26, 0x14, 0x13, 0x8a, 0x09, 0xc5, 0x84,
		0x62, 0x42, 0x31, 0xa1, 0x98, 0x50, 0x4c, 0x28, 0x66, 0x3d, 0x29, 0xa6, 0xd3, 0x8b, 0x26, 0xc9,
		0xea, 0xe6, 0xd8, 0xe6, 0xec, 0x43, 0x20, 0x9e, 0x10, 0x4f, 0x88, 0x27, 0xc4, 0x13, 0xe2, 0x09,
		0xf1, 0x84, 0x78, 0x42, 0x3c, 0x21, 0x9e, 0xf5, 0x22, 0x9e, 0xf1, 0xc8, 0x98, 0x4a, 0x77, 0xca,
		0x1e, 0x8c, 0x0a, 0xb5, 0x84, 0x5a, 0x42, 0x2d, 0xa1, 0x96, 0x50, 0x4b, 0xa8, 0x25, 0xd4, 0x12,
		0x6a, 0x09, 0xb5, 0x2c, 0x11, 0xb5, 0xa4, 0xbc, 0xec, 0xaa, 0x52, 0xa2, 0x89, 0x9b, 0x78, 0xaf,
		0x85, 0xc2, 0xc0, 0xb7, 0x52, 0x16, 0x14, 0x3d, 0x9f, 0x3c, 0x8e, 0xea, 0xb1, 0x79, 0x2d, 0x79,
		0x91, 0xab, 0xb8, 0xf6, 0x63, 0xcf, 0xb9, 0xeb, 0x07, 0x89, 0xdf, 0x0b, 0x3c, 0x67, 0xf0, 0xbe,
		0xb1, 0x7e, 0x49, 0xd7, 0x15, 0x63, 0xe6, 0x5c, 0xdf, 0x75, 0x9b, 0xfa, 0xae, 0x06, 0x9d, 0x2d,
		0xea, 0xbb, 0x3e, 0x7e, 0x73, 0xed, 0xfa, 0xae, 0xed, 0xc9, 0x9e, 0x15, 0xca, 0x3a, 0x1a, 0x8f,
		0x47, 0xce, 0x91, 0x3d, 0xb5, 0x84, 0x9c, 0x23, 0x72, 0x8e, 0xd6, 0x0f, 0x24, 0x95, 0x9b, 0xbd,
		0xb4, 0x7f, 0x65, 0x72, 0xb4, 0x1f, 0x5f, 0x58, 0x36, 0x57, 0xdb, 0x90, 0x9b, 0x89, 0x20, 0x8b,
		0x20, 0x6b, 0x0f, 0x82, 0x64, 0x3d, 0xf6, 0xe2, 0x0b, 0xb2, 0x72, 0xb9, 0xe0, 0x4b, 0x4c, 0x62,
		0x07, 0xa9, 0xa2, 0xc0, 0x52, 0xc5, 0xb2, 0x0b, 0xf7, 0x7a, 0x4c, 0x24, 0xcb, 0x58, 0x0d, 0x65,
		0x70, 0xf6, 0xe5, 0x4a, 0xa1, 0xe8, 0x23, 0x38, 0x74, 0x1a, 0x3a, 0x0d, 0x9d, 0x96, 0xd9, 0x6e,
		0x42, 0xfe, 0xb2, 0x19, 0xbf, 0x59, 0xf8, 0xc0, 0x43, 0x7a, 0x21, 0xbd, 0x90, 0x5e, 0x59, 0x00,
		0x99, 0x0e, 0xe8, 0x06, 0x41, 0xf7, 0xcf, 0x47, 0xd2, 0xe3, 0xc6, 0xe6, 0xba, 0xc1, 0x2f, 0x3f,
		0x4a, 0x78, 0x1b, 0x18, 0xf2, 0xdd, 0x0d, 0xf9, 0xf0, 0xc6, 0x60, 0xcd, 0x24, 0xbc, 0x99, 0x87,
		0x39, 0xd3, 0x70, 0x67, 0x0d, 0xf6, 0xac, 0xc1, 0x9f, 0x15, 0x18, 0x94, 0x85, 0x43, 0x61, 0x58,
		0x34, 0xa7, 0x09, 0x58, 0xd0, 0x06, 0x0c, 0x69, 0x04, 0xf2, 0x0b, 0x46, 0x5b, 0x64, 0x4d, 0x2d,
		0x61, 0xe0, 0x43, 0x8b, 0x08, 0x0a, 0x82, 0x3a, 0x90, 0x48, 0x38, 0x86, 0x4e, 0x4b, 0xd4, 0xb5,
		0x27, 0x4d, 0xa7, 0x45, 0xaa, 0x35, 0x4f, 0xa4, 0x89, 0x27, 0x82, 0x27, 0x82, 0x27, 0x82, 0x27,
		0x82, 0x27, 0x82, 0x27, 0x82, 0x27, 0x82, 0x27, 0x82, 0x27, 0x82, 0x27, 0x52, 0x12, 0x4f, 0x44,
		0x23, 0x4a, 0xd7, 0x80, 0x23, 0xc2, 0x85, 0x74, 0xfa, 0xa5, 0xb3, 0x14, 0x44, 0xff, 0x39, 0xf6,
		0x3e, 0x8c, 0x1f, 0x7e, 0x3e, 0x78, 0xf6, 0xf5, 0xb1, 0x36, 0x90, 0xe7, 0x73, 0x15, 0x2e, 0xe3,
		0xa1, 0x8a, 0x7a, 0xa6, 0xe2, 0x97, 0xe1, 0x4d, 0x2e, 0xc3, 0x0b, 0x40, 0xb9, 0xb8, 0x0c, 0xb7,
		0xef, 0x41, 0x12, 0x5b, 0x4a, 0x6c, 0x29, 0xe2, 0x16, 0xe2, 0x16, 0xb1, 0xa5, 0x50, 0xf9, 0x52,
		0x51, 0x79, 0x01, 0x07, 0x8c, 0x0c, 0x55, 0xa9, 0xd5, 0x68, 0x68, 0xf9, 0x17, 0x99, 0x7d, 0x29,
		0x6b, 0xd9, 0xb1, 0xcf, 0x0c, 0x2e, 0xef, 0xc0, 0xa6, 0x0d, 0xf5, 0xf4, 0xf1, 0xb4, 0x3a, 0xc3,
		0x29, 0xc8, 0x38, 0xc6, 0xa9, 0x1f, 0x27, 0x47, 0x49, 0xa2, 0xc6, 0x05, 0x1b, 0x1f, 0xfc, 0xf0,
		0x38, 0xf0, 0x06, 0x56, 0x29, 0x56, 0x63, 0x2c, 0x8d, 0x0f, 0xee, 0x8f, 0x99, 0x11, 0x76, 0xde,
		0xb4, 0x5a, 0xfb, 0x07, 0xad, 0xd6, 0xf6, 0xc1, 0xee, 0xc1, 0xf6, 0xe1, 0xde, 0xde, 0xce, 0xfe,
		0x8e, 0x42, 0xc5, 0x86, 0xc6, 0x59, 0xd4, 0xf1, 0x22, 0xaf, 0xf3, 0xcb, 0x60, 0x7a, 0xc2, 0x7e,
		0x10, 0x18, 0x5d, 0x05, 0xcd, 0xc3, 0x25, 0x75, 0xa8, 0x14, 0x4e, 0x50, 0x8a, 0x93, 0x93, 0xed,
		0xa0, 0xa4, 0xdf, 0xee, 0xe9, 0x7e, 0x32, 0xe5, 0x52, 0xa8, 0x2e, 0x81, 0xe6, 0xd4, 0xa7, 0x9b,
		0x9b, 0xcd, 0x6f, 0x9a, 0xe2, 0x2d, 0x1b, 0x6e, 0xaf, 0x17, 0xfc, 0xcc, 0x5a, 0x65, 0xf7, 0xf1,
		0xc6, 0x6d, 0xf6, 0xd3, 0x29, 0xe7, 0x34, 0x9b, 0x42, 0x92, 0xd9, 0x6d, 0x51, 0x71, 0x4b, 0x66,
		0xdd, 0x8e, 0xa8, 0xd7, 0x0d, 0x32, 0x6c, 0x79, 0x55, 0xbf, 0x42, 0xdb, 0x6f, 0xd0, 0xf6, 0x0b,
		0x16, 0x79, 0xff, 0xf0, 0xc5, 0x73, 0x3a, 0x67, 0x59, 0x35, 0x03, 0xd5, 0x40, 0x79, 0xbd, 0x80,
		0x78, 0x45, 0x71, 0x4f, 0xd9, 0xf3, 0xd6, 0xf1, 0xb0, 0x35, 0xb6, 0xb4, 0x94, 0xcb, 0x2c, 0xe6,
		0x1a, 0x8b, 0xb9, 0xc0, 0x7a, 0x5b, 0xde, 0x0e, 0xf7, 0x52, 0x95, 0xcf, 0x1a, 0x9d, 0x91, 0x0c,
		0xe5, 0x78, 0x3f, 0x7a, 0xdd, 0x28, 0xd1, 0x2d, 0x9c, 0x3e, 0xdd, 0x3f, 0xab, 0x87, 0x55, 0x2d,
		0x28, 0xf1, 0x28, 0x95, 0x7d, 0x3a, 0xfe, 0x7f, 0xc7, 0xef, 0x2e, 0xaf, 0x3f, 0x9d, 0x7d, 0xbe,
		0x3c, 0xd6, 0xac, 0xa8, 0xb2, 0x5d, 0x91, 0x8a, 0x2a, 0x8a, 0xe7, 0x54, 0x5a, 0xe2, 0x2a, 0x5f,
		0x49, 0x15, 0xb5, 0x73, 0x9c, 0x8f, 0xcb, 0xac, 0xad, 0x41, 0x2d, 0x9d, 0xcc, 0xd1, 0x91, 0x74,
		0x92, 0xc1, 0xc0, 0x1a, 0xbb, 0x67, 0x62, 0xdc, 0x5a, 0x1a, 0x63, 0x1c, 0x87, 0xfd, 0xbb, 0xc1,
		0xcb, 0x3d, 0x14, 0xb8, 0x48, 0xd4, 0x64, 0xda, 0xfc, 0x3b, 0x23, 0x38, 0x39, 0x3f, 0x2c, 0x38,
		0x09, 0x4e, 0x82, 0x93, 0xe0, 0x64, 0x09, 0x71, 0x52, 0x98, 0x47, 0x8a, 0xf0, 0x47, 0x80, 0x0c,
		0x20, 0xab, 0x2f, 0x90, 0x05, 0x9e, 0x7b, 0x13, 0x79, 0x37, 0x12, 0xe0, 0xa5, 0x51, 0x43, 0xbc,
		0x71, 0x3e, 0x95, 0x35, 0x47, 0x0b, 0xf1, 0x36, 0xea, 0xf6, 0x13, 0x3f, 0xbc, 0x1d, 0x9f, 0xed,
		0xe9, 0x5f, 0x8f, 0xf1, 0xb6, 0xe3, 0xdd, 0xf8, 0xa1, 0x9f, 0xf8, 0xdd, 0x30, 0x5e, 0xff, 0x4f,
		0xd3, 0x7f, 0x19, 0x6a, 0xc6, 0x56, 0xd7, 0x47, 0xeb, 0xa2, 0x62, 0x3a, 0x8a, 0xf6, 0x85, 0xc5,
		0xe3, 0x48, 0x06, 0x2e, 0x2e, 0xa6, 0x83, 0xcf, 0x5e, 0x60, 0x08, 0x85, 0xcd, 0xf5, 0x63, 0x2f,
		0xd2, 0xc5, 0x0b, 0xc1, 0xe0, 0x8c, 0x59, 0x30, 0xeb, 0x8e, 0xde, 0xd6, 0xf9, 0x26, 0xd1, 0xdb,
		0xcd, 0x48, 0x20, 0xc6, 0x1c, 0xb0, 0x0d, 0x67, 0xb2, 0x5c, 0xf7, 0xc6, 0x56, 0x98, 0x88, 0xb0,
		0xa7, 0x26, 0xe2, 0xa1, 0xc1, 0x44, 0x60, 0x22, 0x30, 0x11, 0x98, 0x08, 0x4c, 0x04, 0x26, 0x02,
		0x13, 0x29, 0x25, 0x13, 0xa9, 0x60, 0xf0, 0xce, 0x4c, 0x38, 0x86, 0x52, 0x45, 0x8a, 0x0c, 0x71,
		0x36, 0x19, 0x42, 0x24, 0xd4, 0xf2, 0x74, 0xb4, 0xf2, 0x72, 0xb4, 0xaf, 0xea, 0x9b, 0x5c, 0xd5,
		0xe7, 0x0a, 0x4d, 0x5c, 0xd5, 0x67, 0xdf, 0x3f, 0x5c, 0xd5, 0xe3, 0x2f, 0xe1, 0x2f, 0x15, 0xd1,
		0x5f, 0xe2, 0x0a, 0x8a, 0xab, 0x7a, 0x70, 0x12, 0x9c, 0x04, 0x27, 0xc1, 0x49, 0x03, 0x38, 0xc9,
		0x55, 0x3d, 0x40, 0x06, 0x90, 0x15, 0x09, 0xc8, 0x10, 0xc8, 0x4d, 0xac, 0x0f, 0x02, 0xb9, 0xde,
		0xae, 0x44, 0x20, 0x97, 0x02, 0x36, 0xae, 0xea, 0x57, 0xcf, 0x11, 0x57, 0xf5, 0x30, 0x11, 0x98,
		0x08, 0x4c, 0x04, 0x26, 0x02, 0x13, 0x81, 0x89, 0xc0, 0x44, 0x84, 0x98, 0x48, 0xc5, 0xaf, 0xea,
		0x15, 0x2a, 0x06, 0xd5, 0xa3, 0x22, 0x46, 0xf6, 0xf2, 0x12, 0x5b, 0x9b, 0xca, 0x8f, 0x0c, 0x86,
		0x3c, 0x1f, 0x8d, 0x68, 0xb3, 0xcc, 0x46, 0x3c, 0x2c, 0x47, 0xe4, 0x74, 0x7b, 0x43, 0x9b, 0xa6,
		0x50, 0x69, 0x63, 0x61, 0x80, 0x6a, 0x14, 0xdb, 0xc8, 0x56, 0xe3, 0xaf, 0x3a, 0xb5, 0x36, 0x32,
		0xd5, 0xd8, 0xa3, 0xd4, 0x86, 0x79, 0x67, 0x4d, 0x2a, 0x7e, 0x47, 0xad, 0x68, 0x65, 0xf5, 0xc3,
		0x77, 0x94, 0x8a, 0x4a, 0x16, 0x34, 0x7a, 0x67, 0xd4, 0x66, 0xa4, 0xfb, 0x67, 0xa8, 0xd3, 0xcc,
		0x64, 0xa1, 0x69, 0xc9, 0x78, 0x34, 0xfd, 0x3b, 0xe8, 0x6d, 0x54, 0x12, 0x81, 0xea, 0xb1, 0xf5,
		0x15, 0x49, 0xb4, 0xaa, 0xbf, 0x96, 0x55, 0x23, 0xe9, 0xfb, 0x61, 0xf2, 0x46, 0x40, 0x21, 0xd1,
		0x71, 0xb2, 0x3f, 0xb9, 0xe1, 0xed, 0xe0, 0xcb, 0x7c, 0xd5, 0x5a, 0x4e, 0x01, 0x57, 0xf8, 0x83,
		0x1f, 0x0a, 0x16, 0x64, 0x97, 0xad, 0x61, 0xfd, 0xc5, 0x0d, 0xfa, 0x9e, 0xe0, 0x78, 0xef, 0x23,
		0xb7, 0x3d, 0xe0, 0xd3, 0xbf, 0xfa, 0xb7, 0xfe, 0x48, 0x83, 0x29, 0x44, 0xeb, 0xbd, 0x0f, 0xee,
		0x8f, 0xc2, 0x2f, 0x41, 0x73, 0x6f, 0xaf, 0xc0, 0x8b, 0x90, 0x93, 0x20, 0x72, 0x55, 0xe4, 0x60,
		0x3a, 0x3f, 0x76, 0xbf, 0x05, 0x9e, 0xd3, 0xf3, 0xbc, 0xc8, 0x71, 0x63, 0xe7, 0xc6, 0x0f, 0x12,
		0x2f, 0x12, 0x88, 0xa6, 0x5b, 0x3d, 0xae, 0x3e, 0x95, 0xd1, 0x29, 0xa6, 0x0f, 0x9d, 0x81, 0xce,
		0xd4, 0x96, 0xce, 0xe8, 0x17, 0xa3, 0xd7, 0x2c, 0x3e, 0x6f, 0x07, 0xd0, 0x22, 0xaf, 0x17, 0xb8,
		0xed, 0x29, 0xf0, 0xe8, 0x23, 0xd9, 0xe2, 0x80, 0x40, 0x18, 0x10, 0x06, 0x84, 0x01, 0x61, 0x45,
		0x50, 0xab, 0xf2, 0xb9, 0xa4, 0x9a, 0xbf, 0x74, 0x20, 0xa5, 0xb4, 0x8c, 0x29, 0xa5, 0x48, 0xd2,
		0x82, 0xb8, 0x8a, 0x24, 0x9d, 0x9d, 0x04, 0x21, 0x49, 0x43, 0x80, 0x20, 0x40, 0x19, 0xf7, 0x0b,
		0x92, 0xf4, 0xac, 0x1e, 0x8a, 0x24, 0xad, 0xa5, 0x67, 0x22, 0x49, 0x17, 0x60, 0x11, 0x90, 0xa4,
		0x97, 0xa6, 0x19, 0x49, 0x1a, 0x3a, 0x03, 0x9d, 0x41, 0xcf, 0x29, 0xa6, 0x9e, 0x83, 0x24, 0x0d,
		0x84, 0x01, 0x61, 0x40, 0x18, 0x92, 0xf4, 0x9a, 0x4d, 0x51, 0x04, 0x49, 0x9a, 0xd4, 0x89, 0x54,
		0xf3, 0x24, 0x95, 0x3d, 0x11, 0x9f, 0xbb, 0xc9, 0xf7, 0xb3, 0xf1, 0x98, 0x16, 0xf3, 0x27, 0x32,
		0x06, 0xa1, 0xab, 0x05, 0x9f, 0x93, 0x2d, 0xb1, 0x45, 0xb6, 0xc4, 0x02, 0x71, 0xca, 0x9a, 0x2d,
		0xe1, 0xf6, 0x93, 0xef, 0x4e, 0xcf, 0x8d, 0xe3, 0xf1, 0x14, 0x2a, 0x5e, 0x50, 0xcd, 0x0f, 0xa3,
		0x76, 0x51, 0xb5, 0x4d, 0xee, 0x84, 0x4d, 0xf6, 0x55, 0xa7, 0x8b, 0x2a, 0x65, 0x56, 0xf5, 0xe8,
		0xd8, 0x4c, 0xd2, 0xbf, 0xd5, 0xf6, 0xf8, 0x1c, 0x5c, 0xbf, 0x29, 0xc0, 0x85, 0x74, 0xc7, 0x8b,
		0xdb, 0x91, 0xdf, 0x53, 0x62, 0x43, 0x33, 0xe5, 0xcf, 0x1e, 0x07, 0xe1, 0xcc, 0x73, 0xe6, 0x2b,
		0x76, 0xe6, 0xe3, 0x24, 0xf2, 0xc3, 0xdb, 0xb2, 0x9f, 0x74, 0x2f, 0x74, 0xbf, 0x05, 0x9e, 0x86,
		0x6d, 0x9f, 0x0c, 0x90, 0x35, 0x38, 0xe0, 0x51, 0xc3, 0x19, 0xec, 0x33, 0x00, 0x02, 0x80, 0xa8,
		0x1a, 0x40, 0xa8, 0x4b, 0x2c, 0x8a, 0xd2, 0x8a, 0x19, 0x84, 0x08, 0xba, 0x6d, 0x37, 0x50, 0x91,
		0x7f, 0x1f, 0x8b, 0xf6, 0x4c, 0x46, 0xe0, 0x90, 0x73, 0xc8, 0x2b, 0x76, 0xc8, 0xdd, 0xd8, 0x09,
		0xfb, 0x77, 0xdf, 0x94, 0xee, 0x63, 0x27, 0x1b, 0x5c, 0xa1, 0x12, 0x95, 0x66, 0x34, 0x8b, 0x5e,
		0x95, 0x27, 0x81, 0x3b, 0x02, 0x91, 0x90, 0x09, 0xa9, 0x68, 0x15, 0xc9, 0x00, 0x89, 0x07, 0xbd,
		0xb2, 0x57, 0x85, 0x9b, 0xda, 0x56, 0xf3, 0xb0, 0x75, 0xb8, 0x7f, 0xd0, 0x3c, 0xdc, 0x2b, 0xd0,
		0x1c, 0x5b, 0xba, 0x70, 0xb8, 0x2a, 0x80, 0xf5, 0x9d, 0x48, 0xe0, 0x8e, 0xdb, 0xe9, 0x44, 0x5e,
		0xac, 0x61, 0x85, 0x97, 0x46, 0xc2, 0x1a, 0x63, 0x8d, 0x2b, 0x66, 0x8d, 0xfd, 0x9e, 0xe2, 0xee,
		0x9e, 0x63, 0xdd, 0x87, 0x0a, 0x9f, 0x1d, 0x7f, 0x77, 0xeb, 0xe6, 0xf8, 0xf1, 0xcd, 0xef, 0x5b,
		0x1a, 0xef, 0xbe, 0xac, 0x4d, 0xe8, 0x55, 0xc7, 0x4c, 0xbc, 0x28, 0xd4, 0x8e, 0xb5, 0x6d, 0xfc,
		0xf7, 0xf9, 0xf3, 0xaf, 0xdb, 0xce, 0xe1, 0xd5, 0xdf, 0x5f, 0x77, 0x9c, 0xc3, 0xab, 0xd1, 0x6f,
		0x77, 0x86, 0xff, 0x19, 0xfd, 0xbe, 0xf9, 0x75, 0xdb, 0x69, 0x4d, 0x7e, 0xbf, 0xf7, 0x75, 0xdb,
		0xd9, 0xbb, 0x7a, 0xf1, 0xc7, 0x1f, 0xaf, 0x5e, 0xfc, 0xb5, 0xfb, 0x90, 0xfd, 0x83, 0xff, 0x50,
		0x0f, 0x02, 0xb8, 0xd2, 0x99, 0xac, 0xb3, 0x8b, 0x93, 0xff, 0xd4, 0x6f, 0xc6, 0x6c, 0x86, 0x4d,
		0xc8, 0x1c, 0xaf, 0xfd, 0xaa, 0x1e, 0x2f, 0xd7, 0xb9, 0x39, 0x72, 0xde, 0x5f, 0xfd, 0xb5, 0xf3,
		0xb2, 0xf5, 0xf0, 0xf6, 0xc5, 0x5f, 0x07, 0x0f, 0x8b, 0x7f, 0xf9, 0xf7, 0xaa, 0x1f, 0xdb, 0x79,
		0x79, 0xf0, 0xf0, 0x76, 0xcd, 0xbf, 0xec, 0x3f, 0xbc, 0x4d, 0x39, 0xc6, 0xde, 0xc3, 0xf3, 0xa5,
		0x1f, 0x1d, 0xfc, 0x7d, 0x73, 0xdd, 0x07, 0x5a, 0x6b, 0x3e, 0xb0, 0xbb, 0xee, 0x03, 0xbb, 0x6b,
		0x3e, 0xb0, 0xf6, 0x2b, 0x35, 0xd7, 0x7c, 0x60, 0xef, 0xe1, 0xef, 0xa5, 0x9f, 0x7f, 0xbe, 0xfa,
		0x47, 0xf7, 0x1f, 0x5e, 0xfc, 0xbd, 0xee, 0xdf, 0x0e, 0x1e, 0xfe, 0x7e, 0xfb, 0xa2, 0x52, 0x60,
		0xc3, 0xfe, 0x29, 0xd7, 0xfe, 0xa9, 0x91, 0xf7, 0xa4, 0x1a, 0xb9, 0x3a, 0xc5, 0x7d, 0xb5, 0x48,
		0x55, 0x7c, 0x25, 0x7c, 0x25, 0x94, 0x4b, 0x94, 0x4b, 0x94, 0x4b, 0x94, 0xcb, 0xda, 0x2a, 0x97,
		0x43, 0xd3, 0x79, 0x1b, 0x75, 0xfb, 0x3d, 0x4d, 0xf3, 0x3b, 0x1a, 0x03, 0x0b, 0x8c, 0x05, 0xae,
		0x98, 0x05, 0x56, 0x6f, 0x66, 0xa3, 0xd3, 0xc4, 0x66, 0xda, 0xbc, 0xe6, 0xd5, 0xab, 0xd7, 0xd3,
		0xff, 0x7b, 0x3c, 0x68, 0xf1, 0xcc, 0xef, 0x67, 0x7e, 0xeb, 0x64, 0xef, 0x4a, 0x63, 0x10, 0x56,
		0x12, 0x95, 0xb9, 0x9f, 0x47, 0x15, 0x85, 0x6e, 0xac, 0x80, 0x0a, 0xa0, 0x52, 0x78, 0x50, 0x51,
		0xdd, 0xdc, 0x5b, 0x9a, 0x2d, 0x86, 0x15, 0x5b, 0x0b, 0x9b, 0x01, 0x89, 0xc8, 0xbb, 0xeb, 0xde,
		0x7b, 0x4e, 0x2f, 0xf2, 0xef, 0xdd, 0xc4, 0xd3, 0x52, 0x00, 0x96, 0x87, 0x02, 0x34, 0x00, 0x8d,
		0x8a, 0x81, 0xc6, 0xd2, 0x26, 0x1f, 0x67, 0xda, 0xe9, 0x60, 0x88, 0x82, 0xdb, 0xd5, 0x38, 0xe9,
		0x78, 0x61, 0xe2, 0x27, 0x3f, 0x7f, 0x71, 0x63, 0x4f, 0x3f, 0xdd, 0xfc, 0xd3, 0xf1, 0x87, 0xb3,
		0x2f, 0xc7, 0xd7, 0xe7, 0x9f, 0x4e, 0xbe, 0x1c, 0x5d, 0x1e, 0x5f, 0x1f, 0x5d, 0x5c, 0x9f, 0x9d,
		0x5f, 0x9e, 0x9c, 0x7d, 0x54, 0xdd, 0x52, 0x43, 0xcf, 0x32, 0xd6, 0xd2, 0xcd, 0x85, 0x1a, 0xce,
		0xcd, 0xbc, 0xd2, 0xf8, 0x25, 0x8f, 0x4e, 0x4f, 0x1b, 0x79, 0xb8, 0xfe, 0x26, 0x5e, 0xe8, 0xfc,
		0xf4, 0xe8, 0x9d, 0xee, 0x1b, 0x29, 0x7d, 0xf2, 0xca, 0xf4, 0xc1, 0x36, 0x63, 0xec, 0xba, 0xfd,
		0xc4, 0x73, 0x6e, 0x02, 0xb7, 0xe7, 0x74, 0xdc, 0xbb, 0x9e, 0x1f, 0x6a, 0xb4, 0x37, 0x5a, 0x31,
		0x96, 0x7a, 0x60, 0xbf, 0x4a, 0x71, 0x06, 0xcc, 0x25, 0xe6, 0x92, 0xc8, 0x7e, 0x3b, 0xc0, 0x11,
		0x7b, 0x61, 0xc7, 0x69, 0x77, 0xef, 0xee, 0xfa, 0xa1, 0x9f, 0xfc, 0xd4, 0xa8, 0x3f, 0x3b, 0x3f,
		0x8e, 0x3a, 0x60, 0x7c, 0x3c, 0xfb, 0x78, 0x0c, 0x5e, 0x80, 0x17, 0x55, 0xc3, 0x8b, 0xe9, 0xd9,
		0xa8, 0xa6, 0x63, 0x5e, 0xde, 0xba, 0x22, 0x59, 0x4a, 0x80, 0xcb, 0x94, 0xfe, 0xf0, 0xbe, 0xdd,
		0xf6, 0x9c, 0xbb, 0x7e, 0x90, 0xf8, 0xdf, 0xbb, 0xbd, 0xec, 0x15, 0x40, 0xe6, 0x3f, 0x4e, 0x21,
		0x10, 0x8b, 0xd0, 0x47, 0xdb, 0x54, 0xda, 0xa6, 0x62, 0xdb, 0x2b, 0x66, 0xdb, 0x95, 0x6b, 0xd4,
		0xab, 0xe6, 0xcd, 0x2f, 0x23, 0xba, 0x52, 0xfe, 0xbc, 0x94, 0xbb, 0xad, 0x49, 0xa3, 0xb5, 0x8f,
		0x9c, 0xc4, 0xd1, 0x93, 0x3b, 0x82, 0x52, 0x47, 0x51, 0xfc, 0x48, 0x8a, 0x1f, 0x4d, 0xd1, 0x23,
		0xaa, 0x27, 0xba, 0x51, 0x0b, 0xd1, 0x52, 0x39, 0xd7, 0x09, 0x6d, 0x74, 0x92, 0x24, 0xd0, 0xc7,
		0xad, 0xb9, 0xd1, 0x00, 0x1d, 0x40, 0x07, 0xd0, 0xc9, 0xb4, 0x5f, 0x68, 0x89, 0x31, 0xf3, 0x45,
		0x68, 0x89, 0xa1, 0xf5, 0x8b, 0x96, 0x18, 0x45, 0x58, 0x84, 0xaa, 0xb7, 0xc4, 0xa8, 0x5e, 0xf9,
		0xe5, 0x39, 0x35, 0x8d, 0x7e, 0x80, 0xf4, 0x03, 0x44, 0x6b, 0x41, 0x6b, 0x41, 0x6b, 0xc1, 0xed,
		0xc1, 0xed, 0x41, 0x6b, 0x41, 0x6b, 0x01, 0x74, 0x00, 0x1d, 0xb4, 0x16, 0xb4, 0x16, 0xb4, 0x16,
		0xb4, 0x16, 0xb4, 0x16, 0xb4, 0x16, 0x41, 0xad, 0x85, 0x46, 0x57, 0x29, 0x66, 0x49, 0xa8, 0xcd,
		0xd5, 0xf1, 0xb7, 0xdb, 0xde, 0x87, 0xc9, 0x90, 0x36, 0x43, 0xdd, 0xa2, 0xa8, 0x1b, 0x39, 0xdf,
		0xdd, 0xb0, 0x13, 0x64, 0xc9, 0x49, 0x78, 0xf4, 0xd6, 0xe7, 0x3f, 0x4f, 0xb0, 0x9b, 0x45, 0x5e,
		0x4a, 0xb0, 0x1b, 0xc1, 0x6e, 0x08, 0xb0, 0x08, 0xb0, 0xa3, 0x0f, 0x26, 0x91, 0xe7, 0x26, 0x8e,
		0x1b, 0x3b, 0x7f, 0xfa, 0xc9, 0xf7, 0x4e, 0xe4, 0xfe, 0xa9, 0x2f, 0x69, 0x2c, 0x0f, 0x89, 0x28,
		0x8b, 0x3e, 0x82, 0x3e, 0x82, 0x28, 0x5b, 0x5f, 0x0f, 0x69, 0x8e, 0xef, 0x72, 0x1d, 0xcd, 0x75,
		0x34, 0x6c, 0xa8, 0x88, 0x6c, 0x68, 0x70, 0x4e, 0x43, 0xaf, 0xdb, 0x8f, 0x9d, 0x7e, 0xaf, 0xe3,
		0x26, 0x9e, 0x73, 0xe7, 0xc5, 0xb1, 0x7b, 0xeb, 0xc5, 0x02, 0x17, 0xd4, 0x6b, 0x87, 0x86, 0xd5,
		0xc0, 0x6a, 0x60, 0x35, 0x99, 0xf6, 0x4b, 0xdf, 0x0f, 0x93, 0xdd, 0xa6, 0x00, 0xa9, 0x39, 0xe0,
		0xda, 0x47, 0x14, 0x56, 0x96, 0x86, 0xe3, 0xda, 0xa7, 0x30, 0x4b, 0x20, 0x55, 0x35, 0xd7, 0xe8,
		0x5a, 0x54, 0xfd, 0xf6, 0xe7, 0x25, 0x12, 0x0d, 0x64, 0x06, 0x32, 0x03, 0x99, 0x41, 0xa2, 0x29,
		0xb4, 0x44, 0xc3, 0x2d, 0x76, 0x9a, 0x69, 0x92, 0xba, 0xc6, 0x1e, 0x0c, 0xfa, 0xcf, 0xc9, 0x98,
		0x16, 0xef, 0xb1, 0x6f, 0x23, 0xb7, 0xed, 0xdd, 0xf4, 0x03, 0x27, 0xf2, 0xe2, 0xc4, 0x8d, 0x92,
		0xec, 0x37, 0xd9, 0x4b, 0x23, 0x70, 0x97, 0x6d, 0xd1, 0x40, 0x71, 0x97, 0xcd, 0x5d, 0x36, 0xea,
		0x2d, 0xea, 0xed, 0x58, 0xbd, 0x2d, 0x48, 0x32, 0x11, 0xce, 0x0c, 0xce, 0x0c, 0xce, 0x4c, 0x79,
		0x9c, 0x19, 0x05, 0xbb, 0xf0, 0xdd, 0x0b, 0x7a, 0x5e, 0xe4, 0x74, 0xc3, 0xe0, 0xa7, 0x3e, 0xdc,
		0xcc, 0x0e, 0x06, 0xe4, 0x00, 0x39, 0x40, 0x0e, 0x90, 0xb3, 0xfc, 0x1d, 0xc7, 0x0e, 0xa6, 0x93,
		0xf8, 0x77, 0x02, 0x0d, 0x14, 0xe6, 0x46, 0x03, 0x74, 0x00, 0x1d, 0x40, 0x27, 0xd3, 0x7e, 0xe9,
		0xfb, 0x61, 0xb2, 0xb3, 0x2f, 0x80, 0x39, 0xfb, 0xdc, 0x40, 0x8b, 0xc2, 0xca, 0xd2, 0x70, 0xdc,
		0x40, 0x17, 0x66, 0x09, 0x5a, 0xdb, 0x87, 0xfb, 0xdc, 0x3d, 0x2f, 0xfe, 0x2a, 0xf2, 0xdd, 0x73,
		0x9c, 0xb8, 0x81, 0xe7, 0x0c, 0x5b, 0xc7, 0xc4, 0x42, 0xcc, 0x63, 0x79, 0x48, 0xe8, 0x07, 0xf4,
		0x03, 0xfa, 0x91, 0x69, 0xbf, 0x74, 0xbc, 0xb6, 0x7f, 0xe7, 0x06, 0xfb, 0x2d, 0x09, 0xaf, 0xa7,
		0xa9, 0x31, 0xc6, 0x12, 0x0e, 0x37, 0xe1, 0x33, 0xab, 0xa7, 0xb9, 0x09, 0x9f, 0xc9, 0x9b, 0xcf,
		0xec, 0xd6, 0x68, 0x09, 0x28, 0xa3, 0xa0, 0xbe, 0x21, 0xf3, 0x89, 0x40, 0x59, 0x0c, 0x25, 0x20,
		0x4d, 0x88, 0x34, 0x21, 0xeb, 0xb4, 0x8d, 0x8b, 0xe6, 0x14, 0x1f, 0xe4, 0xa2, 0x19, 0x0f, 0x08,
		0x0f, 0x28, 0x5f, 0x0f, 0x88, 0x8b, 0xe6, 0xec, 0x73, 0xc6, 0x45, 0x33, 0x90, 0x03, 0xe4, 0x00,
		0x39, 0x4f, 0x7f, 0xc7, 0xa0, 0xdb, 0x76, 0xa7, 0x4e, 0x88, 0x4a, 0xcb, 0xf1, 0xa5, 0x89, 0x5b,
		0x1a, 0x11, 0xf0, 0x01, 0x7c, 0x00, 0x1f, 0xc0, 0x67, 0xf9, 0x3b, 0xde, 0x75, 0x3b, 0x02, 0x77,
		0x4c, 0xc3, 0x51, 0x00, 0x19, 0x40, 0x06, 0x90, 0xc9, 0xa8, 0x47, 0xf4, 0xef, 0xbc, 0x68, 0x24,
		0x7c, 0x0a, 0x00, 0x4d, 0x4b, 0x63, 0x0c, 0xb5, 0xd6, 0xe6, 0x76, 0xc1, 0xaa, 0xe7, 0x79, 0x91,
		0x23, 0x1b, 0x97, 0xb7, 0x3c, 0x24, 0x30, 0x06, 0x8c, 0x01, 0x63, 0x99, 0xf6, 0x0b, 0xc1, 0x79,
		0xb3, 0x5f, 0x84, 0xe0, 0x3c, 0xad, 0x5f, 0x04, 0xe7, 0x15, 0x62, 0x15, 0x08, 0xce, 0x7b, 0x92,
		0x7e, 0x88, 0xe8, 0x34, 0x8b, 0x03, 0x42, 0x3d, 0xa0, 0x1e, 0x50, 0x0f, 0x64, 0x9a, 0xe5, 0xef,
		0x48, 0x32, 0x12, 0xa0, 0x03, 0xe8, 0xe0, 0xef, 0xe0, 0xef, 0xe0, 0xef, 0xe0, 0xef, 0xe0, 0xef,
		0x90, 0x8c, 0x04, 0xfd, 0x80, 0x7e, 0x90, 0x8c, 0x44, 0x32, 0x52, 0x39, 0xf8, 0x0c, 0xc9, 0x48,
		0xb9, 0xf3, 0x19, 0x92, 0x91, 0xaa, 0x43, 0x66, 0x6a, 0x90, 0x8c, 0x44, 0x41, 0xdc, 0x74, 0x13,
		0x25, 0x54, 0x12, 0xf7, 0xb7, 0xf1, 0xb0, 0x9f, 0xc6, 0xa3, 0x5a, 0x2c, 0x8a, 0x1b, 0x74, 0x6f,
		0x6f, 0xfd, 0xf0, 0xd6, 0xe9, 0xf6, 0x06, 0x53, 0x18, 0x67, 0xaf, 0x89, 0xbb, 0x38, 0x00, 0x25,
		0x71, 0x2d, 0x52, 0x5e, 0x4a, 0xe2, 0x52, 0x12, 0xd7, 0xa4, 0x8f, 0x47, 0xa6, 0x62, 0x0e, 0x14,
		0x40, 0x39, 0x53, 0x31, 0xe8, 0xde, 0x3a, 0x13, 0x53, 0xe5, 0x0c, 0x4d, 0xb8, 0xd3, 0xfe, 0x3e,
		0x70, 0x6c, 0x62, 0x89, 0xa8, 0xfe, 0xb5, 0x63, 0xeb, 0x77, 0x13, 0x19, 0x2c, 0x27, 0x5a, 0x0c,
		0x5a, 0x0c, 0x5a, 0x4c, 0xb6, 0xfd, 0x42, 0x33, 0x91, 0x22, 0x78, 0x4f, 0x0b, 0x0c, 0x98, 0x4a,
		0x0e, 0x54, 0x72, 0x80, 0x1f, 0xc1, 0x8f, 0xe0, 0x47, 0xf0, 0x23, 0xf8, 0x11, 0xfc, 0x08, 0x7e,
		0xb4, 0xc0, 0x8f, 0x10, 0x97, 0x53, 0xcd, 0x93, 0x90, 0xb6, 0x7c, 0x3a, 0x1a, 0xf5, 0x6c, 0x3c,
		0xa8, 0x45, 0x69, 0x79, 0x6a, 0x0e, 0xdd, 0x4e, 0x27, 0xf2, 0x62, 0x05, 0x6d, 0x79, 0x69, 0x84,
		0x6c, 0xe2, 0xf2, 0x36, 0xe2, 0x32, 0xe2, 0xb2, 0xa2, 0x4d, 0x79, 0x24, 0x76, 0x9e, 0x7b, 0x13,
		0x79, 0x37, 0x59, 0x16, 0x6c, 0x62, 0x33, 0x32, 0xf4, 0x1b, 0x6f, 0x9c, 0x8f, 0xb1, 0xe2, 0xd5,
		0xab, 0x11, 0x3e, 0xbe, 0x5e, 0xda, 0xfb, 0x16, 0x4f, 0xee, 0x30, 0x44, 0xca, 0x89, 0xbc, 0x9b,
		0xc0, 0x6b, 0x27, 0xdd, 0x28, 0xfb, 0xc1, 0x5d, 0x1c, 0x80, 0x4b, 0x21, 0xce, 0xad, 0xd2, 0xb9,
		0xe5, 0x52, 0x08, 0xd1, 0x03, 0xd1, 0x43, 0x47, 0xf4, 0x58, 0x80, 0x62, 0xa7, 0x1d, 0xf8, 0xa3,
		0x17, 0xd5, 0x4d, 0xe3, 0x59, 0x3d, 0x2e, 0xad, 0xe5, 0x51, 0x3b, 0x50, 0x3b, 0x50, 0x3b, 0x8c,
		0x4d, 0xda, 0x0a, 0xe0, 0xe9, 0xc7, 0x89, 0x17, 0x39, 0x7e, 0xc7, 0x04, 0xa8, 0x4d, 0xc7, 0x06,
		0x90, 0x00, 0x24, 0x00, 0x29, 0xdb, 0x69, 0x9a, 0x3d, 0x40, 0x4e, 0x32, 0x18, 0x57, 0x00, 0x9b,
		0x0e, 0x35, 0xc6, 0x18, 0xbf, 0x5b, 0xee, 0x51, 0xfe, 0xb3, 0xb9, 0x9c, 0xbb, 0xcd, 0x86, 0x40,
		0xd0, 0xfa, 0x78, 0x76, 0x0e, 0x04, 0x86, 0x92, 0xc9, 0x85, 0x90, 0x9b, 0xad, 0xe9, 0x17, 0x93,
		0xcc, 0x8d, 0x10, 0x02, 0xe8, 0xb5, 0xc3, 0x0a, 0x07, 0xea, 0x4f, 0xc7, 0x35, 0x10, 0xb0, 0xaf,
		0x09, 0x18, 0xab, 0x97, 0x4a, 0x30, 0x87, 0xc2, 0xd6, 0x52, 0xb5, 0x9a, 0x87, 0xad, 0xc3, 0xfd,
		0x83, 0xe6, 0xe1, 0x5e, 0x89, 0xd6, 0xec, 0x59, 0x31, 0x46, 0xb9, 0x7a, 0x96, 0xe3, 0xce, 0x13,
		0x04, 0x64, 0xbf, 0x77, 0xdf, 0xca, 0x78, 0xdb, 0x90, 0xca, 0x68, 0xbd, 0x11, 0x18, 0xeb, 0xdc,
		0x4d, 0x12, 0x2f, 0x0a, 0xc5, 0x90, 0xb9, 0xf1, 0xdf, 0xe7, 0xcf, 0xbf, 0x6e, 0x3b, 0x87, 0x57,
		0x7f, 0x7f, 0xdd, 0x71, 0x0e, 0xaf, 0x46, 0xbf, 0xdd, 0x19, 0xfe, 0x67, 0xf4, 0xfb, 0xe6, 0xd7,
		0x6d, 0xa7, 0x35, 0xf9, 0xfd, 0xde, 0xd7, 0x6d, 0x67, 0xef, 0xea, 0xc5, 0x1f, 0x7f, 0xbc, 0x7a,
		0xf1, 0xd7, 0xee, 0x43, 0xf6, 0x0f, 0xfe, 0xa3, 0xa1, 0xbf, 0xc9, 0x24, 0x26, 0xf1, 0xec, 0xe2,
		0xe4, 0x3f, 0xcc, 0x24, 0x39, 0x5a, 0x1a, 0x5a, 0x5c, 0x2e, 0xb7, 0xe8, 0x0b, 0xae, 0x29, 0x51,
		0x86, 0x44, 0x19, 0x5a, 0x77, 0x97, 0x11, 0xdc, 0x95, 0xf4, 0x29, 0x04, 0x77, 0xf4, 0x2d, 0xf4,
		0xad, 0xea, 0xe9, 0x5b, 0x08, 0xee, 0x08, 0xee, 0x00, 0x12, 0x80, 0x54, 0x18, 0x40, 0x42, 0x70,
		0xdf, 0x34, 0x43, 0x08, 0xee, 0x59, 0xbe, 0x18, 0x82, 0x3b, 0x82, 0x3b, 0x82, 0xbb, 0x90, 0xf6,
		0x25, 0x3b, 0x0a, 0x82, 0xfb, 0xd3, 0x46, 0x0b, 0xc1, 0x1d, 0xc1, 0x1d, 0xc1, 0x1d, 0xc1, 0x7d,
		0x4b, 0x4c, 0x70, 0x27, 0x6d, 0x2d, 0xd5, 0x3c, 0x09, 0xa5, 0xad, 0x7d, 0x1a, 0x8c, 0xfa, 0x69,
		0x3a, 0xa8, 0xc5, 0xe4, 0x97, 0x6c, 0xd7, 0x19, 0x4a, 0xd7, 0x18, 0xca, 0x89, 0x2e, 0x4d, 0x12,
		0x5d, 0x24, 0x45, 0x84, 0x32, 0x27, 0xba, 0xb8, 0xfd, 0xe4, 0xbb, 0xd3, 0x73, 0xe3, 0x78, 0x3c,
		0x85, 0x8a, 0xb7, 0x6f, 0xf3, 0xc3, 0xa8, 0xdd, 0xc2, 0x6d, 0x93, 0xf6, 0x62, 0x53, 0x43, 0xab,
		0xd3, 0x2d, 0x9c, 0xb2, 0x36, 0x36, 0xa7, 0x30, 0xfb, 0xe1, 0xad, 0xea, 0x1e, 0x9f, 0x77, 0x2a,
		0x0a, 0x70, 0xdb, 0xde, 0xf1, 0xe2, 0x76, 0xe4, 0xf7, 0x94, 0xc8, 0xd0, 0x4c, 0x11, 0xef, 0xc7,
		0x41, 0x38, 0xf3, 0x9c, 0xf9, 0x8a, 0x9d, 0xf9, 0x38, 0x89, 0xd4, 0x3a, 0xda, 0x15, 0xeb, 0xa4,
		0xff, 0x0c, 0xdd, 0x3b, 0xbf, 0xed, 0x06, 0xc1, 0x4f, 0x67, 0x44, 0xc3, 0xfb, 0x91, 0xa7, 0x61,
		0xea, 0xd7, 0x8c, 0x97, 0x35, 0x2e, 0x42, 0x2f, 0x70, 0x00, 0xfc, 0x00, 0x3f, 0x0a, 0x8f, 0x1f,
		0xea, 0x17, 0xfb, 0x8a, 0x17, 0xfa, 0x66, 0x00, 0xc4, 0x0b, 0xdd, 0x6f, 0x81, 0x0e, 0x62, 0x4c,
		0x06, 0x50, 0x87, 0x08, 0x85, 0xca, 0x65, 0x20, 0x04, 0x08, 0x01, 0x42, 0x58, 0x42, 0x88, 0x38,
		0x71, 0xbf, 0x05, 0x7e, 0xfc, 0xdd, 0xeb, 0x38, 0x49, 0xe4, 0x86, 0xb1, 0x9f, 0xad, 0x0b, 0xc0,
		0x32, 0x62, 0xac, 0x19, 0x10, 0x08, 0x00, 0x02, 0x2a, 0x06, 0x01, 0xed, 0x6e, 0x3f, 0x4c, 0xbc,
		0x48, 0xa9, 0x11, 0xd6, 0x64, 0x83, 0x2b, 0xdc, 0x52, 0x6a, 0x46, 0x8b, 0x68, 0x44, 0x19, 0x49,
		0x44, 0x83, 0x08, 0x85, 0x14, 0x48, 0x45, 0x7b, 0x48, 0x46, 0x0a, 0x68, 0xdc, 0xa9, 0x8b, 0x44,
		0x6f, 0x48, 0x4f, 0xed, 0xce, 0x9b, 0x56, 0x6b, 0xff, 0xa0, 0xd5, 0xda, 0x3e, 0xd8, 0x3d, 0xd8,
		0x3e, 0xdc, 0xdb, 0xdb, 0xd9, 0xdf, 0xd9, 0x2b, 0xd0, 0x6c, 0x5b, 0xba, 0xd8, 0xbc, 0x2a, 0x80,
		0x95, 0x0e, 0xdc, 0x38, 0x71, 0x66, 0x2c, 0xab, 0xba, 0x79, 0x5e, 0x1a, 0x09, 0xbb, 0x8c, 0x5d,
		0xae, 0x98, 0x5d, 0x4e, 0xfc, 0x3b, 0x2f, 0xf1, 0xdb, 0xff, 0x8b, 0xad, 0x5b, 0xe6, 0xcf, 0xe1,
		0x08, 0xd5, 0x1a, 0xa1, 0x1b, 0x76, 0x63, 0xaf, 0xdd, 0x0d, 0x3b, 0x2a, 0x31, 0x4d, 0x58, 0x78,
		0x2c, 0x3c, 0x16, 0xbe, 0x5e, 0x16, 0xbe, 0xdb, 0x76, 0x03, 0xc7, 0xd5, 0x70, 0xbc, 0xa7, 0x23,
		0x60, 0xd1, 0xb1, 0xe8, 0x15, 0xb3, 0xe8, 0x6e, 0xec, 0x84, 0xfd, 0xbb, 0x6f, 0x5e, 0xa4, 0x61,
		0xcf, 0x0f, 0xb0, 0xc3, 0xd8, 0xe1, 0x82, 0xda, 0x61, 0xa9, 0x3c, 0x08, 0xac, 0xaf, 0x9a, 0xf5,
		0xbd, 0xf3, 0xe2, 0xd8, 0x55, 0xe9, 0x02, 0x34, 0x45, 0xa8, 0xe9, 0x08, 0xd4, 0x8d, 0xc6, 0xfa,
		0x16, 0xca, 0xfa, 0xaa, 0x97, 0xb1, 0xf0, 0xda, 0x9e, 0x7f, 0xef, 0x49, 0xe4, 0x78, 0x4f, 0x46,
		0xd2, 0xcb, 0xe8, 0xde, 0x21, 0xa3, 0x9b, 0x8c, 0x6e, 0xcb, 0xe6, 0x4c, 0xb5, 0xb8, 0x8a, 0xe2,
		0xa1, 0x7b, 0xdc, 0x2e, 0x67, 0x97, 0x27, 0xef, 0x4f, 0xde, 0x1d, 0x5d, 0x9e, 0x9c, 0x7d, 0xd4,
		0x5f, 0xea, 0xc9, 0xe6, 0x9b, 0x1b, 0xf5, 0x65, 0x21, 0x28, 0x90, 0xee, 0xe1, 0x94, 0x3c, 0xa4,
		0xf2, 0x87, 0x55, 0xfa, 0xd0, 0x1a, 0x3b, 0xbc, 0xc6, 0x0e, 0xb1, 0x91, 0xc3, 0xac, 0x77, 0xa8,
		0x05, 0xbc, 0x88, 0x2d, 0x91, 0xb2, 0x0d, 0x4b, 0xfb, 0xad, 0xef, 0x87, 0x89, 0x92, 0x68, 0xbd,
		0xee, 0x74, 0xbe, 0xa1, 0x38, 0x41, 0x2e, 0xb0, 0x66, 0xca, 0x89, 0x36, 0xe9, 0xf0, 0x09, 0x1f,
		0x0f, 0x71, 0xa7, 0xdb, 0xf6, 0x52, 0xc9, 0x8b, 0xe3, 0x56, 0x57, 0xaf, 0x1a, 0x65, 0x0a, 0x72,
		0x91, 0x88, 0x3e, 0x9f, 0xff, 0x7a, 0x74, 0x79, 0x2c, 0x47, 0xbb, 0xc6, 0xe3, 0x41, 0xb8, 0x20,
		0x5c, 0x10, 0x2e, 0x08, 0x17, 0x84, 0x0b, 0xc2, 0x05, 0xe1, 0x82, 0x70, 0x41, 0xb8, 0x26, 0xcb,
		0x32, 0x8c, 0x4a, 0x0c, 0xbb, 0x89, 0x7f, 0xe3, 0xb7, 0x87, 0x55, 0x4b, 0x1c, 0x2f, 0x8a, 0xba,
		0x91, 0xd3, 0xee, 0x76, 0x3c, 0x39, 0x1a, 0xf6, 0xe4, 0x53, 0x20, 0x67, 0x90, 0x33, 0xc8, 0x59,
		0xa1, 0xc8, 0x99, 0xdf, 0xf1, 0xc2, 0xc4, 0x4f, 0x7e, 0x66, 0x6b, 0xbe, 0xbd, 0xe9, 0x88, 0x4a,
		0xd8, 0x94, 0xc6, 0xc9, 0xf8, 0xab, 0xfd, 0xe2, 0xc6, 0x82, 0xdb, 0x78, 0xf2, 0xe2, 0xbf, 0xfc,
		0x76, 0x7e, 0x7d, 0xfc, 0xe9, 0xd3, 0xd9, 0xa7, 0xeb, 0x77, 0x67, 0xbf, 0x1e, 0x4b, 0xed, 0xe5,
		0xa1, 0x99, 0x8d, 0xc5, 0x78, 0xa5, 0x2c, 0xb7, 0x9c, 0x7b, 0xff, 0xf7, 0x27, 0x1f, 0x4f, 0x2e,
		0x8f, 0xaf, 0x2f, 0x2e, 0x8f, 0x2e, 0x8f, 0xaf, 0x3f, 0x1c, 0xbd, 0xfb, 0xe7, 0xc9, 0xc7, 0xe3,
		0xd1, 0x84, 0x34, 0x8a, 0x48, 0xb6, 0x0c, 0xcd, 0xc2, 0x3f, 0xcf, 0x4e, 0x7f, 0xbd, 0xbe, 0x3c,
		0xf9, 0xff, 0xd9, 0x7b, 0xd7, 0xe7, 0xb4, 0x91, 0xed, 0x0b, 0xf4, 0x7b, 0xfe, 0x0a, 0x17, 0x75,
		0x3e, 0xc4, 0x55, 0x51, 0x6c, 0x30, 0x8f, 0x38, 0xdf, 0x48, 0x4c, 0x32, 0xfc, 0x8e, 0x6d, 0xb8,
		0x60, 0xe7, 0xcc, 0xb9, 0x1e, 0x86, 0x92, 0xa1, 0xed, 0xf4, 0x19, 0x21, 0x71, 0x25, 0xe1, 0x89,
		0x2b, 0xe6, 0x7f, 0xbf, 0xc5, 0x4b, 0x36, 0x16, 0x4c, 0x40, 0xda, 0xbd, 0x5b, 0x8f, 0x95, 0xca,
		0x39, 0x61, 0x12, 0xd3, 0x2d, 0xf5, 0x63, 0xed, 0xb5, 0x57, 0xef, 0xde, 0xfb, 0xa2, 0xd1, 0xe9,
		0x37, 0x7e, 0x6f, 0x37, 0x3b, 0x8d, 0xb3, 0x3c, 0xbd, 0xfd, 0xe7, 0x46, 0xbd, 0xdb, 0xc8, 0xd3,
		0x0b, 0xb7, 0xda, 0x8d, 0xcb, 0xfe, 0x45, 0xa3, 0xdb, 0xad, 0x7f, 0xcd, 0xe1, 0x62, 0x5f, 0x48,
		0x64, 0xf9, 0x7d, 0xff, 0x4e, 0xeb, 0xfa, 0xaa, 0xd1, 0xef, 0x34, 0xbe, 0x74, 0x1a, 0xdd, 0xdf,
		0xf2, 0x3b, 0x0c, 0xab, 0x17, 0xff, 0xad, 0x51, 0x3f, 0x9b, 0xe1, 0x1e, 0xf1, 0xfb, 0x93, 0xb4,
		0xd4, 0xd3, 0x4d, 0xd4, 0x12, 0xe5, 0xa2, 0x79, 0x93, 0x5b, 0x1e, 0x2f, 0x6d, 0xd5, 0x11, 0x1c,
		0x35, 0x38, 0x6a, 0x70, 0xd4, 0xe0, 0xa8, 0x25, 0xcb, 0x51, 0xeb, 0x5e, 0x7f, 0xca, 0xa7, 0xaf,
		0xf6, 0x8a, 0xb8, 0xd1, 0x8e, 0x83, 0xca, 0xf1, 0x50, 0x33, 0x2e, 0xa1, 0xf1, 0xa9, 0x5f, 0x5d,
		0x75, 0x9a, 0x9f, 0x66, 0xe4, 0xee, 0xbc, 0x71, 0xf9, 0xf5, 0xea, 0x37, 0x6a, 0x4e, 0xa3, 0x80,
		0xdb, 0x31, 0x8d, 0x4c, 0xf3, 0xf2, 0x5b, 0xfd, 0xbc, 0x79, 0xd6, 0x6f, 0x75, 0x9a, 0x5f, 0x9b,
		0x97, 0xfd, 0x60, 0xa0, 0x30, 0x36, 0x07, 0x85, 0xeb, 0xcb, 0x4e, 0xe3, 0x73, 0xeb, 0xeb, 0x65,
		0xf3, 0xff, 0x6d, 0x9c, 0xf5, 0xff, 0xd3, 0x38, 0x3f, 0xef, 0xff, 0xfb, 0xb2, 0xf5, 0x1f, 0x0c,
		0xd2, 0x2b, 0x8f, 0xf9, 0xaa, 0xd9, 0xba, 0xac, 0x9f, 0x3f, 0x8f, 0x0a, 0x36, 0x57, 0x18, 0x76,
		0xbe, 0x9c, 0xd7, 0xbf, 0x76, 0x31, 0x30, 0x81, 0x87, 0x59, 0x3f, 0xff, 0xd2, 0xea, 0x5c, 0x34,
		0xce, 0xfa, 0xf5, 0x6e, 0xbf, 0x5d, 0xbf, 0xfa, 0x0d, 0x83, 0xf2, 0x0c, 0xc5, 0x97, 0x8d, 0xab,
		0xff, 0xb4, 0x3a, 0xff, 0xee, 0x7f, 0x69, 0x36, 0xce, 0xcf, 0x30, 0x30, 0x07, 0x85, 0x8b, 0x66,
		0xb7, 0xdb, 0xbc, 0xfc, 0x0a, 0x08, 0xfe, 0xf5, 0x6e, 0x7a, 0xe6, 0x39, 0xcd, 0xee, 0x15, 0xc6,
		0xe6, 0xe5, 0xa6, 0xfa, 0xfd, 0xaa, 0xff, 0x5b, 0xab, 0xad, 0x74, 0xe5, 0x90, 0xb6, 0xd8, 0xcb,
		0x91, 0xe2, 0xa8, 0x9a, 0x9f, 0x27, 0x7f, 0x04, 0xd4, 0xf3, 0xf0, 0x14, 0x1c, 0x3f, 0xf0, 0xf1,
		0xed, 0x34, 0x9c, 0x44, 0xa9, 0xe6, 0xd5, 0x69, 0x82, 0x05, 0x25, 0xfc, 0x39, 0x05, 0x27, 0x31,
		0xea, 0x78, 0x72, 0x7a, 0x20, 0x51, 0x11, 0x1f, 0x4e, 0xc1, 0xec, 0xb3, 0xf0, 0xde, 0x54, 0xed,
		0x02, 0x45, 0xfc, 0x36, 0x4d, 0x9b, 0x41, 0x1d, 0x8f, 0x4d, 0xfe, 0x28, 0x6c, 0x8c, 0x49, 0x82,
		0xda, 0xfd, 0x6a, 0x94, 0x3a, 0x8d, 0xcf, 0x8d, 0xe6, 0xb7, 0x46, 0xff, 0xfa, 0xb2, 0xf1, 0x7b,
		0xbb, 0xf1, 0xf9, 0xaa, 0x71, 0x16, 0x9c, 0x0c, 0xb4, 0xda, 0x8d, 0xcb, 0xcf, 0xad, 0xcb, 0x2f,
		0xcd, 0xce, 0x05, 0xbc, 0xc3, 0x7f, 0x1c, 0xa9, 0x46, 0xf7, 0xaa, 0xfe, 0xe9, 0xbc, 0xd9, 0xfd,
		0xad, 0x01, 0x0d, 0xe6, 0xd7, 0x6b, 0xaa, 0xdb, 0xb8, 0xbc, 0x82, 0x43, 0x9d, 0x1c, 0xa0, 0xe4,
		0x86, 0x80, 0x54, 0x8f, 0x88, 0x92, 0xad, 0x9e, 0xfa, 0x35, 0x42, 0xbb, 0xa5, 0xd3, 0xa0, 0x3e,
		0x74, 0xdb, 0x8d, 0xcf, 0xcd, 0x2f, 0xcd, 0xcf, 0xb9, 0x8b, 0xf0, 0x05, 0x85, 0x0a, 0x29, 0x0f,
		0x67, 0x17, 0xcd, 0xcb, 0x66, 0xf7, 0xaa, 0x53, 0xbf, 0x9a, 0x6d, 0x91, 0x4e, 0xa3, 0xdb, 0x80,
		0x9c, 0x3e, 0x5b, 0x2e, 0xad, 0xcb, 0xcb, 0xfe, 0xe7, 0xd6, 0xf9, 0x79, 0xb3, 0xdb, 0x6c, 0x5d,
		0xce, 0xc6, 0xa5, 0x75, 0x7e, 0x3d, 0x4f, 0x64, 0x84, 0xc1, 0x29, 0xb4, 0xae, 0xaf, 0xfa, 0xad,
		0x2f, 0xf3, 0x41, 0xb9, 0xee, 0x7c, 0x6e, 0x74, 0x31, 0x26, 0x07, 0x85, 0x76, 0xa3, 0xd1, 0xe9,
		0x9f, 0x35, 0xfa, 0x73, 0xc6, 0xf1, 0xf5, 0xba, 0x03, 0x36, 0xbd, 0x01, 0x5e, 0xba, 0xbf, 0x5d,
		0x5f, 0x9d, 0xb5, 0xfe, 0x83, 0x4d, 0xb4, 0x44, 0x98, 0xc6, 0xe7, 0xab, 0x05, 0xba, 0xfc, 0xdf,
		0x9c, 0x96, 0x60, 0x58, 0x0e, 0x0a, 0xad, 0xab, 0xdf, 0x1a, 0x9d, 0xe5, 0x2e, 0xea, 0x7f, 0xfe,
		0xad, 0x7e, 0xf9, 0x15, 0x47, 0xdf, 0x73, 0x69, 0xf0, 0xf7, 0xfe, 0xe5, 0xf5, 0x45, 0xbf, 0xdd,
		0x69, 0x7c, 0x69, 0xfe, 0xde, 0xe8, 0xf6, 0x3b, 0x8d, 0xfa, 0x67, 0x35, 0x2e, 0x3b, 0x7c, 0xd1,
		0x44, 0x72, 0xa9, 0x14, 0x50, 0x6c, 0xf5, 0x9c, 0x29, 0x05, 0xc7, 0x99, 0xca, 0xb8, 0x51, 0xf2,
		0xdf, 0x5d, 0x25, 0x07, 0x4a, 0xdd, 0xf6, 0xa7, 0xe7, 0x3a, 0xe9, 0x40, 0x00, 0x65, 0x9c, 0x26,
		0x05, 0x7b, 0x5f, 0x25, 0x77, 0x49, 0xc3, 0xf1, 0xa5, 0x6a, 0x8e, 0x92, 0xb6, 0x9b, 0xb5, 0x90,
		0x9b, 0x5e, 0x0d, 0xcf, 0xea, 0x74, 0x77, 0xa5, 0xbf, 0x2e, 0xa2, 0xe0, 0x40, 0x62, 0x93, 0xb3,
		0x80, 0x55, 0xcf, 0x50, 0xea, 0x6e, 0x85, 0x63, 0x0f, 0x6f, 0x37, 0xf2, 0x97, 0xad, 0xab, 0x7e,
		0xf7, 0xbf, 0x97, 0x9f, 0x7f, 0xeb, 0xb4, 0xe6, 0xc1, 0x8c, 0xf0, 0xd4, 0x0f, 0x0a, 0x9f, 0xea,
		0x0c, 0xf0, 0x96, 0xea, 0x51, 0xb9, 0xfa, 0x6f, 0x1b, 0x41, 0xe9, 0xc9, 0x64, 0xed, 0xea, 0x36,
		0x74, 0xf2, 0x87, 0x41, 0xe5, 0xc6, 0x4d, 0xd7, 0xdb, 0xd3, 0x6e, 0xd0, 0x94, 0x25, 0x43, 0x82,
		0xbd, 0xdf, 0xb0, 0x32, 0x3e, 0x7d, 0x6d, 0xf7, 0x9b, 0x67, 0x8d, 0xcb, 0xab, 0xe6, 0x97, 0x66,
		0x03, 0x37, 0x3b, 0xe7, 0x51, 0x14, 0xf5, 0xcf, 0x9f, 0x1b, 0xed, 0xab, 0xfa, 0xa7, 0xf3, 0x46,
		0x3f, 0x48, 0x9e, 0x86, 0x91, 0x99, 0xc7, 0x97, 0x5c, 0xb7, 0xdb, 0xad, 0xce, 0x55, 0xe3, 0xac,
		0xff, 0xb9, 0xde, 0xae, 0x7f, 0x6a, 0x9e, 0x37, 0xaf, 0xfe, 0x8b, 0x91, 0x59, 0xec, 0xa4, 0xb9,
		0x46, 0x5a, 0xc7, 0x91, 0xf9, 0xab, 0x85, 0xf2, 0xad, 0xd1, 0x99, 0x1f, 0x1a, 0x5c, 0x5e, 0x5f,
		0x7c, 0x02, 0xc0, 0xbc, 0x1e, 0x9d, 0xe0, 0x8e, 0x54, 0xbb, 0xde, 0xa9, 0x5f, 0x34, 0xae, 0x94,
		0x8c, 0x10, 0xf8, 0x73, 0x02, 0x0d, 0x64, 0x1a, 0xc2, 0x09, 0xd5, 0x1a, 0xc2, 0x54, 0x04, 0x54,
		0x2a, 0x35, 0x78, 0xe9, 0xd8, 0x01, 0xe4, 0x86, 0x2d, 0x5d, 0x13, 0xaf, 0xca, 0x80, 0xa5, 0x6b,
		0x14, 0x54, 0x1a, 0x2a, 0xe4, 0xd3, 0xa4, 0xcc, 0xa7, 0xe9, 0xcb, 0x91, 0xd2, 0x34, 0x9a, 0xf3,
		0xf6, 0x91, 0x3d, 0xf3, 0x97, 0x23, 0x87, 0xec, 0x99, 0xc8, 0x9e, 0xb9, 0xfd, 0x8d, 0xe8, 0xb3,
		0x67, 0xce, 0xf6, 0xa5, 0x2f, 0x07, 0x7f, 0x79, 0x89, 0x2b, 0x44, 0x75, 0x6d, 0x2f, 0x8a, 0xe4,
		0x14, 0x6c, 0xd3, 0x76, 0x3c, 0x31, 0x70, 0xec, 0xa1, 0x57, 0x40, 0x81, 0x2b, 0x2d, 0x98, 0x19,
		0x6a, 0x16, 0x05, 0xae, 0x50, 0xe0, 0x8a, 0x77, 0xf6, 0xf2, 0x5e, 0xe0, 0x8a, 0xb5, 0x82, 0x7c,
		0xdd, 0xb6, 0x1d, 0x7f, 0x4e, 0xdc, 0xe2, 0x15, 0x92, 0xf7, 0x06, 0xdf, 0xc5, 0xc8, 0x1c, 0x9b,
		0xfe, 0xf7, 0x19, 0x90, 0x1f, 0x39, 0x63, 0x61, 0x0f, 0xe6, 0xec, 0x6b, 0x66, 0x8c, 0x8f, 0x66,
		0xff, 0xb3, 0x85, 0xbc, 0xff, 0x7e, 0xeb, 0xb8, 0x5e, 0xf0, 0xe9, 0xc8, 0xf3, 0x4d, 0x5f, 0x1c,
		0x8d, 0x84, 0xe7, 0x99, 0xf7, 0xc2, 0x3b, 0x72, 0xc5, 0x40, 0xc8, 0x07, 0x31, 0x8c, 0x81, 0xfd,
		0x05, 0xcf, 0x77, 0x27, 0x03, 0xdf, 0x5e, 0xb9, 0xa7, 0xf7, 0xe3, 0xfe, 0xe5, 0xb2, 0xb7, 0xfe,
		0xc5, 0xb2, 0x9f, 0x7e, 0x67, 0xd5, 0xcf, 0x1b, 0x9e, 0xf9, 0x89, 0x30, 0x37, 0x05, 0x6f, 0xc1,
		0x66, 0xa2, 0xcd, 0x48, 0x60, 0xf3, 0xe7, 0xad, 0x44, 0x5c, 0x19, 0xab, 0xf4, 0xd8, 0x11, 0xbf,
		0x1e, 0x97, 0x7b, 0x53, 0x70, 0x6e, 0x3a, 0xae, 0x4d, 0xc5, 0xb1, 0xc9, 0xb9, 0x35, 0x39, 0xa7,
		0x26, 0xe5, 0xd2, 0xbc, 0x58, 0x76, 0x26, 0xdd, 0x98, 0xcb, 0xa5, 0x75, 0xd5, 0xfc, 0xd2, 0xfc,
		0x5c, 0x9f, 0x5f, 0x5d, 0x20, 0x73, 0x91, 0xd7, 0x5a, 0x85, 0x63, 0x0c, 0xc7, 0x18, 0x8e, 0x71,
		0xa2, 0x1c, 0x63, 0x14, 0x67, 0x86, 0xef, 0x0a, 0xdf, 0x15, 0xbe, 0x2b, 0x7c, 0xd7, 0xf8, 0xbe,
		0x6b, 0x0c, 0x86, 0xbd, 0xa8, 0xf0, 0x42, 0x47, 0xbb, 0x96, 0xed, 0x81, 0x70, 0x81, 0x70, 0x81,
		0x70, 0x81, 0x70, 0x81, 0x70, 0x81, 0x70, 0x81, 0x70, 0x81, 0x70, 0x81, 0x70, 0xad, 0xa6, 0x65,
		0x5b, 0x05, 0x54, 0x9e, 0x3a, 0xab, 0x28, 0xb2, 0x0a, 0x72, 0x06, 0x72, 0x86, 0x22, 0xab, 0x7b,
		0xb4, 0xc5, 0x55, 0x64, 0x35, 0x9f, 0x15, 0x56, 0x37, 0x66, 0x9e, 0xcf, 0x5d, 0x3d, 0x92, 0x20,
		0x8e, 0xbd, 0xd3, 0x6f, 0xfc, 0xde, 0x6e, 0xe6, 0x2c, 0x93, 0xd1, 0x3c, 0x57, 0x6e, 0x6e, 0x2f,
		0x80, 0xe6, 0x6e, 0xb1, 0xbf, 0x2a, 0xaa, 0x9c, 0xbb, 0xf7, 0x5f, 0xcf, 0xd9, 0x93, 0xdb, 0x61,
		0x78, 0x95, 0xf7, 0x84, 0xfa, 0xfd, 0x11, 0xbd, 0x4f, 0xee, 0xa2, 0x79, 0x93, 0x5b, 0x1e, 0x2f,
		0x6d, 0xd5, 0x11, 0x1c, 0x35, 0x38, 0x6a, 0x70, 0xd4, 0xe0, 0xa8, 0x25, 0xcb, 0x51, 0xa3, 0xcd,
		0xd8, 0x91, 0x22, 0x5f, 0xed, 0x15, 0x71, 0x43, 0xe6, 0x92, 0x57, 0xe3, 0xa3, 0xba, 0xda, 0xae,
		0x02, 0x6e, 0xc7, 0x34, 0x32, 0xea, 0xab, 0xf0, 0xa6, 0x77, 0x6c, 0x18, 0xab, 0xf3, 0xa6, 0x77,
		0x90, 0xd4, 0x57, 0xed, 0x4d, 0xef, 0xd8, 0x28, 0xae, 0xe6, 0x9b, 0xde, 0x81, 0x51, 0x58, 0xe5,
		0x37, 0xfd, 0x50, 0xac, 0xa8, 0xfa, 0x6f, 0x8a, 0x57, 0x0b, 0x4b, 0x55, 0xe0, 0x4c, 0xec, 0x26,
		0x45, 0xd5, 0x82, 0xb3, 0xb0, 0xa9, 0xd4, 0x55, 0x11, 0xa6, 0x55, 0xb6, 0xe8, 0x14, 0x2e, 0x05,
		0xb3, 0xa6, 0xbc, 0xec, 0xbd, 0x1a, 0x7e, 0x9e, 0x9e, 0x6c, 0xdb, 0xea, 0x78, 0x78, 0x1a, 0xf2,
		0xc7, 0xb0, 0xf1, 0xed, 0x34, 0x9c, 0x44, 0xa9, 0xe6, 0xd5, 0x69, 0x82, 0x05, 0x25, 0xfc, 0x39,
		0x0d, 0x85, 0x34, 0x94, 0xf1, 0xe4, 0xf4, 0x40, 0xa2, 0x22, 0x3e, 0x9c, 0x82, 0xd9, 0x67, 0xe1,
		0xbd, 0xa9, 0xda, 0x05, 0x8a, 0xf8, 0x6d, 0x9a, 0x36, 0x83, 0x3a, 0x1e, 0x9b, 0xfc, 0x51, 0xd8,
		0x18, 0x93, 0x04, 0xb5, 0xfb, 0xd5, 0x28, 0x71, 0x97, 0xc2, 0x4f, 0xaf, 0x77, 0xc8, 0x5d, 0x22,
		0x3f, 0x93, 0x23, 0x45, 0x5f, 0x3a, 0x1f, 0x0e, 0x75, 0xda, 0x20, 0x20, 0xd5, 0x23, 0xa2, 0x64,
		0xab, 0xa7, 0x7e, 0x8d, 0xd0, 0x6e, 0xe9, 0x54, 0x64, 0xaf, 0x6d, 0x37, 0x3e, 0x37, 0xbf, 0x34,
		0x3f, 0xe7, 0x2e, 0xc2, 0x17, 0x14, 0x2a, 0xa4, 0x3c, 0x28, 0xad, 0xe0, 0x9c, 0x5e, 0x1a, 0xc0,
		0x50, 0xd9, 0x39, 0xbd, 0x83, 0xa3, 0xae, 0xe2, 0x73, 0x7a, 0xc7, 0x44, 0x65, 0x25, 0xe8, 0xf4,
		0x8e, 0x8a, 0xf2, 0x0a, 0xd1, 0xe9, 0x46, 0x18, 0x65, 0x95, 0xa3, 0x53, 0x8c, 0x2d, 0x2a, 0x2b,
		0x4a, 0xa7, 0x77, 0x58, 0xd4, 0x57, 0x9a, 0x86, 0x2f, 0x9a, 0x6c, 0x2e, 0x95, 0x8e, 0xaa, 0x9a,
		0x8a, 0x39, 0x53, 0x0a, 0x8e, 0x33, 0x95, 0x71, 0xa3, 0xe4, 0xbf, 0xbb, 0x4a, 0x0e, 0x94, 0xba,
		0xed, 0x4f, 0xcf, 0x75, 0x52, 0x55, 0x57, 0x97, 0x9e, 0xd3, 0xa4, 0x60, 0xef, 0xab, 0xe4, 0x2e,
		0x69, 0x38, 0xbe, 0x54, 0xcd, 0x51, 0xd2, 0x76, 0xb3, 0x16, 0x72, 0xd3, 0xab, 0xe1, 0x59, 0x9d,
		0xee, 0x2a, 0x2f, 0x17, 0x0f, 0x12, 0x9b, 0xd0, 0x19, 0x4a, 0xdd, 0xad, 0x70, 0xec, 0xe1, 0xed,
		0x46, 0x5e, 0x5d, 0xf1, 0xfc, 0xf4, 0x7a, 0xea, 0x2a, 0x8b, 0xea, 0x67, 0x63, 0x54, 0x68, 0x8b,
		0xed, 0x03, 0xf2, 0x53, 0xb1, 0xa1, 0xd3, 0x51, 0xd2, 0x35, 0xbf, 0x56, 0x4f, 0xdd, 0x06, 0x4d,
		0x59, 0x32, 0x24, 0xd8, 0xfb, 0x0d, 0x2b, 0x43, 0x55, 0xb1, 0xef, 0xf4, 0x1a, 0x34, 0xd5, 0x45,
		0xc0, 0xd3, 0x3c, 0x32, 0x6a, 0x8b, 0x83, 0xa7, 0x9b, 0x04, 0x91, 0x17, 0x0d, 0xcf, 0xc6, 0x42,
		0x51, 0x55, 0x4c, 0x3c, 0x1b, 0xa3, 0xa3, 0xb2, 0xc8, 0x38, 0xf8, 0x73, 0x92, 0x0d, 0x64, 0x1a,
		0xc2, 0x09, 0xd5, 0x1a, 0xc2, 0x54, 0x04, 0x54, 0x2a, 0x35, 0x78, 0xe9, 0xd8, 0x01, 0xe4, 0x86,
		0x2d, 0x5d, 0x13, 0xaf, 0xca, 0x80, 0xa5, 0x6b, 0x14, 0x54, 0x1a, 0x2a, 0xe4, 0xd3, 0xa4, 0xcc,
		0xa7, 0xe9, 0xcb, 0x91, 0xd2, 0x34, 0x9a, 0xf3, 0xf6, 0x91, 0x3d, 0xf3, 0x97, 0x23, 0x87, 0xec,
		0x99, 0xc8, 0x9e, 0xb9, 0xfd, 0x8d, 0xe8, 0xb3, 0x67, 0xce, 0xf6, 0xa5, 0x2f, 0x07, 0x7f, 0x79,
		0x89, 0x2b, 0x44, 0x75, 0x6d, 0x2f, 0x8a, 0xe4, 0x14, 0x6c, 0xd3, 0x76, 0x3c, 0x31, 0x70, 0xec,
		0xa1, 0x57, 0x40, 0x81, 0x2b, 0x2d, 0x98, 0x19, 0x6a, 0x16, 0x05, 0xae, 0x50, 0xe0, 0x8a, 0x77,
		0xf6, 0xf2, 0x5e, 0xe0, 0x8a, 0xb5, 0x82, 0x7c, 0xdd, 0xb6, 0x1d, 0x7f, 0x4e, 0xdc, 0xe2, 0x15,
		0x92, 0xf7, 0x06, 0xdf, 0xc5, 0xc8, 0x1c, 0x9b, 0xfe, 0xf7, 0x19, 0x90, 0x1f, 0x39, 0x63, 0x61,
		0x0f, 0xe6, 0xec, 0x6b, 0x66, 0x8c, 0x8f, 0x66, 0xff, 0xb3, 0x85, 0xbc, 0xff, 0x7e, 0xeb, 0xb8,
		0x5e, 0xf0, 0xe9, 0xc8, 0xf3, 0x4d, 0x5f, 0x1c, 0x8d, 0x84, 0xe7, 0x99, 0xf7, 0xc2, 0x3b, 0xf2,
		0x66, 0x16, 0x3c, 0x06, 0xd7, 0xf5, 0x7c, 0x77, 0x32, 0xf0, 0xed, 0x95, 0x6b, 0x7a, 0x3f, 0xee,
		0x5f, 0x2e, 0x7b, 0xea, 0x5f, 0x2c, 0xfb, 0xe8, 0x77, 0x67, 0x7d, 0xbc, 0xe1, 0x99, 0x97, 0xfd,
		0xbe, 0xb1, 0xe7, 0x0c, 0xc6, 0x9d, 0x39, 0x8a, 0x19, 0x8b, 0x30, 0x59, 0xbb, 0x4c, 0xd2, 0x7e,
		0xf3, 0xb3, 0xfb, 0x28, 0xef, 0x31, 0xc2, 0x85, 0xd5, 0x1b, 0x1b, 0xe6, 0x70, 0xe8, 0x0a, 0xcf,
		0xdb, 0x7b, 0x8c, 0x03, 0xde, 0x15, 0x6a, 0x69, 0xcf, 0x79, 0x8e, 0x66, 0x2c, 0x22, 0xfb, 0x3e,
		0x71, 0x7c, 0x9d, 0xf8, 0xbe, 0x4d, 0x5c, 0x5f, 0x86, 0xcc, 0x77, 0x21, 0xf3, 0x55, 0x48, 0x7c,
		0x13, 0xb5, 0x48, 0x12, 0xd9, 0xd7, 0x78, 0xce, 0xcc, 0x3f, 0x8e, 0xb8, 0xba, 0x5f, 0xae, 0xf0,
		0xe2, 0x69, 0x84, 0xef, 0x2e, 0x9f, 0x3d, 0x1a, 0xc5, 0x8f, 0x61, 0xef, 0x9e, 0xdf, 0xfc, 0xa1,
		0x1c, 0xe3, 0xdd, 0x43, 0x63, 0x10, 0xc3, 0x9f, 0x2a, 0xb4, 0x4d, 0xdf, 0x17, 0xae, 0x1d, 0xdb,
		0xe3, 0x29, 0xfc, 0xf9, 0xf6, 0xed, 0xcd, 0xb1, 0x71, 0xda, 0x7b, 0xba, 0x29, 0x1a, 0xa7, 0xbd,
		0xc5, 0xc7, 0xe2, 0xfc, 0x8f, 0xc5, 0xe7, 0xd2, 0xcd, 0xb1, 0x51, 0x5e, 0x7d, 0xae, 0xdc, 0x1c,
		0x1b, 0x95, 0xde, 0xe1, 0x1f, 0x7f, 0xbc, 0x3f, 0xfc, 0x79, 0x32, 0xdd, 0xff, 0x8b, 0xff, 0x8a,
		0xee, 0xaa, 0xf7, 0xe2, 0x0c, 0x56, 0xab, 0xdb, 0xfc, 0x3d, 0x7f, 0x23, 0xc6, 0x49, 0x2e, 0x69,
		0xb6, 0x57, 0x35, 0xab, 0xdb, 0xcb, 0x34, 0xee, 0xea, 0xc6, 0x97, 0xde, 0xcf, 0xe2, 0xbb, 0xf2,
		0xf4, 0xe3, 0xe1, 0xcf, 0xda, 0xf4, 0xf5, 0x5f, 0x3e, 0x6d, 0xfa, 0xb1, 0xe2, 0xbb, 0xda, 0xf4,
		0xe3, 0x96, 0x7f, 0xa9, 0x4e, 0x3f, 0xee, 0xd8, 0x46, 0x65, 0xfa, 0x36, 0xf4, 0xa3, 0xb3, 0xbf,
		0x2f, 0x6d, 0xfb, 0x42, 0x79, 0xcb, 0x17, 0x4e, 0xb6, 0x7d, 0xe1, 0x64, 0xcb, 0x17, 0xb6, 0x3e,
		0x52, 0x69, 0xcb, 0x17, 0x2a, 0xd3, 0xa7, 0xd0, 0xcf, 0xbf, 0xdd, 0xfc, 0xa3, 0xd5, 0xe9, 0xe1,
		0xd3, 0xb6, 0x7f, 0xab, 0x4d, 0x9f, 0x3e, 0x1e, 0x66, 0x0a, 0x6c, 0xb0, 0x7e, 0xd2, 0xb5, 0x7e,
		0x98, 0xbc, 0xce, 0x5e, 0x02, 0xbc, 0xa7, 0xb1, 0x10, 0xae, 0x61, 0xc6, 0x70, 0x9a, 0x56, 0x0d,
		0xc0, 0x57, 0x82, 0xaf, 0x94, 0x31, 0x5f, 0xc9, 0xf4, 0x0c, 0x7b, 0x32, 0xba, 0x15, 0x6e, 0x0c,
		0x57, 0xa9, 0x16, 0xe1, 0xab, 0xf1, 0x4e, 0x43, 0x62, 0x70, 0x39, 0x8a, 0xd3, 0x0e, 0xaa, 0x13,
		0x61, 0xa2, 0xd3, 0x0c, 0x4a, 0xfd, 0x3b, 0xce, 0xe9, 0x3e, 0xc5, 0xe9, 0x04, 0xf5, 0xd0, 0x96,
		0x4b, 0xa7, 0xe5, 0xd3, 0x6a, 0xad, 0x74, 0x5a, 0x49, 0xd0, 0x18, 0xe7, 0xcd, 0xf6, 0xde, 0xbb,
		0xce, 0x64, 0x1c, 0xd3, 0xfc, 0x2e, 0xda, 0x80, 0x05, 0x86, 0x05, 0xce, 0x98, 0x05, 0xb6, 0x84,
		0x79, 0x17, 0xad, 0x86, 0x68, 0xa0, 0x23, 0x44, 0x31, 0xc0, 0xed, 0xe5, 0x51, 0xcb, 0xfb, 0xf7,
		0x47, 0xc1, 0xef, 0xe7, 0x8d, 0xe6, 0xbd, 0xf8, 0xfc, 0xe2, 0xa3, 0x31, 0x3f, 0x29, 0x49, 0x0a,
		0xac, 0xf8, 0x51, 0xc6, 0x7e, 0x1d, 0x55, 0xe6, 0x4d, 0x00, 0x54, 0x00, 0x2a, 0x19, 0x03, 0x95,
		0xa8, 0x8b, 0x7b, 0x0d, 0x56, 0xca, 0x11, 0xbe, 0xdb, 0xb0, 0x27, 0xa3, 0xd9, 0xa3, 0x4f, 0x13,
		0x00, 0x12, 0xff, 0xdf, 0x44, 0x2c, 0xee, 0x3a, 0x46, 0x44, 0x88, 0xe5, 0xf7, 0xa3, 0xc1, 0x43,
		0x11, 0xf0, 0x00, 0x78, 0x50, 0x03, 0x0f, 0x67, 0xd2, 0x8d, 0x36, 0xdd, 0xd2, 0x1e, 0x4f, 0xfc,
		0xe8, 0x73, 0x15, 0x1c, 0x83, 0xcc, 0x9b, 0x89, 0x38, 0xbc, 0xf1, 0xfc, 0xbb, 0xd8, 0x41, 0xd4,
		0x14, 0xc1, 0xd3, 0x74, 0x41, 0xd3, 0x54, 0xc1, 0xd2, 0xe4, 0x41, 0xd2, 0xe4, 0xc1, 0xd1, 0xa4,
		0x41, 0xd1, 0xbc, 0x41, 0x69, 0xb1, 0x83, 0x9f, 0x83, 0xf5, 0x32, 0x91, 0xb6, 0x7f, 0x52, 0x22,
		0x38, 0x39, 0xac, 0xc5, 0x68, 0x82, 0x26, 0x0e, 0x99, 0x20, 0x14, 0x9c, 0x32, 0xee, 0x98, 0x38,
		0x88, 0x95, 0x3a, 0xce, 0x58, 0x45, 0x84, 0x2a, 0x41, 0x5c, 0x31, 0x69, 0x3c, 0xb1, 0xaa, 0x29,
		0xa0, 0x52, 0xf0, 0x94, 0xce, 0x85, 0xa6, 0xe8, 0x5c, 0xae, 0x53, 0xbc, 0x08, 0x6b, 0xad, 0xe0,
		0x4c, 0x7c, 0x12, 0xb6, 0xb1, 0x6c, 0x07, 0x74, 0x03, 0x74, 0x03, 0x74, 0x03, 0x74, 0x03, 0x74,
		0x03, 0x74, 0x03, 0x74, 0x23, 0xe3, 0x74, 0x23, 0xab, 0x57, 0x55, 0x22, 0x29, 0x8a, 0x07, 0xbf,
		0xb8, 0xa8, 0xf2, 0xff, 0x2c, 0x1a, 0x4d, 0x80, 0xe0, 0xea, 0x8a, 0x91, 0xf3, 0x20, 0x8c, 0xb1,
		0x2b, 0x1f, 0x4c, 0x5f, 0xc4, 0x0a, 0xb9, 0x0a, 0x37, 0x85, 0x53, 0x1a, 0x75, 0xc4, 0x0e, 0x32,
		0xac, 0x96, 0x53, 0x9a, 0xd0, 0x22, 0x37, 0x9c, 0xf1, 0x1c, 0x97, 0x62, 0x1c, 0xda, 0x44, 0x30,
		0x5b, 0x85, 0xe6, 0x50, 0xd8, 0xbe, 0xf4, 0x1f, 0x3f, 0x99, 0x9e, 0x88, 0xef, 0xb0, 0x75, 0x1a,
		0x17, 0xad, 0x6f, 0x8d, 0x7e, 0xbb, 0xd3, 0xfc, 0x56, 0xbf, 0x6a, 0xf4, 0xeb, 0xdd, 0x65, 0x3a,
		0x96, 0xa8, 0x4b, 0x8a, 0x20, 0x65, 0x25, 0x51, 0x7a, 0x91, 0x17, 0xaf, 0xb4, 0x7c, 0xc9, 0xfa,
		0xf9, 0x79, 0x41, 0x47, 0xac, 0x95, 0x8a, 0x17, 0x6a, 0x9f, 0xd7, 0x3f, 0xc7, 0x7d, 0xa3, 0x37,
		0x3c, 0xb4, 0x22, 0x09, 0xa7, 0x8b, 0xae, 0x33, 0xf1, 0x85, 0x71, 0x67, 0x99, 0x63, 0x63, 0x68,
		0x8e, 0xc6, 0xd2, 0xbe, 0x8f, 0x61, 0xed, 0xc2, 0x6d, 0xed, 0x7b, 0x26, 0x24, 0xee, 0xcc, 0x89,
		0x35, 0x47, 0xcb, 0x3b, 0xd3, 0xf2, 0x10, 0xd4, 0x00, 0x73, 0x99, 0x39, 0x73, 0x79, 0xeb, 0x38,
		0x96, 0x30, 0x63, 0x59, 0xc7, 0x62, 0x02, 0x80, 0xc3, 0x13, 0xf6, 0xd0, 0x18, 0x38, 0xa3, 0xd1,
		0xc4, 0x96, 0xfe, 0x63, 0x74, 0xd0, 0x78, 0xd5, 0x4e, 0x74, 0xc0, 0xb8, 0x6c, 0x5d, 0x36, 0x80,
		0x17, 0xc0, 0x8b, 0xac, 0xe1, 0x45, 0xb0, 0x37, 0x72, 0x1f, 0x09, 0xe5, 0x09, 0xcf, 0x93, 0x8e,
		0x6d, 0xcc, 0x55, 0x88, 0x38, 0x88, 0xf3, 0xb2, 0x19, 0x20, 0x06, 0x10, 0x23, 0x63, 0x88, 0x21,
		0xec, 0xc9, 0x48, 0xb8, 0x66, 0x5c, 0x1f, 0x3c, 0xf5, 0x70, 0x31, 0x19, 0x8f, 0x1d, 0xd7, 0x17,
		0x43, 0x63, 0x60, 0x8e, 0xcd, 0x5b, 0x69, 0x49, 0x5f, 0xc6, 0x09, 0xa4, 0xdc, 0xd2, 0x1e, 0x00,
		0x04, 0x00, 0x92, 0x31, 0x00, 0x91, 0x4b, 0x25, 0x2d, 0xe6, 0x85, 0x0e, 0xfd, 0x22, 0xde, 0xa7,
		0xaf, 0xed, 0x97, 0x49, 0xc4, 0x53, 0x2f, 0xdd, 0x5d, 0xb4, 0x3f, 0x7d, 0x6d, 0xa7, 0x59, 0xaa,
		0xab, 0x77, 0x2f, 0x4f, 0x4a, 0x69, 0x7e, 0x81, 0xaf, 0x9d, 0xfa, 0xe7, 0xc6, 0x97, 0xeb, 0xf3,
		0x7e, 0xa7, 0xd1, 0xbd, 0xaa, 0x77, 0xae, 0xd2, 0xfc, 0x2e, 0x6b, 0xe5, 0x55, 0x53, 0xbd, 0xaa,
		0xce, 0xce, 0xfa, 0xed, 0xfa, 0xd5, 0x6f, 0xdd, 0x34, 0xbf, 0x44, 0xe3, 0xf7, 0xab, 0xc6, 0xe5,
		0x59, 0xe3, 0xac, 0x7f, 0xd9, 0xf8, 0xfd, 0xea, 0xb7, 0x56, 0xbb, 0xdf, 0xb8, 0xfc, 0xdc, 0x3a,
		0x6b, 0x5e, 0x7e, 0xcd, 0x9c, 0x90, 0xbd, 0xa7, 0x3d, 0x3b, 0x97, 0x9e, 0x5f, 0xf7, 0xfd, 0x88,
		0xb7, 0x05, 0x2e, 0xa4, 0xdd, 0xb0, 0xc4, 0xcc, 0x62, 0x7b, 0xd1, 0xe2, 0x2c, 0x0a, 0x17, 0xe6,
		0x8f, 0x17, 0x2d, 0xd0, 0x24, 0x82, 0x2d, 0xb4, 0xdc, 0xa1, 0x70, 0xc5, 0xf0, 0xd3, 0x63, 0xe1,
		0xe3, 0x81, 0x3d, 0xb1, 0x2c, 0x55, 0x7c, 0xf9, 0x0d, 0xe1, 0x8c, 0x44, 0x8d, 0x39, 0x88, 0x11,
		0x6b, 0xb0, 0xdb, 0xda, 0xff, 0xf5, 0x5b, 0xee, 0xf0, 0x86, 0xf3, 0x64, 0xde, 0xee, 0xee, 0xfe,
		0xc1, 0x5a, 0x12, 0x70, 0x77, 0x57, 0x3f, 0x60, 0xcf, 0x8b, 0x55, 0x7b, 0xf3, 0xfe, 0x28, 0x7c,
		0x3f, 0x3a, 0xcf, 0x8f, 0xca, 0xef, 0x63, 0xf3, 0xfa, 0xd8, 0x7c, 0x3e, 0x16, 0x8f, 0xa7, 0xdd,
		0x55, 0xfb, 0x5e, 0x84, 0x2a, 0x0c, 0x56, 0x6b, 0x22, 0xa2, 0x23, 0xbb, 0xfc, 0x3e, 0x6e, 0x04,
		0xc2, 0x71, 0x4d, 0x94, 0xa1, 0x8f, 0x7c, 0x23, 0x70, 0xe0, 0xd8, 0xb6, 0x18, 0xf8, 0x86, 0x2b,
		0x7c, 0xf7, 0x31, 0xbe, 0xd7, 0xb8, 0xde, 0x5c, 0xc4, 0xe1, 0x7e, 0x71, 0x32, 0x75, 0x72, 0x8c,
		0xb8, 0x7f, 0xc4, 0xfd, 0x73, 0xef, 0xd5, 0x78, 0x4e, 0x80, 0xfe, 0xb8, 0xff, 0xa1, 0x18, 0xc8,
		0x91, 0x69, 0xc5, 0xaa, 0xac, 0x12, 0x18, 0xad, 0x52, 0x8c, 0x36, 0x42, 0xa1, 0xcf, 0x25, 0x5c,
		0x24, 0xd8, 0x3c, 0xcc, 0x25, 0x5c, 0x24, 0xd8, 0xd3, 0xb1, 0x24, 0x9f, 0x82, 0x93, 0x1c, 0x4d,
		0x01, 0xae, 0x2b, 0x86, 0x86, 0xf9, 0xbb, 0x63, 0x0d, 0xe3, 0x55, 0xa3, 0x0b, 0xf0, 0xf7, 0xb9,
		0xa9, 0xf8, 0x0c, 0xe8, 0x14, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c,
		0x08, 0x0c, 0x08, 0x0c, 0x48, 0x1d, 0x03, 0xfa, 0x4b, 0x88, 0xb1, 0x69, 0xc9, 0x07, 0x61, 0x48,
		0xdb, 0x17, 0xee, 0x83, 0x69, 0xc5, 0xa7, 0x42, 0x1b, 0xda, 0x84, 0x2a, 0x04, 0x4e, 0x04, 0x4e,
		0x04, 0x4e, 0x04, 0x4e, 0x04, 0x4e, 0x04, 0x4e, 0x04, 0x4e, 0x94, 0x68, 0x4e, 0x34, 0x92, 0xb6,
		0x1c, 0x4d, 0x46, 0x86, 0x39, 0x7c, 0x10, 0xae, 0x2f, 0xbd, 0x79, 0x30, 0x0b, 0x21, 0x3f, 0xfa,
		0x45, 0xfb, 0xe0, 0x4a, 0xe0, 0x4a, 0xe0, 0x4a, 0xe0, 0x4a, 0xe0, 0x4a, 0xe0, 0x4a, 0xe0, 0x4a,
		0xe0, 0x4a, 0xc8, 0xc0, 0x75, 0x10, 0x39, 0x2a, 0x76, 0x11, 0x6c, 0x7a, 0xb4, 0x0c, 0xe1, 0x4b,
		0xc2, 0x2d, 0xbb, 0x98, 0x97, 0x71, 0x63, 0x5c, 0xc2, 0x8d, 0x1c, 0x8a, 0x58, 0x42, 0x28, 0xa2,
		0x4e, 0x92, 0x86, 0x50, 0xc4, 0x9d, 0x57, 0x0d, 0x42, 0x11, 0xe1, 0x48, 0xc1, 0x91, 0x82, 0x23,
		0x05, 0x47, 0x0a, 0x8e, 0x14, 0x1c, 0x29, 0x38, 0x52, 0xba, 0x1c, 0x29, 0x84, 0x22, 0x82, 0x01,
		0x81, 0x01, 0x81, 0x01, 0x81, 0x01, 0x81, 0x01, 0x81, 0x01, 0x81, 0x01, 0x81, 0x01, 0xed, 0x30,
		0xcc, 0x08, 0x45, 0x04, 0x27, 0x02, 0x27, 0x02, 0x27, 0x02, 0x27, 0x02, 0x27, 0x02, 0x27, 0x02,
		0x27, 0x02, 0x27, 0x42, 0x28, 0x22, 0xb8, 0x12, 0xb8, 0x12, 0xb8, 0x12, 0xb8, 0x12, 0xb8, 0x12,
		0xb8, 0x12, 0xb8, 0x12, 0xb8, 0xd2, 0x3f, 0x0d, 0xb3, 0x2d, 0xee, 0x1d, 0x5f, 0x9a, 0xbe, 0x18,
		0x1a, 0x84, 0x87, 0x69, 0x1b, 0x5b, 0x05, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5,
		0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0xa1, 0xff, 0x46, 0x9a, 0x6e, 0x57, 0xec, 0x91, 0x7a, 0x7c,
		0xff, 0xc1, 0x48, 0x71, 0x4a, 0xf6, 0xbd, 0x32, 0x9d, 0x1f, 0xfc, 0xa2, 0xe0, 0xfb, 0xd5, 0xa2,
		0x31, 0xce, 0x04, 0xef, 0xae, 0x69, 0x7b, 0x63, 0xc7, 0xf5, 0x23, 0xe4, 0x78, 0x0f, 0xbe, 0x8a,
		0x34, 0xef, 0x8c, 0x4c, 0x16, 0x69, 0xde, 0x91, 0xe6, 0x5d, 0xa5, 0xeb, 0x86, 0xbb, 0x55, 0x1a,
		0x2c, 0x7b, 0xe4, 0xbb, 0x55, 0x96, 0x33, 0x30, 0x2d, 0xc3, 0x1c, 0x0e, 0x5d, 0xe1, 0x79, 0xf1,
		0x85, 0x90, 0xf5, 0xe6, 0xa0, 0x80, 0x40, 0x01, 0x81, 0x02, 0xb2, 0xd7, 0x7a, 0x99, 0xd8, 0xd1,
		0x2a, 0x8c, 0x86, 0x6c, 0xcd, 0x69, 0x8c, 0x36, 0x96, 0xaf, 0xa3, 0x5d, 0xaf, 0x08, 0x6a, 0x27,
		0x8e, 0x63, 0x42, 0x0a, 0xf5, 0x08, 0xd1, 0x8e, 0x14, 0xdd, 0x88, 0x6d, 0x18, 0xb9, 0x87, 0x32,
		0xe1, 0xd8, 0x85, 0xc6, 0xf0, 0x03, 0x61, 0x9b, 0x6d, 0xd3, 0xf7, 0x85, 0x6b, 0x93, 0x0d, 0x67,
		0xd0, 0xf0, 0x9f, 0x6f, 0xdf, 0xde, 0x1c, 0x1b, 0xa7, 0xbd, 0xa7, 0x9b, 0xa2, 0x71, 0xda, 0x5b,
		0x7c, 0x2c, 0xce, 0xff, 0x58, 0x7c, 0x2e, 0xdd, 0x1c, 0x1b, 0xe5, 0xd5, 0xe7, 0xca, 0xcd, 0xb1,
		0x51, 0xe9, 0x1d, 0xfe, 0xf1, 0xc7, 0xfb, 0xc3, 0x9f, 0x27, 0xd3, 0xfd, 0xbf, 0xf8, 0xaf, 0x02,
		0xd9, 0xc3, 0xf7, 0x28, 0x07, 0xb7, 0xd5, 0x6d, 0xfe, 0x8e, 0x11, 0x26, 0x91, 0x75, 0x14, 0xe8,
		0x82, 0xea, 0xb6, 0x7f, 0x15, 0xdb, 0x7f, 0xb1, 0x38, 0x4d, 0xe3, 0xae, 0x6e, 0x7c, 0xe9, 0xfd,
		0x2c, 0xbe, 0x2b, 0x4f, 0x3f, 0x1e, 0xfe, 0xac, 0x4d, 0x5f, 0xff, 0xe5, 0xd3, 0xa6, 0x1f, 0x2b,
		0xbe, 0xab, 0x4d, 0x3f, 0x6e, 0xf9, 0x97, 0xea, 0xf4, 0xe3, 0x8e, 0x6d, 0x54, 0xa6, 0x6f, 0x43,
		0x3f, 0x3a, 0xfb, 0xfb, 0xd2, 0xb6, 0x2f, 0x94, 0xb7, 0x7c, 0xe1, 0x64, 0xdb, 0x17, 0x4e, 0xb6,
		0x7c, 0x61, 0xeb, 0x23, 0x95, 0xb6, 0x7c, 0xa1, 0x32, 0x7d, 0x0a, 0xfd, 0xfc, 0xdb, 0xcd, 0x3f,
		0x5a, 0x9d, 0x1e, 0x3e, 0x6d, 0xfb, 0xb7, 0xda, 0xf4, 0xe9, 0xe3, 0x61, 0xae, 0xc1, 0x10, 0xeb,
		0x2d, 0xdd, 0xeb, 0x8d, 0xc6, 0x34, 0xbc, 0xd1, 0xfb, 0x1c, 0x31, 0x4d, 0x13, 0x21, 0x87, 0xf7,
		0x7c, 0x57, 0xda, 0xf7, 0x94, 0xfc, 0xfd, 0x03, 0xc2, 0x5b, 0x42, 0x63, 0x33, 0xf2, 0x27, 0xc6,
		0x50, 0x7a, 0x03, 0xe7, 0x41, 0x50, 0xa4, 0xca, 0x59, 0x6f, 0x2e, 0x7e, 0xa0, 0xef, 0x9d, 0x69,
		0x79, 0x08, 0x8c, 0x81, 0x2c, 0x04, 0x59, 0x68, 0xcf, 0xf5, 0x72, 0xeb, 0x38, 0x96, 0x30, 0x49,
		0x84, 0xa1, 0x62, 0x82, 0xe1, 0x6b, 0x6c, 0x7a, 0x9e, 0x7c, 0x10, 0xc6, 0xc8, 0x19, 0x12, 0x44,
		0xe5, 0xad, 0xb5, 0x06, 0xf0, 0x02, 0x78, 0x01, 0xbc, 0x00, 0x5e, 0xea, 0xc0, 0xcb, 0x1f, 0x8c,
		0x8d, 0x11, 0xc5, 0x21, 0xda, 0xaa, 0x21, 0x40, 0x0d, 0xa0, 0x06, 0x50, 0xb3, 0xd7, 0x7a, 0x99,
		0x48, 0xdb, 0x2f, 0x56, 0x09, 0x90, 0xa6, 0x8a, 0x78, 0x5f, 0x52, 0x58, 0x09, 0x35, 0x87, 0x78,
		0xdf, 0xc4, 0x4c, 0x41, 0xb5, 0x52, 0x39, 0xa9, 0x20, 0xe6, 0x57, 0x9b, 0xce, 0x93, 0xc1, 0x98,
		0xdf, 0x55, 0x68, 0x27, 0x92, 0xaa, 0x23, 0xa9, 0x3a, 0x3b, 0xc5, 0x42, 0xe0, 0xdf, 0x0e, 0x5f,
		0x44, 0xe0, 0x1f, 0x3c, 0x17, 0x78, 0x2e, 0x09, 0xf2, 0x5c, 0x10, 0xf8, 0x17, 0x1e, 0x14, 0x04,
		0xfe, 0x45, 0x1f, 0x39, 0x04, 0xfe, 0x21, 0xf0, 0x0f, 0x81, 0x7f, 0xa4, 0xbe, 0x9d, 0x02, 0x81,
		0xe0, 0x00, 0x81, 0x7f, 0x08, 0xc4, 0x42, 0x20, 0x56, 0x96, 0xc0, 0x10, 0xeb, 0x0d, 0x81, 0x7f,
		0x08, 0xfc, 0x43, 0xe0, 0x5f, 0x74, 0x41, 0xf8, 0x5d, 0x54, 0x39, 0x67, 0xaf, 0x8b, 0xf8, 0xbf,
		0xd0, 0x72, 0xf6, 0xb8, 0x99, 0x0f, 0x21, 0x07, 0x42, 0x0e, 0x84, 0x9c, 0x55, 0xd4, 0x99, 0xe3,
		0xfa, 0x86, 0x3d, 0x19, 0xdd, 0x0a, 0x17, 0xe7, 0xd0, 0x8b, 0x07, 0xc1, 0x39, 0xb4, 0x6e, 0x37,
		0x13, 0xe7, 0xd0, 0x38, 0x87, 0x56, 0x41, 0x3b, 0x70, 0xdf, 0x00, 0x24, 0x06, 0x24, 0x26, 0x7b,
		0x24, 0x06, 0xf7, 0x0d, 0xa2, 0x30, 0x3f, 0xdc, 0x37, 0x00, 0x78, 0x01, 0xbc, 0x00, 0x5e, 0x3c,
		0xe0, 0xe5, 0x8a, 0x91, 0xe3, 0x0b, 0xba, 0x10, 0x9e, 0x57, 0xed, 0x01, 0x78, 0x00, 0x3c, 0x00,
		0x9e, 0xbd, 0xd6, 0x0b, 0x49, 0xb8, 0x4a, 0x46, 0x03, 0x79, 0x48, 0xc3, 0x51, 0x28, 0xcf, 0xa1,
		0xc9, 0xcf, 0x9f, 0x53, 0x17, 0x14, 0xd1, 0xa3, 0x18, 0x44, 0x15, 0x27, 0xab, 0xe9, 0x1b, 0xc9,
		0x8c, 0x9c, 0xd9, 0x11, 0x87, 0x8f, 0xa4, 0x62, 0xbb, 0xe2, 0xd8, 0x3e, 0x95, 0xc7, 0xf6, 0x89,
		0x07, 0x2f, 0xac, 0xab, 0x74, 0xae, 0x2b, 0xa8, 0xfd, 0xdb, 0x3c, 0x4e, 0x9a, 0x28, 0x83, 0x97,
		0x8d, 0xc1, 0xd7, 0x84, 0xaf, 0x09, 0x5f, 0x73, 0x3f, 0xb1, 0x19, 0x61, 0x06, 0xaf, 0x1f, 0x04,
		0x61, 0x06, 0x07, 0x1a, 0xdd, 0x8f, 0x03, 0x84, 0x19, 0x20, 0xcc, 0x40, 0x11, 0xf1, 0x40, 0x6a,
		0x1d, 0x10, 0x0e, 0x10, 0x0e, 0xbd, 0x84, 0x03, 0xa9, 0x75, 0xc0, 0x35, 0xc0, 0x35, 0xc0, 0x35,
		0x52, 0xc5, 0x35, 0xb2, 0x9c, 0x5a, 0x07, 0x15, 0x35, 0x7f, 0x31, 0x42, 0x54, 0x45, 0x35, 0x83,
		0xf6, 0x18, 0xeb, 0x6a, 0x4e, 0x3c, 0x61, 0x8c, 0x26, 0x96, 0x2f, 0xc7, 0x96, 0x30, 0x66, 0x03,
		0xe0, 0xed, 0x5f, 0x60, 0x73, 0x43, 0x1b, 0xa8, 0xb4, 0xc9, 0xc8, 0x4b, 0x51, 0x69, 0x13, 0x95,
		0x36, 0x55, 0x3a, 0x62, 0x48, 0xb8, 0xa5, 0xc1, 0xe8, 0x47, 0x4e, 0xb8, 0x25, 0x6c, 0xf3, 0xd6,
		0x12, 0xc3, 0xf8, 0x1a, 0xc6, 0xaa, 0x21, 0x44, 0x18, 0x43, 0x0b, 0x81, 0x16, 0xa2, 0x45, 0x0b,
		0x49, 0x63, 0x84, 0x71, 0xf6, 0x5c, 0xa1, 0x30, 0xbf, 0x4d, 0x50, 0xba, 0x51, 0x31, 0xdb, 0x18,
		0x91, 0xd9, 0x8f, 0xd8, 0x1f, 0x8e, 0xc0, 0x7d, 0xc0, 0x7d, 0x92, 0xca, 0x7d, 0x22, 0x3a, 0x03,
		0x34, 0x4e, 0x41, 0xcc, 0x0d, 0x02, 0xc6, 0x02, 0xc6, 0xa2, 0x8b, 0xb1, 0x44, 0xdd, 0x70, 0x41,
		0x03, 0xa6, 0x65, 0x39, 0x7f, 0x3f, 0x1b, 0x49, 0xd3, 0x8b, 0x3f, 0xdf, 0xab, 0x15, 0x18, 0x6e,
		0x3a, 0xe6, 0x34, 0x11, 0x39, 0x26, 0x44, 0x0e, 0x0a, 0xd9, 0xb6, 0xa7, 0xdc, 0xfe, 0xf4, 0x30,
		0x40, 0x0d, 0x07, 0xca, 0x60, 0x41, 0x19, 0x3c, 0x28, 0x81, 0x89, 0x78, 0x70, 0x11, 0x13, 0x36,
		0xe8, 0x1c, 0x1e, 0x05, 0x8e, 0x0f, 0x91, 0x03, 0x14, 0x7f, 0x80, 0x79, 0x91, 0x3c, 0xa6, 0x83,
		0x44, 0xee, 0x28, 0xcd, 0x1c, 0x8c, 0x48, 0xde, 0x52, 0x0c, 0x0f, 0x34, 0x02, 0xcb, 0x8f, 0x56,
		0xb4, 0x21, 0xb4, 0x6c, 0xa3, 0x14, 0x6f, 0x20, 0xa7, 0x8d, 0x25, 0xd0, 0x46, 0xd0, 0x46, 0xd0,
		0x46, 0xd0, 0x46, 0xd0, 0x46, 0xd0, 0x46, 0xd0, 0x46, 0xd0, 0xc6, 0xb4, 0xd2, 0xc6, 0x08, 0x81,
		0x47, 0x31, 0x58, 0x63, 0x2e, 0xce, 0x2d, 0x44, 0x44, 0x15, 0xfc, 0x1f, 0xc2, 0x96, 0xae, 0x3d,
		0x71, 0xb1, 0xec, 0xa4, 0x3d, 0xeb, 0xa3, 0xdf, 0xd8, 0x1b, 0x9a, 0x50, 0x88, 0x0d, 0x85, 0xd8,
		0x70, 0x36, 0xa2, 0x96, 0x73, 0x23, 0x2e, 0x84, 0x96, 0x37, 0xc3, 0x5d, 0x86, 0xbb, 0xcc, 0xcd,
		0x77, 0x11, 0x17, 0x92, 0x74, 0x7e, 0x85, 0x58, 0xf9, 0x5d, 0x87, 0x8a, 0x28, 0x68, 0xfe, 0x35,
		0xfb, 0x24, 0x8b, 0x9d, 0x7f, 0x13, 0x63, 0x8c, 0x67, 0x28, 0x3a, 0x7b, 0xd2, 0xd5, 0xeb, 0xef,
		0x98, 0xe2, 0xa8, 0x70, 0x2e, 0x3d, 0xbf, 0xee, 0xfb, 0xbb, 0x19, 0xf8, 0xc2, 0x85, 0xb4, 0x1b,
		0x96, 0x98, 0x41, 0xa1, 0xb7, 0x9b, 0x19, 0x2b, 0x5c, 0x98, 0x3f, 0x5e, 0x7c, 0xa3, 0xf8, 0xa1,
		0x5c, 0xae, 0xd6, 0xca, 0xe5, 0xe3, 0xda, 0x49, 0xed, 0xf8, 0xb4, 0x52, 0x29, 0x56, 0x8b, 0x3b,
		0x5c, 0x21, 0x2a, 0xb4, 0xdc, 0xa1, 0x70, 0xc5, 0xf0, 0xd3, 0xec, 0x0d, 0xed, 0x89, 0x65, 0xc5,
		0x1a, 0xa8, 0x3d, 0x17, 0x61, 0xa4, 0xc5, 0xb7, 0xc3, 0x4a, 0xfb, 0x87, 0x15, 0xf6, 0xcf, 0x0b,
		0x6a, 0xfb, 0x32, 0xd9, 0xfc, 0x2f, 0x5b, 0xc6, 0x63, 0xd7, 0x71, 0xd8, 0xe7, 0xfd, 0x37, 0x3f,
		0x78, 0xf8, 0xb1, 0x36, 0x3c, 0x52, 0x61, 0x2c, 0x84, 0x6b, 0xdc, 0xbb, 0xce, 0x64, 0xbc, 0x5d,
		0x91, 0x7d, 0xce, 0x10, 0xf1, 0xe2, 0x87, 0xb7, 0xbc, 0xde, 0x3f, 0xbb, 0x45, 0xbf, 0xe4, 0x62,
		0xbb, 0x70, 0xad, 0xdd, 0xb9, 0xd4, 0xae, 0x5c, 0x69, 0x6f, 0x2e, 0xb4, 0x37, 0xd7, 0xd9, 0x8b,
		0xcb, 0xec, 0xb7, 0xa0, 0x7e, 0xe5, 0x26, 0xbc, 0x98, 0xb5, 0x5f, 0x0f, 0x44, 0x78, 0xa6, 0x7f,
		0x35, 0x12, 0xbb, 0xf9, 0xc1, 0x3b, 0x93, 0xf0, 0x7d, 0xc8, 0xf6, 0xfe, 0xa4, 0x7a, 0x5f, 0xf2,
		0x1c, 0x99, 0x24, 0x47, 0x26, 0xc3, 0x91, 0x48, 0x6f, 0x3c, 0x13, 0xb6, 0xab, 0x9f, 0x59, 0x30,
		0xef, 0xa4, 0xe1, 0x99, 0x77, 0x32, 0xc2, 0xc5, 0xb1, 0xe7, 0xaf, 0xe2, 0xbe, 0x18, 0xa3, 0x8f,
		0x96, 0xeb, 0xfb, 0x62, 0xab, 0x35, 0x17, 0x5d, 0x18, 0x0c, 0x5a, 0x40, 0xdc, 0x34, 0xb4, 0xc1,
		0x6c, 0x68, 0x83, 0xe6, 0x70, 0xb8, 0xe7, 0xe5, 0xdf, 0xed, 0xbb, 0x23, 0x68, 0x0a, 0xd1, 0xd3,
		0xd0, 0xf5, 0x72, 0xa1, 0xeb, 0xc5, 0x0e, 0x83, 0x89, 0x79, 0x6d, 0x21, 0xb4, 0xec, 0x62, 0x5d,
		0x5f, 0x20, 0xda, 0x88, 0x64, 0x1b, 0x92, 0x72, 0x63, 0xd2, 0x6f, 0x50, 0xea, 0x8d, 0xaa, 0x6c,
		0xc3, 0x2a, 0xdb, 0xb8, 0x4a, 0x36, 0x70, 0xbc, 0x8d, 0x1c, 0x73, 0x43, 0x93, 0x6d, 0xec, 0xa0,
		0x21, 0x61, 0xc9, 0x7b, 0x79, 0x6b, 0x09, 0x63, 0x31, 0x95, 0xc6, 0xd8, 0xb1, 0xe4, 0xe0, 0x91,
		0x6e, 0xb1, 0x04, 0x47, 0x73, 0x9b, 0xfb, 0x79, 0x97, 0xc8, 0xdc, 0x45, 0x54, 0xc0, 0xa0, 0x02,
		0x20, 0xd4, 0x01, 0x85, 0x2a, 0xc0, 0x50, 0x0e, 0x1c, 0xca, 0x01, 0x44, 0x29, 0x90, 0xd0, 0x00,
		0x0a, 0x11, 0xb0, 0x04, 0x6f, 0x4a, 0x16, 0x01, 0x17, 0x5a, 0xaf, 0x96, 0x30, 0xef, 0x5c, 0x71,
		0x47, 0xb9, 0x60, 0x57, 0x7c, 0xa0, 0x46, 0xd8, 0x66, 0x3b, 0x50, 0xb2, 0x07, 0x86, 0x3b, 0x76,
		0xac, 0x8f, 0xae, 0x33, 0xf1, 0xa5, 0x7d, 0xbf, 0x44, 0xae, 0xe0, 0xaf, 0x17, 0xff, 0x69, 0x0c,
		0xc5, 0x9d, 0xb4, 0xa5, 0x2f, 0x1d, 0xdb, 0xdb, 0xfe, 0x4f, 0xc1, 0xbf, 0xcc, 0xe5, 0xfc, 0x84,
		0x54, 0xd9, 0xa7, 0x48, 0x44, 0xe7, 0x8a, 0x81, 0x90, 0x0f, 0x82, 0xde, 0x6c, 0xac, 0x1a, 0x26,
		0x5a, 0xd5, 0xc4, 0x91, 0xd2, 0xb0, 0x3f, 0xb0, 0x3f, 0xb0, 0x3f, 0x29, 0xb3, 0x3f, 0x74, 0x91,
		0xd8, 0x21, 0xfb, 0x53, 0xcc, 0x10, 0xa4, 0x7b, 0xc2, 0x1e, 0xd2, 0xe3, 0xf9, 0xbc, 0x55, 0x80,
		0x39, 0xc0, 0x1c, 0x60, 0x0e, 0x30, 0x07, 0x98, 0x73, 0x82, 0xb9, 0x31, 0xa2, 0xcc, 0x16, 0xfd,
		0x12, 0xd0, 0xe7, 0x2d, 0x03, 0x7c, 0x01, 0xbe, 0x00, 0xdf, 0x5c, 0x81, 0xef, 0x44, 0xda, 0xfe,
		0x07, 0x05, 0xd0, 0x5b, 0x21, 0x6c, 0x92, 0xa6, 0x5c, 0xc2, 0xeb, 0x5f, 0xb4, 0xdb, 0xe9, 0x80,
		0xba, 0x9c, 0x82, 0x62, 0x54, 0x0d, 0x35, 0x4f, 0x5c, 0x6e, 0x21, 0xd4, 0xbe, 0x82, 0xbc, 0xff,
		0x8a, 0x76, 0xdb, 0xfa, 0x94, 0x9a, 0x3f, 0x52, 0x3f, 0xa5, 0xa5, 0x4a, 0x25, 0xc5, 0x93, 0xfa,
		0x26, 0x99, 0xad, 0xf5, 0x92, 0x42, 0x2d, 0xb5, 0x9e, 0x61, 0x12, 0xdd, 0xec, 0x7e, 0x26, 0xb9,
		0xbf, 0x8c, 0x40, 0x7f, 0x11, 0x0f, 0xfe, 0xe2, 0xf3, 0x51, 0x10, 0xec, 0x19, 0x7c, 0x3a, 0x0a,
		0x62, 0x85, 0x62, 0x65, 0x08, 0x8a, 0x3f, 0xce, 0x31, 0xc6, 0x38, 0x66, 0xe6, 0xa0, 0x30, 0xd3,
		0x8f, 0x91, 0x41, 0x28, 0xe4, 0x5c, 0x51, 0x45, 0x6e, 0x94, 0x10, 0xb9, 0x91, 0x00, 0xda, 0x8e,
		0xc8, 0x8d, 0xdd, 0xdf, 0x08, 0x91, 0x1b, 0xf0, 0xf7, 0xe1, 0xef, 0xc3, 0xdf, 0x4f, 0xa1, 0xbf,
		0x8f, 0xc8, 0x0d, 0x44, 0x6e, 0xec, 0xbc, 0x58, 0x10, 0xb9, 0x01, 0xfb, 0x03, 0xfb, 0x03, 0xfb,
		0x43, 0xb8, 0x5e, 0x71, 0xd8, 0xb7, 0x9b, 0xdf, 0x8f, 0xc8, 0x0d, 0x80, 0x39, 0xc0, 0x1c, 0x60,
		0x0e, 0x30, 0xcf, 0x06, 0x98, 0x23, 0x72, 0x03, 0xe0, 0x0b, 0xf0, 0x05, 0xf8, 0xd2, 0xad, 0x57,
		0x44, 0x6e, 0x10, 0x2e, 0x48, 0x44, 0x6e, 0x6c, 0x6f, 0x1f, 0x91, 0x1b, 0xda, 0xa6, 0x14, 0x91,
		0x1b, 0x0a, 0x5a, 0x43, 0xe4, 0x46, 0x7a, 0x22, 0x37, 0x62, 0x24, 0xe9, 0x8f, 0x3f, 0xcc, 0x59,
		0x2d, 0x92, 0x10, 0x61, 0x22, 0x0a, 0xb1, 0x62, 0x58, 0x5e, 0x67, 0xbf, 0x6c, 0x0b, 0xe1, 0x7e,
		0x9d, 0xf5, 0xd9, 0xaf, 0xdf, 0xc9, 0xae, 0x79, 0x27, 0xfb, 0xf5, 0xe1, 0x70, 0x8f, 0x04, 0xab,
		0xf1, 0x27, 0x2a, 0x4a, 0x15, 0xaf, 0xd5, 0xa8, 0x18, 0xcb, 0x57, 0x89, 0x9b, 0xca, 0x68, 0xad,
		0x39, 0xa4, 0x29, 0x47, 0x3a, 0x23, 0x4d, 0x0e, 0x54, 0x5a, 0xd3, 0x94, 0xc7, 0x3f, 0xca, 0xa6,
		0x38, 0xba, 0x0e, 0x8e, 0xaa, 0xdf, 0xbf, 0x5f, 0x58, 0xab, 0xa3, 0xf5, 0x8d, 0x9d, 0x64, 0x40,
		0x1b, 0x8f, 0xad, 0xc7, 0xb8, 0x31, 0x47, 0xcf, 0x78, 0xf6, 0xb2, 0x35, 0x64, 0x67, 0x2b, 0x2c,
		0xa3, 0x0d, 0x80, 0x67, 0x11, 0xf0, 0x6c, 0x3e, 0x70, 0xc8, 0xcf, 0x16, 0x6d, 0xe1, 0x21, 0x3f,
		0x1b, 0xdf, 0x16, 0xa5, 0xde, 0xaa, 0xca, 0xb6, 0xac, 0xb2, 0xad, 0xab, 0x66, 0x0b, 0x27, 0xc3,
		0x47, 0x26, 0x8b, 0xf3, 0x1d, 0x2e, 0x0e, 0xcb, 0x0d, 0xf1, 0x63, 0xec, 0xb8, 0xbe, 0xb2, 0x30,
		0xdf, 0xcd, 0xdd, 0xd0, 0x1f, 0xf8, 0x77, 0x1a, 0xff, 0xd7, 0xf8, 0x7c, 0xd5, 0xef, 0xb4, 0xae,
		0xaf, 0x1a, 0x38, 0x7a, 0x4a, 0x12, 0x0e, 0xa9, 0xc2, 0x23, 0xe5, 0xb8, 0xa4, 0x1c, 0x9f, 0xd4,
		0xe2, 0x14, 0xad, 0x4a, 0x99, 0xfc, 0xc3, 0xa7, 0x15, 0xd2, 0x2c, 0x83, 0x6c, 0xfd, 0x59, 0x47,
		0x0a, 0xa2, 0x00, 0xca, 0x84, 0x6d, 0x36, 0xec, 0xc9, 0x68, 0x36, 0x18, 0xd3, 0x0c, 0x45, 0x16,
		0xac, 0xa6, 0x41, 0x8e, 0x58, 0xec, 0xca, 0x7a, 0x37, 0xb0, 0x2b, 0xb0, 0x2b, 0xb0, 0x2b, 0xb0,
		0x2b, 0xb0, 0x2b, 0x99, 0xb3, 0x2b, 0x8a, 0xfd, 0x14, 0x25, 0xfe, 0x09, 0x80, 0x1e, 0x40, 0x0f,
		0xa0, 0x4f, 0x0b, 0xd0, 0xe3, 0x1e, 0x22, 0xe9, 0x3d, 0x44, 0xa2, 0xf9, 0xde, 0xab, 0x44, 0xe8,
		0xce, 0xad, 0xee, 0x5d, 0x4a, 0x74, 0xf7, 0x96, 0x09, 0x4a, 0x8e, 0xee, 0xdc, 0xd9, 0xcb, 0xd2,
		0xa4, 0xc4, 0xa0, 0x18, 0xc4, 0x74, 0x7a, 0xc2, 0xa5, 0xc6, 0x43, 0x45, 0x40, 0xfe, 0x1a, 0xcc,
		0x9d, 0xc5, 0xe8, 0x18, 0xb7, 0x8f, 0x05, 0x05, 0xc1, 0x7c, 0xaa, 0x41, 0x3d, 0x04, 0xec, 0xf3,
		0x99, 0x48, 0x68, 0x00, 0x5b, 0x96, 0x98, 0xa6, 0x62, 0xe5, 0x42, 0x89, 0x62, 0x01, 0xa6, 0x09,
		0xa6, 0x09, 0xa6, 0x09, 0xa6, 0x09, 0xa6, 0x09, 0xa6, 0x09, 0xa6, 0x09, 0xa6, 0x09, 0xa6, 0xa9,
		0x9c, 0x69, 0xe2, 0xaa, 0xc4, 0xb6, 0x08, 0xfd, 0x17, 0x51, 0x97, 0xc8, 0x73, 0x89, 0x3c, 0x97,
		0xda, 0xe8, 0x3c, 0x22, 0xe0, 0x10, 0x01, 0xf7, 0x0f, 0x0d, 0x21, 0x02, 0x0e, 0xb2, 0x02, 0x64,
		0x05, 0xc8, 0x0a, 0x99, 0x91, 0x15, 0x10, 0xa9, 0x80, 0x08, 0x38, 0xd8, 0x15, 0xd8, 0x15, 0xd8,
		0x15, 0xd8, 0x15, 0xd8, 0x15, 0x44, 0xc0, 0xed, 0x37, 0xcb, 0x88, 0x80, 0x03, 0xd0, 0x03, 0xe8,
		0x73, 0x0d, 0xf4, 0x38, 0x97, 0xc4, 0xb9, 0x24, 0x41, 0xcb, 0x38, 0x97, 0xd4, 0x05, 0xe4, 0x07,
		0x38, 0x97, 0xd4, 0x81, 0xec, 0x07, 0x88, 0x80, 0xdb, 0x67, 0x43, 0x21, 0x02, 0x0e, 0x4c, 0x13,
		0x4c, 0x13, 0x4c, 0x13, 0x4c, 0x13, 0x4c, 0x13, 0x4c, 0x13, 0x4c, 0x13, 0x4c, 0x33, 0x9d, 0x4c,
		0x13, 0x11, 0x70, 0xbb, 0x44, 0xc0, 0x21, 0x5f, 0x70, 0x62, 0xe6, 0x42, 0x79, 0xca, 0xe0, 0x59,
		0x5f, 0xed, 0x45, 0x57, 0x09, 0x4e, 0xb2, 0x19, 0x33, 0xbb, 0x1f, 0x4d, 0x56, 0xbf, 0xac, 0x25,
		0xd6, 0x44, 0x9e, 0xe0, 0x68, 0xfe, 0x53, 0x8a, 0xf2, 0x04, 0xc7, 0x4e, 0xab, 0x49, 0x93, 0xae,
		0x3b, 0xb4, 0xfa, 0x28, 0xd2, 0x76, 0x13, 0xeb, 0x28, 0x89, 0x4f, 0xb2, 0x89, 0x52, 0xfa, 0x28,
		0xa5, 0xaf, 0x5a, 0xf5, 0x78, 0x16, 0x3c, 0x87, 0xc2, 0xf6, 0xa5, 0xff, 0x48, 0xa3, 0x78, 0x04,
		0x96, 0x93, 0xc0, 0xbb, 0x2d, 0x34, 0x97, 0x8f, 0xf6, 0xc9, 0xf4, 0x14, 0x54, 0x6b, 0xae, 0x7f,
		0x69, 0xf6, 0xbb, 0xb3, 0xff, 0xbb, 0xfa, 0x6f, 0x9b, 0x2c, 0x78, 0x6c, 0x5e, 0x89, 0xc6, 0x23,
		0x2d, 0xe1, 0xa4, 0xc8, 0x9f, 0x3f, 0x3f, 0xf9, 0xd6, 0xbe, 0xec, 0x37, 0xdb, 0xdf, 0xca, 0xfd,
		0xeb, 0xcb, 0xe6, 0xe7, 0x7a, 0xf7, 0x8a, 0x50, 0x29, 0x7c, 0x97, 0xf8, 0xb7, 0x6f, 0x5e, 0xfe,
		0xbb, 0x7b, 0x55, 0xbf, 0x6a, 0xe4, 0xe9, 0xa5, 0xe7, 0x93, 0x7d, 0x5e, 0xff, 0xd4, 0x38, 0x6f,
		0x9c, 0xe5, 0x72, 0xd2, 0x4b, 0xb3, 0x25, 0xff, 0xad, 0x7d, 0xde, 0xcd, 0xe5, 0x52, 0xef, 0x77,
		0xdb, 0x5f, 0x72, 0xf5, 0xe2, 0x2b, 0x84, 0xab, 0xe6, 0x71, 0xb1, 0xcf, 0xdf, 0x3b, 0xf7, 0x9b,
		0xbd, 0xf1, 0xad, 0x7d, 0x99, 0xbb, 0x59, 0xcf, 0xe1, 0x6c, 0x77, 0x3b, 0x57, 0x8d, 0x7e, 0xbb,
		0x75, 0xde, 0xfc, 0xfc, 0xdf, 0x39, 0xa7, 0xc9, 0x25, 0xce, 0x95, 0xfb, 0x17, 0xd7, 0xe7, 0x57,
		0x79, 0x44, 0xba, 0x72, 0xff, 0xcb, 0x79, 0xeb, 0x3f, 0xdd, 0x76, 0xe3, 0x73, 0x3e, 0x2d, 0x7b,
		0xce, 0x50, 0xee, 0x5b, 0xfb, 0x32, 0xa7, 0x53, 0xfe, 0x0a, 0xe7, 0xaa, 0xb9, 0xdb, 0xe7, 0x79,
		0x64, 0x32, 0xcf, 0x3c, 0x56, 0x05, 0xbe, 0x93, 0xb4, 0xd4, 0xd3, 0xad, 0xab, 0x69, 0x49, 0xc3,
		0x21, 0x6c, 0xf3, 0xd6, 0x12, 0x43, 0x3a, 0xb5, 0x7c, 0xd5, 0x60, 0xdc, 0x34, 0x04, 0xcf, 0x37,
		0x24, 0xef, 0x4c, 0xcb, 0x83, 0xee, 0xbe, 0xc3, 0xd0, 0x43, 0x77, 0x87, 0xee, 0xbe, 0xfd, 0x8d,
		0xe8, 0x75, 0xf7, 0x5b, 0xc7, 0xb1, 0x84, 0x69, 0x53, 0x6a, 0xee, 0x45, 0x04, 0x72, 0xec, 0xd1,
		0x0e, 0x65, 0x20, 0x47, 0x9c, 0x4c, 0x52, 0x3c, 0x71, 0x15, 0xf7, 0xae, 0x39, 0x10, 0x77, 0x13,
		0xcb, 0x70, 0x85, 0xe7, 0x9b, 0xae, 0x1f, 0x3f, 0xc2, 0x22, 0xd4, 0x22, 0x62, 0x2d, 0x10, 0x6b,
		0xa1, 0xc9, 0x48, 0xa0, 0x84, 0x29, 0x4a, 0x98, 0x82, 0xe5, 0x81, 0xe5, 0x25, 0x25, 0x7d, 0x1b,
		0x95, 0x63, 0xa8, 0xc8, 0x41, 0x54, 0xe5, 0x28, 0x12, 0x3b, 0x8c, 0xe4, 0x90, 0xa2, 0x02, 0x5a,
		0xd4, 0x41, 0x8c, 0x2a, 0xa8, 0x51, 0x0e, 0x39, 0xca, 0xa1, 0x47, 0x29, 0x04, 0xd1, 0x0a, 0x63,
		0xc9, 0xbf, 0xee, 0x46, 0xe7, 0x88, 0x12, 0x3b, 0xa4, 0x74, 0x13, 0x81, 0xdb, 0x20, 0xdb, 0x1c,
		0xd7, 0xd7, 0x4e, 0x1c, 0x72, 0x22, 0x23, 0x27, 0x32, 0x28, 0x35, 0x28, 0x35, 0x28, 0x35, 0x28,
		0x35, 0x28, 0x35, 0x28, 0x35, 0x28, 0x35, 0x28, 0x35, 0x28, 0x75, 0x3c, 0x4a, 0x8d, 0x4b, 0xd6,
		0x89, 0x9a, 0x0f, 0xd5, 0x17, 0xad, 0xbf, 0x2e, 0xfb, 0xeb, 0x2c, 0xbb, 0x4b, 0xf0, 0xa1, 0xa0,
		0x1c, 0x3f, 0x94, 0x0d, 0xcb, 0xbc, 0x15, 0x96, 0x18, 0x1a, 0x13, 0x5b, 0x0e, 0x4c, 0x8f, 0xe0,
		0x60, 0x70, 0x63, 0xab, 0x38, 0x1c, 0xc4, 0xe1, 0xa0, 0x26, 0x16, 0x92, 0xb2, 0xc3, 0xc1, 0xc5,
		0x8c, 0x18, 0x96, 0x1c, 0x49, 0x9f, 0x4e, 0xce, 0x58, 0x6b, 0x15, 0x07, 0x85, 0x50, 0x35, 0xa0,
		0x6a, 0x24, 0x41, 0xd5, 0x20, 0x8a, 0x04, 0x08, 0x2d, 0x5f, 0x92, 0x88, 0x00, 0xe2, 0x0d, 0x0f,
		0xed, 0x01, 0xda, 0x03, 0xb4, 0x07, 0x5a, 0x00, 0x09, 0x1a, 0x1c, 0x99, 0x3f, 0x8c, 0xc5, 0xac,
		0xcf, 0xd3, 0x0f, 0x28, 0xba, 0x8a, 0xb0, 0xd6, 0x0b, 0xf1, 0xe4, 0xd3, 0x0a, 0x9c, 0xca, 0xc0,
		0x46, 0x25, 0xe8, 0xa8, 0x07, 0x1f, 0xd5, 0x20, 0xc4, 0x06, 0x46, 0x6c, 0xa0, 0xc4, 0x02, 0x4e,
		0xb4, 0x20, 0x45, 0x0c, 0x56, 0xc1, 0x08, 0x90, 0x0b, 0xa6, 0xa1, 0xf5, 0x3e, 0x91, 0xb6, 0x7f,
		0x52, 0x52, 0xb1, 0xde, 0x97, 0xe8, 0x52, 0x53, 0xd0, 0x74, 0xc7, 0xb4, 0xef, 0x05, 0x69, 0xca,
		0x97, 0x97, 0xbf, 0xd4, 0xec, 0xcf, 0x83, 0x65, 0xf2, 0x5b, 0x65, 0x00, 0xa0, 0x18, 0xd6, 0x43,
		0xdd, 0xcc, 0x13, 0xef, 0x30, 0xf4, 0xf3, 0xc5, 0x35, 0x07, 0xbe, 0x74, 0xec, 0x33, 0x79, 0x2f,
		0x17, 0x39, 0x83, 0x95, 0xf5, 0x37, 0x7d, 0xa7, 0x70, 0xea, 0xcd, 0x1f, 0x99, 0x9b, 0xfa, 0x72,
		0xe9, 0xb4, 0x7c, 0x5a, 0xad, 0x95, 0x4e, 0x2b, 0x19, 0x5a, 0x03, 0x6f, 0xd2, 0xd1, 0x6a, 0x2f,
		0xa9, 0xf9, 0x88, 0x09, 0xfd, 0xb6, 0xb1, 0x2b, 0x1e, 0x84, 0xed, 0x1b, 0xbe, 0x30, 0xdd, 0xa1,
		0xf3, 0xb7, 0xad, 0x8e, 0x66, 0x87, 0x7a, 0x22, 0x36, 0xe4, 0x8a, 0x62, 0x14, 0x40, 0xe5, 0x41,
		0xe5, 0x41, 0xe5, 0x41, 0xe5, 0x15, 0xc5, 0x40, 0xbc, 0x86, 0x17, 0xa2, 0x58, 0x88, 0x64, 0x1b,
		0x9d, 0xe5, 0xa1, 0xb5, 0xe1, 0xcb, 0x91, 0x70, 0xd5, 0x59, 0x9c, 0xf5, 0x6e, 0x60, 0x0e, 0x60,
		0x0e, 0x60, 0x0e, 0x60, 0x0e, 0x08, 0xd7, 0xfb, 0x50, 0x0c, 0xe4, 0xc8, 0xb4, 0xaa, 0x65, 0x95,
		0x06, 0xa1, 0xa4, 0xa0, 0xed, 0x90, 0xb3, 0x57, 0x82, 0x84, 0xa4, 0x47, 0x42, 0x2a, 0x41, 0x42,
		0xca, 0xab, 0x84, 0x74, 0x82, 0xa9, 0x87, 0x72, 0x94, 0x5e, 0x12, 0xff, 0xb7, 0xe9, 0xda, 0xd2,
		0xbe, 0x37, 0xfc, 0xef, 0xae, 0xf0, 0xbe, 0x3b, 0xd6, 0xd0, 0x18, 0x0f, 0x7c, 0x75, 0x64, 0x7e,
		0x73, 0x77, 0x20, 0xf5, 0x20, 0xf5, 0x20, 0xf5, 0x20, 0xf5, 0x84, 0xeb, 0x7d, 0x2c, 0xdc, 0x81,
		0xb0, 0x7d, 0xf3, 0x5e, 0x28, 0x64, 0xf5, 0x15, 0xf0, 0x6d, 0x3d, 0x7c, 0x1b, 0x47, 0xb6, 0xb9,
		0xe5, 0xdb, 0x5c, 0x53, 0x5f, 0x3c, 0x06, 0xe3, 0x06, 0xe3, 0x26, 0x6d, 0x89, 0x2a, 0x42, 0x93,
		0xf8, 0x8a, 0x61, 0xd0, 0x2e, 0xe5, 0xd5, 0xb6, 0x4d, 0x37, 0xad, 0x8e, 0x5e, 0xde, 0xf4, 0x20,
		0x49, 0xe7, 0x41, 0x37, 0x3f, 0x04, 0x73, 0x43, 0x94, 0xe6, 0x23, 0x44, 0x65, 0x28, 0xd2, 0x7d,
		0xbc, 0x46, 0x51, 0xf2, 0x78, 0xf9, 0x12, 0xe2, 0xe5, 0x53, 0xe4, 0xf3, 0x20, 0x5e, 0x1e, 0xf1,
		0xf2, 0x88, 0x97, 0x87, 0x00, 0x03, 0x01, 0x06, 0x02, 0x8c, 0xa2, 0xf5, 0x8e, 0x78, 0x79, 0x88,
		0x2f, 0x10, 0x5f, 0x20, 0xbe, 0x44, 0x9a, 0x7a, 0xc4, 0xcb, 0x43, 0x83, 0x51, 0xb8, 0x87, 0x10,
		0x2f, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0xbf, 0xd3, 0x7a, 0x47, 0xbc, 0x3c, 0xc9,
		0xbb, 0x22, 0x5e, 0x1e, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xed, 0xe6, 0x00, 0xf1, 0xf2, 0x90,
		0x90, 0x62, 0x4e, 0x2f, 0xe2, 0xe5, 0x73, 0x2b, 0x21, 0x21, 0x5e, 0x1e, 0xca, 0x51, 0x8a, 0x49,
		0x3c, 0xe2, 0xe5, 0x41, 0xea, 0x41, 0xea, 0x41, 0xea, 0xb3, 0x46, 0xea, 0x11, 0x2f, 0x9f, 0x65,
		0xbe, 0x8d, 0x23, 0xdb, 0xdc, 0xf2, 0x6d, 0xc4, 0xcb, 0x83, 0x71, 0xf3, 0x33, 0x6e, 0xc4, 0xcb,
		0x93, 0xc7, 0xcb, 0x13, 0xd4, 0xea, 0xa1, 0x9b, 0x1e, 0xd4, 0x58, 0x8a, 0x3c, 0x91, 0x05, 0x92,
		0x9b, 0x06, 0xbf, 0x2e, 0xf6, 0xd3, 0x1c, 0x3f, 0x94, 0xcf, 0x17, 0xcf, 0x71, 0xbd, 0x78, 0x8c,
		0xfe, 0xc2, 0x71, 0x3a, 0x9f, 0x3f, 0x05, 0x8a, 0x3e, 0x25, 0x68, 0x81, 0xa8, 0x2e, 0xfc, 0x14,
		0x5e, 0x0b, 0x89, 0xaf, 0xfd, 0x44, 0x5b, 0xf3, 0x09, 0xb5, 0x9e, 0x50, 0xeb, 0x49, 0xb3, 0xf2,
		0x90, 0xb2, 0x5a, 0x4f, 0x44, 0xe5, 0x5f, 0x68, 0xcb, 0xbe, 0xa0, 0xbe, 0x93, 0x4e, 0xa9, 0x11,
		0xf5, 0x9d, 0x12, 0xc0, 0x7d, 0xc9, 0xea, 0x3b, 0x79, 0xc2, 0x1e, 0x1a, 0xc3, 0x45, 0xf8, 0xa8,
		0xe1, 0x3a, 0x13, 0x25, 0x57, 0x57, 0xc3, 0x7d, 0xa0, 0x96, 0x75, 0x52, 0x00, 0x47, 0x1d, 0xf0,
		0xa8, 0x02, 0x20, 0xe5, 0x40, 0xa4, 0x1c, 0x90, 0x94, 0x02, 0x53, 0x32, 0xd5, 0x17, 0xd4, 0xb2,
		0x86, 0xce, 0xa2, 0xca, 0x8d, 0x5e, 0xe9, 0x2b, 0x14, 0xb9, 0x24, 0x62, 0x68, 0x1a, 0xef, 0x50,
		0x52, 0x15, 0x94, 0x1b, 0x94, 0x1b, 0x94, 0x9b, 0xc7, 0xa7, 0x56, 0xe3, 0x5b, 0x13, 0x6f, 0x78,
		0x50, 0x60, 0x50, 0x60, 0x50, 0x60, 0x5a, 0x00, 0x09, 0x1a, 0x44, 0x8a, 0x18, 0x26, 0xb0, 0x51,
		0x09, 0x3a, 0xea, 0xc1, 0x47, 0x35, 0x08, 0xb1, 0x81, 0x11, 0x1b, 0x28, 0xb1, 0x80, 0x13, 0x2d,
		0x48, 0x11, 0x83, 0x95, 0x3a, 0xbf, 0x3d, 0xb4, 0xde, 0x91, 0x22, 0x26, 0xf4, 0x0b, 0xf1, 0x86,
		0x3b, 0x75, 0x83, 0x78, 0xc3, 0xfd, 0xa6, 0x1e, 0x29, 0x62, 0xd2, 0xb1, 0x06, 0x10, 0x76, 0x98,
		0x94, 0x3d, 0x84, 0x14, 0x31, 0xa0, 0xf2, 0xa0, 0xf2, 0xa0, 0xf2, 0xa0, 0xf2, 0x3b, 0xad, 0x77,
		0xa4, 0x88, 0x21, 0x79, 0x57, 0xa4, 0x88, 0x81, 0x39, 0x80, 0x39, 0x80, 0x39, 0x48, 0xbb, 0x39,
		0x40, 0x8a, 0x18, 0x48, 0x48, 0x31, 0xa7, 0x17, 0x29, 0x62, 0x72, 0x2b, 0x21, 0x21, 0x45, 0x0c,
		0x94, 0xa3, 0x14, 0x93, 0x78, 0xa4, 0x88, 0x01, 0xa9, 0x07, 0xa9, 0x07, 0xa9, 0xcf, 0x1a, 0xa9,
		0x47, 0x8a, 0x98, 0x2c, 0xf3, 0x6d, 0x1c, 0xd9, 0xe6, 0x96, 0x6f, 0x23, 0x45, 0x0c, 0x18, 0x37,
		0x3f, 0xe3, 0x46, 0x8a, 0x98, 0x38, 0x37, 0x5e, 0x50, 0x4a, 0x35, 0x0a, 0x85, 0x41, 0x29, 0xd5,
		0xa4, 0xfa, 0x3e, 0x88, 0x93, 0xd7, 0xe2, 0xdb, 0x20, 0x4e, 0x9e, 0x60, 0x33, 0x20, 0x4e, 0x1e,
		0xc2, 0x0b, 0x84, 0x17, 0x08, 0x2f, 0xaa, 0xd6, 0x3b, 0xe2, 0xe4, 0x21, 0xba, 0x40, 0x74, 0x81,
		0xe8, 0x12, 0x69, 0xea, 0x11, 0x27, 0x0f, 0xed, 0x45, 0xe1, 0x1e, 0x42, 0x9c, 0x3c, 0xa8, 0x3c,
		0xa8, 0x3c, 0xa8, 0x3c, 0xa8, 0xfc, 0x4e, 0xeb, 0x1d, 0x71, 0xf2, 0x24, 0xef, 0x8a, 0x38, 0x79,
		0x98, 0x03, 0x98, 0x03, 0x98, 0x83, 0xb4, 0x9b, 0x03, 0xc4, 0xc9, 0x43, 0x42, 0x8a, 0x39, 0xbd,
		0x88, 0x93, 0xcf, 0xad, 0x84, 0x84, 0x38, 0x79, 0x28, 0x47, 0x29, 0x26, 0xf1, 0x88, 0x93, 0x07,
		0xa9, 0x07, 0xa9, 0x07, 0xa9, 0xcf, 0x1a, 0xa9, 0x47, 0x9c, 0x7c, 0x96, 0xf9, 0x36, 0x8e, 0x6c,
		0x73, 0xcb, 0xb7, 0x11, 0x27, 0x0f, 0xc6, 0xcd, 0xcf, 0xb8, 0x11, 0x27, 0x4f, 0x16, 0x27, 0x8f,
		0x12, 0xaa, 0xaa, 0x26, 0x92, 0x67, 0x02, 0x39, 0x4b, 0xa7, 0x26, 0xa9, 0x66, 0x6a, 0xac, 0xea,
		0xa0, 0x14, 0x17, 0x29, 0x48, 0x2f, 0x50, 0x90, 0x57, 0x14, 0x29, 0xa1, 0xa2, 0x48, 0x02, 0x9c,
		0x5a, 0x54, 0x14, 0xd9, 0xfd, 0x8d, 0x50, 0xc4, 0xef, 0x00, 0x45, 0xfc, 0x70, 0x33, 0x0b, 0x37,
		0xb3, 0xd2, 0xc2, 0xfb, 0x51, 0xc4, 0x0f, 0x4c, 0x5f, 0x35, 0xd3, 0x27, 0xf0, 0xce, 0xa6, 0x29,
		0xa9, 0xce, 0x4d, 0x34, 0x27, 0xca, 0xe6, 0xa2, 0x10, 0xcb, 0xe3, 0xd8, 0xcb, 0xc1, 0x8a, 0x36,
		0xe1, 0xfb, 0x4f, 0x57, 0x84, 0xa9, 0x2a, 0xc8, 0xf1, 0x43, 0xd5, 0xb0, 0xcc, 0x5b, 0x61, 0x89,
		0x61, 0x30, 0x34, 0x51, 0x27, 0x2c, 0x40, 0xbc, 0x8d, 0xad, 0x46, 0x5c, 0x48, 0xf1, 0x5c, 0xa9,
		0xd8, 0xcc, 0x86, 0x82, 0xc9, 0xd0, 0x31, 0x17, 0x2a, 0xa6, 0x42, 0xce, 0x4c, 0xc8, 0x99, 0x08,
		0x29, 0xf3, 0xe0, 0x85, 0xbe, 0xb8, 0xae, 0x0f, 0x2a, 0xa6, 0x42, 0xdf, 0x80, 0xbe, 0x91, 0x17,
		0x7d, 0x03, 0x15, 0x53, 0xa1, 0x37, 0x40, 0x6f, 0xc8, 0x9f, 0xde, 0x80, 0x4c, 0x30, 0x8a, 0x45,
		0x4d, 0x65, 0x60, 0xa3, 0x12, 0x74, 0xd4, 0x83, 0x8f, 0x6a, 0x10, 0x62, 0x03, 0x23, 0x36, 0x50,
		0x62, 0x01, 0x27, 0x5a, 0x90, 0x22, 0x06, 0xab, 0x60, 0x04, 0x90, 0x09, 0x66, 0x63, 0xd3, 0x08,
		0x2b, 0xe4, 0x87, 0xf5, 0x50, 0x37, 0x08, 0x2b, 0xdc, 0x6f, 0xea, 0x91, 0x09, 0x26, 0x1d, 0x6b,
		0x00, 0xd1, 0x85, 0x49, 0xd9, 0x43, 0xc8, 0x04, 0x03, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a,
		0xbf, 0xd3, 0x7a, 0x47, 0x26, 0x18, 0x92, 0x77, 0x45, 0x26, 0x18, 0x98, 0x03, 0x98, 0x03, 0x98,
		0x83, 0xb4, 0x9b, 0x03, 0x64, 0x82, 0x81, 0x84, 0x14, 0x73, 0x7a, 0x91, 0x09, 0x26, 0xb7, 0x12,
		0x12, 0x32, 0xc1, 0x40, 0x39, 0x4a, 0x31, 0x89, 0x47, 0x26, 0x18, 0x90, 0x7a, 0x90, 0x7a, 0x90,
		0xfa, 0xac, 0x91, 0x7a, 0x64, 0x82, 0xc9, 0x32, 0xdf, 0xc6, 0x91, 0x6d, 0x6e, 0xf9, 0x36, 0x32,
		0xc1, 0x80, 0x71, 0xf3, 0x33, 0x6e, 0x64, 0x82, 0xd9, 0xff, 0x4a, 0x5b, 0xe8, 0xa6, 0x15, 0x2a,
		0xa7, 0x46, 0xa2, 0x32, 0xa8, 0x9c, 0x9a, 0x54, 0x1f, 0x08, 0xf1, 0xf2, 0x5a, 0x7c, 0x1c, 0xc4,
		0xcb, 0x13, 0x6c, 0x06, 0xc4, 0xcb, 0x43, 0x80, 0x81, 0x00, 0x03, 0x01, 0x46, 0xd5, 0x7a, 0x47,
		0xbc, 0x3c, 0xc4, 0x17, 0x88, 0x2f, 0x10, 0x5f, 0x22, 0x4d, 0x3d, 0xe2, 0xe5, 0xa1, 0xc1, 0x28,
		0xdc, 0x43, 0x88, 0x97, 0x07, 0x95, 0x07, 0x95, 0x07, 0x95, 0x07, 0x95, 0xdf, 0x69, 0xbd, 0x23,
		0x5e, 0x9e, 0xe4, 0x5d, 0x11, 0x2f, 0x0f, 0x73, 0x00, 0x73, 0x00, 0x73, 0x90, 0x76, 0x73, 0x80,
		0x78, 0x79, 0x48, 0x48, 0x31, 0xa7, 0x17, 0xf1, 0xf2, 0xb9, 0x95, 0x90, 0x10, 0x2f, 0x0f, 0xe5,
		0x28, 0xc5, 0x24, 0x1e, 0xf1, 0xf2, 0x20, 0xf5, 0x20, 0xf5, 0x20, 0xf5, 0x59, 0x23, 0xf5, 0x88,
		0x97, 0xcf, 0x32, 0xdf, 0xc6, 0x91, 0x6d, 0x6e, 0xf9, 0x36, 0xe2, 0xe5, 0xc1, 0xb8, 0xf9, 0x19,
		0x37, 0xe2, 0xe5, 0xc9, 0xe3, 0xe5, 0x51, 0x41, 0x55, 0xd5, 0x84, 0xf2, 0x4e, 0x24, 0x63, 0x25,
		0xd5, 0xea, 0xf9, 0xe2, 0x39, 0x92, 0x54, 0x50, 0x15, 0xc5, 0x9e, 0xe8, 0x6a, 0x10, 0xc5, 0x58,
		0x0b, 0x89, 0xaf, 0xfd, 0x44, 0x5b, 0xf3, 0x09, 0xb5, 0x9e, 0x50, 0xeb, 0x49, 0xb3, 0xf2, 0x90,
		0xb2, 0x5a, 0x4f, 0x44, 0xe5, 0x5f, 0x68, 0xcb, 0xbe, 0xa0, 0xbe, 0x93, 0x4e, 0xa9, 0x11, 0xf5,
		0x9d, 0x12, 0xc0, 0x7d, 0x51, 0xbf, 0xfa, 0x00, 0xf5, 0xab, 0x71, 0x3f, 0x16, 0xf7, 0x63, 0xd3,
		0xa2, 0xbe, 0xa0, 0x7e, 0x35, 0x74, 0x16, 0x55, 0x6e, 0xf4, 0x4a, 0x5f, 0xa1, 0xc8, 0x25, 0x11,
		0x43, 0xd3, 0x78, 0x87, 0x92, 0xaa, 0xa0, 0xdc, 0xa0, 0xdc, 0xa0, 0xdc, 0x3c, 0x3e, 0xb5, 0x1a,
		0xdf, 0x9a, 0x78, 0xc3, 0x83, 0x02, 0x83, 0x02, 0x83, 0x02, 0xd3, 0x02, 0x48, 0xd0, 0x20, 0x52,
		0xc4, 0x30, 0x81, 0x8d, 0x4a, 0xd0, 0x51, 0x0f, 0x3e, 0xaa, 0x41, 0x88, 0x0d, 0x8c, 0xd8, 0x40,
		0x89, 0x05, 0x9c, 0x68, 0x41, 0x8a, 0x18, 0xac, 0xd4, 0xf9, 0xed, 0xa1, 0xf5, 0x8e, 0x14, 0x31,
		0xa1, 0x5f, 0x88, 0x37, 0xdc, 0xa9, 0x1b, 0xc4, 0x1b, 0xee, 0x37, 0xf5, 0x48, 0x11, 0x93, 0x8e,
		0x35, 0x80, 0xb0, 0xc3, 0xa4, 0xec, 0x21, 0xa4, 0x88, 0x01, 0x95, 0x07, 0x95, 0x07, 0x95, 0x07,
		0x95, 0xdf, 0x69, 0xbd, 0x23, 0x45, 0x0c, 0xc9, 0xbb, 0x22, 0x45, 0x0c, 0xcc, 0x01, 0xcc, 0x01,
		0xcc, 0x41, 0xda, 0xcd, 0x01, 0x52, 0xc4, 0x40, 0x42, 0x8a, 0x39, 0xbd, 0x48, 0x11, 0x93, 0x5b,
		0x09, 0x09, 0x29, 0x62, 0xa0, 0x1c, 0xa5, 0x98, 0xc4, 0x23, 0x45, 0x0c, 0x48, 0x3d, 0x48, 0x3d,
		0x48, 0x7d, 0xd6, 0x48, 0x3d, 0x52, 0xc4, 0x64, 0x99, 0x6f, 0xe3, 0xc8, 0x36, 0xb7, 0x7c, 0x1b,
		0x29, 0x62, 0xc0, 0xb8, 0xf9, 0x19, 0x37, 0x52, 0xc4, 0xc4, 0xb9, 0xf1, 0x82, 0x52, 0xaa, 0x51,
		0x28, 0x0c, 0x4a, 0xa9, 0x26, 0xd5, 0xf7, 0x41, 0x9c, 0xbc, 0x16, 0xdf, 0x06, 0x71, 0xf2, 0x04,
		0x9b, 0x01, 0x71, 0xf2, 0x10, 0x5e, 0x20, 0xbc, 0x40, 0x78, 0x51, 0xb5, 0xde, 0x11, 0x27, 0x0f,
		0xd1, 0x05, 0xa2, 0x0b, 0x44, 0x97, 0x48, 0x53, 0x8f, 0x38, 0x79, 0x68, 0x2f, 0x0a, 0xf7, 0x10,
		0xe2, 0xe4, 0x41, 0xe5, 0x41, 0xe5, 0x41, 0xe5, 0x41, 0xe5, 0x77, 0x5a, 0xef, 0x88, 0x93, 0x27,
		0x79, 0x57, 0xc4, 0xc9, 0xc3, 0x1c, 0xc0, 0x1c, 0xc0, 0x1c, 0xa4, 0xdd, 0x1c, 0x20, 0x4e, 0x1e,
		0x12, 0x52, 0xcc, 0xe9, 0x45, 0x9c, 0x7c, 0x6e, 0x25, 0x24, 0xc4, 0xc9, 0x43, 0x39, 0x4a, 0x31,
		0x89, 0x47, 0x9c, 0x3c, 0x48, 0x3d, 0x48, 0x3d, 0x48, 0x7d, 0xd6, 0x48, 0x3d, 0xe2, 0xe4, 0xb3,
		0xcc, 0xb7, 0x71, 0x64, 0x9b, 0x5b, 0xbe, 0x8d, 0x38, 0x79, 0x30, 0x6e, 0x7e, 0xc6, 0x8d, 0x38,
		0x79, 0xb2, 0x38, 0x79, 0x94, 0x50, 0x55, 0x35, 0x91, 0x3c, 0x13, 0xc8, 0x59, 0x3a, 0x35, 0x49,
		0x35, 0x53, 0x63, 0x55, 0x07, 0xa5, 0xb8, 0x48, 0x41, 0x7a, 0x81, 0x82, 0xbc, 0xa2, 0x48, 0x09,
		0x15, 0x45, 0x12, 0xe0, 0xd4, 0xa2, 0xa2, 0xc8, 0xee, 0x6f, 0x84, 0x22, 0x7e, 0x07, 0x28, 0xe2,
		0x87, 0x9b, 0x59, 0xb8, 0x99, 0x95, 0x16, 0xde, 0x8f, 0x22, 0x7e, 0x60, 0xfa, 0xaa, 0x99, 0x3e,
		0x81, 0x77, 0x36, 0x4d, 0x49, 0x75, 0x6e, 0xa2, 0x39, 0x51, 0x36, 0x17, 0x85, 0x58, 0x1e, 0xc7,
		0x5e, 0x0e, 0x56, 0xb4, 0x09, 0xdf, 0x7f, 0xba, 0x22, 0x4c, 0x55, 0xc1, 0x2a, 0x3d, 0x8c, 0x6d,
		0x43, 0x3c, 0x8c, 0xa3, 0x4f, 0x53, 0x80, 0x73, 0x2f, 0xda, 0x8a, 0xb8, 0x68, 0xe2, 0xb9, 0x4d,
		0xb1, 0x59, 0x0c, 0x05, 0x6b, 0xa1, 0x63, 0x29, 0x54, 0xac, 0x84, 0x9c, 0x85, 0x90, 0xb3, 0x0e,
		0x52, 0x96, 0xc1, 0x0b, 0x73, 0x71, 0xdd, 0x1c, 0x54, 0x47, 0x85, 0x96, 0x01, 0x2d, 0x23, 0x2f,
		0x5a, 0x06, 0xaa, 0xa3, 0x42, 0x5b, 0x80, 0xb6, 0x90, 0x3f, 0x6d, 0x01, 0x59, 0x5f, 0x14, 0x0b,
		0x98, 0xca, 0xc0, 0x46, 0x25, 0xe8, 0xa8, 0x07, 0x1f, 0xd5, 0x20, 0xc4, 0x06, 0x46, 0x6c, 0xa0,
		0xc4, 0x02, 0x4e, 0xb4, 0x20, 0x45, 0x0c, 0x56, 0xc1, 0x08, 0x20, 0xeb, 0xcb, 0xc6, 0xa6, 0x11,
		0x42, 0xc8, 0x0f, 0xeb, 0xa1, 0x6e, 0x10, 0x42, 0xb8, 0xdf, 0xd4, 0x23, 0xeb, 0x4b, 0x3a, 0xd6,
		0x00, 0x22, 0x09, 0x93, 0xb2, 0x87, 0x90, 0xf5, 0x05, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54,
		0x7e, 0xa7, 0xf5, 0x8e, 0xac, 0x2f, 0x24, 0xef, 0x8a, 0xac, 0x2f, 0x30, 0x07, 0x30, 0x07, 0x30,
		0x07, 0x69, 0x37, 0x07, 0xc8, 0xfa, 0x02, 0x09, 0x29, 0xe6, 0xf4, 0x22, 0xeb, 0x4b, 0x6e, 0x25,
		0x24, 0x64, 0x7d, 0x81, 0x72, 0x94, 0x62, 0x12, 0x8f, 0xac, 0x2f, 0x20, 0xf5, 0x20, 0xf5, 0x20,
		0xf5, 0x59, 0x23, 0xf5, 0xc8, 0xfa, 0x92, 0x65, 0xbe, 0x8d, 0x23, 0xdb, 0xdc, 0xf2, 0x6d, 0x64,
		0x7d, 0x01, 0xe3, 0xe6, 0x67, 0xdc, 0xc8, 0xfa, 0xb2, 0xe7, 0xf5, 0xb5, 0xe7, 0xfb, 0x55, 0xa8,
		0x8d, 0x1a, 0x89, 0xc0, 0xa0, 0x36, 0x6a, 0x52, 0x3d, 0x1f, 0x44, 0xc9, 0x6b, 0xf1, 0x6c, 0x10,
		0x25, 0x4f, 0xb0, 0x19, 0x10, 0x25, 0x0f, 0xd9, 0x05, 0xb2, 0x0b, 0x64, 0x17, 0x55, 0xeb, 0x1d,
		0x51, 0xf2, 0x90, 0x5c, 0x20, 0xb9, 0x40, 0x72, 0x89, 0x34, 0xf5, 0x88, 0x92, 0x87, 0xf2, 0xa2,
		0x70, 0x0f, 0x21, 0x4a, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x7e, 0xa7, 0xf5, 0x8e,
		0x28, 0x79, 0x92, 0x77, 0x45, 0x94, 0x3c, 0xcc, 0x01, 0xcc, 0x01, 0xcc, 0x41, 0xda, 0xcd, 0x01,
		0xa2, 0xe4, 0x21, 0x21, 0xc5, 0x9c, 0x5e, 0x44, 0xc9, 0xe7, 0x56, 0x42, 0x42, 0x94, 0x3c, 0x94,
		0xa3, 0x14, 0x93, 0x78, 0x44, 0xc9, 0x83, 0xd4, 0x83, 0xd4, 0x83, 0xd4, 0x67, 0x8d, 0xd4, 0x23,
		0x4a, 0x3e, 0xcb, 0x7c, 0x1b, 0x47, 0xb6, 0xb9, 0xe5, 0xdb, 0x88, 0x92, 0x07, 0xe3, 0xe6, 0x67,
		0xdc, 0x88, 0x92, 0x27, 0x8a, 0x92, 0x47, 0x65, 0x54, 0x55, 0xd3, 0xc8, 0x31, 0x7d, 0x5c, 0x75,
		0x51, 0xcf, 0x4b, 0xdf, 0xc6, 0x76, 0xe3, 0x61, 0x6c, 0x27, 0xa2, 0x2a, 0x6a, 0xee, 0x2b, 0x36,
		0xc5, 0x2e, 0x29, 0xb4, 0xff, 0xc4, 0x27, 0xbf, 0x5a, 0xd3, 0xc3, 0xd8, 0xf2, 0xa8, 0xaa, 0x35,
		0xcd, 0xdb, 0x42, 0xb5, 0x26, 0x54, 0x6b, 0xd2, 0xa4, 0x22, 0xa0, 0x5a, 0x13, 0xaa, 0x35, 0xe9,
		0x93, 0x14, 0x51, 0xad, 0x09, 0xd5, 0x9a, 0xb6, 0x37, 0x84, 0x6a, 0x4d, 0x14, 0x0d, 0xe2, 0x1e,
		0x2a, 0xee, 0xa1, 0xa6, 0x4b, 0xe5, 0xc0, 0x3d, 0x54, 0x26, 0x09, 0x14, 0x07, 0x9b, 0xac, 0x20,
		0xc4, 0x06, 0x46, 0x6c, 0xa0, 0xc4, 0x02, 0x4e, 0xb4, 0x20, 0x45, 0x0c, 0x56, 0xc1, 0x08, 0xe0,
		0x1e, 0xea, 0xc6, 0xa6, 0x71, 0xa8, 0xc9, 0x0f, 0xeb, 0xa1, 0x6e, 0x70, 0xa8, 0xb9, 0xdf, 0xd4,
		0xe3, 0x1e, 0x6a, 0x3a, 0xd6, 0x00, 0xce, 0x36, 0x93, 0xb2, 0x87, 0x70, 0x0f, 0x15, 0x54, 0x1e,
		0x54, 0x1e, 0x54, 0x1e, 0x54, 0x7e, 0xa7, 0xf5, 0x8e, 0x7b, 0xa8, 0x24, 0xef, 0x8a, 0x7b, 0xa8,
		0x30, 0x07, 0x30, 0x07, 0x30, 0x07, 0x69, 0x37, 0x07, 0xb8, 0x87, 0x0a, 0x09, 0x29, 0xe6, 0xf4,
		0xe2, 0x1e, 0x6a, 0x6e, 0x25, 0x24, 0xdc, 0x43, 0x85, 0x72, 0x94, 0x62, 0x12, 0x8f, 0x7b, 0xa8,
		0x20, 0xf5, 0x20, 0xf5, 0x20, 0xf5, 0x59, 0x23, 0xf5, 0xb8, 0x87, 0x9a, 0x65, 0xbe, 0x8d, 0x23,
		0xdb, 0xdc, 0xf2, 0x6d, 0xdc, 0x43, 0x05, 0xe3, 0xe6, 0x67, 0xdc, 0xb8, 0x87, 0x1a, 0xe9, 0xea,
		0xda, 0xc3, 0xd8, 0xf2, 0x50, 0xad, 0x29, 0x12, 0x81, 0x41, 0xb5, 0xa6, 0xa4, 0x7a, 0x3e, 0x88,
		0x92, 0xd7, 0xe2, 0xd9, 0x20, 0x4a, 0x9e, 0x60, 0x33, 0x20, 0x4a, 0x1e, 0xb2, 0x0b, 0x64, 0x17,
		0xc8, 0x2e, 0xaa, 0xd6, 0x3b, 0xa2, 0xe4, 0x21, 0xb9, 0x40, 0x72, 0x81, 0xe4, 0x12, 0x69, 0xea,
		0x11, 0x25, 0x0f, 0xe5, 0x45, 0xe1, 0x1e, 0x42, 0x94, 0x3c, 0xa8, 0x3c, 0xa8, 0x3c, 0xa8, 0x3c,
		0xa8, 0xfc, 0x4e, 0xeb, 0x1d, 0x51, 0xf2, 0x24, 0xef, 0x8a, 0x28, 0x79, 0x98, 0x03, 0x98, 0x03,
		0x98, 0x83, 0xb4, 0x9b, 0x03, 0x44, 0xc9, 0x43, 0x42, 0x8a, 0x39, 0xbd, 0x88, 0x92, 0xcf, 0xad,
		0x84, 0x84, 0x28, 0x79, 0x28, 0x47, 0x29, 0x26, 0xf1, 0x88, 0x92, 0x07, 0xa9, 0x07, 0xa9, 0x07,
		0xa9, 0xcf, 0x1a, 0xa9, 0x47, 0x94, 0x7c, 0x96, 0xf9, 0x36, 0x8e, 0x6c, 0x73, 0xcb, 0xb7, 0x11,
		0x25, 0x0f, 0xc6, 0xcd, 0xcf, 0xb8, 0x11, 0x25, 0x4f, 0x14, 0x25, 0x8f, 0x6a, 0x4d, 0xaa, 0xa6,
		0x91, 0x63, 0xfa, 0x58, 0xab, 0x35, 0x7d, 0x1b, 0x5b, 0x1e, 0xaa, 0x35, 0x25, 0x6b, 0x35, 0xb0,
		0x54, 0x6b, 0x9a, 0x4d, 0x7c, 0xa2, 0xab, 0x35, 0x9d, 0xcc, 0x86, 0x43, 0x8e, 0x1f, 0xca, 0xc6,
		0x68, 0x62, 0xf9, 0x72, 0x60, 0x7a, 0x3e, 0x41, 0xdd, 0xa6, 0x4d, 0xad, 0xa2, 0x82, 0x13, 0x2a,
		0x38, 0x69, 0x52, 0x16, 0x50, 0xc1, 0x09, 0x15, 0x9c, 0xf4, 0xc9, 0x8c, 0xa8, 0xe0, 0x84, 0x0a,
		0x4e, 0xdb, 0x1b, 0x42, 0x05, 0x27, 0x8a, 0x06, 0x71, 0x37, 0x15, 0x77, 0x53, 0xd3, 0xa5, 0x7c,
		0xe0, 0x6e, 0x2a, 0x93, 0x2c, 0x8a, 0xc3, 0x4e, 0x56, 0x10, 0x62, 0x03, 0x23, 0x36, 0x50, 0x62,
		0x01, 0x27, 0x5a, 0x90, 0x22, 0x06, 0xab, 0x60, 0x04, 0x70, 0x37, 0x75, 0x63, 0xd3, 0x38, 0xe8,
		0xe4, 0x87, 0xf5, 0x50, 0x37, 0x38, 0xe8, 0xdc, 0x6f, 0xea, 0x71, 0x37, 0x35, 0x1d, 0x6b, 0x00,
		0xe7, 0x9d, 0x49, 0xd9, 0x43, 0xb8, 0x9b, 0x0a, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0xbf,
		0xd3, 0x7a, 0xc7, 0xdd, 0x54, 0x92, 0x77, 0xc5, 0xdd, 0x54, 0x98, 0x03, 0x98, 0x03, 0x98, 0x83,
		0xb4, 0x9b, 0x03, 0xdc, 0x4d, 0x85, 0x84, 0x14, 0x73, 0x7a, 0x71, 0x37, 0x35, 0xb7, 0x12, 0x12,
		0xee, 0xa6, 0x42, 0x39, 0x4a, 0x31, 0x89, 0xc7, 0xdd, 0x54, 0x90, 0x7a, 0x90, 0x7a, 0x90, 0xfa,
		0xac, 0x91, 0x7a, 0xdc, 0x4d, 0xcd, 0x32, 0xdf, 0xc6, 0x91, 0x6d, 0x6e, 0xf9, 0x36, 0xee, 0xa6,
		0x82, 0x71, 0xf3, 0x33, 0x6e, 0xdc, 0x4d, 0xdd, 0xf7, 0x3a, 0xdb, 0x86, 0x9b, 0x56, 0xa8, 0xe5,
		0x14, 0x89, 0xca, 0xa0, 0x96, 0x53, 0x52, 0x7d, 0x20, 0xc4, 0xcb, 0x6b, 0xf1, 0x71, 0x10, 0x2f,
		0x4f, 0xb0, 0x19, 0x10, 0x2f, 0x0f, 0x01, 0x06, 0x02, 0x0c, 0x04, 0x18, 0x55, 0xeb, 0x1d, 0xf1,
		0xf2, 0x10, 0x5f, 0x20, 0xbe, 0x40, 0x7c, 0x89, 0x34, 0xf5, 0x88, 0x97, 0x87, 0x06, 0xa3, 0x70,
		0x0f, 0x21, 0x5e, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x7e, 0xa7, 0xf5, 0x8e, 0x78,
		0x79, 0x92, 0x77, 0x45, 0xbc, 0x3c, 0xcc, 0x01, 0xcc, 0x01, 0xcc, 0x41, 0xda, 0xcd, 0x01, 0xe2,
		0xe5, 0x21, 0x21, 0xc5, 0x9c, 0x5e, 0xc4, 0xcb, 0xe7, 0x56, 0x42, 0x42, 0xbc, 0x3c, 0x94, 0xa3,
		0x14, 0x93, 0x78, 0xc4, 0xcb, 0x83, 0xd4, 0x83, 0xd4, 0x83, 0xd4, 0x67, 0x8d, 0xd4, 0x23, 0x5e,
		0x3e, 0xcb, 0x7c, 0x1b, 0x47, 0xb6, 0xb9, 0xe5, 0xdb, 0x88, 0x97, 0x07, 0xe3, 0xe6, 0x67, 0xdc,
		0x88, 0x97, 0x27, 0x8f, 0x97, 0x47, 0x55, 0x27, 0x55, 0x13, 0xca, 0x3b, 0x91, 0x6c, 0xf5, 0x9d,
		0x4e, 0xbe, 0x8d, 0xed, 0xe6, 0xf8, 0xa1, 0x7c, 0xb1, 0x7a, 0x0c, 0x14, 0x7a, 0x4a, 0xea, 0x02,
		0x51, 0x5e, 0xf2, 0x29, 0xb4, 0x16, 0x52, 0x52, 0xfb, 0x69, 0x62, 0xd3, 0x57, 0x7e, 0x5a, 0xb5,
		0x89, 0xba, 0x4f, 0xa8, 0xfb, 0xa4, 0x49, 0x85, 0x40, 0xdd, 0x27, 0xd4, 0x7d, 0xd2, 0x27, 0x49,
		0xa2, 0xee, 0x13, 0xea, 0x3e, 0x6d, 0x6f, 0x08, 0x75, 0x9f, 0x28, 0x1a, 0xc4, 0x3d, 0x56, 0xdc,
		0x63, 0x4d, 0x97, 0x4a, 0x82, 0x7b, 0xac, 0x4c, 0x12, 0x2a, 0x0e, 0x46, 0x59, 0x41, 0x88, 0x0d,
		0x8c, 0xd8, 0x40, 0x89, 0x05, 0x9c, 0x68, 0x41, 0x8a, 0x18, 0xac, 0x82, 0x11, 0xc0, 0x3d, 0xd6,
		0x8d, 0x4d, 0xe3, 0x50, 0x94, 0x1f, 0xd6, 0x43, 0xdd, 0xe0, 0x50, 0x74, 0xbf, 0xa9, 0xc7, 0x3d,
		0xd6, 0x74, 0xac, 0x01, 0x9c, 0x8d, 0x26, 0x65, 0x0f, 0xe1, 0x1e, 0x2b, 0xa8, 0x3c, 0xa8, 0x3c,
		0xa8, 0x3c, 0xa8, 0xfc, 0x4e, 0xeb, 0x1d, 0xf7, 0x58, 0x49, 0xde, 0x15, 0xf7, 0x58, 0x61, 0x0e,
		0x60, 0x0e, 0x60, 0x0e, 0xd2, 0x6e, 0x0e, 0x70, 0x8f, 0x15, 0x12, 0x52, 0xcc, 0xe9, 0xc5, 0x3d,
		0xd6, 0xdc, 0x4a, 0x48, 0xb8, 0xc7, 0x0a, 0xe5, 0x28, 0xc5, 0x24, 0x1e, 0xf7, 0x58, 0x41, 0xea,
		0x41, 0xea, 0x41, 0xea, 0xb3, 0x46, 0xea, 0x71, 0x8f, 0x35, 0xcb, 0x7c, 0x1b, 0x47, 0xb6, 0xb9,
		0xe5, 0xdb, 0xb8, 0xc7, 0x0a, 0xc6, 0xcd, 0xcf, 0xb8, 0x71, 0x8f, 0x35, 0xfa, 0xed, 0xb6, 0xe5,
		0x3d, 0x2b, 0x54, 0x7d, 0x8a, 0x44, 0x64, 0x50, 0xf5, 0x29, 0xa9, 0x1e, 0x10, 0xa2, 0xe5, 0xb5,
		0x78, 0x38, 0x88, 0x96, 0x27, 0xd8, 0x0c, 0x88, 0x96, 0x87, 0xfc, 0x02, 0xf9, 0x05, 0xf2, 0x8b,
		0xaa, 0xf5, 0x8e, 0x68, 0x79, 0x48, 0x2f, 0x90, 0x5e, 0x20, 0xbd, 0x44, 0x9a, 0x7a, 0x44, 0xcb,
		0x43, 0x81, 0x51, 0xb8, 0x87, 0x10, 0x2d, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0xbf,
		0xd3, 0x7a, 0x47, 0xb4, 0x3c, 0xc9, 0xbb, 0x22, 0x5a, 0x1e, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20,
		0xed, 0xe6, 0x00, 0xd1, 0xf2, 0x90, 0x90, 0x62, 0x4e, 0x2f, 0xa2, 0xe5, 0x73, 0x2b, 0x21, 0x21,
		0x5a, 0x1e, 0xca, 0x51, 0x8a, 0x49, 0x3c, 0xa2, 0xe5, 0x41, 0xea, 0x41, 0xea, 0x41, 0xea, 0xb3,
		0x46, 0xea, 0x11, 0x2d, 0x9f, 0x65, 0xbe, 0x8d, 0x23, 0xdb, 0xdc, 0xf2, 0x6d, 0x44, 0xcb, 0x83,
		0x71, 0xf3, 0x33, 0x6e, 0x44, 0xcb, 0x13, 0x47, 0xcb, 0xa3, 0xe6, 0x93, 0xaa, 0xe9, 0xe4, 0x9c,
		0x46, 0xf6, 0x8a, 0x4f, 0xd7, 0x36, 0xea, 0x3d, 0x25, 0xb1, 0xde, 0x53, 0xbc, 0xca, 0x43, 0x91,
		0xd7, 0x41, 0x2a, 0x6a, 0x3d, 0x55, 0x5f, 0x54, 0xc3, 0xa2, 0xab, 0xf6, 0x54, 0x8d, 0x5d, 0x63,
		0x0b, 0xf5, 0x9e, 0x54, 0xe8, 0x18, 0xa8, 0xf7, 0xa4, 0x10, 0x05, 0x51, 0xef, 0x89, 0x5b, 0xac,
		0x44, 0xbd, 0x27, 0xd4, 0x7b, 0x62, 0xe6, 0xc3, 0xa8, 0xf7, 0x94, 0x84, 0x8d, 0xaf, 0x02, 0x00,
		0xd4, 0x01, 0x81, 0x2a, 0x40, 0x50, 0x0e, 0x0c, 0xca, 0x01, 0x42, 0x29, 0x50, 0x24, 0x53, 0x1f,
		0xc1, 0x0d, 0x56, 0x26, 0xf1, 0x14, 0x47, 0xa2, 0xac, 0x20, 0xc4, 0x06, 0x46, 0x6c, 0xa0, 0xc4,
		0x02, 0x4e, 0xb4, 0x20, 0x45, 0x0c, 0x56, 0xc1, 0x08, 0xe0, 0x06, 0xeb, 0xc6, 0xa6, 0x71, 0x1c,
		0xca, 0x0f, 0xeb, 0xa1, 0x6e, 0x70, 0x1c, 0xba, 0xdf, 0xd4, 0xe3, 0x06, 0x6b, 0x3a, 0xd6, 0x00,
		0x4e, 0x45, 0x93, 0xb2, 0x87, 0x70, 0x83, 0x15, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x7e,
		0xa7, 0xf5, 0x8e, 0x1b, 0xac, 0x24, 0xef, 0x8a, 0x1b, 0xac, 0x30, 0x07, 0x30, 0x07, 0x30, 0x07,
		0x69, 0x37, 0x07, 0xb8, 0xc1, 0x0a, 0x09, 0x29, 0xe6, 0xf4, 0xe2, 0x06, 0x6b, 0x6e, 0x25, 0x24,
		0xdc, 0x60, 0x85, 0x72, 0x94, 0x62, 0x12, 0x8f, 0x1b, 0xac, 0x20, 0xf5, 0x20, 0xf5, 0x20, 0xf5,
		0x59, 0x23, 0xf5, 0xb8, 0xc1, 0x9a, 0x65, 0xbe, 0x8d, 0x23, 0xdb, 0xdc, 0xf2, 0x6d, 0xdc, 0x60,
		0x05, 0xe3, 0xe6, 0x67, 0xdc, 0xb8, 0xc1, 0x1a, 0xf5, 0x76, 0xdb, 0x8b, 0x9b, 0x56, 0xa8, 0xf8,
		0x14, 0x89, 0xca, 0xa0, 0xe2, 0x53, 0x52, 0x7d, 0x20, 0xc4, 0xcb, 0x6b, 0xf1, 0x71, 0x10, 0x2f,
		0x4f, 0xb0, 0x19, 0x10, 0x2f, 0x0f, 0x01, 0x06, 0x02, 0x0c, 0x04, 0x18, 0x55, 0xeb, 0x1d, 0xf1,
		0xf2, 0x10, 0x5f, 0x20, 0xbe, 0x40, 0x7c, 0x89, 0x34, 0xf5, 0x88, 0x97, 0x87, 0x06, 0xa3, 0x70,
		0x0f, 0x21, 0x5e, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x1e, 0x54, 0x7e, 0xa7, 0xf5, 0x8e, 0x78,
		0x79, 0x92, 0x77, 0x45, 0xbc, 0x3c, 0xcc, 0x01, 0xcc, 0x01, 0xcc, 0x41, 0xda, 0xcd, 0x01, 0xe2,
		0xe5, 0x21, 0x21, 0xc5, 0x9c, 0x5e, 0xc4, 0xcb, 0xe7, 0x56, 0x42, 0x42, 0xbc, 0x3c, 0x94, 0xa3,
		0x14, 0x93, 0x78, 0xc4, 0xcb, 0x83, 0xd4, 0x83, 0xd4, 0x83, 0xd4, 0x67, 0x8d, 0xd4, 0x23, 0x5e,
		0x3e, 0xcb, 0x7c, 0x1b, 0x47, 0xb6, 0xb9, 0xe5, 0xdb, 0x88, 0x97, 0x07, 0xe3, 0xe6, 0x67, 0xdc,
		0x88, 0x97, 0x27, 0x8f, 0x97, 0x47, 0xcd, 0x27, 0x55, 0x13, 0xca, 0x3b, 0x91, 0xdc, 0x55, 0x9f,
		0xaa, 0x17, 0xab, 0xc7, 0x40, 0xdd, 0xa7, 0xa4, 0x2e, 0x10, 0xae, 0xca, 0x4f, 0xcf, 0x6b, 0x21,
		0x25, 0xb5, 0x9f, 0x56, 0x95, 0xb1, 0x28, 0x2b, 0x3f, 0xc5, 0xab, 0xb6, 0x85, 0xba, 0x4f, 0x2a,
		0xd4, 0x0c, 0xd4, 0x7d, 0x52, 0x88, 0x82, 0xa8, 0xfb, 0xc4, 0x2d, 0x59, 0xa2, 0xee, 0x13, 0xea,
		0x3e, 0x31, 0x73, 0x62, 0xd4, 0x7d, 0x4a, 0xc2, 0xc6, 0x57, 0x01, 0x00, 0xea, 0x80, 0x40, 0x15,
		0x20, 0x28, 0x07, 0x06, 0xe5, 0x00, 0xa1, 0x14, 0x28, 0x92, 0xa9, 0x92, 0xe0, 0x1e, 0x2b, 0x93,
		0x84, 0x8a, 0x83, 0x51, 0x56, 0x10, 0x62, 0x03, 0x23, 0x36, 0x50, 0x62, 0x01, 0x27, 0x5a, 0x90,
		0x22, 0x06, 0xab, 0x60, 0x04, 0x70, 0x8f, 0x75, 0x63, 0xd3, 0x38, 0x14, 0xe5, 0x87, 0xf5, 0x50,
		0x37, 0x38, 0x14, 0xdd, 0x6f, 0xea, 0x71, 0x8f, 0x35, 0x1d, 0x6b, 0x00, 0x67, 0xa3, 0x49, 0xd9,
		0x43, 0xb8, 0xc7, 0x0a, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0xbf, 0xd3, 0x7a, 0xc7, 0x3d,
		0x56, 0x92, 0x77, 0xc5, 0x3d, 0x56, 0x98, 0x03, 0x98, 0x03, 0x98, 0x83, 0xb4, 0x9b, 0x03, 0xdc,
		0x63, 0x85, 0x84, 0x14, 0x73, 0x7a, 0x71, 0x8f, 0x35, 0xb7, 0x12, 0x12, 0xee, 0xb1, 0x42, 0x39,
		0x4a, 0x31, 0x89, 0xc7, 0x3d, 0x56, 0x90, 0x7a, 0x90, 0x7a, 0x90, 0xfa, 0xac, 0x91, 0x7a, 0xdc,
		0x63, 0xcd, 0x32, 0xdf, 0xc6, 0x91, 0x6d, 0x6e, 0xf9, 0x36, 0xee, 0xb1, 0x82, 0x71, 0xf3, 0x33,
		0x6e, 0xdc, 0x63, 0x8d, 0x7e, 0xbb, 0x6d, 0x79, 0xcf, 0x0a, 0x55, 0x9f, 0x22, 0x11, 0x19, 0x54,
		0x7d, 0x4a, 0xaa, 0x07, 0x84, 0x68, 0x79, 0x2d, 0x1e, 0x0e, 0xa2, 0xe5, 0x09, 0x36, 0x03, 0xa2,
		0xe5, 0x21, 0xbf, 0x40, 0x7e, 0x81, 0xfc, 0xa2, 0x6a, 0xbd, 0x23, 0x5a, 0x1e, 0xd2, 0x0b, 0xa4,
		0x17, 0x48, 0x2f, 0x91, 0xa6, 0x1e, 0xd1, 0xf2, 0x50, 0x60, 0x14, 0xee, 0x21, 0x44, 0xcb, 0x83,
		0xca, 0x83, 0xca, 0x83, 0xca, 0x83, 0xca, 0xef, 0xb4, 0xde, 0x11, 0x2d, 0x4f, 0xf2, 0xae, 0x88,
		0x96, 0x87, 0x39, 0x80, 0x39, 0x80, 0x39, 0x48, 0xbb, 0x39, 0x40, 0xb4, 0x3c, 0x24, 0xa4, 0x98,
		0xd3, 0x8b, 0x68, 0xf9, 0xdc, 0x4a, 0x48, 0x88, 0x96, 0x87, 0x72, 0x94, 0x62, 0x12, 0x8f, 0x68,
		0x79, 0x90, 0x7a, 0x90, 0x7a, 0x90, 0xfa, 0xac, 0x91, 0x7a, 0x44, 0xcb, 0x67, 0x99, 0x6f, 0xe3,
		0xc8, 0x36, 0xb7, 0x7c, 0x1b, 0xd1, 0xf2, 0x60, 0xdc, 0xfc, 0x8c, 0x1b, 0xd1, 0xf2, 0xc4, 0xd1,
		0xf2, 0xa8, 0xf9, 0xa4, 0x6a, 0x3a, 0x39, 0xa7, 0x91, 0xbd, 0xe2, 0xd3, 0xb5, 0x8d, 0x7a, 0x4f,
		0x49, 0xac, 0xf7, 0x14, 0xaf, 0xf2, 0x50, 0xe4, 0x75, 0x90, 0xe4, 0x5a, 0x4f, 0x9e, 0xeb, 0x0b,
		0x63, 0xec, 0x58, 0x72, 0xf0, 0x38, 0x1b, 0xa3, 0x72, 0xfc, 0x4a, 0x4f, 0xa1, 0x16, 0x51, 0xe7,
		0x09, 0x75, 0x9e, 0x34, 0xe9, 0x0e, 0xa8, 0xf3, 0x84, 0x3a, 0x4f, 0xfa, 0x44, 0x48, 0xd4, 0x79,
		0x42, 0x9d, 0xa7, 0xed, 0x0d, 0xa1, 0xce, 0x13, 0x45, 0x83, 0xb8, 0xb9, 0x8a, 0x9b, 0xab, 0xe9,
		0xd2, 0x45, 0x70, 0x73, 0x95, 0x49, 0x34, 0xc5, 0x51, 0x28, 0x2b, 0x08, 0xb1, 0x81, 0x11, 0x1b,
		0x28, 0xb1, 0x80, 0x13, 0x2d, 0x48, 0x11, 0x83, 0x55, 0x30, 0x02, 0xb8, 0xb9, 0xba, 0xb1, 0x69,
		0x1c, 0x83, 0xf2, 0xc3, 0x7a, 0xa8, 0x1b, 0x1c, 0x83, 0xee, 0x37, 0xf5, 0xb8, 0xb9, 0x9a, 0x8e,
		0x35, 0x80, 0xd3, 0xd0, 0xa4, 0xec, 0x21, 0xdc, 0x5c, 0x05, 0x95, 0x07, 0x95, 0x07, 0x95, 0x07,
		0x95, 0xdf, 0x69, 0xbd, 0xe3, 0xe6, 0x2a, 0xc9, 0xbb, 0xe2, 0xe6, 0x2a, 0xcc, 0x01, 0xcc, 0x01,
		0xcc, 0x41, 0xda, 0xcd, 0x01, 0x6e, 0xae, 0x42, 0x42, 0x8a, 0x39, 0xbd, 0xb8, 0xb9, 0x9a, 0x5b,
		0x09, 0x09, 0x37, 0x57, 0xa1, 0x1c, 0xa5, 0x98, 0xc4, 0xe3, 0xe6, 0x2a, 0x48, 0x3d, 0x48, 0x3d,
		0x48, 0x7d, 0xd6, 0x48, 0x3d, 0x6e, 0xae, 0x66, 0x99, 0x6f, 0xe3, 0xc8, 0x36, 0xb7, 0x7c, 0x1b,
		0x37, 0x57, 0xc1, 0xb8, 0xf9, 0x19, 0x37, 0x6e, 0xae, 0xee, 0x79, 0xab, 0xed, 0xf5, 0x2d, 0x2b,
		0x54, 0x79, 0x8a, 0x44, 0x63, 0x50, 0xe5, 0x29, 0xa9, 0xfe, 0x0f, 0x62, 0xe5, 0xb5, 0xf8, 0x37,
		0x88, 0x95, 0x27, 0xd8, 0x0c, 0x88, 0x95, 0x87, 0xf8, 0x02, 0xf1, 0x05, 0xe2, 0x8b, 0xaa, 0xf5,
		0x8e, 0x58, 0x79, 0x08, 0x2f, 0x10, 0x5e, 0x20, 0xbc, 0x44, 0x9a, 0x7a, 0xc4, 0xca, 0x43, 0x7f,
		0x51, 0xb8, 0x87, 0x10, 0x2b, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0xbf, 0xd3, 0x7a,
		0x47, 0xac, 0x3c, 0xc9, 0xbb, 0x22, 0x56, 0x1e, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xed, 0xe6,
		0x00, 0xb1, 0xf2, 0x90, 0x90, 0x62, 0x4e, 0x2f, 0x62, 0xe5, 0x73, 0x2b, 0x21, 0x21, 0x56, 0x1e,
		0xca, 0x51, 0x8a, 0x49, 0x3c, 0x62, 0xe5, 0x41, 0xea, 0x41, 0xea, 0x41, 0xea, 0xb3, 0x46, 0xea,
		0x11, 0x2b, 0x9f, 0x65, 0xbe, 0x8d, 0x23, 0xdb, 0xdc, 0xf2, 0x6d, 0xc4, 0xca, 0x83, 0x71, 0xf3,
		0x33, 0x6e, 0xc4, 0xca, 0x93, 0xc6, 0xca, 0xa3, 0xc6, 0x93, 0xaa, 0xc9, 0xe4, 0x9b, 0x44, 0xae,
		0x0a, 0x4f, 0x5d, 0xd7, 0x17, 0xed, 0xf9, 0x33, 0x34, 0xc7, 0x0f, 0x65, 0xd4, 0x77, 0x4a, 0xe2,
		0xc2, 0x50, 0x5d, 0xdd, 0x69, 0x7d, 0x0d, 0xa4, 0xa8, 0xb6, 0x53, 0x95, 0xbc, 0xb6, 0x53, 0x15,
		0xb5, 0x9d, 0x50, 0xdb, 0x49, 0x97, 0xda, 0x80, 0xda, 0x4e, 0xa8, 0xed, 0xa4, 0x4f, 0x7a, 0x44,
		0x6d, 0x27, 0xd4, 0x76, 0xda, 0xde, 0x10, 0x6a, 0x3b, 0x51, 0x34, 0x88, 0xfb, 0xaa, 0xb8, 0xaf,
		0x9a, 0x2e, 0x35, 0x04, 0xf7, 0x55, 0x99, 0xa4, 0x52, 0x1c, 0x80, 0xb2, 0x82, 0x10, 0x1b, 0x18,
		0xb1, 0x81, 0x12, 0x0b, 0x38, 0xd1, 0x82, 0x14, 0x31, 0x58, 0x05, 0x23, 0x80, 0xfb, 0xaa, 0x1b,
		0x9b, 0xc6, 0xe1, 0x27, 0x3f, 0xac, 0x87, 0xba, 0xc1, 0xe1, 0xe7, 0x7e, 0x53, 0x8f, 0xfb, 0xaa,
		0xe9, 0x58, 0x03, 0x38, 0x03, 0x4d, 0xca, 0x1e, 0xc2, 0x7d, 0x55, 0x50, 0x79, 0x50, 0x79, 0x50,
		0x79, 0x50, 0xf9, 0x9d, 0xd6, 0x3b, 0xee, 0xab, 0x92, 0xbc, 0x2b, 0xee, 0xab, 0xc2, 0x1c, 0xc0,
		0x1c, 0xc0, 0x1c, 0xa4, 0xdd, 0x1c, 0xe0, 0xbe, 0x2a, 0x24, 0xa4, 0x98, 0xd3, 0x8b, 0xfb, 0xaa,
		0xb9, 0x95, 0x90, 0x70, 0x5f, 0x15, 0xca, 0x51, 0x8a, 0x49, 0x3c, 0xee, 0xab, 0x82, 0xd4, 0x83,
		0xd4, 0x83, 0xd4, 0x67, 0x8d, 0xd4, 0xe3, 0xbe, 0x6a, 0x96, 0xf9, 0x36, 0x8e, 0x6c, 0x73, 0xcb,
		0xb7, 0x71, 0x5f, 0x15, 0x8c, 0x9b, 0x9f, 0x71, 0xe3, 0xbe, 0x6a, 0xbc, 0x1b, 0x6d, 0x55, 0xd4,
		0x76, 0x8a, 0x44, 0x63, 0x50, 0xdb, 0x29, 0xa9, 0xfe, 0x0f, 0x62, 0xe5, 0xb5, 0xf8, 0x37, 0x88,
		0x95, 0x27, 0xd8, 0x0c, 0x88, 0x95, 0x87, 0xf8, 0x02, 0xf1, 0x05, 0xe2, 0x8b, 0xaa, 0xf5, 0x8e,
		0x58, 0x79, 0x08, 0x2f, 0x10, 0x5e, 0x20, 0xbc, 0x44, 0x9a, 0x7a, 0xc4, 0xca, 0x43, 0x7f, 0x51,
		0xb8, 0x87, 0x10, 0x2b, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0xbf, 0xd3, 0x7a, 0x47,
		0xac, 0x3c, 0xc9, 0xbb, 0x22, 0x56, 0x1e, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xed, 0xe6, 0x00,
		0xb1, 0xf2, 0x90, 0x90, 0x62, 0x4e, 0x2f, 0x62, 0xe5, 0x73, 0x2b, 0x21, 0x21, 0x56, 0x1e, 0xca,
		0x51, 0x8a, 0x49, 0x3c, 0x62, 0xe5, 0x41, 0xea, 0x41, 0xea, 0x41, 0xea, 0xb3, 0x46, 0xea, 0x11,
		0x2b, 0x9f, 0x65, 0xbe, 0x8d, 0x23, 0xdb, 0xdc, 0xf2, 0x6d, 0xc4, 0xca, 0x83, 0x71, 0xf3, 0x33,
		0x6e, 0xc4, 0xca, 0x93, 0xc6, 0xca, 0xa3, 0xb6, 0x93, 0xaa, 0xc9, 0xe4, 0x9b, 0x44, 0x2d, 0xb5,
		0x9d, 0xaa, 0xa8, 0xed, 0x94, 0xc4, 0x85, 0xc1, 0x5a, 0xdb, 0xa9, 0x9a, 0xe8, 0xda, 0x4e, 0xb1,
		0xee, 0xcc, 0x90, 0xdc, 0x91, 0x21, 0xab, 0xe2, 0x54, 0x42, 0x15, 0x27, 0x85, 0x3a, 0x04, 0xaa,
		0x38, 0x3d, 0x3f, 0x79, 0xec, 0x2a, 0x4e, 0x2b, 0x64, 0x32, 0x96, 0x38, 0x42, 0x54, 0xc6, 0x69,
		0xbd, 0x59, 0x9a, 0x3a, 0x4e, 0xc7, 0xa8, 0xe3, 0xa4, 0x41, 0x56, 0x44, 0x1d, 0xa7, 0x04, 0x70,
		0x5d, 0x32, 0xd9, 0x2f, 0x58, 0x6f, 0x72, 0x28, 0x6c, 0x5f, 0xfa, 0x8f, 0xae, 0xb8, 0xa3, 0x58,
		0x74, 0x2b, 0xcb, 0x49, 0x20, 0xec, 0x15, 0x9a, 0xcb, 0x47, 0xfb, 0x64, 0x7a, 0x0a, 0x2e, 0xd1,
		0xd6, 0xbf, 0x34, 0xfb, 0xdd, 0xd9, 0xff, 0x5d, 0xfd, 0xb7, 0xdd, 0xa0, 0x5a, 0xca, 0x73, 0xed,
		0xc3, 0x23, 0x15, 0x1f, 0x15, 0x9d, 0x23, 0x9d, 0x9f, 0x7c, 0x6b, 0x5f, 0xf6, 0x9b, 0xed, 0x6f,
		0xe5, 0xfe, 0xf5, 0x65, 0xf3, 0x73, 0xbd, 0x7b, 0x55, 0x48, 0xe2, 0xf1, 0x9a, 0xaa, 0xb7, 0x6f,
		0x5e, 0xfe, 0xbb, 0x7b, 0x55, 0xbf, 0x6a, 0xe4, 0xe9, 0xa5, 0xe7, 0x93, 0x7d, 0x5e, 0xff, 0xd4,
		0x38, 0x6f, 0x9c, 0xe5, 0x72, 0xd2, 0x4b, 0xb3, 0x25, 0xff, 0xad, 0x7d, 0xde, 0xcd, 0xe5, 0x52,
		0xef, 0x77, 0xdb, 0x5f, 0x72, 0xf5, 0xe2, 0x2b, 0x84, 0xab, 0xe6, 0x71, 0xb1, 0xcf, 0xdf, 0x3b,
		0xf7, 0x9b, 0xbd, 0xf1, 0xad, 0x7d, 0x99, 0xbb, 0x59, 0xcf, 0xe1, 0x6c, 0x77, 0x3b, 0x57, 0x8d,
		0x7e, 0xbb, 0x75, 0xde, 0xfc, 0xfc, 0xdf, 0x39, 0xa7, 0xc9, 0x25, 0xce, 0x95, 0xfb, 0x17, 0xd7,
		0xe7, 0x57, 0x79, 0x44, 0xba, 0x72, 0xff, 0xcb, 0x79, 0xeb, 0x3f, 0xdd, 0x76, 0xe3, 0x73, 0x3e,
		0x2d, 0x7b, 0xce, 0x50, 0xee, 0x5b, 0xfb, 0x32, 0xa7, 0x53, 0xfe, 0x0a, 0xe7, 0xaa, 0xb9, 0xdb,
		0xe7, 0x79, 0x64, 0x32, 0xcf, 0x3c, 0x56, 0x05, 0xbe, 0x93, 0xb4, 0xd4, 0xd3, 0xad, 0xab, 0xbd,
		0xd1, 0x30, 0xff, 0x05, 0x61, 0x9b, 0xb7, 0x96, 0x18, 0xd2, 0xa9, 0xe5, 0xab, 0x06, 0xe3, 0x56,
		0x7b, 0xa7, 0xbd, 0x02, 0x0e, 0xdd, 0x7d, 0xaf, 0x16, 0xa1, 0xbb, 0x43, 0x77, 0xff, 0xf5, 0x7a,
		0xa3, 0xbb, 0x42, 0x4d, 0x74, 0x65, 0x1a, 0xd1, 0x1c, 0x31, 0xa2, 0x39, 0xa2, 0x47, 0x63, 0xf1,
		0x04, 0x55, 0x4c, 0x3c, 0x61, 0x8c, 0x26, 0x96, 0x2f, 0xc7, 0x96, 0x30, 0x66, 0xef, 0xec, 0xc5,
		0x8f, 0xb0, 0xd8, 0xd0, 0xa6, 0xe6, 0x70, 0x8b, 0x63, 0x84, 0x5b, 0x28, 0xb4, 0x1b, 0x08, 0xb7,
		0x78, 0xc1, 0xb0, 0xe2, 0x86, 0x5b, 0x0c, 0x56, 0x6b, 0x96, 0x88, 0x39, 0x2e, 0xdb, 0xa3, 0x21,
		0x7a, 0x45, 0x10, 0x3d, 0x10, 0xbd, 0x7c, 0x12, 0x3d, 0xaa, 0xdc, 0xbd, 0x64, 0xbe, 0xa1, 0x22,
		0x1f, 0x51, 0x95, 0xaf, 0x48, 0xec, 0x33, 0x92, 0x43, 0x8a, 0x0a, 0x68, 0x51, 0x07, 0x31, 0xaa,
		0xa0, 0x46, 0x39, 0xe4, 0x28, 0x87, 0x1e, 0xa5, 0x10, 0x44, 0xab, 0x8d, 0x51, 0x5d, 0x5a, 0x21,
		0xbf, 0xf2, 0xa9, 0x30, 0x9d, 0x17, 0x71, 0x1a, 0x2f, 0x5c, 0x51, 0x51, 0xe7, 0xbb, 0x86, 0xdd,
		0x38, 0x92, 0x42, 0x1c, 0x9a, 0x14, 0xd9, 0xd9, 0xfe, 0xa7, 0x93, 0x63, 0xe3, 0xa3, 0x38, 0x28,
		0x35, 0x28, 0x35, 0x28, 0x35, 0xcd, 0x72, 0x23, 0xf2, 0x99, 0xd5, 0xf8, 0xce, 0xc4, 0x1b, 0x1e,
		0xc4, 0x17, 0xc4, 0x17, 0xc4, 0x97, 0x16, 0x40, 0x82, 0x06, 0x4d, 0xcb, 0x72, 0xfe, 0x7e, 0x26,
		0x3d, 0xa6, 0xc2, 0xa2, 0x3a, 0xe1, 0xae, 0x90, 0xee, 0x1b, 0xa9, 0xa0, 0xb8, 0xe1, 0x8e, 0x0d,
		0xf6, 0xd8, 0xe0, 0x8f, 0x05, 0x06, 0x69, 0xe1, 0x90, 0x18, 0x16, 0xd5, 0xe9, 0x02, 0x0c, 0xfa,
		0x80, 0x22, 0x9d, 0x80, 0x7e, 0xc2, 0x28, 0x33, 0x05, 0x8e, 0xcc, 0x1f, 0x72, 0x34, 0x19, 0xc5,
		0x3c, 0x7f, 0xfd, 0xe5, 0x6c, 0xad, 0x77, 0xa3, 0xce, 0xdc, 0x14, 0x61, 0x6a, 0x60, 0x6a, 0x60,
		0x6a, 0x60, 0x6a, 0x28, 0xd7, 0x3b, 0x8a, 0xc4, 0x85, 0x7e, 0x21, 0xe3, 0xe0, 0x4e, 0xdd, 0x20,
		0xe3, 0xe0, 0x7e, 0x53, 0x8f, 0x22, 0x71, 0xe9, 0x58, 0x03, 0x48, 0x3c, 0x98, 0x21, 0x29, 0x2b,
		0x0d, 0x89, 0x07, 0x37, 0x1c, 0x08, 0x8a, 0x59, 0x0b, 0x28, 0xcf, 0xbf, 0x23, 0x87, 0x41, 0x79,
		0xfe, 0xa4, 0x3a, 0x3f, 0x38, 0x4e, 0xd0, 0xe2, 0xdc, 0xe0, 0x38, 0x81, 0x6a, 0x47, 0xe0, 0x38,
		0x01, 0x1a, 0x0f, 0x34, 0x1e, 0x68, 0x3c, 0xa9, 0xd6, 0x78, 0x70, 0x9c, 0x40, 0xf2, 0xae, 0x38,
		0x4e, 0x80, 0xa9, 0x81, 0xa9, 0x81, 0xa9, 0x81, 0xa9, 0xd9, 0xbe, 0xde, 0x71, 0x9c, 0x10, 0xfa,
		0x85, 0xe3, 0x84, 0x9d, 0xba, 0xc1, 0x71, 0xc2, 0x7e, 0x53, 0x8f, 0xe3, 0x84, 0x74, 0xac, 0x01,
		0x1c, 0x27, 0x64, 0x48, 0xca, 0x4a, 0xf3, 0x71, 0x02, 0x2a, 0x18, 0xa9, 0x9a, 0x46, 0x8e, 0xe9,
		0xe3, 0xaa, 0x5d, 0x74, 0xed, 0x89, 0x8b, 0x65, 0xef, 0xed, 0x59, 0xe7, 0xfd, 0x46, 0x6c, 0x9e,
		0xac, 0xe7, 0x66, 0x9a, 0x24, 0xbd, 0x99, 0x26, 0x71, 0x33, 0x8d, 0xd7, 0xdf, 0xc5, 0xcd, 0x34,
		0xdc, 0x4c, 0xdb, 0xde, 0x10, 0x6e, 0xa6, 0x25, 0x54, 0x00, 0xc3, 0x51, 0x32, 0xbf, 0xc0, 0x85,
		0xa3, 0xe4, 0xe8, 0x0d, 0x42, 0xd3, 0xd7, 0xa1, 0x00, 0x40, 0xd3, 0x67, 0x85, 0x38, 0x36, 0xa8,
		0x63, 0x83, 0x3c, 0x16, 0xe8, 0x53, 0x23, 0xb6, 0x40, 0xd3, 0x0f, 0xa1, 0x0b, 0x34, 0xfd, 0x17,
		0x0f, 0x0e, 0x4d, 0x7f, 0xff, 0x7e, 0xa0, 0xe9, 0x27, 0x76, 0xea, 0xa1, 0xe9, 0xeb, 0x6b, 0x15,
		0x9a, 0xfe, 0x4e, 0x14, 0x22, 0x9d, 0x9a, 0xbe, 0xc4, 0x15, 0x81, 0x3d, 0x38, 0x0c, 0xae, 0x08,
		0x40, 0xd7, 0x81, 0xae, 0x03, 0x5d, 0x07, 0xba, 0x0e, 0x74, 0x1d, 0xe8, 0x3a, 0xd0, 0x75, 0xa0,
		0xeb, 0x40, 0xd7, 0x81, 0xae, 0x03, 0x5d, 0x07, 0xba, 0x0e, 0x74, 0x1d, 0xe8, 0x3a, 0xd0, 0x75,
		0x12, 0xa6, 0xeb, 0x20, 0x56, 0x53, 0xd5, 0x34, 0x72, 0x4c, 0x9f, 0xb6, 0x58, 0xcd, 0x66, 0x4a,
		0x63, 0x35, 0x69, 0x44, 0x3f, 0x52, 0xb1, 0x8f, 0x3c, 0x5a, 0xb3, 0x84, 0x68, 0xcd, 0x04, 0x78,
		0xb4, 0x88, 0xd6, 0xe4, 0x17, 0xe5, 0x50, 0x9a, 0x0b, 0xa5, 0xb9, 0x70, 0x5e, 0x80, 0xf3, 0x02,
		0x94, 0xe6, 0x02, 0x9f, 0x4f, 0x1d, 0x9f, 0x27, 0xf0, 0xc4, 0x50, 0xe8, 0x9b, 0x72, 0x46, 0x0a,
		0xb1, 0xfc, 0x8c, 0xfd, 0x9d, 0x2a, 0xb6, 0x2a, 0xe3, 0x6f, 0x14, 0xce, 0xf1, 0xcc, 0xb8, 0xcd,
		0xd3, 0x99, 0x2d, 0xc7, 0xd5, 0x98, 0x8f, 0xc1, 0x9e, 0x6d, 0x9c, 0x4b, 0xcf, 0xaf, 0xfb, 0x7e,
		0x34, 0x52, 0x58, 0xb8, 0x90, 0x76, 0xc3, 0x12, 0x33, 0xf3, 0xe4, 0x45, 0xa3, 0x2e, 0x85, 0x0b,
		0xf3, 0xc7, 0x8b, 0x16, 0x8a, 0x1f, 0xca, 0xe5, 0x6a, 0xad, 0x5c, 0x3e, 0xae, 0x9d, 0xd4, 0x8e,
		0x4f, 0x2b, 0x95, 0x62, 0xb5, 0x18, 0x41, 0x8a, 0x2c, 0xb4, 0xdc, 0xa1, 0x70, 0xc5, 0xf0, 0xd3,
		0x6c, 0x78, 0xec, 0x89, 0x65, 0x29, 0x9d, 0x85, 0x98, 0x3b, 0x8c, 0x72, 0x67, 0x45, 0xd8, 0x46,
		0xbb, 0x6c, 0x9f, 0xfd, 0x76, 0xcb, 0xee, 0x6b, 0x7e, 0xb7, 0x9f, 0xdc, 0x71, 0x3e, 0xa2, 0xce,
		0x03, 0xc1, 0xf8, 0xef, 0x36, 0x3e, 0xbf, 0x7e, 0xdb, 0x1d, 0xde, 0xb4, 0x60, 0x8e, 0xc7, 0xd6,
		0xa3, 0x31, 0x76, 0x2c, 0x39, 0x78, 0xdc, 0xf9, 0x3d, 0x9f, 0x33, 0x1f, 0xbe, 0xfc, 0xf6, 0x8e,
		0xe3, 0xba, 0x9f, 0x66, 0xb2, 0xb7, 0x23, 0x13, 0xc5, 0x51, 0x79, 0xe9, 0x88, 0xb8, 0x63, 0xc7,
		0xda, 0x63, 0xdd, 0x47, 0xf5, 0x34, 0x62, 0x7b, 0x12, 0xb1, 0x3d, 0x85, 0xd7, 0x9e, 0xc0, 0xfc,
		0xc5, 0x35, 0xed, 0xb5, 0x7d, 0x55, 0x84, 0xa8, 0x77, 0x3b, 0xe3, 0xdd, 0xe1, 0x8c, 0x28, 0xf7,
		0x45, 0xf6, 0xc5, 0xe3, 0xf8, 0xdc, 0x31, 0x96, 0x34, 0x95, 0x13, 0x4d, 0xe6, 0x2c, 0x93, 0x39,
		0xc5, 0xf1, 0x96, 0x3c, 0x0f, 0x09, 0x8b, 0x2a, 0xa8, 0x15, 0x86, 0x0b, 0x61, 0xca, 0x10, 0x3f,
		0xc6, 0x8e, 0xeb, 0xef, 0x0b, 0xe9, 0x5b, 0xd7, 0xcf, 0xe6, 0x66, 0x23, 0x8e, 0xff, 0x0b, 0xf1,
		0xac, 0xd3, 0xf8, 0xbf, 0xc6, 0xe7, 0xab, 0x7e, 0xa7, 0x75, 0x7d, 0xd5, 0x88, 0xda, 0x5c, 0x3c,
		0xcd, 0x2c, 0xb6, 0x46, 0x46, 0xa1, 0x89, 0x11, 0xec, 0x53, 0x6a, 0xd1, 0x8b, 0x5c, 0xe4, 0x22,
		0x17, 0xb5, 0x68, 0xf6, 0xb1, 0x1e, 0x07, 0x3a, 0xb6, 0x2a, 0x15, 0xda, 0x99, 0x8b, 0x2d, 0x69,
		0xf8, 0xb3, 0x86, 0x63, 0xac, 0x9e, 0x95, 0x71, 0x2b, 0xc7, 0x68, 0xa3, 0x61, 0x4f, 0x46, 0xb3,
		0x97, 0x9b, 0x72, 0xf9, 0xc3, 0xef, 0xa2, 0xe3, 0xa4, 0x1c, 0x29, 0xc1, 0xc9, 0xf5, 0x66, 0x81,
		0x93, 0xc0, 0x49, 0xe0, 0x24, 0x70, 0x32, 0x85, 0x38, 0x49, 0xcc, 0x23, 0x49, 0xf8, 0x23, 0x80,
		0x0c, 0x40, 0x96, 0x5f, 0x20, 0xb3, 0x84, 0x79, 0xe7, 0x8a, 0x3b, 0x0a, 0xf0, 0x8a, 0x11, 0x75,
		0x5f, 0x68, 0x07, 0xd2, 0xe6, 0x62, 0x22, 0x3e, 0xba, 0xce, 0xc4, 0x97, 0xf6, 0xfd, 0x72, 0x6f,
		0x07, 0x7f, 0xbd, 0xc4, 0xdb, 0xa1, 0xb8, 0x93, 0xb6, 0xf4, 0xa5, 0x63, 0x7b, 0xdb, 0xff, 0x29,
		0xf8, 0x97, 0xb9, 0x70, 0xcc, 0x3a, 0x3f, 0xb1, 0x4e, 0x2c, 0x82, 0x56, 0x62, 0x9f, 0x5c, 0x3c,
		0xb7, 0xa4, 0xe0, 0x04, 0x23, 0x68, 0xfc, 0xe5, 0x49, 0x06, 0x51, 0x20, 0xdd, 0xc4, 0x13, 0x6e,
		0x5c, 0xbc, 0x20, 0x0c, 0xd7, 0x78, 0x09, 0x66, 0xce, 0xe2, 0x6d, 0x8d, 0xdb, 0x47, 0x8a, 0xf0,
		0x35, 0x15, 0xa1, 0x19, 0x6b, 0xc0, 0x36, 0x1f, 0xc9, 0x74, 0x9d, 0x22, 0xb3, 0x30, 0x11, 0x62,
		0x4f, 0x8d, 0xc4, 0x43, 0x03, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01, 0x13,
		0x01, 0x13, 0x49, 0x25, 0x13, 0xc9, 0x68, 0x14, 0xcf, 0x8b, 0x90, 0x8c, 0x48, 0xa9, 0x7f, 0xf6,
		0x88, 0xb7, 0xd9, 0x23, 0x4c, 0x22, 0xda, 0xed, 0x9d, 0x58, 0xb7, 0x75, 0x62, 0x1f, 0xd7, 0x97,
		0x70, 0x5c, 0xaf, 0x15, 0x9e, 0x70, 0x5c, 0xbf, 0xff, 0xfa, 0xc1, 0x71, 0x3d, 0x7c, 0x26, 0xf8,
		0x4c, 0x49, 0xf4, 0x99, 0x70, 0x0c, 0x85, 0xe3, 0x7a, 0xe0, 0x24, 0x70, 0x12, 0x38, 0x09, 0x9c,
		0x54, 0x80, 0x93, 0x38, 0xae, 0x07, 0x90, 0x01, 0xc8, 0x92, 0x04, 0x64, 0x10, 0xc9, 0x55, 0xcc,
		0x0f, 0x44, 0xf2, 0x78, 0xab, 0x12, 0x22, 0x39, 0x15, 0xb0, 0xe1, 0xb8, 0x7e, 0xf3, 0x18, 0xe1,
		0xb8, 0x1e, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x84,
		0x88, 0x89, 0xe4, 0xe0, 0xb8, 0x3e, 0x42, 0x1e, 0xa1, 0xfc, 0x64, 0xc7, 0xd8, 0x3f, 0xd5, 0xc4,
		0xc1, 0x2f, 0xf3, 0x91, 0xcc, 0xda, 0x6c, 0x2f, 0x9a, 0xe4, 0xcc, 0xb9, 0xe1, 0xcd, 0xb3, 0x14,
		0x19, 0xce, 0x78, 0x6e, 0xdc, 0x22, 0xa4, 0xdd, 0x78, 0xd5, 0x40, 0x36, 0x32, 0x6f, 0xec, 0x97,
		0x02, 0x30, 0x3b, 0x89, 0x37, 0xf6, 0x4a, 0xc1, 0x87, 0xbc, 0x1b, 0xea, 0xbd, 0x36, 0xaa, 0x40,
		0x9e, 0x68, 0x39, 0x2d, 0xb3, 0x1f, 0xc7, 0x13, 0x29, 0xe7, 0x64, 0x42, 0xc3, 0x78, 0x4c, 0xcb,
		0x72, 0xfe, 0x36, 0x9c, 0xbf, 0x6d, 0xc3, 0xf4, 0xe2, 0x6b, 0x1d, 0x6b, 0xad, 0xc5, 0x3f, 0x8c,
		0x3e, 0x86, 0x5c, 0x42, 0x90, 0x5c, 0x36, 0xbf, 0x6a, 0x49, 0xac, 0xe4, 0xb0, 0x69, 0x15, 0x4b,
		0x26, 0xd2, 0xf6, 0x3f, 0x10, 0x48, 0x25, 0x71, 0xbc, 0x6d, 0x9a, 0x02, 0x46, 0x04, 0x3e, 0x31,
		0x65, 0x41, 0x22, 0xea, 0x14, 0xd7, 0xc4, 0x05, 0x86, 0x54, 0x14, 0x91, 0xa1, 0x28, 0x76, 0x4a,
		0x59, 0x18, 0x48, 0xd5, 0x14, 0x94, 0x2a, 0x95, 0x04, 0x4f, 0x82, 0x26, 0x65, 0xa4, 0x97, 0xe4,
		0xa8, 0x3a, 0xe9, 0x99, 0xb7, 0x96, 0x30, 0xe6, 0x0e, 0xb6, 0xe9, 0x19, 0x77, 0xd2, 0xf2, 0x85,
		0x4b, 0x10, 0x56, 0xb7, 0xb9, 0xdd, 0xf8, 0x54, 0x26, 0x4e, 0xae, 0x7d, 0xd0, 0x19, 0xd0, 0x99,
		0xdc, 0xd2, 0x99, 0xf8, 0xb9, 0xea, 0x63, 0xe6, 0xa6, 0xe7, 0x01, 0x34, 0x57, 0x8c, 0x2d, 0x73,
		0x10, 0x00, 0x4f, 0x7c, 0x24, 0x7b, 0xdd, 0x20, 0x20, 0x0c, 0x10, 0x06, 0x08, 0x03, 0x84, 0x25,
		0x41, 0xad, 0xd2, 0x77, 0x5a, 0xb5, 0x7e, 0xf0, 0x80, 0xfb, 0xa5, 0x69, 0xbc, 0x5f, 0x0a, 0x59,
		0x9a, 0x10, 0x5b, 0x21, 0x4b, 0xef, 0x4f, 0x84, 0x20, 0x4b, 0x83, 0x04, 0x81, 0x04, 0xed, 0xb9,
		0x5e, 0x20, 0x4b, 0xbf, 0xd4, 0x44, 0x21, 0x4b, 0xc7, 0xd2, 0x34, 0x21, 0x4b, 0x27, 0x60, 0x12,
		0x20, 0x4b, 0x87, 0x86, 0x19, 0xb2, 0x34, 0xe8, 0x0c, 0xe8, 0x0c, 0x34, 0x9d, 0x64, 0x6a, 0x3a,
		0x90, 0xa5, 0x01, 0x61, 0x80, 0x30, 0x40, 0x18, 0x64, 0xe9, 0x2d, 0x8b, 0x22, 0x29, 0xb2, 0x34,
		0xee, 0x51, 0xec, 0x3c, 0x56, 0x64, 0x57, 0x29, 0xbc, 0xb6, 0xe9, 0x7f, 0x6f, 0x2d, 0x1b, 0x65,
		0xbc, 0x4c, 0xb1, 0x67, 0x44, 0x7a, 0xb4, 0x48, 0x74, 0x5c, 0x9d, 0x38, 0xc0, 0xd5, 0x89, 0x57,
		0x0c, 0x6a, 0xdf, 0xab, 0x13, 0xe6, 0xc4, 0xff, 0x6e, 0x8c, 0x4d, 0xcf, 0x5b, 0x0e, 0x61, 0xc4,
		0x93, 0xaa, 0xf5, 0x66, 0xa2, 0x9d, 0x58, 0x1d, 0xe3, 0x22, 0x05, 0x27, 0x0d, 0xcb, 0xd3, 0x89,
		0x55, 0x64, 0x7a, 0xf5, 0xec, 0xe1, 0xac, 0x2e, 0x85, 0x47, 0x5b, 0xe3, 0x6b, 0x70, 0xfd, 0x21,
		0x01, 0x27, 0xd3, 0x43, 0xe1, 0x0d, 0x5c, 0x39, 0x8e, 0x44, 0x8b, 0x5e, 0x24, 0x45, 0x7b, 0x6e,
		0x04, 0x7b, 0x1e, 0x7b, 0x3e, 0x63, 0x7b, 0xde, 0xf3, 0x5d, 0x69, 0xdf, 0xa7, 0x7d, 0xa7, 0x5b,
		0xce, 0xc0, 0xb4, 0xa2, 0xa8, 0x3c, 0xcf, 0x89, 0x3a, 0x56, 0x2d, 0x60, 0x8f, 0x63, 0x8f, 0x67,
		0x6c, 0x8f, 0x9b, 0x9e, 0x61, 0x4f, 0x46, 0xb7, 0x91, 0x8e, 0x5d, 0x56, 0x0b, 0x3c, 0x42, 0xf6,
		0x99, 0x98, 0x87, 0xd6, 0xf1, 0x32, 0xbb, 0x10, 0x48, 0x81, 0x24, 0x27, 0xa3, 0x54, 0x87, 0xd2,
		0x94, 0xe7, 0xa0, 0xd3, 0x78, 0xa9, 0x6e, 0x12, 0x37, 0xb4, 0xe5, 0xd2, 0x69, 0xf9, 0xb4, 0x5a,
		0x2b, 0x9d, 0x56, 0x12, 0x34, 0xc6, 0x4c, 0xba, 0x62, 0x2f, 0x01, 0xd6, 0x37, 0xea, 0x11, 0x4b,
		0x00, 0x50, 0xd1, 0x8e, 0x54, 0x60, 0x7b, 0x61, 0x7b, 0x61, 0x7b, 0x61, 0x7b, 0x61, 0x7b, 0x61,
		0x7b, 0xf3, 0x6d, 0x7b, 0xe7, 0xe7, 0x4b, 0xc6, 0xf2, 0x78, 0x28, 0x8e, 0x0d, 0x7e, 0xd1, 0x10,
		0x6c, 0x31, 0x6c, 0x31, 0xb4, 0xae, 0x04, 0x6a, 0x5d, 0xf3, 0x8d, 0xea, 0x47, 0x19, 0x8c, 0xf5,
		0xbd, 0x1e, 0xa1, 0xbc, 0x07, 0x76, 0x39, 0x76, 0x79, 0xe2, 0x77, 0x79, 0xd4, 0xc5, 0x7d, 0x10,
		0xb3, 0x66, 0x4d, 0xc4, 0x5a, 0x35, 0x6a, 0x40, 0xc2, 0x15, 0x23, 0xe7, 0x41, 0x18, 0x63, 0x57,
		0x3e, 0x98, 0xbe, 0x88, 0xe5, 0x9c, 0x87, 0x9b, 0x02, 0x68, 0x00, 0x34, 0x32, 0x06, 0x1a, 0xa1,
		0x45, 0xbe, 0x8c, 0xd2, 0x8a, 0x83, 0x21, 0x11, 0x3c, 0xa2, 0x42, 0x73, 0x28, 0x6c, 0x5f, 0xfa,
		0x8f, 0x9f, 0x4c, 0x4f, 0xc4, 0x0f, 0x59, 0xee, 0x34, 0x2e, 0x5a, 0xdf, 0x1a, 0xfd, 0x76, 0xa7,
		0xf9, 0xad, 0x7e, 0xd5, 0xe8, 0xd7, 0xbb, 0xfd, 0x56, 0xfb, 0xaa, 0xd9, 0xba, 0x8c, 0xba, 0xa4,
		0xe6, 0x4e, 0x9f, 0x17, 0xeb, 0x1a, 0x1a, 0x51, 0x06, 0xf3, 0x17, 0xaf, 0xb4, 0x7c, 0xc9, 0xfa,
		0xf9, 0x79, 0x41, 0x87, 0x57, 0xae, 0xe2, 0x85, 0xda, 0xe7, 0xf5, 0xcf, 0x71, 0xdf, 0x28, 0xd2,
		0x37, 0x7b, 0xaa, 0x37, 0xb6, 0x1a, 0x63, 0xe7, 0x4c, 0x7c, 0x61, 0xdc, 0x59, 0xe6, 0xd8, 0x18,
		0x9a, 0xa3, 0xf1, 0x8c, 0xe3, 0x47, 0xb7, 0x76, 0xe1, 0xb6, 0xf6, 0xbd, 0x39, 0x1e, 0x2f, 0xc0,
		0x1f, 0xe6, 0x12, 0xe6, 0x32, 0xf1, 0xe6, 0x32, 0x7a, 0x00, 0x7e, 0xc4, 0xc0, 0x7b, 0x45, 0xa9,
		0x4b, 0x84, 0x3d, 0x34, 0x06, 0xce, 0x68, 0x34, 0xb1, 0xa5, 0xff, 0x18, 0x23, 0x87, 0xc9, 0x7a,
		0x3b, 0xd1, 0x01, 0xe3, 0xb2, 0x75, 0xd9, 0x00, 0x5e, 0x00, 0x2f, 0xb2, 0x86, 0x17, 0xc1, 0xde,
		0xc8, 0xa6, 0x63, 0x9e, 0xee, 0x7b, 0x29, 0xfb, 0xa4, 0x92, 0xa2, 0xb9, 0x39, 0x22, 0x6e, 0xef,
		0xc7, 0xc6, 0x68, 0x62, 0xf9, 0xf2, 0xbb, 0x33, 0xde, 0xff, 0x02, 0xc9, 0xfa, 0xd7, 0x71, 0x8f,
		0x84, 0x11, 0xfe, 0x50, 0x82, 0x03, 0x25, 0x38, 0x60, 0xdf, 0x33, 0x66, 0xdf, 0x23, 0xe7, 0x3a,
		0x13, 0xb6, 0x79, 0x6b, 0x89, 0x21, 0x41, 0xcd, 0xf3, 0x65, 0x43, 0xb8, 0x53, 0x8f, 0x3b, 0xf5,
		0x7c, 0x5b, 0x93, 0x74, 0x8b, 0xc6, 0x13, 0xde, 0x70, 0xa7, 0x9e, 0x29, 0x2d, 0xc8, 0x8a, 0x36,
		0x1a, 0xbe, 0x6f, 0xc5, 0xc7, 0xad, 0xb5, 0xd6, 0x00, 0x3a, 0x00, 0x1d, 0x80, 0xce, 0x5e, 0xeb,
		0x05, 0xa9, 0x15, 0x5f, 0x3c, 0x08, 0x52, 0x2b, 0xc6, 0xfa, 0x85, 0xd4, 0x8a, 0x49, 0x98, 0x84,
		0xac, 0xa7, 0x56, 0xcc, 0x66, 0x1a, 0x9f, 0x35, 0x45, 0x0d, 0xb9, 0xe5, 0x91, 0x5b, 0x1e, 0x7a,
		0x0b, 0xf4, 0x16, 0xe8, 0x2d, 0x70, 0x7d, 0xe0, 0xfa, 0x40, 0x6f, 0x81, 0xde, 0x02, 0xd0, 0x01,
		0xe8, 0x40, 0x6f, 0x81, 0xde, 0x02, 0xbd, 0x05, 0x7a, 0x0b, 0xf4, 0x16, 0xe8, 0x2d, 0xc4, 0x7a,
		0x0b, 0x92, 0x26, 0xef, 0x38, 0x52, 0x54, 0x29, 0x93, 0x1b, 0xb7, 0xf7, 0xe3, 0x8b, 0x55, 0x9b,
		0x9c, 0x71, 0x6f, 0xae, 0xeb, 0xb8, 0xc6, 0x77, 0xd3, 0x1e, 0x5a, 0xfb, 0x5c, 0x52, 0x78, 0x76,
		0xdb, 0xd7, 0xbf, 0x8f, 0xc8, 0x37, 0x46, 0x82, 0x8a, 0xc8, 0x37, 0x44, 0xbe, 0x41, 0x89, 0x85,
		0x12, 0xbb, 0xf8, 0xa2, 0xef, 0x0a, 0xd3, 0x37, 0x4c, 0xcf, 0xf8, 0x5b, 0xfa, 0xdf, 0x87, 0xae,
		0xf9, 0x77, 0x7c, 0x6d, 0x23, 0xdc, 0x24, 0xd4, 0x59, 0x08, 0x25, 0x10, 0x4a, 0xa0, 0xce, 0xe6,
		0xdb, 0x55, 0x5a, 0xe3, 0xbc, 0x38, 0x9b, 0xc6, 0xd9, 0x34, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11,
		0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0xd4, 0xe3, 0x9d, 0x87, 0x8a, 0x4c, 0x3e, 0x9e,
		0xb5, 0xfa, 0xdb, 0xaa, 0x51, 0x46, 0xfd, 0xf8, 0xde, 0x35, 0x07, 0xe2, 0x6e, 0x62, 0x19, 0xae,
		0xf0, 0x7c, 0xd3, 0xf5, 0xf7, 0x57, 0x90, 0x43, 0x2d, 0x40, 0x43, 0x86, 0x86, 0x0c, 0x0d, 0x19,
		0x1a, 0x32, 0x3c, 0x26, 0x76, 0x8f, 0x29, 0x29, 0xd1, 0xbc, 0xf0, 0x6a, 0xe0, 0xd5, 0xc0, 0xab,
		0x49, 0x8f, 0x57, 0x13, 0xc1, 0x2e, 0x7c, 0x17, 0xd6, 0x58, 0xb8, 0x86, 0x63, 0x5b, 0x8f, 0xf1,
		0xe1, 0xe6, 0x65, 0x63, 0x80, 0x1c, 0x40, 0x0e, 0x20, 0x07, 0x90, 0x13, 0x7e, 0xc6, 0xa5, 0x83,
		0x69, 0xf8, 0x72, 0x44, 0x90, 0xc9, 0x78, 0xad, 0x35, 0x80, 0x0e, 0x40, 0x07, 0xa0, 0xb3, 0xd7,
		0x7a, 0x99, 0x48, 0xdb, 0x2f, 0x56, 0x09, 0x30, 0xa7, 0x8a, 0xc8, 0x7f, 0x52, 0x58, 0x09, 0x35,
		0x87, 0xc8, 0xff, 0xc4, 0x4c, 0x41, 0xf9, 0xf8, 0xb4, 0x8a, 0xd0, 0xff, 0xd7, 0xbf, 0x7a, 0x09,
		0x26, 0x1d, 0x9e, 0x6f, 0x5a, 0xc2, 0x98, 0xe7, 0x70, 0xf7, 0x88, 0x98, 0x47, 0xb8, 0x49, 0xd0,
		0x0f, 0xd0, 0x0f, 0xd0, 0x8f, 0xbd, 0xd6, 0xcb, 0x50, 0x0c, 0xe4, 0xc8, 0xb4, 0xaa, 0x65, 0x0a,
		0xaf, 0xa7, 0x14, 0xa3, 0x8d, 0x10, 0x0e, 0x97, 0xc0, 0x67, 0x36, 0x0f, 0x73, 0x09, 0x7c, 0x46,
		0x37, 0x9f, 0x39, 0xc9, 0xd1, 0x14, 0xe0, 0x1e, 0x63, 0xf4, 0x05, 0xa9, 0x2f, 0x14, 0xe5, 0x75,
		0x38, 0x01, 0xc2, 0x73, 0x11, 0x9e, 0xcb, 0x4e, 0xdd, 0x70, 0xd8, 0xbc, 0xc3, 0x17, 0x71, 0xd8,
		0x0c, 0x2f, 0x08, 0x5e, 0x90, 0x5e, 0x2f, 0x08, 0x87, 0xcd, 0xfb, 0x8f, 0x19, 0x0e, 0x9b, 0x01,
		0x39, 0x80, 0x1c, 0x40, 0xce, 0x3f, 0x3f, 0x23, 0x0e, 0x9b, 0x01, 0x3a, 0x00, 0x9d, 0xa4, 0x80,
		0x0e, 0x0e, 0x9b, 0xd7, 0x94, 0x41, 0x1c, 0x36, 0xc7, 0xd2, 0xf6, 0x70, 0xd8, 0x9c, 0x84, 0x59,
		0xc0, 0x61, 0xf3, 0x26, 0x85, 0x11, 0x87, 0xcd, 0xa0, 0x1f, 0xa0, 0x1f, 0x09, 0xa3, 0x1f, 0x38,
		0x6c, 0x4e, 0x1d, 0x9f, 0xc1, 0x61, 0xb3, 0x76, 0x3e, 0x83, 0xc3, 0xe6, 0xec, 0x90, 0x99, 0x9c,
		0x1c, 0x36, 0x23, 0xf3, 0xc1, 0xee, 0x83, 0x45, 0x95, 0xfb, 0xe0, 0xeb, 0xb2, 0xdd, 0xce, 0xb2,
		0x59, 0xc6, 0xec, 0x07, 0x96, 0x73, 0x7f, 0x2f, 0xed, 0x7b, 0xc3, 0x19, 0xcf, 0xc6, 0xd1, 0xdb,
		0x3f, 0xf9, 0xc1, 0xeb, 0x06, 0x90, 0xfb, 0x80, 0x91, 0xfb, 0x22, 0xf7, 0x01, 0x72, 0x1f, 0xa8,
		0x74, 0xf6, 0x10, 0x8e, 0xa2, 0x81, 0x0b, 0x44, 0x0e, 0x47, 0xb1, 0x9c, 0x7b, 0xc3, 0x16, 0xf2,
		0xfe, 0xfb, 0xad, 0xe3, 0x1a, 0x73, 0x3b, 0x6e, 0x0c, 0xbe, 0xcf, 0x3c, 0x1c, 0x2f, 0xbe, 0x88,
		0xf2, 0x0f, 0x6d, 0xc7, 0xcf, 0x1f, 0x37, 0x9b, 0x4e, 0x88, 0x32, 0x10, 0x65, 0x20, 0xca, 0xec,
		0xb7, 0x5e, 0x90, 0x3e, 0x2e, 0x29, 0x6e, 0xd4, 0x2b, 0x16, 0x8c, 0x90, 0x5d, 0x84, 0xec, 0x82,
		0x23, 0x81, 0x23, 0x81, 0x23, 0x81, 0x23, 0x81, 0x23, 0x81, 0x23, 0x81, 0x23, 0x6d, 0xe0, 0x48,
		0x50, 0x9a, 0x77, 0x1e, 0x2b, 0x2a, 0xa1, 0xf9, 0x7c, 0xd1, 0x6c, 0x6b, 0xd9, 0x2a, 0xa3, 0xce,
		0xfc, 0xfc, 0x6e, 0xc6, 0xf2, 0xd1, 0xf6, 0xd4, 0x99, 0x5f, 0x37, 0xb0, 0x9f, 0xce, 0x7c, 0x0c,
		0x9d, 0x19, 0x3a, 0x73, 0x44, 0xd3, 0xf2, 0xcc, 0xef, 0x84, 0x79, 0xe7, 0x8a, 0xbb, 0x7d, 0x26,
		0x6c, 0x65, 0x3a, 0x6a, 0x7b, 0x7c, 0xa7, 0xbd, 0x84, 0x8b, 0xf7, 0xef, 0x17, 0x10, 0x79, 0xf4,
		0x7a, 0xe9, 0x33, 0x6e, 0xdb, 0x79, 0xd4, 0x94, 0xe1, 0x8a, 0x3b, 0x4b, 0x0c, 0x7c, 0xc7, 0xdd,
		0x7f, 0xdb, 0xbe, 0x6e, 0x00, 0xc7, 0x43, 0xd8, 0xb6, 0x91, 0xb6, 0x2d, 0x8e, 0x87, 0x20, 0x7d,
		0x40, 0xfa, 0x88, 0x23, 0x7d, 0xbc, 0x82, 0x62, 0x63, 0x60, 0xc9, 0xc5, 0x8b, 0xc6, 0xbd, 0xd9,
		0xb3, 0xb9, 0x5d, 0x94, 0x15, 0x82, 0xe6, 0x01, 0xcd, 0x03, 0x9a, 0x87, 0xb2, 0x41, 0xdb, 0x00,
		0x3c, 0x13, 0xcf, 0x17, 0xae, 0x21, 0x87, 0x2a, 0x40, 0x2d, 0x68, 0x1b, 0x80, 0x04, 0x40, 0x02,
		0x20, 0xed, 0xb7, 0x9b, 0x5e, 0x6e, 0x20, 0xc3, 0x9f, 0xb5, 0x4b, 0x80, 0x4d, 0xa7, 0x31, 0xda,
		0x58, 0xbe, 0x9b, 0xf6, 0xc0, 0xff, 0x97, 0xd7, 0x3b, 0x4f, 0x4a, 0x05, 0x82, 0x38, 0xf6, 0xe5,
		0xe8, 0xd4, 0x08, 0x9a, 0xa2, 0xb9, 0x1e, 0x41, 0x37, 0x5a, 0xc1, 0x83, 0x51, 0x5e, 0x97, 0x20,
		0x02, 0xe8, 0xad, 0xcd, 0x12, 0xc7, 0xee, 0x07, 0xed, 0x2a, 0x88, 0xe1, 0x8f, 0x09, 0x18, 0x9b,
		0xa7, 0x8a, 0xf0, 0x5a, 0x05, 0xd7, 0x54, 0x95, 0x4b, 0xa7, 0xe5, 0xd3, 0x6a, 0xad, 0x74, 0x5a,
		0x49, 0xd1, 0x9c, 0xbd, 0x49, 0x46, 0x2b, 0xbd, 0x37, 0x1a, 0x57, 0x1e, 0x21, 0x20, 0xcb, 0xf1,
		0x43, 0xd9, 0x30, 0x87, 0x43, 0x57, 0x78, 0x1e, 0x21, 0x2c, 0x17, 0x3f, 0x10, 0xb4, 0xd5, 0x36,
		0x7d, 0x5f, 0xb8, 0x36, 0x19, 0x32, 0x17, 0xfe, 0x7c, 0xfb, 0xf6, 0xe6, 0xd8, 0x38, 0xed, 0x3d,
		0xdd, 0x14, 0x8d, 0xd3, 0xde, 0xe2, 0x63, 0x71, 0xfe, 0xc7, 0xe2, 0x73, 0xe9, 0xe6, 0xd8, 0x28,
		0xaf, 0x3e, 0x57, 0x6e, 0x8e, 0x8d, 0x4a, 0xef, 0xf0, 0x8f, 0x3f, 0xde, 0x1f, 0xfe, 0x3c, 0x99,
		0xee, 0xff, 0xc5, 0x7f, 0x15, 0xe2, 0x2f, 0x32, 0x8a, 0x41, 0x6c, 0x75, 0x9b, 0xbf, 0x63, 0x24,
		0x71, 0x6d, 0x2b, 0x86, 0x16, 0xa7, 0xed, 0x2c, 0xfd, 0x95, 0x7b, 0x8a, 0x78, 0x43, 0xc4, 0x1b,
		0xb2, 0xbb, 0xcc, 0x10, 0xdd, 0x23, 0x69, 0x54, 0x10, 0xdd, 0xa1, 0x71, 0x41, 0xe3, 0xca, 0x9e,
		0xc6, 0x05, 0xd1, 0x1d, 0xa2, 0x3b, 0x00, 0x09, 0x80, 0x94, 0x18, 0x40, 0x82, 0xe8, 0xfe, 0xab,
		0x11, 0x82, 0xe8, 0xbe, 0xcf, 0x83, 0x41, 0x74, 0x87, 0xe8, 0x0e, 0xd1, 0x9d, 0x48, 0xff, 0xa2,
		0x6d, 0x05, 0xa2, 0xfb, 0x3f, 0x1b, 0x2d, 0x88, 0xee, 0x10, 0xdd, 0x21, 0xba, 0x43, 0x74, 0x3f,
		0x20, 0x15, 0xdd, 0x71, 0x81, 0x6d, 0xe7, 0xb1, 0xa2, 0xba, 0xc0, 0xd6, 0x99, 0x35, 0xdb, 0x09,
		0x5a, 0x65, 0xbc, 0x09, 0xb3, 0xdf, 0xb9, 0x46, 0xa4, 0xf3, 0x8c, 0xc8, 0xb7, 0x5e, 0x4a, 0xb8,
		0xf5, 0x42, 0xa9, 0x26, 0xa4, 0xf9, 0xd6, 0x8b, 0x39, 0xf1, 0xbf, 0x1b, 0x63, 0xd3, 0xf3, 0x96,
		0x43, 0x18, 0xf1, 0x18, 0x6e, 0xbd, 0x99, 0x68, 0xc7, 0x71, 0xc7, 0xb8, 0x03, 0xc3, 0x29, 0xa6,
		0xe5, 0xe9, 0x38, 0x2e, 0xb2, 0x48, 0xb6, 0x26, 0x35, 0x4b, 0xfb, 0x3e, 0xea, 0x1a, 0x5f, 0xf7,
		0x2e, 0x12, 0x70, 0xec, 0x3e, 0x14, 0xde, 0xc0, 0x95, 0xe3, 0x48, 0xac, 0xe8, 0x45, 0x92, 0xef,
		0xe7, 0x46, 0xb0, 0xe7, 0xb1, 0xe7, 0x33, 0xb6, 0xe7, 0x3d, 0xdf, 0x95, 0xf6, 0x7d, 0xda, 0x77,
		0xba, 0xe5, 0x0c, 0x4c, 0xcb, 0x30, 0xbd, 0xe8, 0xdb, 0x3c, 0x68, 0x01, 0x7b, 0x1c, 0x7b, 0x3c,
		0x63, 0x7b, 0xdc, 0xf4, 0x0c, 0x7b, 0x32, 0xba, 0x15, 0x6e, 0x8c, 0x6d, 0x1e, 0xe1, 0x14, 0x27,
		0xe6, 0xa9, 0x4d, 0x8c, 0xd3, 0x3e, 0x8a, 0x53, 0x19, 0x22, 0x69, 0x9f, 0xea, 0xd4, 0x85, 0x52,
		0xb1, 0x8f, 0xa1, 0x6d, 0x93, 0x9c, 0xa2, 0x50, 0x0f, 0x2d, 0xd5, 0x29, 0x09, 0xe9, 0x18, 0x33,
		0xc9, 0x8a, 0xbd, 0x04, 0x58, 0xdf, 0xb9, 0xc4, 0x15, 0xc7, 0xf8, 0xae, 0x1a, 0x80, 0xed, 0x85,
		0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0xdd, 0xdd, 0xf6, 0x46, 0xc8,
		0x21, 0xb8, 0xd9, 0x06, 0xef, 0x9d, 0x4b, 0x10, 0xb6, 0x18, 0xb6, 0x18, 0x5a, 0x17, 0xff, 0x8e,
		0xf7, 0xa3, 0x0c, 0xc6, 0xfa, 0x5e, 0x8f, 0x10, 0xfc, 0x8a, 0x5d, 0x8e, 0x5d, 0x9e, 0xf8, 0x5d,
		0x1e, 0x75, 0x71, 0xaf, 0x6d, 0xf4, 0x72, 0x84, 0xef, 0x36, 0xec, 0xc9, 0x68, 0xf6, 0xe8, 0xd3,
		0x04, 0x80, 0x84, 0x2b, 0x46, 0xce, 0x83, 0x30, 0xc6, 0xae, 0x7c, 0x30, 0x7d, 0x11, 0xcb, 0x39,
		0x0f, 0x37, 0x05, 0xd0, 0x00, 0x68, 0x64, 0x0c, 0x34, 0x42, 0x8b, 0x7c, 0x99, 0x65, 0x3c, 0x0e,
		0x86, 0x44, 0xf0, 0x88, 0x0a, 0xcd, 0xa1, 0xb0, 0x7d, 0xe9, 0x3f, 0x7e, 0x32, 0x3d, 0x82, 0x2a,
		0xef, 0x9d, 0xc6, 0x45, 0xeb, 0x5b, 0xa3, 0xdf, 0xee, 0x34, 0xbf, 0xd5, 0xaf, 0x1a, 0xfd, 0x7a,
		0xb7, 0xdf, 0x6a, 0x5f, 0x35, 0x5b, 0x97, 0x51, 0x97, 0xd4, 0xdc, 0xe9, 0xf3, 0x62, 0xc5, 0xa8,
		0xc6, 0xf4, 0x5e, 0x57, 0x6f, 0xf6, 0xe2, 0x95, 0x96, 0x2f, 0x59, 0x3f, 0x3f, 0x2f, 0xe8, 0xf0,
		0xca, 0x55, 0xbc, 0x50, 0xfb, 0xbc, 0xfe, 0x39, 0xee, 0x1b, 0x45, 0xfa, 0x66, 0x4f, 0xf5, 0xc6,
		0x56, 0x63, 0xec, 0xe6, 0x71, 0x95, 0x77, 0x96, 0x39, 0x36, 0x86, 0xe6, 0x68, 0x3c, 0xe3, 0xf8,
		0xd1, 0xad, 0x5d, 0xb8, 0xad, 0x7d, 0xaf, 0xc5, 0xc7, 0xbb, 0x37, 0x0e, 0x73, 0x09, 0x73, 0x99,
		0x78, 0x73, 0x19, 0xfd, 0x5e, 0x77, 0xc4, 0xfb, 0xdc, 0x8a, 0xf2, 0xb2, 0x08, 0x7b, 0x68, 0x0c,
		0x9c, 0xd1, 0x68, 0x62, 0x4b, 0xff, 0x31, 0x46, 0x82, 0x96, 0xf5, 0x76, 0xa2, 0x03, 0xc6, 0x65,
		0xeb, 0xb2, 0x01, 0xbc, 0x00, 0x5e, 0x64, 0x0d, 0x2f, 0x82, 0xbd, 0x91, 0x7b, 0xc7, 0xdc, 0x77,
		0x7c, 0xd3, 0x32, 0xc6, 0xa6, 0xff, 0x3d, 0x86, 0x4b, 0xfe, 0xb2, 0x11, 0xa0, 0x05, 0xd0, 0x22,
		0x63, 0x68, 0x11, 0x39, 0x05, 0x01, 0x0e, 0xcc, 0x71, 0x60, 0xbe, 0x36, 0xb4, 0x38, 0x30, 0x57,
		0x28, 0x16, 0xa4, 0xf3, 0xc0, 0x7c, 0x69, 0x3b, 0xe7, 0x68, 0x2e, 0xe2, 0xdb, 0xe0, 0x55, 0x3b,
		0x30, 0xc3, 0x30, 0xc3, 0x30, 0xc3, 0x30, 0xc3, 0x30, 0xc3, 0x30, 0xc3, 0xb9, 0x35, 0xc3, 0xe9,
		0x4e, 0xcf, 0xb0, 0x47, 0xea, 0x0a, 0x9a, 0xf4, 0x09, 0xbe, 0x1c, 0x09, 0xd7, 0xdb, 0x3f, 0x7f,
		0xc2, 0xf2, 0x7b, 0x28, 0x1b, 0xca, 0x48, 0x21, 0x50, 0x36, 0x14, 0x65, 0x43, 0xc1, 0x91, 0x33,
		0xc6, 0x91, 0x23, 0x67, 0x30, 0x1f, 0x38, 0xb6, 0x2d, 0x06, 0xbe, 0xe1, 0x0a, 0xdf, 0x7d, 0x8c,
		0x1f, 0xa7, 0xb1, 0xde, 0x5c, 0xfc, 0x7c, 0xe5, 0x27, 0xc7, 0xc8, 0x0d, 0x8c, 0xdc, 0xc0, 0xdc,
		0x7b, 0x35, 0x26, 0x8d, 0xd5, 0x9e, 0x1b, 0x78, 0x28, 0x06, 0x72, 0x64, 0x5a, 0xd5, 0x32, 0x45,
		0x4a, 0xe0, 0x52, 0x8c, 0x36, 0x42, 0x2e, 0x45, 0x9c, 0xc6, 0x68, 0x52, 0xe7, 0x12, 0xe4, 0xb3,
		0xa4, 0x4c, 0x95, 0xbb, 0x1a, 0xe6, 0x12, 0x4d, 0x5a, 0x54, 0xea, 0xd4, 0xb8, 0x2a, 0xd2, 0xab,
		0x12, 0xa4, 0xc2, 0x25, 0x4d, 0x81, 0xbb, 0x9a, 0x82, 0x93, 0x1c, 0x4d, 0x41, 0xd6, 0x53, 0x54,
		0x46, 0xa0, 0xad, 0xdf, 0x1d, 0x6b, 0x68, 0xcc, 0x1c, 0xd2, 0xf8, 0x2c, 0xe8, 0xb9, 0xa9, 0xf8,
		0x0c, 0xe8, 0x14, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c, 0x08, 0x0c,
		0x08, 0x0c, 0x48, 0x1d, 0x03, 0xfa, 0x4b, 0x88, 0xb1, 0x69, 0xc9, 0x07, 0x61, 0x48, 0xdb, 0x17,
		0xee, 0x83, 0x69, 0xc5, 0xa7, 0x42, 0x1b, 0xda, 0x84, 0x2a, 0x04, 0x4e, 0x04, 0x4e, 0x04, 0x4e,
		0x04, 0x4e, 0x04, 0x4e, 0x04, 0x4e, 0x04, 0x4e, 0x94, 0x68, 0x4e, 0x34, 0x92, 0xb6, 0x1c, 0x4d,
		0x46, 0x86, 0x39, 0x7c, 0x10, 0xae, 0x2f, 0x3d, 0x31, 0xb3, 0x22, 0x84, 0xfc, 0xe8, 0x17, 0xed,
		0x83, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81, 0x2b,
		0xa1, 0xc8, 0xdb, 0x41, 0xac, 0xc8, 0xd8, 0x45, 0xc0, 0xe9, 0xd1, 0x32, 0x8c, 0x2f, 0x09, 0x17,
		0xf7, 0xf7, 0x2a, 0x3c, 0x16, 0xb2, 0x53, 0xfb, 0x14, 0x20, 0x0b, 0xd9, 0xa5, 0xa8, 0xe1, 0x88,
		0x25, 0x84, 0x23, 0xea, 0x24, 0x6a, 0x08, 0x47, 0xdc, 0x79, 0xd5, 0x20, 0x1c, 0x11, 0xce, 0x14,
		0x9c, 0x29, 0x38, 0x53, 0x70, 0xa6, 0xe0, 0x4c, 0xc1, 0x99, 0x82, 0x33, 0xa5, 0xcb, 0x99, 0x42,
		0x38, 0x22, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10,
		0x18, 0xd0, 0x0e, 0xc3, 0x8c, 0x70, 0x44, 0x70, 0x22, 0x70, 0x22, 0x70, 0x22, 0x70, 0x22, 0x70,
		0x22, 0x70, 0x22, 0x70, 0x22, 0x70, 0x22, 0x84, 0x23, 0x82, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81,
		0x2b, 0x81, 0x2b, 0x81, 0x2b, 0x81, 0x2b, 0xe5, 0x88, 0x2b, 0x65, 0x3a, 0x1c, 0x71, 0x8f, 0x7c,
		0x9d, 0xfb, 0x0f, 0x48, 0xca, 0x73, 0x99, 0xee, 0x95, 0x22, 0x74, 0xd1, 0x95, 0xef, 0x4e, 0x06,
		0xfe, 0xb2, 0x86, 0x78, 0xe1, 0xd3, 0xfd, 0xb8, 0xdf, 0x16, 0xc2, 0xfd, 0x3a, 0x6b, 0xad, 0x7f,
		0xb5, 0x68, 0x8d, 0x33, 0x35, 0xaa, 0x6b, 0xda, 0xde, 0xd8, 0x71, 0xfd, 0x08, 0xd9, 0x51, 0x83,
		0xaf, 0x22, 0x41, 0x2a, 0x23, 0xa5, 0x45, 0x82, 0x54, 0x24, 0x48, 0x55, 0xe9, 0xc3, 0x21, 0x22,
		0x59, 0x83, 0x89, 0x8f, 0x1c, 0x91, 0x6c, 0x39, 0x03, 0xd3, 0x32, 0xcc, 0xe1, 0xd0, 0x15, 0x9e,
		0x17, 0x5f, 0x60, 0x59, 0x6f, 0x0e, 0x52, 0x08, 0xa4, 0x10, 0x48, 0x21, 0x7b, 0xad, 0x97, 0x89,
		0x1d, 0xad, 0x98, 0x75, 0xc8, 0xd6, 0x9c, 0xc6, 0x68, 0x63, 0xf9, 0x3a, 0xda, 0x85, 0x8b, 0xd5,
		0xa0, 0xc8, 0x71, 0x4c, 0x48, 0xa1, 0x1e, 0x21, 0xda, 0x91, 0xa2, 0x1b, 0xb1, 0x0d, 0x23, 0xf7,
		0x50, 0x26, 0x1c, 0xbb, 0xd0, 0x18, 0x7e, 0x20, 0x6c, 0xb3, 0x6d, 0xfa, 0xbe, 0x70, 0x6d, 0xb2,
		0xe1, 0x0c, 0x1a, 0xfe, 0xf3, 0xed, 0xdb, 0x9b, 0x63, 0xe3, 0xb4, 0xf7, 0x74, 0x53, 0x34, 0x4e,
		0x7b, 0x8b, 0x8f, 0xc5, 0xf9, 0x1f, 0x8b, 0xcf, 0xa5, 0x9b, 0x63, 0xa3, 0xbc, 0xfa, 0x5c, 0xb9,
		0x39, 0x36, 0x2a, 0xbd, 0xc3, 0x3f, 0xfe, 0x78, 0x7f, 0xf8, 0xf3, 0x64, 0xba, 0xff, 0x17, 0xff,
		0x55, 0x20, 0x7b, 0xf8, 0x1e, 0xe5, 0xe0, 0xb6, 0xba, 0xcd, 0xdf, 0x31, 0xc2, 0x24, 0xfa, 0x8e,
		0x02, 0x81, 0x50, 0xdd, 0xf6, 0xaf, 0x62, 0xfb, 0x2f, 0x16, 0xa7, 0x69, 0xdc, 0xd5, 0x8d, 0x2f,
		0xbd, 0x9f, 0xc5, 0x77, 0xe5, 0xe9, 0xc7, 0xc3, 0x9f, 0xb5, 0xe9, 0xeb, 0xbf, 0x7c, 0xda, 0xf4,
		0x63, 0xc5, 0x77, 0xb5, 0xe9, 0xc7, 0x2d, 0xff, 0x52, 0x9d, 0x7e, 0xdc, 0xb1, 0x8d, 0xca, 0xf4,
		0x6d, 0xe8, 0x47, 0x67, 0x7f, 0x5f, 0xda, 0xf6, 0x85, 0xf2, 0x96, 0x2f, 0x9c, 0x6c, 0xfb, 0xc2,
		0xc9, 0x96, 0x2f, 0x6c, 0x7d, 0xa4, 0xd2, 0x96, 0x2f, 0x54, 0xa6, 0x4f, 0xa1, 0x9f, 0x7f, 0xbb,
		0xf9, 0x47, 0xab, 0xd3, 0xc3, 0xa7, 0x6d, 0xff, 0x56, 0x9b, 0x3e, 0x7d, 0x3c, 0xcc, 0x35, 0x18,
		0x62, 0xbd, 0xa5, 0x7b, 0xbd, 0xd1, 0x98, 0x86, 0x37, 0x7a, 0x9f, 0x23, 0xa6, 0x69, 0x22, 0xe4,
		0xf0, 0x9e, 0xef, 0x4a, 0xfb, 0x9e, 0x92, 0xbf, 0x7f, 0x40, 0x00, 0x4d, 0x68, 0x6c, 0x46, 0xfe,
		0xc4, 0x18, 0x4a, 0x6f, 0xe0, 0x3c, 0x08, 0x8a, 0x0b, 0xe6, 0xeb, 0xcd, 0xc5, 0x0f, 0x8f, 0xb9,
		0x33, 0x2d, 0x4f, 0x40, 0x16, 0x82, 0x2c, 0x04, 0x59, 0x68, 0xbf, 0xf5, 0x72, 0xeb, 0x38, 0x96,
		0x30, 0x49, 0x84, 0xa1, 0x62, 0x82, 0xe1, 0x6b, 0x6c, 0x7a, 0x9e, 0x7c, 0x10, 0xc6, 0xc8, 0x19,
		0x12, 0x5c, 0x0c, 0x5d, 0x6b, 0x0d, 0xe0, 0x05, 0xf0, 0x02, 0x78, 0x01, 0xbc, 0xd4, 0x81, 0x97,
		0x3f, 0x18, 0x1b, 0x23, 0x8a, 0x43, 0xb4, 0x55, 0x43, 0x80, 0x1a, 0x40, 0x0d, 0xa0, 0x66, 0xaf,
		0xf5, 0x32, 0x91, 0xb6, 0x5f, 0xac, 0x12, 0x20, 0x4d, 0x15, 0x81, 0xbf, 0xa4, 0xb0, 0x12, 0x6a,
		0x0e, 0x81, 0xbf, 0x89, 0x99, 0x82, 0x6a, 0xa5, 0x72, 0x52, 0x41, 0xf0, 0xaf, 0x36, 0x9d, 0x27,
		0xa3, 0xc1, 0xbf, 0xab, 0xf0, 0x4e, 0xa4, 0x23, 0x45, 0x3a, 0x52, 0x76, 0x9a, 0x85, 0xe0, 0xbf,
		0x1d, 0xbe, 0x88, 0xe0, 0x3f, 0x78, 0x2f, 0xf0, 0x5e, 0x12, 0xe4, 0xbd, 0x20, 0xf8, 0x2f, 0x3c,
		0x28, 0x08, 0xfe, 0x8b, 0x3e, 0x72, 0x08, 0xfe, 0x43, 0xf0, 0x1f, 0x82, 0xff, 0x48, 0xfd, 0x3b,
		0x05, 0x22, 0xc1, 0x01, 0x82, 0xff, 0x10, 0x8c, 0x85, 0x60, 0xac, 0x2c, 0x81, 0x21, 0xd6, 0x1b,
		0x82, 0xff, 0x10, 0xfc, 0x87, 0xe0, 0xbf, 0xe8, 0xa2, 0x30, 0x82, 0xff, 0x20, 0x0b, 0x41, 0x16,
		0x82, 0x2c, 0x84, 0xe0, 0xbf, 0x68, 0x83, 0x86, 0xe0, 0x3f, 0x80, 0x17, 0xc0, 0x0b, 0xe0, 0x85,
		0xe0, 0x3f, 0x40, 0x0d, 0xa0, 0x26, 0x17, 0x50, 0x83, 0xe0, 0xbf, 0x97, 0x0f, 0x82, 0xe0, 0xbf,
		0x03, 0x8d, 0xe2, 0xc9, 0x01, 0x82, 0xff, 0x10, 0xfc, 0x47, 0xfe, 0x8d, 0x14, 0x06, 0xff, 0x21,
		0xf9, 0xe7, 0x0e, 0xa3, 0x44, 0x96, 0xff, 0x33, 0x68, 0x90, 0x31, 0x05, 0xe8, 0xc4, 0x13, 0xc6,
		0x68, 0x62, 0xf9, 0x72, 0x6c, 0x09, 0x63, 0x36, 0x0a, 0xde, 0xfe, 0xb9, 0x40, 0x37, 0xb4, 0x81,
		0xa4, 0xa0, 0x8c, 0x04, 0x15, 0x49, 0x41, 0x91, 0x14, 0x54, 0xa5, 0x47, 0x86, 0xb8, 0x60, 0x0d,
		0xd6, 0x3f, 0x72, 0x5c, 0xb0, 0xb0, 0xcd, 0x5b, 0x4b, 0x0c, 0xe3, 0x8b, 0x19, 0xab, 0x86, 0xa0,
		0xbf, 0x42, 0x14, 0x81, 0x28, 0x02, 0xfd, 0x35, 0xd7, 0x3e, 0x51, 0x98, 0xe3, 0x26, 0xe8, 0x66,
		0x94, 0x98, 0x6d, 0x8e, 0xc8, 0x0c, 0x48, 0xec, 0x0f, 0x49, 0xe0, 0x3f, 0xe0, 0x3f, 0x49, 0xe5,
		0x3f, 0x11, 0x1d, 0x02, 0x1a, 0xc7, 0x20, 0xe6, 0x06, 0x01, 0x6b, 0x01, 0x6b, 0xd1, 0xc5, 0x5a,
		0xa2, 0x6e, 0xb8, 0xa0, 0x01, 0xd3, 0xb2, 0x9c, 0xbf, 0x9f, 0x8d, 0xa4, 0xe9, 0xc5, 0x9f, 0xef,
		0xd5, 0x0a, 0x0c, 0x37, 0x1d, 0x73, 0x9a, 0x88, 0x9c, 0x13, 0x22, 0x27, 0x85, 0x6c, 0xdb, 0x53,
		0x6e, 0x7f, 0x7a, 0x18, 0xa0, 0x86, 0x03, 0x65, 0xb0, 0xa0, 0x0c, 0x1e, 0x94, 0xc0, 0x44, 0x3c,
		0xb8, 0x88, 0x09, 0x1b, 0x74, 0x4e, 0x8f, 0x02, 0xe7, 0x87, 0xc8, 0x09, 0x8a, 0x3f, 0xc0, 0x31,
		0x06, 0xb7, 0x30, 0x32, 0x7f, 0xcc, 0xcb, 0xde, 0xee, 0x27, 0xce, 0xff, 0x72, 0x74, 0xd7, 0x9b,
		0xa5, 0x83, 0xd3, 0x22, 0xa0, 0x14, 0x50, 0x0a, 0x28, 0x4d, 0x16, 0x94, 0x4e, 0xa4, 0xed, 0x9f,
		0x94, 0x08, 0x91, 0xb4, 0x46, 0xd0, 0x14, 0x4d, 0xb0, 0xcd, 0xea, 0x17, 0xe1, 0x1d, 0x4c, 0xca,
		0xe0, 0x1b, 0x62, 0x58, 0x0b, 0x35, 0x4b, 0x1c, 0x8c, 0x13, 0xb4, 0xab, 0x20, 0x1a, 0x84, 0x68,
		0x7b, 0xac, 0x4f, 0x15, 0x61, 0x90, 0x0e, 0xd7, 0x54, 0x95, 0x4b, 0xa7, 0xe5, 0xd3, 0x6a, 0xad,
		0x74, 0x5a, 0x49, 0xd1, 0x9c, 0x65, 0xe3, 0x4e, 0x5d, 0x4a, 0x5c, 0xf1, 0x98, 0x2a, 0x77, 0xd0,
		0x0e, 0xa5, 0xda, 0x2d, 0x66, 0x3f, 0x1e, 0x45, 0xf2, 0x8e, 0x3e, 0x84, 0x51, 0x42, 0xb9, 0xa3,
		0x25, 0x09, 0x0b, 0x19, 0xcc, 0x28, 0xc9, 0xc2, 0xc8, 0xb5, 0xbf, 0x12, 0xb4, 0x3f, 0x68, 0x7f,
		0xd0, 0xfe, 0xa0, 0xfd, 0xc1, 0x61, 0x85, 0xc3, 0x0a, 0xed, 0x0f, 0xda, 0x1f, 0xb4, 0x3f, 0x40,
		0x29, 0xa0, 0x14, 0x50, 0x0a, 0xed, 0x0f, 0xda, 0x1f, 0xb4, 0x3f, 0x68, 0x7f, 0xd0, 0xfe, 0xa0,
		0xfd, 0xb1, 0x69, 0x7f, 0x11, 0xee, 0x02, 0xc6, 0x90, 0xfe, 0x72, 0x13, 0x45, 0x2c, 0x22, 0xc6,
		0xa4, 0xfe, 0xd3, 0x4d, 0xc2, 0x6b, 0x4f, 0x5c, 0x2c, 0x7b, 0x69, 0xcf, 0x3a, 0xe9, 0x37, 0xf6,
		0x66, 0x46, 0x6a, 0x02, 0x95, 0x65, 0xac, 0x40, 0x65, 0x89, 0x40, 0x65, 0xb5, 0x1e, 0x01, 0x02,
		0x95, 0x11, 0xa8, 0xcc, 0xec, 0x6a, 0xe3, 0xb0, 0x42, 0x8f, 0x0b, 0x9d, 0xe7, 0xc3, 0x0a, 0xa8,
		0x6a, 0x50, 0xd5, 0xa0, 0xaa, 0x41, 0x55, 0x83, 0xaa, 0x06, 0x55, 0x0d, 0xaa, 0x1a, 0x54, 0x35,
		0xa8, 0x6a, 0x50, 0xd5, 0x34, 0x28, 0x3f, 0x12, 0x11, 0x75, 0xdc, 0x4e, 0x2a, 0x22, 0xea, 0xe0,
		0xa4, 0xc2, 0x49, 0x85, 0x93, 0x0a, 0x27, 0x15, 0x4e, 0x2a, 0x9c, 0x54, 0x38, 0xa9, 0x70, 0x52,
		0xe1, 0xa4, 0xc2, 0x49, 0x85, 0x93, 0x0a, 0x27, 0xf5, 0x1f, 0x9d, 0x54, 0x84, 0x7e, 0x28, 0x1b,
		0x5b, 0xe5, 0xa1, 0x1f, 0xcd, 0x84, 0x84, 0x7e, 0x44, 0x93, 0x11, 0x62, 0xc9, 0x07, 0xb1, 0x83,
		0x3f, 0x4a, 0x08, 0xfe, 0xd0, 0xc9, 0xf9, 0x91, 0xa5, 0x77, 0x87, 0xf5, 0x82, 0x2c, 0xbd, 0x50,
		0xe8, 0xa0, 0xd0, 0xe9, 0x70, 0xb7, 0x91, 0xa5, 0x37, 0x0d, 0x24, 0x0b, 0x25, 0x4c, 0xf6, 0x19,
		0x2e, 0xaa, 0x5a, 0x26, 0xaf, 0x69, 0x28, 0x59, 0x49, 0x93, 0x37, 0x31, 0x06, 0x7a, 0x06, 0xa7,
		0x73, 0x28, 0x0d, 0x46, 0xc0, 0x98, 0x3f, 0xfd, 0x2f, 0xbe, 0x75, 0x2e, 0x3d, 0xbf, 0xee, 0xfb,
		0xbb, 0x19, 0xfa, 0xc2, 0x85, 0xb4, 0x1b, 0x96, 0x98, 0x41, 0xa2, 0xb7, 0x9b, 0x39, 0x2b, 0x5c,
		0x98, 0x3f, 0x5e, 0x7c, 0xa3, 0xf8, 0xa1, 0x5c, 0xae, 0xd6, 0xca, 0xe5, 0xe3, 0xda, 0x49, 0xed,
		0xf8, 0xb4, 0x52, 0x29, 0x56, 0x8b, 0x3b, 0x08, 0x06, 0x85, 0x96, 0x3b, 0x14, 0xae, 0x18, 0x7e,
		0x9a, 0xbd, 0xa0, 0x3d, 0xb1, 0xac, 0x58, 0xe3, 0xb4, 0xe7, 0x42, 0x8c, 0xbc, 0x00, 0x77, 0x58,
		0x6d, 0xff, 0xb4, 0xca, 0xfe, 0x79, 0x51, 0x6d, 0x5f, 0x2a, 0x9b, 0xff, 0x65, 0xcb, 0xa0, 0xec,
		0x3a, 0x18, 0xfb, 0x0d, 0xc2, 0xe6, 0x47, 0x0f, 0x3f, 0xd8, 0x86, 0x87, 0x2a, 0xb8, 0xf2, 0x76,
		0xeb, 0x93, 0x04, 0x36, 0x69, 0xf6, 0x43, 0x5b, 0x5e, 0xe8, 0x9f, 0xbd, 0xa2, 0x5f, 0x7a, 0x3f,
		0xbb, 0x50, 0xad, 0x97, 0x54, 0xca, 0x95, 0xb7, 0xbf, 0xa0, 0x53, 0xbb, 0xd2, 0xa5, 0xbd, 0xe9,
		0xd0, 0xde, 0x74, 0xe7, 0x35, 0x9d, 0x59, 0x3d, 0x3b, 0xd1, 0x52, 0xfa, 0x95, 0xb7, 0x50, 0x30,
		0xef, 0xa4, 0xe1, 0x99, 0x77, 0xf2, 0xd7, 0x07, 0x7e, 0xcf, 0xe9, 0x31, 0x82, 0xaf, 0xfc, 0x0a,
		0xfc, 0x76, 0x72, 0x86, 0x77, 0x76, 0x7e, 0xf7, 0x61, 0xdc, 0xfb, 0x2d, 0x87, 0xa8, 0x2c, 0x3a,
		0x32, 0x5b, 0x8e, 0xcc, 0x8a, 0xf7, 0x5e, 0x2e, 0x34, 0x66, 0x6c, 0x57, 0xa7, 0x33, 0x58, 0x1b,
		0xfb, 0x97, 0xf4, 0x0a, 0xbe, 0x99, 0x8d, 0x42, 0x5e, 0xbb, 0x2f, 0xba, 0xb8, 0x2e, 0x5c, 0xf2,
		0x8a, 0x79, 0xed, 0xbc, 0x28, 0xd5, 0x90, 0xda, 0xbd, 0x0b, 0x7a, 0xad, 0x96, 0x9e, 0xb1, 0xb4,
		0xf9, 0x11, 0x05, 0xc3, 0xf5, 0x66, 0xa2, 0x09, 0x87, 0xc7, 0x29, 0xbb, 0x35, 0xb6, 0xff, 0x32,
		0xcf, 0x8f, 0x78, 0xb8, 0xf7, 0x36, 0xe0, 0x71, 0x95, 0x23, 0xab, 0x10, 0xc1, 0xbc, 0x5b, 0xc2,
		0xbc, 0x73, 0xc5, 0x5d, 0x94, 0x49, 0x5f, 0xa1, 0x76, 0x84, 0x63, 0xfd, 0x42, 0x7b, 0x49, 0x74,
		0xdf, 0xbf, 0x5f, 0xb8, 0xd8, 0x47, 0xeb, 0x1b, 0x2e, 0x09, 0x97, 0x4d, 0xc7, 0x0f, 0x65, 0xc3,
		0x73, 0x7d, 0x61, 0x8c, 0x1d, 0x4b, 0x0e, 0x1e, 0x63, 0x5c, 0x3c, 0x7d, 0xdd, 0x52, 0x3e, 0x2e,
		0xa1, 0x02, 0x4e, 0x52, 0x07, 0x27, 0x91, 0xcf, 0x23, 0xac, 0xc5, 0x3b, 0xc5, 0x3f, 0x8f, 0x58,
		0x35, 0x84, 0xeb, 0xa8, 0xf1, 0xb6, 0x10, 0xce, 0x12, 0x22, 0x6f, 0x31, 0x3d, 0xe7, 0x09, 0xb1,
		0x23, 0x7e, 0x5d, 0x67, 0xe2, 0x0b, 0xc2, 0x50, 0xdf, 0x65, 0x7b, 0x34, 0x71, 0xb9, 0xc5, 0x8c,
		0xc7, 0xe5, 0xc6, 0xdf, 0xa8, 0xd4, 0x1b, 0x56, 0xd9, 0xc6, 0x55, 0xb6, 0x81, 0x95, 0x6d, 0xe4,
		0x78, 0x1b, 0x3a, 0xe6, 0xc6, 0x26, 0xdb, 0xe0, 0xeb, 0x1b, 0x9d, 0x6e, 0x7d, 0xac, 0xed, 0x77,
		0xaa, 0xb5, 0x41, 0xb3, 0xed, 0xc9, 0xb7, 0xbf, 0x0a, 0x18, 0x50, 0x0b, 0x07, 0xaa, 0x60, 0x41,
		0x39, 0x3c, 0x28, 0x87, 0x09, 0xe5, 0x70, 0x41, 0x03, 0x1b, 0x44, 0xf0, 0x41, 0x0e, 0x23, 0x41,
		0x83, 0x03, 0xc7, 0x72, 0x5c, 0xfa, 0x75, 0xf5, 0x9c, 0x5e, 0x66, 0xd6, 0xfc, 0xbb, 0x54, 0xc4,
		0x5a, 0x53, 0xc3, 0x8c, 0x4a, 0xb8, 0xe1, 0x81, 0x1d, 0xd5, 0xf0, 0xc3, 0x06, 0x43, 0x6c, 0x70,
		0xc4, 0x06, 0x4b, 0xb4, 0xf0, 0x44, 0x0c, 0x53, 0xf1, 0x05, 0xca, 0xdd, 0x15, 0x83, 0xc8, 0x02,
		0xe6, 0xce, 0x2c, 0xa6, 0xa6, 0xa0, 0xed, 0x90, 0x00, 0xba, 0x00, 0xca, 0x37, 0xc9, 0x5c, 0x1a,
		0x94, 0xb7, 0x6f, 0x84, 0x3d, 0x1c, 0x3b, 0x72, 0xbe, 0x31, 0x14, 0xd9, 0x9c, 0xa0, 0x07, 0x98,
		0x1d, 0x98, 0x1d, 0x98, 0x1d, 0x98, 0x1d, 0x98, 0x9d, 0xad, 0x66, 0x27, 0xc0, 0xca, 0x1c, 0x58,
		0x9e, 0xb1, 0xe9, 0x7f, 0x37, 0xe4, 0x50, 0x9d, 0xe1, 0x59, 0x75, 0x00, 0xbb, 0x03, 0xbb, 0x03,
		0xbb, 0x03, 0xbb, 0x03, 0xbb, 0xb3, 0xd5, 0xee, 0xac, 0xa0, 0x32, 0x07, 0x66, 0x27, 0x5e, 0x0a,
		0xac, 0x5f, 0xae, 0x88, 0x38, 0xa9, 0xb1, 0x7e, 0xb9, 0x16, 0x60, 0x72, 0x60, 0x72, 0x60, 0x72,
		0x92, 0x6c, 0x72, 0xa8, 0x0f, 0x04, 0x82, 0x86, 0x4d, 0xdf, 0x77, 0x0d, 0x69, 0x0f, 0xc5, 0x0f,
		0x75, 0x8b, 0x32, 0x08, 0xb7, 0x7d, 0xee, 0x4b, 0xd1, 0x62, 0x51, 0xc3, 0xa1, 0x95, 0x03, 0x1b,
		0x07, 0xc0, 0xf1, 0x02, 0x1d, 0x17, 0xe0, 0xb1, 0x03, 0x1f, 0x3b, 0x00, 0xb2, 0x03, 0xa1, 0x1a,
		0x40, 0x54, 0x04, 0x8c, 0xea, 0x39, 0x39, 0x23, 0x37, 0xe7, 0xe0, 0xe8, 0x9b, 0xb8, 0xfa, 0xc6,
		0xdf, 0x73, 0xb0, 0xf6, 0x84, 0xef, 0x05, 0x9f, 0x96, 0x9c, 0x7e, 0x01, 0xe0, 0x6f, 0xd2, 0xb1,
		0xe4, 0x14, 0x2c, 0x37, 0x45, 0x67, 0xe9, 0xa1, 0x75, 0xa6, 0xe2, 0x4c, 0x1d, 0x86, 0x12, 0x86,
		0x12, 0x86, 0x12, 0x86, 0x92, 0x65, 0xdf, 0x90, 0x65, 0x16, 0xfd, 0x15, 0x8a, 0xa9, 0x34, 0x93,
		0xb4, 0x99, 0x48, 0xb7, 0xfd, 0x52, 0xbb, 0xe7, 0x0f, 0x54, 0x65, 0x2e, 0xd5, 0x64, 0x5e, 0x42,
		0xdd, 0x29, 0xca, 0x74, 0xba, 0xb5, 0x3f, 0x85, 0xd9, 0x34, 0x99, 0xe1, 0x60, 0x7d, 0x89, 0x98,
		0x3f, 0x32, 0xbf, 0x44, 0x54, 0x65, 0x58, 0x4d, 0xd4, 0x5a, 0x79, 0x93, 0xce, 0xd6, 0x7b, 0xb9,
		0x76, 0x2a, 0x46, 0xa3, 0x89, 0x2d, 0xfd, 0x47, 0x2e, 0x31, 0xee, 0x75, 0x87, 0x70, 0x34, 0xe0,
		0x68, 0xc0, 0xd1, 0x80, 0xa3, 0x91, 0x42, 0x47, 0x23, 0x27, 0x8a, 0xdc, 0x0a, 0xb1, 0xa5, 0xf0,
		0x82, 0xcf, 0x8f, 0x10, 0xe5, 0x16, 0x83, 0xa7, 0x2c, 0xde, 0x38, 0xb4, 0xda, 0x14, 0xc5, 0x1d,
		0xc3, 0x62, 0xc2, 0x62, 0xc2, 0x62, 0xc2, 0x62, 0xb2, 0xec, 0x1b, 0x39, 0x36, 0xcc, 0xe1, 0xd0,
		0x15, 0x9e, 0xc7, 0x61, 0x34, 0x4f, 0x15, 0xf6, 0xb1, 0x1c, 0xb3, 0xd4, 0xcb, 0x73, 0x6b, 0x69,
		0x84, 0xd4, 0xcf, 0x4d, 0x68, 0x8e, 0x3e, 0x30, 0xf4, 0xd5, 0x36, 0x7d, 0x5f, 0xb8, 0xb6, 0xf2,
		0xe9, 0x0a, 0x3a, 0xfc, 0xf3, 0xed, 0xdb, 0x9b, 0x63, 0xe3, 0xb4, 0xf7, 0x74, 0x53, 0x34, 0x4e,
		0x7b, 0x8b, 0x8f, 0xc5, 0xf9, 0x1f, 0x8b, 0xcf, 0xa5, 0x9b, 0x63, 0xa3, 0xbc, 0xfa, 0x5c, 0xb9,
		0x39, 0x36, 0x2a, 0xbd, 0xc3, 0x3f, 0xfe, 0x78, 0x7f, 0xf8, 0xf3, 0x64, 0xba, 0xff, 0x17, 0xff,
		0x55, 0x50, 0xfe, 0x52, 0x3d, 0x8e, 0x49, 0x6a, 0x75, 0x9b, 0xbf, 0x63, 0xa6, 0x12, 0x29, 0x65,
		0x29, 0x36, 0x40, 0x7a, 0xe0, 0xae, 0x0a, 0xb8, 0xa3, 0xdd, 0x44, 0xa6, 0x71, 0x57, 0x37, 0xbe,
		0xf4, 0x7e, 0x16, 0xdf, 0x95, 0xa7, 0x1f, 0x0f, 0x7f, 0xd6, 0xa6, 0xaf, 0xff, 0xf2, 0x69, 0xd3,
		0x8f, 0x15, 0xdf, 0xd5, 0xa6, 0x1f, 0xb7, 0xfc, 0x4b, 0x75, 0xfa, 0x71, 0xc7, 0x36, 0x2a, 0xd3,
		0xb7, 0xa1, 0x1f, 0x9d, 0xfd, 0x7d, 0x69, 0xdb, 0x17, 0xca, 0x5b, 0xbe, 0x70, 0xb2, 0xed, 0x0b,
		0x27, 0x5b, 0xbe, 0xb0, 0xf5, 0x91, 0x4a, 0x5b, 0xbe, 0x50, 0x99, 0x3e, 0x85, 0x7e, 0xfe, 0xed,
		0xe6, 0x1f, 0xad, 0x4e, 0x0f, 0x9f, 0xb6, 0xfd, 0x5b, 0x6d, 0xfa, 0xf4, 0xf1, 0x10, 0xe0, 0x8f,
		0x75, 0x8b, 0x75, 0xab, 0xc5, 0x14, 0xe2, 0x34, 0x4a, 0x85, 0x9a, 0xf6, 0xc3, 0x37, 0xd8, 0x4f,
		0xa4, 0x36, 0x75, 0x0a, 0x8d, 0x0d, 0x1a, 0x1b, 0x34, 0x36, 0x68, 0x6c, 0x29, 0xd4, 0xd8, 0x72,
		0x72, 0x2a, 0xf5, 0x12, 0xb5, 0xa5, 0xf0, 0xd6, 0xfe, 0x1b, 0xa7, 0x53, 0xcb, 0x41, 0x94, 0xf6,
		0x83, 0x69, 0xc9, 0xa1, 0xe1, 0x0a, 0xd3, 0x73, 0x6c, 0xf5, 0xa6, 0xf4, 0x55, 0x7f, 0xb0, 0xa2,
		0xb0, 0xa2, 0xb0, 0xa2, 0xb0, 0xa2, 0x29, 0xb4, 0xa2, 0x72, 0x28, 0x6c, 0x5f, 0xfa, 0x8f, 0x4c,
		0x96, 0x54, 0x61, 0x54, 0x68, 0xa1, 0xb9, 0x7c, 0x95, 0x4f, 0xa6, 0xc7, 0xb0, 0x45, 0x57, 0x03,
		0xd8, 0xbc, 0xfc, 0x56, 0x3f, 0x6f, 0x9e, 0xf5, 0x3b, 0xad, 0xeb, 0xab, 0x46, 0xbf, 0xd3, 0xa8,
		0x77, 0x5b, 0x97, 0xaa, 0x77, 0xeb, 0x3c, 0xd8, 0xd6, 0x63, 0x11, 0x90, 0x98, 0xa2, 0x95, 0x5f,
		0x8f, 0xe6, 0xe7, 0xf3, 0xeb, 0xee, 0x55, 0xa3, 0xd3, 0x3f, 0x6f, 0xb5, 0xda, 0x85, 0x2c, 0x04,
		0x7f, 0x6b, 0x1a, 0xc7, 0x7a, 0x17, 0x43, 0x18, 0x73, 0x08, 0x5b, 0x9d, 0xe6, 0xd7, 0xe6, 0x65,
		0xfd, 0xaa, 0xd5, 0xc1, 0x28, 0xc6, 0xd8, 0xd0, 0xad, 0xcb, 0x2f, 0x8d, 0xb3, 0x42, 0xca, 0x63,
		0xf3, 0x7b, 0x69, 0xe3, 0x27, 0xa9, 0xf0, 0xde, 0x2c, 0xd3, 0xf3, 0x8d, 0x91, 0x33, 0x94, 0x77,
		0x52, 0x0c, 0xd5, 0x3b, 0x6f, 0xeb, 0xdd, 0xc1, 0x77, 0x83, 0xef, 0x06, 0xdf, 0x0d, 0xbe, 0x5b,
		0x0a, 0x7d, 0x37, 0x5f, 0x8e, 0x84, 0x2f, 0x07, 0x7f, 0x79, 0xd5, 0x32, 0x83, 0xef, 0xa6, 0x30,
		0xa4, 0xa3, 0x70, 0x6d, 0x2f, 0xee, 0xee, 0x15, 0x6c, 0xd3, 0x76, 0x3c, 0x31, 0x70, 0xec, 0xa1,
		0xd2, 0xc8, 0x49, 0xdc, 0x3a, 0x4e, 0x9e, 0x4d, 0xdb, 0xec, 0xe5, 0xe2, 0xd6, 0x71, 0xec, 0x25,
		0x92, 0x83, 0x5b, 0xc7, 0xc5, 0x0f, 0xe5, 0x72, 0xb5, 0x56, 0x2e, 0x1f, 0xd7, 0x4e, 0x6a, 0xc7,
		0xa7, 0x95, 0x4a, 0xb1, 0x5a, 0xc4, 0xfd, 0xe3, 0xc4, 0xb5, 0x9e, 0xe7, 0x88, 0x0f, 0x55, 0x59,
		0xb3, 0x43, 0xa4, 0x40, 0x4d, 0xf6, 0xec, 0xa0, 0x9b, 0x33, 0x71, 0x67, 0x4e, 0xac, 0x39, 0xf5,
		0x3b, 0x86, 0xef, 0x04, 0xdf, 0x09, 0xbe, 0x13, 0x7c, 0xa7, 0x34, 0xfa, 0x4e, 0x48, 0x9e, 0x04,
		0x37, 0x06, 0x6e, 0x0c, 0xdc, 0x98, 0x44, 0x2d, 0x11, 0x24, 0x4f, 0x82, 0xf3, 0x92, 0x44, 0xe7,
		0x65, 0x19, 0xec, 0x46, 0x5a, 0x32, 0x79, 0xab, 0x65, 0x7e, 0xd9, 0x19, 0x1c, 0x0c, 0x38, 0x18,
		0x70, 0x30, 0xe0, 0x60, 0xa4, 0xd0, 0xc1, 0xb8, 0x75, 0x1c, 0x4b, 0x98, 0x36, 0x47, 0x50, 0x5d,
		0x31, 0x2d, 0xa6, 0x29, 0xd1, 0x25, 0x40, 0xea, 0xb6, 0xed, 0xf8, 0xe6, 0x8c, 0x0d, 0xa9, 0xa9,
		0x04, 0xe2, 0x0d, 0xbe, 0x8b, 0x91, 0x39, 0x5e, 0x86, 0xfb, 0x1f, 0x39, 0x63, 0x61, 0x0f, 0xe6,
		0x86, 0x62, 0xb6, 0x3f, 0x8f, 0x66, 0xff, 0x73, 0xe5, 0xed, 0x91, 0x79, 0x27, 0x0d, 0xcf, 0xbc,
		0x93, 0x5e, 0xf0, 0xe9, 0x68, 0x9e, 0xb2, 0xc2, 0x73, 0x7d, 0x61, 0x8c, 0x1d, 0x4b, 0x0e, 0x1e,
		0x8f, 0xac, 0xc5, 0xbe, 0x3e, 0x9a, 0xdb, 0x48, 0x6f, 0xf1, 0xc7, 0xe2, 0x26, 0x40, 0x1e, 0x0a,
		0x41, 0x4d, 0xec, 0xbf, 0x6c, 0xe7, 0x6f, 0xdb, 0x30, 0x7d, 0xdf, 0x95, 0xb7, 0xb3, 0x11, 0x50,
		0x57, 0x15, 0x6a, 0x43, 0x5f, 0x28, 0x11, 0x85, 0x12, 0x51, 0x89, 0xa0, 0x18, 0x28, 0x11, 0xc5,
		0x6b, 0x1f, 0x94, 0x95, 0x88, 0x0a, 0x81, 0x8c, 0x7a, 0x1f, 0x2b, 0xdc, 0xa5, 0x5a, 0x4f, 0xab,
		0x08, 0x4f, 0x0b, 0x9e, 0x16, 0x3c, 0xad, 0x3c, 0x79, 0x5a, 0xaa, 0xe0, 0x32, 0xe8, 0x60, 0x5e,
		0x36, 0xc9, 0x57, 0xed, 0xcf, 0x1d, 0x84, 0x0a, 0xec, 0xcd, 0xbb, 0x54, 0xbc, 0xb4, 0x78, 0xf4,
		0x67, 0xe5, 0xf0, 0xc9, 0x09, 0xa3, 0x7a, 0xe0, 0x94, 0x1b, 0x56, 0xb5, 0xc1, 0xab, 0x36, 0x98,
		0xd5, 0x06, 0xb7, 0x6a, 0x61, 0x57, 0x31, 0xfc, 0xf2, 0x09, 0x5e, 0xa1, 0x7d, 0xa7, 0x3e, 0x2f,
		0x43, 0x88, 0x5d, 0xd6, 0x78, 0xb2, 0xcd, 0xad, 0xd7, 0xde, 0x7e, 0x36, 0x06, 0x29, 0x3d, 0xd1,
		0x52, 0xb8, 0xf4, 0x14, 0x55, 0xeb, 0xde, 0xba, 0xe6, 0x54, 0x54, 0xef, 0x66, 0xf6, 0x65, 0x60,
		0x94, 0x61, 0x94, 0x61, 0x94, 0xf3, 0x61, 0x94, 0x55, 0xfb, 0x46, 0xeb, 0x3e, 0x92, 0x25, 0x18,
		0x83, 0xab, 0xd6, 0x5c, 0xa5, 0x59, 0xcf, 0xef, 0x32, 0x19, 0xb1, 0xc3, 0x05, 0xd2, 0x3a, 0xc0,
		0x5a, 0x2f, 0x68, 0xeb, 0x02, 0x6f, 0xed, 0x20, 0xae, 0x1d, 0xcc, 0xb5, 0x83, 0x3a, 0x0f, 0xb8,
		0x33, 0x81, 0x3c, 0xbf, 0x07, 0x16, 0xda, 0xb7, 0x13, 0x69, 0xfb, 0xc5, 0x2a, 0xe7, 0x9e, 0x5d,
		0xa2, 0x70, 0x95, 0xb1, 0x4b, 0x9e, 0x18, 0xe8, 0xd7, 0xbf, 0x78, 0x31, 0xe9, 0x80, 0x3b, 0x46,
		0x5a, 0xb3, 0x79, 0x0d, 0x75, 0xcf, 0x1c, 0x43, 0x1d, 0xea, 0x5f, 0x43, 0x9c, 0xac, 0x26, 0xb8,
		0x5a, 0x5f, 0x72, 0xe6, 0x8f, 0xdc, 0x2f, 0xb9, 0x6a, 0xa5, 0x72, 0x52, 0xc9, 0xf1, 0xb2, 0x7b,
		0x93, 0xcd, 0xde, 0x7a, 0x6f, 0xb2, 0xf1, 0x3e, 0x1c, 0x57, 0x2f, 0xf8, 0x4e, 0xda, 0x36, 0xbb,
		0x91, 0x0c, 0x27, 0x6e, 0xf0, 0x23, 0xe1, 0x47, 0xc2, 0x8f, 0x84, 0x1f, 0x09, 0x3f, 0x72, 0x8b,
		0x1f, 0xf9, 0x41, 0x83, 0x1b, 0x59, 0x81, 0x1b, 0x09, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0xc8, 0x0c,
		0x2c, 0xb9, 0x52, 0x05, 0x4e, 0x24, 0x9c, 0xc8, 0xbc, 0x3b, 0x91, 0x0f, 0xcb, 0xdd, 0xa0, 0xc3,
		0x8b, 0x5c, 0xf4, 0x0d, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48, 0xb8, 0x91, 0x70, 0x23, 0xd9, 0xf7,
		0xed, 0xad, 0xb4, 0x4d, 0xf7, 0x51, 0x83, 0x1f, 0x79, 0xca, 0xd8, 0xe5, 0xb9, 0xb0, 0xef, 0xe7,
		0x81, 0xa2, 0x70, 0x24, 0x73, 0xc0, 0xea, 0x8b, 0x70, 0x24, 0xe1, 0x48, 0xf2, 0x2e, 0x39, 0x9c,
		0x47, 0xc2, 0x95, 0xcc, 0xb9, 0x2b, 0x29, 0x7e, 0xf8, 0xc2, 0x1e, 0x2a, 0x2c, 0x15, 0xb2, 0x95,
		0xc2, 0x04, 0x3d, 0xc3, 0x8d, 0x84, 0x1b, 0x09, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48, 0x7e, 0x37,
		0x52, 0x79, 0x62, 0xad, 0x6d, 0x30, 0xac, 0x28, 0xd1, 0x56, 0x36, 0x8d, 0xb4, 0x33, 0x9e, 0x31,
		0x45, 0xd3, 0xe2, 0x37, 0xd2, 0x41, 0xcf, 0x30, 0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x30,
		0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x9b, 0xc6, 0x6c, 0x6c, 0xba, 0xbe, 0xd4, 0x61, 0xa3, 0x57, 0x1d,
		0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0x6f, 0x1a,
		0x33, 0xdf, 0x35, 0x6d, 0x4f, 0xfa, 0xf2, 0x41, 0x43, 0xdc, 0xd4, 0x8b, 0xbe, 0x61, 0xa8, 0x61,
		0xa8, 0x61, 0xa8, 0x61, 0xa8, 0x61, 0xa8, 0x61, 0xa8, 0x53, 0x68, 0xa8, 0x53, 0x9d, 0x2e, 0x4a,
		0x71, 0x65, 0x8a, 0x50, 0x7f, 0x8a, 0x2b, 0x55, 0x84, 0x8b, 0x2a, 0x84, 0xff, 0x4a, 0x45, 0x39,
		0x0b, 0xbe, 0x45, 0x91, 0xae, 0x4c, 0xcd, 0xff, 0x16, 0x8f, 0x1c, 0x57, 0xad, 0x0b, 0xe7, 0xd2,
		0xf3, 0xeb, 0xbe, 0xaf, 0x38, 0x2d, 0xf4, 0x85, 0xb4, 0x1b, 0x96, 0x98, 0xd9, 0x3d, 0x4f, 0x2d,
		0xaf, 0x2b, 0x5c, 0x98, 0x3f, 0x5e, 0xf4, 0xc4, 0x5b, 0x82, 0xbc, 0xd0, 0x72, 0x87, 0xc2, 0x15,
		0xc3, 0x4f, 0xb3, 0xa9, 0xb3, 0x27, 0x96, 0x95, 0xaa, 0x15, 0xc7, 0x04, 0x68, 0x49, 0x00, 0xb2,
		0x82, 0xd2, 0x24, 0xab, 0xee, 0x64, 0xe0, 0xdb, 0x4b, 0x9a, 0xf0, 0xe9, 0x7e, 0xdc, 0xef, 0xc8,
		0xdb, 0x7e, 0xfd, 0x4e, 0x76, 0xcd, 0x3b, 0xd9, 0x6f, 0x8e, 0x1f, 0xca, 0x5d, 0xd7, 0x17, 0xed,
		0xf9, 0x1b, 0xf4, 0xcf, 0x9d, 0xc1, 0xec, 0x5f, 0x3b, 0xb3, 0x27, 0xef, 0x5f, 0x2f, 0x1e, 0xb3,
		0x1e, 0x3c, 0x25, 0x2a, 0x48, 0x25, 0x7f, 0x59, 0xf3, 0x2f, 0xe7, 0xc4, 0x96, 0x93, 0x7a, 0x93,
		0xa0, 0xe9, 0x5f, 0xd9, 0xcf, 0x65, 0xe1, 0xfd, 0x03, 0x61, 0x0f, 0xc7, 0x8e, 0xb4, 0xfd, 0x83,
		0x81, 0x63, 0x39, 0x2e, 0xd1, 0xfe, 0x57, 0x63, 0x3c, 0xd5, 0x19, 0x4b, 0x56, 0xe3, 0xa8, 0xc6,
		0x18, 0x52, 0x2d, 0x0f, 0x45, 0xa8, 0xa0, 0x18, 0x0d, 0x08, 0xed, 0x56, 0x74, 0x3b, 0x45, 0x83,
		0x3f, 0xf1, 0xd1, 0x22, 0x5e, 0x0b, 0x31, 0x17, 0x12, 0xf5, 0x02, 0x52, 0xb6, 0x70, 0xe2, 0xcd,
		0x56, 0xf4, 0x31, 0x8e, 0xf6, 0xcd, 0x88, 0xb3, 0x42, 0x35, 0x1b, 0xf4, 0xb3, 0x10, 0x63, 0xc7,
		0x46, 0xd9, 0xa1, 0xd1, 0x66, 0x7b, 0xff, 0xb9, 0x8a, 0x30, 0x4f, 0x05, 0x5b, 0xc8, 0xfb, 0xef,
		0xb7, 0x8e, 0x1b, 0xbd, 0x32, 0x64, 0x20, 0xbe, 0x3d, 0x37, 0x15, 0x71, 0xbd, 0xc4, 0xab, 0x1a,
		0x10, 0xfb, 0x84, 0x82, 0xe2, 0xc4, 0x81, 0xf6, 0x04, 0x81, 0xea, 0x44, 0x80, 0x5c, 0xe1, 0x27,
		0x57, 0xec, 0xc9, 0x15, 0x78, 0x5e, 0xa4, 0x8b, 0x9b, 0xa5, 0x3e, 0xd8, 0x3b, 0xf1, 0xa7, 0xfa,
		0xf5, 0x6e, 0x8c, 0x3b, 0xd3, 0x34, 0xa5, 0x3c, 0xc8, 0x8e, 0x0f, 0x29, 0x8f, 0x05, 0xd5, 0x1c,
		0xf7, 0x51, 0x1f, 0xe3, 0x29, 0x3b, 0x9e, 0x53, 0x76, 0xec, 0xa6, 0xec, 0x38, 0x4d, 0x2f, 0xb9,
		0xa4, 0x2a, 0x45, 0x51, 0x30, 0x87, 0xff, 0x9b, 0x8f, 0x89, 0xb4, 0x8d, 0xb1, 0xe3, 0xf9, 0x74,
		0x2b, 0x25, 0x48, 0xe2, 0xf2, 0xaa, 0x03, 0x2a, 0xef, 0x9d, 0xb4, 0xaa, 0x0f, 0x79, 0x44, 0x81,
		0x8a, 0x88, 0x01, 0xb5, 0x11, 0x01, 0xaa, 0x4e, 0xfc, 0x95, 0x9f, 0xe8, 0x2b, 0x3f, 0xb1, 0x57,
		0x7e, 0x22, 0x9f, 0x2c, 0x5d, 0x8c, 0xba, 0xca, 0x4d, 0x61, 0xe9, 0x66, 0x2a, 0xab, 0xf6, 0xbe,
		0x6c, 0x1f, 0x15, 0xde, 0x51, 0xe1, 0x5d, 0x2b, 0x10, 0xb1, 0x01, 0x12, 0x1b, 0x30, 0xd1, 0x02,
		0x14, 0x31, 0x50, 0x29, 0x03, 0xac, 0x75, 0xe0, 0x52, 0x5f, 0xd5, 0x9d, 0x5a, 0xb8, 0x65, 0x80,
		0x31, 0xe5, 0x70, 0xc6, 0x01, 0x6b, 0xbc, 0xf0, 0xc6, 0x05, 0x73, 0xec, 0x70, 0xc7, 0x0e, 0x7b,
		0xec, 0xf0, 0xa7, 0x06, 0x06, 0x15, 0xc1, 0xa1, 0x72, 0x58, 0x0c, 0x3a, 0x58, 0x1c, 0x94, 0xb2,
		0x15, 0x8b, 0xa5, 0x3c, 0x97, 0xfd, 0x15, 0x5c, 0xa2, 0x82, 0x7b, 0xd2, 0x61, 0x94, 0x1b, 0x4e,
		0xb5, 0xc1, 0xaa, 0x36, 0x78, 0xd5, 0x06, 0xb3, 0x6a, 0xe1, 0x56, 0x31, 0xec, 0x06, 0xa3, 0x86,
		0x0a, 0xee, 0x54, 0x10, 0xf6, 0xba, 0x82, 0xfb, 0xc2, 0x10, 0xa0, 0x7a, 0x7b, 0x68, 0xa4, 0x56,
		0x21, 0x4c, 0x7c, 0x36, 0x39, 0xe8, 0x11, 0x66, 0x19, 0x66, 0x19, 0x66, 0x19, 0x66, 0x19, 0x66,
		0x39, 0xb7, 0x66, 0x39, 0xb0, 0x05, 0xb0, 0xcc, 0xa1, 0xc1, 0x5a, 0x06, 0x19, 0xf3, 0x19, 0xe6,
		0x55, 0x87, 0xb0, 0xcb, 0xb0, 0xcb, 0xb0, 0xcb, 0xb0, 0xcb, 0xb0, 0xcb, 0xb9, 0xb5, 0xcb, 0x2b,
		0x53, 0x00, 0xb3, 0x1c, 0x1a, 0xab, 0xc5, 0x6d, 0x65, 0x36, 0xa3, 0xbc, 0xe8, 0x8e, 0xc7, 0x24,
		0x17, 0x61, 0x92, 0x61, 0x92, 0x61, 0x92, 0x61, 0x92, 0xa3, 0x8f, 0x9a, 0xea, 0x03, 0xc4, 0xa0,
		0xa3, 0x79, 0x0a, 0x03, 0x69, 0x0f, 0xc5, 0x0f, 0x4d, 0x35, 0x06, 0x17, 0x7d, 0x23, 0x57, 0x56,
		0xda, 0x00, 0x5b, 0x2f, 0x70, 0xeb, 0x02, 0x70, 0xed, 0x40, 0xae, 0x1d, 0xd0, 0xb5, 0x03, 0x3b,
		0x0f, 0xc0, 0x33, 0x01, 0x3d, 0xbf, 0x0f, 0xa6, 0xd1, 0x17, 0xd3, 0xe1, 0x93, 0x6d, 0xf2, 0xcd,
		0xfe, 0xe1, 0xf7, 0xdc, 0x24, 0x79, 0xc2, 0xf7, 0x82, 0x4f, 0x4b, 0x4f, 0x6e, 0x61, 0xa6, 0x90,
		0x84, 0x73, 0xe7, 0xf1, 0xbe, 0x15, 0x9e, 0x6f, 0x2c, 0xef, 0xea, 0x32, 0xf3, 0x8a, 0xe7, 0xae,
		0x41, 0x2b, 0x40, 0x2b, 0x40, 0x2b, 0x40, 0x2b, 0x40, 0x2b, 0xd8, 0xf7, 0x2d, 0x52, 0x70, 0xa6,
		0xc2, 0x4c, 0xf3, 0x04, 0x12, 0x87, 0x56, 0x07, 0x47, 0x40, 0x31, 0xcc, 0x33, 0xcc, 0x33, 0xcc,
		0x33, 0xcc, 0x33, 0xcc, 0xf3, 0x86, 0x7d, 0x3b, 0x91, 0xb6, 0x7f, 0x52, 0xd2, 0x60, 0x9d, 0x39,
		0x7d, 0xfe, 0x8e, 0x69, 0xdf, 0xcf, 0xde, 0xf6, 0x86, 0x75, 0x8f, 0xfc, 0xd4, 0x50, 0xe5, 0x5d,
		0xda, 0xb9, 0xaf, 0xf2, 0x7e, 0x9c, 0xe3, 0x0a, 0xef, 0xef, 0x34, 0x2c, 0x39, 0xf3, 0x47, 0xee,
		0x97, 0x5c, 0xb9, 0x74, 0x5a, 0x3e, 0xad, 0xd6, 0x4a, 0xa7, 0x95, 0x1c, 0xaf, 0xbd, 0x37, 0xd9,
		0xec, 0xad, 0x07, 0x27, 0x72, 0x0f, 0x27, 0x72, 0x34, 0x9a, 0xd8, 0xd2, 0x7f, 0xd4, 0x75, 0x92,
		0xfc, 0xfa, 0x01, 0xe0, 0x58, 0xc2, 0xb1, 0x84, 0x63, 0x09, 0xc7, 0x12, 0x8e, 0x25, 0xfb, 0xbe,
		0xc5, 0x71, 0xf2, 0x8b, 0xdf, 0x2b, 0xbb, 0x24, 0x85, 0x17, 0x7c, 0x7e, 0xc4, 0x89, 0x72, 0xb4,
		0x21, 0x67, 0xbb, 0x62, 0x1b, 0x5a, 0xd3, 0x4c, 0x57, 0x6d, 0xc1, 0x2b, 0xc0, 0x2b, 0xc0, 0x2b,
		0xc0, 0x2b, 0xc0, 0x2b, 0x36, 0xec, 0x5b, 0x39, 0x36, 0xcc, 0xe1, 0xd0, 0x15, 0x9e, 0xa7, 0x83,
		0x5a, 0x9c, 0x32, 0xf6, 0xb9, 0x1c, 0xe3, 0xcc, 0x8b, 0xd6, 0xcf, 0x33, 0xfb, 0x50, 0xd6, 0x30,
		0xb7, 0xa1, 0x39, 0xfe, 0xa0, 0xa1, 0xef, 0xb6, 0xe9, 0xfb, 0xc2, 0xb5, 0xd9, 0xa7, 0x3b, 0x78,
		0x80, 0x3f, 0xdf, 0xbe, 0xbd, 0x39, 0x36, 0x4e, 0x7b, 0x4f, 0x37, 0x45, 0xe3, 0xb4, 0xb7, 0xf8,
		0x58, 0x9c, 0xff, 0xb1, 0xf8, 0x5c, 0xba, 0x39, 0x36, 0xca, 0xab, 0xcf, 0x95, 0x9b, 0x63, 0xa3,
		0xd2, 0x3b, 0xfc, 0xe3, 0x8f, 0xf7, 0x87, 0x3f, 0x4f, 0xa6, 0xfb, 0x7f, 0xf1, 0x5f, 0x05, 0xf6,
		0x97, 0xec, 0xe9, 0x98, 0xd4, 0x56, 0xb7, 0xf9, 0x3b, 0x66, 0x56, 0xf5, 0xcc, 0xf2, 0x0a, 0xcf,
		0xef, 0x72, 0x04, 0xc7, 0x55, 0xc0, 0xb1, 0xde, 0x4d, 0x6b, 0x1a, 0x77, 0x75, 0xe3, 0x4b, 0xef,
		0x67, 0xf1, 0x5d, 0x79, 0xfa, 0xf1, 0xf0, 0x67, 0x6d, 0xfa, 0xfa, 0x2f, 0x9f, 0x36, 0xfd, 0x58,
		0xf1, 0x5d, 0x6d, 0xfa, 0x71, 0xcb, 0xbf, 0x54, 0xa7, 0x1f, 0x77, 0x6c, 0xa3, 0x32, 0x7d, 0x1b,
		0xfa, 0xd1, 0xd9, 0xdf, 0x97, 0xb6, 0x7d, 0xa1, 0xbc, 0xe5, 0x0b, 0x27, 0xdb, 0xbe, 0x70, 0xb2,
		0xe5, 0x0b, 0x5b, 0x1f, 0xa9, 0xb4, 0xe5, 0x0b, 0x95, 0xe9, 0x53, 0xe8, 0xe7, 0xdf, 0x6e, 0xfe,
		0xd1, 0xea, 0xf4, 0xf0, 0x69, 0xdb, 0xbf, 0xd5, 0xa6, 0x4f, 0x1f, 0x0f, 0x61, 0x9c, 0xb0, 0xce,
		0xb1, 0xce, 0x33, 0x61, 0xaa, 0x71, 0x46, 0x9c, 0x44, 0xf5, 0xf6, 0x87, 0x6f, 0x68, 0x3f, 0x27,
		0xde, 0xf4, 0x10, 0xd0, 0x74, 0xa1, 0xe9, 0x42, 0xd3, 0x85, 0xa6, 0x0b, 0x4d, 0x97, 0x7d, 0xdf,
		0xe2, 0xac, 0xf8, 0xc5, 0xef, 0x97, 0xb6, 0x49, 0x0a, 0x6f, 0xed, 0xbf, 0x71, 0x66, 0x1c, 0x71,
		0xe8, 0xa5, 0xfd, 0x60, 0x5a, 0x72, 0x68, 0xb8, 0xc2, 0xf4, 0x1c, 0x9b, 0x9f, 0x70, 0xbc, 0xea,
		0x1f, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x83, 0x7d, 0xdf, 0xca, 0xa1, 0xb0,
		0x7d, 0xe9, 0x3f, 0x6a, 0xe2, 0x1b, 0x8c, 0x37, 0x04, 0x0a, 0xcd, 0xe5, 0xab, 0x7e, 0x32, 0x3d,
		0x0d, 0x90, 0xb1, 0x1a, 0xf0, 0xe6, 0xe5, 0xb7, 0xfa, 0x79, 0xf3, 0xac, 0xdf, 0x69, 0x5d, 0x5f,
		0x35, 0xfa, 0x9d, 0x46, 0xbd, 0xdb, 0xba, 0xe4, 0x46, 0x8f, 0xf9, 0x45, 0x0d, 0x4f, 0x8b, 0xcc,
		0xa9, 0xe9, 0x66, 0xcc, 0xeb, 0xd1, 0xff, 0x7c, 0x7e, 0xdd, 0xbd, 0x6a, 0x74, 0xfa, 0xe7, 0xad,
		0x56, 0xbb, 0x90, 0x87, 0x8b, 0x49, 0x09, 0x19, 0xf7, 0x7a, 0x17, 0x43, 0xce, 0x3c, 0xe4, 0xad,
		0x4e, 0xf3, 0x6b, 0xf3, 0xb2, 0x7e, 0xd5, 0xea, 0x60, 0xd4, 0x19, 0x01, 0xa6, 0x75, 0xf9, 0xa5,
		0x71, 0x56, 0xc8, 0xf8, 0xbd, 0xb3, 0x5e, 0xd6, 0xf8, 0x5e, 0x26, 0xbc, 0x7b, 0xcb, 0xf4, 0x7c,
		0x63, 0xe4, 0x0c, 0xe5, 0x9d, 0x14, 0x43, 0x7e, 0xe7, 0x7e, 0xbd, 0x7b, 0xf8, 0xf6, 0xf0, 0xed,
		0xe1, 0xdb, 0xc3, 0xb7, 0x87, 0x6f, 0xcf, 0xbe, 0x6f, 0x7d, 0x39, 0x12, 0xbe, 0x1c, 0xfc, 0xe5,
		0x55, 0xcb, 0x1a, 0x7c, 0x7b, 0xc6, 0x40, 0xb5, 0xc2, 0xb5, 0xbd, 0xb8, 0xe7, 0x5f, 0xb0, 0x4d,
		0xdb, 0xf1, 0xc4, 0xc0, 0xb1, 0x87, 0xac, 0xf1, 0xf0, 0xc8, 0xa8, 0x92, 0x3d, 0x1b, 0xbf, 0x59,
		0x35, 0x41, 0x46, 0x15, 0xf6, 0x25, 0x87, 0x8c, 0x2a, 0x07, 0xc5, 0x0f, 0xe5, 0x72, 0xb5, 0x56,
		0x2e, 0x1f, 0xd7, 0x4e, 0x6a, 0xc7, 0xa7, 0x95, 0x4a, 0xb1, 0x5a, 0x44, 0x6e, 0x95, 0xcc, 0xf5,
		0x86, 0xb8, 0xb9, 0xdd, 0x97, 0x21, 0x57, 0xf9, 0xc2, 0x10, 0xa9, 0xe2, 0x29, 0x63, 0x18, 0x74,
		0x7b, 0x26, 0xee, 0xcc, 0x89, 0x35, 0xa7, 0xe2, 0xc7, 0xf0, 0xa5, 0xe1, 0x4b, 0xc3, 0x97, 0x86,
		0x2f, 0x0d, 0x5f, 0x1a, 0x89, 0x41, 0xe1, 0xc6, 0xc2, 0x8d, 0x85, 0x1b, 0x0b, 0x37, 0x36, 0x55,
		0x4b, 0x0e, 0x89, 0x41, 0xe1, 0xbc, 0xc2, 0x79, 0x3d, 0x28, 0x2c, 0x83, 0x9f, 0x9d, 0x89, 0x2f,
		0xf8, 0x1d, 0xd8, 0x97, 0x9d, 0xc3, 0xa1, 0x84, 0x43, 0x09, 0x87, 0x12, 0x0e, 0x25, 0x1c, 0x4a,
		0xf6, 0x7d, 0x8b, 0x42, 0x50, 0x09, 0xef, 0x41, 0x75, 0x2d, 0xeb, 0xba, 0x6d, 0x3b, 0xbe, 0x39,
		0x63, 0xa3, 0x3c, 0x25, 0xad, 0xbd, 0xc1, 0x77, 0x31, 0x32, 0x97, 0xa5, 0x27, 0x0b, 0x47, 0xce,
		0x58, 0xd8, 0x83, 0xb9, 0xa1, 0x9c, 0xe1, 0xc7, 0xd1, 0xec, 0x7f, 0xae, 0xbc, 0x3d, 0x32, 0xef,
		0xa4, 0xe1, 0x99, 0x77, 0xd2, 0x0b, 0x3e, 0x1d, 0xcd, 0x13, 0x91, 0x79, 0xae, 0x2f, 0x8c, 0xb1,
		0x63, 0xc9, 0xc1, 0xe3, 0x91, 0x2d, 0xe4, 0xfd, 0xf7, 0x5b, 0xc7, 0xf5, 0x82, 0x4f, 0x47, 0xe6,
		0xf0, 0x7f, 0x73, 0x28, 0x92, 0xb6, 0x31, 0x76, 0x3c, 0xff, 0x68, 0x4e, 0x2f, 0xbc, 0xc5, 0x1f,
		0x8b, 0x4b, 0x7a, 0x6a, 0x11, 0x4a, 0xdd, 0x52, 0x50, 0xb8, 0x0c, 0x0a, 0x13, 0xfb, 0x2f, 0xdb,
		0xf9, 0xdb, 0x36, 0x4c, 0xdf, 0x77, 0xe5, 0xed, 0x6c, 0xc4, 0x94, 0x2f, 0x85, 0x67, 0x41, 0x2b,
		0xdc, 0xb7, 0xe2, 0x05, 0xbf, 0x82, 0x1f, 0xc5, 0xdd, 0x70, 0xb1, 0x3f, 0x4e, 0xd6, 0xa7, 0x87,
		0xed, 0x71, 0xb3, 0x3c, 0x6d, 0xec, 0x4e, 0x1b, 0xab, 0xd3, 0xc6, 0xe6, 0xd2, 0x6d, 0x3a, 0xcf,
		0x24, 0x4f, 0x6d, 0xc6, 0x30, 0x48, 0xf2, 0xbb, 0xeb, 0xe1, 0x47, 0xe0, 0x75, 0xda, 0x8b, 0x70,
		0xda, 0xe1, 0xb4, 0xc3, 0x69, 0x87, 0xd3, 0x9e, 0x1c, 0xa7, 0x9d, 0x0b, 0xfe, 0x83, 0x0e, 0x67,
		0xd8, 0x6b, 0xf8, 0xdc, 0x52, 0xc1, 0x1a, 0x62, 0x3c, 0x3f, 0x02, 0xf3, 0xd2, 0xd5, 0x73, 0x74,
		0xc4, 0x6e, 0x0e, 0x74, 0x9a, 0x85, 0x64, 0x98, 0x07, 0xdd, 0x66, 0x22, 0x31, 0xe6, 0x22, 0x31,
		0x66, 0x23, 0x31, 0xe6, 0x83, 0xd7, 0x8c, 0x30, 0x9b, 0x93, 0x60, 0x94, 0xaf, 0x74, 0x00, 0xfc,
		0x81, 0xde, 0xc4, 0x5f, 0x21, 0xb6, 0x5f, 0xd3, 0x93, 0x5e, 0x7a, 0x95, 0x08, 0x6c, 0x91, 0xcf,
		0xeb, 0xd9, 0xd8, 0x65, 0xf4, 0xb0, 0x9c, 0x71, 0x69, 0x17, 0x16, 0xea, 0xab, 0x36, 0xe2, 0xb2,
		0xe8, 0x5e, 0x0f, 0x69, 0x29, 0x82, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x64, 0x97, 0xb4,
		0x70, 0xfb, 0xc2, 0xeb, 0x3e, 0xb1, 0x25, 0x34, 0xc6, 0xd1, 0xae, 0xb9, 0xc6, 0xb3, 0x27, 0x79,
		0x97, 0xcb, 0xe0, 0x4a, 0x5d, 0x46, 0x27, 0x09, 0xc6, 0x27, 0x59, 0x46, 0x28, 0x29, 0xc6, 0x28,
		0x71, 0x46, 0x29, 0x71, 0xc6, 0x29, 0x71, 0x46, 0x4a, 0x8f, 0xb1, 0xd2, 0x64, 0xb4, 0xf4, 0x7b,
		0xdc, 0x21, 0xdc, 0x98, 0x48, 0xdb, 0x2f, 0x56, 0x75, 0x62, 0xc6, 0xd2, 0x8a, 0x54, 0x35, 0x3e,
		0x82, 0x9e, 0xeb, 0x3f, 0xaf, 0x7f, 0xe9, 0xc5, 0xcc, 0x03, 0xdd, 0xd7, 0x83, 0x12, 0x46, 0x2f,
		0x42, 0x8f, 0xa3, 0xf9, 0xfa, 0x50, 0xe8, 0x79, 0x12, 0x70, 0xa5, 0x23, 0x21, 0x70, 0xba, 0xbe,
		0x84, 0xcd, 0x1f, 0x58, 0xc2, 0xbf, 0x58, 0xc2, 0xd5, 0x4a, 0xe5, 0xa4, 0x82, 0x65, 0x9c, 0x2c,
		0x2e, 0xa2, 0xbf, 0xf7, 0xde, 0x9b, 0x7c, 0xbc, 0xaf, 0x8e, 0x5b, 0x90, 0xfa, 0x4e, 0xd2, 0x37,
		0xcb, 0x06, 0x1a, 0x4e, 0xd4, 0xa1, 0x1b, 0x40, 0x37, 0x80, 0x6e, 0x00, 0xdd, 0x00, 0xba, 0x41,
		0x46, 0x74, 0x83, 0x0f, 0x09, 0x90, 0x0d, 0x2a, 0x90, 0x0d, 0x20, 0x1b, 0x40, 0x36, 0x80, 0x6c,
		0x00, 0xd9, 0x40, 0xf9, 0x12, 0x2e, 0x55, 0x20, 0x1a, 0x40, 0x34, 0x80, 0x68, 0xc0, 0x2b, 0x1a,
		0x3c, 0x2c, 0x77, 0x5f, 0x12, 0x54, 0x83, 0xc5, 0xb3, 0x40, 0x36, 0x80, 0x6c, 0x00, 0xd9, 0x00,
		0xb2, 0x01, 0x64, 0x03, 0xc8, 0x06, 0x7b, 0xe2, 0xc6, 0xad, 0xb4, 0x4d, 0xf7, 0x31, 0x01, 0xba,
		0xc1, 0xa9, 0xc6, 0x47, 0x38, 0x17, 0xf6, 0xfd, 0x3c, 0xf0, 0x1f, 0xc2, 0x01, 0x84, 0x83, 0x5f,
		0x7a, 0x5d, 0x45, 0xf8, 0x5c, 0x10, 0x0e, 0xd2, 0xbd, 0x84, 0x11, 0x6f, 0x00, 0xe9, 0x00, 0xd2,
		0x01, 0xeb, 0x32, 0x17, 0x3f, 0x7c, 0x61, 0x0f, 0x19, 0xab, 0x60, 0x6e, 0xa5, 0x7c, 0xc1, 0x93,
		0x40, 0x36, 0x80, 0x6c, 0x00, 0xd9, 0x00, 0xb2, 0x01, 0x64, 0x03, 0xc8, 0x06, 0xfb, 0xca, 0x06,
		0xec, 0x39, 0x63, 0xb7, 0x99, 0x11, 0xa6, 0x1c, 0xb2, 0xf9, 0x24, 0x2d, 0xce, 0x78, 0xc6, 0xcc,
		0x4d, 0x4b, 0x3f, 0x69, 0x09, 0x9e, 0x04, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4,
		0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x25, 0x3c, 0xc6, 0x63, 0xd3, 0xf5, 0x65, 0x12, 0x38, 0xcb,
		0xea, 0x41, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59,
		0x40, 0x59, 0xc2, 0x63, 0xec, 0xbb, 0xa6, 0xed, 0x49, 0x5f, 0x3e, 0x24, 0x20, 0xae, 0xf4, 0xc5,
		0xb3, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x24,
		0x9e, 0xb8, 0x64, 0x3a, 0xbd, 0x28, 0x73, 0x91, 0xc2, 0x50, 0xff, 0xfa, 0x8a, 0x16, 0x86, 0xeb,
		0xe3, 0x85, 0xff, 0x8a, 0xa3, 0xb2, 0xa1, 0xbe, 0xf5, 0x96, 0xad, 0xa2, 0x31, 0xff, 0x16, 0x8f,
		0x3a, 0xb2, 0xbe, 0x14, 0xce, 0xa5, 0xe7, 0xd7, 0x7d, 0x9f, 0xb9, 0x62, 0xcd, 0x85, 0xb4, 0x1b,
		0x96, 0x98, 0x51, 0x02, 0x8f, 0x97, 0x52, 0x17, 0x2e, 0xcc, 0x1f, 0x2f, 0x7a, 0x2e, 0x7e, 0x28,
		0x97, 0xab, 0xb5, 0x72, 0xf9, 0xb8, 0x76, 0x52, 0x3b, 0x3e, 0xad, 0x54, 0x8a, 0xd5, 0x22, 0x63,
		0x04, 0x6c, 0xa1, 0xe5, 0x0e, 0x85, 0x2b, 0x86, 0x9f, 0x66, 0x53, 0x6f, 0x4f, 0x2c, 0x2b, 0x53,
		0x2b, 0x5a, 0x13, 0x36, 0x27, 0x1c, 0x93, 0x0b, 0xac, 0xa5, 0x15, 0xdc, 0xc9, 0xc0, 0xb7, 0x97,
		0xe4, 0xeb, 0xd3, 0xfd, 0xb8, 0xdf, 0x91, 0xb7, 0xfd, 0xfa, 0x9d, 0xec, 0x9a, 0x77, 0xb2, 0xdf,
		0x1c, 0x3f, 0x94, 0xbb, 0xae, 0x2f, 0xda, 0xf3, 0x97, 0xed, 0x5f, 0x2e, 0x5f, 0xb1, 0x5f, 0x1f,
		0xfe, 0xaf, 0x23, 0x6f, 0x9b, 0x76, 0xdb, 0xf1, 0xfc, 0x7e, 0x67, 0xf6, 0x62, 0xfd, 0xeb, 0xc5,
		0x5b, 0xd4, 0x83, 0x97, 0x40, 0x85, 0x66, 0xfd, 0x1b, 0x2d, 0x47, 0x15, 0x9a, 0x37, 0x14, 0x03,
		0x4e, 0x6b, 0xb9, 0xe6, 0x37, 0x29, 0x5a, 0x69, 0x2b, 0x52, 0x32, 0x9b, 0x72, 0x43, 0x0e, 0x0f,
		0x84, 0x3d, 0x1c, 0x3b, 0xd2, 0xf6, 0x0f, 0x06, 0x8e, 0xe5, 0xb8, 0x8a, 0x90, 0x8c, 0x87, 0x91,
		0xf0, 0x31, 0x10, 0xad, 0x8c, 0x83, 0x87, 0x61, 0xa8, 0x5a, 0x7e, 0x4c, 0x00, 0xa7, 0x0f, 0xd8,
		0x14, 0x92, 0x01, 0x32, 0xe3, 0xaf, 0x06, 0x69, 0xe9, 0x71, 0x90, 0xb6, 0x45, 0xe2, 0x25, 0xad,
		0x7a, 0x29, 0xeb, 0x58, 0xc2, 0xb4, 0x0b, 0x83, 0x6e, 0xfa, 0x68, 0x5a, 0x22, 0x5a, 0x00, 0xaa,
		0x26, 0x9e, 0x75, 0xc2, 0x09, 0x61, 0x8a, 0x00, 0x96, 0x68, 0xd6, 0x5d, 0xfc, 0x55, 0x42, 0xb0,
		0x42, 0x0a, 0x2f, 0x07, 0xda, 0xa5, 0x13, 0xe9, 0x9f, 0xd3, 0x01, 0xad, 0xb7, 0x4f, 0xb4, 0xa6,
		0x69, 0xcb, 0xd7, 0x91, 0x1f, 0xad, 0xaa, 0x38, 0x2a, 0x55, 0x7b, 0xf4, 0xa9, 0xea, 0x28, 0x53,
		0xf9, 0xd1, 0xa4, 0xf2, 0xa3, 0x46, 0xe5, 0x47, 0x87, 0xc9, 0xb2, 0x16, 0xd4, 0xe5, 0xd2, 0x0a,
		0x4b, 0x53, 0x4d, 0xbe, 0xb0, 0x56, 0xdb, 0x61, 0xd9, 0x3e, 0xf1, 0xa4, 0xab, 0xa9, 0x8f, 0xa9,
		0x2c, 0x86, 0x43, 0x65, 0x6c, 0x06, 0x4f, 0xcc, 0x85, 0xea, 0x58, 0x0a, 0xb6, 0x18, 0x09, 0xb6,
		0xd8, 0x07, 0xb6, 0x98, 0x86, 0x64, 0xfb, 0x35, 0xaa, 0xea, 0x3b, 0x2e, 0x80, 0x45, 0xdd, 0x7a,
		0x5c, 0xc3, 0x2f, 0x55, 0x6b, 0x51, 0x6d, 0x99, 0x5f, 0xe5, 0x21, 0x69, 0x1c, 0x21, 0x67, 0xbc,
		0x21, 0x65, 0x5c, 0x21, 0x63, 0xec, 0x21, 0x61, 0xec, 0x21, 0x5f, 0xec, 0x21, 0x5d, 0xe9, 0x12,
		0xce, 0x55, 0x97, 0xbd, 0x2d, 0x2c, 0x14, 0x78, 0xe5, 0xeb, 0x78, 0xb5, 0x3b, 0x55, 0x0a, 0xfe,
		0xaf, 0xe1, 0x52, 0x71, 0x34, 0x00, 0x5b, 0x24, 0x2f, 0x67, 0xc4, 0xae, 0x9e, 0xc8, 0x5c, 0xee,
		0x08, 0x5c, 0x6d, 0x91, 0xb6, 0xda, 0x22, 0x6a, 0xb5, 0x45, 0xce, 0xa6, 0xfb, 0x64, 0x9c, 0x2d,
		0xe2, 0x35, 0xd8, 0x77, 0x96, 0x30, 0xef, 0x5c, 0x71, 0xc7, 0xb1, 0xe9, 0x56, 0xac, 0xb2, 0xc6,
		0xd0, 0x57, 0x7b, 0xa9, 0x2f, 0xbf, 0x7f, 0xbf, 0x88, 0x25, 0x3c, 0x5a, 0x18, 0x82, 0xb4, 0x1e,
		0xbe, 0x2b, 0x64, 0x96, 0xab, 0xb3, 0x71, 0x3e, 0x9b, 0x1c, 0xf4, 0x08, 0xb3, 0x0c, 0xb3, 0x0c,
		0xb3, 0x0c, 0xb3, 0x0c, 0xb3, 0x9c, 0x5b, 0xb3, 0x1c, 0xd8, 0x02, 0x58, 0xe6, 0xd0, 0x60, 0x2d,
		0xa3, 0xd7, 0xf8, 0x0c, 0xf3, 0xaa, 0x43, 0xd8, 0x65, 0xd8, 0x65, 0xd8, 0x65, 0xd8, 0x65, 0xd8,
		0xe5, 0xdc, 0xda, 0xe5, 0x95, 0x29, 0x80, 0x59, 0x0e, 0x8d, 0xd5, 0xe2, 0x6e, 0x22, 0x9b, 0x51,
		0x5e, 0x74, 0xc7, 0x63, 0x92, 0x8b, 0x30, 0xc9, 0x30, 0xc9, 0x30, 0xc9, 0x30, 0xc9, 0xd1, 0x47,
		0x4d, 0xf5, 0x01, 0x62, 0xd0, 0xd1, 0xfc, 0xc2, 0xb1, 0xb4, 0x87, 0x82, 0x2f, 0xb5, 0xcc, 0x7a,
		0xb1, 0xca, 0x45, 0xdf, 0x5c, 0xb7, 0xac, 0x59, 0x93, 0x08, 0xb1, 0x27, 0x0d, 0xd2, 0x91, 0x24,
		0x48, 0x6f, 0x52, 0x20, 0x5d, 0x49, 0x80, 0xb4, 0x27, 0xfd, 0xd1, 0x9e, 0xe4, 0x47, 0x7b, 0x52,
		0x9f, 0x6c, 0xe5, 0x7f, 0x60, 0x4f, 0xd2, 0xa3, 0xc1, 0x17, 0xd3, 0xe1, 0x93, 0x6d, 0xf2, 0xcd,
		0xfe, 0xe1, 0xf7, 0xdc, 0x24, 0x79, 0xc2, 0xf7, 0x82, 0x4f, 0x4b, 0x4f, 0x6e, 0x61, 0xa6, 0xb2,
		0x72, 0xef, 0x9d, 0x81, 0x59, 0xf3, 0x44, 0x28, 0x85, 0x56, 0x33, 0x47, 0xa4, 0x12, 0xe8, 0x04,
		0xe8, 0x04, 0xe8, 0x04, 0xe8, 0x04, 0xe8, 0xc4, 0x86, 0x7d, 0x3b, 0x91, 0xb6, 0x7f, 0x52, 0xd2,
		0xc0, 0x26, 0x38, 0xc9, 0x44, 0xc7, 0xb4, 0xef, 0x05, 0x7b, 0x69, 0x68, 0x0d, 0x09, 0xee, 0x74,
		0x96, 0x7e, 0xd6, 0x9d, 0xf2, 0x77, 0x55, 0x17, 0x57, 0x57, 0xff, 0x09, 0xa8, 0x81, 0xab, 0x23,
		0xed, 0xb5, 0xce, 0x52, 0xcd, 0x49, 0x59, 0x72, 0xe5, 0xd2, 0x69, 0xf9, 0xb4, 0x5a, 0x2b, 0x9d,
		0x56, 0x72, 0xbc, 0xf6, 0x32, 0x9a, 0xb7, 0xb2, 0x07, 0x27, 0x72, 0x0f, 0x27, 0x72, 0x34, 0x9a,
		0xd8, 0xd2, 0x7f, 0xd4, 0x25, 0x51, 0xbf, 0x7e, 0x00, 0x38, 0x96, 0x70, 0x2c, 0xe1, 0x58, 0xc2,
		0xb1, 0x84, 0x63, 0xc9, 0xbe, 0x6f, 0xa1, 0x53, 0xbf, 0xf8, 0xbd, 0xb2, 0x4b, 0x52, 0x78, 0xc1,
		0xe7, 0x47, 0x48, 0xd5, 0xd1, 0x86, 0x9c, 0xed, 0xee, 0x4e, 0x68, 0x4d, 0x33, 0xdd, 0xe1, 0x01,
		0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0xd8, 0xb0, 0x6f, 0xe5, 0xd8, 0x30, 0x87,
		0x43, 0x57, 0x78, 0x9e, 0x0e, 0x6a, 0x71, 0xca, 0xd8, 0xe7, 0x72, 0x8c, 0x33, 0x2f, 0x5a, 0x3f,
		0xcf, 0xec, 0x43, 0x59, 0xc3, 0xdc, 0x86, 0xe6, 0xf8, 0x83, 0x86, 0xbe, 0xdb, 0xa6, 0xef, 0x0b,
		0xd7, 0x66, 0x9f, 0xee, 0xe0, 0x01, 0xfe, 0x7c, 0xfb, 0xf6, 0xe6, 0xd8, 0x38, 0xed, 0x3d, 0xdd,
		0x14, 0x8d, 0xd3, 0xde, 0xe2, 0x63, 0x71, 0xfe, 0xc7, 0xe2, 0x73, 0xe9, 0xe6, 0xd8, 0x28, 0xaf,
		0x3e, 0x57, 0x6e, 0x8e, 0x8d, 0x4a, 0xef, 0xf0, 0x8f, 0x3f, 0xde, 0x1f, 0xfe, 0x3c, 0x99, 0xee,
		0xff, 0xc5, 0x7f, 0xf1, 0xd7, 0x12, 0xeb, 0xe9, 0x98, 0xd4, 0x56, 0xb7, 0xf9, 0x3b, 0x66, 0x56,
		0xf5, 0xcc, 0x66, 0xb9, 0x64, 0x96, 0x5e, 0x38, 0xae, 0x02, 0x8e, 0xf5, 0x6e, 0x5a, 0xd3, 0xb8,
		0xab, 0x1b, 0x5f, 0x7a, 0x3f, 0x8b, 0xef, 0xca, 0xd3, 0x8f, 0x87, 0x3f, 0x6b, 0xd3, 0xd7, 0x7f,
		0xf9, 0xb4, 0xe9, 0xc7, 0x8a, 0xef, 0x6a, 0xd3, 0x8f, 0x5b, 0xfe, 0xa5, 0x3a, 0xfd, 0xb8, 0x63,
		0x1b, 0x95, 0xe9, 0xdb, 0xd0, 0x8f, 0xce, 0xfe, 0xbe, 0xb4, 0xed, 0x0b, 0xe5, 0x2d, 0x5f, 0x38,
		0xd9, 0xf6, 0x85, 0x93, 0x2d, 0x5f, 0xd8, 0xfa, 0x48, 0xa5, 0x2d, 0x5f, 0xa8, 0x4c, 0x9f, 0x42,
		0x3f, 0xff, 0x76, 0xf3, 0x8f, 0x56, 0xa7, 0x87, 0x4f, 0xdb, 0xfe, 0xad, 0x36, 0x7d, 0xfa, 0x78,
		0x08, 0xe3, 0x84, 0x75, 0x8e, 0x75, 0x9e, 0x09, 0x53, 0x8d, 0x33, 0xe2, 0x24, 0xaa, 0xb7, 0x3f,
		0x7c, 0x43, 0xfb, 0x39, 0xf1, 0xa6, 0x87, 0x80, 0xa6, 0x0b, 0x4d, 0x17, 0x9a, 0x2e, 0x34, 0x5d,
		0x68, 0xba, 0xec, 0xfb, 0x16, 0x67, 0xc5, 0x2f, 0x7e, 0xbf, 0xb4, 0x4d, 0x52, 0x78, 0x6b, 0xff,
		0x8d, 0x33, 0xe3, 0x88, 0x43, 0x2f, 0xed, 0x07, 0xd3, 0x92, 0x43, 0xc3, 0x15, 0xa6, 0xc7, 0x58,
		0xe1, 0xf6, 0x59, 0x4c, 0x59, 0xef, 0x1f, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03, 0x5c,
		0x83, 0x7d, 0xdf, 0xca, 0xa1, 0xb0, 0x7d, 0xe9, 0x3f, 0x6a, 0xe2, 0x1b, 0x9c, 0xf5, 0xea, 0x9b,
		0xcb, 0x57, 0xfd, 0x64, 0x7a, 0x1a, 0x20, 0x63, 0x35, 0xe0, 0xcd, 0xcb, 0x6f, 0xf5, 0xf3, 0xe6,
		0x59, 0xbf, 0xd3, 0xba, 0xbe, 0x6a, 0xf4, 0x3b, 0x8d, 0x7a, 0xb7, 0x75, 0xc9, 0x8d, 0x1e, 0xf3,
		0x8b, 0x1a, 0x9e, 0x16, 0x99, 0x53, 0xd3, 0xcd, 0x98, 0xd7, 0xa3, 0xff, 0xf9, 0xfc, 0xba, 0x7b,
		0xd5, 0xe8, 0xf4, 0xcf, 0x5b, 0xad, 0x76, 0x21, 0x0f, 0x17, 0x93, 0x12, 0x32, 0xee, 0xf5, 0x2e,
		0x86, 0x9c, 0x79, 0xc8, 0x5b, 0x9d, 0xe6, 0xd7, 0xe6, 0x65, 0xfd, 0xaa, 0xd5, 0xc1, 0xa8, 0x33,
		0x02, 0x4c, 0xeb, 0xf2, 0x4b, 0xe3, 0xac, 0x90, 0xf1, 0x7b, 0x67, 0xbd, 0xac, 0xf1, 0xbd, 0x4c,
		0x78, 0xf7, 0x96, 0xe9, 0xf9, 0xc6, 0xc8, 0x19, 0xca, 0x3b, 0x29, 0x86, 0xfc, 0xce, 0xfd, 0x7a,
		0xf7, 0xf0, 0xed, 0xe1, 0xdb, 0xc3, 0xb7, 0x87, 0x6f, 0x0f, 0xdf, 0x9e, 0x7d, 0xdf, 0xfa, 0x72,
		0x24, 0x7c, 0x39, 0xf8, 0xcb, 0xab, 0x96, 0x35, 0xf8, 0xf6, 0x8c, 0x81, 0x6a, 0x85, 0x6b, 0x7b,
		0x71, 0xcf, 0xbf, 0x60, 0x9b, 0xb6, 0xe3, 0x89, 0x81, 0x63, 0x0f, 0x59, 0xe3, 0xe1, 0x91, 0x51,
		0x25, 0x7b, 0x36, 0x7e, 0xb3, 0x6a, 0x82, 0x8c, 0x2a, 0xec, 0x4b, 0x0e, 0x19, 0x55, 0x0e, 0x8a,
		0x1f, 0xca, 0xe5, 0x6a, 0xad, 0x5c, 0x3e, 0xae, 0x9d, 0xd4, 0x8e, 0x4f, 0x2b, 0x95, 0x62, 0xb5,
		0x88, 0xdc, 0x2a, 0x99, 0xeb, 0x0d, 0x71, 0x73, 0xbb, 0x2f, 0x43, 0xae, 0xba, 0x48, 0x21, 0x52,
		0xc5, 0x53, 0x1f, 0x29, 0xe8, 0xf6, 0x4c, 0xdc, 0x99, 0x13, 0x6b, 0x4e, 0xc5, 0x8f, 0xe1, 0x4b,
		0xc3, 0x97, 0x86, 0x2f, 0x0d, 0x5f, 0x1a, 0xbe, 0x34, 0x12, 0x83, 0xc2, 0x8d, 0x85, 0x1b, 0x0b,
		0x37, 0x16, 0x6e, 0x6c, 0xaa, 0x96, 0x1c, 0x12, 0x83, 0xc2, 0x79, 0x85, 0xf3, 0x7a, 0x50, 0x58,
		0x06, 0x3f, 0x3b, 0x13, 0x5f, 0xf0, 0x3b, 0xb0, 0x2f, 0x3b, 0x87, 0x43, 0x09, 0x87, 0x12, 0x0e,
		0x25, 0x1c, 0x4a, 0x38, 0x94, 0xec, 0xfb, 0xf6, 0xd6, 0x71, 0x2c, 0x61, 0xda, 0x3a, 0x82, 0xae,
		0x8b, 0x59, 0x31, 0xd5, 0xa9, 0x2e, 0x92, 0x59, 0xb7, 0x6d, 0xc7, 0x37, 0x67, 0x6c, 0x94, 0xa7,
		0x56, 0xa6, 0x37, 0xf8, 0x2e, 0x46, 0xe6, 0x78, 0x79, 0xe9, 0xee, 0xc8, 0x19, 0x0b, 0x7b, 0x30,
		0x37, 0x94, 0x33, 0xfc, 0x38, 0x9a, 0xfd, 0xcf, 0x95, 0xb7, 0x47, 0xe6, 0x9d, 0x34, 0x3c, 0xf3,
		0x4e, 0x7a, 0xc1, 0xa7, 0xa3, 0x79, 0x22, 0x32, 0xcf, 0xf5, 0x85, 0x31, 0x76, 0x2c, 0x39, 0x78,
		0x3c, 0xb2, 0x85, 0xbc, 0xff, 0x7e, 0xeb, 0xb8, 0x5e, 0xf0, 0xe9, 0xc8, 0x1c, 0xfe, 0x6f, 0x0e,
		0x45, 0xd2, 0x36, 0xc6, 0xae, 0x38, 0x9a, 0xb3, 0x0b, 0x6f, 0xf1, 0xc7, 0xe2, 0x8e, 0x1e, 0x8a,
		0x48, 0x87, 0x67, 0x64, 0x62, 0xff, 0x65, 0x3b, 0x7f, 0xdb, 0x86, 0xe9, 0xfb, 0xae, 0xbc, 0x9d,
		0x8d, 0x18, 0x5f, 0x45, 0xe9, 0x0d, 0x7d, 0xa3, 0xbc, 0x74, 0x52, 0x49, 0x1f, 0xca, 0x4b, 0x67,
		0x93, 0xd4, 0xa1, 0xbc, 0x74, 0xa4, 0x51, 0x63, 0x2b, 0x2f, 0x1d, 0x02, 0x49, 0x7e, 0x6f, 0x3d,
		0xfc, 0x08, 0xbc, 0x3e, 0x7b, 0x11, 0x3e, 0x3b, 0x7c, 0x76, 0xf8, 0xec, 0xf0, 0xd9, 0x93, 0xe3,
		0xb3, 0x73, 0xc1, 0x7f, 0xd0, 0xe1, 0xbc, 0x98, 0xb2, 0xcf, 0xad, 0x14, 0xac, 0x21, 0xc6, 0xf3,
		0x23, 0x30, 0x2f, 0x5d, 0x3d, 0x27, 0x47, 0xec, 0xe6, 0x40, 0xa7, 0x59, 0x48, 0x86, 0x79, 0xd0,
		0x6d, 0x26, 0x12, 0x63, 0x2e, 0x12, 0x63, 0x36, 0x12, 0x63, 0x3e, 0x78, 0xcd, 0x08, 0xb3, 0x39,
		0x09, 0x46, 0xf9, 0x4a, 0x07, 0xc0, 0x1f, 0xe8, 0xcd, 0xfb, 0x15, 0x62, 0xfb, 0x35, 0x3d, 0xd9,
		0xa5, 0x57, 0x79, 0xc0, 0x16, 0xe9, 0xbc, 0x9e, 0x8d, 0x5d, 0x46, 0xcf, 0xca, 0x19, 0x97, 0x76,
		0x61, 0xa1, 0xbe, 0x6a, 0x23, 0x2e, 0x8b, 0xee, 0xf5, 0x90, 0x96, 0x22, 0x48, 0x0b, 0x48, 0x0b,
		0x48, 0x0b, 0x48, 0x4b, 0x76, 0x49, 0x0b, 0xb7, 0x2f, 0xbc, 0xee, 0x13, 0x5b, 0x42, 0x63, 0x18,
		0xed, 0x9a, 0x6b, 0x3c, 0x7b, 0x92, 0x77, 0xb9, 0x8c, 0xad, 0xd4, 0x65, 0x74, 0x92, 0x60, 0x7c,
		0x92, 0x65, 0x84, 0x92, 0x62, 0x8c, 0x12, 0x67, 0x94, 0x12, 0x67, 0x9c, 0x12, 0x67, 0xa4, 0xf4,
		0x18, 0x2b, 0x4d, 0x46, 0x4b, 0xbf, 0xc7, 0x1d, 0xc2, 0x8d, 0x89, 0xb4, 0xfd, 0x62, 0x55, 0x27,
		0x66, 0x2c, 0xad, 0x48, 0x55, 0xe3, 0x23, 0xe8, 0xb9, 0xfd, 0xf3, 0xfa, 0x97, 0x5e, 0xcc, 0x3c,
		0xd0, 0x7d, 0x3b, 0x28, 0x61, 0xf4, 0x22, 0xf4, 0x38, 0x9a, 0x6f, 0x0f, 0x85, 0x9e, 0x27, 0x01,
		0x37, 0x3a, 0x12, 0x02, 0xa7, 0xeb, 0x4b, 0xd8, 0xfc, 0x81, 0x25, 0xfc, 0x8b, 0x25, 0x5c, 0xad,
		0x54, 0x4e, 0x2a, 0x58, 0xc6, 0xc9, 0xe2, 0x22, 0xfa, 0x7b, 0xef, 0xbd, 0xc9, 0xc7, 0xfb, 0xea,
		0xb8, 0x04, 0xa9, 0xef, 0x24, 0x7d, 0xb3, 0x6c, 0xa0, 0xe1, 0x44, 0x1d, 0xba, 0x01, 0x74, 0x03,
		0xe8, 0x06, 0xd0, 0x0d, 0xa0, 0x1b, 0x64, 0x44, 0x37, 0xf8, 0x90, 0x00, 0xd9, 0xa0, 0x02, 0xd9,
		0x00, 0xb2, 0x01, 0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x94, 0x2f, 0xe1, 0x52, 0x05, 0xa2, 0x01,
		0x44, 0x03, 0x88, 0x06, 0xbc, 0xa2, 0xc1, 0xc3, 0x72, 0xf7, 0x25, 0x41, 0x35, 0x58, 0x3c, 0x0b,
		0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b, 0x40, 0x36, 0x80, 0x6c, 0xb0, 0x27, 0x6e, 0xdc,
		0x4a, 0xdb, 0x74, 0x1f, 0x13, 0xa0, 0x1b, 0x9c, 0x6a, 0x7c, 0x84, 0x73, 0x61, 0xdf, 0xcf, 0x03,
		0xff, 0x21, 0x1c, 0x40, 0x38, 0xf8, 0xa5, 0xd7, 0x55, 0x84, 0xcf, 0x05, 0xe1, 0x20, 0xdd, 0x4b,
		0x18, 0xf1, 0x06, 0x90, 0x0e, 0x20, 0x1d, 0xb0, 0x2e, 0x73, 0xf1, 0xc3, 0x17, 0xf6, 0x90, 0xb1,
		0x08, 0xe6, 0x56, 0xca, 0x17, 0x3c, 0x09, 0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b, 0x40,
		0x36, 0x80, 0x6c, 0xb0, 0xaf, 0x6c, 0xc0, 0x9e, 0x32, 0x76, 0x9b, 0x19, 0x61, 0x4a, 0x21, 0x9b,
		0x4f, 0xd2, 0xe2, 0x8c, 0x67, 0xcc, 0xdc, 0xb4, 0xf4, 0x93, 0x96, 0xe0, 0x49, 0x40, 0x5a, 0x40,
		0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0xc2, 0x63, 0x3c,
		0x36, 0x5d, 0x5f, 0x26, 0x81, 0xb3, 0xac, 0x1e, 0x04, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94,
		0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x25, 0x3c, 0xc6, 0xbe, 0x6b, 0xda, 0x9e, 0xf4,
		0xe5, 0x43, 0x02, 0xe2, 0x4a, 0x5f, 0x3c, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b,
		0x88, 0x0b, 0x88, 0x0b, 0x88, 0x4b, 0xe2, 0x89, 0x4b, 0xa6, 0xd3, 0x8b, 0x32, 0xd7, 0x28, 0x0c,
		0xf5, 0xaf, 0xad, 0x66, 0x61, 0xb8, 0x3c, 0x5e, 0xf8, 0xaf, 0x38, 0x0a, 0x1b, 0xea, 0x5b, 0x6e,
		0xd9, 0xaa, 0x19, 0xf3, 0x6f, 0xf1, 0xa8, 0x23, 0xe9, 0x4b, 0xe1, 0x5c, 0x7a, 0x7e, 0xdd, 0xf7,
		0x99, 0x0b, 0xd6, 0x5c, 0x48, 0xbb, 0x61, 0x89, 0x19, 0x23, 0xf0, 0x78, 0x19, 0x75, 0xe1, 0xc2,
		0xfc, 0xf1, 0xa2, 0xe7, 0xe2, 0x87, 0x72, 0xb9, 0x5a, 0x2b, 0x97, 0x8f, 0x6b, 0x27, 0xb5, 0xe3,
		0xd3, 0x4a, 0xa5, 0x58, 0x2d, 0x32, 0x06, 0xc0, 0x16, 0x5a, 0xee, 0x50, 0xb8, 0x62, 0xf8, 0x69,
		0x36, 0xf5, 0xf6, 0xc4, 0xb2, 0x32, 0xb5, 0xa2, 0x35, 0x41, 0x73, 0xb2, 0x21, 0xb9, 0xc0, 0x5a,
		0x58, 0xc1, 0x9d, 0x0c, 0x7c, 0x7b, 0x49, 0xbd, 0x3e, 0xdd, 0x8f, 0xfb, 0x1d, 0x79, 0xdb, 0xaf,
		0xdf, 0xc9, 0xae, 0x79, 0x27, 0xfb, 0xcd, 0xf1, 0x43, 0xb9, 0xeb, 0xfa, 0xa2, 0x3d, 0x7f, 0xd7,
		0xfe, 0xe5, 0xf2, 0x0d, 0xfb, 0xf5, 0xe1, 0xff, 0x3a, 0xf2, 0xb6, 0x69, 0xb7, 0x5d, 0xd1, 0xef,
		0xcc, 0xde, 0xab, 0x7f, 0xbd, 0x78, 0x89, 0x7a, 0xf0, 0x0e, 0xa8, 0xce, 0xac, 0x7f, 0x9b, 0xe5,
		0xa7, 0x3a, 0xf3, 0x86, 0x42, 0xc0, 0x69, 0x2d, 0xd5, 0xfc, 0x26, 0x45, 0x0b, 0x6d, 0xc5, 0x48,
		0x66, 0x33, 0x6e, 0xc8, 0xe1, 0x81, 0xb0, 0x87, 0x63, 0x47, 0xda, 0xfe, 0xc1, 0xc0, 0xb1, 0x1c,
		0x57, 0x11, 0x8e, 0xf1, 0xd0, 0x11, 0x3e, 0xfa, 0xa1, 0x95, 0x6e, 0xf0, 0xd0, 0x0b, 0x55, 0xcb,
		0x8f, 0x09, 0xdf, 0xb4, 0xe1, 0x9a, 0x42, 0x26, 0x40, 0x65, 0xf9, 0xd5, 0xe0, 0x2c, 0x3d, 0x0a,
		0xd2, 0xb6, 0x48, 0xbc, 0xa0, 0x55, 0x2f, 0x64, 0x0d, 0x0b, 0x98, 0x76, 0x5d, 0xd0, 0xcd, 0x1e,
		0x4d, 0x4b, 0x44, 0xf3, 0xaf, 0x6a, 0xde, 0x39, 0xe7, 0x9b, 0x10, 0xa3, 0xe2, 0x63, 0x12, 0xcd,
		0xaa, 0x8b, 0xbf, 0x46, 0x08, 0xd6, 0x47, 0x61, 0x35, 0xcc, 0xce, 0xc4, 0x37, 0xc6, 0x8e, 0xe7,
		0x93, 0xad, 0x90, 0xe7, 0x3c, 0x40, 0xaf, 0x7b, 0x20, 0x5a, 0xd5, 0xb4, 0x95, 0xeb, 0xc8, 0x4f,
		0x55, 0x55, 0x9c, 0x92, 0xaa, 0x3d, 0xf5, 0x54, 0x75, 0x8a, 0xa9, 0xfc, 0x54, 0x52, 0xf9, 0x29,
		0xa3, 0xf2, 0x53, 0xc3, 0x64, 0xd9, 0x0b, 0xea, 0x4a, 0x69, 0x85, 0xa5, 0xb1, 0x26, 0x5f, 0x58,
		0xab, 0xed, 0xb0, 0x6c, 0x9f, 0x78, 0xd2, 0xd5, 0x94, 0xc6, 0x54, 0x16, 0xbe, 0xa1, 0x32, 0x2c,
		0x83, 0x27, 0xdc, 0x42, 0x75, 0x18, 0x05, 0x5b, 0x78, 0x04, 0x5b, 0xd8, 0x03, 0x5b, 0x38, 0x43,
		0xb2, 0x1d, 0x1b, 0x55, 0xa5, 0x1d, 0x17, 0xc0, 0xa2, 0x6e, 0x3d, 0xae, 0xe1, 0x97, 0xaa, 0xb5,
		0xa8, 0xb6, 0xc2, 0xaf, 0xf2, 0x68, 0x34, 0x8e, 0x68, 0x33, 0xde, 0x68, 0x32, 0xae, 0x68, 0x31,
		0xf6, 0x68, 0x30, 0xf6, 0x68, 0x2f, 0xf6, 0x68, 0xae, 0x74, 0xe9, 0xe6, 0xaa, 0x2b, 0xde, 0x16,
		0x16, 0x02, 0xbc, 0xf2, 0x75, 0xbc, 0xda, 0x9d, 0x2a, 0xf5, 0xfe, 0xd7, 0x70, 0xa9, 0x38, 0x12,
		0x80, 0x2d, 0x88, 0x97, 0x33, 0x58, 0x57, 0x4f, 0x50, 0x2e, 0x77, 0xf0, 0xad, 0xb6, 0x20, 0x5b,
		0x6d, 0xc1, 0xb4, 0xda, 0x82, 0x66, 0xd3, 0x7d, 0x2e, 0xce, 0x16, 0xec, 0x1a, 0xec, 0x3b, 0x4b,
		0x98, 0x77, 0xae, 0xb8, 0xe3, 0xd8, 0x74, 0x2b, 0x56, 0x59, 0x63, 0xe8, 0xab, 0xbd, 0x54, 0x98,
		0xdf, 0xbf, 0x5f, 0xc4, 0x11, 0x1e, 0x2d, 0x0c, 0x41, 0x5a, 0xcf, 0xde, 0x15, 0x32, 0xcb, 0xd5,
		0xd1, 0x38, 0x9f, 0x4d, 0x0e, 0x7a, 0x84, 0x59, 0x86, 0x59, 0x86, 0x59, 0x86, 0x59, 0x86, 0x59,
		0xce, 0xad, 0x59, 0x0e, 0x6c, 0x01, 0x2c, 0x73, 0x68, 0xb0, 0x96, 0xc1, 0x6b, 0x7c, 0x86, 0x79,
		0xd5, 0x21, 0xec, 0x32, 0xec, 0x32, 0xec, 0x32, 0xec, 0x32, 0xec, 0x72, 0x6e, 0xed, 0xf2, 0xca,
		0x14, 0xc0, 0x2c, 0x87, 0xc6, 0x6a, 0x71, 0x2f, 0x91, 0xcd, 0x28, 0x2f, 0xba, 0xe3, 0x31, 0xc9,
		0x45, 0x98, 0x64, 0x98, 0x64, 0x98, 0x64, 0x98, 0xe4, 0xe8, 0xa3, 0xa6, 0xfa, 0x00, 0x31, 0xe8,
		0x68, 0x7e, 0xd9, 0x58, 0xda, 0x43, 0xc1, 0x97, 0x55, 0x66, 0xbd, 0x4e, 0xe5, 0xa2, 0x6f, 0xae,
		0x1b, 0xd6, 0xac, 0xf9, 0x83, 0xd8, 0xf3, 0x05, 0xe9, 0xc8, 0x0f, 0xa4, 0x37, 0x1f, 0x90, 0xae,
		0xfc, 0x3f, 0xda, 0xf3, 0xfd, 0x68, 0xcf, 0xef, 0xa3, 0x3d, 0x9f, 0x4f, 0xb6, 0x72, 0x3f, 0xb0,
		0xe7, 0xe7, 0xd1, 0xe0, 0x8b, 0xe9, 0xf0, 0xc9, 0x36, 0xf9, 0x66, 0xff, 0xf0, 0x7b, 0x6e, 0x92,
		0x3c, 0xe1, 0x7b, 0xc1, 0xa7, 0xa5, 0x27, 0xb7, 0x30, 0x53, 0x59, 0xb9, 0xf5, 0xce, 0xc0, 0xac,
		0x79, 0x22, 0x94, 0x42, 0xab, 0x99, 0x23, 0x52, 0x09, 0x74, 0x02, 0x74, 0x02, 0x74, 0x02, 0x74,
		0x02, 0x74, 0x62, 0xc3, 0xbe, 0x9d, 0x48, 0xdb, 0x3f, 0x29, 0x69, 0x60, 0x13, 0x9c, 0x64, 0xa2,
		0x63, 0xda, 0xf7, 0x82, 0xbd, 0x2a, 0xb4, 0x86, 0xdc, 0x76, 0x3a, 0xab, 0x3e, 0xeb, 0xce, 0xf6,
		0xbb, 0x2a, 0x89, 0xab, 0xab, 0xff, 0x04, 0x94, 0xbf, 0xd5, 0x91, 0xf1, 0x5a, 0x67, 0x95, 0xe6,
		0xa4, 0x2c, 0xb9, 0x72, 0xe9, 0xb4, 0x7c, 0x5a, 0xad, 0x95, 0x4e, 0x2b, 0x39, 0x5e, 0x7b, 0x19,
		0xcd, 0x59, 0xd9, 0x83, 0x13, 0xb9, 0x87, 0x13, 0x39, 0x1a, 0x4d, 0x6c, 0xe9, 0x3f, 0xea, 0x92,
		0xa8, 0x5f, 0x3f, 0x00, 0x1c, 0x4b, 0x38, 0x96, 0x70, 0x2c, 0xe1, 0x58, 0xc2, 0xb1, 0x64, 0xdf,
		0xb7, 0xd0, 0xa9, 0x5f, 0xfc, 0x5e, 0xd9, 0x25, 0x29, 0xbc, 0xe0, 0xf3, 0x23, 0xa4, 0xea, 0x68,
		0x43, 0xce, 0x76, 0x77, 0x27, 0xb4, 0xa6, 0x99, 0xee, 0xf0, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57,
		0x80, 0x57, 0x80, 0x57, 0x6c, 0xd8, 0xb7, 0x72, 0x6c, 0x98, 0xc3, 0xa1, 0x2b, 0x3c, 0x4f, 0x07,
		0xb5, 0x38, 0x65, 0xec, 0x73, 0x39, 0xc6, 0x99, 0x17, 0xad, 0x9f, 0x67, 0xf6, 0xa1, 0xac, 0x61,
		0x6e, 0x43, 0x73, 0xfc, 0x41, 0x43, 0xdf, 0x6d, 0xd3, 0xf7, 0x85, 0x6b, 0xb3, 0x4f, 0x77, 0xf0,
		0x00, 0x7f, 0xbe, 0x7d, 0x7b, 0x73, 0x6c, 0x9c, 0xf6, 0x9e, 0x6e, 0x8a, 0xc6, 0x69, 0x6f, 0xf1,
		0xb1, 0x38, 0xff, 0x63, 0xf1, 0xb9, 0x74, 0x73, 0x6c, 0x94, 0x57, 0x9f, 0x2b, 0x37, 0xc7, 0x46,
		0xa5, 0x77, 0xf8, 0xc7, 0x1f, 0xef, 0x0f, 0x7f, 0x9e, 0x4c, 0xf7, 0xff, 0xe2, 0xbf, 0xf8, 0xcb,
		0x88, 0xf5, 0x74, 0x4c, 0x6a, 0xab, 0xdb, 0xfc, 0x1d, 0x33, 0xab, 0x7a, 0x66, 0xb3, 0x5c, 0x2d,
		0x4b, 0x2f, 0x1c, 0x57, 0x01, 0xc7, 0x7a, 0x37, 0xad, 0x69, 0xdc, 0xd5, 0x8d, 0x2f, 0xbd, 0x9f,
		0xc5, 0x77, 0xe5, 0xe9, 0xc7, 0xc3, 0x9f, 0xb5, 0xe9, 0xeb, 0xbf, 0x7c, 0xda, 0xf4, 0x63, 0xc5,
		0x77, 0xb5, 0xe9, 0xc7, 0x2d, 0xff, 0x52, 0x9d, 0x7e, 0xdc, 0xb1, 0x8d, 0xca, 0xf4, 0x6d, 0xe8,
		0x47, 0x67, 0x7f, 0x5f, 0xda, 0xf6, 0x85, 0xf2, 0x96, 0x2f, 0x9c, 0x6c, 0xfb, 0xc2, 0xc9, 0x96,
		0x2f, 0x6c, 0x7d, 0xa4, 0xd2, 0x96, 0x2f, 0x54, 0xa6, 0x4f, 0xa1, 0x9f, 0x7f, 0xbb, 0xf9, 0x47,
		0xab, 0xd3, 0xc3, 0xa7, 0x6d, 0xff, 0x56, 0x9b, 0x3e, 0x7d, 0x3c, 0x84, 0x71, 0xc2, 0x3a, 0xc7,
		0x3a, 0xcf, 0x84, 0xa9, 0xc6, 0x19, 0x71, 0x12, 0xd5, 0xdb, 0x1f, 0xbe, 0xa1, 0xfd, 0x9c, 0x78,
		0xd3, 0x43, 0x40, 0xd3, 0x85, 0xa6, 0x0b, 0x4d, 0x17, 0x9a, 0x2e, 0x34, 0x5d, 0xf6, 0x7d, 0x8b,
		0xb3, 0xe2, 0x17, 0xbf, 0x5f, 0xda, 0x26, 0x29, 0xbc, 0xb5, 0xff, 0xc6, 0x99, 0x71, 0xc4, 0xa1,
		0x97, 0xf6, 0x83, 0x69, 0xc9, 0xa1, 0xe1, 0x0a, 0xd3, 0x63, 0xac, 0x6e, 0xfb, 0x2c, 0xa6, 0xac,
		0xf7, 0x0f, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0xc1, 0xbe, 0x6f, 0xe5, 0x50,
		0xd8, 0xbe, 0xf4, 0x1f, 0x35, 0xf1, 0x0d, 0xce, 0x5a, 0xf5, 0xcd, 0xe5, 0xab, 0x7e, 0x32, 0x3d,
		0x0d, 0x90, 0xb1, 0x1a, 0xf0, 0xe6, 0xe5, 0xb7, 0xfa, 0x79, 0xf3, 0xac, 0xdf, 0x69, 0x5d, 0x5f,
		0x35, 0xfa, 0x9d, 0x46, 0xbd, 0xdb, 0xba, 0xe4, 0x46, 0x8f, 0xf9, 0x45, 0x0d, 0x4f, 0x8b, 0xcc,
		0xa9, 0xe9, 0x66, 0xcc, 0xeb, 0xd1, 0xff, 0x7c, 0x7e, 0xdd, 0xbd, 0x6a, 0x74, 0xfa, 0xe7, 0xad,
		0x56, 0xbb, 0x90, 0x87, 0x8b, 0x49, 0x09, 0x19, 0xf7, 0x7a, 0x17, 0x43, 0xce, 0x3c, 0xe4, 0xad,
		0x4e, 0xf3, 0x6b, 0xf3, 0xb2, 0x7e, 0xd5, 0xea, 0x60, 0xd4, 0x19, 0x01, 0xa6, 0x75, 0xf9, 0xa5,
		0x71, 0x56, 0xc8, 0xf8, 0xbd, 0xb3, 0x5e, 0xd6, 0xf8, 0x5e, 0x26, 0xbc, 0x7b, 0xcb, 0xf4, 0x7c,
		0x63, 0xe4, 0x0c, 0xe5, 0x9d, 0x14, 0x43, 0x7e, 0xe7, 0x7e, 0xbd, 0x7b, 0xf8, 0xf6, 0xf0, 0xed,
		0xe1, 0xdb, 0xc3, 0xb7, 0x87, 0x6f, 0xcf, 0xbe, 0x6f, 0x7d, 0x39, 0x12, 0xbe, 0x1c, 0xfc, 0xe5,
		0x55, 0xcb, 0x1a, 0x7c, 0x7b, 0xc6, 0x40, 0xb5, 0xc2, 0xb5, 0xbd, 0xb8, 0xe7, 0x5f, 0xb0, 0x4d,
		0xdb, 0xf1, 0xc4, 0xc0, 0xb1, 0x87, 0xac, 0xf1, 0xf0, 0xc8, 0xa8, 0x92, 0x3d, 0x1b, 0xbf, 0x59,
		0x35, 0x41, 0x46, 0x15, 0xf6, 0x25, 0x87, 0x8c, 0x2a, 0x07, 0xc5, 0x0f, 0xe5, 0x72, 0xb5, 0x56,
		0x2e, 0x1f, 0xd7, 0x4e, 0x6a, 0xc7, 0xa7, 0x95, 0x4a, 0xb1, 0x5a, 0x44, 0x6e, 0x95, 0xcc, 0xf5,
		0x86, 0xb8, 0xb9, 0xdd, 0x97, 0x21, 0x57, 0x5d, 0xa4, 0x10, 0xa9, 0xe2, 0xa9, 0x8f, 0x14, 0x74,
		0x7b, 0x26, 0xee, 0xcc, 0x89, 0x35, 0xa7, 0xe2, 0xc7, 0xf0, 0xa5, 0xe1, 0x4b, 0xc3, 0x97, 0x86,
		0x2f, 0x0d, 0x5f, 0x1a, 0x89, 0x41, 0xe1, 0xc6, 0xc2, 0x8d, 0x85, 0x1b, 0x0b, 0x37, 0x36, 0x55,
		0x4b, 0x0e, 0x89, 0x41, 0xe1, 0xbc, 0xc2, 0x79, 0x3d, 0x28, 0x2c, 0x83, 0x9f, 0x9d, 0x89, 0x2f,
		0xf8, 0x1d, 0xd8, 0x97, 0x9d, 0xc3, 0xa1, 0x84, 0x43, 0x09, 0x87, 0x12, 0x0e, 0x25, 0x1c, 0x4a,
		0xf6, 0x7d, 0x7b, 0xeb, 0x38, 0x96, 0x30, 0x6d, 0x1d, 0x41, 0xd7, 0xc5, 0xac, 0x98, 0xea, 0x54,
		0x17, 0xc9, 0xac, 0xdb, 0xb6, 0xe3, 0x9b, 0x33, 0x36, 0xca, 0x53, 0x2b, 0xd3, 0x1b, 0x7c, 0x17,
		0x23, 0x73, 0xbc, 0xbc, 0x74, 0x77, 0xe4, 0x8c, 0x85, 0x3d, 0x98, 0x1b, 0xca, 0x19, 0x7e, 0x1c,
		0xcd, 0xfe, 0xe7, 0xca, 0xdb, 0x23, 0xf3, 0x4e, 0x1a, 0x9e, 0x79, 0x27, 0xbd, 0xe0, 0xd3, 0xd1,
		0x3c, 0x11, 0x99, 0xe7, 0xfa, 0xc2, 0x18, 0x3b, 0x96, 0x1c, 0x3c, 0x1e, 0xd9, 0x42, 0xde, 0x7f,
		0xbf, 0x75, 0x5c, 0x2f, 0xf8, 0x74, 0x64, 0x0e, 0xff, 0x37, 0x87, 0x22, 0x67, 0xe2, 0x1b, 0x63,
		0xc7, 0xf3, 0x8f, 0xe6, 0xfc, 0xc2, 0x5b, 0xfc, 0xb1, 0xb8, 0xa5, 0x87, 0x32, 0xd2, 0xe1, 0x39,
		0x99, 0xd8, 0x7f, 0xd9, 0xce, 0xdf, 0xb6, 0x61, 0xfa, 0xbe, 0x2b, 0x6f, 0x67, 0x23, 0xc6, 0x57,
		0x53, 0x7a, 0x43, 0xdf, 0x28, 0x30, 0x9d, 0x54, 0xda, 0x87, 0x02, 0xd3, 0xd9, 0xa4, 0x75, 0x28,
		0x30, 0x1d, 0x69, 0xd4, 0xd8, 0x0a, 0x4c, 0x87, 0x40, 0x92, 0xdf, 0x5f, 0x0f, 0x3f, 0x02, 0xaf,
		0xd7, 0x5e, 0x84, 0xd7, 0x0e, 0xaf, 0x1d, 0x5e, 0x3b, 0xbc, 0xf6, 0xe4, 0x78, 0xed, 0x5c, 0xf0,
		0x1f, 0x74, 0x38, 0x2f, 0xa7, 0xec, 0x73, 0x6b, 0x05, 0x6b, 0x88, 0xf1, 0xfc, 0x08, 0xcc, 0x4b,
		0x57, 0xcf, 0xd9, 0x11, 0xbb, 0x39, 0xd0, 0x69, 0x16, 0x92, 0x61, 0x1e, 0x74, 0x9b, 0x89, 0xc4,
		0x98, 0x8b, 0xc4, 0x98, 0x8d, 0xc4, 0x98, 0x0f, 0x5e, 0x33, 0xc2, 0x6c, 0x4e, 0x82, 0x51, 0xbe,
		0xd2, 0x01, 0xf0, 0x07, 0x7a, 0x33, 0x7f, 0x85, 0xd8, 0x7e, 0x4d, 0x4f, 0x7e, 0xe9, 0x55, 0x26,
		0xb0, 0x45, 0x42, 0xaf, 0x67, 0x63, 0x97, 0xd1, 0xd3, 0x72, 0xc6, 0xa5, 0x5d, 0x58, 0xa8, 0xaf,
		0xda, 0x88, 0xcb, 0xa2, 0x7b, 0x3d, 0xa4, 0xa5, 0x08, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2,
		0x92, 0x5d, 0xd2, 0xc2, 0xed, 0x0b, 0xaf, 0xfb, 0xc4, 0x96, 0xd0, 0x18, 0x48, 0xbb, 0xe6, 0x1a,
		0xcf, 0x9e, 0xe4, 0x5d, 0x2e, 0xa3, 0x2b, 0x75, 0x19, 0x9d, 0x24, 0x18, 0x9f, 0x64, 0x19, 0xa1,
		0xa4, 0x18, 0xa3, 0xc4, 0x19, 0xa5, 0xc4, 0x19, 0xa7, 0xc4, 0x19, 0x29, 0x3d, 0xc6, 0x4a, 0x93,
		0xd1, 0xd2, 0xef, 0x71, 0x87, 0x70, 0x63, 0x22, 0x6d, 0xbf, 0x58, 0xd5, 0x89, 0x19, 0x4b, 0x2b,
		0x52, 0xd5, 0xf8, 0x08, 0x7a, 0xee, 0xff, 0xbc, 0xfe, 0xa5, 0x17, 0x33, 0x0f, 0x74, 0xdf, 0x0f,
		0x4a, 0x18, 0xbd, 0x08, 0x3d, 0x8e, 0xe6, 0xfb, 0x43, 0xa1, 0xe7, 0x49, 0xc0, 0x9d, 0x8e, 0x84,
		0xc0, 0xe9, 0xfa, 0x12, 0x36, 0x7f, 0x60, 0x09, 0xff, 0x62, 0x09, 0x57, 0x2b, 0x95, 0x93, 0x0a,
		0x96, 0x71, 0xb2, 0xb8, 0x88, 0xfe, 0xde, 0x7b, 0x6f, 0xf2, 0xf1, 0xbe, 0x3a, 0xae, 0x41, 0xea,
		0x3b, 0x49, 0xdf, 0x2c, 0x1b, 0x68, 0x38, 0x51, 0x87, 0x6e, 0x00, 0xdd, 0x00, 0xba, 0x01, 0x74,
		0x03, 0xe8, 0x06, 0x19, 0xd1, 0x0d, 0x3e, 0x24, 0x40, 0x36, 0xa8, 0x40, 0x36, 0x80, 0x6c, 0x00,
		0xd9, 0x00, 0xb2, 0x01, 0x64, 0x03, 0xe5, 0x4b, 0xb8, 0x54, 0x81, 0x68, 0x00, 0xd1, 0x00, 0xa2,
		0x01, 0xaf, 0x68, 0xf0, 0xb0, 0xdc, 0x7d, 0x49, 0x50, 0x0d, 0x16, 0xcf, 0x02, 0xd9, 0x00, 0xb2,
		0x01, 0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b, 0xec, 0x89, 0x1b, 0xb7, 0xd2, 0x36, 0xdd,
		0xc7, 0x04, 0xe8, 0x06, 0xa7, 0x1a, 0x1f, 0xe1, 0x5c, 0xd8, 0xf7, 0xf3, 0xc0, 0x7f, 0x08, 0x07,
		0x10, 0x0e, 0x7e, 0xe9, 0x75, 0x15, 0xe1, 0x73, 0x41, 0x38, 0x48, 0xf7, 0x12, 0x46, 0xbc, 0x01,
		0xa4, 0x03, 0x48, 0x07, 0xac, 0xcb, 0x5c, 0xfc, 0xf0, 0x85, 0x3d, 0x64, 0x2c, 0x83, 0xb9, 0x95,
		0xf2, 0x05, 0x4f, 0x02, 0xd9, 0x00, 0xb2, 0x01, 0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b,
		0xec, 0x2b, 0x1b, 0xb0, 0x27, 0x8d, 0xdd, 0x66, 0x46, 0x98, 0x92, 0xc8, 0xe6, 0x93, 0xb4, 0x38,
		0xe3, 0x19, 0x33, 0x37, 0x2d, 0xfd, 0xa4, 0x25, 0x78, 0x12, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16,
		0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x96, 0xf0, 0x18, 0x8f, 0x4d, 0xd7, 0x97,
		0x49, 0xe0, 0x2c, 0xab, 0x07, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01,
		0x65, 0x01, 0x65, 0x01, 0x65, 0x09, 0x8f, 0xb1, 0xef, 0x9a, 0xb6, 0x27, 0x7d, 0xf9, 0x90, 0x80,
		0xb8, 0xd2, 0x17, 0xcf, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2,
		0x02, 0xe2, 0x92, 0x78, 0xe2, 0x92, 0xe9, 0xf4, 0xa2, 0xcc, 0x55, 0x0a, 0x43, 0xfd, 0x6b, 0xac,
		0x5a, 0x18, 0x2e, 0x90, 0x17, 0xfe, 0x2b, 0x8e, 0xd2, 0x86, 0xfa, 0x16, 0x5c, 0xb6, 0xaa, 0xc6,
		0xfc, 0x5b, 0x3c, 0xea, 0x48, 0xfb, 0x52, 0x38, 0x97, 0x9e, 0x5f, 0xf7, 0x7d, 0xe6, 0x92, 0x35,
		0x17, 0xd2, 0x6e, 0x58, 0x62, 0xc6, 0x09, 0x3c, 0x5e, 0x4e, 0x5d, 0xb8, 0x30, 0x7f, 0xbc, 0xe8,
		0xb9, 0xf8, 0xa1, 0x5c, 0xae, 0xd6, 0xca, 0xe5, 0xe3, 0xda, 0x49, 0xed, 0xf8, 0xb4, 0x52, 0x29,
		0x56, 0x8b, 0x8c, 0x21, 0xb0, 0x85, 0x96, 0x3b, 0x14, 0xae, 0x18, 0x7e, 0x9a, 0x4d, 0xbd, 0x3d,
		0xb1, 0xac, 0x4c, 0xad, 0x68, 0x4d, 0xe0, 0x9c, 0x74, 0x50, 0x2e, 0xb0, 0x16, 0x57, 0x70, 0x27,
		0x03, 0xdf, 0x5e, 0xd2, 0xaf, 0x4f, 0xf7, 0xe3, 0x7e, 0x47, 0xde, 0xf6, 0xeb, 0x77, 0xb2, 0x6b,
		0xde, 0xc9, 0x7e, 0x73, 0xfc, 0x50, 0xee, 0xba, 0xbe, 0x68, 0xcf, 0xdf, 0xb6, 0x7f, 0xb9, 0x7c,
		0xc7, 0x7e, 0x7d, 0xf8, 0xbf, 0x8e, 0xbc, 0x6d, 0x4d, 0xfc, 0xb6, 0xe3, 0xf9, 0xfd, 0xce, 0xec,
		0xcd, 0xfa, 0xd7, 0x8b, 0xd7, 0xa8, 0x07, 0x6f, 0x81, 0x2a, 0xcd, 0xfa, 0xb7, 0x5a, 0x9e, 0xaa,
		0x34, 0x6f, 0x28, 0x08, 0x9c, 0xd6, 0x92, 0xcd, 0x6f, 0x52, 0xb4, 0xd4, 0x56, 0xbc, 0x64, 0x36,
		0xe7, 0x86, 0x1c, 0x1e, 0x08, 0x7b, 0x38, 0x76, 0xa4, 0xed, 0x1f, 0x0c, 0x1c, 0xcb, 0x71, 0x15,
		0x61, 0x19, 0x0f, 0x29, 0xe1, 0x23, 0x21, 0x5a, 0x49, 0x07, 0x0f, 0xc9, 0x50, 0xb5, 0xfc, 0x98,
		0x10, 0x4e, 0x23, 0xb2, 0x29, 0xe4, 0x03, 0x74, 0xf6, 0x5f, 0x0d, 0xd6, 0xd2, 0x23, 0x21, 0x6d,
		0x8b, 0xc4, 0x8b, 0x5a, 0xf5, 0x62, 0xd6, 0xb2, 0x88, 0x69, 0x57, 0x06, 0xdd, 0xfc, 0xd1, 0xb4,
		0x44, 0xb4, 0x02, 0x54, 0xcd, 0x3c, 0xef, 0x8c, 0x13, 0x22, 0x15, 0x05, 0x32, 0xd1, 0xac, 0xbc,
		0xf8, 0xeb, 0x84, 0x60, 0x8d, 0x14, 0xd6, 0x86, 0xda, 0xa5, 0x93, 0xeb, 0x9f, 0x13, 0x03, 0xbd,
		0xea, 0x80, 0x68, 0x5d, 0xd3, 0x56, 0xb2, 0x23, 0x3f, 0x65, 0x55, 0x71, 0x6a, 0xaa, 0xf6, 0x14,
		0x54, 0xd5, 0xa9, 0xa6, 0xf2, 0x53, 0x4a, 0xe5, 0xa7, 0x8e, 0xca, 0x4f, 0x11, 0x93, 0x65, 0x31,
		0xa8, 0x2b, 0xa7, 0x15, 0x96, 0xe6, 0x9a, 0x7c, 0x61, 0xad, 0xb6, 0xc3, 0xb2, 0x7d, 0xe2, 0x49,
		0x57, 0x53, 0x2a, 0x53, 0x59, 0x38, 0x87, 0xca, 0x30, 0x0d, 0x9e, 0xf0, 0x0b, 0xd5, 0x61, 0x15,
		0x6c, 0xe1, 0x12, 0x6c, 0x61, 0x10, 0x6c, 0xe1, 0x0d, 0xc9, 0x76, 0x6e, 0x54, 0x95, 0x7a, 0x5c,
		0x00, 0x8b, 0xba, 0xf5, 0xb8, 0x86, 0x5f, 0xaa, 0xd6, 0xa2, 0xda, 0x8a, 0xbf, 0xca, 0xa3, 0xd3,
		0x38, 0xa2, 0xcf, 0x78, 0xa3, 0xcb, 0xb8, 0xa2, 0xc7, 0xd8, 0xa3, 0xc3, 0xd8, 0xa3, 0xbf, 0xd8,
		0xa3, 0xbb, 0xd2, 0xa5, 0x9f, 0xab, 0xae, 0x80, 0x5b, 0x58, 0x08, 0xf1, 0xca, 0xd7, 0xf1, 0x6a,
		0x77, 0xaa, 0xd4, 0xfd, 0x5f, 0xc3, 0xa5, 0xe2, 0xb8, 0x00, 0xb6, 0xa0, 0x5e, 0xce, 0xe0, 0x5d,
		0x3d, 0x41, 0xba, 0xdc, 0xc1, 0xb8, 0xda, 0x82, 0x6e, 0xb5, 0x05, 0xd7, 0x6a, 0x0b, 0xa2, 0x4d,
		0xf7, 0x09, 0x39, 0x5b, 0xf0, 0x6b, 0xb0, 0xef, 0x2c, 0x61, 0xde, 0xb9, 0xe2, 0x8e, 0x63, 0xd3,
		0xad, 0x58, 0x65, 0x8d, 0xa1, 0xaf, 0xf6, 0x52, 0x63, 0x7e, 0xff, 0x7e, 0x11, 0x55, 0x78, 0xb4,
		0x30, 0x04, 0x69, 0x3d, 0x83, 0x57, 0xc8, 0x2c, 0x57, 0x47, 0xe4, 0x7c, 0x36, 0x39, 0xe8, 0x11,
		0x66, 0x19, 0x66, 0x19, 0x66, 0x19, 0x66, 0x19, 0x66, 0x39, 0xb7, 0x66, 0x39, 0xb0, 0x05, 0xb0,
		0xcc, 0xa1, 0xc1, 0x5a, 0x06, 0xb1, 0xf1, 0x19, 0xe6, 0x55, 0x87, 0xb0, 0xcb, 0xb0, 0xcb, 0xb0,
		0xcb, 0xb0, 0xcb, 0xb0, 0xcb, 0xb9, 0xb5, 0xcb, 0x2b, 0x53, 0x00, 0xb3, 0x1c, 0x1a, 0xab, 0xc5,
		0x2d, 0x45, 0x36, 0xa3, 0xbc, 0xe8, 0x8e, 0xc7, 0x24, 0x17, 0x61, 0x92, 0x61, 0x92, 0x61, 0x92,
		0x61, 0x92, 0xa3, 0x8f, 0x9a, 0xea, 0x03, 0xc4, 0xa0, 0xa3, 0xf9, 0xd5, 0x63, 0x69, 0x0f, 0x05,
		0x5f, 0x96, 0x99, 0xf5, 0xba, 0x95, 0x8b, 0xbe, 0xb9, 0xee, 0x5b, 0xb3, 0xe6, 0x13, 0x62, 0xcf,
		0x1f, 0xa4, 0x23, 0x5f, 0x90, 0xde, 0xfc, 0x40, 0xba, 0xf2, 0x01, 0x69, 0xcf, 0xff, 0xa3, 0x3d,
		0xdf, 0x8f, 0xf6, 0xfc, 0x3e, 0xd9, 0xca, 0x04, 0xc1, 0x9e, 0xaf, 0x47, 0x83, 0x2f, 0xa6, 0xc3,
		0x27, 0xdb, 0xe4, 0x9b, 0xfd, 0xc3, 0xef, 0xb9, 0x49, 0xf2, 0x84, 0xef, 0x05, 0x9f, 0x96, 0x9e,
		0xdc, 0xc2, 0x4c, 0x65, 0xe5, 0xfe, 0x3b, 0x03, 0xb3, 0xe6, 0x89, 0x50, 0x0a, 0xad, 0x66, 0x8e,
		0x48, 0x25, 0xd0, 0x09, 0xd0, 0x09, 0xd0, 0x09, 0xd0, 0x09, 0xd0, 0x89, 0x0d, 0xfb, 0x76, 0x22,
		0x6d, 0xff, 0xa4, 0xa4, 0x81, 0x4d, 0x70, 0x92, 0x89, 0x8e, 0x69, 0xdf, 0x0b, 0xf6, 0x2a, 0xd1,
		0x1a, 0x72, 0xdd, 0xe9, 0xac, 0x02, 0xad, 0x3b, 0xfb, 0xef, 0xaa, 0x44, 0xae, 0xae, 0xfe, 0x13,
		0x50, 0x0e, 0x57, 0x47, 0x06, 0x6c, 0x9d, 0x55, 0x9b, 0x93, 0xb2, 0xe4, 0xca, 0xa5, 0xd3, 0xf2,
		0x69, 0xb5, 0x56, 0x3a, 0xad, 0xe4, 0x78, 0xed, 0x65, 0x34, 0x83, 0x65, 0x0f, 0x4e, 0xe4, 0x1e,
		0x4e, 0xe4, 0x68, 0x34, 0xb1, 0xa5, 0xff, 0xa8, 0x4b, 0xa2, 0x7e, 0xfd, 0x00, 0x70, 0x2c, 0xe1,
		0x58, 0xc2, 0xb1, 0x84, 0x63, 0x09, 0xc7, 0x92, 0x7d, 0xdf, 0x42, 0xa7, 0x7e, 0xf1, 0x7b, 0x65,
		0x97, 0xa4, 0xf0, 0x82, 0xcf, 0x8f, 0x90, 0xaa, 0xa3, 0x0d, 0x39, 0xdb, 0xdd, 0x9d, 0xd0, 0x9a,
		0x66, 0xba, 0xc3, 0x03, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0xb1, 0x61, 0xdf,
		0xca, 0xb1, 0x61, 0x0e, 0x87, 0xae, 0xf0, 0x3c, 0x1d, 0xd4, 0xe2, 0x94, 0xb1, 0xcf, 0xe5, 0x18,
		0x67, 0x5e, 0xb4, 0x7e, 0x9e, 0xd9, 0x87, 0xb2, 0x86, 0xb9, 0x0d, 0xcd, 0xf1, 0x07, 0x0d, 0x7d,
		0xb7, 0x4d, 0xdf, 0x17, 0xae, 0xcd, 0x3e, 0xdd, 0xc1, 0x03, 0xfc, 0xf9, 0xf6, 0xed, 0xcd, 0xb1,
		0x71, 0xda, 0x7b, 0xba, 0x29, 0x1a, 0xa7, 0xbd, 0xc5, 0xc7, 0xe2, 0xfc, 0x8f, 0xc5, 0xe7, 0xd2,
		0xcd, 0xb1, 0x51, 0x5e, 0x7d, 0xae, 0xdc, 0x1c, 0x1b, 0x95, 0xde, 0xe1, 0x1f, 0x7f, 0xbc, 0x3f,
		0xfc, 0x79, 0x32, 0xdd, 0xff, 0x8b, 0xff, 0xe2, 0x2f, 0x2b, 0xd6, 0xd3, 0x31, 0xa9, 0xad, 0x6e,
		0xf3, 0x77, 0xcc, 0xac, 0xea, 0x99, 0xcd, 0x72, 0xf5, 0x2c, 0xbd, 0x70, 0x5c, 0x05, 0x1c, 0xeb,
		0xdd, 0xb4, 0xa6, 0x71, 0x57, 0x37, 0xbe, 0xf4, 0x7e, 0x16, 0xdf, 0x95, 0xa7, 0x1f, 0x0f, 0x7f,
		0xd6, 0xa6, 0xaf, 0xff, 0xf2, 0x69, 0xd3, 0x8f, 0x15, 0xdf, 0xd5, 0xa6, 0x1f, 0xb7, 0xfc, 0x4b,
		0x75, 0xfa, 0x71, 0xc7, 0x36, 0x2a, 0xd3, 0xb7, 0xa1, 0x1f, 0x9d, 0xfd, 0x7d, 0x69, 0xdb, 0x17,
		0xca, 0x5b, 0xbe, 0x70, 0xb2, 0xed, 0x0b, 0x27, 0x5b, 0xbe, 0xb0, 0xf5, 0x91, 0x4a, 0x5b, 0xbe,
		0x50, 0x99, 0x3e, 0x85, 0x7e, 0xfe, 0xed, 0xe6, 0x1f, 0xad, 0x4e, 0x0f, 0x9f, 0xb6, 0xfd, 0x5b,
		0x6d, 0xfa, 0xf4, 0xf1, 0x10, 0xc6, 0x09, 0xeb, 0x1c, 0xeb, 0x3c, 0x13, 0xa6, 0x1a, 0x67, 0xc4,
		0x49, 0x54, 0x6f, 0x7f, 0xf8, 0x86, 0xf6, 0x73, 0xe2, 0x4d, 0x0f, 0x01, 0x4d, 0x17, 0x9a, 0x2e,
		0x34, 0x5d, 0x68, 0xba, 0xd0, 0x74, 0xd9, 0xf7, 0x2d, 0xce, 0x8a, 0x5f, 0xfc, 0x7e, 0x69, 0x9b,
		0xa4, 0xf0, 0xd6, 0xfe, 0x1b, 0x67, 0xc6, 0x11, 0x87, 0x5e, 0xda, 0x0f, 0xa6, 0x25, 0x87, 0x86,
		0x2b, 0x4c, 0x8f, 0xb1, 0xd6, 0xed, 0xb3, 0x98, 0xb2, 0xde, 0x3f, 0xb8, 0x06, 0xb8, 0x06, 0xb8,
		0x06, 0xb8, 0x06, 0xb8, 0x06, 0xfb, 0xbe, 0x95, 0x43, 0x61, 0xfb, 0xd2, 0x7f, 0xd4, 0xc4, 0x37,
		0x38, 0x2b, 0xd7, 0x37, 0x97, 0xaf, 0xfa, 0xc9, 0xf4, 0x34, 0x40, 0xc6, 0x6a, 0xc0, 0x9b, 0x97,
		0xdf, 0xea, 0xe7, 0xcd, 0xb3, 0x7e, 0xa7, 0x75, 0x7d, 0xd5, 0xe8, 0x77, 0x1a, 0xf5, 0x6e, 0xeb,
		0x92, 0x1b, 0x3d, 0xe6, 0x17, 0x35, 0x3c, 0x2d, 0x32, 0xa7, 0xa6, 0x9b, 0x31, 0xaf, 0x47, 0xff,
		0xf3, 0xf9, 0x75, 0xf7, 0xaa, 0xd1, 0xe9, 0x9f, 0xb7, 0x5a, 0xed, 0x42, 0x1e, 0x2e, 0x26, 0x25,
		0x64, 0xdc, 0xeb, 0x5d, 0x0c, 0x39, 0xf3, 0x90, 0xb7, 0x3a, 0xcd, 0xaf, 0xcd, 0xcb, 0xfa, 0x55,
		0xab, 0x83, 0x51, 0x67, 0x04, 0x98, 0xd6, 0xe5, 0x97, 0xc6, 0x59, 0x21, 0xe3, 0xf7, 0xce, 0x7a,
		0x59, 0xe3, 0x7b, 0x99, 0xf0, 0xee, 0x2d, 0xd3, 0xf3, 0x8d, 0x91, 0x33, 0x94, 0x77, 0x52, 0x0c,
		0xf9, 0x9d, 0xfb, 0xf5, 0xee, 0xe1, 0xdb, 0xc3, 0xb7, 0x87, 0x6f, 0x0f, 0xdf, 0x1e, 0xbe, 0x3d,
		0xfb, 0xbe, 0xf5, 0xe5, 0x48, 0xf8, 0x72, 0xf0, 0x97, 0x57, 0x2d, 0x6b, 0xf0, 0xed, 0x19, 0x03,
		0xd5, 0x0a, 0xd7, 0xf6, 0xe2, 0x9e, 0x7f, 0xc1, 0x36, 0x6d, 0xc7, 0x13, 0x03, 0xc7, 0x1e, 0xb2,
		0xc6, 0xc3, 0x23, 0xa3, 0x4a, 0xf6, 0x6c, 0xfc, 0x66, 0xd5, 0x04, 0x19, 0x55, 0xd8, 0x97, 0x1c,
		0x32, 0xaa, 0x1c, 0x14, 0x3f, 0x94, 0xcb, 0xd5, 0x5a, 0xb9, 0x7c, 0x5c, 0x3b, 0xa9, 0x1d, 0x9f,
		0x56, 0x2a, 0xc5, 0x6a, 0x11, 0xb9, 0x55, 0x32, 0xd7, 0x1b, 0xe2, 0xe6, 0x76, 0x5f, 0x86, 0x5c,
		0x75, 0x91, 0x42, 0xa4, 0x8a, 0xa7, 0x3e, 0x52, 0xd0, 0xed, 0x99, 0xb8, 0x33, 0x27, 0xd6, 0x9c,
		0x8a, 0x1f, 0xc3, 0x97, 0x86, 0x2f, 0x0d, 0x5f, 0x1a, 0xbe, 0x34, 0x7c, 0x69, 0x24, 0x06, 0x85,
		0x1b, 0x0b, 0x37, 0x16, 0x6e, 0x2c, 0xdc, 0xd8, 0x54, 0x2d, 0x39, 0x24, 0x06, 0x85, 0xf3, 0x0a,
		0xe7, 0xf5, 0xa0, 0xb0, 0x0c, 0x7e, 0x76, 0x26, 0xbe, 0xe0, 0x77, 0x60, 0x5f, 0x76, 0x0e, 0x87,
		0x12, 0x0e, 0x25, 0x1c, 0x4a, 0x38, 0x94, 0x70, 0x28, 0xd9, 0xf7, 0xed, 0xad, 0xe3, 0x58, 0xc2,
		0xb4, 0x75, 0x04, 0x5d, 0x17, 0xb3, 0x62, 0xaa, 0x53, 0x5d, 0x24, 0xb3, 0x6e, 0xdb, 0x8e, 0x6f,
		0xce, 0xd8, 0x28, 0x4f, 0xad, 0x4c, 0x6f, 0xf0, 0x5d, 0x8c, 0xcc, 0xf1, 0xf2, 0xd2, 0xdd, 0x91,
		0x33, 0x16, 0xf6, 0x60, 0x6e, 0x28, 0x67, 0xf8, 0x71, 0x34, 0xfb, 0x9f, 0x2b, 0x6f, 0x8f, 0xcc,
		0x3b, 0x69, 0x78, 0xe6, 0x9d, 0xf4, 0x82, 0x4f, 0x47, 0xf3, 0x44, 0x64, 0x9e, 0xeb, 0x0b, 0x63,
		0xec, 0x58, 0x72, 0xf0, 0x78, 0x64, 0x0b, 0x79, 0xff, 0xfd, 0xd6, 0x71, 0xbd, 0xe0, 0xd3, 0x91,
		0x39, 0xfc, 0xdf, 0x1c, 0x8a, 0x9c, 0x89, 0x6f, 0x8c, 0x5d, 0x71, 0x34, 0xa7, 0x17, 0xde, 0xe2,
		0x8f, 0xc5, 0x25, 0x3d, 0x54, 0x91, 0x0e, 0x4f, 0xc9, 0xc4, 0xfe, 0xcb, 0x76, 0xfe, 0xb6, 0x0d,
		0xd3, 0xf7, 0x5d, 0x79, 0x3b, 0x1b, 0x31, 0xbe, 0x92, 0xd2, 0x1b, 0xfa, 0x46, 0x7d, 0xe9, 0xa4,
		0xb2, 0x3e, 0xd4, 0x97, 0xce, 0x26, 0xab, 0x43, 0x7d, 0xe9, 0x48, 0xa3, 0xc6, 0x56, 0x5f, 0x3a,
		0x04, 0x92, 0xfc, 0xee, 0x7a, 0xf8, 0x11, 0x78, 0x9d, 0xf6, 0x22, 0x9c, 0x76, 0x38, 0xed, 0x70,
		0xda, 0xe1, 0xb4, 0x27, 0xc7, 0x69, 0xe7, 0x82, 0xff, 0xa0, 0xc3, 0x79, 0x35, 0x65, 0x9f, 0x5b,
		0x2a, 0x58, 0x43, 0x8c, 0xe7, 0x47, 0x60, 0x5e, 0xba, 0x7a, 0x8e, 0x8e, 0xd8, 0xcd, 0x81, 0x4e,
		0xb3, 0x90, 0x0c, 0xf3, 0xa0, 0xdb, 0x4c, 0x24, 0xc6, 0x5c, 0x24, 0xc6, 0x6c, 0x24, 0xc6, 0x7c,
		0xf0, 0x9a, 0x11, 0x66, 0x73, 0x12, 0x8c, 0xf2, 0x95, 0x0e, 0x80, 0x3f, 0xd0, 0x9b, 0xf8, 0x2b,
		0xc4, 0xf6, 0x6b, 0x7a, 0xd2, 0x4b, 0xaf, 0x12, 0x81, 0x2d, 0xf2, 0x79, 0x3d, 0x1b, 0xbb, 0x8c,
		0x1e, 0x96, 0x33, 0x2e, 0xed, 0xc2, 0x42, 0x7d, 0xd5, 0x46, 0x5c, 0x16, 0xdd, 0xeb, 0x21, 0x2d,
		0x45, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x96, 0xec, 0x92, 0x16, 0x6e, 0x5f, 0x78, 0xdd,
		0x27, 0xb6, 0x84, 0xc6, 0x38, 0xda, 0x35, 0xd7, 0x78, 0xf6, 0x24, 0xef, 0x72, 0x19, 0x5c, 0xa9,
		0xcb, 0xe8, 0x24, 0xc1, 0xf8, 0x24, 0xcb, 0x08, 0x25, 0xc5, 0x18, 0x25, 0xce, 0x28, 0x25, 0xce,
		0x38, 0x25, 0xce, 0x48, 0xe9, 0x31, 0x56, 0x9a, 0x8c, 0x96, 0x7e, 0x8f, 0x3b, 0x84, 0x1b, 0x13,
		0x69, 0xfb, 0xc5, 0xaa, 0x4e, 0xcc, 0x58, 0x5a, 0x91, 0xaa, 0xc6, 0x47, 0xd0, 0x73, 0xfd, 0xe7,
		0xf5, 0x2f, 0xbd, 0x98, 0x79, 0xa0, 0xfb, 0x7a, 0x50, 0xc2, 0xe8, 0x45, 0xe8, 0x71, 0x34, 0x5f,
		0x1f, 0x0a, 0x3d, 0x4f, 0x02, 0xae, 0x74, 0x24, 0x04, 0x4e, 0xd7, 0x97, 0xb0, 0xf9, 0x03, 0x4b,
		0xf8, 0x17, 0x4b, 0xb8, 0x5a, 0xa9, 0x9c, 0x54, 0xb0, 0x8c, 0x93, 0xc5, 0x45, 0xf4, 0xf7, 0xde,
		0x7b, 0x93, 0x8f, 0xf7, 0xd5, 0x71, 0x0b, 0x52, 0xdf, 0x49, 0xfa, 0x66, 0xd9, 0x40, 0xc3, 0x89,
		0x3a, 0x74, 0x03, 0xe8, 0x06, 0xd0, 0x0d, 0xa0, 0x1b, 0x40, 0x37, 0xc8, 0x88, 0x6e, 0xf0, 0x21,
		0x01, 0xb2, 0x41, 0x05, 0xb2, 0x01, 0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b, 0x28, 0x5f,
		0xc2, 0xa5, 0x0a, 0x44, 0x03, 0x88, 0x06, 0x10, 0x0d, 0x78, 0x45, 0x83, 0x87, 0xe5, 0xee, 0x4b,
		0x82, 0x6a, 0xb0, 0x78, 0x16, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b, 0x40, 0x36, 0x80, 0x6c, 0x00,
		0xd9, 0x60, 0x4f, 0xdc, 0xb8, 0x95, 0xb6, 0xe9, 0x3e, 0x26, 0x40, 0x37, 0x38, 0xd5, 0xf8, 0x08,
		0xe7, 0xc2, 0xbe, 0x9f, 0x07, 0xfe, 0x43, 0x38, 0x80, 0x70, 0xf0, 0x4b, 0xaf, 0xab, 0x08, 0x9f,
		0x0b, 0xc2, 0x41, 0xba, 0x97, 0x30, 0xe2, 0x0d, 0x20, 0x1d, 0x40, 0x3a, 0x60, 0x5d, 0xe6, 0xe2,
		0x87, 0x2f, 0xec, 0x21, 0x63, 0x15, 0xcc, 0xad, 0x94, 0x2f, 0x78, 0x12, 0xc8, 0x06, 0x90, 0x0d,
		0x20, 0x1b, 0x40, 0x36, 0x80, 0x6c, 0x00, 0xd9, 0x60, 0x5f, 0xd9, 0x80, 0x3d, 0x67, 0xec, 0x36,
		0x33, 0xc2, 0x94, 0x43, 0x36, 0x9f, 0xa4, 0xc5, 0x19, 0xcf, 0x98, 0xb9, 0x69, 0xe9, 0x27, 0x2d,
		0xc1, 0x93, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4,
		0x80, 0xb4, 0x84, 0xc7, 0x78, 0x6c, 0xba, 0xbe, 0x4c, 0x02, 0x67, 0x59, 0x3d, 0x08, 0x28, 0x0b,
		0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x4b, 0x78, 0x8c,
		0x7d, 0xd7, 0xb4, 0x3d, 0xe9, 0xcb, 0x87, 0x04, 0xc4, 0x95, 0xbe, 0x78, 0x16, 0x10, 0x17, 0x10,
		0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x97, 0xc4, 0x13, 0x97, 0x4c, 0xa7,
		0x17, 0x65, 0x2e, 0x52, 0x18, 0xea, 0x5f, 0x5f, 0xd1, 0xc2, 0x70, 0x7d, 0xbc, 0xf0, 0x5f, 0x71,
		0x54, 0x36, 0xd4, 0xb7, 0xde, 0xb2, 0x55, 0x34, 0xe6, 0xdf, 0xe2, 0x51, 0x47, 0xd6, 0x97, 0xc2,
		0xb9, 0xf4, 0xfc, 0xba, 0xef, 0x33, 0x57, 0xac, 0xb9, 0x90, 0x76, 0xc3, 0x12, 0x33, 0x4a, 0xe0,
		0xf1, 0x52, 0xea, 0xc2, 0x85, 0xf9, 0xe3, 0x45, 0xcf, 0xc5, 0x0f, 0xe5, 0x72, 0xb5, 0x56, 0x2e,
		0x1f, 0xd7, 0x4e, 0x6a, 0xc7, 0xa7, 0x95, 0x4a, 0xb1, 0x5a, 0x64, 0x8c, 0x80, 0x2d, 0xb4, 0xdc,
		0xa1, 0x70, 0xc5, 0xf0, 0xd3, 0x6c, 0xea, 0xed, 0x89, 0x65, 0x65, 0x6a, 0x45, 0x6b, 0xc2, 0xe6,
		0x84, 0x63, 0x72, 0x81, 0xb5, 0xb4, 0x82, 0x3b, 0x19, 0xf8, 0xf6, 0x92, 0x7c, 0x7d, 0xba, 0x1f,
		0xf7, 0x3b, 0xf2, 0xb6, 0x5f, 0xbf, 0x93, 0x5d, 0xf3, 0x4e, 0xf6, 0x9b, 0xe3, 0x87, 0x72, 0xd7,
		0xf5, 0x45, 0x7b, 0xfe, 0xb2, 0xfd, 0xcb, 0xe5, 0x2b, 0xf6, 0xeb, 0xc3, 0xff, 0x75, 0xe4, 0x6d,
		0x6b, 0xe2, 0xb7, 0x5d, 0xd1, 0xef, 0xcc, 0x5e, 0xac, 0x7f, 0xbd, 0x78, 0x8b, 0x7a, 0xf0, 0x12,
		0xa8, 0xd0, 0xac, 0x7f, 0xa3, 0xe5, 0xa8, 0x42, 0xf3, 0x86, 0x62, 0xc0, 0x69, 0x2d, 0xd7, 0xfc,
		0x26, 0x45, 0x2b, 0x6d, 0x45, 0x4a, 0x66, 0x53, 0x6e, 0xc8, 0xe1, 0x81, 0xb0, 0x87, 0x63, 0x47,
		0xda, 0xfe, 0xc1, 0xc0, 0xb1, 0x1c, 0x57, 0x11, 0x92, 0xf1, 0x30, 0x12, 0x3e, 0x06, 0xa2, 0x95,
		0x71, 0xf0, 0x30, 0x0c, 0x55, 0xcb, 0x8f, 0x09, 0xe0, 0xf4, 0x01, 0x9b, 0x42, 0x32, 0x40, 0x66,
		0xfc, 0xd5, 0x20, 0x2d, 0x3d, 0x0e, 0xd2, 0xb6, 0x48, 0xbc, 0xa4, 0x55, 0x2f, 0x65, 0x1d, 0x4b,
		0x98, 0x76, 0x61, 0xd0, 0x4d, 0x1f, 0x4d, 0x4b, 0x44, 0x0b, 0x40, 0xd5, 0xc4, 0xb3, 0x4e, 0x38,
		0x21, 0x4c, 0x11, 0xc0, 0x12, 0xcd, 0xba, 0x8b, 0xbf, 0x4a, 0x08, 0x56, 0x48, 0x61, 0x35, 0xe2,
		0x86, 0x39, 0x1c, 0xba, 0xc2, 0xf3, 0xc8, 0xd6, 0x48, 0x20, 0xb9, 0x87, 0x7a, 0x20, 0x5a, 0xd7,
		0xb4, 0xc7, 0xb1, 0xe4, 0xc7, 0xab, 0x2a, 0x8e, 0x4b, 0xd5, 0x1e, 0x7f, 0xaa, 0x3a, 0xce, 0x54,
		0x7e, 0x3c, 0xa9, 0xfc, 0xb8, 0x51, 0xf9, 0xf1, 0x61, 0xb2, 0x2c, 0x06, 0xf9, 0x71, 0x9d, 0xc2,
		0xfa, 0xad, 0x2a, 0xea, 0xb2, 0x86, 0xeb, 0xad, 0x86, 0x30, 0x2c, 0x43, 0x16, 0x80, 0xb6, 0xfc,
		0xa9, 0x92, 0xb2, 0xa6, 0xc4, 0xe5, 0x4a, 0x81, 0xf5, 0xc0, 0x7a, 0x60, 0xfd, 0xe2, 0x6d, 0xa9,
		0xcb, 0x63, 0xaa, 0x23, 0x94, 0x5c, 0xc4, 0x52, 0x11, 0xc1, 0x54, 0x06, 0x3e, 0x2a, 0x41, 0x88,
		0x07, 0x8c, 0x54, 0x83, 0x12, 0x1b, 0x38, 0xb1, 0x81, 0x14, 0x1b, 0x58, 0xa5, 0x43, 0xdb, 0x52,
		0x16, 0x5f, 0x16, 0xac, 0x7b, 0x39, 0x56, 0x84, 0x32, 0x6b, 0xf4, 0x46, 0x41, 0xb2, 0xc1, 0xd5,
		0xd8, 0xa8, 0x49, 0x21, 0xa8, 0x50, 0x12, 0x7f, 0x1e, 0xf9, 0x87, 0xb2, 0xc2, 0xb1, 0x0f, 0xcd,
		0xc1, 0x07, 0x85, 0x7d, 0xb4, 0x4d, 0xdf, 0x17, 0xae, 0xad, 0x3c, 0xa3, 0x63, 0xe1, 0xcf, 0xb7,
		0x6f, 0x6f, 0x8e, 0x8d, 0xd3, 0xde, 0xd3, 0x4d, 0xd1, 0x38, 0xed, 0x2d, 0x3e, 0x16, 0xe7, 0x7f,
		0x2c, 0x3e, 0x97, 0x6e, 0x8e, 0x8d, 0xf2, 0xea, 0x73, 0xe5, 0xe6, 0xd8, 0xa8, 0xf4, 0x0e, 0xff,
		0xf8, 0xe3, 0xfd, 0xe1, 0xcf, 0x93, 0xe9, 0xfe, 0x5f, 0xfc, 0x97, 0xba, 0xa3, 0xd0, 0x9e, 0xca,
		0xc9, 0x68, 0x75, 0x9b, 0xbf, 0x63, 0x46, 0xf6, 0x9d, 0x91, 0x34, 0x9d, 0xdf, 0xf1, 0xc0, 0x53,
		0x15, 0xf0, 0x14, 0x6d, 0x33, 0x98, 0xc6, 0x5d, 0xdd, 0xf8, 0xd2, 0xfb, 0x59, 0x7c, 0x57, 0x9e,
		0x7e, 0x3c, 0xfc, 0x59, 0x9b, 0xbe, 0xfe, 0xcb, 0xa7, 0x4d, 0x3f, 0x56, 0x7c, 0x57, 0x9b, 0x7e,
		0xdc, 0xf2, 0x2f, 0xd5, 0xe9, 0xc7, 0x1d, 0xdb, 0xa8, 0x4c, 0xdf, 0x86, 0x7e, 0x74, 0xf6, 0xf7,
		0xa5, 0x6d, 0x5f, 0x28, 0x6f, 0xf9, 0xc2, 0xc9, 0xb6, 0x2f, 0x9c, 0x6c, 0xf9, 0xc2, 0xd6, 0x47,
		0x2a, 0x6d, 0xf9, 0x42, 0x65, 0xfa, 0x14, 0xfa, 0xf9, 0xb7, 0x9b, 0x7f, 0xb4, 0x3a, 0x3d, 0x7c,
		0xda, 0xf6, 0x6f, 0xb5, 0xe9, 0xd3, 0xc7, 0x43, 0x80, 0x35, 0xd6, 0x67, 0x6e, 0xd7, 0x67, 0x4a,
		0xe2, 0x08, 0x7a, 0x38, 0xd6, 0xde, 0xc5, 0xf3, 0x4d, 0xe3, 0xb1, 0x36, 0xe1, 0x75, 0x08, 0x82,
		0xc3, 0x83, 0x37, 0x1a, 0xe7, 0x71, 0x15, 0xd9, 0x47, 0x2c, 0xe2, 0xd1, 0xc6, 0xee, 0xd1, 0xc7,
		0xe8, 0xb1, 0xc4, 0xe2, 0xd1, 0xc6, 0xdc, 0xc5, 0x9d, 0x68, 0xe2, 0x8d, 0xaa, 0x74, 0x83, 0x16,
		0x48, 0xce, 0xd3, 0x22, 0xc4, 0x97, 0xc4, 0xc3, 0x84, 0xe8, 0x3b, 0x39, 0xda, 0x37, 0x23, 0x2e,
		0x09, 0xaa, 0xa5, 0xa0, 0x62, 0x09, 0x44, 0x9b, 0x80, 0xfd, 0x87, 0x6f, 0xbf, 0x6f, 0xec, 0x39,
		0xd0, 0x71, 0x07, 0x98, 0x6e, 0x60, 0x23, 0x6c, 0xa4, 0xbd, 0x36, 0xce, 0x7e, 0xd3, 0xb5, 0xfb,
		0xa0, 0xef, 0x31, 0xe0, 0x0b, 0x65, 0x72, 0x62, 0xcb, 0x81, 0xe9, 0xf9, 0x7b, 0x0f, 0xf7, 0xba,
		0xbe, 0xb9, 0x6a, 0x65, 0xcf, 0xe9, 0x8e, 0x76, 0x2c, 0x1e, 0xf9, 0x04, 0x2a, 0xce, 0x09, 0x13,
		0xcd, 0x09, 0x52, 0xdc, 0x13, 0x22, 0xb2, 0x13, 0x20, 0xb2, 0x13, 0x1e, 0xb2, 0x13, 0x1c, 0xb5,
		0xc0, 0x12, 0xf5, 0x98, 0xb8, 0x60, 0x2d, 0xde, 0x29, 0xfa, 0x8c, 0x05, 0xa1, 0x43, 0xcb, 0x86,
		0x22, 0x0e, 0x73, 0xbc, 0x08, 0x92, 0xe7, 0x2d, 0x53, 0x8a, 0xd8, 0x00, 0xc1, 0xe1, 0x2c, 0xed,
		0x21, 0x2c, 0xd5, 0x61, 0x2b, 0xf9, 0xa1, 0x2a, 0xf9, 0xe1, 0x29, 0xf9, 0x21, 0x29, 0x2f, 0x69,
		0x8a, 0x1b, 0xa1, 0x51, 0x58, 0x06, 0xcb, 0xc7, 0x9e, 0xe8, 0xd5, 0xf2, 0x5b, 0xb6, 0x17, 0xd7,
		0xff, 0x23, 0x09, 0xe9, 0x22, 0x8b, 0xa6, 0xa0, 0x8c, 0x9e, 0x50, 0x13, 0x2d, 0x41, 0x1d, 0x1d,
		0xa1, 0x2c, 0x1a, 0x42, 0x59, 0xf4, 0x83, 0xb2, 0x68, 0x07, 0xbd, 0x4a, 0x08, 0x55, 0x08, 0xd6,
		0x62, 0x63, 0xd2, 0x47, 0x72, 0x52, 0x5e, 0x14, 0x43, 0x24, 0x27, 0x22, 0x39, 0x55, 0xc3, 0x84,
		0x72, 0xb8, 0xa0, 0x93, 0x60, 0x0f, 0x92, 0x1c, 0xc9, 0xe9, 0xb8, 0xf2, 0x5e, 0x41, 0xdd, 0xcd,
		0xe7, 0xed, 0xb0, 0x68, 0x1f, 0x51, 0x9b, 0x88, 0xda, 0xd4, 0x0a, 0x44, 0x6c, 0x80, 0xc4, 0x06,
		0x4c, 0xb4, 0x00, 0x45, 0x0c, 0x54, 0xc1, 0x28, 0xa8, 0x8f, 0xda, 0xa4, 0xbf, 0x6e, 0x14, 0xe2,
		0x31, 0x35, 0x05, 0x6d, 0x87, 0xae, 0x1f, 0x2d, 0x91, 0x32, 0xa9, 0xe7, 0xc2, 0x84, 0x64, 0x66,
		0x99, 0xe8, 0x43, 0x9d, 0xd1, 0x59, 0x75, 0x00, 0xab, 0x03, 0xab, 0x03, 0xab, 0x03, 0xab, 0x03,
		0xab, 0xb3, 0xd5, 0xea, 0xac, 0xa0, 0x32, 0x0f, 0x66, 0x47, 0x0d, 0x1c, 0x3e, 0x5b, 0x1d, 0x25,
		0x0e, 0x34, 0x8c, 0x0e, 0x8c, 0x0e, 0x8c, 0x0e, 0x8c, 0x4e, 0xa6, 0x8c, 0xce, 0x62, 0xd9, 0xe7,
		0xc0, 0xe6, 0xd0, 0xe6, 0x5d, 0x08, 0x2d, 0x08, 0xca, 0xfc, 0x0b, 0xa1, 0xa5, 0x00, 0x8b, 0x03,
		0x8b, 0x03, 0x8b, 0x93, 0x64, 0x8b, 0x43, 0x7d, 0x1a, 0x10, 0x34, 0x3c, 0xcf, 0x0f, 0x2f, 0xed,
		0xa1, 0x50, 0x57, 0x09, 0x28, 0xd8, 0x5a, 0x2f, 0xfa, 0x52, 0x95, 0x5f, 0x56, 0x69, 0x4d, 0x27,
		0xe5, 0x35, 0x9b, 0x38, 0x6a, 0x32, 0xf1, 0xd6, 0x5c, 0xe2, 0xaa, 0xa9, 0xc4, 0x5e, 0x33, 0x89,
		0xbd, 0x26, 0x12, 0x7b, 0xcd, 0xa3, 0x74, 0x65, 0x96, 0x56, 0x5e, 0x93, 0x88, 0x81, 0x9a, 0x73,
		0x50, 0xf4, 0x4d, 0x54, 0x7d, 0xe3, 0xef, 0x39, 0x58, 0x7b, 0xc2, 0xf7, 0x82, 0x4f, 0x4b, 0x4a,
		0xbf, 0x00, 0xf0, 0xb4, 0x24, 0xf1, 0x55, 0xc0, 0xe1, 0x06, 0xce, 0x68, 0x34, 0xb1, 0xa5, 0xff,
		0xc8, 0x65, 0x37, 0x5f, 0x77, 0x08, 0xe3, 0x09, 0xe3, 0x09, 0xe3, 0x09, 0xe3, 0x09, 0xe3, 0x99,
		0x54, 0xe3, 0xb9, 0x42, 0x6c, 0x29, 0xbc, 0xe0, 0xf3, 0x23, 0xec, 0xe7, 0x62, 0xf0, 0xc4, 0x0f,
		0xdf, 0x60, 0xb7, 0xa1, 0x9b, 0x3a, 0x85, 0x1d, 0x85, 0x1d, 0x85, 0x1d, 0x85, 0x1d, 0x85, 0x1d,
		0x4d, 0xaa, 0x1d, 0x7d, 0x89, 0xda, 0x33, 0x5b, 0xba, 0x86, 0xe2, 0xb0, 0xa7, 0x8b, 0x41, 0x94,
		0xf6, 0x83, 0x69, 0xc9, 0xa1, 0xe1, 0x0a, 0xd3, 0x53, 0x58, 0xd9, 0xe8, 0xf9, 0x8a, 0xf3, 0x7a,
		0x7f, 0xb0, 0xa2, 0xb0, 0xa2, 0xb0, 0xa2, 0xb0, 0xa2, 0x29, 0xb4, 0xa2, 0x72, 0x28, 0x6c, 0x5f,
		0xfa, 0x8f, 0x4c, 0x96, 0x54, 0x65, 0x5d, 0xbe, 0xe6, 0xf2, 0x55, 0x3e, 0x99, 0x1e, 0xc3, 0x16,
		0x5d, 0x0d, 0x60, 0xf3, 0xf2, 0x5b, 0xfd, 0xbc, 0x79, 0xd6, 0xef, 0xb4, 0xae, 0xaf, 0x1a, 0xfd,
		0x4e, 0xa3, 0xde, 0x6d, 0x5d, 0xaa, 0xde, 0xad, 0xdf, 0x4c, 0x6b, 0x32, 0xbf, 0xff, 0x7c, 0xa3,
		0xbc, 0x42, 0x29, 0x4f, 0x91, 0xe1, 0xd0, 0x68, 0x7e, 0x3e, 0xbf, 0xee, 0x5e, 0x35, 0x3a, 0xfd,
		0xf3, 0x56, 0xab, 0xad, 0xbe, 0x32, 0x2e, 0x43, 0xf9, 0x66, 0x4d, 0xe3, 0x58, 0xef, 0x62, 0x08,
		0x63, 0x0e, 0x61, 0xab, 0xd3, 0xfc, 0xda, 0xbc, 0xac, 0x5f, 0xb5, 0x3a, 0x18, 0xc5, 0x18, 0x1b,
		0xba, 0x75, 0xf9, 0xa5, 0x71, 0x56, 0x48, 0x79, 0xf9, 0xe9, 0x5e, 0xda, 0xf8, 0x49, 0x2a, 0xbc,
		0x37, 0xcb, 0xf4, 0x7c, 0x63, 0xe4, 0x0c, 0xe5, 0x9d, 0x14, 0x43, 0xf5, 0xce, 0xdb, 0x7a, 0x77,
		0xf0, 0xdd, 0xe0, 0xbb, 0xc1, 0x77, 0x83, 0xef, 0x96, 0x42, 0xdf, 0xcd, 0x97, 0x23, 0xe1, 0xcb,
		0xc1, 0x5f, 0x5e, 0xb5, 0xcc, 0xe0, 0xbb, 0xa9, 0xcc, 0xd3, 0x7f, 0x6d, 0xcb, 0x79, 0xf6, 0xd8,
		0x82, 0x6d, 0xda, 0x8e, 0x27, 0x06, 0x8e, 0x3d, 0x54, 0x5a, 0x7b, 0xa0, 0x63, 0xda, 0xf7, 0x42,
		0xb9, 0xff, 0xa4, 0x9e, 0x6a, 0x15, 0x2e, 0xa4, 0xad, 0x1c, 0xd1, 0x98, 0x6c, 0xda, 0x66, 0x2f,
		0x97, 0xb1, 0xbf, 0x2f, 0xae, 0x39, 0xf0, 0xa5, 0x63, 0x9f, 0xc9, 0xfb, 0xc5, 0x6a, 0x3c, 0xce,
		0x02, 0xdf, 0x2f, 0x5c, 0x98, 0x3f, 0x32, 0xbf, 0x44, 0xd4, 0x64, 0x9d, 0x4e, 0xec, 0xaa, 0x79,
		0x93, 0xce, 0xd6, 0x7b, 0x39, 0xf6, 0x71, 0x14, 0xa5, 0x1e, 0x0a, 0x73, 0x69, 0x15, 0x29, 0x88,
		0xe0, 0xd5, 0xc0, 0xab, 0x81, 0x57, 0x03, 0xaf, 0x86, 0x65, 0xdf, 0x4c, 0x6c, 0xa9, 0xec, 0x48,
		0xfd, 0x40, 0x71, 0x6d, 0xca, 0xd7, 0xc3, 0x95, 0x7a, 0xff, 0x82, 0xa5, 0x5a, 0xa8, 0x8e, 0x19,
		0xe2, 0x9d, 0x29, 0xbe, 0x19, 0xdb, 0x30, 0x73, 0x2c, 0xd5, 0x46, 0xb7, 0xce, 0xe1, 0x07, 0xc6,
		0x3e, 0xb9, 0xca, 0xa9, 0x85, 0x3a, 0xce, 0x4a, 0x2d, 0xcc, 0x10, 0x63, 0xe7, 0x9c, 0x3c, 0xce,
		0x82, 0x78, 0xf9, 0x99, 0x41, 0x96, 0x9e, 0xa6, 0xef, 0x32, 0x0c, 0x9f, 0x55, 0xc0, 0x27, 0xcf,
		0xe6, 0x43, 0x75, 0xca, 0x4c, 0x55, 0xa7, 0xcc, 0xbd, 0x31, 0xc1, 0x7a, 0xce, 0xf6, 0x7a, 0xe6,
		0x31, 0xad, 0x6f, 0xd2, 0xfd, 0x1e, 0x8a, 0xa9, 0x01, 0xa7, 0x0f, 0xcc, 0x12, 0x2a, 0x1b, 0x62,
		0x00, 0x0c, 0x07, 0x19, 0xbc, 0xa1, 0xb3, 0xa1, 0x81, 0x6d, 0x5e, 0x76, 0xaf, 0xea, 0xe7, 0xe7,
		0xfd, 0x76, 0xa7, 0x75, 0xd5, 0xfa, 0xdc, 0x3a, 0xef, 0x5f, 0xfd, 0xb7, 0xdd, 0x28, 0x70, 0x1e,
		0x21, 0x79, 0xac, 0x36, 0xe2, 0x27, 0xaf, 0x35, 0x5a, 0x0d, 0x73, 0xbb, 0x79, 0xc1, 0x07, 0x8e,
		0xd3, 0x77, 0x59, 0x1f, 0xce, 0xe6, 0xd7, 0x8b, 0x36, 0xc6, 0x93, 0x6e, 0x3c, 0xcf, 0x9a, 0x9d,
		0xc6, 0xe7, 0xab, 0xf3, 0xff, 0xf6, 0x3f, 0xb7, 0x2e, 0x2f, 0x1b, 0x9f, 0xaf, 0x38, 0xa2, 0x45,
		0xf3, 0x33, 0xba, 0xad, 0x6e, 0xfb, 0xcb, 0x09, 0x06, 0x94, 0x6e, 0x40, 0xbb, 0x57, 0xf5, 0xab,
		0xe6, 0x67, 0x8c, 0x28, 0x21, 0xa0, 0x76, 0x9b, 0x5d, 0x8c, 0x27, 0xdd, 0x78, 0x7e, 0xfa, 0x0a,
		0xfb, 0x44, 0x8c, 0xa0, 0x18, 0x4f, 0xba, 0xf1, 0x3c, 0x6f, 0x7d, 0xae, 0x9f, 0xf7, 0xeb, 0x5f,
		0xbf, 0x76, 0x1a, 0x5f, 0xeb, 0x57, 0x0d, 0xc6, 0xa1, 0x7d, 0x93, 0x0d, 0x75, 0x00, 0x61, 0x60,
		0x6a, 0x9f, 0x57, 0x45, 0x18, 0x98, 0xaa, 0x6a, 0x40, 0xa1, 0xdd, 0xa5, 0xa6, 0x2a, 0x50, 0xd0,
		0xcd, 0x99, 0xb8, 0x33, 0x27, 0xd6, 0x3c, 0x56, 0xe6, 0x18, 0xc1, 0x66, 0x9b, 0x3b, 0x40, 0xb0,
		0x59, 0xe4, 0x99, 0x47, 0xb0, 0x59, 0x2a, 0xd0, 0x3c, 0x03, 0xc1, 0x66, 0xd2, 0xf6, 0x4f, 0x4a,
		0x0c, 0xd1, 0x66, 0x35, 0xdc, 0x66, 0xf9, 0xf5, 0x8b, 0xe0, 0x36, 0x0b, 0x5d, 0x7f, 0xb8, 0xcd,
		0x92, 0xda, 0x25, 0x52, 0x2e, 0x9d, 0x96, 0x4f, 0xab, 0xb5, 0xd2, 0x29, 0xee, 0xb0, 0xc0, 0x79,
		0x49, 0x92, 0xf3, 0xa2, 0x96, 0xd0, 0xaa, 0xad, 0x2d, 0x07, 0xb7, 0x02, 0x6e, 0x05, 0xdc, 0x0a,
		0xb8, 0x15, 0x3c, 0x59, 0xd5, 0xc6, 0x0f, 0x65, 0x43, 0xf9, 0x1a, 0xe3, 0x08, 0x12, 0x65, 0x0b,
		0x0a, 0xe5, 0x8d, 0xc0, 0x3e, 0x5a, 0x76, 0x76, 0xf8, 0xf4, 0xf6, 0xa6, 0x68, 0x94, 0x7a, 0xab,
		0xff, 0x38, 0xb9, 0x39, 0x36, 0x4a, 0x3d, 0xa5, 0x61, 0x64, 0x3d, 0x95, 0x93, 0xc5, 0x19, 0xf6,
		0x98, 0x9f, 0x19, 0xcb, 0x31, 0xe7, 0x5b, 0xe6, 0xb9, 0x75, 0x26, 0xbe, 0x50, 0x4f, 0xfc, 0x5e,
		0x76, 0x06, 0xf6, 0x07, 0xf6, 0x07, 0xf6, 0x07, 0xf6, 0x97, 0x42, 0xf6, 0x77, 0xeb, 0x38, 0x96,
		0x30, 0x59, 0xee, 0x30, 0x17, 0xd3, 0x62, 0x9a, 0x12, 0x5d, 0x5a, 0xb4, 0x6e, 0xdb, 0x8e, 0x6f,
		0xfa, 0x52, 0x51, 0xea, 0xf8, 0x82, 0x37, 0xf8, 0x2e, 0x46, 0xe6, 0x78, 0x99, 0xe9, 0xff, 0xc8,
		0x19, 0x0b, 0x7b, 0x30, 0x37, 0x14, 0xb3, 0xfd, 0x79, 0x34, 0xfb, 0x9f, 0x2b, 0x6f, 0x8f, 0xcc,
		0x3b, 0x69, 0x78, 0xe6, 0x9d, 0xf4, 0x82, 0x4f, 0x47, 0x73, 0x3f, 0x62, 0x62, 0xcb, 0x81, 0xe9,
		0xf9, 0x47, 0xd6, 0x62, 0x4f, 0x1f, 0xcd, 0xed, 0xa3, 0xb7, 0xf8, 0x63, 0x51, 0x00, 0x20, 0x0f,
		0xc5, 0xa5, 0x27, 0xf6, 0x5f, 0xb6, 0xf3, 0xb7, 0x6d, 0x98, 0xbe, 0xef, 0xca, 0xdb, 0xd9, 0x08,
		0xa8, 0xab, 0x34, 0xbd, 0xa1, 0x2f, 0x94, 0x9d, 0x46, 0xd9, 0xe9, 0x44, 0xd0, 0x0b, 0x94, 0x9d,
		0xe6, 0xb5, 0x0d, 0xca, 0xca, 0x4e, 0x87, 0x40, 0x46, 0xbd, 0x7f, 0x15, 0xee, 0x52, 0xad, 0x97,
		0x55, 0x84, 0x97, 0x05, 0x2f, 0x0b, 0x5e, 0x56, 0x9e, 0xbc, 0x2c, 0x55, 0x70, 0x19, 0x74, 0x30,
		0x2f, 0xc5, 0xec, 0xab, 0xf6, 0xe5, 0x0e, 0x42, 0x45, 0xfb, 0xe7, 0x5d, 0x2a, 0x5e, 0x5a, 0x3c,
		0xf1, 0x06, 0xca, 0xe1, 0x93, 0x13, 0x46, 0xf5, 0xc0, 0x29, 0x37, 0xac, 0x6a, 0x83, 0x57, 0x6d,
		0x30, 0xab, 0x0d, 0x6e, 0xd5, 0xc2, 0xae, 0x62, 0xf8, 0xe5, 0x13, 0xbb, 0x42, 0xfb, 0x4e, 0x7d,
		0x39, 0xc6, 0x10, 0xbb, 0xac, 0x31, 0xf4, 0xf5, 0xa2, 0x3c, 0xe3, 0xa2, 0xd6, 0xe2, 0xb3, 0x31,
		0x48, 0x69, 0x04, 0x93, 0xc2, 0xa5, 0x57, 0x58, 0xa8, 0x51, 0x6c, 0x86, 0x79, 0xd1, 0x1d, 0x8f,
		0x51, 0x2e, 0xc2, 0x28, 0xc3, 0x28, 0xc3, 0x28, 0xc3, 0x28, 0x27, 0xd7, 0x37, 0x5a, 0xf7, 0x91,
		0x2c, 0x61, 0xf3, 0xa7, 0x72, 0x09, 0x7a, 0x7e, 0x97, 0xc9, 0x08, 0x6d, 0x2e, 0x90, 0xd6, 0x01,
		0xd6, 0x7a, 0x41, 0x5b, 0x17, 0x78, 0x6b, 0x07, 0x71, 0xed, 0x60, 0xae, 0x1d, 0xd4, 0x79, 0xc0,
		0x9d, 0x09, 0xe4, 0xf9, 0x3d, 0xb0, 0xd0, 0xbe, 0x9d, 0x48, 0xdb, 0x2f, 0x56, 0x35, 0x24, 0x2b,
		0xad, 0x32, 0x76, 0xc9, 0x73, 0xe7, 0xed, 0xf5, 0x2f, 0x5e, 0x4c, 0x3a, 0xe0, 0xbe, 0x13, 0xa7,
		0xd9, 0xbc, 0x86, 0xba, 0x67, 0xbe, 0x33, 0x17, 0xea, 0x5f, 0xc3, 0xbd, 0x28, 0x4d, 0x70, 0xb5,
		0xbe, 0xe4, 0xcc, 0x1f, 0xb9, 0x5f, 0x72, 0xd5, 0x4a, 0xe5, 0xa4, 0x92, 0xe3, 0x65, 0xf7, 0x26,
		0x9b, 0xbd, 0x65, 0x25, 0x67, 0x2b, 0xc7, 0x55, 0x5b, 0xbe, 0x93, 0xb6, 0xcd, 0x6e, 0x24, 0xc3,
		0x89, 0x1b, 0xfc, 0x48, 0xf8, 0x91, 0xf0, 0x23, 0xe1, 0x47, 0xc2, 0x8f, 0xdc, 0xe2, 0x47, 0x7e,
		0xd0, 0xe0, 0x46, 0x56, 0xe0, 0x46, 0xc2, 0x8d, 0x84, 0x1b, 0x09, 0x37, 0x32, 0x03, 0x4b, 0xae,
		0x54, 0x81, 0x13, 0x09, 0x27, 0x32, 0xef, 0x4e, 0xe4, 0xc3, 0x72, 0x37, 0xe8, 0xf0, 0x22, 0x17,
		0x7d, 0xc3, 0x8d, 0x84, 0x1b, 0x09, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48, 0xf6, 0x7d, 0x7b, 0x2b,
		0x6d, 0xd3, 0x7d, 0xd4, 0xe0, 0x47, 0x9e, 0x32, 0x76, 0x79, 0x2e, 0xec, 0xfb, 0x79, 0xa0, 0x28,
		0x1c, 0xc9, 0x1c, 0xb0, 0xfa, 0x22, 0x1c, 0x49, 0x38, 0x92, 0xbc, 0x4b, 0x0e, 0xe7, 0x91, 0x70,
		0x25, 0x73, 0xee, 0x4a, 0x8a, 0x1f, 0xbe, 0xb0, 0x87, 0x62, 0xc8, 0xef, 0x48, 0x06, 0x3d, 0xc3,
		0x8d, 0x84, 0x1b, 0x09, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48, 0x7e, 0x37, 0x52, 0x79, 0x52, 0xad,
		0x6d, 0x30, 0xac, 0x28, 0xc9, 0x56, 0x36, 0x8d, 0xb4, 0x33, 0x9e, 0x31, 0x45, 0xd3, 0xe2, 0x37,
		0xd2, 0x41, 0xcf, 0x30, 0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x30, 0xd2, 0x30,
		0xd2, 0x9b, 0xc6, 0x6c, 0x6c, 0xba, 0xbe, 0xd4, 0x61, 0xa3, 0x57, 0x1d, 0xc3, 0x44, 0xc3, 0x44,
		0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0xc3, 0x44, 0x6f, 0x1a, 0x33, 0xdf, 0x35, 0x6d,
		0x4f, 0xfa, 0xf2, 0x41, 0x43, 0xdc, 0xd4, 0x8b, 0xbe, 0x61, 0xa8, 0x61, 0xa8, 0x61, 0xa8, 0x61,
		0xa8, 0x61, 0xa8, 0x61, 0xa8, 0x53, 0x68, 0xa8, 0x53, 0x9d, 0x2e, 0x4a, 0x71, 0x55, 0x8a, 0x50,
		0x7f, 0x0a, 0xab, 0x54, 0x84, 0x0b, 0x2a, 0x84, 0xff, 0x4a, 0x45, 0x29, 0x0b, 0xbe, 0x05, 0x91,
		0xae, 0x2c, 0xcd, 0xff, 0x16, 0x8f, 0x1c, 0xd7, 0xac, 0x0b, 0xe7, 0xd2, 0xf3, 0xeb, 0xbe, 0xaf,
		0x38, 0x25, 0xf4, 0x85, 0xb4, 0x1b, 0x96, 0x98, 0xd9, 0x3c, 0x4f, 0x2d, 0xa7, 0x2b, 0x5c, 0x98,
		0x3f, 0x5e, 0xf4, 0x54, 0xfc, 0x50, 0x2e, 0x57, 0x6b, 0xe5, 0xf2, 0x71, 0xed, 0xa4, 0x76, 0x7c,
		0x5a, 0xa9, 0x14, 0xab, 0x45, 0x85, 0x21, 0x5a, 0x85, 0x96, 0x3b, 0x14, 0xae, 0x18, 0x7e, 0x9a,
		0x4d, 0x9d, 0x3d, 0xb1, 0xac, 0x54, 0xad, 0x38, 0x26, 0x30, 0xd3, 0x0d, 0x62, 0x05, 0xa5, 0xc9,
		0x55, 0xdd, 0xc9, 0xc0, 0xb7, 0x97, 0xf4, 0xe0, 0xd3, 0xfd, 0xb8, 0xdf, 0x91, 0xb7, 0xfd, 0xfa,
		0x9d, 0xec, 0x9a, 0x77, 0xb2, 0xdf, 0x1c, 0x3f, 0x94, 0xaf, 0x17, 0x8f, 0xdf, 0x3f, 0x77, 0x06,
		0xb3, 0x7f, 0xea, 0xcc, 0x1e, 0xbb, 0x7f, 0xbd, 0x78, 0xc6, 0x7a, 0xf0, 0x88, 0x28, 0x19, 0x95,
		0xfc, 0xf5, 0xcc, 0xbb, 0x8e, 0x13, 0x5b, 0x3f, 0xea, 0x4d, 0x82, 0xa6, 0x7e, 0x65, 0x34, 0x17,
		0x6e, 0xe5, 0x81, 0xe3, 0xca, 0x7b, 0x69, 0x1f, 0xcc, 0x66, 0xc8, 0x90, 0x54, 0x91, 0x81, 0x6a,
		0x0c, 0xa6, 0x3a, 0x03, 0xc9, 0x6a, 0x10, 0xd5, 0x18, 0x40, 0xaa, 0xd5, 0xa1, 0x08, 0x10, 0x14,
		0x02, 0x01, 0xa1, 0xad, 0x8a, 0x68, 0x9b, 0x68, 0x70, 0x27, 0x3e, 0x4a, 0xc4, 0x6b, 0x21, 0xe6,
		0x0a, 0xa2, 0x5e, 0x39, 0x4a, 0x56, 0x4c, 0xbc, 0x99, 0x8a, 0x3e, 0xbe, 0x31, 0xc6, 0x96, 0x28,
		0x19, 0x3d, 0x69, 0xb2, 0x79, 0xa2, 0x64, 0xf2, 0xcf, 0x02, 0x76, 0x29, 0x66, 0x43, 0x84, 0xc2,
		0xb4, 0x1a, 0xc1, 0x99, 0x5a, 0x48, 0x56, 0x26, 0x10, 0x2b, 0x13, 0x7e, 0x95, 0x09, 0xba, 0x40,
		0xbd, 0xed, 0xa8, 0x47, 0xa0, 0x45, 0xc5, 0x00, 0xbd, 0x37, 0x8c, 0x13, 0x42, 0x35, 0x11, 0xb4,
		0x13, 0x50, 0x88, 0x85, 0xfb, 0xfb, 0x71, 0x91, 0x68, 0xd3, 0xbc, 0xff, 0x24, 0x45, 0x98, 0xa0,
		0x82, 0x2d, 0xe4, 0xfd, 0xf7, 0x5b, 0xc7, 0x8d, 0x5e, 0xec, 0x36, 0x80, 0xe5, 0xe7, 0xa6, 0x22,
		0x2e, 0x94, 0x78, 0xb6, 0x2b, 0xb6, 0xcd, 0xa2, 0xb0, 0x55, 0xb4, 0x36, 0x8a, 0xca, 0x36, 0x91,
		0xdb, 0x24, 0x72, 0x5b, 0x44, 0x6e, 0x83, 0x78, 0x21, 0x2e, 0x6e, 0xe1, 0x8d, 0x60, 0xef, 0xd0,
		0xb1, 0xc9, 0xa0, 0xc5, 0x84, 0x11, 0xca, 0x63, 0x10, 0x4a, 0x10, 0xca, 0x54, 0x12, 0x4a, 0xaa,
		0xea, 0x3a, 0x05, 0x73, 0xf8, 0xbf, 0xf9, 0x98, 0x48, 0xdb, 0x18, 0x3b, 0x9e, 0x4f, 0xb7, 0x52,
		0x82, 0xbc, 0x54, 0xaf, 0x3a, 0xa0, 0xd2, 0x27, 0x49, 0x0b, 0x95, 0x91, 0x07, 0x49, 0xa9, 0x08,
		0x82, 0x52, 0x1b, 0xe4, 0xa4, 0x2a, 0x88, 0x49, 0x79, 0x90, 0x92, 0xf2, 0x20, 0x24, 0xe5, 0x41,
		0x46, 0xc9, 0x52, 0xfe, 0xa9, 0x0b, 0x77, 0x15, 0x96, 0xa2, 0x1a, 0xf9, 0xc2, 0x5a, 0x6d, 0x87,
		0x65, 0xfb, 0xc4, 0x93, 0xae, 0xa6, 0x12, 0x22, 0x99, 0x98, 0xc5, 0x01, 0x38, 0x3c, 0xc0, 0xa3,
		0x1a, 0x80, 0xd8, 0x80, 0x88, 0x0d, 0x90, 0xd8, 0x80, 0x89, 0x16, 0xa0, 0x88, 0x81, 0x4a, 0x19,
		0x60, 0xad, 0x03, 0x97, 0xba, 0xf5, 0xb8, 0x86, 0x5f, 0xaa, 0xd6, 0xa2, 0xda, 0x82, 0xae, 0xca,
		0x83, 0xcb, 0x39, 0x82, 0xc9, 0x79, 0x83, 0xc7, 0xb9, 0x82, 0xc5, 0xd9, 0x83, 0xc3, 0xd9, 0x83,
		0xc1, 0xd9, 0x83, 0xbf, 0xd3, 0x15, 0xf6, 0xa8, 0xba, 0x00, 0x6b, 0x61, 0x15, 0x0d, 0xc2, 0x56,
		0x01, 0x9b, 0x36, 0xfc, 0xe4, 0x57, 0x90, 0x79, 0x8c, 0x1a, 0xd8, 0x09, 0x87, 0x52, 0x6e, 0x48,
		0xd5, 0x06, 0xad, 0xda, 0x20, 0x56, 0x1b, 0xd4, 0xaa, 0x85, 0x5c, 0xc5, 0xd0, 0x1b, 0x8c, 0x1a,
		0xdb, 0x7d, 0x9a, 0x60, 0xdf, 0x59, 0xc2, 0xbc, 0x73, 0xc5, 0x1d, 0xc7, 0xa6, 0x5b, 0x31, 0xcb,
		0x1a, 0x43, 0x5f, 0xed, 0xe5, 0x41, 0xeb, 0xfb, 0xf7, 0x8b, 0xc3, 0xea, 0xa3, 0x95, 0x29, 0x48,
		0xeb, 0x05, 0x0a, 0x85, 0xfc, 0x72, 0xcc, 0x03, 0xf7, 0xcf, 0x56, 0x99, 0x85, 0x5c, 0xc2, 0x28,
		0xc3, 0x28, 0xc3, 0x28, 0xc3, 0x28, 0xc3, 0x28, 0x27, 0xd8, 0x28, 0x2f, 0xb6, 0x1d, 0x6c, 0x72,
		0x68, 0xa8, 0x68, 0xa2, 0x73, 0x77, 0x5e, 0x70, 0x14, 0xd1, 0xbb, 0x3b, 0x2f, 0x35, 0x58, 0x64,
		0x58, 0x64, 0x58, 0x64, 0x58, 0xe4, 0xe8, 0xa3, 0xa6, 0x5a, 0xa9, 0x0c, 0x3a, 0x9a, 0x5f, 0x01,
		0x97, 0xf6, 0x50, 0xfc, 0xd0, 0x54, 0x9f, 0x6d, 0xd1, 0x37, 0xf2, 0x0c, 0xa5, 0x0d, 0xb0, 0xf5,
		0x02, 0xb7, 0x2e, 0x00, 0xd7, 0x0e, 0xe4, 0xda, 0x01, 0x5d, 0x3b, 0xb0, 0xf3, 0x00, 0x3c, 0x13,
		0xd0, 0xf3, 0xbb, 0x60, 0x1a, 0x5d, 0x31, 0x1d, 0x2e, 0xd9, 0x26, 0xd7, 0xec, 0x1f, 0x7e, 0xcf,
		0x4d, 0x92, 0x27, 0x7c, 0x2f, 0xf8, 0xb4, 0x74, 0xe4, 0x16, 0x66, 0x0a, 0x09, 0x0c, 0x77, 0x1e,
		0xef, 0x5b, 0xe1, 0xf9, 0xc6, 0xf2, 0x36, 0x10, 0x33, 0xaf, 0x78, 0xee, 0x1a, 0xb4, 0x02, 0xb4,
		0x02, 0xb4, 0x02, 0xb4, 0x02, 0xb4, 0x82, 0x7d, 0xdf, 0x22, 0x7d, 0x61, 0x2a, 0xcc, 0xf4, 0xc0,
		0x19, 0x8d, 0x26, 0xb6, 0xf4, 0x1f, 0x75, 0x89, 0x00, 0xaf, 0x1f, 0x00, 0x26, 0x1b, 0x26, 0x1b,
		0x26, 0x1b, 0x26, 0x1b, 0x26, 0x1b, 0x4a, 0x80, 0x4e, 0x25, 0x60, 0x65, 0x97, 0xa4, 0xf0, 0x82,
		0xcf, 0x8f, 0x10, 0x03, 0xa2, 0x0d, 0xb9, 0xf8, 0xe1, 0x1b, 0xda, 0x99, 0xc6, 0xa6, 0x87, 0x00,
		0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0xd0, 0xc9, 0x36, 0x5e, 0xda,
		0xa6, 0x19, 0xe3, 0x58, 0xb3, 0x55, 0x60, 0x1d, 0xd1, 0x86, 0x5e, 0xda, 0x0f, 0xa6, 0x25, 0x87,
		0x86, 0x2b, 0x4c, 0x8f, 0xa9, 0x88, 0xc2, 0xda, 0x0a, 0x7f, 0xd5, 0x3f, 0xb8, 0x06, 0xb8, 0x06,
		0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xfb, 0xbe, 0x95, 0x43, 0x61, 0xfb, 0xd2, 0x7f, 0xd4, 0xc4,
		0x37, 0x2a, 0x8c, 0x7d, 0x36, 0x97, 0xaf, 0xfa, 0xc9, 0xf4, 0x34, 0x40, 0xc6, 0x6a, 0xc0, 0x9b,
		0x97, 0xdf, 0xea, 0xe7, 0xcd, 0xb3, 0x7e, 0xa7, 0x75, 0x7d, 0xd5, 0xe8, 0x77, 0x1a, 0xf5, 0x6e,
		0xeb, 0x92, 0x1b, 0x3d, 0xbe, 0x99, 0xd6, 0x64, 0x9e, 0x64, 0xe7, 0x86, 0xb5, 0xdf, 0xd9, 0xaf,
		0x9f, 0xec, 0x3d, 0x6e, 0x1c, 0xfd, 0xcf, 0xe7, 0xd7, 0xdd, 0xab, 0x46, 0xa7, 0x7f, 0xde, 0x6a,
		0xb5, 0x0b, 0xec, 0x8f, 0x34, 0x7d, 0x97, 0xd7, 0x71, 0xaf, 0x77, 0x31, 0xe4, 0xcc, 0x43, 0xde,
		0xea, 0x34, 0xbf, 0x36, 0x2f, 0xeb, 0x57, 0xad, 0x0e, 0x46, 0x9d, 0x11, 0x60, 0x5a, 0x97, 0x5f,
		0x1a, 0x67, 0x1a, 0x46, 0x9c, 0xb5, 0xc7, 0x5e, 0xd6, 0xf8, 0x5e, 0x26, 0xbc, 0x7b, 0xcb, 0xf4,
		0x7c, 0x63, 0xe4, 0x0c, 0xe5, 0x9d, 0x14, 0x43, 0x7e, 0xe7, 0x7e, 0xbd, 0x7b, 0xf8, 0xf6, 0xf0,
		0xed, 0xe1, 0xdb, 0xc3, 0xb7, 0x87, 0x6f, 0xcf, 0xbe, 0x6f, 0x7d, 0x39, 0x12, 0xbe, 0x1c, 0xfc,
		0xe5, 0x55, 0xcb, 0x1a, 0x7c, 0xfb, 0x0f, 0x8c, 0x5d, 0x5e, 0xdb, 0x72, 0x5e, 0x66, 0xad, 0x60,
		0x9b, 0xb6, 0xe3, 0x89, 0x81, 0x63, 0x0f, 0x3d, 0xce, 0x57, 0xee, 0x98, 0xf6, 0xbd, 0x60, 0xf7,
		0xa7, 0xf9, 0xa9, 0x6e, 0xe1, 0x42, 0xda, 0xec, 0x88, 0xac, 0xc9, 0xc6, 0x6f, 0x56, 0x4d, 0x34,
		0xf6, 0xff, 0xc5, 0x35, 0x07, 0xbe, 0x74, 0xec, 0x33, 0x79, 0xbf, 0x58, 0xed, 0xc7, 0x79, 0xf0,
		0xe7, 0x0a, 0x17, 0xe6, 0x8f, 0xdc, 0x2f, 0x39, 0xde, 0x7a, 0xca, 0x89, 0x5f, 0x85, 0x6f, 0xb2,
		0xd9, 0x5b, 0x0f, 0x3e, 0xee, 0xce, 0xcb, 0x90, 0x2b, 0x9f, 0x68, 0x88, 0x54, 0xf1, 0xe4, 0x15,
		0x85, 0x5f, 0x0b, 0xbf, 0x16, 0x7e, 0x2d, 0xfc, 0x5a, 0xf8, 0xb5, 0x1b, 0xf6, 0xed, 0x44, 0xda,
		0xfe, 0x49, 0x49, 0x83, 0x4b, 0x5b, 0x83, 0x4b, 0x09, 0x97, 0x12, 0x2e, 0x25, 0x5c, 0xca, 0x0c,
		0x2c, 0xb9, 0x72, 0xe9, 0xb4, 0x7c, 0x5a, 0xad, 0x95, 0x4e, 0xe1, 0x48, 0xc2, 0x91, 0xcc, 0xb3,
		0x23, 0xc9, 0xeb, 0x80, 0xf0, 0x66, 0xc2, 0x86, 0x1b, 0x09, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48,
		0xb8, 0x91, 0x1b, 0xf6, 0xed, 0xbc, 0xba, 0x3e, 0xfb, 0x1a, 0x0e, 0x42, 0x9f, 0x3f, 0xf0, 0x5e,
		0xb5, 0xf2, 0x85, 0x6b, 0xb3, 0xbb, 0x93, 0x85, 0x3f, 0xdf, 0xbe, 0xbd, 0x39, 0x36, 0x4e, 0x7b,
		0x4f, 0x37, 0x45, 0xe3, 0xb4, 0xb7, 0xf8, 0x58, 0x9c, 0xff, 0xb1, 0xf8, 0x5c, 0xba, 0x39, 0x36,
		0xca, 0xab, 0xcf, 0x95, 0x9b, 0x63, 0xa3, 0xd2, 0x3b, 0xfc, 0xe3, 0x8f, 0xf7, 0x87, 0x3f, 0x4f,
		0xa6, 0xfb, 0x7f, 0xf1, 0x68, 0xd9, 0xd9, 0xe1, 0xd3, 0xdb, 0x9b, 0xa2, 0x51, 0xea, 0xad, 0xfe,
		0xe3, 0xe4, 0xe6, 0xd8, 0x28, 0xf5, 0x0e, 0x0f, 0xff, 0xc5, 0xb7, 0x47, 0x7b, 0x9c, 0x93, 0xdb,
		0xea, 0x36, 0x7f, 0xc7, 0x0c, 0x73, 0xcf, 0x30, 0x38, 0xf6, 0xce, 0x6b, 0x64, 0x79, 0xd9, 0x4f,
		0x69, 0x85, 0xcc, 0xad, 0x30, 0xff, 0xb2, 0x73, 0xb0, 0x6d, 0xb0, 0x6d, 0xb0, 0x6d, 0xb0, 0x6d,
		0xb0, 0x6d, 0xf6, 0x7d, 0x8b, 0xac, 0x87, 0x09, 0xef, 0x41, 0x75, 0xe1, 0x86, 0xba, 0x6d, 0x3b,
		0xbe, 0xe9, 0x4b, 0xa6, 0x7c, 0x03, 0x05, 0x6f, 0xf0, 0x5d, 0x8c, 0xcc, 0x65, 0x9e, 0xe5, 0xff,
		0x9f, 0xbd, 0xaf, 0x6b, 0x4a, 0x24, 0x69, 0xbe, 0xbf, 0x9f, 0x4f, 0x61, 0x74, 0x3c, 0x17, 0x1a,
		0x31, 0x3d, 0xbc, 0xc8, 0x8b, 0x78, 0xc7, 0xec, 0x38, 0x1b, 0xc4, 0x3a, 0x62, 0xa0, 0xee, 0x7f,
		0x7f, 0xe1, 0xb2, 0x44, 0x0b, 0x85, 0x5b, 0x3b, 0x58, 0x4d, 0x74, 0x17, 0xae, 0xc6, 0xc8, 0x77,
		0xff, 0x07, 0x34, 0xb4, 0x62, 0xc3, 0x8e, 0x42, 0x55, 0x66, 0xd3, 0x9c, 0x89, 0xd9, 0x67, 0x78,
		0x14, 0xa8, 0xee, 0xea, 0xac, 0x3c, 0xe7, 0x64, 0x65, 0x65, 0x3a, 0x39, 0x7f, 0x28, 0x54, 0x77,
		0x0a, 0x94, 0x13, 0xff, 0x91, 0x9b, 0xfc, 0x17, 0xc8, 0x9b, 0x9c, 0xd7, 0x97, 0x6e, 0xe8, 0xf5,
		0x65, 0x18, 0xbf, 0xca, 0x4d, 0x75, 0xe1, 0x48, 0xc9, 0xae, 0x17, 0xea, 0x9c, 0x12, 0xf2, 0xf6,
		0xef, 0x1b, 0x3f, 0x08, 0xe3, 0x57, 0x39, 0xaf, 0xf7, 0xcf, 0xd4, 0x0d, 0x49, 0xe5, 0x0e, 0xfd,
		0x50, 0xe7, 0xa6, 0xd4, 0x22, 0x8c, 0xfe, 0x89, 0x0a, 0x52, 0xa0, 0xab, 0x51, 0xf2, 0x71, 0x8c,
		0xd4, 0x77, 0xe5, 0xff, 0xab, 0x5c, 0x4f, 0xeb, 0x40, 0xde, 0x4c, 0x66, 0x8c, 0xae, 0xc5, 0xd1,
		0x92, 0xb1, 0xd1, 0xef, 0x28, 0xad, 0x8c, 0x0f, 0xfd, 0x8e, 0xb2, 0xc9, 0xe8, 0xd0, 0xef, 0x68,
		0xad, 0x59, 0x23, 0xeb, 0x77, 0x94, 0x70, 0x92, 0xf4, 0x52, 0x3d, 0x79, 0x09, 0xb4, 0x82, 0xbd,
		0x00, 0xc1, 0x0e, 0xc1, 0x0e, 0xc1, 0x0e, 0xc1, 0x9e, 0x1e, 0xc1, 0x4e, 0xe5, 0xfe, 0xe3, 0x01,
		0xa7, 0xdd, 0x7d, 0x34, 0x75, 0x98, 0x60, 0x2f, 0xd1, 0xfd, 0x6e, 0x7a, 0x09, 0xc4, 0xa6, 0xcb,
		0x93, 0x9a, 0x45, 0x0e, 0x07, 0x9c, 0xb0, 0x90, 0x0e, 0x78, 0xe0, 0x86, 0x89, 0xd4, 0xc0, 0x45,
		0x6a, 0x60, 0x23, 0x35, 0xf0, 0x41, 0x0b, 0x23, 0xc4, 0x70, 0x12, 0xcf, 0xf2, 0x25, 0x87, 0x83,
		0xdf, 0xe3, 0x2d, 0x72, 0x9b, 0x60, 0xfb, 0x55, 0x86, 0xb1, 0x13, 0x7d, 0xd0, 0x9f, 0xc1, 0x2e,
		0xa3, 0xc9, 0xa8, 0x84, 0xa6, 0x4d, 0xd4, 0x3a, 0x7d, 0xa5, 0x4d, 0x53, 0xb4, 0x52, 0x67, 0xd6,
		0xae, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x1c, 0xa4, 0x85, 0x5a, 0x0b, 0x2f, 0x6a,
		0xe2, 0x81, 0x60, 0x3c, 0xa7, 0xb6, 0x20, 0x8d, 0x27, 0x57, 0xf2, 0x71, 0x27, 0x0f, 0x2f, 0x71,
		0x81, 0x4e, 0x1a, 0xc0, 0x27, 0x5d, 0x20, 0x94, 0x16, 0x30, 0x4a, 0x1d, 0x28, 0xa5, 0x0e, 0x9c,
		0x52, 0x07, 0x52, 0x3c, 0x60, 0xc5, 0x04, 0x5a, 0xfc, 0x8a, 0x3b, 0xe1, 0x37, 0x46, 0x52, 0xe9,
		0x42, 0x85, 0xd3, 0x67, 0xcc, 0x50, 0xa4, 0xc2, 0x78, 0x09, 0x3c, 0xc7, 0xeb, 0x5f, 0xff, 0xe1,
		0xf5, 0x99, 0x7b, 0xdc, 0xc7, 0xef, 0x53, 0x46, 0x2f, 0x12, 0x97, 0xc3, 0x7c, 0x3c, 0x3f, 0x71,
		0x3d, 0x29, 0x38, 0x32, 0x9d, 0x12, 0x77, 0xba, 0x68, 0xc2, 0xde, 0x03, 0x4c, 0xf8, 0x27, 0x26,
		0x5c, 0x29, 0x97, 0x0f, 0xcb, 0x30, 0xe3, 0x74, 0x71, 0x11, 0xfe, 0xd1, 0xdb, 0x1f, 0x76, 0xe3,
		0x7e, 0x39, 0xaa, 0x8c, 0xf0, 0xed, 0xa4, 0x2f, 0x0f, 0x1b, 0x30, 0xec, 0xa8, 0x23, 0x6e, 0x80,
		0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e, 0x90, 0x91, 0xb8, 0xc1, 0x51, 0x0a, 0xc2, 0x06,
		0x65, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0xac, 0x9b, 0x70, 0xb1,
		0x8c, 0xa0, 0x01, 0x82, 0x06, 0x08, 0x1a, 0xd0, 0x06, 0x0d, 0xee, 0x67, 0xab, 0x2f, 0x0d, 0x51,
		0x83, 0xe8, 0x5a, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8,
		0xe0, 0x9d, 0x7e, 0xe3, 0x46, 0x2a, 0x2f, 0x78, 0x4c, 0x41, 0xdc, 0xa0, 0xc6, 0x78, 0x09, 0xa7,
		0x42, 0xdd, 0x4e, 0x13, 0xff, 0x11, 0x38, 0x40, 0xe0, 0xe0, 0xa7, 0xaa, 0xab, 0x00, 0xcd, 0x85,
		0xc0, 0xc1, 0x76, 0x9b, 0x30, 0xf2, 0x0d, 0x10, 0x3a, 0x40, 0xe8, 0x80, 0xd4, 0xcc, 0xc5, 0x83,
		0x16, 0xaa, 0x47, 0xd8, 0xf1, 0x7d, 0x25, 0xe5, 0x8b, 0xaf, 0x04, 0x61, 0x03, 0x84, 0x0d, 0x10,
		0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0xde, 0x1b, 0x36, 0x20, 0xaf, 0x17, 0xbb, 0x0a,
		0x46, 0x88, 0xea, 0xc7, 0xee, 0x26, 0x69, 0xf1, 0x87, 0x13, 0x66, 0xee, 0x0d, 0xf8, 0x49, 0x4b,
		0x7c, 0x25, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d,
		0x20, 0x2d, 0xc9, 0x39, 0x1e, 0x7a, 0x81, 0x96, 0x69, 0xe0, 0x2c, 0xf3, 0x0b, 0x01, 0x65, 0x01,
		0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x49, 0xce, 0xb1,
		0x0e, 0x3c, 0x15, 0x4a, 0x2d, 0xef, 0x53, 0x90, 0x57, 0xfa, 0xe2, 0x5a, 0x40, 0x5c, 0x40, 0x5c,
		0x40, 0x5c, 0x40, 0x5c, 0x40, 0x5c, 0x40, 0x5c, 0x40, 0x5c, 0x52, 0x4f, 0x5c, 0x32, 0x5d, 0x5e,
		0x94, 0xb8, 0x41, 0x61, 0x62, 0x7c, 0x9e, 0x86, 0x85, 0xc9, 0xde, 0x78, 0xc9, 0x1f, 0x51, 0x74,
		0x35, 0xe4, 0xb3, 0xb5, 0x6c, 0x35, 0x8c, 0xf9, 0x4d, 0x3c, 0x72, 0x54, 0x7c, 0x71, 0x4e, 0x65,
		0xa8, 0xeb, 0x5a, 0x13, 0x77, 0xab, 0xf9, 0x26, 0xd5, 0xc9, 0x40, 0x4c, 0xe8, 0x40, 0x48, 0x4b,
		0xa7, 0x9d, 0x6f, 0xde, 0xc3, 0x8b, 0x91, 0x0b, 0x47, 0xa5, 0x52, 0xa5, 0x5a, 0x2a, 0xe5, 0xab,
		0x87, 0xd5, 0x7c, 0xad, 0x5c, 0x2e, 0x54, 0x0a, 0x84, 0xd9, 0xaf, 0x4e, 0x33, 0xe8, 0x89, 0x40,
		0xf4, 0x3e, 0x4f, 0x1e, 0xbd, 0x1a, 0x0d, 0x06, 0x99, 0xb2, 0x68, 0x26, 0xbf, 0x9c, 0x62, 0x7f,
		0xec, 0x90, 0xb6, 0x54, 0x08, 0x46, 0x5d, 0xad, 0x66, 0xa4, 0xeb, 0xf3, 0xed, 0xb0, 0xd3, 0x92,
		0x37, 0x9d, 0x7a, 0x5f, 0x5e, 0x78, 0x7d, 0xd9, 0x69, 0x0c, 0xef, 0x4b, 0x57, 0xd1, 0x9d, 0x76,
		0xce, 0x66, 0xf7, 0xd7, 0xa9, 0xf7, 0xfe, 0x69, 0xc9, 0x9b, 0x86, 0x3a, 0xf7, 0x43, 0xdd, 0x69,
		0x4d, 0xee, 0xaa, 0x73, 0x15, 0xdd, 0x42, 0x3d, 0xbe, 0x03, 0xb4, 0x64, 0xe6, 0x5f, 0x61, 0x3b,
		0xd2, 0x92, 0x79, 0x49, 0xf7, 0xdf, 0x6d, 0xed, 0xcf, 0xfc, 0x61, 0x8b, 0xac, 0x6c, 0xce, 0x44,
		0xa2, 0x30, 0xc6, 0xde, 0xe4, 0xa9, 0xbb, 0xd2, 0x56, 0x4a, 0x38, 0x0d, 0xfd, 0xa0, 0xa3, 0x1b,
		0xac, 0xf4, 0x82, 0x86, 0x4e, 0xd8, 0x32, 0x3b, 0x22, 0xa7, 0xc6, 0xe3, 0xcc, 0x2c, 0x22, 0xbf,
		0x19, 0xa4, 0xb7, 0xe3, 0x5a, 0xcd, 0x3b, 0x3e, 0xb3, 0xdf, 0x68, 0xd8, 0x96, 0x6d, 0xdb, 0x30,
		0xb5, 0xed, 0x9a, 0x35, 0x0a, 0x73, 0x8f, 0xce, 0xe0, 0x63, 0xb3, 0xd4, 0x7a, 0xcc, 0x6a, 0x6b,
		0x31, 0x4b, 0xad, 0xc3, 0x9e, 0xb7, 0xb7, 0x8a, 0x86, 0xbf, 0xd8, 0xe2, 0xb6, 0x15, 0xcd, 0x76,
		0x94, 0xed, 0x6d, 0x26, 0xb2, 0xed, 0x23, 0xb2, 0x6d, 0x21, 0xb2, 0xed, 0x1e, 0x00, 0x02, 0x09,
		0x20, 0x58, 0x88, 0x24, 0x1b, 0xc4, 0x83, 0x0f, 0x29, 0x7a, 0xf6, 0xb6, 0x9e, 0x39, 0xd9, 0xb3,
		0x76, 0x8c, 0xa2, 0xeb, 0x46, 0xdc, 0xd4, 0x8c, 0xc1, 0x6d, 0x6e, 0x1e, 0x06, 0x4c, 0xc3, 0x79,
		0x39, 0xcb, 0x81, 0x39, 0x28, 0x79, 0xae, 0xfa, 0xb6, 0xf8, 0xfd, 0x86, 0x8c, 0xd9, 0x2c, 0xd5,
		0x30, 0x9e, 0x41, 0x63, 0x83, 0x5a, 0xd8, 0xa5, 0x14, 0xb6, 0xa8, 0x84, 0x75, 0x0a, 0x61, 0x9d,
		0x3a, 0x58, 0xa7, 0x0c, 0xe9, 0x82, 0x09, 0xd3, 0x5d, 0x31, 0x9d, 0x99, 0x66, 0xb3, 0x26, 0x65,
		0x66, 0xdf, 0x0f, 0x2d, 0x03, 0x2d, 0x03, 0x2d, 0xb3, 0x83, 0x5a, 0xc6, 0x56, 0x1b, 0xdf, 0xc8,
		0xb1, 0xd8, 0xb3, 0xc7, 0x05, 0xff, 0x65, 0xcb, 0x16, 0xed, 0x76, 0x73, 0xb7, 0x9e, 0x79, 0x4c,
		0x91, 0x59, 0x4c, 0x9b, 0x39, 0x4c, 0x95, 0x19, 0x4c, 0x9e, 0xf9, 0x4b, 0x9e, 0xd9, 0x4b, 0x9e,
		0xb9, 0xbb, 0x5d, 0xdb, 0xa5, 0xb6, 0xbb, 0x9b, 0x3b, 0xf3, 0x1d, 0x58, 0xeb, 0x96, 0xfc, 0x7c,
		0x3a, 0xd5, 0xe6, 0x96, 0xef, 0x6b, 0x97, 0x69, 0x39, 0xf9, 0x8b, 0xec, 0xd0, 0x06, 0xe5, 0xe1,
		0x0c, 0x9e, 0x43, 0x18, 0xd4, 0x87, 0x2d, 0xd8, 0x0e, 0x55, 0xb0, 0x1d, 0x9e, 0x60, 0x3b, 0x24,
		0xb1, 0xdd, 0xf9, 0x50, 0x64, 0x87, 0x1b, 0xe2, 0x75, 0x37, 0x10, 0x5e, 0x3f, 0x10, 0x7d, 0x8a,
		0x45, 0x37, 0x67, 0x96, 0x55, 0x82, 0xb1, 0xce, 0x67, 0xc1, 0xe5, 0x4f, 0x9f, 0xa2, 0x80, 0x7f,
		0x6e, 0x0e, 0x05, 0xdb, 0x9a, 0x78, 0x65, 0x91, 0x5f, 0x0e, 0x69, 0xdc, 0xfd, 0x33, 0x2a, 0x93,
		0x90, 0x4b, 0x80, 0x32, 0x40, 0x19, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0xa7, 0x18, 0x94, 0xa3, 0x65,
		0x07, 0x4c, 0x4e, 0x4c, 0x95, 0x9d, 0x64, 0xae, 0x95, 0x06, 0x67, 0x23, 0xb9, 0x6b, 0xa5, 0xa9,
		0x01, 0x91, 0x81, 0xc8, 0x40, 0x64, 0x20, 0xf2, 0xfa, 0xb3, 0x66, 0x3b, 0x52, 0x19, 0x0f, 0x34,
		0x3d, 0xc4, 0x2a, 0x55, 0x4f, 0xd0, 0x95, 0x2a, 0x59, 0x6c, 0x7e, 0x18, 0x8d, 0x4d, 0x75, 0x72,
		0x97, 0xb4, 0x28, 0x0d, 0x79, 0x11, 0x1a, 0x8e, 0xa2, 0x33, 0xbc, 0x45, 0x66, 0xb8, 0x8a, 0xca,
		0xb0, 0x17, 0x91, 0x61, 0x2f, 0x1a, 0xc3, 0x5e, 0x24, 0x26, 0x5b, 0x35, 0x05, 0xc8, 0x8b, 0xbe,
		0x30, 0x48, 0x31, 0x0e, 0x49, 0xb6, 0x4c, 0x9a, 0xfd, 0xc7, 0xdf, 0x29, 0x24, 0x85, 0x42, 0x87,
		0xf1, 0xab, 0x99, 0x90, 0x8b, 0x60, 0x2a, 0x2b, 0x47, 0xaa, 0x09, 0x98, 0x75, 0xd7, 0xbf, 0xbb,
		0x1b, 0x29, 0xa9, 0x1f, 0xb9, 0xd8, 0xc5, 0xeb, 0x0b, 0x00, 0xc5, 0x00, 0xc5, 0x00, 0xc5, 0x00,
		0xc5, 0x00, 0xc5, 0x00, 0xc5, 0xe0, 0xa4, 0x18, 0x73, 0x5c, 0x92, 0x22, 0x8c, 0x5f, 0x3f, 0x82,
		0x65, 0xac, 0x37, 0xe5, 0xe2, 0x41, 0xbb, 0xec, 0x4c, 0x63, 0xd9, 0x45, 0x80, 0x6d, 0x80, 0x6d,
		0x80, 0x6d, 0x80, 0x6d, 0x80, 0x6d, 0x80, 0x6d, 0x70, 0xb2, 0x8d, 0x97, 0xd8, 0x34, 0x61, 0x1c,
		0x0b, 0x58, 0x05, 0xd6, 0xb1, 0xde, 0xd4, 0x4b, 0x75, 0xef, 0x0d, 0x64, 0xcf, 0x0d, 0x84, 0x17,
		0x12, 0x96, 0x4c, 0x8c, 0x2d, 0xfc, 0xd5, 0xf8, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a,
		0xe0, 0x1a, 0xe4, 0xeb, 0x56, 0xf6, 0x84, 0xd2, 0x52, 0x3f, 0x32, 0xf1, 0x0d, 0xca, 0x02, 0xc8,
		0x8d, 0xd9, 0xad, 0x7e, 0xf6, 0x42, 0x06, 0x97, 0x31, 0x9f, 0xf0, 0xc6, 0xd9, 0xef, 0xf5, 0xd3,
		0xc6, 0x97, 0x4e, 0xab, 0x79, 0x75, 0x79, 0xd2, 0x69, 0x9d, 0xd4, 0x2f, 0x9a, 0x67, 0xd4, 0xde,
		0xe3, 0x77, 0x6f, 0x30, 0x9a, 0x9e, 0xde, 0xbf, 0x26, 0xaf, 0x60, 0xcf, 0xdc, 0x56, 0x68, 0x3e,
		0xfb, 0xbf, 0x9c, 0x5e, 0x5d, 0x5c, 0x9e, 0xb4, 0x3a, 0xa7, 0xcd, 0xe6, 0xb9, 0xb3, 0x0b, 0xcd,
		0x9d, 0x52, 0x32, 0xef, 0xf5, 0x0b, 0x4c, 0x39, 0xf1, 0x94, 0x37, 0x5b, 0x8d, 0x5f, 0x1b, 0x67,
		0xf5, 0xcb, 0x66, 0x0b, 0xb3, 0x4e, 0xe8, 0x60, 0x9a, 0x67, 0x5f, 0x4f, 0xbe, 0x38, 0x19, 0x6f,
		0xbf, 0xd2, 0xce, 0x1a, 0xdf, 0xcb, 0x84, 0xba, 0x1f, 0x78, 0xa1, 0x76, 0xef, 0xfc, 0x9e, 0xec,
		0x4b, 0xd1, 0xa3, 0x17, 0xf7, 0x8b, 0xc3, 0x43, 0xdb, 0x43, 0xdb, 0x43, 0xdb, 0x43, 0xdb, 0x43,
		0xdb, 0x93, 0xaf, 0x5b, 0x2d, 0xef, 0x84, 0x96, 0xdd, 0xef, 0x61, 0xa5, 0xc4, 0xa0, 0xed, 0x8f,
		0x08, 0x87, 0xbc, 0x52, 0x72, 0xda, 0x03, 0xc1, 0x51, 0x9e, 0xf2, 0x43, 0xd1, 0xf5, 0x55, 0x2f,
		0xa4, 0xbc, 0xe5, 0x96, 0xa7, 0x6e, 0x05, 0xb9, 0x9e, 0x66, 0xe8, 0x3f, 0xf7, 0x4d, 0x2a, 0xbe,
		0xde, 0xc0, 0xcc, 0x1d, 0x79, 0xa7, 0x51, 0x13, 0xc6, 0xf1, 0xbf, 0x06, 0x5e, 0x57, 0x4b, 0x5f,
		0x7d, 0x91, 0xb7, 0x91, 0xb5, 0xe7, 0x77, 0xa2, 0x2b, 0xf5, 0x37, 0xef, 0x61, 0xe7, 0x4d, 0x8e,
		0xb7, 0x75, 0x5c, 0xea, 0xac, 0x30, 0xa3, 0x4d, 0x26, 0xdb, 0xd0, 0xb8, 0x6f, 0x36, 0x43, 0xaa,
		0x42, 0x65, 0x09, 0x52, 0x45, 0x53, 0xb0, 0x0c, 0xba, 0x16, 0xba, 0x16, 0xba, 0x16, 0xba, 0x16,
		0xba, 0x76, 0xc9, 0xba, 0x1d, 0x49, 0xa5, 0x0f, 0x8b, 0x0c, 0x92, 0xb6, 0x0a, 0x49, 0x09, 0x49,
		0x09, 0x49, 0x09, 0x49, 0x99, 0x01, 0x93, 0x2b, 0x15, 0x6b, 0xa5, 0x5a, 0xa5, 0x5a, 0xac, 0x41,
		0x48, 0x42, 0x48, 0xee, 0xb2, 0x90, 0xa4, 0x15, 0x20, 0xb4, 0x25, 0x36, 0x21, 0x23, 0x21, 0x23,
		0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x97, 0xac, 0xdb, 0x69, 0xab, 0x42, 0x72, 0x1b, 0x8e, 0x53,
		0x9f, 0x8f, 0x68, 0x8f, 0x5a, 0x69, 0x11, 0x28, 0x72, 0x39, 0xe9, 0xfc, 0xb5, 0xbf, 0x7f, 0x9d,
		0x77, 0x6b, 0xed, 0xa7, 0xeb, 0x82, 0x5b, 0x6b, 0x47, 0x2f, 0x0b, 0xd3, 0x7f, 0xa2, 0xd7, 0xc5,
		0xeb, 0xbc, 0x5b, 0x9a, 0xbf, 0x2e, 0x5f, 0xe7, 0xdd, 0x72, 0xfb, 0xe0, 0xcf, 0x3f, 0x3f, 0x1d,
		0xfc, 0x38, 0x1c, 0xbf, 0xff, 0x83, 0xb9, 0xd9, 0x60, 0x07, 0x4f, 0xfb, 0xd7, 0x05, 0xb7, 0xd8,
		0x9e, 0xff, 0x9f, 0xc3, 0xeb, 0xbc, 0x5b, 0x6c, 0x1f, 0x1c, 0xfc, 0x8f, 0x6e, 0x8d, 0xb6, 0x29,
		0x1f, 0x6e, 0xf3, 0xa2, 0xf1, 0x07, 0x9e, 0x30, 0xf5, 0x13, 0x06, 0xc7, 0x7e, 0xb3, 0x8d, 0xcc,
		0x0e, 0xfb, 0x59, 0x6d, 0xbd, 0xb5, 0xd2, 0xcd, 0xbf, 0x1c, 0x1c, 0x6c, 0x1b, 0x6c, 0x1b, 0x6c,
		0x1b, 0x6c, 0x1b, 0x6c, 0x9b, 0x7c, 0xdd, 0xde, 0xf8, 0xfe, 0x40, 0x78, 0x8a, 0x83, 0x69, 0x17,
		0xb2, 0x02, 0xd5, 0x5b, 0x5d, 0x11, 0xda, 0x52, 0xab, 0xfa, 0x95, 0xe3, 0x91, 0xb4, 0xb0, 0x0f,
		0x44, 0x2e, 0x6a, 0x55, 0x1c, 0xfd, 0x13, 0xd5, 0xa3, 0x40, 0xb7, 0x84, 0xe4, 0xd3, 0x18, 0xa9,
		0xef, 0xca, 0xff, 0x57, 0xb9, 0x9e, 0xd6, 0x81, 0xbc, 0xb1, 0xd2, 0x3c, 0x7a, 0xa5, 0xeb, 0x59,
		0x32, 0x36, 0xfa, 0x28, 0xa4, 0x95, 0xf0, 0xa1, 0x8f, 0x42, 0x36, 0x09, 0x1d, 0xfa, 0x28, 0xac,
		0x35, 0x6b, 0x64, 0x7d, 0x14, 0x12, 0x4e, 0x92, 0x5e, 0xa9, 0x27, 0x2f, 0x81, 0x56, 0xaf, 0x17,
		0xa0, 0xd7, 0xa1, 0xd7, 0xa1, 0xd7, 0xa1, 0xd7, 0xd3, 0xa3, 0xd7, 0xa9, 0xdc, 0x7f, 0x3c, 0xe0,
		0xb4, 0x6b, 0x80, 0xa6, 0x8e, 0x12, 0xec, 0x25, 0xba, 0xea, 0x4c, 0x2f, 0x81, 0xd8, 0x74, 0x79,
		0x32, 0xb3, 0xc8, 0xe1, 0x80, 0x13, 0x16, 0xd2, 0x01, 0x0f, 0xdc, 0x30, 0x91, 0x1a, 0xb8, 0x48,
		0x0d, 0x6c, 0xa4, 0x06, 0x3e, 0x68, 0x61, 0x84, 0x18, 0x4e, 0xe2, 0x59, 0xbe, 0xe4, 0x70, 0xf0,
		0x7b, 0xbc, 0x35, 0x6e, 0x13, 0x6c, 0xbf, 0xca, 0x30, 0x76, 0xa2, 0xbf, 0xea, 0x33, 0xd8, 0x65,
		0x34, 0x17, 0x95, 0xd0, 0xb4, 0x89, 0x5a, 0xb2, 0xae, 0xb4, 0x69, 0x8a, 0x16, 0xad, 0xcc, 0xda,
		0x15, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x85, 0x83, 0xb4, 0x50, 0x6b, 0xe1, 0x45, 0x4d,
		0x3c, 0x10, 0x8c, 0xc7, 0xd4, 0x16, 0xa4, 0xf1, 0xe4, 0x4a, 0x3e, 0xee, 0xe4, 0xd9, 0x25, 0x2e,
		0xd0, 0x49, 0x03, 0xf8, 0xa4, 0x0b, 0x84, 0xd2, 0x02, 0x46, 0xa9, 0x03, 0xa5, 0xd4, 0x81, 0x53,
		0xea, 0x40, 0x8a, 0x07, 0xac, 0x98, 0x40, 0x8b, 0x5f, 0x71, 0x27, 0xfc, 0xc6, 0x48, 0x2a, 0x5d,
		0xa8, 0x70, 0xfa, 0x8c, 0x19, 0x8a, 0x54, 0x18, 0x2f, 0x81, 0xe7, 0x74, 0xfd, 0xeb, 0x3f, 0xbc,
		0x3e, 0x73, 0x8f, 0xfb, 0xf4, 0x7d, 0xca, 0xe8, 0x45, 0xe2, 0x72, 0x98, 0x4f, 0xe7, 0x27, 0xae,
		0x27, 0x05, 0x27, 0xa6, 0x53, 0xe2, 0x4e, 0x17, 0x4d, 0xd8, 0x7b, 0x80, 0x09, 0xff, 0xc4, 0x84,
		0x2b, 0xe5, 0xf2, 0x61, 0x19, 0x66, 0x9c, 0x2e, 0x2e, 0xc2, 0x3f, 0x7a, 0xfb, 0xc3, 0x6e, 0xdc,
		0x2f, 0x47, 0x91, 0x11, 0xbe, 0x9d, 0xf4, 0xe5, 0x61, 0x03, 0x86, 0x1d, 0x75, 0xc4, 0x0d, 0x10,
		0x37, 0x40, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x32, 0x12, 0x37, 0x38, 0x4a, 0x41, 0xd8, 0xa0,
		0x8c, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x81, 0x75, 0x13, 0x2e, 0x96,
		0x11, 0x34, 0x40, 0xd0, 0x00, 0x41, 0x03, 0xda, 0xa0, 0xc1, 0xfd, 0x6c, 0xf5, 0xa5, 0x21, 0x6a,
		0x10, 0x5d, 0x0b, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b,
		0xbc, 0xd3, 0x6f, 0xdc, 0x48, 0xe5, 0x05, 0x8f, 0x29, 0x88, 0x1b, 0xd4, 0x18, 0x2f, 0xe1, 0x54,
		0xa8, 0xdb, 0x69, 0xe2, 0x3f, 0x02, 0x07, 0x08, 0x1c, 0xfc, 0x54, 0x75, 0x15, 0xa0, 0xb9, 0x10,
		0x38, 0xd8, 0x6e, 0x13, 0x46, 0xbe, 0x01, 0x42, 0x07, 0x08, 0x1d, 0x90, 0x9a, 0xb9, 0x78, 0xd0,
		0x42, 0xf5, 0x08, 0x1b, 0xbe, 0xaf, 0xa4, 0x7c, 0xf1, 0x95, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2,
		0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0xc1, 0x7b, 0xc3, 0x06, 0xe4, 0xe5, 0x62, 0x57, 0xc1,
		0x08, 0x51, 0xf9, 0xd8, 0xdd, 0x24, 0x2d, 0xfe, 0x70, 0xc2, 0xcc, 0xbd, 0x01, 0x3f, 0x69, 0x89,
		0xaf, 0x04, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05,
		0xa4, 0x25, 0x39, 0xc7, 0x43, 0x2f, 0xd0, 0x32, 0x0d, 0x9c, 0x65, 0x7e, 0x21, 0xa0, 0x2c, 0xa0,
		0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xc9, 0x39, 0xd6,
		0x81, 0xa7, 0x42, 0xa9, 0xe5, 0x7d, 0x0a, 0xf2, 0x4a, 0x5f, 0x5c, 0x0b, 0x88, 0x0b, 0x88, 0x0b,
		0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x4b, 0xea, 0x89, 0x4b, 0xa6, 0xcb, 0x8b,
		0x12, 0xf7, 0x27, 0x4c, 0x8c, 0xcf, 0xd2, 0xaf, 0x30, 0xd9, 0x1a, 0x2f, 0xf9, 0x23, 0x8a, 0xa6,
		0x86, 0x7c, 0xa6, 0x96, 0xad, 0x7e, 0x31, 0xbf, 0x89, 0x47, 0x8e, 0x82, 0x2f, 0xce, 0xa9, 0x0c,
		0x75, 0x5d, 0x6b, 0xe2, 0x66, 0x35, 0xdf, 0xa4, 0x3a, 0x19, 0x88, 0x09, 0x1b, 0x08, 0x69, 0xd9,
		0xb4, 0xf3, 0xcd, 0x7b, 0x78, 0x31, 0x72, 0xe1, 0xa8, 0x54, 0xaa, 0x54, 0x4b, 0xa5, 0x7c, 0xf5,
		0xb0, 0x9a, 0xaf, 0x95, 0xcb, 0x85, 0x4a, 0x81, 0x30, 0xf9, 0xd5, 0x69, 0x06, 0x3d, 0x11, 0x88,
		0xde, 0xe7, 0xc9, 0xa3, 0x57, 0xa3, 0xc1, 0x20, 0x53, 0x16, 0xcd, 0xe4, 0x96, 0xd3, 0xeb, 0x8e,
		0x1d, 0xd2, 0x86, 0x0a, 0xc1, 0xa8, 0xab, 0xd5, 0x8c, 0x72, 0x7d, 0xbe, 0x1d, 0x76, 0x5a, 0xf2,
		0xa6, 0x53, 0xef, 0xcb, 0x0b, 0xaf, 0x2f, 0x3b, 0x8d, 0xe1, 0x7d, 0xe9, 0x2a, 0xba, 0xd1, 0xce,
		0xd9, 0xec, 0xf6, 0x3a, 0xf5, 0xde, 0x3f, 0x2d, 0x79, 0xd3, 0x50, 0xe7, 0x81, 0xe8, 0xb4, 0x26,
		0x37, 0xd5, 0xb9, 0x8a, 0xee, 0xa0, 0x1e, 0xdf, 0x00, 0xda, 0x31, 0xf3, 0xaf, 0xaf, 0xdd, 0x68,
		0xc7, 0xbc, 0xa4, 0xf3, 0xef, 0xb6, 0xf6, 0x66, 0xfe, 0xb0, 0x45, 0x46, 0x36, 0xa7, 0x21, 0x51,
		0x08, 0x63, 0x6f, 0xf2, 0xd0, 0x5d, 0x69, 0x2b, 0x1d, 0x9c, 0x86, 0x7b, 0xd0, 0x71, 0x0d, 0x56,
		0x6e, 0x41, 0xc3, 0x25, 0x6c, 0x99, 0x1d, 0x91, 0x4f, 0x63, 0xf1, 0x65, 0x16, 0x61, 0xdf, 0x08,
		0xcc, 0xdb, 0x71, 0xac, 0xe6, 0xdd, 0x9e, 0xd9, 0x6f, 0x34, 0x6c, 0xc9, 0xb6, 0x2d, 0x98, 0xd8,
		0x72, 0xcd, 0xda, 0x84, 0xb9, 0x27, 0x67, 0xf0, 0xa9, 0x59, 0xea, 0x39, 0x66, 0xb5, 0xa7, 0x98,
		0xa5, 0x9e, 0x61, 0xcf, 0xfb, 0x5a, 0x45, 0xc3, 0x5f, 0x6c, 0x71, 0xbf, 0x8a, 0x66, 0x1f, 0xca,
		0xf6, 0xfe, 0x12, 0xd9, 0xbe, 0x11, 0xd9, 0x7e, 0x10, 0xd9, 0x3e, 0x0f, 0xf0, 0x80, 0x02, 0x0f,
		0x2c, 0x84, 0x90, 0x0d, 0xc2, 0xc1, 0x87, 0x14, 0x3d, 0x7a, 0x5b, 0x8f, 0x9c, 0xea, 0x51, 0x3b,
		0x46, 0xb1, 0x75, 0x13, 0x5e, 0x6a, 0xc6, 0xdc, 0x36, 0x37, 0x0e, 0x03, 0x86, 0xe1, 0xcc, 0xe7,
		0xd8, 0x1f, 0x69, 0x77, 0xe8, 0x87, 0xda, 0x98, 0x69, 0x3c, 0x57, 0x7b, 0x7b, 0x3d, 0x82, 0x21,
		0x73, 0x36, 0xcb, 0x35, 0x8c, 0xe7, 0xce, 0xd8, 0xe0, 0x16, 0x76, 0x39, 0x85, 0x2d, 0x2e, 0x61,
		0x9d, 0x43, 0x58, 0xe7, 0x0e, 0xd6, 0x39, 0x43, 0xba, 0x80, 0xc2, 0x74, 0x3f, 0x4c, 0x67, 0x26,
		0xda, 0xac, 0x69, 0x99, 0xd9, 0xf7, 0x43, 0xcc, 0x40, 0xcc, 0x40, 0xcc, 0xec, 0xa0, 0x98, 0xb1,
		0xd5, 0xc0, 0x37, 0x72, 0x2c, 0xf6, 0xec, 0x71, 0xc1, 0x7f, 0xd9, 0xb2, 0x45, 0xbb, 0x7d, 0xdc,
		0xad, 0xe7, 0x1c, 0x53, 0xe4, 0x14, 0xd3, 0xe6, 0x0c, 0x53, 0xe5, 0x04, 0x93, 0xe7, 0xfc, 0x92,
		0xe7, 0xf4, 0x92, 0xe7, 0xec, 0x6e, 0xd7, 0x66, 0xa9, 0xed, 0xbe, 0xe6, 0xce, 0x7c, 0xff, 0xd5,
		0xba, 0x25, 0x3f, 0x9f, 0x4b, 0xb5, 0xb9, 0xe1, 0xfb, 0xda, 0x65, 0x5a, 0xce, 0xfb, 0x22, 0x3b,
		0xae, 0x41, 0x79, 0x2c, 0x83, 0xe7, 0xf8, 0x05, 0xf5, 0x31, 0x0b, 0xb6, 0xe3, 0x14, 0x6c, 0xc7,
		0x26, 0xd8, 0x8e, 0x47, 0x6c, 0x77, 0x32, 0x14, 0xd9, 0xb1, 0x86, 0x78, 0xdd, 0x0d, 0x84, 0xd7,
		0x0f, 0x44, 0x9f, 0x62, 0xd1, 0xcd, 0x99, 0x65, 0x95, 0x60, 0xac, 0xf3, 0x59, 0x78, 0xf9, 0xd3,
		0xa7, 0x28, 0xe4, 0x9f, 0x9b, 0x43, 0xc1, 0xb6, 0xa6, 0x5d, 0x59, 0xe4, 0x97, 0x43, 0x1a, 0x77,
		0xff, 0x8c, 0xca, 0x24, 0xe4, 0x12, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0x03, 0x94, 0x01, 0xca, 0x29,
		0x06, 0xe5, 0x68, 0xd9, 0x01, 0x93, 0x13, 0x53, 0x65, 0x27, 0x9b, 0x6b, 0xa5, 0xc1, 0xd9, 0xc8,
		0xee, 0x5a, 0x69, 0x6a, 0x40, 0x64, 0x20, 0x32, 0x10, 0x19, 0x88, 0xbc, 0xfe, 0xac, 0xd9, 0x8e,
		0x54, 0xc6, 0x03, 0x4d, 0xcf, 0xaf, 0x4a, 0xd5, 0x13, 0x74, 0x45, 0x4a, 0x16, 0xdb, 0x1e, 0x46,
		0x63, 0x53, 0x1d, 0xda, 0x25, 0x2d, 0x47, 0x43, 0x5e, 0x7e, 0x86, 0xa3, 0xdc, 0x0c, 0x6f, 0x79,
		0x19, 0xae, 0x72, 0x32, 0xec, 0xe5, 0x63, 0xd8, 0xcb, 0xc5, 0xb0, 0x97, 0x87, 0xc9, 0x56, 0x39,
		0x01, 0xf2, 0x72, 0x2f, 0x0c, 0x52, 0x8c, 0x43, 0x92, 0x2d, 0x93, 0x66, 0xff, 0xf1, 0x77, 0x0a,
		0x49, 0xa1, 0xd0, 0x61, 0xfc, 0x6a, 0x26, 0xe4, 0x22, 0x98, 0xca, 0xca, 0x79, 0x6a, 0x02, 0x66,
		0xdd, 0xf5, 0xef, 0xee, 0x46, 0x4a, 0xea, 0x47, 0x2e, 0x76, 0xf1, 0xfa, 0x02, 0x40, 0x31, 0x40,
		0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x38, 0x29, 0xc6, 0x1c, 0x97, 0xa4, 0x08,
		0xe3, 0xd7, 0x8f, 0x60, 0x19, 0xeb, 0x4d, 0xb9, 0x78, 0xd0, 0x2e, 0x3b, 0xd3, 0x58, 0x76, 0x11,
		0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x9c, 0x6c, 0xe3, 0x25,
		0x36, 0x4d, 0x18, 0xc7, 0x02, 0x56, 0x81, 0x75, 0xac, 0x37, 0xf5, 0x52, 0xdd, 0x7b, 0x03, 0xd9,
		0x73, 0x03, 0xe1, 0x85, 0x84, 0xd5, 0x12, 0x63, 0x0b, 0x7f, 0x35, 0x3e, 0xb8, 0x06, 0xb8, 0x06,
		0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xf9, 0xba, 0x95, 0x3d, 0xa1, 0xb4, 0xd4, 0x8f, 0x4c, 0x7c,
		0x83, 0xb2, 0xf6, 0x71, 0x63, 0x76, 0xab, 0x9f, 0xbd, 0x90, 0xc1, 0x65, 0xcc, 0x27, 0xbc, 0x71,
		0xf6, 0x7b, 0xfd, 0xb4, 0xf1, 0xa5, 0xd3, 0x6a, 0x5e, 0x5d, 0x9e, 0x74, 0x5a, 0x27, 0xf5, 0x8b,
		0xe6, 0x19, 0xb5, 0xf7, 0xf8, 0xdd, 0x1b, 0x8c, 0xa6, 0xa7, 0xf7, 0xaf, 0xc9, 0x6b, 0xd7, 0x33,
		0x37, 0x14, 0x9a, 0xcf, 0xfe, 0x2f, 0xa7, 0x57, 0x17, 0x97, 0x27, 0xad, 0xce, 0x69, 0xb3, 0x79,
		0xee, 0xec, 0x42, 0x5b, 0xa7, 0x94, 0xcc, 0x7b, 0xfd, 0x02, 0x53, 0x4e, 0x3c, 0xe5, 0xcd, 0x56,
		0xe3, 0xd7, 0xc6, 0x59, 0xfd, 0xb2, 0xd9, 0xc2, 0xac, 0x13, 0x3a, 0x98, 0xe6, 0xd9, 0xd7, 0x93,
		0x2f, 0x4e, 0xc6, 0x1b, 0xaf, 0xb4, 0xb3, 0xc6, 0xf7, 0x32, 0xa1, 0xee, 0x07, 0x5e, 0xa8, 0xdd,
		0x3b, 0xbf, 0x27, 0xfb, 0x52, 0xf4, 0xe8, 0xc5, 0xfd, 0xe2, 0xf0, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0,
		0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xe4, 0xeb, 0x56, 0xcb, 0x3b, 0xa1, 0x65, 0xf7, 0x7b, 0x58, 0x29,
		0x31, 0x68, 0xfb, 0x23, 0xc2, 0x21, 0xaf, 0x94, 0x9c, 0x76, 0x40, 0x70, 0x94, 0xa7, 0xfc, 0x50,
		0x74, 0x7d, 0xd5, 0x0b, 0x29, 0x6f, 0xb9, 0xe5, 0xa9, 0x5b, 0x41, 0xae, 0xa7, 0x19, 0x3a, 0xcf,
		0x7d, 0x93, 0x8a, 0xaf, 0x2b, 0x30, 0x73, 0x2f, 0xde, 0x69, 0xd4, 0x84, 0x71, 0xfc, 0xaf, 0x81,
		0xd7, 0xd5, 0xd2, 0x57, 0x5f, 0xe4, 0x6d, 0x64, 0xed, 0xf9, 0x9d, 0xe8, 0x47, 0xfd, 0xcd, 0x7b,
		0xd8, 0x79, 0x93, 0xe3, 0xed, 0x1a, 0x97, 0x3a, 0x2b, 0xcc, 0x68, 0x7f, 0xc9, 0x36, 0x34, 0xee,
		0x9b, 0xcd, 0x90, 0xaa, 0x50, 0x59, 0x82, 0x54, 0xd1, 0x14, 0x2c, 0x83, 0xae, 0x85, 0xae, 0x85,
		0xae, 0x85, 0xae, 0x85, 0xae, 0x5d, 0xb2, 0x6e, 0x47, 0x52, 0xe9, 0xc3, 0x22, 0x83, 0xa4, 0xad,
		0x42, 0x52, 0x42, 0x52, 0x42, 0x52, 0x42, 0x52, 0x66, 0xc0, 0xe4, 0x4a, 0xc5, 0x5a, 0xa9, 0x56,
		0xa9, 0x16, 0x6b, 0x10, 0x92, 0x10, 0x92, 0xbb, 0x2c, 0x24, 0x69, 0x05, 0x08, 0x6d, 0x89, 0x4d,
		0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0xc8, 0x25, 0xeb, 0x76, 0xda, 0xac, 0x90,
		0xdc, 0x86, 0xe3, 0xd4, 0xe7, 0x23, 0xda, 0xa3, 0x56, 0x5a, 0x04, 0x8a, 0x5c, 0x4e, 0x3a, 0x7f,
		0xed, 0xef, 0x5f, 0xe7, 0xdd, 0x5a, 0xfb, 0xe9, 0xba, 0xe0, 0xd6, 0xda, 0xd1, 0xcb, 0xc2, 0xf4,
		0x9f, 0xe8, 0x75, 0xf1, 0x3a, 0xef, 0x96, 0xe6, 0xaf, 0xcb, 0xd7, 0x79, 0xb7, 0xdc, 0x3e, 0xf8,
		0xf3, 0xcf, 0x4f, 0x07, 0x3f, 0x0e, 0xc7, 0xef, 0xff, 0x60, 0x6e, 0x36, 0xd8, 0xc1, 0xd3, 0xfe,
		0x75, 0xc1, 0x2d, 0xb6, 0xe7, 0xff, 0xe7, 0xf0, 0x3a, 0xef, 0x16, 0xdb, 0x07, 0x07, 0xff, 0xa3,
		0x5b, 0xa3, 0x6d, 0xca, 0x87, 0xdb, 0xbc, 0x68, 0xfc, 0x81, 0x27, 0x4c, 0xfd, 0x84, 0xc1, 0xb1,
		0xdf, 0x6c, 0x23, 0xb3, 0xc3, 0x7e, 0x56, 0x5b, 0x6f, 0xad, 0x74, 0xf3, 0x2f, 0x07, 0x07, 0xdb,
		0x06, 0xdb, 0x06, 0xdb, 0x06, 0xdb, 0x06, 0xdb, 0x26, 0x5f, 0xb7, 0x37, 0xbe, 0x3f, 0x10, 0x9e,
		0xe2, 0x60, 0xda, 0x85, 0xac, 0x40, 0xf5, 0x56, 0x57, 0x84, 0xb6, 0xd4, 0xac, 0x7e, 0xe5, 0x78,
		0xd6, 0x9b, 0xd8, 0xcf, 0xdb, 0x9f, 0xe7, 0xa2, 0x66, 0xc5, 0xd1, 0x3f, 0x51, 0x45, 0x0a, 0xf4,
		0x4b, 0x48, 0x3e, 0x8f, 0x91, 0xfa, 0xae, 0xfc, 0x7f, 0x95, 0xeb, 0x69, 0x1d, 0xc8, 0x1b, 0x2b,
		0xed, 0xa3, 0x57, 0x3a, 0x9f, 0x25, 0x63, 0xa3, 0x93, 0x42, 0x5a, 0x29, 0x1f, 0x3a, 0x29, 0x64,
		0x93, 0xd2, 0xa1, 0x93, 0xc2, 0x5a, 0xb3, 0x46, 0xd6, 0x49, 0x21, 0xe1, 0x24, 0xe9, 0xb5, 0x7a,
		0xf2, 0x12, 0x68, 0x15, 0x7b, 0x01, 0x8a, 0x1d, 0x8a, 0x1d, 0x8a, 0x1d, 0x8a, 0x3d, 0x3d, 0x8a,
		0x9d, 0xca, 0xfd, 0xc7, 0x03, 0x4e, 0xfb, 0x06, 0x68, 0xea, 0x38, 0xc1, 0x5e, 0xa2, 0xaf, 0xce,
		0xf4, 0x12, 0x88, 0x4d, 0x97, 0x27, 0x37, 0x8b, 0x1c, 0x0e, 0x38, 0x61, 0x21, 0x1d, 0xf0, 0xc0,
		0x0d, 0x13, 0xa9, 0x81, 0x8b, 0xd4, 0xc0, 0x46, 0x6a, 0xe0, 0x83, 0x16, 0x46, 0x88, 0xe1, 0x24,
		0x9e, 0xe5, 0x4b, 0x0e, 0x07, 0xbf, 0xc7, 0x5b, 0xe5, 0x36, 0xc1, 0xf6, 0xab, 0x0c, 0x63, 0x27,
		0x3a, 0xac, 0x3e, 0x83, 0x5d, 0x46, 0xb3, 0x51, 0x09, 0x4d, 0x9b, 0xa8, 0x29, 0xeb, 0x4a, 0x9b,
		0xa6, 0x68, 0xd2, 0xca, 0xac, 0x5d, 0x41, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x38, 0x48,
		0x0b, 0xb5, 0x16, 0x5e, 0xd4, 0xc4, 0x03, 0xc1, 0x78, 0x50, 0x6d, 0x41, 0x1a, 0x4f, 0xae, 0xe4,
		0xe3, 0x4e, 0x9e, 0x5e, 0xe2, 0x02, 0x9d, 0x34, 0x80, 0x4f, 0xba, 0x40, 0x28, 0x2d, 0x60, 0x94,
		0x3a, 0x50, 0x4a, 0x1d, 0x38, 0xa5, 0x0e, 0xa4, 0x78, 0xc0, 0x8a, 0x09, 0xb4, 0xf8, 0x15, 0x77,
		0xc2, 0x6f, 0x8c, 0xa4, 0xd2, 0x85, 0x0a, 0xa7, 0xcf, 0x98, 0xa1, 0x48, 0x85, 0xf1, 0x12, 0x78,
		0xce, 0xd7, 0xbf, 0xfe, 0xc3, 0xeb, 0x33, 0xf7, 0xb8, 0xcf, 0xdf, 0xa7, 0x8c, 0x5e, 0x24, 0x2e,
		0x87, 0xf9, 0x7c, 0x7e, 0xe2, 0x7a, 0x52, 0x70, 0x66, 0x3a, 0x25, 0xee, 0x74, 0xd1, 0x84, 0xbd,
		0x07, 0x98, 0xf0, 0x4f, 0x4c, 0xb8, 0x52, 0x2e, 0x1f, 0x96, 0x61, 0xc6, 0xe9, 0xe2, 0x22, 0xfc,
		0xa3, 0xb7, 0x3f, 0xec, 0xc6, 0xfd, 0x72, 0x94, 0x19, 0xe1, 0xdb, 0x49, 0x5f, 0x1e, 0x36, 0x60,
		0xd8, 0x51, 0x47, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc, 0x20, 0x23, 0x71,
		0x83, 0xa3, 0x14, 0x84, 0x0d, 0xca, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08,
		0x1b, 0x58, 0x37, 0xe1, 0x62, 0x19, 0x41, 0x03, 0x04, 0x0d, 0x10, 0x34, 0xa0, 0x0d, 0x1a, 0xdc,
		0xcf, 0x56, 0x5f, 0x1a, 0xa2, 0x06, 0xd1, 0xb5, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08,
		0x1b, 0x20, 0x6c, 0x80, 0xb0, 0xc1, 0x3b, 0xfd, 0xc6, 0x8d, 0x54, 0x5e, 0xf0, 0x98, 0x82, 0xb8,
		0x41, 0x8d, 0xf1, 0x12, 0x4e, 0x85, 0xba, 0x9d, 0x26, 0xfe, 0x23, 0x70, 0x80, 0xc0, 0xc1, 0x4f,
		0x55, 0x57, 0x01, 0x9a, 0x0b, 0x81, 0x83, 0xed, 0x36, 0x61, 0xe4, 0x1b, 0x20, 0x74, 0x80, 0xd0,
		0x01, 0xa9, 0x99, 0x8b, 0x07, 0x2d, 0x54, 0x8f, 0xb0, 0xe5, 0xfb, 0x4a, 0xca, 0x17, 0x5f, 0x09,
		0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0xbc, 0x37, 0x6c,
		0x40, 0x5e, 0x30, 0x76, 0x15, 0x8c, 0x10, 0x15, 0x90, 0xdd, 0x4d, 0xd2, 0xe2, 0x0f, 0x27, 0xcc,
		0xdc, 0x1b, 0xf0, 0x93, 0x96, 0xf8, 0x4a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40,
		0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x92, 0x73, 0x3c, 0xf4, 0x02, 0x2d, 0xd3, 0xc0, 0x59,
		0xe6, 0x17, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca,
		0x02, 0xca, 0x92, 0x9c, 0x63, 0x1d, 0x78, 0x2a, 0x94, 0x5a, 0xde, 0xa7, 0x20, 0xaf, 0xf4, 0xc5,
		0xb5, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0xa4,
		0x9e, 0xb8, 0x64, 0xba, 0xbc, 0x28, 0x71, 0x87, 0xc2, 0xc4, 0xf8, 0x4c, 0x1d, 0x0b, 0x93, 0xcd,
		0xf1, 0x92, 0x3f, 0xa2, 0x68, 0x6b, 0xc8, 0x67, 0x6c, 0xd9, 0xea, 0x18, 0xf3, 0x9b, 0x78, 0xe4,
		0x28, 0xf9, 0xe2, 0x9c, 0xca, 0x50, 0xd7, 0xb5, 0x26, 0x6e, 0x57, 0xf3, 0x4d, 0xaa, 0x93, 0x81,
		0x98, 0xf0, 0x81, 0x90, 0x96, 0x4f, 0x3b, 0xdf, 0xbc, 0x87, 0x17, 0x23, 0x17, 0x8e, 0x4a, 0xa5,
		0x4a, 0xb5, 0x54, 0xca, 0x57, 0x0f, 0xab, 0xf9, 0x5a, 0xb9, 0x5c, 0xa8, 0x14, 0x08, 0xd3, 0x5f,
		0x9d, 0x66, 0xd0, 0x13, 0x81, 0xe8, 0x7d, 0x9e, 0x3c, 0x7a, 0x35, 0x1a, 0x0c, 0x32, 0x65, 0xd1,
		0x4c, 0x8e, 0x39, 0xcd, 0x0e, 0xd9, 0x21, 0x6d, 0xaa, 0x10, 0x8c, 0xba, 0x5a, 0xcd, 0x68, 0xd7,
		0xe7, 0xdb, 0x61, 0xa7, 0x25, 0x6f, 0x3a, 0xf5, 0xbe, 0xbc, 0xf0, 0xfa, 0xb2, 0xd3, 0x18, 0xde,
		0x97, 0xae, 0xa2, 0x5b, 0xed, 0x9c, 0xcd, 0x6e, 0xb0, 0x53, 0xef, 0xfd, 0xd3, 0x92, 0x37, 0xcd,
		0x91, 0x3e, 0xf7, 0x43, 0xdd, 0x69, 0x4d, 0x6e, 0xab, 0x73, 0x15, 0xdd, 0x43, 0x3d, 0xbe, 0x05,
		0xb4, 0x65, 0xe6, 0x5f, 0x63, 0xbb, 0xd2, 0x96, 0x79, 0x49, 0x07, 0xe0, 0x6d, 0xed, 0xd1, 0xfc,
		0x61, 0x8b, 0xcc, 0x6c, 0x4e, 0x46, 0xa2, 0x50, 0xc6, 0xde, 0xe4, 0xb1, 0xbb, 0xd2, 0x56, 0x5a,
		0x38, 0x0d, 0x03, 0xa1, 0x63, 0x1c, 0xac, 0x0c, 0x83, 0x86, 0x51, 0xd8, 0x32, 0x3b, 0x22, 0xaf,
		0xc6, 0xe4, 0xcd, 0x2c, 0x82, 0xbf, 0x21, 0xb0, 0xb7, 0xe3, 0x5c, 0xcd, 0xbb, 0x3e, 0xb3, 0xdf,
		0x68, 0xd8, 0x9a, 0x6d, 0x5b, 0x31, 0xb9, 0xf5, 0x9a, 0xb5, 0x0a, 0x73, 0xcf, 0xce, 0xe0, 0x73,
		0xb3, 0xd4, 0x81, 0xcc, 0x6a, 0x87, 0x31, 0x4b, 0x1d, 0xc4, 0x9e, 0x77, 0xb9, 0x8a, 0x86, 0xbf,
		0xd8, 0xe2, 0xee, 0x15, 0xcd, 0xae, 0x94, 0xed, 0xdd, 0x26, 0xb2, 0x5d, 0x24, 0xb2, 0xdd, 0x21,
		0xb2, 0x5d, 0x1f, 0x20, 0x02, 0x0d, 0x22, 0x58, 0x08, 0x28, 0x1b, 0x04, 0x84, 0x0f, 0x29, 0x7a,
		0xf8, 0xb6, 0x1e, 0x3a, 0xdd, 0xc3, 0x76, 0x8c, 0xe2, 0xeb, 0x66, 0xfc, 0xd4, 0x8c, 0xc9, 0x6d,
		0x6e, 0x20, 0x06, 0x8c, 0xc3, 0x59, 0x98, 0xe7, 0xc0, 0x1c, 0x9c, 0x3c, 0x17, 0x80, 0x7b, 0x35,
		0x80, 0x21, 0x83, 0x36, 0xcb, 0x37, 0x8c, 0x67, 0xd3, 0xd8, 0xe0, 0x17, 0x76, 0x79, 0x85, 0x2d,
		0x3e, 0x61, 0x9d, 0x47, 0x58, 0xe7, 0x0f, 0xd6, 0x79, 0x43, 0xba, 0xa0, 0xc2, 0x74, 0x87, 0x4c,
		0x67, 0x26, 0xdc, 0xac, 0xe9, 0x99, 0xd9, 0xf7, 0x43, 0xd0, 0x40, 0xd0, 0x40, 0xd0, 0xec, 0xa0,
		0xa0, 0xb1, 0xd5, 0xd2, 0x37, 0x72, 0x2c, 0xf6, 0xec, 0x71, 0xc1, 0x7f, 0xd9, 0xb2, 0x45, 0xbb,
		0x9d, 0xdd, 0xad, 0x67, 0x21, 0x53, 0x64, 0x19, 0xd3, 0x66, 0x11, 0x53, 0x65, 0x09, 0x93, 0x67,
		0x01, 0x93, 0x67, 0xf9, 0x92, 0x67, 0xf1, 0x6e, 0xd7, 0xb6, 0xa9, 0xed, 0x4e, 0xe7, 0xce, 0x7c,
		0x27, 0xd6, 0xba, 0x25, 0x3f, 0x9f, 0x54, 0xb5, 0xb9, 0xf5, 0xfb, 0xda, 0x65, 0x5a, 0xce, 0x03,
		0x23, 0x3b, 0xc0, 0x41, 0x79, 0x50, 0x83, 0xe7, 0x40, 0x06, 0xf5, 0xc1, 0x0b, 0xb6, 0x03, 0x16,
		0x6c, 0x07, 0x29, 0xd8, 0x0e, 0x4c, 0x6c, 0x77, 0x62, 0x14, 0xd9, 0x41, 0x87, 0x78, 0xdd, 0x0d,
		0x84, 0xd7, 0x0f, 0x44, 0x9f, 0x62, 0xd1, 0xcd, 0x99, 0x65, 0x95, 0x60, 0xac, 0xf3, 0x59, 0x80,
		0xf9, 0xd3, 0xa7, 0x28, 0xe8, 0x9f, 0x9b, 0x43, 0xc1, 0xb6, 0x26, 0x60, 0x59, 0xe4, 0x97, 0x43,
		0x1a, 0x77, 0xff, 0x8c, 0xca, 0x24, 0xe4, 0x12, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0x03, 0x94, 0x01,
		0xca, 0x29, 0x06, 0xe5, 0x68, 0xd9, 0x01, 0x93, 0x13, 0x53, 0x65, 0x27, 0xa3, 0x6b, 0xa5, 0xc1,
		0xd9, 0xc8, 0xf0, 0x5a, 0x69, 0x6a, 0x40, 0x64, 0x20, 0x32, 0x10, 0x19, 0x88, 0xbc, 0xfe, 0xac,
		0xd9, 0x8e, 0x54, 0xc6, 0x03, 0x4d, 0xcf, 0xb3, 0x4a, 0xd5, 0x13, 0x74, 0x65, 0x4b, 0x16, 0x1b,
		0x21, 0x46, 0x63, 0x53, 0x1d, 0xe2, 0x25, 0x2d, 0x50, 0x43, 0x5e, 0x90, 0x86, 0xa3, 0x00, 0x0d,
		0x6f, 0xc1, 0x19, 0xae, 0x02, 0x33, 0xec, 0x05, 0x65, 0xd8, 0x0b, 0xc8, 0xb0, 0x17, 0x8c, 0xc9,
		0x56, 0x79, 0x01, 0xf2, 0x02, 0x30, 0x0c, 0x52, 0x8c, 0x43, 0x92, 0x2d, 0x93, 0x66, 0xff, 0xf1,
		0x77, 0x0a, 0x49, 0xa1, 0xd0, 0x61, 0xfc, 0x6a, 0x26, 0xe4, 0x22, 0x98, 0xca, 0xca, 0xd9, 0x6a,
		0x02, 0x66, 0xdd, 0xf5, 0xef, 0xee, 0x46, 0x4a, 0xea, 0x47, 0x2e, 0x76, 0xf1, 0xfa, 0x02, 0x40,
		0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x38, 0x29, 0xc6, 0x1c, 0x97,
		0xa4, 0x08, 0xe3, 0xd7, 0x8f, 0x60, 0x19, 0xeb, 0x4d, 0xb9, 0x78, 0xd0, 0x2e, 0x3b, 0xd3, 0x58,
		0x76, 0x11, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x9c, 0x6c,
		0xe3, 0x25, 0x36, 0x4d, 0x18, 0xc7, 0x02, 0x56, 0x81, 0x75, 0xac, 0x37, 0xf5, 0x52, 0xdd, 0x7b,
		0x03, 0xd9, 0x73, 0x03, 0xe1, 0x85, 0x84, 0xd5, 0x13, 0x63, 0x0b, 0x7f, 0x35, 0x3e, 0xb8, 0x06,
		0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xf9, 0xba, 0x95, 0x3d, 0xa1, 0xb4, 0xd4, 0x8f,
		0x4c, 0x7c, 0x83, 0xb2, 0x16, 0x72, 0x63, 0x76, 0xab, 0x9f, 0xbd, 0x90, 0xc1, 0x65, 0xcc, 0x27,
		0xbc, 0x71, 0xf6, 0x7b, 0xfd, 0xb4, 0xf1, 0xa5, 0xd3, 0x6a, 0x5e, 0x5d, 0x9e, 0x74, 0x5a, 0x27,
		0xf5, 0x8b, 0xe6, 0x19, 0xb5, 0xf7, 0xf8, 0xdd, 0x1b, 0x8c, 0xa6, 0xa7, 0xf7, 0xaf, 0xc9, 0xab,
		0xd9, 0x33, 0xb7, 0x18, 0x9a, 0xcf, 0xfe, 0x2f, 0xa7, 0x57, 0x17, 0x97, 0x27, 0xad, 0xce, 0x69,
		0xb3, 0x79, 0xee, 0xec, 0x42, 0xa3, 0xa7, 0x94, 0xcc, 0x7b, 0xfd, 0x02, 0x53, 0x4e, 0x3c, 0xe5,
		0xcd, 0x56, 0xe3, 0xd7, 0xc6, 0x59, 0xfd, 0xb2, 0xd9, 0xc2, 0xac, 0x13, 0x3a, 0x98, 0xe6, 0xd9,
		0xd7, 0x93, 0x2f, 0x4e, 0xc6, 0x5b, 0xb1, 0xb4, 0xb3, 0xc6, 0xf7, 0x32, 0xa1, 0xee, 0x07, 0x5e,
		0xa8, 0xdd, 0x3b, 0xbf, 0x27, 0xfb, 0x52, 0xf4, 0xe8, 0xc5, 0xfd, 0xe2, 0xf0, 0xd0, 0xf6, 0xd0,
		0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xe4, 0xeb, 0x56, 0xcb, 0x3b, 0xa1, 0x65, 0xf7, 0x7b,
		0x58, 0x29, 0x31, 0x68, 0xfb, 0x23, 0xc2, 0x21, 0xaf, 0x94, 0x9c, 0xf6, 0x42, 0x70, 0x94, 0xa7,
		0xfc, 0x50, 0x74, 0x7d, 0xd5, 0x0b, 0x29, 0x6f, 0xb9, 0xe5, 0xa9, 0x5b, 0x41, 0xae, 0xa7, 0x19,
		0x7a, 0xd1, 0x7d, 0x93, 0x8a, 0xaf, 0x4f, 0x30, 0x73, 0x77, 0xde, 0x69, 0xd4, 0x84, 0x71, 0xfc,
		0xaf, 0x81, 0xd7, 0xd5, 0xd2, 0x57, 0x5f, 0xe4, 0x6d, 0x64, 0xed, 0xf9, 0x9d, 0xe8, 0x50, 0xfd,
		0xcd, 0x7b, 0xd8, 0x79, 0x93, 0xe3, 0xed, 0x22, 0x97, 0x3a, 0x2b, 0xcc, 0x68, 0xbf, 0xc9, 0x36,
		0x34, 0xee, 0x9b, 0xcd, 0x90, 0xaa, 0x50, 0x59, 0x82, 0x54, 0xd1, 0x14, 0x2c, 0x83, 0xae, 0x85,
		0xae, 0x85, 0xae, 0x85, 0xae, 0x85, 0xae, 0x5d, 0xb2, 0x6e, 0x47, 0x52, 0xe9, 0xc3, 0x22, 0x83,
		0xa4, 0xad, 0x42, 0x52, 0x42, 0x52, 0x42, 0x52, 0x42, 0x52, 0x66, 0xc0, 0xe4, 0x4a, 0xc5, 0x5a,
		0xa9, 0x56, 0xa9, 0x16, 0x6b, 0x10, 0x92, 0x10, 0x92, 0xbb, 0x2c, 0x24, 0x69, 0x05, 0x08, 0x6d,
		0x89, 0x4d, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0xc8, 0x25, 0xeb, 0x76, 0xda,
		0xae, 0x90, 0xdc, 0x86, 0xe3, 0xd4, 0xe7, 0x23, 0xda, 0xa3, 0x56, 0x5a, 0x04, 0x8a, 0x5c, 0x4e,
		0x3a, 0x7f, 0xed, 0xef, 0x5f, 0xe7, 0xdd, 0x5a, 0xfb, 0xe9, 0xba, 0xe0, 0xd6, 0xda, 0xd1, 0xcb,
		0xc2, 0xf4, 0x9f, 0xe8, 0x75, 0xf1, 0x3a, 0xef, 0x96, 0xe6, 0xaf, 0xcb, 0xd7, 0x79, 0xb7, 0xdc,
		0x3e, 0xf8, 0xf3, 0xcf, 0x4f, 0x07, 0x3f, 0x0e, 0xc7, 0xef, 0xff, 0x60, 0x6e, 0x36, 0xd8, 0xc1,
		0xd3, 0xfe, 0x75, 0xc1, 0x2d, 0xb6, 0xe7, 0xff, 0xe7, 0xf0, 0x3a, 0xef, 0x16, 0xdb, 0x07, 0x07,
		0xff, 0xa3, 0x5b, 0xa3, 0x6d, 0xca, 0x87, 0xdb, 0xbc, 0x68, 0xfc, 0x81, 0x27, 0x4c, 0xfd, 0x84,
		0xc1, 0xb1, 0xdf, 0x6c, 0x23, 0xb3, 0xc3, 0x7e, 0x56, 0x5b, 0x6f, 0xad, 0x74, 0xf3, 0x2f, 0x07,
		0x07, 0xdb, 0x06, 0xdb, 0x06, 0xdb, 0x06, 0xdb, 0x06, 0xdb, 0x26, 0x5f, 0xb7, 0x37, 0xbe, 0x3f,
		0x10, 0x9e, 0xe2, 0x60, 0xda, 0x85, 0xac, 0x40, 0xf5, 0x56, 0x57, 0x84, 0xb6, 0xd4, 0xae, 0x7e,
		0xe5, 0x78, 0x34, 0x6d, 0xec, 0x03, 0x91, 0x8b, 0x7a, 0x15, 0x47, 0xff, 0x44, 0x05, 0x29, 0xd0,
		0x2e, 0x21, 0xf9, 0x38, 0x46, 0xea, 0xbb, 0xf2, 0xff, 0x55, 0xae, 0xa7, 0x75, 0x20, 0x6f, 0xac,
		0x74, 0x8f, 0x5e, 0xe9, 0x7b, 0x96, 0x8c, 0x8d, 0x46, 0x0a, 0x69, 0x65, 0x7c, 0x68, 0xa4, 0x90,
		0x4d, 0x46, 0x87, 0x46, 0x0a, 0x6b, 0xcd, 0x1a, 0x59, 0x23, 0x85, 0x84, 0x93, 0xa4, 0x97, 0xea,
		0xc9, 0x4b, 0xa0, 0x15, 0xec, 0x05, 0x08, 0x76, 0x08, 0x76, 0x08, 0x76, 0x08, 0xf6, 0xf4, 0x08,
		0x76, 0x2a, 0xf7, 0x1f, 0x0f, 0x38, 0x6d, 0x1b, 0xa0, 0xa9, 0xc3, 0x04, 0x7b, 0x89, 0xb6, 0x3a,
		0xd3, 0x4b, 0x20, 0x36, 0x5d, 0x9e, 0xd4, 0x2c, 0x72, 0x38, 0xe0, 0x84, 0x85, 0x74, 0xc0, 0x03,
		0x37, 0x4c, 0xa4, 0x06, 0x2e, 0x52, 0x03, 0x1b, 0xa9, 0x81, 0x0f, 0x5a, 0x18, 0x21, 0x86, 0x93,
		0x78, 0x96, 0x2f, 0x39, 0x1c, 0xfc, 0x1e, 0x6f, 0x91, 0xdb, 0x04, 0xdb, 0xaf, 0x32, 0x8c, 0x9d,
		0x68, 0xb0, 0xfa, 0x0c, 0x76, 0x19, 0x4d, 0x46, 0x25, 0x34, 0x6d, 0xa2, 0x9e, 0xac, 0x2b, 0x6d,
		0x9a, 0xa2, 0x47, 0x2b, 0xb3, 0x76, 0x05, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0xe1, 0x20,
		0x2d, 0xd4, 0x5a, 0x78, 0x51, 0x13, 0x0f, 0x04, 0xe3, 0x39, 0xb5, 0x05, 0x69, 0x3c, 0xb9, 0x92,
		0x8f, 0x3b, 0x79, 0x78, 0x89, 0x0b, 0x74, 0xd2, 0x00, 0x3e, 0xe9, 0x02, 0xa1, 0xb4, 0x80, 0x51,
		0xea, 0x40, 0x29, 0x75, 0xe0, 0x94, 0x3a, 0x90, 0xe2, 0x01, 0x2b, 0x26, 0xd0, 0xe2, 0x57, 0xdc,
		0x09, 0xbf, 0x31, 0x92, 0x4a, 0x17, 0x2a, 0x9c, 0x3e, 0x63, 0x86, 0x22, 0x15, 0xc6, 0x4b, 0xe0,
		0x39, 0x5e, 0xff, 0xfa, 0x0f, 0xaf, 0xcf, 0xdc, 0xe3, 0x3e, 0x7e, 0x9f, 0x32, 0x7a, 0x91, 0xb8,
		0x1c, 0xe6, 0xe3, 0xf9, 0x89, 0xeb, 0x49, 0xc1, 0x91, 0xe9, 0x94, 0xb8, 0xd3, 0x45, 0x13, 0xf6,
		0x1e, 0x60, 0xc2, 0x3f, 0x31, 0xe1, 0x4a, 0xb9, 0x7c, 0x58, 0x86, 0x19, 0xa7, 0x8b, 0x8b, 0xf0,
		0x8f, 0xde, 0xfe, 0xb0, 0x1b, 0xf7, 0xcb, 0x51, 0x65, 0x84, 0x6f, 0x27, 0x7d, 0x79, 0xd8, 0x80,
		0x61, 0x47, 0x1d, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x83, 0x8c, 0xc4,
		0x0d, 0x8e, 0x52, 0x10, 0x36, 0x28, 0x23, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20,
		0x6c, 0x60, 0xdd, 0x84, 0x8b, 0x65, 0x04, 0x0d, 0x10, 0x34, 0x40, 0xd0, 0x80, 0x36, 0x68, 0x70,
		0x3f, 0x5b, 0x7d, 0x69, 0x88, 0x1a, 0x44, 0xd7, 0x82, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20,
		0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0xef, 0xf4, 0x1b, 0x37, 0x52, 0x79, 0xc1, 0x63, 0x0a, 0xe2,
		0x06, 0x35, 0xc6, 0x4b, 0x38, 0x15, 0xea, 0x76, 0x9a, 0xf8, 0x8f, 0xc0, 0x01, 0x02, 0x07, 0x3f,
		0x55, 0x5d, 0x05, 0x68, 0x2e, 0x04, 0x0e, 0xb6, 0xdb, 0x84, 0x91, 0x6f, 0x80, 0xd0, 0x01, 0x42,
		0x07, 0xa4, 0x66, 0x2e, 0x1e, 0xb4, 0x50, 0x3d, 0xc2, 0x8e, 0xef, 0x2b, 0x29, 0x5f, 0x7c, 0x25,
		0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0xf0, 0xde, 0xb0,
		0x01, 0x79, 0xbd, 0xd8, 0x55, 0x30, 0x42, 0x54, 0x3f, 0x76, 0x37, 0x49, 0x8b, 0x3f, 0x9c, 0x30,
		0x73, 0x6f, 0xc0, 0x4f, 0x5a, 0xe2, 0x2b, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01,
		0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x49, 0xce, 0xf1, 0xd0, 0x0b, 0xb4, 0x4c, 0x03, 0x67,
		0x99, 0x5f, 0x08, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28,
		0x0b, 0x28, 0x4b, 0x72, 0x8e, 0x75, 0xe0, 0xa9, 0x50, 0x6a, 0x79, 0x9f, 0x82, 0xbc, 0xd2, 0x17,
		0xd7, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x92,
		0x7a, 0xe2, 0x92, 0xe9, 0xf2, 0xa2, 0xc4, 0x0d, 0x0a, 0x13, 0xe3, 0xf3, 0x34, 0x2c, 0x4c, 0xf6,
		0xc6, 0x4b, 0xfe, 0x88, 0xa2, 0xab, 0x21, 0x9f, 0xad, 0x65, 0xab, 0x61, 0xcc, 0x6f, 0xe2, 0x91,
		0xa3, 0xe2, 0x8b, 0x73, 0x2a, 0x43, 0x5d, 0xd7, 0x9a, 0xb8, 0x5b, 0xcd, 0x37, 0xa9, 0x4e, 0x06,
		0x62, 0x42, 0x07, 0x42, 0x5a, 0x3a, 0xed, 0x7c, 0xf3, 0x1e, 0x5e, 0x8c, 0x5c, 0x38, 0x2a, 0x95,
		0x2a, 0xd5, 0x52, 0x29, 0x5f, 0x3d, 0xac, 0xe6, 0x6b, 0xe5, 0x72, 0xa1, 0x52, 0x20, 0xcc, 0x7e,
		0x75, 0x9a, 0x41, 0x4f, 0x04, 0xa2, 0xf7, 0x79, 0xf2, 0xe8, 0xd5, 0x68, 0x30, 0xc8, 0x94, 0x45,
		0x33, 0xf9, 0xe5, 0x14, 0xfb, 0x63, 0x87, 0xb4, 0xa5, 0x42, 0x30, 0xea, 0x6a, 0x35, 0x23, 0x5d,
		0x9f, 0x6f, 0x87, 0x9d, 0x96, 0xbc, 0xe9, 0xd4, 0xfb, 0xf2, 0xc2, 0xeb, 0xcb, 0x4e, 0x63, 0x78,
		0x5f, 0xba, 0x8a, 0xee, 0xb4, 0x73, 0x36, 0xbb, 0xbf, 0x4e, 0xbd, 0xf7, 0x4f, 0x4b, 0xde, 0x34,
		0x47, 0xfa, 0x3c, 0x10, 0x9d, 0xd6, 0xe4, 0xae, 0x3a, 0x57, 0xd1, 0x2d, 0xd4, 0xe3, 0x3b, 0x40,
		0x4b, 0x66, 0xfe, 0x15, 0xb6, 0x23, 0x2d, 0x99, 0x97, 0x74, 0xff, 0xdd, 0xd6, 0xfe, 0xcc, 0x1f,
		0xb6, 0xc8, 0xca, 0xe6, 0x4c, 0x24, 0x0a, 0x63, 0xec, 0x4d, 0x9e, 0xba, 0x2b, 0x6d, 0xa5, 0x84,
		0xd3, 0xd0, 0x0f, 0x3a, 0xba, 0xc1, 0x4a, 0x2f, 0x68, 0xe8, 0x84, 0x2d, 0xb3, 0x23, 0x72, 0x6a,
		0x3c, 0xce, 0xcc, 0x22, 0xf2, 0x9b, 0x41, 0x7a, 0x3b, 0xae, 0xd5, 0xbc, 0xe3, 0x33, 0xfb, 0x8d,
		0x86, 0x6d, 0xd9, 0xb6, 0x0d, 0x53, 0xdb, 0xae, 0x59, 0xa3, 0x30, 0xf7, 0xe8, 0x0c, 0x3e, 0x36,
		0x4b, 0xad, 0xc7, 0xac, 0xb6, 0x16, 0xb3, 0xd4, 0x3a, 0xec, 0x79, 0x7b, 0xab, 0x68, 0xf8, 0x8b,
		0x2d, 0x6e, 0x5b, 0xd1, 0x6c, 0x47, 0xd9, 0xde, 0x66, 0x22, 0xdb, 0x3e, 0x22, 0xdb, 0x16, 0x22,
		0xdb, 0xee, 0x01, 0x20, 0x90, 0x00, 0x82, 0x85, 0x48, 0xb2, 0x41, 0x3c, 0xf8, 0x90, 0xa2, 0x67,
		0x6f, 0xeb, 0x99, 0x93, 0x3d, 0x6b, 0xc7, 0x28, 0xba, 0x6e, 0xc4, 0x4d, 0xcd, 0x18, 0xdc, 0xe6,
		0xe6, 0x61, 0xc0, 0x34, 0x9c, 0xf9, 0x74, 0xbb, 0x5e, 0xaf, 0x17, 0x88, 0x30, 0x34, 0x66, 0x1c,
		0x31, 0x04, 0x26, 0x46, 0x30, 0x64, 0xd0, 0x66, 0xb3, 0x6e, 0x8c, 0x67, 0xd1, 0xd8, 0xa0, 0x17,
		0x76, 0x69, 0x85, 0x2d, 0x3a, 0x61, 0x9d, 0x46, 0x58, 0xa7, 0x0f, 0xd6, 0x69, 0x43, 0xba, 0xa0,
		0xc2, 0x78, 0x56, 0x86, 0xc5, 0x36, 0xdd, 0x36, 0xda, 0x6f, 0x27, 0xdb, 0x6a, 0x27, 0x7c, 0x58,
		0x86, 0x10, 0xc0, 0xac, 0xd4, 0xb4, 0x22, 0x31, 0x0d, 0x4b, 0x4b, 0xf8, 0x7a, 0xf8, 0x7a, 0xf8,
		0xfa, 0xe8, 0x6e, 0x4d, 0x77, 0x41, 0xb6, 0x47, 0x28, 0xa9, 0x88, 0xa5, 0x25, 0x82, 0x69, 0xcd,
		0xf9, 0x20, 0x9e, 0x85, 0x78, 0xd6, 0x8e, 0xc7, 0xb3, 0xac, 0xa5, 0x11, 0xc7, 0x76, 0x2f, 0x87,
		0x96, 0xbc, 0xcc, 0x02, 0xbd, 0xb1, 0x50, 0x53, 0x76, 0x3e, 0x37, 0x76, 0x2a, 0xc5, 0x5a, 0xdc,
		0x10, 0x7d, 0x9e, 0xf9, 0xfb, 0x92, 0xc5, 0xb9, 0x4f, 0x3c, 0x83, 0x23, 0x8b, 0x63, 0x9c, 0x7b,
		0x5a, 0x8b, 0x40, 0x59, 0x2f, 0xdc, 0xeb, 0xfc, 0xb5, 0xbf, 0x7f, 0x9d, 0x77, 0x6b, 0xed, 0xa7,
		0xeb, 0x82, 0x5b, 0x6b, 0x47, 0x2f, 0x0b, 0xd3, 0x7f, 0xa2, 0xd7, 0xc5, 0xeb, 0xbc, 0x5b, 0x9a,
		0xbf, 0x2e, 0x5f, 0xe7, 0xdd, 0x72, 0xfb, 0xe0, 0xcf, 0x3f, 0x3f, 0x1d, 0xfc, 0x38, 0x1c, 0xbf,
		0xff, 0x83, 0xff, 0xb3, 0x97, 0x00, 0xd3, 0xb6, 0xf9, 0x30, 0x9a, 0x17, 0x8d, 0x3f, 0xf0, 0x44,
		0xde, 0xfb, 0x44, 0xb6, 0x29, 0x7b, 0x83, 0xc6, 0x3d, 0x55, 0xe0, 0x9e, 0xd6, 0x5b, 0x0c, 0x9e,
		0xdb, 0xaf, 0xbb, 0x5f, 0xdb, 0x3f, 0x0a, 0x1f, 0x4b, 0xe3, 0xe3, 0x83, 0x1f, 0xd5, 0xf1, 0xeb,
		0x1f, 0x3e, 0x2d, 0x7b, 0x5b, 0xe1, 0x63, 0x75, 0x7c, 0xbc, 0xe2, 0x37, 0x95, 0xf1, 0xf1, 0x1b,
		0xbf, 0xa3, 0x3c, 0xde, 0x4f, 0xbc, 0x75, 0xf2, 0xf3, 0xe2, 0xaa, 0x0f, 0x94, 0x56, 0x7c, 0xe0,
		0x70, 0xd5, 0x07, 0x0e, 0x57, 0x7c, 0x60, 0xe5, 0x25, 0x15, 0x57, 0x7c, 0xa0, 0x3c, 0x7e, 0x4a,
		0xbc, 0x7f, 0x7f, 0xf9, 0x5b, 0x2b, 0xe3, 0x83, 0xa7, 0x55, 0xbf, 0xab, 0x8e, 0x9f, 0x8e, 0x0f,
		0xe0, 0xac, 0x61, 0x9f, 0x3b, 0x6b, 0x9f, 0x5b, 0x92, 0x4c, 0xd6, 0xc6, 0x7e, 0xf6, 0x5b, 0x94,
		0xef, 0xb6, 0xed, 0x67, 0x1b, 0xcc, 0x55, 0x30, 0xb0, 0x71, 0xf0, 0x81, 0xf1, 0x19, 0xce, 0x73,
		0xb9, 0x0d, 0x07, 0xf0, 0xcc, 0x66, 0x6d, 0x9b, 0xcf, 0xce, 0x26, 0xc9, 0xc2, 0x36, 0x9b, 0x6d,
		0xbd, 0xe9, 0x83, 0x36, 0xbc, 0x48, 0xad, 0x2d, 0x4e, 0xc7, 0xc8, 0x3e, 0xda, 0x7b, 0x93, 0x4a,
		0x36, 0x73, 0x06, 0xeb, 0x2f, 0xe1, 0xf5, 0x3e, 0xb9, 0xa6, 0x2d, 0x98, 0xb2, 0x01, 0xd3, 0xcf,
		0x7e, 0xbd, 0xc9, 0x7f, 0xff, 0xd4, 0xbd, 0xef, 0x13, 0xef, 0x9c, 0xe4, 0x4d, 0x27, 0xd7, 0xcc,
		0xa4, 0xae, 0xb1, 0x7a, 0xde, 0xbe, 0x5a, 0xde, 0xf7, 0x9c, 0xde, 0x3e, 0xdb, 0xef, 0x98, 0xe9,
		0x48, 0xe4, 0x87, 0x81, 0x16, 0xee, 0xd0, 0x1f, 0xc8, 0xee, 0xe3, 0xbb, 0xe7, 0x7a, 0x31, 0x5c,
		0xf0, 0xf2, 0x9b, 0xde, 0xf9, 0xbc, 0xd7, 0xdb, 0x08, 0x5f, 0x7b, 0xcf, 0x69, 0x93, 0x3d, 0x25,
		0x33, 0x7b, 0x46, 0x9b, 0xee, 0x09, 0x19, 0xdb, 0xf3, 0x31, 0xb6, 0xa7, 0x63, 0x6c, 0xcf, 0xc6,
		0xae, 0x67, 0x59, 0x77, 0x63, 0xd8, 0x19, 0x44, 0xf7, 0xb4, 0xfe, 0x13, 0x8b, 0x93, 0x85, 0x66,
		0x5f, 0xb4, 0xe6, 0x34, 0x6f, 0x96, 0x33, 0xb2, 0xf1, 0x36, 0xad, 0x89, 0xed, 0x58, 0xb3, 0xdb,
		0xae, 0xa6, 0xb6, 0x57, 0x8d, 0x6f, 0xa3, 0x1a, 0xdf, 0x2e, 0x35, 0xbe, 0x2d, 0x4a, 0xcb, 0x98,
		0x36, 0xcd, 0xc9, 0x70, 0x66, 0xe7, 0xa4, 0x36, 0x7e, 0xd0, 0x73, 0xf3, 0x9b, 0x7d, 0xdf, 0xa6,
		0xaa, 0xcf, 0x48, 0x12, 0x97, 0xb1, 0xfc, 0x09, 0x93, 0xf9, 0x12, 0x76, 0xf2, 0x23, 0x4c, 0xe7,
		0x43, 0x58, 0xcb, 0x7f, 0xb0, 0x96, 0xef, 0x60, 0x2d, 0xbf, 0x81, 0x37, 0xfe, 0x61, 0x2a, 0xe9,
		0x2a, 0x5a, 0x98, 0xe6, 0x73, 0x37, 0x4d, 0x1e, 0x0e, 0x46, 0xee, 0x26, 0x72, 0x37, 0x6d, 0xbb,
		0x09, 0xeb, 0xee, 0xc2, 0x5c, 0xe0, 0x75, 0x2f, 0xcd, 0xb9, 0x9b, 0x5d, 0x7f, 0xe0, 0x07, 0xf6,
		0x12, 0x36, 0xa3, 0xaf, 0x47, 0x96, 0x26, 0xb2, 0x34, 0x59, 0xdd, 0x10, 0x99, 0x3b, 0x22, 0x73,
		0x4b, 0x66, 0xdd, 0x93, 0x61, 0x37, 0x15, 0xcf, 0x82, 0xfd, 0x2c, 0x4d, 0xf3, 0xc7, 0x8b, 0x12,
		0x2c, 0xa6, 0x6a, 0xe1, 0xbb, 0x13, 0xc7, 0x8d, 0x22, 0x47, 0xb9, 0x03, 0x65, 0x2e, 0x84, 0xea,
		0x0d, 0x7d, 0x39, 0x5d, 0x18, 0x96, 0x30, 0x27, 0x1e, 0x01, 0xb0, 0x03, 0xd8, 0x01, 0xec, 0x00,
		0x76, 0x00, 0x3b, 0x2b, 0x61, 0x27, 0xf6, 0x95, 0x3b, 0x80, 0x3c, 0xf3, 0x02, 0x82, 0xd6, 0x80,
		0xc7, 0x4e, 0x85, 0x42, 0xe0, 0x0e, 0x70, 0x07, 0xb8, 0x03, 0xdc, 0xc9, 0x14, 0xee, 0xcc, 0x5d,
		0x25, 0xea, 0xfa, 0x6d, 0x6a, 0x11, 0x5b, 0x59, 0xd7, 0x0f, 0x90, 0x03, 0xc8, 0x01, 0xe4, 0x98,
		0x98, 0x05, 0xd3, 0x1b, 0x02, 0xf1, 0x17, 0x4f, 0xfb, 0x7f, 0x48, 0xd5, 0x13, 0xf6, 0xba, 0xbc,
		0xc5, 0x4b, 0xeb, 0xc5, 0x58, 0xb6, 0x4a, 0x89, 0x5b, 0xed, 0xd7, 0x67, 0xbd, 0x1f, 0x1f, 0x45,
		0xbf, 0x3d, 0xda, 0x7e, 0x7a, 0x54, 0xfd, 0xf2, 0xc8, 0xfb, 0xe1, 0x91, 0xf7, 0xbb, 0x23, 0xef,
		0x67, 0xb7, 0x5d, 0x4d, 0x04, 0xac, 0xf7, 0x9b, 0x23, 0xe0, 0xe6, 0x14, 0x1c, 0x7d, 0x19, 0x57,
		0x5f, 0xfa, 0x77, 0xea, 0xac, 0x43, 0xa1, 0xc3, 0xf8, 0xd5, 0x8c, 0xd3, 0x47, 0x0e, 0x7c, 0x5b,
		0xca, 0xb7, 0x5b, 0xe0, 0x70, 0x76, 0xf6, 0xd2, 0x13, 0x76, 0x66, 0x63, 0x4f, 0x1d, 0x40, 0x09,
		0xa0, 0x04, 0x50, 0x02, 0x28, 0x49, 0xd6, 0xcd, 0x48, 0x2a, 0x7d, 0x58, 0x24, 0xc0, 0x49, 0x9b,
		0x30, 0xd9, 0xf2, 0xd4, 0xad, 0xb0, 0x5e, 0x97, 0x80, 0xa0, 0xa7, 0xd6, 0x37, 0x49, 0xd7, 0x16,
		0x8f, 0xb8, 0x6f, 0xba, 0xf3, 0xbb, 0x37, 0x18, 0x09, 0xc2, 0xf1, 0xbe, 0x06, 0x5e, 0x57, 0x4b,
		0x5f, 0x7d, 0x91, 0xb7, 0x32, 0x3a, 0x43, 0x6c, 0xbf, 0x81, 0xdc, 0x47, 0x02, 0x13, 0xf1, 0x1e,
		0x32, 0x6f, 0x22, 0xa5, 0x62, 0xad, 0x54, 0xab, 0x54, 0x8b, 0xb5, 0x72, 0x86, 0x6d, 0x65, 0x4b,
		0xdb, 0xd6, 0xb5, 0x77, 0x5a, 0x54, 0xdc, 0xdd, 0x8d, 0x94, 0xd4, 0x8f, 0x54, 0xc1, 0xb8, 0xd7,
		0x03, 0x42, 0x68, 0x40, 0x68, 0x40, 0x68, 0x40, 0x68, 0x6c, 0xa1, 0xd0, 0xd8, 0x91, 0x88, 0xdc,
		0xdc, 0x63, 0x4b, 0x11, 0xc6, 0xaf, 0x1f, 0x11, 0x94, 0x8b, 0x26, 0xcf, 0x5a, 0xbe, 0x71, 0xc2,
		0xda, 0x2c, 0xe5, 0x1d, 0x03, 0x31, 0x81, 0x98, 0x40, 0x4c, 0x20, 0xe6, 0x31, 0x4d, 0x6d, 0x5b,
		0xca, 0xca, 0xb6, 0x35, 0x8b, 0x63, 0x58, 0x2d, 0x82, 0x3e, 0xff, 0x43, 0x10, 0x9e, 0x23, 0x2e,
		0x8a, 0x9e, 0x78, 0x46, 0x47, 0x04, 0x63, 0x51, 0x55, 0x79, 0x8d, 0x07, 0xcc, 0x4a, 0x69, 0xee,
		0x38, 0x40, 0x42, 0xf1, 0x90, 0x28, 0xeb, 0xf1, 0x66, 0xf7, 0x49, 0xd9, 0x0d, 0xc1, 0x7d, 0xcc,
		0x90, 0xbb, 0xab, 0xc0, 0xdd, 0x99, 0x5d, 0x44, 0x28, 0x6e, 0x9d, 0xa9, 0xe2, 0xd6, 0x3b, 0xe3,
		0xfc, 0x61, 0xb7, 0xd9, 0xb4, 0x5b, 0xec, 0x46, 0x6d, 0x5f, 0x34, 0xed, 0x41, 0xbb, 0xe4, 0x3b,
		0x52, 0xcb, 0x06, 0x45, 0x8c, 0x0d, 0x31, 0x36, 0xc4, 0xd8, 0x10, 0x63, 0xdb, 0xc2, 0x18, 0xdb,
		0x8e, 0xec, 0x4a, 0xbd, 0xf4, 0xda, 0x52, 0x84, 0x0b, 0xff, 0x1f, 0xbb, 0x53, 0xb3, 0x49, 0x94,
		0xea, 0xde, 0x1b, 0xc8, 0x9e, 0x1b, 0x08, 0x2f, 0xf4, 0x95, 0x7d, 0x28, 0x7d, 0x35, 0x1e, 0x50,
		0x14, 0x28, 0x0a, 0x14, 0x05, 0x8a, 0x6e, 0x21, 0x8a, 0xca, 0x9e, 0x50, 0x5a, 0xea, 0x47, 0x22,
		0x24, 0xb5, 0x98, 0x15, 0xea, 0x34, 0x66, 0xb7, 0xf2, 0xd9, 0x0b, 0x09, 0x96, 0xe8, 0x7c, 0x02,
		0x1b, 0x67, 0xbf, 0xd7, 0x4f, 0x1b, 0x5f, 0x3a, 0xad, 0xe6, 0xd5, 0xe5, 0x49, 0xa7, 0x75, 0x52,
		0xbf, 0x68, 0x9e, 0xd9, 0x5e, 0xad, 0xd3, 0x64, 0xdb, 0x90, 0x24, 0x80, 0x44, 0x94, 0xad, 0xfc,
		0x7a, 0x36, 0x7f, 0x39, 0xbd, 0xba, 0xb8, 0x3c, 0x69, 0x75, 0x4e, 0x9b, 0xcd, 0x73, 0x27, 0x0b,
		0xc9, 0xdf, 0x4c, 0xf3, 0x58, 0xbf, 0xc0, 0x14, 0x6e, 0x38, 0x85, 0xcd, 0x56, 0xe3, 0xd7, 0xc6,
		0x59, 0xfd, 0xb2, 0xd9, 0xc2, 0x2c, 0x6e, 0xb0, 0xa0, 0x9b, 0x67, 0x5f, 0x4f, 0xbe, 0x38, 0x5b,
		0x9e, 0x9b, 0xdf, 0xde, 0x36, 0x7e, 0xb2, 0x15, 0xea, 0x6d, 0xe0, 0x85, 0xda, 0xbd, 0xf3, 0x7b,
		0xb2, 0x2f, 0x45, 0xcf, 0xbe, 0x78, 0x5b, 0x1c, 0x0e, 0xda, 0x0d, 0xda, 0x0d, 0xda, 0x0d, 0xda,
		0x6d, 0x0b, 0xb5, 0x9b, 0x96, 0x77, 0x42, 0xcb, 0xee, 0xf7, 0xb0, 0x52, 0x22, 0xd0, 0x6e, 0x36,
		0xfb, 0xe7, 0x5f, 0xa9, 0xe8, 0xec, 0x9e, 0xa3, 0x3c, 0xe5, 0x87, 0xa2, 0xeb, 0xab, 0x9e, 0xd5,
		0xcc, 0x49, 0x9c, 0x3a, 0x4e, 0x1f, 0xa6, 0x2d, 0x57, 0xb9, 0x38, 0x75, 0xbc, 0xb1, 0x89, 0xec,
		0xc0, 0xa9, 0x63, 0x3b, 0x1d, 0xa1, 0x53, 0x6b, 0x35, 0xc8, 0xf8, 0xd8, 0x3a, 0x8d, 0x63, 0xab,
		0x6a, 0x76, 0x82, 0x14, 0xd8, 0xa9, 0x9e, 0x1d, 0x0f, 0xf3, 0x45, 0xf4, 0xbd, 0xd1, 0x60, 0x4a,
		0xfd, 0xf2, 0xd0, 0x4e, 0xd0, 0x4e, 0xd0, 0x4e, 0xd0, 0x4e, 0xdb, 0xa8, 0x9d, 0x50, 0x3c, 0x09,
		0x32, 0x06, 0x32, 0x06, 0x32, 0x26, 0x55, 0x26, 0x82, 0xe2, 0x49, 0x10, 0x2f, 0x69, 0x14, 0x2f,
		0xb3, 0x64, 0x37, 0xa3, 0x2d, 0x93, 0x57, 0x22, 0xf3, 0xcb, 0xc1, 0x20, 0x30, 0x20, 0x30, 0x20,
		0x30, 0x20, 0x30, 0xb6, 0x50, 0x60, 0xdc, 0xf8, 0xfe, 0x40, 0x78, 0x8a, 0x22, 0xa9, 0xae, 0xb0,
		0x2d, 0xd0, 0x94, 0xea, 0x16, 0x20, 0x75, 0xa5, 0x7c, 0xed, 0x4d, 0xd8, 0x90, 0x9d, 0x4e, 0x20,
		0x61, 0xf7, 0x6f, 0x71, 0xe7, 0x0d, 0x67, 0xe9, 0xfe, 0x39, 0x7f, 0x28, 0x54, 0x77, 0x0a, 0x14,
		0x93, 0xf5, 0x99, 0x9b, 0xfc, 0x17, 0xc8, 0x9b, 0x9c, 0xd7, 0x97, 0x6e, 0xe8, 0xf5, 0x65, 0x18,
		0xbf, 0xca, 0x4d, 0xcf, 0x70, 0x87, 0x81, 0x16, 0xee, 0xd0, 0x1f, 0xc8, 0xee, 0x63, 0x6e, 0x10,
		0xad, 0xeb, 0xdc, 0x14, 0x23, 0xc3, 0xe8, 0x9f, 0xe8, 0x24, 0xc0, 0x2e, 0x34, 0x82, 0x1a, 0xa9,
		0xef, 0xca, 0xff, 0x57, 0xb9, 0x9e, 0xd6, 0x81, 0xbc, 0x99, 0xcc, 0x80, 0xbd, 0xae, 0x50, 0x4b,
		0xc6, 0x42, 0x8b, 0x28, 0xb4, 0x88, 0x4a, 0x05, 0xc5, 0x40, 0x8b, 0x28, 0x5a, 0x7c, 0xb0, 0xd6,
		0x22, 0x2a, 0xe1, 0x64, 0xec, 0x6b, 0xac, 0xe4, 0x90, 0x76, 0x95, 0x56, 0x01, 0x4a, 0x0b, 0x4a,
		0x0b, 0x4a, 0x6b, 0x97, 0x94, 0x96, 0x2d, 0x77, 0x19, 0x0f, 0x30, 0x6d, 0x9b, 0xa4, 0x6d, 0xeb,
		0xb9, 0xbd, 0x44, 0x83, 0xbd, 0xe9, 0x90, 0x96, 0x4d, 0x8b, 0x26, 0xfe, 0x6c, 0xdd, 0x7d, 0x52,
		0xba, 0x51, 0x1e, 0x77, 0x4a, 0xed, 0x56, 0xd9, 0xdc, 0x2b, 0x9b, 0x9b, 0x65, 0x73, 0xb7, 0x76,
		0xdd, 0xae, 0x65, 0xf7, 0x4b, 0x17, 0xf0, 0x4a, 0xac, 0x3b, 0xfb, 0x75, 0x19, 0x12, 0xec, 0xb2,
		0x4a, 0x53, 0x6d, 0x6e, 0xb1, 0xf7, 0xf6, 0x33, 0x18, 0x6c, 0xe9, 0x8e, 0x96, 0x45, 0xd3, 0xb3,
		0xd4, 0xad, 0x7b, 0xa5, 0xcd, 0xd9, 0xe8, 0xde, 0x4d, 0xac, 0x65, 0x00, 0xca, 0x00, 0x65, 0x80,
		0xf2, 0x6e, 0x80, 0xb2, 0x6d, 0x6d, 0xb4, 0xa8, 0x91, 0x06, 0x82, 0x30, 0xb9, 0x6a, 0x41, 0x2a,
		0x4d, 0x46, 0xfe, 0x98, 0xc9, 0x8c, 0x1d, 0x2a, 0x27, 0xcd, 0xe1, 0xac, 0x79, 0x9d, 0x36, 0x97,
		0xf3, 0x66, 0x77, 0xe2, 0xec, 0xce, 0x9c, 0xdd, 0xa9, 0xd3, 0x38, 0x77, 0x22, 0x27, 0x4f, 0xaf,
		0xc0, 0x12, 0xeb, 0x76, 0x24, 0x95, 0x2e, 0x54, 0x28, 0xd7, 0xec, 0xcc, 0x0b, 0x57, 0x08, 0x87,
		0xa4, 0xc9, 0x81, 0x7e, 0xfd, 0x87, 0xd6, 0x27, 0xed, 0x51, 0xe7, 0x48, 0x33, 0xc3, 0x6b, 0x62,
		0x78, 0xe2, 0x1c, 0xea, 0xc4, 0xf8, 0x0c, 0x79, 0xb2, 0x4c, 0xee, 0x6a, 0xd1, 0xe4, 0xbc, 0x87,
		0x9d, 0x37, 0xb9, 0x4a, 0xb9, 0x7c, 0x58, 0xde, 0x61, 0xb3, 0xfb, 0x90, 0xcd, 0xd1, 0xda, 0x1f,
		0xb2, 0x71, 0x3f, 0x14, 0x47, 0x2f, 0xe8, 0x76, 0xda, 0x96, 0xcb, 0x48, 0x82, 0x1d, 0x37, 0xe8,
		0x48, 0xe8, 0x48, 0xe8, 0x48, 0xe8, 0x48, 0xe8, 0xc8, 0x15, 0x3a, 0xf2, 0x88, 0x41, 0x46, 0x96,
		0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x33, 0x60, 0x72, 0xc5, 0x32, 0x44, 0x24, 0x44,
		0xe4, 0xae, 0x8b, 0xc8, 0xfb, 0xd9, 0x6a, 0xe0, 0x50, 0x91, 0xd1, 0xd8, 0x90, 0x91, 0x90, 0x91,
		0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0xe4, 0xeb, 0xf6, 0x46, 0x2a, 0x2f, 0x78, 0x64, 0xd0, 0x91,
		0x35, 0xc2, 0x21, 0x4f, 0x85, 0xba, 0x9d, 0x26, 0x8a, 0x42, 0x48, 0xee, 0x00, 0xab, 0x2f, 0x40,
		0x48, 0x42, 0x48, 0xd2, 0x9a, 0x1c, 0xf6, 0x23, 0x21, 0x25, 0x77, 0x5c, 0x4a, 0x8a, 0x07, 0x2d,
		0x54, 0xcf, 0x62, 0xab, 0x90, 0x95, 0x14, 0x26, 0x1e, 0x19, 0x32, 0x12, 0x32, 0x12, 0x32, 0x12,
		0x32, 0x12, 0x32, 0x92, 0x5e, 0x46, 0x5a, 0x2f, 0xac, 0xb5, 0xca, 0x0d, 0x5b, 0x2a, 0xb4, 0x95,
		0x4d, 0x90, 0xf6, 0x87, 0x13, 0xa6, 0xe8, 0x0d, 0xe8, 0x41, 0x3a, 0x1e, 0x19, 0x20, 0x0d, 0x90,
		0x06, 0x48, 0x03, 0xa4, 0x01, 0xd2, 0x00, 0x69, 0x80, 0xf4, 0xb2, 0x39, 0x1b, 0x7a, 0x81, 0x96,
		0x1c, 0x18, 0x3d, 0x1f, 0x18, 0x10, 0x0d, 0x88, 0x06, 0x44, 0x03, 0xa2, 0x01, 0xd1, 0x80, 0x68,
		0x40, 0xf4, 0xb2, 0x39, 0xd3, 0x81, 0xa7, 0x42, 0xa9, 0xe5, 0x3d, 0x43, 0xde, 0xd4, 0x8b, 0xb1,
		0x01, 0xd4, 0x00, 0x6a, 0x00, 0x35, 0x80, 0x1a, 0x40, 0x0d, 0xa0, 0xde, 0x42, 0xa0, 0xde, 0xea,
		0x72, 0x51, 0x96, 0x3b, 0x53, 0x24, 0xc6, 0xb3, 0xdc, 0xa9, 0x22, 0xd9, 0x54, 0x21, 0xf9, 0x23,
		0x1b, 0xed, 0x2c, 0xe8, 0x8c, 0x62, 0xbb, 0x2a, 0x35, 0xff, 0x26, 0x1e, 0x29, 0x8e, 0x5a, 0x3b,
		0xa7, 0x32, 0xd4, 0x75, 0xad, 0x2d, 0x97, 0x85, 0xfe, 0x26, 0xd5, 0xc9, 0x40, 0x4c, 0x70, 0x2f,
		0xb4, 0xcb, 0xeb, 0x9c, 0x6f, 0xde, 0xc3, 0x8b, 0x91, 0x68, 0x5b, 0x90, 0x3b, 0xcd, 0xa0, 0x27,
		0x02, 0xd1, 0xfb, 0x3c, 0x79, 0x74, 0x6a, 0x34, 0x18, 0x6c, 0x95, 0xc5, 0x11, 0x39, 0xb4, 0x34,
		0x38, 0x32, 0xc7, 0x6a, 0x91, 0xd5, 0x60, 0xd4, 0xd5, 0x6a, 0x46, 0x13, 0x3e, 0xdf, 0x0e, 0x3b,
		0x2d, 0x79, 0xd3, 0xa9, 0xf7, 0xe5, 0x85, 0xd7, 0x97, 0x9d, 0xc6, 0xf0, 0xbe, 0x72, 0x11, 0x68,
		0x71, 0x3e, 0xbd, 0x83, 0xce, 0xa9, 0xdf, 0x9d, 0xfc, 0xb6, 0x35, 0xb9, 0xf2, 0xce, 0x55, 0x74,
		0x99, 0xf5, 0xf8, 0x2a, 0xd1, 0x41, 0x2a, 0xfd, 0x66, 0x4d, 0x6f, 0xce, 0xa9, 0x6d, 0x27, 0xf5,
		0x21, 0x45, 0x8f, 0x7f, 0x8e, 0x9f, 0xb3, 0xc6, 0xfb, 0x7b, 0x42, 0xf5, 0x86, 0xbe, 0x54, 0x7a,
		0xaf, 0xeb, 0x0f, 0xfc, 0xc0, 0xd0, 0xfa, 0xb7, 0x03, 0x9e, 0xf6, 0xc0, 0x92, 0x14, 0x1c, 0xed,
		0x80, 0xa1, 0x29, 0xf3, 0xb0, 0xe4, 0x15, 0x2c, 0x7b, 0x03, 0x83, 0xb8, 0xb5, 0x3e, 0x4e, 0x99,
		0xf1, 0x3f, 0x9b, 0x7b, 0x8b, 0xcd, 0xbe, 0x61, 0x43, 0x43, 0x32, 0x6d, 0x40, 0xd6, 0x0c, 0x67,
		0xb3, 0xa7, 0xb5, 0xfe, 0x1c, 0xaf, 0xf7, 0xc9, 0x35, 0x9f, 0x8a, 0xa9, 0xa7, 0x61, 0xfe, 0x29,
		0x6c, 0xb0, 0x62, 0xd7, 0x59, 0xa1, 0xeb, 0x3d, 0xed, 0xf7, 0x3f, 0xab, 0x35, 0x9e, 0x93, 0xa3,
		0x84, 0xbc, 0xfd, 0xfb, 0xc6, 0x0f, 0xd6, 0xef, 0x0c, 0x19, 0x07, 0xdf, 0x9e, 0xbf, 0x6a, 0x4d,
		0x7b, 0xd9, 0xac, 0x6b, 0xc0, 0xc6, 0x3b, 0x14, 0x26, 0x76, 0x1c, 0xcc, 0xee, 0x20, 0x98, 0xda,
		0x11, 0x30, 0x1e, 0xe1, 0x37, 0x1e, 0xb1, 0x37, 0x1e, 0x81, 0xa7, 0xf5, 0x74, 0x9b, 0x56, 0xa9,
		0x8f, 0xd7, 0xce, 0xe6, 0x8f, 0xfa, 0xf5, 0x6a, 0xdc, 0xf4, 0x49, 0x9b, 0x69, 0xe5, 0x61, 0x6c,
		0xfb, 0xd0, 0xe4, 0xb6, 0xa0, 0x9d, 0xed, 0x3e, 0xd3, 0xdb, 0x78, 0xd6, 0xb6, 0xe7, 0xac, 0x6d,
		0xbb, 0x59, 0xdb, 0x4e, 0xe3, 0x25, 0x97, 0xa6, 0x5a, 0x51, 0x38, 0x5e, 0xef, 0x9f, 0xe9, 0x9c,
		0x48, 0xe5, 0x0e, 0xfd, 0x50, 0x9b, 0xb3, 0x94, 0xb8, 0x88, 0xcb, 0xab, 0x01, 0x4c, 0xa9, 0x77,
		0xa3, 0x5d, 0x7d, 0x8c, 0x67, 0x14, 0xd8, 0xc8, 0x18, 0xb0, 0x9b, 0x11, 0x60, 0x6b, 0xc7, 0xdf,
		0xfa, 0x8e, 0xbe, 0xf5, 0x1d, 0x7b, 0xeb, 0x3b, 0xf2, 0xe9, 0x8a, 0x8b, 0x99, 0xee, 0x72, 0xe3,
		0xcc, 0x64, 0xa6, 0xb5, 0x6e, 0xef, 0xb3, 0xef, 0x47, 0x87, 0x77, 0x74, 0x78, 0x67, 0x75, 0x44,
		0x64, 0x0e, 0x89, 0xcc, 0x31, 0x99, 0x75, 0x50, 0x86, 0x1d, 0x95, 0x35, 0x87, 0xb5, 0xe8, 0xb8,
		0xec, 0x77, 0x75, 0x37, 0x1d, 0xb8, 0x25, 0x70, 0x63, 0xd6, 0xdd, 0x19, 0x85, 0x5b, 0xa3, 0x75,
		0x6f, 0x54, 0x6e, 0x8e, 0xdc, 0xdd, 0x91, 0xbb, 0x3d, 0x72, 0xf7, 0x67, 0xc7, 0x0d, 0x5a, 0x72,
		0x87, 0xd6, 0xdd, 0x62, 0x3c, 0x40, 0xb4, 0x51, 0x4a, 0xd6, 0x2c, 0xd6, 0xe4, 0xbe, 0xec, 0xcf,
		0xdc, 0x25, 0x3a, 0xb8, 0xa7, 0xdd, 0x8d, 0x52, 0xbb, 0x53, 0x36, 0xb7, 0xca, 0xe6, 0x5e, 0xd9,
		0xdc, 0xac, 0x5d, 0x77, 0x6b, 0xd9, 0xed, 0xc6, 0xb3, 0x86, 0x0e, 0xee, 0xa6, 0x5c, 0xd8, 0xeb,
		0x0e, 0xee, 0x11, 0x10, 0xa0, 0x7b, 0x7b, 0x62, 0xa6, 0xe6, 0x29, 0x4c, 0x74, 0x98, 0x1c, 0x8f,
		0x08, 0x58, 0x06, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x80, 0xe5, 0x9d, 0x85, 0xe5, 0x18, 0x0b, 0x80,
		0xcc, 0x89, 0xc9, 0x9a, 0x25, 0x19, 0xd3, 0x01, 0xf3, 0x7c, 0x40, 0xe0, 0x32, 0x70, 0x19, 0xb8,
		0x0c, 0x5c, 0x06, 0x2e, 0xef, 0x2c, 0x2e, 0xcf, 0xa1, 0x00, 0xb0, 0x9c, 0x98, 0xab, 0xe8, 0xb4,
		0x32, 0x19, 0x28, 0x47, 0xc3, 0xd1, 0x40, 0x72, 0x01, 0x90, 0x0c, 0x48, 0x06, 0x24, 0x03, 0x92,
		0xd7, 0x9f, 0x35, 0xdb, 0x1b, 0x88, 0xf1, 0x40, 0xd3, 0x12, 0x06, 0x52, 0xf5, 0xc4, 0x03, 0x53,
		0x8f, 0xc1, 0x68, 0x6c, 0xd4, 0xca, 0xda, 0x36, 0x87, 0xcd, 0xeb, 0xb8, 0xb9, 0x1c, 0x38, 0xbb,
		0x23, 0x67, 0x77, 0xe8, 0xec, 0x8e, 0x9d, 0xc6, 0xc1, 0x13, 0x39, 0x7a, 0x7a, 0x0d, 0xc6, 0xa8,
		0xc5, 0x38, 0x34, 0xd9, 0x32, 0x6d, 0xf6, 0x1f, 0x7f, 0xa7, 0x90, 0x14, 0x0a, 0x1d, 0xc6, 0xaf,
		0x66, 0x4a, 0x2e, 0x82, 0x29, 0x14, 0xe1, 0x7c, 0xf3, 0x7c, 0xdf, 0x88, 0x50, 0xbb, 0xb3, 0xb3,
		0xba, 0xc4, 0xbc, 0xe2, 0x79, 0x68, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a,
		0xf2, 0x75, 0x8b, 0x12, 0x9c, 0x5b, 0x01, 0xd3, 0x34, 0x89, 0xc4, 0x09, 0xeb, 0xa0, 0x48, 0x28,
		0x06, 0x3c, 0x03, 0x9e, 0x01, 0xcf, 0x80, 0x67, 0xc0, 0xf3, 0x92, 0x75, 0x3b, 0x92, 0x4a, 0x1f,
		0x16, 0x19, 0xd0, 0x99, 0x52, 0xf3, 0xb7, 0x3c, 0x75, 0x3b, 0xb9, 0xdb, 0x6b, 0xd2, 0x35, 0xf2,
		0x83, 0xa1, 0xcb, 0xbb, 0x54, 0x3b, 0xdf, 0xe5, 0x3d, 0xbf, 0xc3, 0x1d, 0xde, 0x3f, 0x32, 0x98,
		0x9c, 0xf7, 0xb0, 0xf3, 0x26, 0x57, 0x2a, 0xd6, 0x4a, 0xb5, 0x4a, 0xb5, 0x58, 0x2b, 0xef, 0xb0,
		0xed, 0x7d, 0xc8, 0xe6, 0x68, 0x6d, 0x88, 0xc8, 0x77, 0x88, 0xc8, 0xbb, 0xbb, 0x91, 0x92, 0xfa,
		0x91, 0x6b, 0x27, 0xf9, 0xf5, 0x05, 0x40, 0x58, 0x42, 0x58, 0x42, 0x58, 0x42, 0x58, 0x42, 0x58,
		0x92, 0xaf, 0x5b, 0x6c, 0x27, 0xbf, 0xf8, 0x3b, 0xc7, 0x25, 0x29, 0xc2, 0xf8, 0xf5, 0x23, 0x76,
		0x94, 0xd7, 0x9b, 0x72, 0xb2, 0x23, 0xb6, 0x09, 0x9b, 0x26, 0x3a, 0x6a, 0x0b, 0x5e, 0x01, 0x5e,
		0x01, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0xb1, 0x64, 0xdd, 0xca, 0xa1, 0xeb, 0xf5, 0x7a, 0x81, 0x08,
		0x43, 0x0e, 0x6a, 0x51, 0x23, 0x1c, 0x73, 0x36, 0xc7, 0x99, 0x0f, 0x5a, 0x3f, 0x3f, 0xd9, 0xfb,
		0x12, 0xc3, 0xb3, 0x4d, 0x3c, 0xe3, 0x23, 0x86, 0xb1, 0xcf, 0x3d, 0xad, 0x45, 0xa0, 0xc8, 0x1f,
		0x77, 0x7c, 0x01, 0x7f, 0xed, 0xef, 0x5f, 0xe7, 0xdd, 0x5a, 0xfb, 0xe9, 0xba, 0xe0, 0xd6, 0xda,
		0xd1, 0xcb, 0xc2, 0xf4, 0x9f, 0xe8, 0x75, 0xf1, 0x3a, 0xef, 0x96, 0xe6, 0xaf, 0xcb, 0xd7, 0x79,
		0xb7, 0xdc, 0x3e, 0xf8, 0xf3, 0xcf, 0x4f, 0x07, 0x3f, 0x0e, 0xc7, 0xef, 0xff, 0xe0, 0xff, 0x1c,
		0xf2, 0x9b, 0x6c, 0x73, 0x3c, 0xd4, 0xe6, 0x45, 0xe3, 0x0f, 0x3c, 0x59, 0xdb, 0x4f, 0x96, 0x36,
		0xf0, 0xfc, 0x71, 0x87, 0xdc, 0x71, 0x05, 0xee, 0x98, 0x77, 0xd1, 0x7a, 0x6e, 0xbf, 0xee, 0x7e,
		0x6d, 0xff, 0x28, 0x7c, 0x2c, 0x8d, 0x8f, 0x0f, 0x7e, 0x54, 0xc7, 0xaf, 0x7f, 0xf8, 0xb4, 0xec,
		0x6d, 0x85, 0x8f, 0xd5, 0xf1, 0xf1, 0x8a, 0xdf, 0x54, 0xc6, 0xc7, 0x6f, 0xfc, 0x8e, 0xf2, 0x78,
		0x3f, 0xf1, 0xd6, 0xc9, 0xcf, 0x8b, 0xab, 0x3e, 0x50, 0x5a, 0xf1, 0x81, 0xc3, 0x55, 0x1f, 0x38,
		0x5c, 0xf1, 0x81, 0x95, 0x97, 0x54, 0x5c, 0xf1, 0x81, 0xf2, 0xf8, 0x29, 0xf1, 0xfe, 0xfd, 0xe5,
		0x6f, 0xad, 0x8c, 0x0f, 0x9e, 0x56, 0xfd, 0xae, 0x3a, 0x7e, 0x3a, 0x3e, 0x00, 0x38, 0xc1, 0xce,
		0x61, 0xe7, 0x99, 0x80, 0x6a, 0xec, 0x11, 0xa7, 0x31, 0x7a, 0xfb, 0xa0, 0x5d, 0xf6, 0x7d, 0xe2,
		0x65, 0x17, 0x81, 0x98, 0x2e, 0x62, 0xba, 0x88, 0xe9, 0x22, 0xa6, 0x8b, 0x98, 0x2e, 0xf9, 0xba,
		0xc5, 0x5e, 0xf1, 0x8b, 0xbf, 0x2f, 0xb1, 0x49, 0x8a, 0x70, 0xe1, 0xff, 0x63, 0xcf, 0x78, 0xcd,
		0xa9, 0x97, 0xea, 0xde, 0x1b, 0xc8, 0x9e, 0x1b, 0x08, 0x2f, 0xf4, 0x15, 0x3d, 0xe1, 0x78, 0x35,
		0x3e, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xf9, 0xba, 0x95, 0x3d, 0xa1,
		0xb4, 0xd4, 0x8f, 0x4c, 0x7c, 0x83, 0xf0, 0x84, 0x80, 0xd3, 0x98, 0xdd, 0xea, 0x67, 0x2f, 0x64,
		0x70, 0x19, 0xf3, 0x09, 0x6f, 0x9c, 0xfd, 0x5e, 0x3f, 0x6d, 0x7c, 0xe9, 0xb4, 0x9a, 0x57, 0x97,
		0x27, 0x9d, 0xd6, 0x49, 0xfd, 0xa2, 0x79, 0x46, 0xed, 0x3d, 0xa6, 0x07, 0x35, 0x42, 0x96, 0x30,
		0x27, 0xd3, 0xc9, 0x98, 0xd7, 0xb3, 0xff, 0xcb, 0xe9, 0xd5, 0xc5, 0xe5, 0x49, 0xab, 0x73, 0xda,
		0x6c, 0x9e, 0x3b, 0xbb, 0x70, 0x30, 0x29, 0x25, 0xf3, 0x5e, 0xbf, 0xc0, 0x94, 0x13, 0x4f, 0x79,
		0xb3, 0xd5, 0xf8, 0xb5, 0x71, 0x56, 0xbf, 0x6c, 0xb6, 0x30, 0xeb, 0x84, 0x0e, 0xa6, 0x79, 0xf6,
		0xf5, 0xe4, 0x8b, 0x93, 0xf1, 0x73, 0x67, 0xed, 0xac, 0xf1, 0xbd, 0x4c, 0xa8, 0xfb, 0x81, 0x17,
		0x6a, 0xf7, 0xce, 0xef, 0xc9, 0xbe, 0x14, 0x3d, 0x7a, 0x71, 0xbf, 0x38, 0x3c, 0xb4, 0x3d, 0xb4,
		0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xf9, 0xba, 0xd5, 0xf2, 0x4e, 0x68, 0xd9, 0xfd, 0x1e,
		0x56, 0x4a, 0x0c, 0xda, 0x9e, 0x30, 0x51, 0xcd, 0xb9, 0x52, 0xd1, 0x39, 0x7f, 0x47, 0x79, 0xca,
		0x0f, 0x45, 0xd7, 0x57, 0x3d, 0xd2, 0x7c, 0x78, 0x54, 0x54, 0xc9, 0x1e, 0xc6, 0x2f, 0x8f, 0x9a,
		0xa0, 0xa2, 0x0a, 0xb9, 0xc9, 0xa1, 0xa2, 0xca, 0x5e, 0xe1, 0xa8, 0x54, 0xaa, 0x54, 0x4b, 0xa5,
		0x7c, 0xf5, 0xb0, 0x9a, 0xaf, 0x95, 0xcb, 0x85, 0x4a, 0x01, 0xb5, 0x55, 0x32, 0x37, 0x1a, 0xf2,
		0xe6, 0xde, 0x6e, 0x86, 0x54, 0xed, 0x0b, 0x13, 0xa4, 0x8a, 0xa6, 0x8d, 0x61, 0x3c, 0xec, 0x17,
		0xd1, 0xf7, 0x46, 0x83, 0x29, 0x15, 0xcf, 0x43, 0x4b, 0x43, 0x4b, 0x43, 0x4b, 0x43, 0x4b, 0x43,
		0x4b, 0xa3, 0x30, 0x28, 0x64, 0x2c, 0x64, 0x2c, 0x64, 0x2c, 0x64, 0xec, 0x56, 0x99, 0x1c, 0x0a,
		0x83, 0x42, 0xbc, 0x42, 0xbc, 0xee, 0x39, 0xb3, 0xe4, 0x67, 0x7f, 0xa4, 0x05, 0xbd, 0x80, 0x7d,
		0x39, 0x38, 0x04, 0x25, 0x04, 0x25, 0x04, 0x25, 0x04, 0x25, 0x04, 0x25, 0xf9, 0xba, 0x45, 0x23,
		0xa8, 0x94, 0x8f, 0x60, 0xbb, 0x97, 0x75, 0x5d, 0x29, 0x5f, 0x7b, 0x13, 0x36, 0x4a, 0xd3, 0xd2,
		0x3a, 0xec, 0xfe, 0x2d, 0xee, 0xbc, 0x59, 0xeb, 0x49, 0x27, 0xe7, 0x0f, 0x85, 0xea, 0x4e, 0x81,
		0x72, 0xe2, 0x3f, 0x72, 0x93, 0xff, 0x02, 0x79, 0x93, 0xf3, 0xfa, 0xd2, 0x0d, 0xbd, 0xbe, 0x0c,
		0xe3, 0x57, 0xb9, 0x69, 0xe5, 0x9b, 0x30, 0xd0, 0xc2, 0x1d, 0xfa, 0x03, 0xd9, 0x7d, 0xcc, 0x29,
		0x21, 0x6f, 0xff, 0xbe, 0xf1, 0x83, 0x30, 0x7e, 0x95, 0xf3, 0x7a, 0xff, 0x4c, 0x5d, 0x91, 0x54,
		0xee, 0xd0, 0x0f, 0x75, 0x6e, 0x4a, 0x2f, 0xc2, 0xe8, 0x9f, 0xe8, 0x90, 0x9e, 0x5d, 0x0f, 0x65,
		0xcf, 0x14, 0x2c, 0x9a, 0x81, 0x33, 0x52, 0xdf, 0x95, 0xff, 0xaf, 0x72, 0x3d, 0xad, 0x03, 0x79,
		0x33, 0x99, 0x31, 0xeb, 0xa6, 0xf0, 0x1c, 0xd0, 0x4a, 0x8e, 0x6d, 0xd9, 0xe0, 0xe7, 0xee, 0xc7,
		0xf2, 0x30, 0x54, 0xec, 0x8f, 0x92, 0xf5, 0xf1, 0xb0, 0x3d, 0x6a, 0x96, 0xc7, 0xc6, 0xee, 0xd8,
		0x58, 0x1d, 0x1b, 0x9b, 0xdb, 0x6e, 0xe8, 0xfc, 0x22, 0x69, 0x7a, 0x33, 0x26, 0x9d, 0x24, 0xbd,
		0x5c, 0x4f, 0x5e, 0x02, 0xad, 0x68, 0x2f, 0x40, 0xb4, 0x43, 0xb4, 0x43, 0xb4, 0x43, 0xb4, 0xa7,
		0x47, 0xb4, 0x53, 0xb9, 0xff, 0x78, 0xc0, 0x89, 0xef, 0x75, 0x35, 0x75, 0xa8, 0x60, 0xc1, 0x63,
		0x3c, 0x5f, 0x02, 0xb1, 0xe9, 0xf2, 0x6c, 0x1d, 0x91, 0xc3, 0x01, 0x27, 0x2c, 0xa4, 0x03, 0x1e,
		0xb8, 0x61, 0x22, 0x35, 0x70, 0x91, 0x1a, 0xd8, 0x48, 0x0d, 0x7c, 0xd0, 0xc2, 0x08, 0x31, 0x9c,
		0xc4, 0xb3, 0x7c, 0xc9, 0xe1, 0xe0, 0xf7, 0x78, 0x0b, 0x7f, 0x25, 0xd8, 0x7e, 0x95, 0xa7, 0xbc,
		0xf4, 0xbc, 0x10, 0x58, 0x54, 0xcf, 0xeb, 0x19, 0xec, 0x32, 0xba, 0x59, 0x4e, 0x68, 0xda, 0x4e,
		0x14, 0x7d, 0x65, 0x23, 0x2e, 0xd1, 0xf0, 0x3c, 0xa4, 0xa5, 0x00, 0xd2, 0x02, 0xd2, 0x02, 0xd2,
		0x02, 0xd2, 0x92, 0x5d, 0xd2, 0x42, 0xad, 0x85, 0x17, 0x35, 0xf1, 0x40, 0x30, 0xe6, 0xd1, 0x2e,
		0x48, 0xe3, 0xc9, 0x95, 0x7c, 0xdc, 0xc9, 0xe4, 0x4a, 0x2e, 0xd0, 0x49, 0x03, 0xf8, 0xa4, 0x0b,
		0x84, 0xd2, 0x02, 0x46, 0xa9, 0x03, 0xa5, 0xd4, 0x81, 0x53, 0xea, 0x40, 0x8a, 0x07, 0xac, 0x98,
		0x40, 0x8b, 0x5f, 0x71, 0x27, 0xfc, 0xc6, 0x48, 0x2a, 0x5d, 0xa8, 0x70, 0xfa, 0x8c, 0x19, 0x8a,
		0x54, 0x18, 0x2f, 0x81, 0xe7, 0xf8, 0xcf, 0xeb, 0x3f, 0xbc, 0x3e, 0x73, 0x8f, 0xfb, 0x78, 0x50,
		0xca, 0xe8, 0x45, 0xe2, 0x72, 0x98, 0x8f, 0x0f, 0x25, 0xae, 0x27, 0x05, 0x47, 0x3a, 0x52, 0xe2,
		0x4e, 0x17, 0x4d, 0xd8, 0x7b, 0x80, 0x09, 0xff, 0xc4, 0x84, 0x2b, 0xe5, 0xf2, 0x61, 0x19, 0x66,
		0x9c, 0x2e, 0x2e, 0xc2, 0x3f, 0x7a, 0xfb, 0xc3, 0x6e, 0xdc, 0x2f, 0xc7, 0x29, 0x48, 0xbe, 0x9d,
		0xf4, 0xe5, 0x61, 0x03, 0x86, 0x1d, 0x75, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x03,
		0xc4, 0x0d, 0x32, 0x12, 0x37, 0x38, 0x4a, 0x41, 0xd8, 0xa0, 0x8c, 0xb0, 0x01, 0xc2, 0x06, 0x08,
		0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x81, 0x75, 0x13, 0x2e, 0x96, 0x11, 0x34, 0x40, 0xd0, 0x00, 0x41,
		0x03, 0xda, 0xa0, 0xc1, 0xfd, 0x6c, 0xf5, 0xa5, 0x21, 0x6a, 0x10, 0x5d, 0x0b, 0xc2, 0x06, 0x08,
		0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0xbc, 0xd3, 0x6f, 0xdc, 0x48, 0xe5,
		0x05, 0x8f, 0x29, 0x88, 0x1b, 0xd4, 0x18, 0x2f, 0xe1, 0x54, 0xa8, 0xdb, 0x69, 0xe2, 0x3f, 0x02,
		0x07, 0x08, 0x1c, 0xfc, 0x54, 0x75, 0x15, 0xa0, 0xb9, 0x10, 0x38, 0xd8, 0x6e, 0x13, 0x46, 0xbe,
		0x01, 0x42, 0x07, 0x08, 0x1d, 0x90, 0x9a, 0xb9, 0x78, 0xd0, 0x42, 0xf5, 0x08, 0xbb, 0x60, 0xae,
		0xa4, 0x7c, 0xf1, 0x95, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80,
		0xb0, 0xc1, 0x7b, 0xc3, 0x06, 0xe4, 0x35, 0x63, 0x57, 0xc1, 0x08, 0x51, 0x0d, 0xd9, 0xdd, 0x24,
		0x2d, 0xfe, 0x70, 0xc2, 0xcc, 0xbd, 0x01, 0x3f, 0x69, 0x89, 0xaf, 0x04, 0xa4, 0x05, 0xa4, 0x05,
		0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x25, 0x39, 0xc7, 0x43, 0x2f,
		0xd0, 0x32, 0x0d, 0x9c, 0x65, 0x7e, 0x21, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0,
		0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xc9, 0x39, 0xd6, 0x81, 0xa7, 0x42, 0xa9, 0xe5, 0x7d,
		0x0a, 0xf2, 0x4a, 0x5f, 0x5c, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b,
		0x88, 0x0b, 0x88, 0x4b, 0xea, 0x89, 0x4b, 0xa6, 0xcb, 0x8b, 0x12, 0x37, 0x29, 0x4c, 0x8c, 0xcf,
		0xd7, 0xb4, 0x30, 0xd9, 0x1f, 0x2f, 0xf9, 0x23, 0x8a, 0xce, 0x86, 0x7c, 0xf6, 0x96, 0xad, 0xa6,
		0x31, 0xbf, 0x89, 0x47, 0x8e, 0xaa, 0x2f, 0xce, 0xa9, 0x0c, 0x75, 0x5d, 0x6b, 0xe2, 0x8e, 0x35,
		0xdf, 0xa4, 0x3a, 0x19, 0x88, 0x09, 0x25, 0x08, 0x69, 0x29, 0xb5, 0xf3, 0xcd, 0x7b, 0x78, 0x31,
		0x72, 0xe1, 0xa8, 0x54, 0xaa, 0x54, 0x4b, 0xa5, 0x7c, 0xf5, 0xb0, 0x9a, 0xaf, 0x95, 0xcb, 0x85,
		0x4a, 0x81, 0x30, 0x03, 0xd6, 0x69, 0x06, 0x3d, 0x11, 0x88, 0xde, 0xe7, 0xc9, 0xa3, 0x57, 0xa3,
		0xc1, 0x20, 0x53, 0x16, 0xcd, 0xe4, 0x9b, 0x53, 0xee, 0x93, 0x1d, 0xd2, 0xd6, 0x0a, 0xc1, 0xa8,
		0xab, 0xd5, 0x8c, 0x7c, 0x7d, 0xbe, 0x1d, 0x76, 0x5a, 0xf2, 0xa6, 0x53, 0xef, 0xcb, 0x0b, 0xaf,
		0x2f, 0x3b, 0x8d, 0xe1, 0x7d, 0xe5, 0x22, 0xd0, 0xe2, 0x7c, 0x7a, 0xb3, 0x9d, 0xb3, 0xd9, 0x2d,
		0x76, 0xea, 0xbd, 0x7f, 0x5a, 0xf2, 0xa6, 0xa1, 0xce, 0xfd, 0x50, 0x77, 0x5a, 0x93, 0x1b, 0xeb,
		0x5c, 0x45, 0x77, 0x51, 0x8f, 0x6f, 0x02, 0x1d, 0x9a, 0xf9, 0x17, 0xda, 0x0e, 0x75, 0x68, 0x5e,
		0xd2, 0x0c, 0x78, 0x5b, 0xdb, 0x35, 0x7f, 0xd8, 0x22, 0x4b, 0x9b, 0x93, 0x92, 0xc9, 0x23, 0x77,
		0x65, 0x6f, 0x4f, 0xa8, 0xde, 0xd0, 0x97, 0x4a, 0xef, 0x75, 0xfd, 0x81, 0x1f, 0x58, 0xf2, 0x64,
		0x34, 0x8c, 0x84, 0x8e, 0x81, 0xb0, 0x32, 0x0e, 0x1a, 0x86, 0x61, 0xcb, 0xfc, 0x88, 0x1c, 0x1c,
		0x9f, 0x63, 0xb3, 0x48, 0x06, 0x8c, 0x81, 0xbf, 0x1d, 0x4f, 0x6b, 0xde, 0x0f, 0x9a, 0xfd, 0x46,
		0xc3, 0x26, 0x6d, 0xdb, 0x94, 0x39, 0x4c, 0xd8, 0xac, 0x61, 0x98, 0x7b, 0x7c, 0x66, 0xbe, 0xc9,
		0x90, 0x01, 0xd8, 0x7a, 0xf0, 0xa4, 0x0f, 0xdc, 0xa0, 0x9b, 0x32, 0xe0, 0x96, 0xcc, 0xd8, 0xdd,
		0xe6, 0x56, 0x62, 0xc0, 0x42, 0x9c, 0x97, 0x13, 0x1d, 0x98, 0x0b, 0xd2, 0x3f, 0x97, 0x03, 0x5a,
		0xfc, 0x7e, 0x43, 0x36, 0x6d, 0xb6, 0x7d, 0x9d, 0xf1, 0xad, 0x55, 0x1b, 0x5b, 0xa5, 0x76, 0xb7,
		0x3e, 0x6d, 0x6d, 0x65, 0x5a, 0xdf, 0x9a, 0xb4, 0xbe, 0xd5, 0x68, 0x7d, 0xeb, 0x30, 0x5d, 0x68,
		0x61, 0xba, 0x5d, 0x9a, 0x33, 0x83, 0x6a, 0xe3, 0x86, 0x35, 0x5f, 0x0e, 0xb3, 0xef, 0x37, 0xfc,
		0xd0, 0xed, 0xf4, 0xc7, 0xb4, 0x96, 0xc3, 0x61, 0x33, 0x37, 0x83, 0x26, 0xe7, 0xc2, 0x76, 0x2e,
		0x05, 0x59, 0x8e, 0x04, 0x59, 0xee, 0x03, 0x59, 0x4e, 0x43, 0xba, 0x75, 0x8d, 0xad, 0xfe, 0x8e,
		0x91, 0x63, 0xb1, 0x67, 0x8f, 0x0b, 0xfe, 0xcb, 0x96, 0x2d, 0xda, 0x6d, 0xf3, 0x6b, 0x3d, 0x25,
		0x8d, 0x22, 0xe5, 0x8c, 0x36, 0xa5, 0x8c, 0x2a, 0x65, 0x8c, 0x3c, 0x25, 0x8c, 0x3c, 0xe5, 0x8b,
		0x3c, 0xa5, 0x6b, 0xbb, 0x02, 0xe7, 0xb6, 0xdb, 0xde, 0x3a, 0x51, 0x04, 0xde, 0xba, 0x1d, 0xcf,
		0x57, 0xa7, 0xcd, 0x80, 0xff, 0x6b, 0x77, 0x69, 0x39, 0x1b, 0x80, 0x2c, 0x93, 0x97, 0x32, 0x63,
		0x97, 0x27, 0x33, 0x97, 0x3a, 0x03, 0x97, 0x2d, 0xd3, 0x96, 0x2d, 0xa3, 0x96, 0x2d, 0x73, 0x76,
		0xbb, 0x77, 0xc6, 0xc9, 0x32, 0x5e, 0xe3, 0x75, 0x37, 0x10, 0x5e, 0x3f, 0x10, 0x7d, 0x8a, 0x45,
		0x37, 0x67, 0x95, 0x55, 0x82, 0xb1, 0xce, 0x67, 0xf1, 0xe5, 0x4f, 0x9f, 0xa2, 0x5c, 0xc2, 0x5c,
		0x04, 0x04, 0xdb, 0xba, 0xf9, 0x6e, 0x91, 0x59, 0xce, 0xf7, 0xc6, 0xe9, 0x30, 0x39, 0x1e, 0x11,
		0xb0, 0x0c, 0x58, 0x06, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x3b, 0x0b, 0xcb, 0x31, 0x16, 0x00, 0x99,
		0x13, 0x93, 0x35, 0xcb, 0x5e, 0xa3, 0x03, 0xe6, 0xf9, 0x80, 0xc0, 0x65, 0xe0, 0x32, 0x70, 0x19,
		0xb8, 0x0c, 0x5c, 0xde, 0x59, 0x5c, 0x9e, 0x43, 0x01, 0x60, 0x39, 0x31, 0x57, 0xd1, 0xd9, 0x44,
		0x32, 0x50, 0x8e, 0x86, 0xa3, 0x81, 0xe4, 0x02, 0x20, 0x19, 0x90, 0x0c, 0x48, 0x06, 0x24, 0xaf,
		0x3f, 0x6b, 0xb6, 0x37, 0x10, 0xe3, 0x81, 0xa6, 0x07, 0x8e, 0xa5, 0xea, 0x09, 0xba, 0xd2, 0x32,
		0x8b, 0xcd, 0x2a, 0xa3, 0xb1, 0xa9, 0x4e, 0x59, 0x93, 0x16, 0x11, 0x22, 0x2f, 0x1a, 0xc4, 0x51,
		0x24, 0x88, 0xb7, 0x28, 0x10, 0x57, 0x11, 0x20, 0xf6, 0xa2, 0x3f, 0xec, 0x45, 0x7e, 0xd8, 0x8b,
		0xfa, 0x64, 0xab, 0xfe, 0x03, 0x79, 0x91, 0x1e, 0x06, 0x2d, 0xc6, 0xa1, 0xc9, 0x96, 0x69, 0xb3,
		0xff, 0xf8, 0x3b, 0x85, 0xa4, 0x50, 0xe8, 0x30, 0x7e, 0x35, 0x53, 0x72, 0x11, 0x4c, 0x65, 0xe5,
		0xdc, 0x3b, 0x01, 0xb3, 0xa6, 0xc9, 0x50, 0x4a, 0x58, 0x33, 0x45, 0xa6, 0x12, 0xe8, 0x04, 0xe8,
		0x04, 0xe8, 0x04, 0xe8, 0x04, 0xe8, 0xc4, 0x92, 0x75, 0x3b, 0x92, 0x4a, 0x1f, 0x16, 0x19, 0xd8,
		0x04, 0x25, 0x99, 0x68, 0x79, 0xea, 0x56, 0x90, 0xb7, 0x86, 0x66, 0x28, 0x70, 0xc7, 0xd9, 0xfa,
		0x99, 0xbb, 0xe4, 0xef, 0xbc, 0x2f, 0x2e, 0xd7, 0xf8, 0x29, 0xe8, 0x81, 0xcb, 0x51, 0xf6, 0x9a,
		0xb3, 0x55, 0x73, 0x5a, 0x4c, 0xae, 0x54, 0xac, 0x95, 0x6a, 0x95, 0x6a, 0xb1, 0x56, 0xde, 0x61,
		0xdb, 0xcb, 0x68, 0xdd, 0xca, 0x36, 0x44, 0xe4, 0x3b, 0x44, 0xe4, 0xdd, 0xdd, 0x48, 0x49, 0xfd,
		0xc8, 0x15, 0xa2, 0x7e, 0x7d, 0x01, 0x10, 0x96, 0x10, 0x96, 0x10, 0x96, 0x10, 0x96, 0x10, 0x96,
		0xe4, 0xeb, 0x16, 0x71, 0xea, 0x17, 0x7f, 0xe7, 0xb8, 0x24, 0x45, 0x18, 0xbf, 0x7e, 0x44, 0xa8,
		0x7a, 0xbd, 0x29, 0x27, 0x3b, 0xbb, 0x93, 0xb0, 0x69, 0xa2, 0x33, 0x3c, 0xe0, 0x15, 0xe0, 0x15,
		0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0x4b, 0xd6, 0xad, 0x1c, 0xba, 0x5e, 0xaf, 0x17, 0x88, 0x30,
		0xe4, 0xa0, 0x16, 0x35, 0xc2, 0x31, 0x67, 0x73, 0x9c, 0xf9, 0xa0, 0xf5, 0xf3, 0x93, 0xbd, 0x2f,
		0x31, 0x3c, 0xdb, 0xc4, 0x33, 0x3e, 0x62, 0x18, 0xfb, 0xdc, 0xd3, 0x5a, 0x04, 0x8a, 0xfc, 0x71,
		0xc7, 0x17, 0xf0, 0xd7, 0xfe, 0xfe, 0x75, 0xde, 0xad, 0xb5, 0x9f, 0xae, 0x0b, 0x6e, 0xad, 0x1d,
		0xbd, 0x2c, 0x4c, 0xff, 0x89, 0x5e, 0x17, 0xaf, 0xf3, 0x6e, 0x69, 0xfe, 0xba, 0x7c, 0x9d, 0x77,
		0xcb, 0xed, 0x83, 0x3f, 0xff, 0xfc, 0x74, 0xf0, 0xe3, 0x70, 0xfc, 0xfe, 0x0f, 0xfe, 0x8f, 0xbe,
		0x97, 0x58, 0x9b, 0xe3, 0xa1, 0x36, 0x2f, 0x1a, 0x7f, 0xe0, 0xc9, 0xda, 0x7e, 0xb2, 0x59, 0x6e,
		0x99, 0xc5, 0xeb, 0x8e, 0x2b, 0x70, 0xc7, 0xbc, 0x8b, 0xd6, 0x73, 0xfb, 0x75, 0xf7, 0x6b, 0xfb,
		0x47, 0xe1, 0x63, 0x69, 0x7c, 0x7c, 0xf0, 0xa3, 0x3a, 0x7e, 0xfd, 0xc3, 0xa7, 0x65, 0x6f, 0x2b,
		0x7c, 0xac, 0x8e, 0x8f, 0x57, 0xfc, 0xa6, 0x32, 0x3e, 0x7e, 0xe3, 0x77, 0x94, 0xc7, 0xfb, 0x89,
		0xb7, 0x4e, 0x7e, 0x5e, 0x5c, 0xf5, 0x81, 0xd2, 0x8a, 0x0f, 0x1c, 0xae, 0xfa, 0xc0, 0xe1, 0x8a,
		0x0f, 0xac, 0xbc, 0xa4, 0xe2, 0x8a, 0x0f, 0x94, 0xc7, 0x4f, 0x89, 0xf7, 0xef, 0x2f, 0x7f, 0x6b,
		0x65, 0x7c, 0xf0, 0xb4, 0xea, 0x77, 0xd5, 0xf1, 0xd3, 0xf1, 0x01, 0xc0, 0x09, 0x76, 0x0e, 0x3b,
		0xcf, 0x04, 0x54, 0x63, 0x8f, 0x38, 0x8d, 0xd1, 0xdb, 0x07, 0xed, 0xb2, 0xef, 0x13, 0x2f, 0xbb,
		0x08, 0xc4, 0x74, 0x11, 0xd3, 0x45, 0x4c, 0x17, 0x31, 0x5d, 0xc4, 0x74, 0xc9, 0xd7, 0x2d, 0xf6,
		0x8a, 0x5f, 0xfc, 0x7d, 0x89, 0x4d, 0x52, 0x84, 0x0b, 0xff, 0x1f, 0x7b, 0xc6, 0x6b, 0x4e, 0xbd,
		0x54, 0xf7, 0xde, 0x40, 0xf6, 0xdc, 0x40, 0x78, 0x21, 0x61, 0x87, 0xdb, 0xe7, 0x60, 0xca, 0xe2,
		0xf8, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe4, 0xeb, 0x56, 0xf6, 0x84,
		0xd2, 0x52, 0x3f, 0x32, 0xf1, 0x0d, 0xca, 0x7e, 0xf5, 0x8d, 0xd9, 0xad, 0x7e, 0xf6, 0x42, 0x06,
		0x97, 0x31, 0x9f, 0xf0, 0xc6, 0xd9, 0xef, 0xf5, 0xd3, 0xc6, 0x97, 0x4e, 0xab, 0x79, 0x75, 0x79,
		0xd2, 0x69, 0x9d, 0xd4, 0x2f, 0x9a, 0x67, 0xd4, 0xde, 0x63, 0x7a, 0x50, 0x23, 0x64, 0x09, 0x73,
		0x32, 0x9d, 0x8c, 0x79, 0x3d, 0xfb, 0xbf, 0x9c, 0x5e, 0x5d, 0x5c, 0x9e, 0xb4, 0x3a, 0xa7, 0xcd,
		0xe6, 0xb9, 0xb3, 0x0b, 0x07, 0x93, 0x52, 0x32, 0xef, 0xf5, 0x0b, 0x4c, 0x39, 0xf1, 0x94, 0x37,
		0x5b, 0x8d, 0x5f, 0x1b, 0x67, 0xf5, 0xcb, 0x66, 0x0b, 0xb3, 0x4e, 0xe8, 0x60, 0x9a, 0x67, 0x5f,
		0x4f, 0xbe, 0x38, 0x19, 0x3f, 0x77, 0xd6, 0xce, 0x1a, 0xdf, 0xcb, 0x84, 0xba, 0x1f, 0x78, 0xa1,
		0x76, 0xef, 0xfc, 0x9e, 0xec, 0x4b, 0xd1, 0xa3, 0x17, 0xf7, 0x8b, 0xc3, 0x43, 0xdb, 0x43, 0xdb,
		0x43, 0xdb, 0x43, 0xdb, 0x43, 0xdb, 0x93, 0xaf, 0x5b, 0x2d, 0xef, 0x84, 0x96, 0xdd, 0xef, 0x61,
		0xa5, 0xc4, 0xa0, 0xed, 0x09, 0x13, 0xd5, 0x9c, 0x2b, 0x15, 0x9d, 0xf3, 0x77, 0x94, 0xa7, 0xfc,
		0x50, 0x74, 0x7d, 0xd5, 0x23, 0xcd, 0x87, 0x47, 0x45, 0x95, 0xec, 0x61, 0xfc, 0xf2, 0xa8, 0x09,
		0x2a, 0xaa, 0x90, 0x9b, 0x1c, 0x2a, 0xaa, 0xec, 0x15, 0x8e, 0x4a, 0xa5, 0x4a, 0xb5, 0x54, 0xca,
		0x57, 0x0f, 0xab, 0xf9, 0x5a, 0xb9, 0x5c, 0xa8, 0x14, 0x50, 0x5b, 0x25, 0x73, 0xa3, 0x21, 0x6f,
		0xee, 0xed, 0x66, 0x48, 0xd5, 0x17, 0x29, 0x41, 0xaa, 0x68, 0xfa, 0x23, 0xc5, 0xc3, 0x7e, 0x11,
		0x7d, 0x6f, 0x34, 0x98, 0x52, 0xf1, 0x3c, 0xb4, 0x34, 0xb4, 0x34, 0xb4, 0x34, 0xb4, 0x34, 0xb4,
		0x34, 0x0a, 0x83, 0x42, 0xc6, 0x42, 0xc6, 0x42, 0xc6, 0x42, 0xc6, 0x6e, 0x95, 0xc9, 0xa1, 0x30,
		0x28, 0xc4, 0x2b, 0xc4, 0xeb, 0x9e, 0x33, 0x4b, 0x7e, 0xf6, 0x47, 0x5a, 0xd0, 0x0b, 0xd8, 0x97,
		0x83, 0x43, 0x50, 0x42, 0x50, 0x42, 0x50, 0x42, 0x50, 0x42, 0x50, 0x92, 0xaf, 0xdb, 0x1b, 0xdf,
		0x1f, 0x08, 0x4f, 0x71, 0x24, 0x5d, 0x17, 0xb2, 0x02, 0xd5, 0x5b, 0xdd, 0x24, 0xb3, 0xae, 0x94,
		0xaf, 0xbd, 0x09, 0x1b, 0xa5, 0xe9, 0x95, 0x19, 0x76, 0xff, 0x16, 0x77, 0xde, 0x70, 0x76, 0xe8,
		0x2e, 0xe7, 0x0f, 0x85, 0xea, 0x4e, 0x81, 0x72, 0xe2, 0x3f, 0x72, 0x93, 0xff, 0x02, 0x79, 0x93,
		0xf3, 0xfa, 0xd2, 0x0d, 0xbd, 0xbe, 0x0c, 0xe3, 0x57, 0xb9, 0x69, 0xe5, 0x9b, 0x30, 0xd0, 0xc2,
		0x1d, 0xfa, 0x03, 0xd9, 0x7d, 0xcc, 0x29, 0x21, 0x6f, 0xff, 0xbe, 0xf1, 0x83, 0x30, 0x7e, 0x95,
		0xf3, 0x7a, 0xff, 0x4c, 0x5d, 0x91, 0x54, 0xee, 0x30, 0x10, 0xb9, 0x29, 0xbb, 0x08, 0xa3, 0x7f,
		0xa2, 0x33, 0x7a, 0x68, 0x22, 0x9d, 0x7c, 0x22, 0x23, 0xf5, 0x5d, 0xf9, 0xff, 0x2a, 0xd7, 0xd3,
		0x3a, 0x90, 0x37, 0x93, 0x19, 0xa3, 0xeb, 0x28, 0xbd, 0x64, 0x6c, 0xb4, 0x97, 0x4e, 0x2b, 0xe9,
		0x43, 0x7b, 0xe9, 0x6c, 0x92, 0x3a, 0xb4, 0x97, 0x5e, 0x6b, 0xd6, 0xc8, 0xda, 0x4b, 0x27, 0x9c,
		0x24, 0xbd, 0x5a, 0x4f, 0x5e, 0x02, 0xad, 0x66, 0x2f, 0x40, 0xb3, 0x43, 0xb3, 0x43, 0xb3, 0x43,
		0xb3, 0xa7, 0x47, 0xb3, 0x53, 0xb9, 0xff, 0x78, 0xc0, 0x69, 0x33, 0x65, 0x4d, 0x1d, 0x29, 0x58,
		0xf0, 0x18, 0xcf, 0x97, 0x40, 0x6c, 0xba, 0x3c, 0x3b, 0x47, 0xe4, 0x70, 0xc0, 0x09, 0x0b, 0xe9,
		0x80, 0x07, 0x6e, 0x98, 0x48, 0x0d, 0x5c, 0xa4, 0x06, 0x36, 0x52, 0x03, 0x1f, 0xb4, 0x30, 0x42,
		0x0c, 0x27, 0xf1, 0x2c, 0x5f, 0x72, 0x38, 0xf8, 0x3d, 0xde, 0xba, 0x5f, 0x09, 0xb6, 0x5f, 0xe5,
		0xa9, 0x2e, 0x3d, 0xaf, 0x03, 0x16, 0x95, 0xf3, 0x7a, 0x06, 0xbb, 0x8c, 0xee, 0x95, 0x13, 0x9a,
		0xb6, 0x13, 0x45, 0x5f, 0xd9, 0x88, 0x4b, 0x34, 0x3c, 0x0f, 0x69, 0x29, 0x80, 0xb4, 0x80, 0xb4,
		0x80, 0xb4, 0x80, 0xb4, 0x64, 0x97, 0xb4, 0x50, 0x6b, 0xe1, 0x45, 0x4d, 0x3c, 0x10, 0x8c, 0x69,
		0xb4, 0x0b, 0xd2, 0x78, 0x72, 0x25, 0x1f, 0x77, 0x32, 0xb7, 0x92, 0x0b, 0x74, 0xd2, 0x00, 0x3e,
		0xe9, 0x02, 0xa1, 0xb4, 0x80, 0x51, 0xea, 0x40, 0x29, 0x75, 0xe0, 0x94, 0x3a, 0x90, 0xe2, 0x01,
		0x2b, 0x26, 0xd0, 0xe2, 0x57, 0xdc, 0x09, 0xbf, 0x31, 0x92, 0x4a, 0x17, 0x2a, 0x9c, 0x3e, 0x63,
		0x86, 0x22, 0x15, 0xc6, 0x4b, 0xe0, 0x39, 0xfd, 0xf3, 0xfa, 0x0f, 0xaf, 0xcf, 0xdc, 0xe3, 0x3e,
		0x1d, 0x94, 0x32, 0x7a, 0x91, 0xb8, 0x1c, 0xe6, 0xd3, 0x43, 0x89, 0xeb, 0x49, 0xc1, 0x89, 0x8e,
		0x94, 0xb8, 0xd3, 0x45, 0x13, 0xf6, 0x1e, 0x60, 0xc2, 0x3f, 0x31, 0xe1, 0x4a, 0xb9, 0x7c, 0x58,
		0x86, 0x19, 0xa7, 0x8b, 0x8b, 0xf0, 0x8f, 0xde, 0xfe, 0xb0, 0x1b, 0xf7, 0xcb, 0x71, 0x08, 0x92,
		0x6f, 0x27, 0x7d, 0x79, 0xd8, 0x80, 0x61, 0x47, 0x1d, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40,
		0xdc, 0x00, 0x71, 0x83, 0x8c, 0xc4, 0x0d, 0x8e, 0x52, 0x10, 0x36, 0x28, 0x23, 0x6c, 0x80, 0xb0,
		0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x60, 0xdd, 0x84, 0x8b, 0x65, 0x04, 0x0d, 0x10, 0x34,
		0x40, 0xd0, 0x80, 0x36, 0x68, 0x70, 0x3f, 0x5b, 0x7d, 0x69, 0x88, 0x1a, 0x44, 0xd7, 0x82, 0xb0,
		0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0xef, 0xf4, 0x1b, 0x37,
		0x52, 0x79, 0xc1, 0x63, 0x0a, 0xe2, 0x06, 0x35, 0xc6, 0x4b, 0x38, 0x15, 0xea, 0x76, 0x9a, 0xf8,
		0x8f, 0xc0, 0x01, 0x02, 0x07, 0x3f, 0x55, 0x5d, 0x05, 0x68, 0x2e, 0x04, 0x0e, 0xb6, 0xdb, 0x84,
		0x91, 0x6f, 0x80, 0xd0, 0x01, 0x42, 0x07, 0xa4, 0x66, 0x2e, 0x1e, 0xb4, 0x50, 0x3d, 0xc2, 0x26,
		0x98, 0x2b, 0x29, 0x5f, 0x7c, 0x25, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08,
		0x1b, 0x20, 0x6c, 0xf0, 0xde, 0xb0, 0x01, 0x79, 0xc9, 0xd8, 0x55, 0x30, 0x42, 0x54, 0x42, 0x76,
		0x37, 0x49, 0x8b, 0x3f, 0x9c, 0x30, 0x73, 0x6f, 0xc0, 0x4f, 0x5a, 0xe2, 0x2b, 0x01, 0x69, 0x01,
		0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x49, 0xce, 0xf1,
		0xd0, 0x0b, 0xb4, 0x4c, 0x03, 0x67, 0x99, 0x5f, 0x08, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28,
		0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x4b, 0x72, 0x8e, 0x75, 0xe0, 0xa9, 0x50, 0x6a,
		0x79, 0x9f, 0x82, 0xbc, 0xd2, 0x17, 0xd7, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02,
		0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x92, 0x7a, 0xe2, 0x92, 0xe9, 0xf2, 0xa2, 0xc4, 0x3d, 0x0a, 0x13,
		0xe3, 0xb3, 0xf5, 0x2c, 0x4c, 0xb6, 0xc7, 0x4b, 0xfe, 0x88, 0xa2, 0xb1, 0x21, 0x9f, 0xb9, 0x65,
		0xab, 0x67, 0xcc, 0x6f, 0xe2, 0x91, 0xa3, 0xe8, 0x8b, 0x73, 0x2a, 0x43, 0x5d, 0xd7, 0x9a, 0xb8,
		0x61, 0xcd, 0x37, 0xa9, 0x4e, 0x06, 0x62, 0xc2, 0x08, 0x42, 0x5a, 0x46, 0xed, 0x7c, 0xf3, 0x1e,
		0x5e, 0x8c, 0x5c, 0x38, 0x2a, 0x95, 0x2a, 0xd5, 0x52, 0x29, 0x5f, 0x3d, 0xac, 0xe6, 0x6b, 0xe5,
		0x72, 0xa1, 0x52, 0x20, 0x4c, 0x80, 0x75, 0x9a, 0x41, 0x4f, 0x04, 0xa2, 0xf7, 0x79, 0xf2, 0xe8,
		0xd5, 0x68, 0x30, 0xc8, 0x94, 0x45, 0x33, 0xb9, 0xe6, 0x74, 0xbb, 0x64, 0x87, 0xb4, 0xb1, 0x42,
		0x30, 0xea, 0x6a, 0x35, 0xa3, 0x5e, 0x9f, 0x6f, 0x87, 0x9d, 0x96, 0xbc, 0xe9, 0xd4, 0xfb, 0xf2,
		0xc2, 0xeb, 0xcb, 0x4e, 0x63, 0x78, 0x5f, 0xb9, 0x08, 0xb4, 0x38, 0x9f, 0xde, 0x6b, 0xe7, 0x6c,
		0x76, 0x87, 0x9d, 0x7a, 0xef, 0x9f, 0x96, 0xbc, 0x69, 0xa8, 0xf3, 0x40, 0x74, 0x5a, 0x93, 0xfb,
		0xea, 0x5c, 0x45, 0x37, 0x51, 0x8f, 0xef, 0x01, 0xdd, 0x99, 0xf9, 0x97, 0xd9, 0xee, 0x74, 0x67,
		0x5e, 0xd2, 0x08, 0x78, 0x5b, 0x5b, 0x35, 0x7f, 0xd8, 0x22, 0x43, 0x9b, 0x33, 0x92, 0xc9, 0x13,
		0x77, 0x65, 0x6f, 0x4f, 0xa8, 0xde, 0xd0, 0x97, 0x4a, 0xef, 0x75, 0xfd, 0x81, 0x1f, 0x58, 0xf2,
		0x63, 0x34, 0x74, 0x84, 0x8e, 0x7e, 0xb0, 0xd2, 0x0d, 0x1a, 0x7a, 0x61, 0xcb, 0xfc, 0x88, 0xfc,
		0x1b, 0x9b, 0x5f, 0xb3, 0xc8, 0x04, 0x4c, 0x21, 0xbf, 0x1d, 0x3f, 0x6b, 0xde, 0x0b, 0x9a, 0xfd,
		0x46, 0xc3, 0x06, 0x6d, 0xdb, 0x90, 0x19, 0x0c, 0xd8, 0xac, 0x5d, 0x98, 0x7b, 0x7a, 0x66, 0xbe,
		0xc9, 0xd0, 0xf3, 0xb7, 0xf5, 0xdc, 0x29, 0x9f, 0xb7, 0x41, 0x1f, 0xb5, 0xb9, 0x4f, 0x32, 0x63,
		0x75, 0x9b, 0xdb, 0x88, 0x01, 0xfb, 0x70, 0xe6, 0xd3, 0xec, 0x8f, 0xb4, 0x3b, 0xf4, 0x43, 0x6d,
		0xcc, 0x42, 0x9e, 0xeb, 0x00, 0xbd, 0x1e, 0xc1, 0x90, 0x55, 0x9b, 0xed, 0x5c, 0x67, 0x7c, 0x57,
		0xd5, 0xc6, 0x2e, 0xa9, 0xdd, 0x5d, 0x4f, 0x5b, 0xbb, 0x98, 0xd6, 0x77, 0x25, 0xad, 0xef, 0x32,
		0x5a, 0xdf, 0x35, 0x4c, 0x17, 0x5e, 0x98, 0xee, 0x94, 0xe6, 0xcc, 0xc0, 0xda, 0xb8, 0x61, 0xcd,
		0x97, 0xc3, 0xec, 0xfb, 0x0d, 0x3f, 0x74, 0x3b, 0xad, 0x31, 0xad, 0xa5, 0x6f, 0xd8, 0x4c, 0xcb,
		0xa0, 0x49, 0xb7, 0xb0, 0x9d, 0x46, 0x41, 0x96, 0x1e, 0x41, 0x96, 0xf6, 0x40, 0x96, 0xce, 0x90,
		0x6e, 0x61, 0x63, 0xab, 0xb5, 0x63, 0xe4, 0x58, 0xec, 0xd9, 0xe3, 0x82, 0xff, 0xb2, 0x65, 0x8b,
		0x76, 0x3b, 0xfc, 0x5a, 0xcf, 0x46, 0xa3, 0xc8, 0x36, 0xa3, 0xcd, 0x26, 0xa3, 0xca, 0x16, 0x23,
		0xcf, 0x06, 0x23, 0xcf, 0xf6, 0x22, 0xcf, 0xe6, 0xda, 0xae, 0xb8, 0xb9, 0xed, 0x8e, 0xb7, 0x4e,
		0x14, 0x80, 0xb7, 0x6e, 0xc7, 0xf3, 0xd5, 0x69, 0x33, 0xde, 0xff, 0xda, 0x5d, 0x5a, 0xce, 0x04,
		0x20, 0x4b, 0xe2, 0xa5, 0x4c, 0xd6, 0xe5, 0x49, 0xca, 0xa5, 0x4e, 0xbe, 0x65, 0x4b, 0xb2, 0x65,
		0x4b, 0xa6, 0x65, 0x4b, 0x9a, 0xdd, 0xee, 0x7d, 0x71, 0xb2, 0x64, 0xd7, 0x78, 0xdd, 0x0d, 0x84,
		0xd7, 0x0f, 0x44, 0x9f, 0x62, 0xd1, 0xcd, 0x59, 0x65, 0x95, 0x60, 0xac, 0xf3, 0x59, 0x84, 0xf9,
		0xd3, 0xa7, 0x28, 0x8f, 0x30, 0x17, 0x01, 0xc1, 0xb6, 0xee, 0xbd, 0x5b, 0x64, 0x96, 0xf3, 0xad,
		0x71, 0x3a, 0x4c, 0x8e, 0x47, 0x04, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x80, 0x65, 0xc0, 0xf2, 0xce,
		0xc2, 0x72, 0x8c, 0x05, 0x40, 0xe6, 0xc4, 0x64, 0xcd, 0x92, 0xd7, 0xe8, 0x80, 0x79, 0x3e, 0x20,
		0x70, 0x19, 0xb8, 0x0c, 0x5c, 0x06, 0x2e, 0x03, 0x97, 0x77, 0x16, 0x97, 0xe7, 0x50, 0x00, 0x58,
		0x4e, 0xcc, 0x55, 0x74, 0x2e, 0x91, 0x0c, 0x94, 0xa3, 0xe1, 0x68, 0x20, 0xb9, 0x00, 0x48, 0x06,
		0x24, 0x03, 0x92, 0x01, 0xc9, 0xeb, 0xcf, 0x9a, 0xed, 0x0d, 0xc4, 0x78, 0xa0, 0xe9, 0x61, 0x63,
		0xa9, 0x7a, 0x82, 0xae, 0xaa, 0xcc, 0x62, 0x9f, 0xca, 0x68, 0x6c, 0xaa, 0x13, 0xd6, 0xa4, 0xf5,
		0x83, 0xc8, 0xeb, 0x05, 0x71, 0xd4, 0x07, 0xe2, 0xad, 0x07, 0xc4, 0x55, 0xff, 0x87, 0xbd, 0xde,
		0x0f, 0x7b, 0x7d, 0x1f, 0xf6, 0x7a, 0x3e, 0xd9, 0xaa, 0xfd, 0x40, 0x5e, 0x9f, 0x87, 0x41, 0x8b,
		0x71, 0x68, 0xb2, 0x65, 0xda, 0xec, 0x3f, 0xfe, 0x4e, 0x21, 0x29, 0x14, 0x3a, 0x8c, 0x5f, 0xcd,
		0x94, 0x5c, 0x04, 0x53, 0x59, 0x39, 0xf5, 0x4e, 0xc0, 0xac, 0x69, 0x32, 0x94, 0x12, 0xd6, 0x4c,
		0x91, 0xa9, 0x04, 0x3a, 0x01, 0x3a, 0x01, 0x3a, 0x01, 0x3a, 0x01, 0x3a, 0xb1, 0x64, 0xdd, 0x8e,
		0xa4, 0xd2, 0x87, 0x45, 0x06, 0x36, 0x41, 0x49, 0x26, 0x5a, 0x9e, 0xba, 0x15, 0xe4, 0x5d, 0xa1,
		0x19, 0x6a, 0xdb, 0x71, 0x76, 0x7d, 0xe6, 0xae, 0xf6, 0x3b, 0x6f, 0x89, 0xcb, 0x35, 0x7e, 0x0a,
		0xda, 0xdf, 0x72, 0x54, 0xbc, 0xe6, 0xec, 0xd2, 0x9c, 0x16, 0x93, 0x2b, 0x15, 0x6b, 0xa5, 0x5a,
		0xa5, 0x5a, 0xac, 0x95, 0x77, 0xd8, 0xf6, 0x32, 0x5a, 0xb3, 0xb2, 0x0d, 0x11, 0xf9, 0x0e, 0x11,
		0x79, 0x77, 0x37, 0x52, 0x52, 0x3f, 0x72, 0x85, 0xa8, 0x5f, 0x5f, 0x00, 0x84, 0x25, 0x84, 0x25,
		0x84, 0x25, 0x84, 0x25, 0x84, 0x25, 0xf9, 0xba, 0x45, 0x9c, 0xfa, 0xc5, 0xdf, 0x39, 0x2e, 0x49,
		0x11, 0xc6, 0xaf, 0x1f, 0x11, 0xaa, 0x5e, 0x6f, 0xca, 0xc9, 0xce, 0xee, 0x24, 0x6c, 0x9a, 0xe8,
		0x0c, 0x0f, 0x78, 0x05, 0x78, 0x05, 0x78, 0x05, 0x78, 0x05, 0x78, 0xc5, 0x92, 0x75, 0x2b, 0x87,
		0xae, 0xd7, 0xeb, 0x05, 0x22, 0x0c, 0x39, 0xa8, 0x45, 0x8d, 0x70, 0xcc, 0xd9, 0x1c, 0x67, 0x3e,
		0x68, 0xfd, 0xfc, 0x64, 0xef, 0x4b, 0x0c, 0xcf, 0x36, 0xf1, 0x8c, 0x8f, 0x18, 0xc6, 0x3e, 0xf7,
		0xb4, 0x16, 0x81, 0x22, 0x7f, 0xdc, 0xf1, 0x05, 0xfc, 0xb5, 0xbf, 0x7f, 0x9d, 0x77, 0x6b, 0xed,
		0xa7, 0xeb, 0x82, 0x5b, 0x6b, 0x47, 0x2f, 0x0b, 0xd3, 0x7f, 0xa2, 0xd7, 0xc5, 0xeb, 0xbc, 0x5b,
		0x9a, 0xbf, 0x2e, 0x5f, 0xe7, 0xdd, 0x72, 0xfb, 0xe0, 0xcf, 0x3f, 0x3f, 0x1d, 0xfc, 0x38, 0x1c,
		0xbf, 0xff, 0x83, 0xff, 0xa3, 0x6f, 0x23, 0xd6, 0xe6, 0x78, 0xa8, 0xcd, 0x8b, 0xc6, 0x1f, 0x78,
		0xb2, 0xb6, 0x9f, 0x6c, 0x96, 0xbb, 0x65, 0xf1, 0xba, 0xe3, 0x0a, 0xdc, 0x31, 0xef, 0xa2, 0xf5,
		0xdc, 0x7e, 0xdd, 0xfd, 0xda, 0xfe, 0x51, 0xf8, 0x58, 0x1a, 0x1f, 0x1f, 0xfc, 0xa8, 0x8e, 0x5f,
		0xff, 0xf0, 0x69, 0xd9, 0xdb, 0x0a, 0x1f, 0xab, 0xe3, 0xe3, 0x15, 0xbf, 0xa9, 0x8c, 0x8f, 0xdf,
		0xf8, 0x1d, 0xe5, 0xf1, 0x7e, 0xe2, 0xad, 0x93, 0x9f, 0x17, 0x57, 0x7d, 0xa0, 0xb4, 0xe2, 0x03,
		0x87, 0xab, 0x3e, 0x70, 0xb8, 0xe2, 0x03, 0x2b, 0x2f, 0xa9, 0xb8, 0xe2, 0x03, 0xe5, 0xf1, 0x53,
		0xe2, 0xfd, 0xfb, 0xcb, 0xdf, 0x5a, 0x19, 0x1f, 0x3c, 0xad, 0xfa, 0x5d, 0x75, 0xfc, 0x74, 0x7c,
		0x00, 0x70, 0x82, 0x9d, 0xc3, 0xce, 0x33, 0x01, 0xd5, 0xd8, 0x23, 0x4e, 0x63, 0xf4, 0xf6, 0x41,
		0xbb, 0xec, 0xfb, 0xc4, 0xcb, 0x2e, 0x02, 0x31, 0x5d, 0xc4, 0x74, 0x11, 0xd3, 0x45, 0x4c, 0x17,
		0x31, 0x5d, 0xf2, 0x75, 0x8b, 0xbd, 0xe2, 0x17, 0x7f, 0x5f, 0x62, 0x93, 0x14, 0xe1, 0xc2, 0xff,
		0xc7, 0x9e, 0xf1, 0x9a, 0x53, 0x2f, 0xd5, 0xbd, 0x37, 0x90, 0x3d, 0x37, 0x10, 0x5e, 0x48, 0xd8,
		0xdd, 0xf6, 0x39, 0x98, 0xb2, 0x38, 0x3e, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8,
		0x06, 0xf9, 0xba, 0x95, 0x3d, 0xa1, 0xb4, 0xd4, 0x8f, 0x4c, 0x7c, 0x83, 0xb2, 0x57, 0x7d, 0x63,
		0x76, 0xab, 0x9f, 0xbd, 0x90, 0xc1, 0x65, 0xcc, 0x27, 0xbc, 0x71, 0xf6, 0x7b, 0xfd, 0xb4, 0xf1,
		0xa5, 0xd3, 0x6a, 0x5e, 0x5d, 0x9e, 0x74, 0x5a, 0x27, 0xf5, 0x8b, 0xe6, 0x19, 0xb5, 0xf7, 0x98,
		0x1e, 0xd4, 0x08, 0x59, 0xc2, 0x9c, 0x4c, 0x27, 0x63, 0x5e, 0xcf, 0xfe, 0x2f, 0xa7, 0x57, 0x17,
		0x97, 0x27, 0xad, 0xce, 0x69, 0xb3, 0x79, 0xee, 0xec, 0xc2, 0xc1, 0xa4, 0x94, 0xcc, 0x7b, 0xfd,
		0x02, 0x53, 0x4e, 0x3c, 0xe5, 0xcd, 0x56, 0xe3, 0xd7, 0xc6, 0x59, 0xfd, 0xb2, 0xd9, 0xc2, 0xac,
		0x13, 0x3a, 0x98, 0xe6, 0xd9, 0xd7, 0x93, 0x2f, 0x4e, 0xc6, 0xcf, 0x9d, 0xb5, 0xb3, 0xc6, 0xf7,
		0x32, 0xa1, 0xee, 0x07, 0x5e, 0xa8, 0xdd, 0x3b, 0xbf, 0x27, 0xfb, 0x52, 0xf4, 0xe8, 0xc5, 0xfd,
		0xe2, 0xf0, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xe4, 0xeb, 0x56, 0xcb,
		0x3b, 0xa1, 0x65, 0xf7, 0x7b, 0x58, 0x29, 0x31, 0x68, 0x7b, 0xc2, 0x44, 0x35, 0xe7, 0x4a, 0x45,
		0xe7, 0xfc, 0x1d, 0xe5, 0x29, 0x3f, 0x14, 0x5d, 0x5f, 0xf5, 0x48, 0xf3, 0xe1, 0x51, 0x51, 0x25,
		0x7b, 0x18, 0xbf, 0x3c, 0x6a, 0x82, 0x8a, 0x2a, 0xe4, 0x26, 0x87, 0x8a, 0x2a, 0x7b, 0x85, 0xa3,
		0x52, 0xa9, 0x52, 0x2d, 0x95, 0xf2, 0xd5, 0xc3, 0x6a, 0xbe, 0x56, 0x2e, 0x17, 0x2a, 0x05, 0xd4,
		0x56, 0xc9, 0xdc, 0x68, 0xc8, 0x9b, 0x7b, 0xbb, 0x19, 0x52, 0xf5, 0x45, 0x4a, 0x90, 0x2a, 0x9a,
		0xfe, 0x48, 0xf1, 0xb0, 0x5f, 0x44, 0xdf, 0x1b, 0x0d, 0xa6, 0x54, 0x3c, 0x0f, 0x2d, 0x0d, 0x2d,
		0x0d, 0x2d, 0x0d, 0x2d, 0x0d, 0x2d, 0x8d, 0xc2, 0xa0, 0x90, 0xb1, 0x90, 0xb1, 0x90, 0xb1, 0x90,
		0xb1, 0x5b, 0x65, 0x72, 0x28, 0x0c, 0x0a, 0xf1, 0x0a, 0xf1, 0xba, 0xe7, 0xcc, 0x92, 0x9f, 0xfd,
		0x91, 0x16, 0xf4, 0x02, 0xf6, 0xe5, 0xe0, 0x10, 0x94, 0x10, 0x94, 0x10, 0x94, 0x10, 0x94, 0x10,
		0x94, 0xe4, 0xeb, 0xf6, 0xc6, 0xf7, 0x07, 0xc2, 0x53, 0x1c, 0x49, 0xd7, 0x85, 0xac, 0x40, 0xf5,
		0x56, 0x37, 0xc9, 0xac, 0x2b, 0xe5, 0x6b, 0x6f, 0xc2, 0x46, 0x69, 0x7a, 0x65, 0x86, 0xdd, 0xbf,
		0xc5, 0x9d, 0x37, 0x9c, 0x1d, 0xba, 0xcb, 0xf9, 0x43, 0xa1, 0xba, 0x53, 0xa0, 0x9c, 0xf8, 0x8f,
		0xdc, 0xe4, 0xbf, 0x40, 0xde, 0xe4, 0xbc, 0xbe, 0x74, 0x43, 0xaf, 0x2f, 0xc3, 0xf8, 0x55, 0x6e,
		0x5a, 0xf9, 0x26, 0x0c, 0xb4, 0x70, 0x87, 0xfe, 0x40, 0x76, 0x1f, 0x73, 0x4a, 0xc8, 0xdb, 0xbf,
		0x6f, 0xfc, 0x20, 0x8c, 0x5f, 0xe5, 0xbc, 0xde, 0x3f, 0x53, 0x57, 0xe4, 0x8f, 0xb4, 0x3b, 0xf4,
		0x43, 0x9d, 0x9b, 0xf2, 0x8b, 0x30, 0xfa, 0x27, 0x3a, 0xa5, 0x87, 0x36, 0xd2, 0xc9, 0x67, 0x32,
		0x52, 0xdf, 0x95, 0xff, 0xaf, 0x72, 0x3d, 0xad, 0x03, 0x79, 0x33, 0x99, 0x31, 0xba, 0x9e, 0xd2,
		0x4b, 0xc6, 0x46, 0x83, 0xe9, 0xb4, 0xd2, 0x3e, 0x34, 0x98, 0xce, 0x26, 0xad, 0x43, 0x83, 0xe9,
		0xb5, 0x66, 0x8d, 0xac, 0xc1, 0x74, 0xc2, 0x49, 0xd2, 0xeb, 0xf5, 0xe4, 0x25, 0xd0, 0xaa, 0xf6,
		0x02, 0x54, 0x3b, 0x54, 0x3b, 0x54, 0x3b, 0x54, 0x7b, 0x7a, 0x54, 0x3b, 0x95, 0xfb, 0x8f, 0x07,
		0x9c, 0xb6, 0x53, 0xd6, 0xd4, 0xb1, 0x82, 0x05, 0x8f, 0xf1, 0x7c, 0x09, 0xc4, 0xa6, 0xcb, 0xb3,
		0x77, 0x44, 0x0e, 0x07, 0x9c, 0xb0, 0x90, 0x0e, 0x78, 0xe0, 0x86, 0x89, 0xd4, 0xc0, 0x45, 0x6a,
		0x60, 0x23, 0x35, 0xf0, 0x41, 0x0b, 0x23, 0xc4, 0x70, 0x12, 0xcf, 0xf2, 0x25, 0x87, 0x83, 0xdf,
		0xe3, 0xad, 0xfc, 0x95, 0x60, 0xfb, 0x55, 0x9e, 0xfa, 0xd2, 0xf3, 0x4a, 0x60, 0x51, 0x41, 0xaf,
		0x67, 0xb0, 0xcb, 0xe8, 0x6e, 0x39, 0xa1, 0x69, 0x3b, 0x51, 0xf4, 0x95, 0x8d, 0xb8, 0x44, 0xc3,
		0xf3, 0x90, 0x96, 0x02, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x4b, 0x76, 0x49, 0x0b, 0xb5,
		0x16, 0x5e, 0xd4, 0xc4, 0x03, 0xc1, 0x98, 0x48, 0xbb, 0x20, 0x8d, 0x27, 0x57, 0xf2, 0x71, 0x27,
		0xb3, 0x2b, 0xb9, 0x40, 0x27, 0x0d, 0xe0, 0x93, 0x2e, 0x10, 0x4a, 0x0b, 0x18, 0xa5, 0x0e, 0x94,
		0x52, 0x07, 0x4e, 0xa9, 0x03, 0x29, 0x1e, 0xb0, 0x62, 0x02, 0x2d, 0x7e, 0xc5, 0x9d, 0xf0, 0x1b,
		0x23, 0xa9, 0x74, 0xa1, 0xc2, 0xe9, 0x33, 0x66, 0x28, 0x52, 0x61, 0xbc, 0x04, 0x9e, 0xf3, 0x3f,
		0xaf, 0xff, 0xf0, 0xfa, 0xcc, 0x3d, 0xee, 0xf3, 0x41, 0x29, 0xa3, 0x17, 0x89, 0xcb, 0x61, 0x3e,
		0x3f, 0x94, 0xb8, 0x9e, 0x14, 0x9c, 0xe9, 0x48, 0x89, 0x3b, 0x5d, 0x34, 0x61, 0xef, 0x01, 0x26,
		0xfc, 0x13, 0x13, 0xae, 0x94, 0xcb, 0x87, 0x65, 0x98, 0x71, 0xba, 0xb8, 0x08, 0xff, 0xe8, 0xed,
		0x0f, 0xbb, 0x71, 0xbf, 0x1c, 0xc7, 0x20, 0xf9, 0x76, 0xd2, 0x97, 0x87, 0x0d, 0x18, 0x76, 0xd4,
		0x11, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0xc8, 0x48, 0xdc, 0xe0, 0x28,
		0x05, 0x61, 0x83, 0x32, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0xd6,
		0x4d, 0xb8, 0x58, 0x46, 0xd0, 0x00, 0x41, 0x03, 0x04, 0x0d, 0x68, 0x83, 0x06, 0xf7, 0xb3, 0xd5,
		0x97, 0x86, 0xa8, 0x41, 0x74, 0x2d, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08,
		0x1b, 0x20, 0x6c, 0xf0, 0x4e, 0xbf, 0x71, 0x23, 0x95, 0x17, 0x3c, 0xa6, 0x20, 0x6e, 0x50, 0x63,
		0xbc, 0x84, 0x53, 0xa1, 0x6e, 0xa7, 0x89, 0xff, 0x08, 0x1c, 0x20, 0x70, 0xf0, 0x53, 0xd5, 0x55,
		0x80, 0xe6, 0x42, 0xe0, 0x60, 0xbb, 0x4d, 0x18, 0xf9, 0x06, 0x08, 0x1d, 0x20, 0x74, 0x40, 0x6a,
		0xe6, 0xe2, 0x41, 0x0b, 0xd5, 0x23, 0x6c, 0x83, 0xb9, 0x92, 0xf2, 0xc5, 0x57, 0x82, 0xb0, 0x01,
		0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0xef, 0x0d, 0x1b, 0x90, 0x17,
		0x8d, 0x5d, 0x05, 0x23, 0x44, 0x45, 0x64, 0x77, 0x93, 0xb4, 0xf8, 0xc3, 0x09, 0x33, 0xf7, 0x06,
		0xfc, 0xa4, 0x25, 0xbe, 0x12, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90,
		0x16, 0x90, 0x16, 0x90, 0x96, 0xe4, 0x1c, 0x0f, 0xbd, 0x40, 0xcb, 0x34, 0x70, 0x96, 0xf9, 0x85,
		0x80, 0xb2, 0x80, 0xb2, 0x80, 0xb2, 0x80, 0xb2, 0x80, 0xb2, 0x80, 0xb2, 0x80, 0xb2, 0x80, 0xb2,
		0x24, 0xe7, 0x58, 0x07, 0x9e, 0x0a, 0xa5, 0x96, 0xf7, 0x29, 0xc8, 0x2b, 0x7d, 0x71, 0x2d, 0x20,
		0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0xa9, 0x27, 0x2e,
		0x99, 0x2e, 0x2f, 0x4a, 0xdc, 0xa5, 0x30, 0x31, 0x3e, 0x63, 0xd7, 0xc2, 0x64, 0x83, 0xbc, 0xe4,
		0x8f, 0x28, 0x5a, 0x1b, 0xf2, 0x19, 0x5c, 0xb6, 0xba, 0xc6, 0xfc, 0x26, 0x1e, 0x39, 0xca, 0xbe,
		0x38, 0xa7, 0x32, 0xd4, 0x75, 0xad, 0x89, 0x5b, 0xd6, 0x7c, 0x93, 0xea, 0x64, 0x20, 0x26, 0x9c,
		0x20, 0xa4, 0xe5, 0xd4, 0xce, 0x37, 0xef, 0xe1, 0xc5, 0xc8, 0x85, 0xa3, 0x52, 0xa9, 0x52, 0x2d,
		0x95, 0xf2, 0xd5, 0xc3, 0x6a, 0xbe, 0x56, 0x2e, 0x17, 0x2a, 0x05, 0xc2, 0x14, 0x58, 0xa7, 0x19,
		0xf4, 0x44, 0x20, 0x7a, 0x9f, 0x27, 0x8f, 0x5e, 0x8d, 0x06, 0x83, 0x4c, 0x59, 0x34, 0x93, 0x73,
		0x4e, 0xbb, 0x53, 0x76, 0x48, 0x9b, 0x2b, 0x04, 0xa3, 0xae, 0x56, 0x33, 0xfa, 0xf5, 0xf9, 0x76,
		0xd8, 0x69, 0xc9, 0x9b, 0x4e, 0xbd, 0x2f, 0x2f, 0xbc, 0xbe, 0xec, 0x34, 0x86, 0xf7, 0x95, 0x8b,
		0x40, 0x8b, 0xf3, 0xe9, 0xdd, 0x76, 0xce, 0x66, 0xf7, 0xd8, 0xa9, 0xf7, 0xfe, 0x69, 0xc9, 0x9b,
		0xe6, 0x48, 0x9f, 0xfb, 0xa1, 0xee, 0xb4, 0x26, 0x77, 0xd6, 0xb9, 0x8a, 0x6e, 0xa3, 0x1e, 0xdf,
		0x05, 0xba, 0x34, 0xf3, 0x2f, 0xb5, 0x5d, 0xea, 0xd2, 0xbc, 0xa4, 0x21, 0xf0, 0xb6, 0xb6, 0x6c,
		0xfe, 0xb0, 0x45, 0xa6, 0x36, 0xe7, 0x25, 0x93, 0x67, 0xee, 0xca, 0xde, 0x9e, 0x50, 0xbd, 0xa1,
		0x2f, 0x95, 0xde, 0xeb, 0xfa, 0x03, 0x3f, 0xb0, 0xe4, 0xcb, 0x68, 0x48, 0x09, 0x1d, 0x09, 0x61,
		0x25, 0x1d, 0x34, 0x24, 0xc3, 0x96, 0xf9, 0x11, 0x79, 0x38, 0x46, 0xcf, 0x66, 0x91, 0x0f, 0x98,
		0xc3, 0x7f, 0x3b, 0xbe, 0xd6, 0xbc, 0x27, 0x34, 0xfb, 0x8d, 0x86, 0x8d, 0xda, 0xb6, 0x31, 0xb3,
		0x18, 0xb1, 0x59, 0xcb, 0x30, 0xf7, 0xfc, 0xcc, 0x7c, 0x93, 0x21, 0x0b, 0xb0, 0xf5, 0xe4, 0x69,
		0x9f, 0xb8, 0x41, 0x4f, 0x65, 0xc2, 0x33, 0x99, 0xb1, 0xbc, 0xcd, 0xed, 0xc4, 0x80, 0x8d, 0x38,
		0x0b, 0x53, 0x1d, 0x98, 0x0b, 0xd7, 0x3f, 0x17, 0x06, 0x7a, 0x35, 0x80, 0x21, 0xbb, 0x36, 0xdb,
		0xc9, 0xce, 0xf8, 0x2e, 0xab, 0x8d, 0x5d, 0x53, 0xbb, 0xbb, 0xa0, 0xb6, 0x76, 0x35, 0xad, 0xef,
		0x52, 0x5a, 0xdf, 0x75, 0xb4, 0xbe, 0x8b, 0x98, 0x2e, 0xc4, 0x30, 0xdd, 0x39, 0xcd, 0x99, 0xc1,
		0xb5, 0x71, 0xc3, 0x9a, 0x2f, 0x87, 0xd9, 0xf7, 0x1b, 0x7e, 0xe8, 0x76, 0x5a, 0x65, 0x5a, 0x4b,
		0xe7, 0xb0, 0x99, 0xa6, 0x41, 0x93, 0x7e, 0x61, 0x3b, 0xad, 0x82, 0x2c, 0x5d, 0x82, 0x2c, 0x0d,
		0x82, 0x2c, 0xbd, 0x21, 0xdd, 0xe2, 0xc6, 0x56, 0xab, 0xc7, 0xc8, 0xb1, 0xd8, 0xb3, 0xc7, 0x05,
		0xff, 0x65, 0xcb, 0x16, 0xed, 0x76, 0xfc, 0xb5, 0x9e, 0x9d, 0x46, 0x91, 0x7d, 0x46, 0x9b, 0x5d,
		0x46, 0x95, 0x3d, 0x46, 0x9e, 0x1d, 0x46, 0x9e, 0xfd, 0x45, 0x9e, 0xdd, 0xb5, 0x5d, 0xf1, 0x73,
		0xdb, 0x1d, 0x70, 0x9d, 0x28, 0x10, 0x6f, 0xdd, 0x8e, 0xe7, 0xab, 0xd3, 0x66, 0xdc, 0xff, 0xb5,
		0xbb, 0xb4, 0x9c, 0x17, 0x40, 0x96, 0xd4, 0x4b, 0x99, 0xbc, 0xcb, 0x93, 0xa4, 0x4b, 0x9d, 0x8c,
		0xcb, 0x96, 0x74, 0xcb, 0x96, 0x5c, 0xcb, 0x96, 0x44, 0xbb, 0xdd, 0x3b, 0xe4, 0x64, 0xc9, 0xaf,
		0xf1, 0xba, 0x1b, 0x08, 0xaf, 0x1f, 0x88, 0x3e, 0xc5, 0xa2, 0x9b, 0xb3, 0xca, 0x2a, 0xc1, 0x58,
		0xe7, 0xb3, 0x18, 0xf3, 0xa7, 0x4f, 0x51, 0x56, 0x61, 0x2e, 0x02, 0x82, 0x6d, 0xdd, 0x83, 0xb7,
		0xc8, 0x2c, 0xe7, 0x5b, 0xe4, 0x74, 0x98, 0x1c, 0x8f, 0x08, 0x58, 0x06, 0x2c, 0x03, 0x96, 0x01,
		0xcb, 0x80, 0xe5, 0x9d, 0x85, 0xe5, 0x18, 0x0b, 0x80, 0xcc, 0x89, 0xc9, 0x9a, 0x25, 0xb1, 0xd1,
		0x01, 0xf3, 0x7c, 0x40, 0xe0, 0x32, 0x70, 0x19, 0xb8, 0x0c, 0x5c, 0x06, 0x2e, 0xef, 0x2c, 0x2e,
		0xcf, 0xa1, 0x00, 0xb0, 0x9c, 0x98, 0xab, 0xe8, 0x94, 0x22, 0x19, 0x28, 0x47, 0xc3, 0xd1, 0x40,
		0x72, 0x01, 0x90, 0x0c, 0x48, 0x06, 0x24, 0x03, 0x92, 0xd7, 0x9f, 0x35, 0xdb, 0x1b, 0x88, 0xf1,
		0x40, 0xd3, 0xa3, 0xc7, 0x52, 0xf5, 0x04, 0x5d, 0x95, 0x99, 0xc5, 0xbe, 0x95, 0xd1, 0xd8, 0x54,
		0xe7, 0xad, 0x49, 0xeb, 0x09, 0x91, 0xd7, 0x0f, 0xe2, 0xa8, 0x17, 0xc4, 0x5b, 0x1f, 0x88, 0xab,
		0x1e, 0x10, 0x7b, 0xfd, 0x1f, 0xf6, 0x7a, 0x3f, 0xec, 0xf5, 0x7d, 0xb2, 0x55, 0x09, 0x82, 0xbc,
		0x5e, 0x0f, 0x83, 0x16, 0xe3, 0xd0, 0x64, 0xcb, 0xb4, 0xd9, 0x7f, 0xfc, 0x9d, 0x42, 0x52, 0x28,
		0x74, 0x18, 0xbf, 0x9a, 0x29, 0xb9, 0x08, 0xa6, 0xb2, 0x72, 0xfe, 0x9d, 0x80, 0x59, 0xd3, 0x64,
		0x28, 0x25, 0xac, 0x99, 0x22, 0x53, 0x09, 0x74, 0x02, 0x74, 0x02, 0x74, 0x02, 0x74, 0x02, 0x74,
		0x62, 0xc9, 0xba, 0x1d, 0x49, 0xa5, 0x0f, 0x8b, 0x0c, 0x6c, 0x82, 0x92, 0x4c, 0xb4, 0x3c, 0x75,
		0x2b, 0xc8, 0xbb, 0x44, 0x33, 0xd4, 0xba, 0xe3, 0xec, 0x02, 0xcd, 0x5d, 0xfd, 0x77, 0xde, 0x22,
		0x97, 0x6b, 0xfc, 0x14, 0xb4, 0xc3, 0xe5, 0xa8, 0x80, 0xcd, 0xd9, 0xb5, 0x39, 0x2d, 0x26, 0x57,
		0x2a, 0xd6, 0x4a, 0xb5, 0x4a, 0xb5, 0x58, 0x2b, 0xef, 0xb0, 0xed, 0x65, 0xb4, 0x82, 0x65, 0x1b,
		0x22, 0xf2, 0x1d, 0x22, 0xf2, 0xee, 0x6e, 0xa4, 0xa4, 0x7e, 0xe4, 0x0a, 0x51, 0xbf, 0xbe, 0x00,
		0x08, 0x4b, 0x08, 0x4b, 0x08, 0x4b, 0x08, 0x4b, 0x08, 0x4b, 0xf2, 0x75, 0x8b, 0x38, 0xf5, 0x8b,
		0xbf, 0x73, 0x5c, 0x92, 0x22, 0x8c, 0x5f, 0x3f, 0x22, 0x54, 0xbd, 0xde, 0x94, 0x93, 0x9d, 0xdd,
		0x49, 0xd8, 0x34, 0xd1, 0x19, 0x1e, 0xf0, 0x0a, 0xf0, 0x0a, 0xf0, 0x0a, 0xf0, 0x0a, 0xf0, 0x8a,
		0x25, 0xeb, 0x56, 0x0e, 0x5d, 0xaf, 0xd7, 0x0b, 0x44, 0x18, 0x72, 0x50, 0x8b, 0x1a, 0xe1, 0x98,
		0xb3, 0x39, 0xce, 0x7c, 0xd0, 0xfa, 0xf9, 0xc9, 0xde, 0x97, 0x18, 0x9e, 0x6d, 0xe2, 0x19, 0x1f,
		0x31, 0x8c, 0x7d, 0xee, 0x69, 0x2d, 0x02, 0x45, 0xfe, 0xb8, 0xe3, 0x0b, 0xf8, 0x6b, 0x7f, 0xff,
		0x3a, 0xef, 0xd6, 0xda, 0x4f, 0xd7, 0x05, 0xb7, 0xd6, 0x8e, 0x5e, 0x16, 0xa6, 0xff, 0x44, 0xaf,
		0x8b, 0xd7, 0x79, 0xb7, 0x34, 0x7f, 0x5d, 0xbe, 0xce, 0xbb, 0xe5, 0xf6, 0xc1, 0x9f, 0x7f, 0x7e,
		0x3a, 0xf8, 0x71, 0x38, 0x7e, 0xff, 0x07, 0xff, 0x47, 0xdf, 0x56, 0xac, 0xcd, 0xf1, 0x50, 0x9b,
		0x17, 0x8d, 0x3f, 0xf0, 0x64, 0x6d, 0x3f, 0xd9, 0x2c, 0x77, 0xcf, 0xe2, 0x75, 0xc7, 0x15, 0xb8,
		0x63, 0xde, 0x45, 0xeb, 0xb9, 0xfd, 0xba, 0xfb, 0xb5, 0xfd, 0xa3, 0xf0, 0xb1, 0x34, 0x3e, 0x3e,
		0xf8, 0x51, 0x1d, 0xbf, 0xfe, 0xe1, 0xd3, 0xb2, 0xb7, 0x15, 0x3e, 0x56, 0xc7, 0xc7, 0x2b, 0x7e,
		0x53, 0x19, 0x1f, 0xbf, 0xf1, 0x3b, 0xca, 0xe3, 0xfd, 0xc4, 0x5b, 0x27, 0x3f, 0x2f, 0xae, 0xfa,
		0x40, 0x69, 0xc5, 0x07, 0x0e, 0x57, 0x7d, 0xe0, 0x70, 0xc5, 0x07, 0x56, 0x5e, 0x52, 0x71, 0xc5,
		0x07, 0xca, 0xe3, 0xa7, 0xc4, 0xfb, 0xf7, 0x97, 0xbf, 0xb5, 0x32, 0x3e, 0x78, 0x5a, 0xf5, 0xbb,
		0xea, 0xf8, 0xe9, 0xf8, 0x00, 0xe0, 0x04, 0x3b, 0x87, 0x9d, 0x67, 0x02, 0xaa, 0xb1, 0x47, 0x9c,
		0xc6, 0xe8, 0xed, 0x83, 0x76, 0xd9, 0xf7, 0x89, 0x97, 0x5d, 0x04, 0x62, 0xba, 0x88, 0xe9, 0x22,
		0xa6, 0x8b, 0x98, 0x2e, 0x62, 0xba, 0xe4, 0xeb, 0x16, 0x7b, 0xc5, 0x2f, 0xfe, 0xbe, 0xc4, 0x26,
		0x29, 0xc2, 0x85, 0xff, 0x8f, 0x3d, 0xe3, 0x35, 0xa7, 0x5e, 0xaa, 0x7b, 0x6f, 0x20, 0x7b, 0x6e,
		0x20, 0xbc, 0x90, 0xb0, 0xd7, 0xed, 0x73, 0x30, 0x65, 0x71, 0x7c, 0x70, 0x0d, 0x70, 0x0d, 0x70,
		0x0d, 0x70, 0x0d, 0x70, 0x0d, 0xf2, 0x75, 0x2b, 0x7b, 0x42, 0x69, 0xa9, 0x1f, 0x99, 0xf8, 0x06,
		0x65, 0xe7, 0xfa, 0xc6, 0xec, 0x56, 0x3f, 0x7b, 0x21, 0x83, 0xcb, 0x98, 0x4f, 0x78, 0xe3, 0xec,
		0xf7, 0xfa, 0x69, 0xe3, 0x4b, 0xa7, 0xd5, 0xbc, 0xba, 0x3c, 0xe9, 0xb4, 0x4e, 0xea, 0x17, 0xcd,
		0x33, 0x6a, 0xef, 0x31, 0x3d, 0xa8, 0x11, 0xb2, 0x84, 0x39, 0x99, 0x4e, 0xc6, 0xbc, 0x9e, 0xfd,
		0x5f, 0x4e, 0xaf, 0x2e, 0x2e, 0x4f, 0x5a, 0x9d, 0xd3, 0x66, 0xf3, 0xdc, 0xd9, 0x85, 0x83, 0x49,
		0x29, 0x99, 0xf7, 0xfa, 0x05, 0xa6, 0x9c, 0x78, 0xca, 0x9b, 0xad, 0xc6, 0xaf, 0x8d, 0xb3, 0xfa,
		0x65, 0xb3, 0x85, 0x59, 0x27, 0x74, 0x30, 0xcd, 0xb3, 0xaf, 0x27, 0x5f, 0x9c, 0x8c, 0x9f, 0x3b,
		0x6b, 0x67, 0x8d, 0xef, 0x65, 0x42, 0xdd, 0x0f, 0xbc, 0x50, 0xbb, 0x77, 0x7e, 0x4f, 0xf6, 0xa5,
		0xe8, 0xd1, 0x8b, 0xfb, 0xc5, 0xe1, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed,
		0xc9, 0xd7, 0xad, 0x96, 0x77, 0x42, 0xcb, 0xee, 0xf7, 0xb0, 0x52, 0x62, 0xd0, 0xf6, 0x84, 0x89,
		0x6a, 0xce, 0x95, 0x8a, 0xce, 0xf9, 0x3b, 0xca, 0x53, 0x7e, 0x28, 0xba, 0xbe, 0xea, 0x91, 0xe6,
		0xc3, 0xa3, 0xa2, 0x4a, 0xf6, 0x30, 0x7e, 0x79, 0xd4, 0x04, 0x15, 0x55, 0xc8, 0x4d, 0x0e, 0x15,
		0x55, 0xf6, 0x0a, 0x47, 0xa5, 0x52, 0xa5, 0x5a, 0x2a, 0xe5, 0xab, 0x87, 0xd5, 0x7c, 0xad, 0x5c,
		0x2e, 0x54, 0x0a, 0xa8, 0xad, 0x92, 0xb9, 0xd1, 0x90, 0x37, 0xf7, 0x76, 0x33, 0xa4, 0xea, 0x8b,
		0x94, 0x20, 0x55, 0x34, 0xfd, 0x91, 0xe2, 0x61, 0xbf, 0x88, 0xbe, 0x37, 0x1a, 0x4c, 0xa9, 0x78,
		0x1e, 0x5a, 0x1a, 0x5a, 0x1a, 0x5a, 0x1a, 0x5a, 0x1a, 0x5a, 0x1a, 0x85, 0x41, 0x21, 0x63, 0x21,
		0x63, 0x21, 0x63, 0x21, 0x63, 0xb7, 0xca, 0xe4, 0x50, 0x18, 0x14, 0xe2, 0x15, 0xe2, 0x75, 0xcf,
		0x99, 0x25, 0x3f, 0xfb, 0x23, 0x2d, 0xe8, 0x05, 0xec, 0xcb, 0xc1, 0x21, 0x28, 0x21, 0x28, 0x21,
		0x28, 0x21, 0x28, 0x21, 0x28, 0xc9, 0xd7, 0xed, 0x8d, 0xef, 0x0f, 0x84, 0xa7, 0x38, 0x92, 0xae,
		0x0b, 0x59, 0x81, 0xea, 0xad, 0x6e, 0x92, 0x59, 0x57, 0xca, 0xd7, 0xde, 0x84, 0x8d, 0xd2, 0xf4,
		0xca, 0x0c, 0xbb, 0x7f, 0x8b, 0x3b, 0x6f, 0x38, 0x3b, 0x74, 0x97, 0xf3, 0x87, 0x42, 0x75, 0xa7,
		0x40, 0x39, 0xf1, 0x1f, 0xb9, 0xc9, 0x7f, 0x81, 0xbc, 0xc9, 0x79, 0x7d, 0xe9, 0x86, 0x5e, 0x5f,
		0x86, 0xf1, 0xab, 0xdc, 0xb4, 0xf2, 0x4d, 0x18, 0x68, 0xe1, 0x0e, 0xfd, 0x81, 0xec, 0x3e, 0xe6,
		0x94, 0x90, 0xb7, 0x7f, 0xdf, 0xf8, 0x41, 0x18, 0xbf, 0xca, 0x79, 0xbd, 0x7f, 0xa6, 0xae, 0xc8,
		0x1f, 0x69, 0x77, 0x18, 0x88, 0xdc, 0x94, 0x5e, 0x84, 0xd1, 0x3f, 0xd1, 0x21, 0x3d, 0x74, 0x91,
		0x4e, 0x3e, 0x92, 0x91, 0xfa, 0xae, 0xfc, 0x7f, 0x95, 0xeb, 0x69, 0x1d, 0xc8, 0x9b, 0xc9, 0x8c,
		0xd1, 0xb5, 0x94, 0x5e, 0x32, 0x36, 0xfa, 0x4b, 0xa7, 0x95, 0xf5, 0xa1, 0xbf, 0x74, 0x36, 0x59,
		0x1d, 0xfa, 0x4b, 0xaf, 0x35, 0x6b, 0x64, 0xfd, 0xa5, 0x13, 0x4e, 0x92, 0x5e, 0xae, 0x27, 0x2f,
		0x81, 0x56, 0xb4, 0x17, 0x20, 0xda, 0x21, 0xda, 0x21, 0xda, 0x21, 0xda, 0xd3, 0x23, 0xda, 0xa9,
		0xdc, 0x7f, 0x3c, 0xe0, 0xb4, 0x9b, 0xb2, 0xa6, 0x0e, 0x15, 0x2c, 0x78, 0x8c, 0xe7, 0x4b, 0x20,
		0x36, 0x5d, 0x9e, 0xad, 0x23, 0x72, 0x38, 0xe0, 0x84, 0x85, 0x74, 0xc0, 0x03, 0x37, 0x4c, 0xa4,
		0x06, 0x2e, 0x52, 0x03, 0x1b, 0xa9, 0x81, 0x0f, 0x5a, 0x18, 0x21, 0x86, 0x93, 0x78, 0x96, 0x2f,
		0x39, 0x1c, 0xfc, 0x1e, 0x6f, 0xe1, 0xaf, 0x04, 0xdb, 0xaf, 0xf2, 0x94, 0x97, 0x9e, 0x17, 0x02,
		0x8b, 0xea, 0x79, 0x3d, 0x83, 0x5d, 0x46, 0x37, 0xcb, 0x09, 0x4d, 0xdb, 0x89, 0xa2, 0xaf, 0x6c,
		0xc4, 0x25, 0x1a, 0x9e, 0x87, 0xb4, 0x14, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0xb2,
		0x4b, 0x5a, 0xa8, 0xb5, 0xf0, 0xa2, 0x26, 0x1e, 0x08, 0xc6, 0x3c, 0xda, 0x05, 0x69, 0x3c, 0xb9,
		0x92, 0x8f, 0x3b, 0x99, 0x5c, 0xc9, 0x05, 0x3a, 0x69, 0x00, 0x9f, 0x74, 0x81, 0x50, 0x5a, 0xc0,
		0x28, 0x75, 0xa0, 0x94, 0x3a, 0x70, 0x4a, 0x1d, 0x48, 0xf1, 0x80, 0x15, 0x13, 0x68, 0xf1, 0x2b,
		0xee, 0x84, 0xdf, 0x18, 0x49, 0xa5, 0x0b, 0x15, 0x4e, 0x9f, 0x31, 0x43, 0x91, 0x0a, 0xe3, 0x25,
		0xf0, 0x1c, 0xff, 0x79, 0xfd, 0x87, 0xd7, 0x67, 0xee, 0x71, 0x1f, 0x0f, 0x4a, 0x19, 0xbd, 0x48,
		0x5c, 0x0e, 0xf3, 0xf1, 0xa1, 0xc4, 0xf5, 0xa4, 0xe0, 0x48, 0x47, 0x4a, 0xdc, 0xe9, 0xa2, 0x09,
		0x7b, 0x0f, 0x30, 0xe1, 0x9f, 0x98, 0x70, 0xa5, 0x5c, 0x3e, 0x2c, 0xc3, 0x8c, 0xd3, 0xc5, 0x45,
		0xf8, 0x47, 0x6f, 0x7f, 0xd8, 0x8d, 0xfb, 0xe5, 0x38, 0x05, 0xc9, 0xb7, 0x93, 0xbe, 0x3c, 0x6c,
		0xc0, 0xb0, 0xa3, 0x8e, 0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e, 0x80, 0xb8, 0x41, 0x46,
		0xe2, 0x06, 0x47, 0x29, 0x08, 0x1b, 0x94, 0x11, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d,
		0x10, 0x36, 0xb0, 0x6e, 0xc2, 0xc5, 0x32, 0x82, 0x06, 0x08, 0x1a, 0x20, 0x68, 0x40, 0x1b, 0x34,
		0xb8, 0x9f, 0xad, 0xbe, 0x34, 0x44, 0x0d, 0xa2, 0x6b, 0x41, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d,
		0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x83, 0x77, 0xfa, 0x8d, 0x1b, 0xa9, 0xbc, 0xe0, 0x31, 0x05,
		0x71, 0x83, 0x1a, 0xe3, 0x25, 0x9c, 0x0a, 0x75, 0x3b, 0x4d, 0xfc, 0x47, 0xe0, 0x00, 0x81, 0x83,
		0x9f, 0xaa, 0xae, 0x02, 0x34, 0x17, 0x02, 0x07, 0xdb, 0x6d, 0xc2, 0xc8, 0x37, 0x40, 0xe8, 0x00,
		0xa1, 0x03, 0x52, 0x33, 0x17, 0x0f, 0x5a, 0xa8, 0x1e, 0x61, 0x17, 0xcc, 0x95, 0x94, 0x2f, 0xbe,
		0x12, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x78, 0x6f,
		0xd8, 0x80, 0xbc, 0x66, 0xec, 0x2a, 0x18, 0x21, 0xaa, 0x21, 0xbb, 0x9b, 0xa4, 0xc5, 0x1f, 0x4e,
		0x98, 0xb9, 0x37, 0xe0, 0x27, 0x2d, 0xf1, 0x95, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4,
		0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x24, 0xe7, 0x78, 0xe8, 0x05, 0x5a, 0xa6, 0x81,
		0xb3, 0xcc, 0x2f, 0x04, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05,
		0x94, 0x05, 0x94, 0x25, 0x39, 0xc7, 0x3a, 0xf0, 0x54, 0x28, 0xb5, 0xbc, 0x4f, 0x41, 0x5e, 0xe9,
		0x8b, 0x6b, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71,
		0x49, 0x3d, 0x71, 0xc9, 0x74, 0x79, 0x51, 0xe2, 0x26, 0x85, 0x89, 0xf1, 0xf9, 0x9a, 0x16, 0x26,
		0xfb, 0xe3, 0x25, 0x7f, 0x44, 0xd1, 0xd9, 0x90, 0xcf, 0xde, 0xb2, 0xd5, 0x34, 0xe6, 0x37, 0xf1,
		0xc8, 0x51, 0xf5, 0xc5, 0x39, 0x95, 0xa1, 0xae, 0x6b, 0x4d, 0xdc, 0xb1, 0xe6, 0x9b, 0x54, 0x27,
		0x03, 0x31, 0xa1, 0x04, 0x21, 0x2d, 0xa5, 0x76, 0xbe, 0x79, 0x0f, 0x2f, 0x46, 0x2e, 0x1c, 0x95,
		0x4a, 0x95, 0x6a, 0xa9, 0x94, 0xaf, 0x1e, 0x56, 0xf3, 0xb5, 0x72, 0xb9, 0x50, 0x29, 0x10, 0x66,
		0xc0, 0x3a, 0xcd, 0xa0, 0x27, 0x02, 0xd1, 0xfb, 0x3c, 0x79, 0xf4, 0x6a, 0x34, 0x18, 0x64, 0xca,
		0xa2, 0x99, 0x7c, 0x73, 0xca, 0x7d, 0xb2, 0x43, 0xda, 0x5a, 0x21, 0x18, 0x75, 0xb5, 0x9a, 0x91,
		0xaf, 0xcf, 0xb7, 0xc3, 0x4e, 0x4b, 0xde, 0x74, 0xea, 0x7d, 0x79, 0xe1, 0xf5, 0x65, 0xa7, 0x31,
		0xbc, 0xaf, 0x5c, 0x04, 0x5a, 0x9c, 0x4f, 0x6f, 0xb6, 0x73, 0x36, 0xbb, 0xc5, 0x4e, 0xbd, 0xf7,
		0x4f, 0x4b, 0xde, 0x34, 0x47, 0xfa, 0x3c, 0x10, 0x9d, 0xd6, 0xe4, 0xc6, 0x3a, 0x57, 0xd1, 0x5d,
		0xd4, 0xe3, 0x9b, 0x40, 0x87, 0x66, 0xfe, 0x85, 0xb6, 0x43, 0x1d, 0x9a, 0x97, 0x34, 0x03, 0xde,
		0xd6, 0x76, 0xcd, 0x1f, 0xb6, 0xc8, 0xd2, 0xe6, 0xa4, 0x64, 0xf2, 0xc8, 0x5d, 0xd9, 0xdb, 0x13,
		0xaa, 0x37, 0xf4, 0xa5, 0xd2, 0x7b, 0x5d, 0x7f, 0xe0, 0x07, 0x96, 0x3c, 0x19, 0x0d, 0x23, 0xa1,
		0x63, 0x20, 0xac, 0x8c, 0x83, 0x86, 0x61, 0xd8, 0x32, 0x3f, 0x22, 0x07, 0xc7, 0xe7, 0xd8, 0x2c,
		0x92, 0x01, 0x63, 0xe0, 0x6f, 0xc7, 0xd3, 0x9a, 0xf7, 0x83, 0x66, 0xbf, 0xd1, 0xb0, 0x49, 0xdb,
		0x36, 0x65, 0x0e, 0x13, 0x36, 0x6b, 0x18, 0xe6, 0x1e, 0x9f, 0x99, 0x6f, 0x32, 0x64, 0x00, 0xb6,
		0x1e, 0x3c, 0xe9, 0x03, 0x37, 0xe8, 0xa6, 0x0c, 0xb8, 0x25, 0x33, 0x76, 0xb7, 0xb9, 0x95, 0x18,
		0xb0, 0x10, 0x67, 0x3e, 0xe3, 0xae, 0xd7, 0xeb, 0x05, 0x22, 0x0c, 0x8d, 0xd9, 0x48, 0x1c, 0x72,
		0x4f, 0x8c, 0x60, 0xc8, 0xae, 0xcd, 0x6e, 0xc7, 0x1a, 0xdf, 0x5e, 0xb5, 0xb1, 0x5d, 0x6a, 0x77,
		0xfb, 0xd3, 0xd6, 0x76, 0xa6, 0xf5, 0xed, 0x49, 0xeb, 0xdb, 0x8d, 0xd6, 0xb7, 0x0f, 0xd3, 0x85,
		0x18, 0xc6, 0xb7, 0xeb, 0x2c, 0xf6, 0x6f, 0xb5, 0xd1, 0x97, 0x35, 0xd9, 0x6f, 0x35, 0xe1, 0xc3,
		0x32, 0x84, 0x00, 0x66, 0xdb, 0x9f, 0x5a, 0x69, 0x6b, 0x6a, 0xb8, 0x5d, 0x29, 0x7c, 0x3d, 0x7c,
		0x3d, 0x7c, 0x7d, 0x74, 0xb7, 0xa6, 0xdb, 0x63, 0xda, 0x23, 0x94, 0x54, 0xc4, 0xd2, 0x12, 0xc1,
		0xb4, 0xe6, 0x7c, 0x6c, 0x3a, 0x21, 0x1a, 0x67, 0x64, 0xdb, 0x29, 0x91, 0x39, 0x27, 0x32, 0x27,
		0x45, 0xe6, 0xac, 0xb6, 0x23, 0xb6, 0x65, 0x2d, 0xbf, 0x2c, 0xb6, 0x7b, 0x39, 0xb4, 0xe4, 0x65,
		0x16, 0xe8, 0x8d, 0x85, 0x62, 0x83, 0xf3, 0xb9, 0xb1, 0x53, 0x42, 0xd0, 0x62, 0x48, 0xfc, 0x79,
		0xe6, 0xef, 0x4b, 0x16, 0xe7, 0x3e, 0xf1, 0x0c, 0x8e, 0x2c, 0x8e, 0x71, 0xee, 0x69, 0x2d, 0x02,
		0x65, 0xbd, 0xa2, 0xa3, 0xf3, 0xd7, 0xfe, 0xfe, 0x75, 0xde, 0xad, 0xb5, 0x9f, 0xae, 0x0b, 0x6e,
		0xad, 0x1d, 0xbd, 0x2c, 0x4c, 0xff, 0x89, 0x5e, 0x17, 0xaf, 0xf3, 0x6e, 0x69, 0xfe, 0xba, 0x7c,
		0x9d, 0x77, 0xcb, 0xed, 0x83, 0x3f, 0xff, 0xfc, 0x74, 0xf0, 0xe3, 0x70, 0xfc, 0xfe, 0x0f, 0xfe,
		0xcf, 0xde, 0x56, 0x68, 0xdb, 0xe6, 0xc3, 0x68, 0x5e, 0x34, 0xfe, 0xc0, 0x13, 0x79, 0xef, 0x13,
		0xd9, 0xa6, 0xfd, 0x3b, 0x1a, 0xf7, 0x54, 0x81, 0x7b, 0x5a, 0x6f, 0x31, 0x78, 0x6e, 0xbf, 0xee,
		0x7e, 0x6d, 0xff, 0x28, 0x7c, 0x2c, 0x8d, 0x8f, 0x0f, 0x7e, 0x54, 0xc7, 0xaf, 0x7f, 0xf8, 0xb4,
		0xec, 0x6d, 0x85, 0x8f, 0xd5, 0xf1, 0xf1, 0x8a, 0xdf, 0x54, 0xc6, 0xc7, 0x6f, 0xfc, 0x8e, 0xf2,
		0x78, 0x3f, 0xf1, 0xd6, 0xc9, 0xcf, 0x8b, 0xab, 0x3e, 0x50, 0x5a, 0xf1, 0x81, 0xc3, 0x55, 0x1f,
		0x38, 0x5c, 0xf1, 0x81, 0x95, 0x97, 0x54, 0x5c, 0xf1, 0x81, 0xf2, 0xf8, 0x29, 0xf1, 0xfe, 0xfd,
		0xe5, 0x6f, 0xad, 0x8c, 0x0f, 0x9e, 0x56, 0xfd, 0xae, 0x3a, 0x7e, 0x3a, 0x3e, 0x80, 0xb3, 0x86,
		0x7d, 0xee, 0xac, 0x7d, 0x6e, 0x49, 0x1e, 0x41, 0x1b, 0xdb, 0xda, 0x6f, 0x51, 0xbe, 0xdb, 0xb8,
		0xad, 0x6d, 0xf0, 0x38, 0x84, 0x81, 0xcd, 0x83, 0x0f, 0x8c, 0xcf, 0x71, 0x9e, 0xd9, 0x67, 0x38,
		0x88, 0x67, 0x36, 0x77, 0xcf, 0x7c, 0x8e, 0x1e, 0x49, 0x2e, 0x9e, 0xd9, 0x9c, 0xbb, 0x4d, 0x1f,
		0xb4, 0xe1, 0x85, 0x6a, 0x75, 0x81, 0x3a, 0x46, 0xf6, 0xd3, 0xd6, 0xc8, 0x2f, 0xd9, 0xcc, 0x27,
		0xac, 0xbf, 0x92, 0xd7, 0xfb, 0xe4, 0x9a, 0x26, 0x61, 0xca, 0x14, 0x6c, 0x98, 0xc0, 0x7a, 0x0f,
		0xe0, 0xfd, 0xd3, 0xf7, 0xbe, 0x4f, 0xbc, 0x73, 0xa2, 0x37, 0x9d, 0x60, 0x73, 0x13, 0xbb, 0xc6,
		0x42, 0x7a, 0xd7, 0xc2, 0x79, 0xdf, 0xe3, 0x7a, 0xfb, 0xa4, 0xbf, 0x63, 0xc2, 0x23, 0xe9, 0x3f,
		0x52, 0xb2, 0xeb, 0x85, 0xfa, 0xdd, 0xd3, 0xbd, 0x18, 0x40, 0x98, 0x7f, 0xcb, 0x3b, 0x1f, 0xf7,
		0x7a, 0xdb, 0xe2, 0x6b, 0xef, 0x40, 0x6d, 0xb2, 0xc3, 0x64, 0x66, 0x07, 0x69, 0xd3, 0x1d, 0x22,
		0x63, 0x3b, 0x40, 0xc6, 0x76, 0x78, 0x8c, 0xed, 0xe0, 0xd8, 0x75, 0x2c, 0xeb, 0x6e, 0x13, 0x3b,
		0x83, 0xe8, 0x9e, 0xd6, 0x7f, 0x62, 0x71, 0xea, 0xd0, 0xec, 0x8b, 0xd6, 0x9c, 0xe6, 0xcd, 0x32,
		0x48, 0x9e, 0x97, 0x4c, 0x71, 0xcd, 0x2f, 0x30, 0xb0, 0x39, 0x6b, 0x76, 0x13, 0xd6, 0xd4, 0x66,
		0xab, 0xf1, 0x4d, 0x55, 0xe3, 0x9b, 0xa7, 0xc6, 0x37, 0x49, 0x69, 0x49, 0xd3, 0xa6, 0x19, 0x1a,
		0xce, 0x2c, 0x59, 0x7e, 0xe3, 0x07, 0x3d, 0x37, 0xbf, 0xd9, 0xf7, 0x6d, 0xaa, 0xff, 0x8c, 0xa4,
		0x74, 0x19, 0xcb, 0xa6, 0x30, 0x99, 0x3d, 0x61, 0x27, 0x5b, 0xc2, 0x74, 0x76, 0x84, 0xb5, 0x6c,
		0x08, 0x6b, 0xd9, 0x0f, 0xd6, 0xb2, 0x1d, 0x78, 0x23, 0x21, 0xa6, 0x52, 0xb0, 0xa2, 0x85, 0x69,
		0x3e, 0x93, 0xd3, 0xe4, 0x41, 0x31, 0x64, 0x72, 0x22, 0x93, 0xd3, 0xb6, 0x9b, 0xb0, 0xee, 0x2e,
		0xcc, 0x85, 0x60, 0xf7, 0xd2, 0x9c, 0xc9, 0xe9, 0x07, 0xf2, 0xd6, 0x42, 0xdf, 0xcd, 0xe7, 0xe5,
		0x10, 0x7d, 0x3f, 0xb2, 0x36, 0x91, 0xb5, 0xc9, 0xea, 0x88, 0xc8, 0x1c, 0x12, 0x99, 0x63, 0x32,
		0xeb, 0xa0, 0x0c, 0x3b, 0xaa, 0x78, 0x16, 0xec, 0x67, 0x6d, 0x9a, 0x3f, 0x6e, 0x94, 0xe0, 0x31,
		0x55, 0x0b, 0xdf, 0x9d, 0x38, 0x7e, 0x34, 0xf3, 0x94, 0x69, 0xdd, 0x17, 0x36, 0x48, 0x66, 0x66,
		0x85, 0x3e, 0xec, 0x81, 0xce, 0x7c, 0x00, 0xa0, 0x0e, 0x50, 0x07, 0xa8, 0x03, 0xd4, 0x01, 0xea,
		0xac, 0x44, 0x9d, 0xb9, 0xab, 0xdc, 0x05, 0xd8, 0xb1, 0xe3, 0x0e, 0x9f, 0x51, 0xc7, 0x8a, 0x80,
		0x06, 0xe8, 0x00, 0x74, 0x00, 0x3a, 0x00, 0x9d, 0x4c, 0x81, 0x4e, 0x64, 0xf6, 0x3b, 0x80, 0x39,
		0x66, 0xeb, 0x2e, 0x24, 0x0c, 0xc2, 0x64, 0xfd, 0x85, 0x84, 0x29, 0x00, 0x71, 0x80, 0x38, 0x40,
		0x9c, 0x34, 0x23, 0x8e, 0xe9, 0xdd, 0x80, 0xf8, 0x8b, 0xa7, 0xf5, 0xe1, 0xa5, 0xea, 0x09, 0x7b,
		0x9d, 0x80, 0xe2, 0xa5, 0xf5, 0x62, 0x2c, 0x5b, 0xf5, 0x65, 0xad, 0xf6, 0x74, 0xb2, 0xde, 0xb3,
		0x89, 0xa2, 0x27, 0x13, 0x6d, 0xcf, 0x25, 0xaa, 0x9e, 0x4a, 0xe4, 0x3d, 0x93, 0xc8, 0x7b, 0x22,
		0x91, 0xf7, 0x3c, 0xda, 0xae, 0xca, 0xd2, 0xd6, 0x7b, 0x12, 0x11, 0x50, 0x73, 0x0a, 0x8a, 0xbe,
		0x8c, 0xaa, 0x2f, 0xfd, 0x3b, 0x75, 0xd6, 0xa1, 0xd0, 0x61, 0xfc, 0x6a, 0x46, 0xe9, 0x23, 0x07,
		0xbe, 0x2d, 0x45, 0x7c, 0x2d, 0x70, 0xb8, 0xae, 0x7f, 0x77, 0x37, 0x52, 0x52, 0x3f, 0x52, 0xe1,
		0xe6, 0xeb, 0x01, 0x01, 0x9e, 0x00, 0x4f, 0x80, 0x27, 0xc0, 0x13, 0xe0, 0x99, 0x56, 0xf0, 0x9c,
		0x7b, 0x6c, 0x29, 0xc2, 0xf8, 0xf5, 0x23, 0xf0, 0x33, 0x9a, 0x3c, 0xf1, 0xa0, 0x5d, 0x72, 0x0c,
		0x5d, 0x36, 0x28, 0x70, 0x14, 0x38, 0x0a, 0x1c, 0x05, 0x8e, 0x02, 0x47, 0xd3, 0x8a, 0xa3, 0x2f,
		0xbd, 0xf6, 0x04, 0x4b, 0x17, 0xbc, 0x38, 0xf0, 0x34, 0x9a, 0x44, 0xa9, 0xee, 0xbd, 0x81, 0xec,
		0xb9, 0x81, 0xf0, 0x42, 0x8b, 0x9d, 0x8d, 0x9e, 0x8f, 0x38, 0x2f, 0x8e, 0x07, 0x14, 0x05, 0x8a,
		0x02, 0x45, 0x81, 0xa2, 0x5b, 0x88, 0xa2, 0xb2, 0x27, 0x94, 0x96, 0xfa, 0x91, 0x08, 0x49, 0x6d,
		0xf6, 0xe5, 0x6b, 0xcc, 0x6e, 0xe5, 0xb3, 0x17, 0x12, 0x2c, 0xd1, 0xf9, 0x04, 0x36, 0xce, 0x7e,
		0xaf, 0x9f, 0x36, 0xbe, 0x74, 0x5a, 0xcd, 0xab, 0xcb, 0x93, 0x4e, 0xeb, 0xa4, 0x7e, 0xd1, 0x3c,
		0xb3, 0xbd, 0x5a, 0x7f, 0xf7, 0x06, 0xa3, 0xe9, 0xf9, 0xe7, 0x6b, 0xeb, 0x1d, 0x4a, 0x69, 0x9a,
		0x0c, 0x27, 0x66, 0xf3, 0x97, 0xd3, 0xab, 0x8b, 0xcb, 0x93, 0x56, 0xe7, 0xb4, 0xd9, 0x3c, 0xb7,
		0xdf, 0x19, 0x97, 0xa0, 0x7d, 0x33, 0xd3, 0x3c, 0xd6, 0x2f, 0x30, 0x85, 0x1b, 0x4e, 0x61, 0xb3,
		0xd5, 0xf8, 0xb5, 0x71, 0x56, 0xbf, 0x6c, 0xb6, 0x30, 0x8b, 0x1b, 0x2c, 0xe8, 0xe6, 0xd9, 0xd7,
		0x93, 0x2f, 0xce, 0x96, 0xb7, 0x9f, 0x6e, 0x6f, 0x1b, 0x3f, 0xd9, 0x0a, 0xf5, 0x36, 0xf0, 0x42,
		0xed, 0xde, 0xf9, 0x3d, 0xd9, 0x97, 0xa2, 0x67, 0x5f, 0xbc, 0x2d, 0x0e, 0x07, 0xed, 0x06, 0xed,
		0x06, 0xed, 0x06, 0xed, 0xb6, 0x85, 0xda, 0x4d, 0xcb, 0x3b, 0xa1, 0x65, 0xf7, 0x7b, 0x58, 0x29,
		0x11, 0x68, 0x37, 0x9b, 0x75, 0xfa, 0xaf, 0x94, 0x9c, 0x56, 0x8f, 0x75, 0x94, 0xa7, 0xfc, 0x50,
		0x74, 0x7d, 0xd5, 0xb3, 0xda, 0x7b, 0xa0, 0xe5, 0xa9, 0x5b, 0x61, 0x5d, 0x3f, 0xd9, 0xa7, 0x5a,
		0xce, 0x37, 0xa9, 0xac, 0x7b, 0x34, 0x22, 0x4c, 0x5b, 0xae, 0x72, 0x09, 0xc7, 0xfb, 0x1a, 0x78,
		0x5d, 0x2d, 0x7d, 0xf5, 0x45, 0xde, 0x46, 0xd6, 0x98, 0xcf, 0x02, 0xdf, 0x77, 0xbe, 0x79, 0x0f,
		0x99, 0x37, 0x11, 0x3b, 0x55, 0xa7, 0x53, 0x6b, 0x35, 0x1f, 0xb6, 0xf3, 0xdb, 0xdb, 0x3b, 0xac,
		0x71, 0x2c, 0x95, 0x1e, 0x4a, 0x72, 0x69, 0x1b, 0x25, 0x88, 0xa0, 0x6a, 0xa0, 0x6a, 0xa0, 0x6a,
		0xa0, 0x6a, 0x48, 0xd6, 0xcd, 0x48, 0x49, 0x6b, 0x5b, 0xea, 0x7b, 0x96, 0x7b, 0x53, 0xbe, 0x9e,
		0xae, 0xad, 0xd7, 0x17, 0x24, 0xdd, 0x42, 0x39, 0x9e, 0x10, 0xed, 0x93, 0xa2, 0x7b, 0x62, 0x4b,
		0x9e, 0x1c, 0x49, 0xb7, 0xd1, 0x95, 0xcf, 0xf0, 0x88, 0x70, 0x4c, 0xaa, 0x76, 0x6a, 0x89, 0x81,
		0xb3, 0xd2, 0x0b, 0x33, 0xc1, 0xd8, 0x29, 0x1f, 0x1e, 0x65, 0x43, 0xbc, 0xdd, 0x79, 0x82, 0x24,
		0x23, 0x8d, 0x3f, 0x66, 0xd8, 0x7d, 0x56, 0xe0, 0x3e, 0x69, 0x16, 0x1f, 0xba, 0x53, 0x66, 0xaa,
		0x3b, 0xe5, 0xce, 0x83, 0x09, 0xec, 0x39, 0xdb, 0xf6, 0x4c, 0x03, 0xad, 0x1f, 0xb6, 0xfb, 0x3e,
		0x2c, 0x53, 0x03, 0x4a, 0x0d, 0x4c, 0x92, 0x2a, 0x9b, 0x60, 0x00, 0x04, 0x1b, 0x19, 0xb4, 0xa9,
		0xb3, 0x89, 0x89, 0x6d, 0x9c, 0x5d, 0x5c, 0xd6, 0x4f, 0x4f, 0x3b, 0xe7, 0xad, 0xe6, 0x65, 0xf3,
		0x97, 0xe6, 0x69, 0xe7, 0xf2, 0xff, 0xce, 0x4f, 0x1c, 0xca, 0x2d, 0xa4, 0x90, 0x14, 0x23, 0x7e,
		0xd0, 0xa2, 0xd1, 0x7c, 0x9a, 0xcf, 0x1b, 0xdf, 0xe8, 0x9c, 0xe3, 0xf8, 0x63, 0xd6, 0xa7, 0xb3,
		0xf1, 0xeb, 0xb7, 0x73, 0xcc, 0xa7, 0xb9, 0xf9, 0xfc, 0xd2, 0x68, 0x9d, 0xfc, 0x72, 0x79, 0xfa,
		0x7f, 0x9d, 0x5f, 0x9a, 0x67, 0x67, 0x27, 0xbf, 0x5c, 0x52, 0x64, 0x8b, 0xee, 0xce, 0xec, 0x36,
		0x2f, 0xce, 0xbf, 0x1e, 0x62, 0x42, 0xcd, 0x4d, 0xe8, 0xc5, 0x65, 0xfd, 0xb2, 0xf1, 0x0b, 0x66,
		0xd4, 0xa0, 0x43, 0xbd, 0x68, 0x5c, 0x60, 0x3e, 0xcd, 0xcd, 0xe7, 0xe7, 0x5f, 0x81, 0x4f, 0x86,
		0x3d, 0x28, 0xe6, 0xd3, 0xdc, 0x7c, 0x9e, 0x36, 0x7f, 0xa9, 0x9f, 0x76, 0xea, 0xbf, 0xfe, 0xda,
		0x3a, 0xf9, 0xb5, 0x7e, 0x79, 0x42, 0x38, 0xb5, 0x1f, 0xb2, 0x11, 0x1d, 0x40, 0x1a, 0x98, 0xdd,
		0xeb, 0xb5, 0x91, 0x06, 0x66, 0xab, 0x1b, 0x50, 0x62, 0x75, 0xd9, 0xe9, 0x0a, 0x14, 0x0f, 0xf3,
		0x45, 0xf4, 0xbd, 0xd1, 0x60, 0x9a, 0x2b, 0x93, 0x47, 0xb2, 0xd9, 0xf2, 0x01, 0x90, 0x6c, 0xb6,
		0xf6, 0x93, 0x47, 0xb2, 0xd9, 0x56, 0x78, 0xf3, 0x0c, 0x24, 0x9b, 0x49, 0xa5, 0x0f, 0x8b, 0x04,
		0xd9, 0x66, 0x55, 0x9c, 0x66, 0xf9, 0xf9, 0x8d, 0xe0, 0x34, 0x8b, 0xb9, 0xf1, 0x70, 0x9a, 0x65,
		0x6b, 0x4d, 0xa4, 0x54, 0xac, 0x95, 0x6a, 0x95, 0x6a, 0xb1, 0x86, 0x33, 0x2c, 0x10, 0x2f, 0x69,
		0x12, 0x2f, 0x76, 0x09, 0xad, 0xdd, 0xde, 0x72, 0x90, 0x15, 0x90, 0x15, 0x90, 0x15, 0x90, 0x15,
		0x34, 0x55, 0xd5, 0x86, 0xf7, 0x15, 0xd7, 0xba, 0x8d, 0x51, 0x24, 0x89, 0x92, 0x25, 0x85, 0x22,
		0x69, 0x8e, 0x2f, 0x69, 0x2e, 0xb7, 0x5f, 0x28, 0x5e, 0xe7, 0xdd, 0xa3, 0x28, 0x73, 0xbd, 0xd0,
		0x4e, 0x24, 0xb4, 0x4f, 0xff, 0xd7, 0x66, 0x6e, 0x5d, 0xdb, 0xa6, 0x05, 0x53, 0xe6, 0x82, 0xc2,
		0x8c, 0x77, 0xda, 0x8c, 0x77, 0x58, 0x1d, 0xcc, 0x2a, 0x22, 0xfb, 0x23, 0x2d, 0xec, 0x4b, 0x84,
		0x97, 0x83, 0x41, 0x27, 0x40, 0x27, 0x40, 0x27, 0x40, 0x27, 0x6c, 0xa1, 0x4e, 0xb8, 0xf1, 0xfd,
		0x81, 0xf0, 0x48, 0x4e, 0xbb, 0x17, 0xb6, 0x05, 0x9a, 0x52, 0xdd, 0x84, 0xb6, 0xae, 0x94, 0xaf,
		0x3d, 0x2d, 0x2d, 0x35, 0x19, 0x70, 0xc2, 0xee, 0xdf, 0xe2, 0xce, 0x1b, 0xce, 0x7a, 0x42, 0xe4,
		0xfc, 0xa1, 0x50, 0xdd, 0x29, 0x50, 0x4c, 0xd6, 0x67, 0x6e, 0xf2, 0x5f, 0x20, 0x6f, 0x72, 0x5e,
		0x5f, 0xba, 0xa1, 0xd7, 0x97, 0x61, 0xfc, 0x2a, 0x37, 0x55, 0x9c, 0x23, 0x25, 0xbb, 0x5e, 0xa8,
		0x73, 0x83, 0x68, 0x4d, 0xe7, 0xa6, 0xf8, 0x18, 0x46, 0xff, 0x44, 0xad, 0x22, 0x76, 0xa1, 0x0d,
		0xf9, 0x48, 0x7d, 0x57, 0xfe, 0xbf, 0xca, 0xf5, 0xb4, 0x0e, 0xe4, 0xcd, 0x64, 0x06, 0xec, 0xf5,
		0x24, 0x5f, 0x32, 0x16, 0x1a, 0x94, 0xa3, 0x41, 0x79, 0x2a, 0xe8, 0x05, 0x1a, 0x94, 0xd3, 0x62,
		0x83, 0xb5, 0x06, 0xe5, 0x09, 0x27, 0x63, 0x5f, 0x5f, 0x25, 0x87, 0xb4, 0xab, 0xb2, 0x0a, 0x50,
		0x59, 0x50, 0x59, 0x50, 0x59, 0xbb, 0xa4, 0xb2, 0x6c, 0xb9, 0xcb, 0x78, 0x80, 0x69, 0xd3, 0x6e,
		0x6d, 0x5b, 0xcb, 0x2d, 0xac, 0xd0, 0xe7, 0x21, 0x2d, 0x9b, 0x16, 0x4d, 0x66, 0x8a, 0x75, 0xf7,
		0x49, 0xe9, 0x46, 0x79, 0xdc, 0x29, 0xb5, 0x5b, 0x65, 0x73, 0xaf, 0x6c, 0x6e, 0x96, 0xcd, 0xdd,
		0xda, 0x75, 0xbb, 0x96, 0xdd, 0x2f, 0x5d, 0xb0, 0x2b, 0xb1, 0xee, 0xec, 0x37, 0xee, 0x4c, 0xb0,
		0xcb, 0x2a, 0xc1, 0x58, 0x2f, 0x1a, 0x79, 0x46, 0x5d, 0x39, 0x9f, 0xc1, 0x60, 0x4b, 0x73, 0xdd,
		0x2c, 0x9a, 0x9e, 0x13, 0x45, 0xa3, 0xc8, 0x80, 0x39, 0x1a, 0x8e, 0x06, 0x94, 0x0b, 0x00, 0x65,
		0x80, 0x32, 0x40, 0x19, 0xa0, 0x9c, 0x5e, 0x6d, 0xb4, 0xa8, 0x91, 0x06, 0x42, 0xd1, 0x17, 0xfd,
		0x89, 0x47, 0xfe, 0x98, 0xc9, 0x5c, 0x7e, 0x2a, 0x27, 0xcd, 0xe1, 0xac, 0x79, 0x9d, 0x36, 0x97,
		0xf3, 0x66, 0x77, 0xe2, 0xec, 0xce, 0x9c, 0xdd, 0xa9, 0xd3, 0x38, 0x77, 0x22, 0x27, 0x4f, 0xaf,
		0xc0, 0x12, 0xeb, 0x76, 0x24, 0x95, 0x2e, 0x54, 0x18, 0xca, 0xda, 0x56, 0x08, 0x87, 0xa4, 0x39,
		0x1d, 0xf9, 0xfa, 0x0f, 0xad, 0x4f, 0xda, 0xa3, 0x3e, 0x3d, 0xc9, 0x0c, 0xaf, 0x89, 0xe1, 0x89,
		0x4f, 0x57, 0x26, 0xc6, 0x67, 0x38, 0x41, 0xc7, 0xe4, 0xae, 0x16, 0x4d, 0xce, 0x7b, 0xd8, 0x79,
		0x93, 0xab, 0x94, 0xcb, 0x87, 0xe5, 0x1d, 0x36, 0xbb, 0x0f, 0xd9, 0x1c, 0x2d, 0x2b, 0xd5, 0x7d,
		0x29, 0x0e, 0x65, 0xd3, 0xed, 0xb4, 0x2d, 0x97, 0x91, 0x04, 0x3b, 0x6e, 0xd0, 0x91, 0xd0, 0x91,
		0xd0, 0x91, 0xd0, 0x91, 0xd0, 0x91, 0x2b, 0x74, 0xe4, 0x11, 0x83, 0x8c, 0x2c, 0x43, 0x46, 0x42,
		0x46, 0x42, 0x46, 0x42, 0x46, 0x66, 0xc0, 0xe4, 0x8a, 0x65, 0x88, 0x48, 0x88, 0xc8, 0x5d, 0x17,
		0x91, 0xf7, 0xb3, 0xd5, 0xc0, 0xa1, 0x22, 0xa3, 0xb1, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x21,
		0x23, 0x21, 0x23, 0xc9, 0xd7, 0xed, 0x8d, 0x54, 0x5e, 0xf0, 0xc8, 0xa0, 0x23, 0x6b, 0x84, 0x43,
		0x9e, 0x0a, 0x75, 0x3b, 0x4d, 0x14, 0x85, 0x90, 0xdc, 0x01, 0x56, 0x5f, 0x80, 0x90, 0x84, 0x90,
		0xa4, 0x35, 0x39, 0xec, 0x47, 0x42, 0x4a, 0xee, 0xb8, 0x94, 0x14, 0x0f, 0x5a, 0xa8, 0x9e, 0xe8,
		0xd1, 0x0b, 0xc9, 0x78, 0x64, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0x7a,
		0x19, 0x69, 0xbd, 0xa8, 0xd6, 0x2a, 0x37, 0x6c, 0xa9, 0xc8, 0x56, 0x36, 0x41, 0xda, 0x1f, 0x4e,
		0x98, 0xa2, 0x37, 0xa0, 0x07, 0xe9, 0x78, 0x64, 0x80, 0x34, 0x40, 0x1a, 0x20, 0x0d, 0x90, 0x06,
		0x48, 0x03, 0xa4, 0x01, 0xd2, 0xcb, 0xe6, 0x6c, 0xe8, 0x05, 0x5a, 0x72, 0x60, 0xf4, 0x7c, 0x60,
		0x40, 0x34, 0x20, 0x1a, 0x10, 0x0d, 0x88, 0x06, 0x44, 0x03, 0xa2, 0x01, 0xd1, 0xcb, 0xe6, 0x4c,
		0x07, 0x9e, 0x0a, 0xa5, 0x96, 0xf7, 0x0c, 0x79, 0x53, 0x2f, 0xc6, 0x06, 0x50, 0x03, 0xa8, 0x01,
		0xd4, 0x00, 0x6a, 0x00, 0x35, 0x80, 0x7a, 0x0b, 0x81, 0x7a, 0xab, 0xcb, 0x45, 0x59, 0xee, 0x4a,
		0x91, 0x18, 0xcf, 0x62, 0x97, 0x8a, 0x64, 0x43, 0x85, 0xe4, 0x8f, 0x6c, 0xb4, 0xb2, 0xa0, 0x33,
		0x88, 0xed, 0xaa, 0xd2, 0xfc, 0x9b, 0x78, 0xa4, 0x38, 0x66, 0xed, 0x9c, 0xca, 0x50, 0xd7, 0xb5,
		0xb6, 0x5c, 0x12, 0xfa, 0x9b, 0x54, 0x27, 0x03, 0x31, 0xc1, 0xbc, 0xd0, 0x2e, 0xa7, 0x73, 0xbe,
		0x79, 0x0f, 0x2f, 0x46, 0x2a, 0x1c, 0x95, 0x4a, 0x95, 0x6a, 0xa9, 0x94, 0xaf, 0x1e, 0x56, 0xf3,
		0xb5, 0x72, 0xb9, 0x50, 0x29, 0x58, 0x4c, 0xd1, 0x72, 0x9a, 0x41, 0x4f, 0x04, 0xa2, 0xf7, 0x79,
		0xf2, 0xe8, 0xd4, 0x68, 0x30, 0xd8, 0x2a, 0x8b, 0x23, 0x72, 0x66, 0xdc, 0x4e, 0xcc, 0xb1, 0x5a,
		0x5c, 0x35, 0x18, 0x75, 0xb5, 0x9a, 0xd1, 0x83, 0xcf, 0xb7, 0xc3, 0x4e, 0x4b, 0xde, 0x74, 0xea,
		0x7d, 0x79, 0xe1, 0xf5, 0x65, 0xa7, 0x31, 0xbc, 0xaf, 0x5c, 0x45, 0x97, 0xdf, 0x39, 0xf5, 0xbb,
		0x93, 0x5f, 0xb5, 0x26, 0x97, 0xdd, 0xb9, 0x8a, 0xae, 0xb1, 0x1e, 0x5f, 0x22, 0x5a, 0x46, 0xa5,
		0xdf, 0x9e, 0x69, 0xed, 0x38, 0xb5, 0xfd, 0xa3, 0x3e, 0xa4, 0xe8, 0xd1, 0xcf, 0x41, 0x33, 0x92,
		0x95, 0x7b, 0x7e, 0x20, 0x6f, 0xa5, 0xda, 0x9b, 0x3c, 0x21, 0x57, 0x9a, 0xca, 0x0c, 0xb4, 0x03,
		0x98, 0xf6, 0x00, 0x92, 0x14, 0x10, 0xed, 0x00, 0xa0, 0x29, 0xeb, 0xb0, 0xe4, 0x10, 0x2c, 0x3a,
		0x02, 0x83, 0x58, 0xb5, 0x26, 0x36, 0x99, 0xf1, 0x3b, 0x9b, 0x7b, 0x89, 0xcd, 0xbe, 0x61, 0x43,
		0x0b, 0x32, 0x6d, 0x39, 0x56, 0x2c, 0x66, 0xb3, 0x27, 0xb5, 0xfe, 0xfc, 0x6e, 0x30, 0xb7, 0x86,
		0x8a, 0xd1, 0x1b, 0x2d, 0x36, 0x6f, 0xa8, 0x98, 0xfc, 0x73, 0x00, 0xbb, 0xb8, 0xe1, 0x17, 0x19,
		0x0c, 0x4c, 0xdb, 0x09, 0x38, 0x9b, 0x0e, 0x24, 0x5b, 0x0b, 0x10, 0x5b, 0x0b, 0xfc, 0x5a, 0x0b,
		0xe8, 0xc2, 0xeb, 0xad, 0xf6, 0x7a, 0x06, 0x62, 0x51, 0x1b, 0x38, 0xbd, 0x0f, 0x84, 0x0f, 0xc4,
		0xd4, 0x83, 0x30, 0xfb, 0x00, 0x9c, 0x8d, 0xfc, 0xfe, 0xfb, 0xb8, 0xc8, 0x7a, 0x8f, 0xf9, 0xfd,
		0x0f, 0x69, 0x8d, 0x07, 0xe4, 0x28, 0x21, 0x6f, 0xff, 0xbe, 0xf1, 0x83, 0xf5, 0x9b, 0xdd, 0xc6,
		0x6e, 0xf9, 0xf9, 0xab, 0xd6, 0x34, 0x94, 0xcd, 0xb0, 0x6b, 0x63, 0xcc, 0x32, 0x81, 0x55, 0x66,
		0x31, 0xca, 0x14, 0x36, 0x19, 0xc7, 0x24, 0xe3, 0x58, 0x64, 0x1c, 0x83, 0x68, 0x5d, 0xdc, 0xa6,
		0x8d, 0x37, 0xe2, 0xb5, 0x63, 0x8e, 0x4d, 0xc6, 0xdf, 0x98, 0x32, 0x42, 0x99, 0x07, 0xa1, 0x04,
		0xa1, 0xdc, 0x4a, 0x42, 0x69, 0xaa, 0xbb, 0x8e, 0xe3, 0xf5, 0xfe, 0x99, 0xce, 0x89, 0x54, 0xee,
		0xd0, 0x0f, 0xb5, 0x39, 0x4b, 0x89, 0xeb, 0x52, 0xbd, 0x1a, 0xc0, 0x54, 0x7c, 0xd2, 0x68, 0xa3,
		0x32, 0xe3, 0x49, 0x52, 0x36, 0x92, 0xa0, 0xec, 0x26, 0x39, 0xd9, 0x4a, 0x62, 0xb2, 0x9e, 0xa4,
		0x64, 0x3d, 0x09, 0xc9, 0x7a, 0x92, 0x51, 0xba, 0x22, 0xff, 0xa6, 0x1b, 0x77, 0x39, 0xb3, 0xa0,
		0x9a, 0x71, 0xc3, 0x9a, 0x2f, 0x87, 0xd9, 0xf7, 0x1b, 0x7e, 0xe8, 0x76, 0x3a, 0x21, 0x1a, 0x0b,
		0x66, 0x51, 0x38, 0x1c, 0x1a, 0xc7, 0x63, 0xdb, 0x01, 0x91, 0x39, 0x22, 0x32, 0x87, 0x44, 0xe6,
		0x98, 0xcc, 0x3a, 0x28, 0xc3, 0x8e, 0xca, 0x9a, 0xc3, 0x5a, 0x74, 0x5c, 0xf6, 0xec, 0x71, 0xc1,
		0x7f, 0xd9, 0xb2, 0x45, 0xbb, 0x0d, 0x5d, 0xad, 0x27, 0x97, 0x53, 0x24, 0x93, 0xd3, 0x26, 0x8f,
		0x53, 0x25, 0x8b, 0x93, 0x27, 0x87, 0x93, 0x27, 0x83, 0x93, 0x27, 0x7f, 0x6f, 0x57, 0xda, 0xa3,
		0xed, 0x06, 0xac, 0xce, 0x3c, 0x1b, 0x84, 0xac, 0x03, 0xb6, 0xd9, 0xf4, 0x93, 0x9f, 0xb9, 0xcc,
		0x3c, 0x7a, 0x60, 0xa7, 0xdc, 0x95, 0x52, 0xbb, 0x54, 0x36, 0xd7, 0xca, 0xe6, 0x62, 0xd9, 0x5c,
		0xad, 0x5d, 0x97, 0x6b, 0xd9, 0xf5, 0xc6, 0xb3, 0x46, 0x76, 0x9e, 0x26, 0x5e, 0x77, 0x03, 0xe1,
		0xf5, 0x03, 0xd1, 0xa7, 0x58, 0x74, 0x73, 0x66, 0x59, 0x25, 0x18, 0xeb, 0x7c, 0xb6, 0xd1, 0xfa,
		0xe9, 0x53, 0xb4, 0x59, 0x9d, 0x9b, 0x43, 0xc1, 0xb6, 0x1e, 0xa0, 0xb0, 0xc8, 0x2f, 0x87, 0x34,
		0xee, 0xfe, 0x19, 0x95, 0x49, 0xc8, 0x25, 0x40, 0x19, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0x03, 0x94,
		0x53, 0x0c, 0xca, 0xd1, 0xb2, 0x03, 0x26, 0x27, 0xa6, 0xca, 0x4c, 0x76, 0xee, 0x9b, 0x0d, 0xce,
		0x44, 0xf6, 0xee, 0x9b, 0x4d, 0x0d, 0x88, 0x0c, 0x44, 0x06, 0x22, 0x03, 0x91, 0xd7, 0x9f, 0x35,
		0xdb, 0x91, 0xca, 0x78, 0xa0, 0xe9, 0x11, 0x70, 0xa9, 0x7a, 0xe2, 0x81, 0xa9, 0x3f, 0x5b, 0x34,
		0x36, 0xea, 0x0c, 0x6d, 0x9b, 0xc3, 0xe6, 0x75, 0xdc, 0x5c, 0x0e, 0x9c, 0xdd, 0x91, 0xb3, 0x3b,
		0x74, 0x76, 0xc7, 0x4e, 0xe3, 0xe0, 0x89, 0x1c, 0x3d, 0xbd, 0x04, 0x63, 0x94, 0x62, 0x1c, 0x92,
		0x6c, 0x99, 0x34, 0xfb, 0x8f, 0xbf, 0x53, 0x48, 0x0a, 0x85, 0x0e, 0xe3, 0x57, 0x33, 0x21, 0x17,
		0xc1, 0x14, 0x0a, 0x18, 0xbe, 0x79, 0xbe, 0x6f, 0x44, 0xa8, 0xdd, 0xd9, 0x69, 0x20, 0x62, 0x5e,
		0xf1, 0x3c, 0x34, 0x68, 0x05, 0x68, 0x05, 0x68, 0x05, 0x68, 0x05, 0x68, 0x05, 0xf9, 0xba, 0x45,
		0xf9, 0xc2, 0xad, 0x80, 0xe9, 0xae, 0x7f, 0x77, 0x37, 0x52, 0x52, 0x3f, 0x72, 0x05, 0x01, 0x5e,
		0x5f, 0x00, 0x20, 0x1b, 0x90, 0x0d, 0xc8, 0x06, 0x64, 0x03, 0xb2, 0x11, 0x09, 0xe0, 0x8c, 0x04,
		0xcc, 0x71, 0x49, 0x8a, 0x30, 0x7e, 0xfd, 0x88, 0x60, 0xc0, 0x7a, 0x53, 0x2e, 0x1e, 0xb4, 0xcb,
		0xce, 0x34, 0x96, 0x5d, 0x04, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8,
		0x06, 0x27, 0xdb, 0x78, 0x89, 0x4d, 0x13, 0xc6, 0xb1, 0x80, 0x55, 0x60, 0x1d, 0xeb, 0x4d, 0xbd,
		0x54, 0xf7, 0xde, 0x40, 0xf6, 0xdc, 0x40, 0x78, 0x21, 0x51, 0x13, 0x85, 0x05, 0x0b, 0x7f, 0x35,
		0x3e, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xf9, 0xba, 0x95, 0x3d, 0xa1,
		0xb4, 0xd4, 0x8f, 0x4c, 0x7c, 0xa3, 0x4c, 0x38, 0x66, 0x63, 0x76, 0xab, 0x9f, 0xbd, 0x90, 0xc1,
		0x65, 0xcc, 0x27, 0xbc, 0x71, 0xf6, 0x7b, 0xfd, 0xb4, 0xf1, 0xa5, 0xd3, 0x6a, 0x5e, 0x5d, 0x9e,
		0x74, 0x5a, 0x27, 0xf5, 0x8b, 0xe6, 0x19, 0xb5, 0xf7, 0xf8, 0xdd, 0x1b, 0x8c, 0xa6, 0x45, 0x76,
		0xae, 0x49, 0xc7, 0x9d, 0xfc, 0xf9, 0x41, 0x3e, 0xe2, 0xd2, 0xd9, 0xff, 0xe5, 0xf4, 0xea, 0xe2,
		0xf2, 0xa4, 0xd5, 0x39, 0x6d, 0x36, 0xcf, 0x1d, 0xf2, 0x4b, 0x1a, 0x7f, 0xdc, 0xd5, 0x79, 0xaf,
		0x5f, 0x60, 0xca, 0x89, 0xa7, 0xbc, 0xd9, 0x6a, 0xfc, 0xda, 0x38, 0xab, 0x5f, 0x36, 0x5b, 0x98,
		0x75, 0x42, 0x07, 0xd3, 0x3c, 0xfb, 0x7a, 0xf2, 0x85, 0x61, 0xc6, 0x49, 0x47, 0x6c, 0x67, 0x8d,
		0xef, 0x65, 0x42, 0xdd, 0x0f, 0xbc, 0x50, 0xbb, 0x77, 0x7e, 0x4f, 0xf6, 0xa5, 0xe8, 0xd1, 0x8b,
		0xfb, 0xc5, 0xe1, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xc9, 0xd7, 0xad,
		0x96, 0x77, 0x42, 0xcb, 0xee, 0xf7, 0xb0, 0x52, 0x62, 0xd0, 0xf6, 0x47, 0x84, 0x43, 0x5e, 0x29,
		0x39, 0x6d, 0xb3, 0xe6, 0x28, 0x4f, 0xf9, 0xa1, 0xe8, 0xfa, 0xaa, 0x17, 0x52, 0xde, 0x72, 0xcb,
		0x53, 0xb7, 0x82, 0x5c, 0x4f, 0xd3, 0x53, 0x5d, 0xe7, 0x9b, 0x54, 0xe4, 0x1e, 0x99, 0x09, 0xe3,
		0x97, 0x47, 0x4d, 0x18, 0xc7, 0xff, 0x1a, 0x78, 0x5d, 0x2d, 0x7d, 0xf5, 0x45, 0xde, 0x46, 0xd6,
		0x9e, 0xdf, 0x05, 0x3d, 0xe7, 0x7c, 0xf3, 0x1e, 0x76, 0xde, 0xe4, 0x68, 0xfb, 0x29, 0xa7, 0xde,
		0x0a, 0x3f, 0x64, 0x73, 0xb4, 0x36, 0x34, 0xee, 0x9b, 0xcd, 0x90, 0xaa, 0x9e, 0x68, 0x82, 0x54,
		0xd1, 0xd4, 0x15, 0x85, 0xae, 0x85, 0xae, 0x85, 0xae, 0x85, 0xae, 0x85, 0xae, 0x5d, 0xb2, 0x6e,
		0x47, 0x52, 0xe9, 0xc3, 0x22, 0x83, 0xa4, 0xad, 0x42, 0x52, 0x42, 0x52, 0x42, 0x52, 0x42, 0x52,
		0x66, 0xc0, 0xe4, 0x4a, 0xc5, 0x5a, 0xa9, 0x56, 0xa9, 0x16, 0x6b, 0x10, 0x92, 0x10, 0x92, 0xbb,
		0x2c, 0x24, 0x69, 0x05, 0x08, 0x6d, 0x25, 0x6c, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48,
		0xc8, 0xc8, 0x25, 0xeb, 0x76, 0xda, 0x5d, 0x9f, 0xdc, 0x86, 0xe3, 0xd4, 0xe7, 0x23, 0xda, 0xa3,
		0x56, 0x5a, 0x04, 0x8a, 0x5c, 0x4e, 0x3a, 0x7f, 0xed, 0xef, 0x5f, 0xe7, 0xdd, 0x9a, 0xe7, 0xf6,
		0xeb, 0xee, 0xd7, 0xf6, 0x8f, 0xc2, 0xc7, 0xd2, 0xf8, 0xf8, 0xe0, 0x47, 0x75, 0xfc, 0xfa, 0x87,
		0x4f, 0xcb, 0xde, 0x56, 0xf8, 0x58, 0x1d, 0x1f, 0xaf, 0xf8, 0x4d, 0x65, 0x7c, 0xfc, 0xc6, 0xef,
		0x28, 0x8f, 0xf7, 0x13, 0x6f, 0x9d, 0xfc, 0xbc, 0xb8, 0xea, 0x03, 0xa5, 0x15, 0x1f, 0x38, 0x5c,
		0xf5, 0x81, 0xc3, 0x15, 0x1f, 0x58, 0x79, 0x49, 0xc5, 0x15, 0x1f, 0x28, 0x8f, 0x9f, 0x12, 0xef,
		0xdf, 0x5f, 0xfe, 0xd6, 0xca, 0xf8, 0xe0, 0x69, 0xd5, 0xef, 0xaa, 0xe3, 0xa7, 0xe3, 0x83, 0x83,
		0xdc, 0x7e, 0xa1, 0x78, 0x9d, 0x77, 0x8f, 0xda, 0x4f, 0x85, 0xeb, 0xbc, 0x5b, 0x68, 0x4f, 0xde,
		0xd9, 0x7e, 0xba, 0x2e, 0xb8, 0xb5, 0xf9, 0xcb, 0xc9, 0xff, 0x1e, 0xfc, 0x8f, 0xce, 0x71, 0xb5,
		0x29, 0x2d, 0xbe, 0x79, 0xd1, 0xf8, 0x03, 0x66, 0x0f, 0xb3, 0x4f, 0x81, 0xd9, 0x43, 0x8d, 0xbd,
		0x79, 0xe1, 0xcc, 0x8e, 0x85, 0x5a, 0xed, 0xa5, 0xba, 0x92, 0x10, 0xbc, 0x1c, 0x1c, 0xba, 0x0c,
		0xba, 0x0c, 0xba, 0x0c, 0xba, 0x0c, 0xba, 0x8c, 0x7c, 0xdd, 0xa2, 0x3e, 0x66, 0xca, 0x47, 0xb0,
		0xdd, 0xe2, 0xa3, 0xae, 0x94, 0xaf, 0x3d, 0x2d, 0x89, 0x2a, 0x53, 0x38, 0x61, 0xf7, 0x6f, 0x71,
		0xe7, 0xcd, 0x2a, 0x72, 0x3b, 0x39, 0x7f, 0x28, 0x54, 0x77, 0x0a, 0x94, 0x13, 0xff, 0x91, 0x9b,
		0xfc, 0x17, 0xc8, 0x9b, 0x9c, 0xd7, 0x97, 0x6e, 0xe8, 0xf5, 0x65, 0x18, 0xbf, 0xca, 0x4d, 0x23,
		0x08, 0x23, 0x25, 0xbb, 0x5e, 0xa8, 0x73, 0x4a, 0xc8, 0xdb, 0xbf, 0x6f, 0xfc, 0x20, 0x8c, 0x5f,
		0xe5, 0xbc, 0xde, 0x3f, 0x53, 0x37, 0x24, 0x95, 0x3b, 0xf4, 0x43, 0x9d, 0x9b, 0x52, 0x8b, 0x30,
		0xfa, 0x27, 0x2a, 0x5d, 0x82, 0xfe, 0x57, 0xc9, 0xc7, 0x31, 0x52, 0xdf, 0x95, 0xff, 0xaf, 0x72,
		0x3d, 0xad, 0x03, 0x79, 0x33, 0x99, 0x31, 0xba, 0x66, 0x58, 0x4b, 0xc6, 0x46, 0x67, 0xac, 0xb4,
		0x32, 0x3e, 0x74, 0xc6, 0xca, 0x26, 0xa3, 0x43, 0x67, 0xac, 0xb5, 0x66, 0x8d, 0xac, 0x33, 0x56,
		0xc2, 0x49, 0xd2, 0x4b, 0xf5, 0xe4, 0x25, 0xd0, 0x0a, 0xf6, 0x02, 0x04, 0x3b, 0x04, 0x3b, 0x04,
		0x3b, 0x04, 0x7b, 0x7a, 0x04, 0x3b, 0x95, 0xfb, 0x8f, 0x07, 0x9c, 0xf6, 0x81, 0xd2, 0xd4, 0x61,
		0x82, 0xbd, 0x44, 0x9f, 0xc4, 0xe9, 0x25, 0x10, 0x9b, 0x2e, 0x4f, 0x12, 0x1f, 0x39, 0x1c, 0x70,
		0xc2, 0x42, 0x3a, 0xe0, 0x81, 0x1b, 0x26, 0x52, 0x03, 0x17, 0xa9, 0x81, 0x8d, 0xd4, 0xc0, 0x07,
		0x2d, 0x8c, 0x10, 0xc3, 0x49, 0x3c, 0xcb, 0x97, 0x1c, 0x0e, 0x7e, 0x8f, 0xb7, 0x1c, 0x72, 0x82,
		0xed, 0x57, 0x19, 0xc6, 0x4e, 0x74, 0xcc, 0x7f, 0x06, 0xbb, 0x8c, 0xa6, 0x2d, 0x13, 0x9a, 0x36,
		0x51, 0x93, 0xfd, 0x95, 0x36, 0x4d, 0xd1, 0x74, 0x9f, 0x59, 0xbb, 0x82, 0xb4, 0x80, 0xb4, 0x80,
		0xb4, 0x80, 0xb4, 0x70, 0x90, 0x16, 0x6a, 0x2d, 0xbc, 0xa8, 0x89, 0x07, 0x82, 0xf1, 0x44, 0xe3,
		0x82, 0x34, 0x9e, 0x5c, 0xc9, 0xc7, 0x9d, 0x3c, 0xe6, 0xc6, 0x05, 0x3a, 0x69, 0x00, 0x9f, 0x74,
		0x81, 0x50, 0x5a, 0xc0, 0x28, 0x75, 0xa0, 0x94, 0x3a, 0x70, 0x4a, 0x1d, 0x48, 0xf1, 0x80, 0x15,
		0x13, 0x68, 0xf1, 0x2b, 0xee, 0x84, 0xdf, 0x18, 0x49, 0xa5, 0x0b, 0x15, 0x4e, 0x9f, 0x31, 0x43,
		0x91, 0x0a, 0xe3, 0x25, 0xf0, 0x14, 0x62, 0x78, 0xfd, 0x87, 0xd7, 0x67, 0xee, 0x71, 0x17, 0x6a,
		0x48, 0x19, 0xbd, 0x48, 0x5c, 0x0e, 0x73, 0x21, 0x87, 0xc4, 0xf5, 0xa4, 0xe0, 0x70, 0x7d, 0x4a,
		0xdc, 0xe9, 0xa2, 0x09, 0x7b, 0x0f, 0x30, 0xe1, 0x9f, 0x98, 0x70, 0xa5, 0x5c, 0x3e, 0x2c, 0xc3,
		0x8c, 0xd3, 0xc5, 0x45, 0xf8, 0x47, 0x6f, 0x7f, 0xd8, 0x8d, 0xfb, 0xe5, 0xa8, 0x47, 0xc3, 0xb7,
		0x93, 0xbe, 0x3c, 0x6c, 0xc0, 0xb0, 0xa3, 0x8e, 0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e,
		0x80, 0xb8, 0x41, 0x46, 0xe2, 0x06, 0x47, 0x29, 0x08, 0x1b, 0x94, 0x11, 0x36, 0x40, 0xd8, 0x00,
		0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0xb0, 0x6e, 0xc2, 0xc5, 0x32, 0x82, 0x06, 0x08, 0x1a, 0x20,
		0x68, 0x40, 0x1b, 0x34, 0xb8, 0x9f, 0xad, 0xbe, 0x34, 0x44, 0x0d, 0xa2, 0x6b, 0x41, 0xd8, 0x00,
		0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x83, 0x77, 0xfa, 0x8d, 0x1b, 0xa9,
		0xbc, 0xe0, 0x31, 0x05, 0x71, 0x83, 0x1a, 0xe3, 0x25, 0x9c, 0x0a, 0x75, 0x3b, 0x4d, 0xfc, 0x47,
		0xe0, 0x00, 0x81, 0x83, 0x9f, 0xaa, 0xae, 0x02, 0x34, 0x17, 0x02, 0x07, 0xdb, 0x6d, 0xc2, 0xc8,
		0x37, 0x40, 0xe8, 0x00, 0xa1, 0x03, 0x52, 0x33, 0x17, 0x0f, 0x5a, 0xa8, 0x9e, 0xe8, 0xf1, 0x07,
		0x0e, 0xe2, 0x2b, 0x41, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61,
		0x83, 0xf7, 0x86, 0x0d, 0xc8, 0xeb, 0xc5, 0xae, 0x82, 0x11, 0xa2, 0xfa, 0xb1, 0xbb, 0x49, 0x5a,
		0xfc, 0xe1, 0x84, 0x99, 0x7b, 0x03, 0x7e, 0xd2, 0x12, 0x5f, 0x09, 0x48, 0x0b, 0x48, 0x0b, 0x48,
		0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x4b, 0x72, 0x8e, 0x87, 0x5e, 0xa0,
		0x65, 0x1a, 0x38, 0xcb, 0xfc, 0x42, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59,
		0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x92, 0x73, 0xac, 0x03, 0x4f, 0x85, 0x52, 0xcb, 0xfb, 0x14,
		0xe4, 0x95, 0xbe, 0xb8, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10,
		0x17, 0x10, 0x97, 0xd4, 0x13, 0x97, 0x4c, 0x97, 0x17, 0x25, 0x6e, 0x50, 0x98, 0x18, 0x9f, 0xa7,
		0x61, 0x61, 0xb2, 0x37, 0x5e, 0xf2, 0x47, 0x14, 0x5d, 0x0d, 0xf9, 0x6c, 0x2d, 0x5b, 0x0d, 0x63,
		0x7e, 0x13, 0x8f, 0x1c, 0x15, 0x5f, 0x9c, 0x53, 0x19, 0xea, 0xba, 0xd6, 0xc4, 0xdd, 0x6a, 0xbe,
		0x49, 0x75, 0x32, 0x10, 0x13, 0x3a, 0x10, 0xd2, 0xd2, 0x69, 0xe7, 0x9b, 0xf7, 0xf0, 0x62, 0xe4,
		0xc2, 0x51, 0xa9, 0x54, 0xa9, 0x96, 0x4a, 0xf9, 0xea, 0x61, 0x35, 0x5f, 0x2b, 0x97, 0x0b, 0x95,
		0x02, 0x61, 0xf6, 0xab, 0xd3, 0x0c, 0x7a, 0x22, 0x10, 0xbd, 0xcf, 0x93, 0x47, 0xaf, 0x46, 0x83,
		0x41, 0xa6, 0x2c, 0x9a, 0xc9, 0x2f, 0xa7, 0xd8, 0x1f, 0x3b, 0xa4, 0x2d, 0x15, 0x82, 0x51, 0x57,
		0xab, 0x19, 0xe9, 0xfa, 0x7c, 0x3b, 0xec, 0xb4, 0xe4, 0x4d, 0xa7, 0xde, 0x97, 0x17, 0x5e, 0x5f,
		0x76, 0x1a, 0xc3, 0xfb, 0xca, 0x55, 0x74, 0xa7, 0x9d, 0xb3, 0xd9, 0xfd, 0x75, 0xea, 0xbd, 0x7f,
		0x5a, 0xf2, 0xa6, 0xa1, 0xce, 0xfd, 0x50, 0x77, 0x5a, 0x93, 0xbb, 0xea, 0x5c, 0x45, 0xb7, 0x50,
		0x8f, 0xef, 0x00, 0x2d, 0x99, 0xf9, 0x57, 0xd8, 0x8e, 0xb4, 0x64, 0x5e, 0xd2, 0xfd, 0x77, 0x5b,
		0xfb, 0x33, 0x7f, 0xd8, 0x22, 0x2b, 0x9b, 0x33, 0x91, 0x28, 0x8c, 0xb1, 0x37, 0x79, 0xea, 0xae,
		0xb4, 0x95, 0x12, 0x4e, 0x43, 0x3f, 0xe8, 0xe8, 0x06, 0x2b, 0xbd, 0xa0, 0xa1, 0x13, 0xb6, 0xcc,
		0x8e, 0xc8, 0xa9, 0xf1, 0x38, 0x33, 0x8b, 0xc8, 0x6f, 0x06, 0xe9, 0xed, 0xb8, 0x56, 0xf3, 0x8e,
		0xcf, 0xec, 0x37, 0x1a, 0xb6, 0x65, 0xdb, 0x36, 0x4c, 0x6d, 0xbb, 0x66, 0x8d, 0xc2, 0xdc, 0xa3,
		0x33, 0xf3, 0x4d, 0x86, 0x1e, 0xbe, 0xad, 0x87, 0x4e, 0xf6, 0xb0, 0x0d, 0xfa, 0xa6, 0x4d, 0x7d,
		0x91, 0x19, 0x83, 0xdb, 0xdc, 0x3c, 0x0c, 0x98, 0x86, 0xf3, 0x72, 0x96, 0x03, 0x73, 0xb1, 0xf7,
		0xe7, 0x2a, 0x3f, 0x8b, 0xdf, 0x6f, 0xc8, 0x98, 0xcd, 0x76, 0xa5, 0x33, 0xbe, 0x63, 0x6a, 0x63,
		0x07, 0xd4, 0xee, 0x8e, 0xa6, 0xad, 0x1d, 0x4a, 0xeb, 0x3b, 0x8e, 0xd6, 0x77, 0x10, 0xad, 0xef,
		0x08, 0xa6, 0x0b, 0x26, 0x4c, 0x77, 0x41, 0x73, 0x66, 0x18, 0x6d, 0xdc, 0xb0, 0xe6, 0xcb, 0x61,
		0xf6, 0xfd, 0x86, 0x1f, 0xba, 0x9d, 0xb6, 0x97, 0xcf, 0x8e, 0xa6, 0x68, 0xf8, 0x8b, 0x2d, 0xa6,
		0x5c, 0xd0, 0xa4, 0x52, 0xd8, 0x4e, 0x91, 0x20, 0x4b, 0x7d, 0x20, 0x4b, 0x69, 0x20, 0x4b, 0x55,
		0x48, 0xb7, 0x98, 0xb1, 0xd5, 0xb6, 0x31, 0x72, 0x2c, 0xf6, 0xec, 0x71, 0xc1, 0x7f, 0xd9, 0xb2,
		0x45, 0xbb, 0xdd, 0x7b, 0xad, 0x67, 0x9a, 0x51, 0x64, 0x92, 0xd1, 0x66, 0x8a, 0x51, 0x65, 0x82,
		0x91, 0x67, 0x7a, 0x91, 0x67, 0x72, 0x91, 0x67, 0x6a, 0x6d, 0x57, 0x78, 0xdc, 0x76, 0x37, 0x5b,
		0x67, 0x1e, 0x71, 0xb7, 0x6e, 0xc9, 0xcf, 0xa7, 0x91, 0x6c, 0x86, 0xf8, 0x5f, 0xbb, 0x4c, 0xcb,
		0x9b, 0xfd, 0x64, 0x49, 0xba, 0x94, 0xc9, 0xb8, 0x3c, 0x49, 0xb7, 0xd4, 0xc9, 0xb5, 0x6c, 0x49,
		0xb4, 0x6c, 0xc9, 0xb2, 0x6c, 0x49, 0xb1, 0xdb, 0xbd, 0xff, 0x4d, 0x96, 0xcc, 0x1a, 0xaf, 0xbb,
		0x81, 0xf0, 0xfa, 0x81, 0xe8, 0x53, 0x2c, 0xba, 0x39, 0xb3, 0xac, 0x12, 0x8c, 0x75, 0x3e, 0x0b,
		0x2e, 0x7f, 0xfa, 0x14, 0xa5, 0x0a, 0xe6, 0xe6, 0x50, 0xb0, 0xad, 0x1b, 0xed, 0x16, 0xf9, 0xe5,
		0x90, 0xc6, 0xdd, 0x3f, 0xa3, 0x32, 0x09, 0xb9, 0x04, 0x28, 0x03, 0x94, 0x01, 0xca, 0x00, 0x65,
		0x80, 0x72, 0x8a, 0x41, 0x39, 0x5a, 0x76, 0xc0, 0xe4, 0xc4, 0x54, 0x45, 0xe7, 0x1b, 0xc8, 0x20,
		0x39, 0x1a, 0x8e, 0x06, 0x91, 0x0b, 0x40, 0x64, 0x20, 0x32, 0x10, 0x19, 0x88, 0xbc, 0xfe, 0xac,
		0xd9, 0x8e, 0x54, 0xc6, 0x03, 0x4d, 0x0f, 0x2d, 0x49, 0xd5, 0x13, 0x74, 0x47, 0xd3, 0x17, 0x9b,
		0x5d, 0x45, 0x63, 0x53, 0x9d, 0xd4, 0x22, 0x2d, 0x42, 0x40, 0x5e, 0x74, 0x80, 0xa3, 0xc8, 0x00,
		0x6f, 0x51, 0x01, 0xae, 0x22, 0x02, 0xec, 0x45, 0x03, 0xd8, 0x8b, 0x04, 0xb0, 0x17, 0x05, 0xc8,
		0xd6, 0x19, 0x52, 0xf2, 0x43, 0xfe, 0x0c, 0x52, 0x8c, 0x43, 0x92, 0x2d, 0x93, 0x66, 0xff, 0xf1,
		0x77, 0x0a, 0x49, 0xa1, 0xd0, 0x61, 0xfc, 0x6a, 0x26, 0xe4, 0x22, 0x98, 0xca, 0xca, 0x11, 0x3a,
		0x02, 0x66, 0xdd, 0xf5, 0xef, 0xee, 0x46, 0x4a, 0xea, 0x47, 0x2e, 0x76, 0xf1, 0xfa, 0x02, 0x40,
		0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x38, 0x29, 0xc6, 0x1c, 0x97,
		0xa4, 0x08, 0xe3, 0xd7, 0x8f, 0x60, 0x19, 0xeb, 0x4d, 0xb9, 0x78, 0xd0, 0x2e, 0x3b, 0xd3, 0x58,
		0x76, 0x11, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x9c, 0x6c,
		0xe3, 0x25, 0x36, 0x4d, 0x18, 0xc7, 0x02, 0x56, 0x81, 0x75, 0xac, 0x37, 0xf5, 0x52, 0xdd, 0x7b,
		0x03, 0xd9, 0x73, 0x03, 0xe1, 0x85, 0x84, 0x25, 0xb2, 0x62, 0x0b, 0x7f, 0x35, 0x3e, 0xb8, 0x06,
		0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xf9, 0xba, 0x95, 0x3d, 0xa1, 0xb4, 0xd4, 0x8f,
		0x4c, 0x7c, 0x83, 0xb2, 0xe0, 0x65, 0x63, 0x76, 0xab, 0x9f, 0xbd, 0x90, 0xc1, 0x65, 0xcc, 0x27,
		0xbc, 0x71, 0xf6, 0x7b, 0xfd, 0xb4, 0xf1, 0xa5, 0xd3, 0x6a, 0x5e, 0x5d, 0x9e, 0x74, 0x5a, 0x27,
		0xf5, 0x8b, 0xe6, 0x19, 0xb5, 0xf7, 0x98, 0x36, 0xdc, 0x0f, 0x9d, 0xe3, 0xbd, 0x6b, 0xf2, 0x8a,
		0xc5, 0xcc, 0x6d, 0x24, 0xe6, 0xb3, 0xff, 0xcb, 0xe9, 0xd5, 0xc5, 0xe5, 0x49, 0xab, 0x73, 0xda,
		0x6c, 0x9e, 0x3b, 0xbb, 0xd0, 0xcc, 0x23, 0x25, 0xf3, 0x5e, 0xbf, 0xc0, 0x94, 0x13, 0x4f, 0x79,
		0xb3, 0xd5, 0xf8, 0xb5, 0x71, 0x56, 0xbf, 0x6c, 0xb6, 0x30, 0xeb, 0x84, 0x0e, 0xa6, 0x79, 0xf6,
		0xf5, 0xe4, 0x8b, 0x93, 0xf1, 0x72, 0xfb, 0xed, 0xac, 0xf1, 0xbd, 0x4c, 0xa8, 0xfb, 0x81, 0x17,
		0x6a, 0xf7, 0xce, 0xef, 0xc9, 0xbe, 0x14, 0x3d, 0x7a, 0x71, 0xbf, 0x38, 0x3c, 0xb4, 0x3d, 0xb4,
		0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xf9, 0xba, 0xd5, 0xf2, 0x4e, 0x68, 0xd9, 0xfd, 0x1e,
		0x56, 0x4a, 0x0c, 0xda, 0xfe, 0x88, 0x70, 0xc8, 0x2b, 0x25, 0xa7, 0x35, 0xaf, 0x1d, 0xe5, 0x29,
		0x3f, 0x14, 0x5d, 0x5f, 0xf5, 0x42, 0xca, 0x5b, 0x6e, 0x79, 0xea, 0x56, 0x90, 0xeb, 0x69, 0x86,
		0x7e, 0x43, 0xdf, 0xa4, 0xe2, 0xeb, 0x05, 0xc9, 0xdc, 0x81, 0x71, 0x1a, 0x35, 0x61, 0x1c, 0xff,
		0x6b, 0xe0, 0x75, 0xb5, 0xf4, 0xd5, 0x17, 0x79, 0x1b, 0x59, 0x7b, 0x7e, 0x27, 0xba, 0x90, 0x7e,
		0xf3, 0x1e, 0x76, 0xde, 0xe4, 0x78, 0x5b, 0x05, 0xa5, 0xce, 0x0a, 0x33, 0xda, 0x54, 0xac, 0x0d,
		0x8d, 0xfb, 0x66, 0x33, 0xa4, 0x2a, 0x54, 0x96, 0x20, 0x55, 0x34, 0x05, 0xcb, 0xa0, 0x6b, 0xa1,
		0x6b, 0xa1, 0x6b, 0xa1, 0x6b, 0xa1, 0x6b, 0x97, 0xac, 0xdb, 0x91, 0x54, 0xfa, 0xb0, 0xc8, 0x20,
		0x69, 0xab, 0x90, 0x94, 0x90, 0x94, 0x90, 0x94, 0x90, 0x94, 0x19, 0x30, 0xb9, 0x52, 0xb1, 0x56,
		0xaa, 0x55, 0xaa, 0xc5, 0x1a, 0x84, 0x24, 0x84, 0xe4, 0x2e, 0x0b, 0x49, 0x5a, 0x01, 0x42, 0x5b,
		0x62, 0x13, 0x32, 0x12, 0x32, 0x12, 0x32, 0x12, 0x32, 0x12, 0x32, 0x72, 0xc9, 0xba, 0x9d, 0xb6,
		0x2a, 0x24, 0xb7, 0xe1, 0x38, 0xf5, 0xf9, 0x88, 0xf6, 0xa8, 0x95, 0x16, 0x81, 0x22, 0x97, 0x93,
		0xce, 0x5f, 0xfb, 0xfb, 0xd7, 0x79, 0xb7, 0xe6, 0xb9, 0xfd, 0xba, 0xfb, 0xb5, 0xfd, 0xa3, 0xf0,
		0xb1, 0x34, 0x3e, 0x3e, 0xf8, 0x51, 0x1d, 0xbf, 0xfe, 0xe1, 0xd3, 0xb2, 0xb7, 0x15, 0x3e, 0x56,
		0xc7, 0xc7, 0x2b, 0x7e, 0x53, 0x19, 0x1f, 0xbf, 0xf1, 0x3b, 0xca, 0xe3, 0xfd, 0xc4, 0x5b, 0x27,
		0x3f, 0x2f, 0xae, 0xfa, 0x40, 0x69, 0xc5, 0x07, 0x0e, 0x57, 0x7d, 0xe0, 0x70, 0xc5, 0x07, 0x56,
		0x5e, 0x52, 0x71, 0xc5, 0x07, 0xca, 0xe3, 0xa7, 0xc4, 0xfb, 0xf7, 0x97, 0xbf, 0xb5, 0x32, 0x3e,
		0x78, 0x5a, 0xf5, 0xbb, 0xea, 0xf8, 0xe9, 0xf8, 0xe0, 0x20, 0xb7, 0x5f, 0x28, 0x5e, 0xe7, 0xdd,
		0xa3, 0xf6, 0x53, 0xe1, 0x3a, 0xef, 0x16, 0xda, 0x93, 0x77, 0xb6, 0x9f, 0xae, 0x0b, 0x6e, 0x6d,
		0xfe, 0x72, 0xf2, 0xbf, 0x07, 0xff, 0xa3, 0x73, 0x5c, 0x6d, 0x4a, 0x8b, 0x6f, 0x5e, 0x34, 0xfe,
		0x80, 0xd9, 0xc3, 0xec, 0x53, 0x60, 0xf6, 0x50, 0x63, 0x6f, 0x5e, 0x38, 0xb3, 0x63, 0xa1, 0x56,
		0x9b, 0xb4, 0xad, 0x24, 0x04, 0x2f, 0x07, 0x87, 0x2e, 0x83, 0x2e, 0x83, 0x2e, 0x83, 0x2e, 0x83,
		0x2e, 0x23, 0x5f, 0xb7, 0x37, 0xbe, 0x3f, 0x10, 0x9e, 0xe2, 0xd0, 0x64, 0x85, 0xac, 0x40, 0xf5,
		0x56, 0xd7, 0x0e, 0xaf, 0x2b, 0xe5, 0x6b, 0x4f, 0x4b, 0xa2, 0xca, 0x14, 0x4e, 0xd8, 0xfd, 0x5b,
		0xdc, 0x79, 0xc3, 0x59, 0x39, 0x92, 0x9c, 0x3f, 0x14, 0xaa, 0x3b, 0x05, 0xca, 0x89, 0xff, 0xc8,
		0x4d, 0xfe, 0x0b, 0xe4, 0x4d, 0xce, 0xeb, 0x4b, 0x37, 0xf4, 0xfa, 0x32, 0x8c, 0x5f, 0xe5, 0xa6,
		0x11, 0x84, 0x91, 0x92, 0x5d, 0x2f, 0xd4, 0x39, 0x25, 0xe4, 0xed, 0xdf, 0x37, 0x7e, 0x10, 0xc6,
		0xaf, 0x72, 0x8b, 0x6d, 0xf2, 0x73, 0x51, 0x53, 0xeb, 0xe8, 0x9f, 0xa8, 0x72, 0x09, 0xfa, 0x6a,
		0x24, 0x9f, 0xc6, 0x48, 0x7d, 0x57, 0xfe, 0xbf, 0xca, 0xf5, 0xb4, 0x0e, 0xe4, 0x8d, 0x95, 0x36,
		0xe3, 0x2b, 0x5d, 0xcf, 0x92, 0xb1, 0xd1, 0x71, 0x23, 0xad, 0x84, 0x0f, 0x1d, 0x37, 0xb2, 0x49,
		0xe8, 0xd0, 0x71, 0x63, 0xad, 0x59, 0x23, 0xeb, 0xb8, 0x91, 0x70, 0x92, 0xf4, 0x4a, 0x3d, 0x79,
		0x09, 0xb4, 0x7a, 0xbd, 0x00, 0xbd, 0x0e, 0xbd, 0x0e, 0xbd, 0x0e, 0xbd, 0x9e, 0x1e, 0xbd, 0x4e,
		0xe5, 0xfe, 0xe3, 0x01, 0xa7, 0xfd, 0x25, 0x34, 0x75, 0x94, 0x60, 0x2f, 0xd1, 0x7f, 0x69, 0x7a,
		0x09, 0xc4, 0xa6, 0xcb, 0x93, 0xc3, 0x47, 0x0e, 0x07, 0x9c, 0xb0, 0x90, 0x0e, 0x78, 0xe0, 0x86,
		0x89, 0xd4, 0xc0, 0x45, 0x6a, 0x60, 0x23, 0x35, 0xf0, 0x41, 0x0b, 0x23, 0xc4, 0x70, 0x12, 0xcf,
		0xf2, 0x25, 0x87, 0x83, 0xdf, 0xe3, 0xad, 0x86, 0x9c, 0x60, 0xfb, 0x55, 0x86, 0xb1, 0x13, 0x9d,
		0x78, 0x9f, 0xc1, 0x2e, 0xa3, 0x59, 0xcb, 0x84, 0xa6, 0x4d, 0xd4, 0xbc, 0x77, 0xa5, 0x4d, 0x53,
		0x34, 0xf3, 0x65, 0xd6, 0xae, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x1c, 0xa4, 0x85,
		0x5a, 0x0b, 0x2f, 0x6a, 0xe2, 0x81, 0x60, 0x3c, 0xd0, 0xb8, 0x20, 0x8d, 0x27, 0x57, 0xf2, 0x71,
		0x27, 0x4f, 0xb9, 0x71, 0x81, 0x4e, 0x1a, 0xc0, 0x27, 0x5d, 0x20, 0x94, 0x16, 0x30, 0x4a, 0x1d,
		0x28, 0xa5, 0x0e, 0x9c, 0x52, 0x07, 0x52, 0x3c, 0x60, 0xc5, 0x04, 0x5a, 0xfc, 0x8a, 0x3b, 0xe1,
		0x37, 0x46, 0x52, 0xe9, 0x42, 0x85, 0xd3, 0x67, 0xcc, 0x50, 0xa4, 0xc2, 0x78, 0x09, 0x3c, 0x75,
		0x18, 0x5e, 0xff, 0xe1, 0xf5, 0x99, 0x7b, 0xdc, 0x75, 0x1a, 0x52, 0x46, 0x2f, 0x12, 0x97, 0xc3,
		0x5c, 0xc7, 0x21, 0x71, 0x3d, 0x29, 0x38, 0x5b, 0x9f, 0x12, 0x77, 0xba, 0x68, 0xc2, 0xde, 0x03,
		0x4c, 0xf8, 0x27, 0x26, 0x5c, 0x29, 0x97, 0x0f, 0xcb, 0x30, 0xe3, 0x74, 0x71, 0x11, 0xfe, 0xd1,
		0xdb, 0x1f, 0x76, 0xe3, 0x7e, 0x39, 0xca, 0xd1, 0xf0, 0xed, 0xa4, 0x2f, 0x0f, 0x1b, 0x30, 0xec,
		0xa8, 0x23, 0x6e, 0x80, 0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e, 0x90, 0x91, 0xb8, 0xc1,
		0x51, 0x0a, 0xc2, 0x06, 0x65, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d,
		0xac, 0x9b, 0x70, 0xb1, 0x8c, 0xa0, 0x01, 0x82, 0x06, 0x08, 0x1a, 0xd0, 0x06, 0x0d, 0xee, 0x67,
		0xab, 0x2f, 0x0d, 0x51, 0x83, 0xe8, 0x5a, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d,
		0x10, 0x36, 0x40, 0xd8, 0xe0, 0x9d, 0x7e, 0xe3, 0x46, 0x2a, 0x2f, 0x78, 0x4c, 0x41, 0xdc, 0xa0,
		0xc6, 0x78, 0x09, 0xa7, 0x42, 0xdd, 0x4e, 0x13, 0xff, 0x11, 0x38, 0x40, 0xe0, 0xe0, 0xa7, 0xaa,
		0xab, 0x00, 0xcd, 0x85, 0xc0, 0xc1, 0x76, 0x9b, 0x30, 0xf2, 0x0d, 0x10, 0x3a, 0x40, 0xe8, 0x80,
		0xd4, 0xcc, 0xc5, 0x83, 0x16, 0xaa, 0x27, 0x7a, 0xfc, 0x81, 0x83, 0xf8, 0x4a, 0x10, 0x36, 0x40,
		0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0xe0, 0xbd, 0x61, 0x03, 0xf2, 0x72,
		0xb1, 0xab, 0x60, 0x84, 0xa8, 0x7c, 0xec, 0x6e, 0x92, 0x16, 0x7f, 0x38, 0x61, 0xe6, 0xde, 0x80,
		0x9f, 0xb4, 0xc4, 0x57, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2,
		0x02, 0xd2, 0x02, 0xd2, 0x92, 0x9c, 0xe3, 0xa1, 0x17, 0x68, 0x99, 0x06, 0xce, 0x32, 0xbf, 0x10,
		0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x96,
		0xe4, 0x1c, 0xeb, 0xc0, 0x53, 0xa1, 0xd4, 0xf2, 0x3e, 0x05, 0x79, 0xa5, 0x2f, 0xae, 0x05, 0xc4,
		0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x25, 0xf5, 0xc4, 0x25,
		0xd3, 0xe5, 0x45, 0x89, 0xfb, 0x13, 0x26, 0xc6, 0x67, 0xe9, 0x57, 0x98, 0x6c, 0x8d, 0x97, 0xfc,
		0x11, 0x45, 0x53, 0x43, 0x3e, 0x53, 0xcb, 0x56, 0xbf, 0x98, 0xdf, 0xc4, 0x23, 0x47, 0xc1, 0x17,
		0xe7, 0x54, 0x86, 0xba, 0xae, 0x35, 0x71, 0xb3, 0x9a, 0x6f, 0x52, 0x9d, 0x0c, 0xc4, 0x84, 0x0d,
		0x84, 0xb4, 0x6c, 0xda, 0xf9, 0xe6, 0x3d, 0xbc, 0x18, 0xb9, 0x70, 0x54, 0x2a, 0x55, 0xaa, 0xa5,
		0x52, 0xbe, 0x7a, 0x58, 0xcd, 0xd7, 0xca, 0xe5, 0x42, 0xa5, 0x40, 0x98, 0xfc, 0xea, 0x34, 0x83,
		0x9e, 0x08, 0x44, 0xef, 0xf3, 0xe4, 0xd1, 0xab, 0xd1, 0x60, 0x90, 0x29, 0x8b, 0x66, 0x72, 0xcb,
		0xe9, 0x75, 0xc7, 0x0e, 0x69, 0x43, 0x85, 0x60, 0xd4, 0xd5, 0x6a, 0x46, 0xb9, 0x3e, 0xdf, 0x0e,
		0x3b, 0x2d, 0x79, 0xd3, 0xa9, 0xf7, 0xe5, 0x85, 0xd7, 0x97, 0x9d, 0xc6, 0xf0, 0xbe, 0x72, 0x15,
		0xdd, 0x68, 0xe7, 0x6c, 0x76, 0x7b, 0x9d, 0x7a, 0xef, 0x9f, 0x96, 0xbc, 0x69, 0xa8, 0xf3, 0x40,
		0x74, 0x5a, 0x93, 0x9b, 0xea, 0x5c, 0x45, 0x77, 0x50, 0x8f, 0x6f, 0x00, 0xed, 0x98, 0xf9, 0xd7,
		0xd7, 0x6e, 0xb4, 0x63, 0x5e, 0xd2, 0xf9, 0x77, 0x5b, 0x7b, 0x33, 0x7f, 0xd8, 0x22, 0x23, 0x9b,
		0xd3, 0x90, 0x28, 0x84, 0xb1, 0x37, 0x79, 0xe8, 0xae, 0xb4, 0x95, 0x0e, 0x4e, 0xc3, 0x3d, 0xe8,
		0xb8, 0x06, 0x2b, 0xb7, 0xa0, 0xe1, 0x12, 0xb6, 0xcc, 0x8e, 0xc8, 0xa7, 0xb1, 0xf8, 0x32, 0x8b,
		0xb0, 0x6f, 0x04, 0xe6, 0xed, 0x38, 0x56, 0xf3, 0x6e, 0xcf, 0xec, 0x37, 0x1a, 0xb6, 0x64, 0xdb,
		0x16, 0x4c, 0x6c, 0xb9, 0x66, 0x6d, 0xc2, 0xdc, 0x93, 0x33, 0xf3, 0x4d, 0x86, 0x9e, 0xbd, 0xad,
		0x67, 0x4e, 0xf5, 0xac, 0x0d, 0x3a, 0xa6, 0x0d, 0x1d, 0x91, 0x19, 0x73, 0xdb, 0xdc, 0x38, 0x0c,
		0x18, 0x86, 0x33, 0x9f, 0x63, 0x7f, 0xa4, 0xdd, 0xa1, 0x1f, 0x6a, 0x63, 0xa6, 0xf1, 0x5c, 0xde,
		0xe7, 0xf5, 0x08, 0x86, 0xcc, 0xd9, 0x6c, 0x43, 0x3a, 0xe3, 0x9b, 0xa5, 0x36, 0x36, 0x3f, 0xed,
		0x6e, 0x66, 0xda, 0xda, 0x9c, 0xb4, 0xbe, 0xd9, 0x68, 0x7d, 0xf3, 0xd0, 0xfa, 0x66, 0x60, 0xba,
		0x80, 0xc2, 0x74, 0x03, 0x34, 0x67, 0x86, 0xd2, 0xc6, 0x0d, 0x6b, 0xbe, 0x1c, 0x66, 0xdf, 0x6f,
		0xf8, 0xa1, 0xdb, 0xe9, 0x78, 0xf9, 0xec, 0x68, 0x8a, 0x86, 0xbf, 0xd8, 0x62, 0xb6, 0x05, 0x4d,
		0x16, 0x85, 0xed, 0xec, 0x08, 0xb2, 0xac, 0x07, 0xb2, 0x6c, 0x06, 0xb2, 0x2c, 0x85, 0x74, 0xab,
		0x19, 0x5b, 0x1d, 0x1b, 0x23, 0xc7, 0x62, 0xcf, 0x1e, 0x17, 0xfc, 0x97, 0x2d, 0x5b, 0xb4, 0xdb,
		0xb8, 0xd7, 0x7a, 0x92, 0x19, 0x45, 0x12, 0x19, 0x6d, 0x92, 0x18, 0x55, 0x12, 0x18, 0x79, 0x92,
		0x17, 0x79, 0x12, 0x17, 0x79, 0x92, 0xd6, 0x76, 0x45, 0xc7, 0x6d, 0x37, 0xb2, 0x75, 0xe6, 0x01,
		0x77, 0xeb, 0x96, 0xfc, 0x7c, 0x10, 0xc9, 0x66, 0x84, 0xff, 0xb5, 0xcb, 0xb4, 0xbc, 0xd1, 0x4f,
		0x96, 0x9f, 0x4b, 0x99, 0x87, 0xcb, 0x93, 0x6f, 0x4b, 0x9d, 0x57, 0xcb, 0x96, 0x3f, 0xcb, 0x96,
		0x27, 0xcb, 0x96, 0x0f, 0xbb, 0xdd, 0xbb, 0xdf, 0x64, 0x79, 0xac, 0xf1, 0xba, 0x1b, 0x08, 0xaf,
		0x1f, 0x88, 0x3e, 0xc5, 0xa2, 0x9b, 0x33, 0xcb, 0x2a, 0xc1, 0x58, 0xe7, 0xb3, 0xf0, 0xf2, 0xa7,
		0x4f, 0x51, 0x9a, 0x60, 0x6e, 0x0e, 0x05, 0xdb, 0xba, 0xcf, 0x6e, 0x91, 0x5f, 0x0e, 0x69, 0xdc,
		0xfd, 0x33, 0x2a, 0x93, 0x90, 0x4b, 0x80, 0x32, 0x40, 0x19, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0xa7,
		0x18, 0x94, 0xa3, 0x65, 0x07, 0x4c, 0x4e, 0x4c, 0x55, 0x74, 0xb6, 0x81, 0x0c, 0x92, 0xa3, 0xe1,
		0x68, 0x10, 0xb9, 0x00, 0x44, 0x06, 0x22, 0x03, 0x91, 0x81, 0xc8, 0xeb, 0xcf, 0x9a, 0xed, 0x48,
		0x65, 0x3c, 0xd0, 0xf4, 0xc0, 0x92, 0x54, 0x3d, 0x41, 0x77, 0x2a, 0x7d, 0xb1, 0xcf, 0x55, 0x34,
		0x36, 0xd5, 0x29, 0x2d, 0xd2, 0xfa, 0x03, 0xe4, 0xf5, 0x06, 0x38, 0xea, 0x0b, 0xf0, 0xd6, 0x13,
		0xe0, 0xaa, 0x1f, 0xc0, 0x5e, 0x2f, 0x80, 0xbd, 0x3e, 0x00, 0x7b, 0x3d, 0x80, 0x6c, 0x9d, 0x1f,
		0x25, 0x3f, 0xdf, 0xcf, 0x20, 0xc5, 0x38, 0x24, 0xd9, 0x32, 0x69, 0xf6, 0x1f, 0x7f, 0xa7, 0x90,
		0x14, 0x0a, 0x1d, 0xc6, 0xaf, 0x66, 0x42, 0x2e, 0x82, 0xa9, 0xac, 0x1c, 0xa0, 0x23, 0x60, 0xd6,
		0x5d, 0xff, 0xee, 0x6e, 0xa4, 0xa4, 0x7e, 0xe4, 0x62, 0x17, 0xaf, 0x2f, 0x00, 0x14, 0x03, 0x14,
		0x03, 0x14, 0x03, 0x14, 0x03, 0x14, 0x03, 0x14, 0x83, 0x93, 0x62, 0xcc, 0x71, 0x49, 0x8a, 0x30,
		0x7e, 0xfd, 0x08, 0x96, 0xb1, 0xde, 0x94, 0x8b, 0x07, 0xed, 0xb2, 0x33, 0x8d, 0x65, 0x17, 0x01,
		0xb6, 0x01, 0xb6, 0x01, 0xb6, 0x01, 0xb6, 0x01, 0xb6, 0x01, 0xb6, 0xc1, 0xc9, 0x36, 0x5e, 0x62,
		0xd3, 0x84, 0x71, 0x2c, 0x60, 0x15, 0x58, 0xc7, 0x7a, 0x53, 0x2f, 0xd5, 0xbd, 0x37, 0x90, 0x3d,
		0x37, 0x10, 0x5e, 0x48, 0x58, 0x1e, 0x2b, 0xb6, 0xf0, 0x57, 0xe3, 0x83, 0x6b, 0x80, 0x6b, 0x80,
		0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x90, 0xaf, 0x5b, 0xd9, 0x13, 0x4a, 0x4b, 0xfd, 0xc8, 0xc4, 0x37,
		0x28, 0x8b, 0x5d, 0x36, 0x66, 0xb7, 0xfa, 0xd9, 0x0b, 0x19, 0x5c, 0xc6, 0x7c, 0xc2, 0x1b, 0x67,
		0xbf, 0xd7, 0x4f, 0x1b, 0x5f, 0x3a, 0xad, 0xe6, 0xd5, 0xe5, 0x49, 0xa7, 0x75, 0x52, 0xbf, 0x68,
		0x9e, 0x51, 0x7b, 0x8f, 0x69, 0xaf, 0xfd, 0xd0, 0x39, 0xde, 0xbb, 0x26, 0x2f, 0x56, 0xcc, 0xdc,
		0x41, 0x62, 0x3e, 0xfb, 0xbf, 0x9c, 0x5e, 0x5d, 0x5c, 0x9e, 0xb4, 0x3a, 0xa7, 0xcd, 0xe6, 0xb9,
		0xb3, 0x0b, 0x7d, 0x3c, 0x52, 0x32, 0xef, 0xf5, 0x0b, 0x4c, 0x39, 0xf1, 0x94, 0x37, 0x5b, 0x8d,
		0x5f, 0x1b, 0x67, 0xf5, 0xcb, 0x66, 0x0b, 0xb3, 0x4e, 0xe8, 0x60, 0x9a, 0x67, 0x5f, 0x4f, 0xbe,
		0x38, 0x19, 0xaf, 0xb4, 0xdf, 0xce, 0x1a, 0xdf, 0xcb, 0x84, 0xba, 0x1f, 0x78, 0xa1, 0x76, 0xef,
		0xfc, 0x9e, 0xec, 0x4b, 0xd1, 0xa3, 0x17, 0xf7, 0x8b, 0xc3, 0x43, 0xdb, 0x43, 0xdb, 0x43, 0xdb,
		0x43, 0xdb, 0x43, 0xdb, 0x93, 0xaf, 0x5b, 0x2d, 0xef, 0x84, 0x96, 0xdd, 0xef, 0x61, 0xa5, 0xc4,
		0xa0, 0xed, 0x8f, 0x08, 0x87, 0xbc, 0x52, 0x72, 0x5a, 0xf2, 0xda, 0x51, 0x9e, 0xf2, 0x43, 0xd1,
		0xf5, 0x55, 0x2f, 0xa4, 0xbc, 0xe5, 0x96, 0xa7, 0x6e, 0x05, 0xb9, 0x9e, 0x66, 0x68, 0x35, 0xf4,
		0x4d, 0x2a, 0xbe, 0x36, 0x90, 0xcc, 0xcd, 0x17, 0xa7, 0x51, 0x13, 0xc6, 0xf1, 0xbf, 0x06, 0x5e,
		0x57, 0x4b, 0x5f, 0x7d, 0x91, 0xb7, 0x91, 0xb5, 0xe7, 0x77, 0xa2, 0x01, 0xe9, 0x37, 0xef, 0x61,
		0xe7, 0x4d, 0x8e, 0xb7, 0x4d, 0x50, 0xea, 0xac, 0x30, 0xa3, 0x0d, 0xc5, 0xda, 0xd0, 0xb8, 0x6f,
		0x36, 0x43, 0xaa, 0x42, 0x65, 0x09, 0x52, 0x45, 0x53, 0xb0, 0x0c, 0xba, 0x16, 0xba, 0x16, 0xba,
		0x16, 0xba, 0x16, 0xba, 0x76, 0xc9, 0xba, 0x1d, 0x49, 0xa5, 0x0f, 0x8b, 0x0c, 0x92, 0xb6, 0x0a,
		0x49, 0x09, 0x49, 0x09, 0x49, 0x09, 0x49, 0x99, 0x01, 0x93, 0x2b, 0x15, 0x6b, 0xa5, 0x5a, 0xa5,
		0x5a, 0xac, 0x41, 0x48, 0x42, 0x48, 0xee, 0xb2, 0x90, 0xa4, 0x15, 0x20, 0xb4, 0x25, 0x36, 0x21,
		0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x97, 0xac, 0xdb, 0x69, 0xb3, 0x42, 0x72,
		0x1b, 0x8e, 0x53, 0x9f, 0x8f, 0x68, 0x8f, 0x5a, 0x69, 0x11, 0x28, 0x72, 0x39, 0xe9, 0xfc, 0xb5,
		0xbf, 0x7f, 0x9d, 0x77, 0x6b, 0x9e, 0xdb, 0xaf, 0xbb, 0x5f, 0xdb, 0x3f, 0x0a, 0x1f, 0x4b, 0xe3,
		0xe3, 0x83, 0x1f, 0xd5, 0xf1, 0xeb, 0x1f, 0x3e, 0x2d, 0x7b, 0x5b, 0xe1, 0x63, 0x75, 0x7c, 0xbc,
		0xe2, 0x37, 0x95, 0xf1, 0xf1, 0x1b, 0xbf, 0xa3, 0x3c, 0xde, 0x4f, 0xbc, 0x75, 0xf2, 0xf3, 0xe2,
		0xaa, 0x0f, 0x94, 0x56, 0x7c, 0xe0, 0x70, 0xd5, 0x07, 0x0e, 0x57, 0x7c, 0x60, 0xe5, 0x25, 0x15,
		0x57, 0x7c, 0xa0, 0x3c, 0x7e, 0x4a, 0xbc, 0x7f, 0x7f, 0xf9, 0x5b, 0x2b, 0xe3, 0x83, 0xa7, 0x55,
		0xbf, 0xab, 0x8e, 0x9f, 0x8e, 0x0f, 0x0e, 0x72, 0xfb, 0x85, 0xe2, 0x75, 0xde, 0x3d, 0x6a, 0x3f,
		0x15, 0xae, 0xf3, 0x6e, 0xa1, 0x3d, 0x79, 0x67, 0xfb, 0xe9, 0xba, 0xe0, 0xd6, 0xe6, 0x2f, 0x27,
		0xff, 0x7b, 0xf0, 0x3f, 0x3a, 0xc7, 0xd5, 0xa6, 0xb4, 0xf8, 0xe6, 0x45, 0xe3, 0x0f, 0x98, 0x3d,
		0xcc, 0x3e, 0x05, 0x66, 0x0f, 0x35, 0xf6, 0xe6, 0x85, 0x33, 0x3b, 0x16, 0x6a, 0xb5, 0x49, 0xdb,
		0x4a, 0x42, 0xf0, 0x72, 0x70, 0xe8, 0x32, 0xe8, 0x32, 0xe8, 0x32, 0xe8, 0x32, 0xe8, 0x32, 0xf2,
		0x75, 0x7b, 0xe3, 0xfb, 0x03, 0xe1, 0x29, 0x0e, 0x4d, 0x56, 0xc8, 0x0a, 0x54, 0x6f, 0x75, 0xed,
		0xf0, 0xba, 0x52, 0xbe, 0xf6, 0xb4, 0x24, 0xaa, 0x4c, 0xe1, 0x84, 0xdd, 0xbf, 0xc5, 0x9d, 0x37,
		0x9c, 0x95, 0x23, 0xc9, 0xf9, 0x43, 0xa1, 0xba, 0x53, 0xa0, 0x9c, 0xf8, 0x8f, 0xdc, 0xe4, 0xbf,
		0x40, 0xde, 0xe4, 0xbc, 0xbe, 0x74, 0x43, 0xaf, 0x2f, 0xc3, 0xf8, 0x55, 0x6e, 0x1a, 0x41, 0x18,
		0x29, 0xd9, 0xf5, 0x42, 0x9d, 0x53, 0x42, 0xde, 0xfe, 0x7d, 0xe3, 0x07, 0x61, 0xfc, 0x2a, 0xf7,
		0xba, 0x51, 0x7e, 0x2e, 0x6a, 0x6b, 0x1d, 0xfd, 0x13, 0xd5, 0x2e, 0x41, 0x67, 0x8d, 0xe4, 0xf3,
		0x18, 0xa9, 0xef, 0xca, 0xff, 0x57, 0xb9, 0x9e, 0xd6, 0x81, 0xbc, 0xb1, 0xd2, 0x68, 0x7c, 0xa5,
		0xf3, 0x59, 0x32, 0x36, 0x7a, 0x6e, 0xa4, 0x95, 0xf2, 0xa1, 0xe7, 0x46, 0x36, 0x29, 0x1d, 0x7a,
		0x6e, 0xac, 0x35, 0x6b, 0x64, 0x3d, 0x37, 0x12, 0x4e, 0x92, 0x5e, 0xab, 0x27, 0x2f, 0x81, 0x56,
		0xb1, 0x17, 0xa0, 0xd8, 0xa1, 0xd8, 0xa1, 0xd8, 0xa1, 0xd8, 0xd3, 0xa3, 0xd8, 0xa9, 0xdc, 0x7f,
		0x3c, 0xe0, 0xb4, 0xc3, 0x84, 0xa6, 0x8e, 0x13, 0xec, 0x25, 0x3a, 0x30, 0x4d, 0x2f, 0x81, 0xd8,
		0x74, 0x79, 0xb2, 0xf8, 0xc8, 0xe1, 0x80, 0x13, 0x16, 0xd2, 0x01, 0x0f, 0xdc, 0x30, 0x91, 0x1a,
		0xb8, 0x48, 0x0d, 0x6c, 0xa4, 0x06, 0x3e, 0x68, 0x61, 0x84, 0x18, 0x4e, 0xe2, 0x59, 0xbe, 0xe4,
		0x70, 0xf0, 0x7b, 0xbc, 0xf5, 0x90, 0x13, 0x6c, 0xbf, 0xca, 0x30, 0x76, 0xa2, 0x17, 0xef, 0x33,
		0xd8, 0x65, 0x34, 0x6f, 0x99, 0xd0, 0xb4, 0x89, 0xda, 0xf7, 0xae, 0xb4, 0x69, 0x8a, 0x76, 0xbe,
		0xcc, 0xda, 0x15, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x85, 0x83, 0xb4, 0x50, 0x6b, 0xe1,
		0x45, 0x4d, 0x3c, 0x10, 0x8c, 0x47, 0x1a, 0x17, 0xa4, 0xf1, 0xe4, 0x4a, 0x3e, 0xee, 0xe4, 0x39,
		0x37, 0x2e, 0xd0, 0x49, 0x03, 0xf8, 0xa4, 0x0b, 0x84, 0xd2, 0x02, 0x46, 0xa9, 0x03, 0xa5, 0xd4,
		0x81, 0x53, 0xea, 0x40, 0x8a, 0x07, 0xac, 0x98, 0x40, 0x8b, 0x5f, 0x71, 0x27, 0xfc, 0xc6, 0x48,
		0x2a, 0x5d, 0xa8, 0x70, 0xfa, 0x8c, 0x19, 0x8a, 0x54, 0x18, 0x2f, 0x81, 0xa7, 0x12, 0xc3, 0xeb,
		0x3f, 0xbc, 0x3e, 0x73, 0x8f, 0xbb, 0x52, 0x43, 0xca, 0xe8, 0x45, 0xe2, 0x72, 0x98, 0x2b, 0x39,
		0x24, 0xae, 0x27, 0x05, 0xa7, 0xeb, 0x53, 0xe2, 0x4e, 0x17, 0x4d, 0xd8, 0x7b, 0x80, 0x09, 0xff,
		0xc4, 0x84, 0x2b, 0xe5, 0xf2, 0x61, 0x19, 0x66, 0x9c, 0x2e, 0x2e, 0xc2, 0x3f, 0x7a, 0xfb, 0xc3,
		0x6e, 0xdc, 0x2f, 0x47, 0x41, 0x1a, 0xbe, 0x9d, 0xf4, 0xe5, 0x61, 0x03, 0x86, 0x1d, 0x75, 0xc4,
		0x0d, 0x10, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x32, 0x12, 0x37, 0x38, 0x4a, 0x41,
		0xd8, 0xa0, 0x8c, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x81, 0x75, 0x13,
		0x2e, 0x96, 0x11, 0x34, 0x40, 0xd0, 0x00, 0x41, 0x03, 0xda, 0xa0, 0xc1, 0xfd, 0x6c, 0xf5, 0xa5,
		0x21, 0x6a, 0x10, 0x5d, 0x0b, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06,
		0x08, 0x1b, 0xbc, 0xd3, 0x6f, 0xdc, 0x48, 0xe5, 0x05, 0x8f, 0x29, 0x88, 0x1b, 0xd4, 0x18, 0x2f,
		0xe1, 0x54, 0xa8, 0xdb, 0x69, 0xe2, 0x3f, 0x02, 0x07, 0x08, 0x1c, 0xfc, 0x54, 0x75, 0x15, 0xa0,
		0xb9, 0x10, 0x38, 0xd8, 0x6e, 0x13, 0x46, 0xbe, 0x01, 0x42, 0x07, 0x08, 0x1d, 0x90, 0x9a, 0xb9,
		0x78, 0xd0, 0x42, 0xf5, 0x44, 0x8f, 0x3f, 0x70, 0x10, 0x5f, 0x09, 0xc2, 0x06, 0x08, 0x1b, 0x20,
		0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0xbc, 0x37, 0x6c, 0x40, 0x5e, 0x30, 0x76, 0x15,
		0x8c, 0x10, 0x15, 0x90, 0xdd, 0x4d, 0xd2, 0xe2, 0x0f, 0x27, 0xcc, 0xdc, 0x1b, 0xf0, 0x93, 0x96,
		0xf8, 0x4a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a,
		0x40, 0x5a, 0x92, 0x73, 0x3c, 0xf4, 0x02, 0x2d, 0xd3, 0xc0, 0x59, 0xe6, 0x17, 0x02, 0xca, 0x02,
		0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x92, 0x9c, 0x63,
		0x1d, 0x78, 0x2a, 0x94, 0x5a, 0xde, 0xa7, 0x20, 0xaf, 0xf4, 0xc5, 0xb5, 0x80, 0xb8, 0x80, 0xb8,
		0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0xa4, 0x9e, 0xb8, 0x64, 0xba, 0xbc,
		0x28, 0x71, 0x87, 0xc2, 0xc4, 0xf8, 0x4c, 0x1d, 0x0b, 0x93, 0xcd, 0xf1, 0x92, 0x3f, 0xa2, 0x68,
		0x6b, 0xc8, 0x67, 0x6c, 0xd9, 0xea, 0x18, 0xf3, 0x9b, 0x78, 0xe4, 0x28, 0xf9, 0xe2, 0x9c, 0xca,
		0x50, 0xd7, 0xb5, 0x26, 0x6e, 0x57, 0xf3, 0x4d, 0xaa, 0x93, 0x81, 0x98, 0xf0, 0x81, 0x90, 0x96,
		0x4f, 0x3b, 0xdf, 0xbc, 0x87, 0x17, 0x23, 0x17, 0x8e, 0x4a, 0xa5, 0x4a, 0xb5, 0x54, 0xca, 0x57,
		0x0f, 0xab, 0xf9, 0x5a, 0xb9, 0x5c, 0xa8, 0x14, 0x08, 0xd3, 0x5f, 0x9d, 0x66, 0xd0, 0x13, 0x81,
		0xe8, 0x7d, 0x9e, 0x3c, 0x7a, 0x35, 0x1a, 0x0c, 0x32, 0x65, 0xd1, 0x4c, 0x8e, 0x39, 0xcd, 0x0e,
		0xd9, 0x21, 0x6d, 0xaa, 0x10, 0x8c, 0xba, 0x5a, 0xcd, 0x68, 0xd7, 0xe7, 0xdb, 0x61, 0xa7, 0x25,
		0x6f, 0x3a, 0xf5, 0xbe, 0xbc, 0xf0, 0xfa, 0xb2, 0xd3, 0x18, 0xde, 0x57, 0xae, 0xa2, 0x5b, 0xed,
		0x9c, 0xcd, 0x6e, 0xb0, 0x53, 0xef, 0xfd, 0xd3, 0x92, 0x37, 0xcd, 0x91, 0x3e, 0xf7, 0x43, 0xdd,
		0x69, 0x4d, 0x6e, 0xab, 0x73, 0x15, 0xdd, 0x43, 0x3d, 0xbe, 0x05, 0xb4, 0x65, 0xe6, 0x5f, 0x63,
		0xbb, 0xd2, 0x96, 0x79, 0x49, 0x07, 0xe0, 0x6d, 0xed, 0xd1, 0xfc, 0x61, 0x8b, 0xcc, 0x6c, 0x4e,
		0x46, 0xa2, 0x50, 0xc6, 0xde, 0xe4, 0xb1, 0xbb, 0xd2, 0x56, 0x5a, 0x38, 0x0d, 0x03, 0xa1, 0x63,
		0x1c, 0xac, 0x0c, 0x83, 0x86, 0x51, 0xd8, 0x32, 0x3b, 0x22, 0xaf, 0xc6, 0xe4, 0xcd, 0x2c, 0x82,
		0xbf, 0x21, 0xb0, 0xb7, 0xe3, 0x5c, 0xcd, 0xbb, 0x3e, 0xb3, 0xdf, 0x68, 0xd8, 0x9a, 0x6d, 0x5b,
		0x31, 0xb9, 0xf5, 0x9a, 0xb5, 0x0a, 0x73, 0xcf, 0xce, 0xcc, 0x37, 0x19, 0x7a, 0xfa, 0xb6, 0x9e,
		0x3a, 0xdd, 0xd3, 0x36, 0xe8, 0x9e, 0x36, 0x76, 0x47, 0x66, 0x4c, 0x6e, 0x73, 0x03, 0x31, 0x60,
		0x1c, 0xce, 0xc2, 0x3c, 0x07, 0xe6, 0xa2, 0xf0, 0xcf, 0xf5, 0x7e, 0x5e, 0x0d, 0x60, 0xc8, 0xa0,
		0xcd, 0x36, 0xa8, 0x33, 0xbe, 0x79, 0x6a, 0x63, 0x33, 0xd4, 0xee, 0xe6, 0xa6, 0xad, 0xcd, 0x4a,
		0xeb, 0x9b, 0x8f, 0xd6, 0x37, 0x13, 0xad, 0x6f, 0x0e, 0xa6, 0x0b, 0x2a, 0x4c, 0x37, 0x44, 0x73,
		0x66, 0x38, 0x6d, 0xdc, 0xb0, 0xe6, 0xcb, 0x61, 0xf6, 0xfd, 0x86, 0x1f, 0xba, 0x9d, 0x0e, 0x98,
		0xcf, 0x8e, 0xa6, 0x68, 0xf8, 0x8b, 0x2d, 0x66, 0x5f, 0xd0, 0x64, 0x55, 0xd8, 0xce, 0x96, 0x20,
		0xcb, 0x82, 0x20, 0xcb, 0x6e, 0x20, 0xcb, 0x5a, 0x48, 0xb7, 0xa2, 0xb1, 0xd5, 0xc1, 0x31, 0x72,
		0x2c, 0xf6, 0xec, 0x71, 0xc1, 0x7f, 0xd9, 0xb2, 0x45, 0xbb, 0x8d, 0x7c, 0xad, 0x27, 0x9d, 0x51,
		0x24, 0x95, 0xd1, 0x26, 0x8d, 0x51, 0x25, 0x85, 0x91, 0x27, 0x7d, 0x91, 0x27, 0x75, 0x91, 0x27,
		0x6d, 0x6d, 0x57, 0x94, 0xdc, 0x76, 0x63, 0x5b, 0x67, 0x1e, 0x78, 0xb7, 0x6e, 0xc9, 0xcf, 0x07,
		0x93, 0x6c, 0x46, 0xfa, 0x5f, 0xbb, 0x4c, 0xcb, 0xdb, 0xfe, 0x64, 0xf9, 0xba, 0x94, 0x79, 0xb9,
		0x3c, 0xf9, 0xb7, 0xd4, 0x79, 0xb6, 0x6c, 0xf9, 0xb4, 0x6c, 0x79, 0xb3, 0x6c, 0xf9, 0xb1, 0xdb,
		0xbd, 0x0f, 0x4e, 0x96, 0xd7, 0x1a, 0xaf, 0xbb, 0x81, 0xf0, 0xfa, 0x81, 0xe8, 0x53, 0x2c, 0xba,
		0x39, 0xb3, 0xac, 0x12, 0x8c, 0x75, 0x3e, 0x0b, 0x30, 0x7f, 0xfa, 0x14, 0x25, 0x0d, 0xe6, 0xe6,
		0x50, 0xb0, 0xad, 0xfb, 0xed, 0x16, 0xf9, 0xe5, 0x90, 0xc6, 0xdd, 0x3f, 0xa3, 0x32, 0x09, 0xb9,
		0x04, 0x28, 0x03, 0x94, 0x01, 0xca, 0x00, 0x65, 0x80, 0x72, 0x8a, 0x41, 0x39, 0x5a, 0x76, 0xc0,
		0xe4, 0xc4, 0x54, 0x45, 0x27, 0x1d, 0xc8, 0x20, 0x39, 0x1a, 0x8e, 0x06, 0x91, 0x0b, 0x40, 0x64,
		0x20, 0x32, 0x10, 0x19, 0x88, 0xbc, 0xfe, 0xac, 0xd9, 0x8e, 0x54, 0xc6, 0x03, 0x4d, 0x8f, 0x2f,
		0x49, 0xd5, 0x13, 0x74, 0xa7, 0xd4, 0x17, 0xfb, 0x5e, 0x45, 0x63, 0x53, 0x9d, 0xd9, 0x22, 0xad,
		0x47, 0x40, 0x5e, 0x7f, 0x80, 0xa3, 0xde, 0x00, 0x6f, 0x7d, 0x01, 0xae, 0x7a, 0x02, 0xec, 0xf5,
		0x03, 0xd8, 0xeb, 0x05, 0xb0, 0xd7, 0x07, 0xc8, 0xd6, 0x69, 0x52, 0xf2, 0xf3, 0xfe, 0x0c, 0x52,
		0x8c, 0x43, 0x92, 0x2d, 0x93, 0x66, 0xff, 0xf1, 0x77, 0x0a, 0x49, 0xa1, 0xd0, 0x61, 0xfc, 0x6a,
		0x26, 0xe4, 0x22, 0x98, 0xca, 0xca, 0x51, 0x3a, 0x02, 0x66, 0xdd, 0xf5, 0xef, 0xee, 0x46, 0x4a,
		0xea, 0x47, 0x2e, 0x76, 0xf1, 0xfa, 0x02, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40,
		0x31, 0x40, 0x31, 0x38, 0x29, 0xc6, 0x1c, 0x97, 0xa4, 0x08, 0xe3, 0xd7, 0x8f, 0x60, 0x19, 0xeb,
		0x4d, 0xb9, 0x78, 0xd0, 0x2e, 0x3b, 0xd3, 0x58, 0x76, 0x11, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b,
		0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x9c, 0x6c, 0xe3, 0x25, 0x36, 0x4d, 0x18, 0xc7, 0x02, 0x56,
		0x81, 0x75, 0xac, 0x37, 0xf5, 0x52, 0xdd, 0x7b, 0x03, 0xd9, 0x73, 0x03, 0xe1, 0x85, 0x84, 0xc5,
		0xb2, 0x62, 0x0b, 0x7f, 0x35, 0x3e, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06,
		0xf9, 0xba, 0x95, 0x3d, 0xa1, 0xb4, 0xd4, 0x8f, 0x4c, 0x7c, 0x83, 0xb2, 0xf4, 0x65, 0x63, 0x76,
		0xab, 0x9f, 0xbd, 0x90, 0xc1, 0x65, 0xcc, 0x27, 0xbc, 0x71, 0xf6, 0x7b, 0xfd, 0xb4, 0xf1, 0xa5,
		0xd3, 0x6a, 0x5e, 0x5d, 0x9e, 0x74, 0x5a, 0x27, 0xf5, 0x8b, 0xe6, 0x19, 0xb5, 0xf7, 0x98, 0xf6,
		0xde, 0x0f, 0x9d, 0xe3, 0xbd, 0x6b, 0xf2, 0xe2, 0xc5, 0xcc, 0x1d, 0x25, 0xe6, 0xb3, 0xff, 0xcb,
		0xe9, 0xd5, 0xc5, 0xe5, 0x49, 0xab, 0x73, 0xda, 0x6c, 0x9e, 0x3b, 0xbb, 0xd0, 0xd7, 0x23, 0x25,
		0xf3, 0x5e, 0xbf, 0xc0, 0x94, 0x13, 0x4f, 0x79, 0xb3, 0xd5, 0xf8, 0xb5, 0x71, 0x56, 0xbf, 0x6c,
		0xb6, 0x30, 0xeb, 0x84, 0x0e, 0xa6, 0x79, 0xf6, 0xf5, 0xe4, 0x8b, 0x93, 0xf1, 0xca, 0xfb, 0xed,
		0xac, 0xf1, 0xbd, 0x4c, 0xa8, 0xfb, 0x81, 0x17, 0x6a, 0xf7, 0xce, 0xef, 0xc9, 0xbe, 0x14, 0x3d,
		0x7a, 0x71, 0xbf, 0x38, 0x3c, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xf9,
		0xba, 0xd5, 0xf2, 0x4e, 0x68, 0xd9, 0xfd, 0x1e, 0x56, 0x4a, 0x0c, 0xda, 0xfe, 0x88, 0x70, 0xc8,
		0x2b, 0x25, 0xa7, 0xa5, 0xaf, 0x1d, 0xe5, 0x29, 0x3f, 0x14, 0x5d, 0x5f, 0xf5, 0x42, 0xca, 0x5b,
		0x6e, 0x79, 0xea, 0x56, 0x90, 0xeb, 0x69, 0x86, 0xd6, 0x43, 0xdf, 0xa4, 0xe2, 0x6b, 0x0b, 0xc9,
		0xdc, 0x8c, 0x71, 0x1a, 0x35, 0x61, 0x1c, 0xff, 0x6b, 0xe0, 0x75, 0xb5, 0xf4, 0xd5, 0x17, 0x79,
		0x1b, 0x59, 0x7b, 0x7e, 0x27, 0x1a, 0x92, 0x7e, 0xf3, 0x1e, 0x76, 0xde, 0xe4, 0x78, 0x9b, 0x06,
		0xa5, 0xce, 0x0a, 0x33, 0xda, 0x5e, 0xac, 0x0d, 0x8d, 0xfb, 0x66, 0x33, 0xa4, 0x2a, 0x54, 0x96,
		0x20, 0x55, 0x34, 0x05, 0xcb, 0xa0, 0x6b, 0xa1, 0x6b, 0xa1, 0x6b, 0xa1, 0x6b, 0xa1, 0x6b, 0x97,
		0xac, 0xdb, 0x91, 0x54, 0xfa, 0xb0, 0xc8, 0x20, 0x69, 0xab, 0x90, 0x94, 0x90, 0x94, 0x90, 0x94,
		0x90, 0x94, 0x19, 0x30, 0xb9, 0x52, 0xb1, 0x56, 0xaa, 0x55, 0xaa, 0xc5, 0x1a, 0x84, 0x24, 0x84,
		0xe4, 0x2e, 0x0b, 0x49, 0x5a, 0x01, 0x42, 0x5b, 0x62, 0x13, 0x32, 0x12, 0x32, 0x12, 0x32, 0x12,
		0x32, 0x12, 0x32, 0x72, 0xc9, 0xba, 0x9d, 0xb6, 0x2b, 0x24, 0xb7, 0xe1, 0x38, 0xf5, 0xf9, 0x88,
		0xf6, 0xa8, 0x95, 0x16, 0x81, 0x22, 0x97, 0x93, 0xce, 0x5f, 0xfb, 0xfb, 0xd7, 0x79, 0xb7, 0xe6,
		0xb9, 0xfd, 0xba, 0xfb, 0xb5, 0xfd, 0xa3, 0xf0, 0xb1, 0x34, 0x3e, 0x3e, 0xf8, 0x51, 0x1d, 0xbf,
		0xfe, 0xe1, 0xd3, 0xb2, 0xb7, 0x15, 0x3e, 0x56, 0xc7, 0xc7, 0x2b, 0x7e, 0x53, 0x19, 0x1f, 0xbf,
		0xf1, 0x3b, 0xca, 0xe3, 0xfd, 0xc4, 0x5b, 0x27, 0x3f, 0x2f, 0xae, 0xfa, 0x40, 0x69, 0xc5, 0x07,
		0x0e, 0x57, 0x7d, 0xe0, 0x70, 0xc5, 0x07, 0x56, 0x5e, 0x52, 0x71, 0xc5, 0x07, 0xca, 0xe3, 0xa7,
		0xc4, 0xfb, 0xf7, 0x97, 0xbf, 0xb5, 0x32, 0x3e, 0x78, 0x5a, 0xf5, 0xbb, 0xea, 0xf8, 0xe9, 0xf8,
		0xe0, 0x20, 0xb7, 0x5f, 0x28, 0x5e, 0xe7, 0xdd, 0xa3, 0xf6, 0x53, 0xe1, 0x3a, 0xef, 0x16, 0xda,
		0x93, 0x77, 0xb6, 0x9f, 0xae, 0x0b, 0x6e, 0x6d, 0xfe, 0x72, 0xf2, 0xbf, 0x07, 0xff, 0xa3, 0x73,
		0x5c, 0x6d, 0x4a, 0x8b, 0x6f, 0x5e, 0x34, 0xfe, 0x80, 0xd9, 0xc3, 0xec, 0x53, 0x60, 0xf6, 0x50,
		0x63, 0x6f, 0x5e, 0x38, 0xb3, 0x63, 0xa1, 0x56, 0x9b, 0xb4, 0xad, 0x24, 0x04, 0x2f, 0x07, 0x87,
		0x2e, 0x83, 0x2e, 0x83, 0x2e, 0x83, 0x2e, 0x83, 0x2e, 0x23, 0x5f, 0xb7, 0x37, 0xbe, 0x3f, 0x10,
		0x9e, 0xe2, 0xd0, 0x64, 0x85, 0xac, 0x40, 0xf5, 0x56, 0xd7, 0x0e, 0xaf, 0x2b, 0xe5, 0x6b, 0x4f,
		0x4b, 0xa2, 0xca, 0x14, 0x4e, 0xd8, 0xfd, 0x5b, 0xdc, 0x79, 0xc3, 0x59, 0x39, 0x92, 0x9c, 0x3f,
		0x14, 0xaa, 0x3b, 0x05, 0xca, 0x89, 0xff, 0xc8, 0x4d, 0xfe, 0x0b, 0xe4, 0x4d, 0xce, 0xeb, 0x4b,
		0x37, 0xf4, 0xfa, 0x32, 0x8c, 0x5f, 0xe5, 0xa6, 0x11, 0x84, 0x91, 0x92, 0x5d, 0x2f, 0xd4, 0x39,
		0x25, 0xe4, 0xed, 0xdf, 0x37, 0x7e, 0x10, 0xc6, 0xaf, 0x72, 0xaf, 0xfa, 0xe4, 0xe7, 0xa2, 0xae,
		0xd6, 0xd1, 0x3f, 0x51, 0xe9, 0x12, 0x34, 0xd6, 0x48, 0x3e, 0x8e, 0x91, 0xfa, 0xae, 0xfc, 0x7f,
		0x95, 0xeb, 0x69, 0x1d, 0xc8, 0x1b, 0x2b, 0x7d, 0xc6, 0x57, 0xfa, 0x9e, 0x25, 0x63, 0xa3, 0xe5,
		0x46, 0x5a, 0x19, 0x1f, 0x5a, 0x6e, 0x64, 0x93, 0xd1, 0xa1, 0xe5, 0xc6, 0x5a, 0xb3, 0x46, 0xd6,
		0x72, 0x23, 0xe1, 0x24, 0xe9, 0xa5, 0x7a, 0xf2, 0x12, 0x68, 0x05, 0x7b, 0x01, 0x82, 0x1d, 0x82,
		0x1d, 0x82, 0x1d, 0x82, 0x3d, 0x3d, 0x82, 0x9d, 0xca, 0xfd, 0xc7, 0x03, 0x4e, 0x1b, 0x4c, 0x68,
		0xea, 0x30, 0xc1, 0x5e, 0xa2, 0x01, 0xd3, 0xf4, 0x12, 0x88, 0x4d, 0x97, 0x27, 0x89, 0x8f, 0x1c,
		0x0e, 0x38, 0x61, 0x21, 0x1d, 0xf0, 0xc0, 0x0d, 0x13, 0xa9, 0x81, 0x8b, 0xd4, 0xc0, 0x46, 0x6a,
		0xe0, 0x83, 0x16, 0x46, 0x88, 0xe1, 0x24, 0x9e, 0xe5, 0x4b, 0x0e, 0x07, 0xbf, 0xc7, 0x5b, 0x0e,
		0x39, 0xc1, 0xf6, 0xab, 0x0c, 0x63, 0x27, 0x5a, 0xf1, 0x3e, 0x83, 0x5d, 0x46, 0xd3, 0x96, 0x09,
		0x4d, 0x9b, 0xa8, 0x7b, 0xef, 0x4a, 0x9b, 0xa6, 0xe8, 0xe6, 0xcb, 0xac, 0x5d, 0x41, 0x5a, 0x40,
		0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x38, 0x48, 0x0b, 0xb5, 0x16, 0x5e, 0xd4, 0xc4, 0x03, 0xc1, 0x78,
		0xa2, 0x71, 0x41, 0x1a, 0x4f, 0xae, 0xe4, 0xe3, 0x4e, 0x1e, 0x73, 0xe3, 0x02, 0x9d, 0x34, 0x80,
		0x4f, 0xba, 0x40, 0x28, 0x2d, 0x60, 0x94, 0x3a, 0x50, 0x4a, 0x1d, 0x38, 0xa5, 0x0e, 0xa4, 0x78,
		0xc0, 0x8a, 0x09, 0xb4, 0xf8, 0x15, 0x77, 0xc2, 0x6f, 0x8c, 0xa4, 0xd2, 0x85, 0x0a, 0xa7, 0xcf,
		0x98, 0xa1, 0x48, 0x85, 0xf1, 0x12, 0x78, 0x0a, 0x31, 0xbc, 0xfe, 0xc3, 0xeb, 0x33, 0xf7, 0xb8,
		0x0b, 0x35, 0xa4, 0x8c, 0x5e, 0x24, 0x2e, 0x87, 0xb9, 0x90, 0x43, 0xe2, 0x7a, 0x52, 0x70, 0xb8,
		0x3e, 0x25, 0xee, 0x74, 0xd1, 0x84, 0xbd, 0x07, 0x98, 0xf0, 0x4f, 0x4c, 0xb8, 0x52, 0x2e, 0x1f,
		0x96, 0x61, 0xc6, 0xe9, 0xe2, 0x22, 0xfc, 0xa3, 0xb7, 0x3f, 0xec, 0xc6, 0xfd, 0x72, 0xd4, 0xa3,
		0xe1, 0xdb, 0x49, 0x5f, 0x1e, 0x36, 0x60, 0xd8, 0x51, 0x47, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d,
		0x10, 0x37, 0x40, 0xdc, 0x20, 0x23, 0x71, 0x83, 0xa3, 0x14, 0x84, 0x0d, 0xca, 0x08, 0x1b, 0x20,
		0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x58, 0x37, 0xe1, 0x62, 0x19, 0x41, 0x03, 0x04,
		0x0d, 0x10, 0x34, 0xa0, 0x0d, 0x1a, 0xdc, 0xcf, 0x56, 0x5f, 0x1a, 0xa2, 0x06, 0xd1, 0xb5, 0x20,
		0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0xc1, 0x3b, 0xfd, 0xc6,
		0x8d, 0x54, 0x5e, 0xf0, 0x98, 0x82, 0xb8, 0x41, 0x8d, 0xf1, 0x12, 0x4e, 0x85, 0xba, 0x9d, 0x26,
		0xfe, 0x23, 0x70, 0x80, 0xc0, 0xc1, 0x4f, 0x55, 0x57, 0x01, 0x9a, 0x0b, 0x81, 0x83, 0xed, 0x36,
		0x61, 0xe4, 0x1b, 0x20, 0x74, 0x80, 0xd0, 0x01, 0xa9, 0x99, 0x8b, 0x07, 0x2d, 0x54, 0x4f, 0xf4,
		0xf8, 0x03, 0x07, 0xf1, 0x95, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c,
		0x80, 0xb0, 0xc1, 0x7b, 0xc3, 0x06, 0xe4, 0xf5, 0x62, 0x57, 0xc1, 0x08, 0x51, 0xfd, 0xd8, 0xdd,
		0x24, 0x2d, 0xfe, 0x70, 0xc2, 0xcc, 0xbd, 0x01, 0x3f, 0x69, 0x89, 0xaf, 0x04, 0xa4, 0x05, 0xa4,
		0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x25, 0x39, 0xc7, 0x43,
		0x2f, 0xd0, 0x32, 0x0d, 0x9c, 0x65, 0x7e, 0x21, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c,
		0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xc9, 0x39, 0xd6, 0x81, 0xa7, 0x42, 0xa9, 0xe5,
		0x7d, 0x0a, 0xf2, 0x4a, 0x5f, 0x5c, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88,
		0x0b, 0x88, 0x0b, 0x88, 0x4b, 0xea, 0x89, 0x4b, 0xa6, 0xcb, 0x8b, 0x12, 0x37, 0x28, 0x4c, 0x8c,
		0xcf, 0xd3, 0xb0, 0x30, 0xd9, 0x1b, 0x2f, 0xf9, 0x23, 0x8a, 0xae, 0x86, 0x7c, 0xb6, 0x96, 0xad,
		0x86, 0x31, 0xbf, 0x89, 0x47, 0x8e, 0x8a, 0x2f, 0xce, 0xa9, 0x0c, 0x75, 0x5d, 0x6b, 0xe2, 0x6e,
		0x35, 0xdf, 0xa4, 0x3a, 0x19, 0x88, 0x09, 0x1d, 0x08, 0x69, 0xe9, 0xb4, 0xf3, 0xcd, 0x7b, 0x78,
		0x31, 0x72, 0xe1, 0xa8, 0x54, 0xaa, 0x54, 0x4b, 0xa5, 0x7c, 0xf5, 0xb0, 0x9a, 0xaf, 0x95, 0xcb,
		0x85, 0x4a, 0x81, 0x30, 0xfb, 0xd5, 0x69, 0x06, 0x3d, 0x11, 0x88, 0xde, 0xe7, 0xc9, 0xa3, 0x57,
		0xa3, 0xc1, 0x20, 0x53, 0x16, 0xcd, 0xe4, 0x97, 0x53, 0xec, 0x8f, 0x1d, 0xd2, 0x96, 0x0a, 0xc1,
		0xa8, 0xab, 0xd5, 0x8c, 0x74, 0x7d, 0xbe, 0x1d, 0x76, 0x5a, 0xf2, 0xa6, 0x53, 0xef, 0xcb, 0x0b,
		0xaf, 0x2f, 0x3b, 0x8d, 0xe1, 0x7d, 0xe5, 0x2a, 0xba, 0xd3, 0xce, 0xd9, 0xec, 0xfe, 0x3a, 0xf5,
		0xde, 0x3f, 0x2d, 0x79, 0xd3, 0x1c, 0xe9, 0xf3, 0x40, 0x74, 0x5a, 0x93, 0xbb, 0xea, 0x5c, 0x45,
		0xb7, 0x50, 0x8f, 0xef, 0x00, 0x2d, 0x99, 0xf9, 0x57, 0xd8, 0x8e, 0xb4, 0x64, 0x5e, 0xd2, 0xfd,
		0x77, 0x5b, 0xfb, 0x33, 0x7f, 0xd8, 0x22, 0x2b, 0x9b, 0x33, 0x91, 0x28, 0x8c, 0xb1, 0x37, 0x79,
		0xea, 0xae, 0xb4, 0x95, 0x12, 0x4e, 0x43, 0x3f, 0xe8, 0xe8, 0x06, 0x2b, 0xbd, 0xa0, 0xa1, 0x13,
		0xb6, 0xcc, 0x8e, 0xc8, 0xa9, 0xf1, 0x38, 0x33, 0x8b, 0xc8, 0x6f, 0x06, 0xe9, 0xed, 0xb8, 0x56,
		0xf3, 0x8e, 0xcf, 0xec, 0x37, 0x1a, 0xb6, 0x65, 0xdb, 0x36, 0x4c, 0x6d, 0xbb, 0x66, 0x8d, 0xc2,
		0xdc, 0xa3, 0x33, 0xf3, 0x4d, 0x86, 0x1e, 0xbe, 0xad, 0x87, 0x4e, 0xf6, 0xb0, 0x0d, 0xfa, 0xa6,
		0x4d, 0x7d, 0x91, 0x19, 0x83, 0xdb, 0xdc, 0x3c, 0x0c, 0x98, 0x86, 0x33, 0x9f, 0x6e, 0xd7, 0xeb,
		0xf5, 0x02, 0x11, 0x86, 0xc6, 0x8c, 0x23, 0x8e, 0xa4, 0x27, 0x46, 0x30, 0x64, 0xd0, 0x66, 0x77,
		0x59, 0x8d, 0xef, 0x9a, 0xda, 0xd8, 0x05, 0xb5, 0xbb, 0xab, 0x69, 0x6b, 0x97, 0xd2, 0xfa, 0xae,
		0xa3, 0xf5, 0x5d, 0x44, 0xeb, 0xbb, 0x82, 0xe9, 0x82, 0x0a, 0xe3, 0xbb, 0x70, 0x16, 0xdb, 0xb2,
		0xda, 0x68, 0xb7, 0x9a, 0x6c, 0xa3, 0x9a, 0xf0, 0x61, 0x19, 0x42, 0x00, 0xb3, 0x5d, 0x4d, 0xad,
		0x74, 0x2b, 0x35, 0xdc, 0x85, 0x14, 0xbe, 0x1e, 0xbe, 0x1e, 0xbe, 0x3e, 0xba, 0x5b, 0xd3, 0x5d,
		0x2f, 0xed, 0x11, 0x4a, 0x2a, 0x62, 0x69, 0x89, 0x60, 0x5a, 0x73, 0x3e, 0x36, 0x9d, 0x10, 0x8d,
		0x33, 0xb2, 0xed, 0x94, 0xc8, 0x9c, 0x13, 0x99, 0x93, 0x22, 0x73, 0x56, 0xdb, 0x11, 0xd0, 0xb2,
		0x96, 0x36, 0x16, 0xdb, 0xbd, 0x1c, 0x5a, 0xf2, 0x32, 0x0b, 0xf4, 0xc6, 0x42, 0x0d, 0xc1, 0xf9,
		0xdc, 0xd8, 0xa9, 0x0c, 0x68, 0x31, 0x00, 0xfe, 0x3c, 0xf3, 0xf7, 0x25, 0x8b, 0x73, 0x9f, 0x78,
		0x06, 0x47, 0x16, 0xc7, 0x38, 0xf7, 0xb4, 0x16, 0x81, 0xb2, 0x5e, 0xa8, 0xd1, 0xf9, 0x6b, 0x7f,
		0xff, 0x3a, 0xef, 0xd6, 0xda, 0x4f, 0xd7, 0x05, 0xb7, 0xd6, 0x8e, 0x5e, 0x16, 0xa6, 0xff, 0x44,
		0xaf, 0x8b, 0xd7, 0x79, 0xb7, 0x34, 0x7f, 0x5d, 0xbe, 0xce, 0xbb, 0xe5, 0xf6, 0xc1, 0x9f, 0x7f,
		0x7e, 0x3a, 0xf8, 0x71, 0x38, 0x7e, 0xff, 0x07, 0xff, 0x67, 0x6f, 0xc3, 0xb3, 0x6d, 0xf3, 0x61,
		0x34, 0x2f, 0x1a, 0x7f, 0xe0, 0x89, 0xbc, 0xf7, 0x89, 0x6c, 0xd3, 0x6e, 0x1d, 0x8d, 0x7b, 0xaa,
		0xc0, 0x3d, 0xad, 0xb7, 0x18, 0x3c, 0xb7, 0x5f, 0x77, 0xbf, 0xb6, 0x7f, 0x14, 0x3e, 0x96, 0xc6,
		0xc7, 0x07, 0x3f, 0xaa, 0xe3, 0xd7, 0x3f, 0x7c, 0x5a, 0xf6, 0xb6, 0xc2, 0xc7, 0xea, 0xf8, 0x78,
		0xc5, 0x6f, 0x2a, 0xe3, 0xe3, 0x37, 0x7e, 0x47, 0x79, 0xbc, 0x9f, 0x78, 0xeb, 0xe4, 0xe7, 0xc5,
		0x55, 0x1f, 0x28, 0xad, 0xf8, 0xc0, 0xe1, 0xaa, 0x0f, 0x1c, 0xae, 0xf8, 0xc0, 0xca, 0x4b, 0x2a,
		0xae, 0xf8, 0x40, 0x79, 0xfc, 0x94, 0x78, 0xff, 0xfe, 0xf2, 0xb7, 0x56, 0xc6, 0x07, 0x4f, 0xab,
		0x7e, 0x57, 0x1d, 0x3f, 0x1d, 0x1f, 0xc0, 0x59, 0xc3, 0x3e, 0x77, 0xd6, 0x3e, 0xb7, 0x24, 0x79,
		0xa0, 0x8d, 0xfd, 0xec, 0xb7, 0x28, 0xdf, 0x6d, 0xdb, 0xcf, 0x36, 0x78, 0xca, 0xc1, 0xc0, 0xc6,
		0xc1, 0x07, 0xc6, 0x67, 0x38, 0xcf, 0xdd, 0x33, 0x1c, 0xc0, 0x33, 0x9b, 0xa5, 0x67, 0x3e, 0x1b,
		0x8f, 0x24, 0xeb, 0xce, 0x6c, 0x76, 0xdd, 0xa6, 0x0f, 0xda, 0xf0, 0x22, 0xb5, 0xb6, 0x38, 0x1d,
		0x23, 0xfb, 0x68, 0xef, 0x4d, 0x2a, 0xd9, 0xcc, 0x19, 0xac, 0xbf, 0x84, 0xd7, 0xfb, 0xe4, 0x9a,
		0xb6, 0x60, 0xca, 0x06, 0x4c, 0x3f, 0xfb, 0xf5, 0x26, 0xff, 0xfd, 0x53, 0xf7, 0xbe, 0x4f, 0xbc,
		0x73, 0x92, 0x37, 0x9d, 0x5c, 0x33, 0x93, 0xba, 0xc6, 0xea, 0x79, 0xfb, 0x6a, 0x79, 0xdf, 0x73,
		0x7a, 0xfb, 0x6c, 0xbf, 0x63, 0xa6, 0xd7, 0xdc, 0x22, 0xdf, 0x68, 0x2b, 0x7c, 0xcd, 0x2d, 0xef,
		0xe7, 0xdd, 0xa5, 0xe2, 0x3b, 0x3f, 0xb8, 0xc1, 0xee, 0x91, 0x99, 0xdd, 0xa1, 0x4d, 0x77, 0x7f,
		0x8c, 0xed, 0xee, 0x18, 0xdb, 0xbd, 0x31, 0xb6, 0x3b, 0x63, 0xd7, 0x87, 0xac, 0xbb, 0x05, 0xec,
		0xcc, 0x9d, 0x81, 0x3b, 0x5b, 0xc6, 0x6b, 0x3e, 0xb7, 0xb8, 0x21, 0xe0, 0xc2, 0xd7, 0xad, 0x39,
		0xe5, 0x9b, 0x6d, 0xda, 0x6e, 0xbc, 0x39, 0x6b, 0x62, 0x13, 0xd6, 0xec, 0x66, 0xab, 0xa9, 0x4d,
		0x55, 0xe3, 0x9b, 0xa7, 0xc6, 0x37, 0x49, 0x8d, 0x6f, 0x86, 0xd2, 0xf2, 0xa4, 0x8d, 0x37, 0x31,
		0x9f, 0x63, 0xd2, 0x3d, 0xa1, 0xb4, 0xd4, 0x8f, 0x9b, 0x65, 0xda, 0xc5, 0x08, 0xb4, 0x81, 0x2a,
		0x71, 0x1a, 0xb3, 0x4b, 0xf9, 0xec, 0x85, 0x06, 0x4c, 0x70, 0x7e, 0x83, 0xf5, 0xaf, 0x8d, 0xce,
		0xc5, 0xe4, 0x7f, 0x2e, 0xff, 0xef, 0xfc, 0x64, 0x53, 0x33, 0x9c, 0xf6, 0x14, 0x0a, 0x8d, 0x04,
		0x15, 0x0d, 0xa7, 0xd0, 0x9d, 0x1e, 0xfe, 0x7e, 0x7e, 0xd6, 0x69, 0x9c, 0xff, 0x5e, 0xea, 0x5c,
		0x9d, 0x35, 0x7e, 0xa9, 0x5f, 0x5c, 0x3a, 0x69, 0xc8, 0x18, 0x34, 0x7d, 0x97, 0x8d, 0xb3, 0xdf,
		0x2e, 0x2e, 0xeb, 0x97, 0x27, 0x59, 0xbc, 0xb9, 0xe9, 0xc3, 0x3b, 0xad, 0x7f, 0x3e, 0x39, 0x3d,
		0xf9, 0x92, 0xe9, 0x87, 0x58, 0x9c, 0x98, 0xea, 0xef, 0xe7, 0xa7, 0x17, 0x99, 0x36, 0xd1, 0xce,
		0xc5, 0xf9, 0xd7, 0x4c, 0xde, 0xe0, 0xdc, 0xd3, 0x54, 0xb2, 0x6c, 0xa4, 0xd3, 0xfb, 0xdb, 0x99,
		0xc5, 0x78, 0xf2, 0xfb, 0xf9, 0x59, 0x66, 0x9f, 0x62, 0x86, 0x9f, 0xde, 0x45, 0xeb, 0xf2, 0xa4,
		0x73, 0xde, 0x3c, 0x6d, 0xfc, 0xf2, 0x7f, 0x53, 0xec, 0xcf, 0xb4, 0xbf, 0x29, 0x75, 0xbe, 0x5d,
		0x9d, 0x5e, 0x66, 0xd9, 0xe3, 0x94, 0x3a, 0x5f, 0x4f, 0x9b, 0xff, 0xef, 0xe2, 0xfc, 0xe4, 0x97,
		0x6c, 0x23, 0x63, 0x46, 0xbd, 0xcd, 0xef, 0xe7, 0x67, 0x19, 0x7f, 0x84, 0xaf, 0xfc, 0x4d, 0x25,
		0xb3, 0xeb, 0x30, 0xcb, 0x88, 0xff, 0xcc, 0xdf, 0x4c, 0xfa, 0xd3, 0x8d, 0xbe, 0xa1, 0x4d, 0x1d,
		0x77, 0xc1, 0xd6, 0x4c, 0xb4, 0x35, 0xb3, 0x46, 0xa2, 0xc1, 0x3b, 0xb6, 0x4d, 0x3e, 0x18, 0x9c,
		0xab, 0xb8, 0x9c, 0xe0, 0x1a, 0x91, 0xdf, 0xf5, 0x76, 0xfb, 0xd7, 0xdf, 0xd5, 0x37, 0xba, 0x7b,
		0xbf, 0xde, 0x2e, 0xfd, 0x5b, 0x67, 0x75, 0x4d, 0xcb, 0x5b, 0xdb, 0xe2, 0x9c, 0x77, 0x6d, 0xa5,
		0xfd, 0xc7, 0xbe, 0xdf, 0xdb, 0x8c, 0xf6, 0xe7, 0x26, 0xf8, 0xdf, 0xef, 0xf8, 0xc9, 0x34, 0xbe,
		0x77, 0xfa, 0xde, 0x3b, 0x6d, 0xff, 0x7d, 0x93, 0xab, 0x2f, 0xfd, 0x3f, 0x2e, 0x3b, 0xaa, 0xc7,
		0x19, 0x0a, 0xfd, 0xf3, 0xd3, 0x76, 0xcf, 0xbb, 0x2d, 0xf1, 0x47, 0x7e, 0x32, 0x1d, 0x6f, 0xdb,
		0x88, 0x7c, 0xf3, 0xce, 0xc9, 0x7b, 0x76, 0x48, 0xd6, 0xdb, 0x09, 0x79, 0xef, 0x8e, 0xc7, 0xda,
		0x3b, 0x1b, 0x6b, 0xef, 0x60, 0xac, 0xbd, 0x53, 0xb1, 0x99, 0x61, 0xbf, 0x75, 0xa3, 0x2f, 0xb6,
		0x8d, 0xb7, 0x4f, 0xe1, 0x6b, 0xab, 0x7a, 0xeb, 0x0c, 0xbe, 0x6f, 0x97, 0xfb, 0xdd, 0xdb, 0x73,
		0xeb, 0x6c, 0xc7, 0x6d, 0xb6, 0xfd, 0xb6, 0xee, 0x76, 0xdb, 0xc6, 0xdb, 0x6b, 0x1b, 0x6f, 0xa7,
		0x6d, 0xbc, 0x7d, 0x66, 0x96, 0x1a, 0xbc, 0x77, 0x57, 0xda, 0xf1, 0x6e, 0x6f, 0x03, 0x71, 0xeb,
		0x69, 0x3f, 0x58, 0x3f, 0x53, 0xe3, 0xc5, 0x77, 0x10, 0xa7, 0x6b, 0xe4, 0x91, 0xae, 0x81, 0x74,
		0x0d, 0x2b, 0x0b, 0xe3, 0x05, 0xf5, 0xda, 0xa4, 0xd0, 0x87, 0x91, 0xc2, 0x1e, 0x1b, 0x16, 0xf2,
		0x58, 0x3b, 0xbb, 0xc9, 0xc4, 0xb2, 0x31, 0xbb, 0x7c, 0x4c, 0x2d, 0x23, 0xe3, 0xcb, 0xc9, 0xf8,
		0xb2, 0x32, 0xbe, 0xbc, 0x36, 0x0c, 0x13, 0xac, 0x69, 0x39, 0x9b, 0x16, 0xca, 0x70, 0x4c, 0xd5,
		0xc3, 0x78, 0x06, 0x2b, 0x33, 0x59, 0xf3, 0x66, 0xca, 0x5c, 0x18, 0x2b, 0x6b, 0x61, 0xb2, 0x8c,
		0x85, 0x9d, 0xb2, 0x15, 0xa6, 0xcb, 0x54, 0x58, 0x2b, 0x4b, 0x61, 0xad, 0x0c, 0x85, 0xb5, 0xb2,
		0x13, 0xbc, 0xc7, 0x52, 0x8c, 0x95, 0x91, 0xb0, 0x55, 0xbc, 0xc0, 0xe4, 0x29, 0x60, 0xe3, 0xa7,
		0x7d, 0xb7, 0xee, 0x88, 0x7b, 0xdb, 0xc4, 0x24, 0xda, 0x38, 0x97, 0xba, 0x7d, 0x33, 0xc9, 0x75,
		0x90, 0x65, 0x03, 0xde, 0xe5, 0x99, 0x44, 0x62, 0x80, 0x30, 0x40, 0x18, 0x20, 0x9c, 0x52, 0x10,
		0xf6, 0x42, 0x57, 0x8d, 0xee, 0x6e, 0x44, 0x60, 0x10, 0x81, 0x0d, 0x54, 0x1b, 0x75, 0x5a, 0x9e,
		0xba, 0x35, 0x57, 0x9a, 0xc9, 0xe0, 0x11, 0xe8, 0x6f, 0x52, 0x59, 0x28, 0x0c, 0x69, 0xa7, 0x9a,
		0xde, 0x34, 0x7b, 0xdb, 0xc2, 0xf7, 0x7e, 0x0d, 0xbc, 0xae, 0x96, 0xbe, 0xfa, 0x22, 0x6f, 0x65,
		0xb4, 0x55, 0x68, 0xee, 0x1c, 0xbd, 0xc1, 0x32, 0x9e, 0xdf, 0xbc, 0x87, 0xad, 0x7b, 0x54, 0xa5,
		0x62, 0xad, 0x54, 0xab, 0x54, 0x8b, 0xb5, 0xf2, 0x16, 0x3d, 0xb3, 0x94, 0x9c, 0xdb, 0xdf, 0x4e,
		0xa6, 0x55, 0x32, 0x49, 0xb5, 0x4a, 0xe0, 0x5a, 0xe0, 0x5a, 0xe0, 0x5a, 0xe0, 0x5a, 0xe0, 0x5a,
		0xe0, 0x5a, 0xe0, 0x5a, 0xe0, 0x5a, 0x99, 0xe3, 0x5a, 0x59, 0x2e, 0xcf, 0x32, 0xcf, 0x3a, 0x8b,
		0x5f, 0xe5, 0x9e, 0x73, 0x2e, 0x36, 0x29, 0x91, 0xb5, 0xa3, 0xd9, 0xbf, 0xff, 0x35, 0x9d, 0x06,
		0xcb, 0xb2, 0x68, 0x1d, 0x5c, 0x08, 0xdd, 0xa9, 0x3f, 0x7f, 0x77, 0x0a, 0xaa, 0xb2, 0x78, 0xa1,
		0x3b, 0x9b, 0x9f, 0x75, 0xb3, 0x7d, 0x66, 0x5f, 0x80, 0x54, 0x1f, 0xbb, 0xfc, 0x1f, 0xa9, 0x3e,
		0x6b, 0x3a, 0x91, 0xf5, 0x2b, 0xb3, 0x84, 0x6e, 0x28, 0x6e, 0x67, 0x37, 0xb8, 0x69, 0x59, 0x96,
		0xe7, 0xef, 0x62, 0x4e, 0xfa, 0x41, 0x4d, 0x16, 0xdb, 0x42, 0x1a, 0x49, 0x3f, 0x66, 0x16, 0xe0,
		0x0b, 0x3c, 0x35, 0xd1, 0x5c, 0xcb, 0x68, 0x53, 0x2d, 0x43, 0xcd, 0xb4, 0x36, 0xce, 0xc5, 0x43,
		0xfc, 0x0b, 0xf1, 0x2f, 0xe6, 0xf8, 0x97, 0xa9, 0xe6, 0x57, 0xce, 0x9d, 0x98, 0xc6, 0xbc, 0x8c,
		0x37, 0xd1, 0x9b, 0x7d, 0x2f, 0x3a, 0xa6, 0xa6, 0xcb, 0x21, 0xd8, 0x72, 0x0c, 0xd6, 0x1d, 0x84,
		0x75, 0x47, 0x61, 0xdd, 0x61, 0x18, 0x0e, 0x12, 0xa5, 0xbe, 0x63, 0xaa, 0xc9, 0x80, 0xfa, 0x6b,
		0x47, 0x60, 0xb2, 0x65, 0xaa, 0xd9, 0x00, 0xfb, 0xfc, 0x8f, 0x85, 0x8e, 0x5e, 0x36, 0x02, 0xee,
		0x96, 0x3c, 0x6c, 0xe2, 0xeb, 0x2d, 0x05, 0xe0, 0xe3, 0xef, 0xb7, 0x18, 0xd4, 0x35, 0xbc, 0xe2,
		0x16, 0x1f, 0xa9, 0xf7, 0xb0, 0xf5, 0x8f, 0xd4, 0x56, 0xa0, 0x9e, 0xf4, 0xd9, 0xa6, 0xb4, 0x71,
		0x45, 0x3b, 0x55, 0x58, 0x61, 0xb4, 0x4b, 0xc1, 0x4b, 0xb7, 0x66, 0xb6, 0x5b, 0xc1, 0xcb, 0xd5,
		0x65, 0xbd, 0x6b, 0x41, 0x3c, 0x98, 0xd1, 0xee, 0x05, 0xe6, 0x2c, 0xc9, 0x44, 0x9f, 0x6d, 0x6d,
		0x92, 0x23, 0xc4, 0xfc, 0x60, 0xfa, 0xad, 0xd0, 0x07, 0xd0, 0x07, 0xd0, 0x07, 0xbb, 0xaa, 0x0f,
		0x86, 0x9e, 0xfe, 0x7b, 0x1e, 0xa2, 0x77, 0x0d, 0xfa, 0x83, 0x97, 0x3e, 0xa1, 0x50, 0x32, 0xf8,
		0x9d, 0x27, 0x6a, 0x74, 0x37, 0x99, 0x8d, 0x31, 0x9a, 0x21, 0xf1, 0xf5, 0xc8, 0x59, 0xb2, 0x73,
		0x1c, 0x99, 0x52, 0xee, 0x79, 0xc3, 0xc7, 0x44, 0xcf, 0xaa, 0x6d, 0xc9, 0x83, 0x30, 0x42, 0xcb,
		0xcc, 0xd1, 0x30, 0xab, 0xb4, 0xcb, 0x0c, 0xcd, 0xda, 0xde, 0x8c, 0x93, 0x84, 0xa1, 0x6f, 0xb2,
		0x97, 0xf7, 0x93, 0x94, 0x89, 0xf0, 0x62, 0x36, 0x04, 0xd2, 0x5a, 0x0c, 0x3c, 0xb3, 0x74, 0xe4,
		0x9d, 0x94, 0x36, 0x4e, 0x3c, 0x29, 0x21, 0xf3, 0x84, 0x82, 0x40, 0x23, 0xf3, 0x64, 0xcd, 0x75,
		0xbe, 0x41, 0xe6, 0x49, 0xc9, 0x64, 0xea, 0x49, 0x09, 0xb9, 0x27, 0xc8, 0x3d, 0x49, 0x8b, 0xc6,
		0x44, 0xee, 0x09, 0x72, 0x4f, 0xa8, 0x43, 0x49, 0xc8, 0x3d, 0x41, 0xee, 0xc9, 0x7f, 0x7f, 0x11,
		0x72, 0x4f, 0x4c, 0x7c, 0x21, 0x62, 0xcb, 0xb6, 0x1d, 0x84, 0x75, 0x47, 0x61, 0xdd, 0x61, 0x98,
		0x8b, 0x38, 0xee, 0x21, 0xf7, 0x04, 0xb9, 0x27, 0x86, 0xbf, 0x1c, 0xb9, 0x27, 0x44, 0x2b, 0x6e,
		0xf1, 0x91, 0x22, 0xf7, 0x24, 0x1d, 0xcf, 0x16, 0xb9, 0x27, 0x6f, 0x78, 0x10, 0xc8, 0x3d, 0xf9,
		0x8f, 0xc1, 0x90, 0x7b, 0xf2, 0x4e, 0x7e, 0x80, 0xdc, 0x13, 0xe8, 0x03, 0xe8, 0x83, 0x9d, 0xd6,
		0x07, 0xc8, 0x3d, 0xd9, 0xea, 0x20, 0x54, 0x8a, 0x72, 0x4f, 0x4a, 0xf3, 0x3d, 0xf9, 0x12, 0xb2,
		0x4f, 0xd8, 0x89, 0x18, 0xb2, 0x4f, 0x68, 0x4d, 0xdd, 0x66, 0xfe, 0x49, 0x09, 0x09, 0x28, 0x26,
		0x1f, 0x5b, 0x1a, 0x32, 0x50, 0xa4, 0xea, 0x89, 0x87, 0xf5, 0xd3, 0x4f, 0xa2, 0x8f, 0xaf, 0x97,
		0x7b, 0x92, 0x47, 0xee, 0x09, 0x35, 0x51, 0xde, 0xb5, 0xdc, 0x93, 0xb5, 0x09, 0x6b, 0xfc, 0xdc,
		0x07, 0xc2, 0xeb, 0x07, 0xa2, 0xbf, 0xce, 0x43, 0x9f, 0x73, 0xce, 0x35, 0xe2, 0xd3, 0xce, 0xf9,
		0xcc, 0xab, 0x7c, 0xfa, 0x14, 0x51, 0x97, 0x5c, 0xb4, 0xd0, 0x52, 0xe0, 0x30, 0xd6, 0x4b, 0x05,
		0xd8, 0x68, 0xeb, 0x7f, 0xe3, 0x64, 0xb5, 0x22, 0x1c, 0x06, 0x1c, 0xc6, 0x9b, 0xae, 0x72, 0xfd,
		0x64, 0x35, 0x79, 0x3b, 0x34, 0x90, 0xa5, 0x26, 0xd7, 0x0e, 0xdc, 0x6c, 0x18, 0xf6, 0x42, 0x7a,
		0x1a, 0x5d, 0x98, 0x0a, 0xe9, 0x69, 0x86, 0xc3, 0x4a, 0xb1, 0xdd, 0x8c, 0xa4, 0xd2, 0x95, 0x4d,
		0xaa, 0x7a, 0xcf, 0x57, 0xd1, 0x06, 0x5d, 0x91, 0x0c, 0xed, 0x21, 0x1b, 0x08, 0xa1, 0x98, 0xdc,
		0x23, 0x36, 0x1d, 0x55, 0x37, 0xbc, 0x07, 0x6c, 0x63, 0x5f, 0xd0, 0xc4, 0x6e, 0x89, 0xc9, 0x3d,
		0x5d, 0x5b, 0x8f, 0xc0, 0xde, 0x5e, 0x98, 0x95, 0xa7, 0xc2, 0x14, 0xc4, 0x6b, 0x53, 0xc5, 0x3c,
		0xd6, 0x60, 0x8b, 0x9e, 0xf6, 0xef, 0x64, 0xd7, 0x9d, 0xd7, 0x6b, 0x35, 0xd0, 0x99, 0x35, 0xf1,
		0x8d, 0x20, 0x25, 0x20, 0x25, 0x20, 0x25, 0x6b, 0xd9, 0xcd, 0x8d, 0xef, 0x0f, 0x84, 0xa7, 0x0c,
		0xb0, 0x92, 0x42, 0x21, 0xc5, 0x4e, 0xa8, 0x3b, 0x18, 0x85, 0x5a, 0x04, 0xee, 0x40, 0x86, 0x06,
		0xce, 0xeb, 0x2c, 0x7c, 0x1b, 0x9c, 0x0f, 0x9c, 0x0f, 0x9c, 0xcf, 0x5a, 0x76, 0x63, 0xa8, 0x6d,
		0xac, 0x89, 0x76, 0xb1, 0xc6, 0xda, 0xc4, 0x6e, 0x4d, 0x53, 0xd3, 0xf6, 0x26, 0x93, 0x65, 0xb2,
		0x1d, 0xec, 0xf6, 0xcc, 0x18, 0xb6, 0xca, 0xd3, 0xbd, 0x55, 0x4e, 0x42, 0x25, 0xd6, 0xdb, 0x94,
		0x4c, 0xfa, 0xbe, 0x35, 0x36, 0x27, 0x41, 0x1e, 0x40, 0x1e, 0x40, 0x1e, 0x10, 0x4e, 0x45, 0x38,
		0x15, 0xe1, 0x54, 0x84, 0x53, 0x77, 0x33, 0x9c, 0x3a, 0xf0, 0xbb, 0xde, 0xc0, 0x9d, 0x60, 0xd3,
		0xe6, 0x1c, 0xe4, 0xc5, 0x77, 0x81, 0x88, 0x80, 0x88, 0x80, 0x88, 0xac, 0x4d, 0x44, 0x0e, 0x8b,
		0x06, 0x88, 0x48, 0x15, 0x44, 0x04, 0x44, 0x64, 0x47, 0x88, 0x88, 0xe9, 0xb3, 0xb8, 0xa0, 0x1f,
		0x34, 0xf4, 0xe3, 0x4e, 0xf4, 0x36, 0xe7, 0x1d, 0x93, 0x2f, 0x01, 0xe1, 0x00, 0xe1, 0x00, 0xe1,
		0x00, 0xe1, 0x00, 0xe1, 0x00, 0xe1, 0x00, 0xe1, 0x00, 0xe1, 0x58, 0x35, 0xcd, 0x4a, 0x3c, 0x68,
		0xf7, 0x6f, 0xdf, 0x40, 0xfe, 0x7a, 0xfc, 0x4d, 0xa0, 0x1e, 0xa0, 0x1e, 0xa0, 0x1e, 0x6b, 0xd9,
		0x8d, 0x1c, 0x9a, 0xcc, 0xd7, 0xa8, 0x6d, 0xf0, 0x1d, 0xb3, 0x7b, 0x62, 0xa7, 0x1f, 0x86, 0x73,
		0x59, 0x12, 0x73, 0x74, 0x64, 0xe0, 0xbb, 0x4c, 0x65, 0x6a, 0xc4, 0x5f, 0xb8, 0x2d, 0x19, 0x1b,
		0x31, 0xc0, 0x99, 0x98, 0x44, 0x93, 0x39, 0x2f, 0xdb, 0x3b, 0x93, 0x9c, 0x75, 0x3c, 0xcc, 0x2e,
		0xd7, 0xca, 0xae, 0x2d, 0x57, 0xcf, 0xed, 0xd7, 0xdd, 0xaf, 0xed, 0x1f, 0x85, 0x8f, 0xa5, 0xf1,
		0xf1, 0xc1, 0x8f, 0xea, 0xf8, 0xf5, 0x0f, 0x9f, 0x96, 0xbd, 0xad, 0xf0, 0xb1, 0x3a, 0x3e, 0x5e,
		0xf1, 0x9b, 0xca, 0xf8, 0xf8, 0x8d, 0xdf, 0x51, 0x1e, 0xef, 0x27, 0xde, 0x3a, 0xf9, 0x79, 0x71,
		0xd5, 0x07, 0x4a, 0x2b, 0x3e, 0x70, 0xb8, 0xea, 0x03, 0x87, 0x2b, 0x3e, 0xb0, 0xf2, 0x92, 0x8a,
		0x2b, 0x3e, 0x50, 0x1e, 0x3f, 0x25, 0xde, 0xbf, 0xbf, 0xfc, 0xad, 0x95, 0xf1, 0xc1, 0xd3, 0xaa,
		0xdf, 0x55, 0xc7, 0x4f, 0xc7, 0x07, 0x3b, 0xe1, 0xbc, 0x60, 0x57, 0xdb, 0x69, 0x57, 0x50, 0x9b,
		0x09, 0x8b, 0xf6, 0x03, 0x79, 0xbb, 0x41, 0x3c, 0xe9, 0x59, 0x5f, 0x45, 0xdf, 0x03, 0xa5, 0x09,
		0xa5, 0x09, 0xa5, 0xb9, 0x96, 0xdd, 0xdc, 0xdc, 0x0e, 0xdd, 0x68, 0x15, 0xb9, 0xd3, 0xda, 0x44,
		0x1b, 0x16, 0xdd, 0x33, 0x51, 0x64, 0x6f, 0xc3, 0xa2, 0x7a, 0x94, 0x1e, 0xcc, 0xd3, 0x7e, 0xe0,
		0xca, 0x9e, 0x29, 0x47, 0x36, 0xff, 0x3a, 0xf8, 0x33, 0xf8, 0x33, 0xf8, 0x33, 0xce, 0xf8, 0x10,
		0xce, 0x3a, 0x11, 0x4b, 0x28, 0x9c, 0x75, 0xb2, 0x0b, 0x71, 0xd9, 0xac, 0xa2, 0xb8, 0x46, 0x49,
		0x57, 0x3b, 0x15, 0xd1, 0xf4, 0x48, 0x29, 0x31, 0x70, 0x85, 0xea, 0x7a, 0xc3, 0x70, 0x34, 0x58,
		0x6f, 0x2e, 0x9e, 0x2b, 0xa1, 0x2f, 0xfb, 0x36, 0xd4, 0x4b, 0xb3, 0x0b, 0xf6, 0xa8, 0x97, 0xb6,
		0xe6, 0xea, 0x5f, 0xbb, 0x5e, 0x5a, 0x64, 0xe6, 0xe1, 0xe6, 0xec, 0x79, 0xfe, 0x45, 0x68, 0xea,
		0x09, 0xde, 0xbc, 0x53, 0xbc, 0x79, 0xe3, 0xa6, 0x9e, 0xd1, 0xca, 0x31, 0xd7, 0xd5, 0x73, 0xf6,
		0x7d, 0x29, 0x6b, 0xeb, 0x99, 0x47, 0x5b, 0x4f, 0xe6, 0x85, 0x6b, 0x6d, 0x01, 0x5b, 0x5b, 0xc8,
		0x9b, 0x2d, 0xe8, 0x0d, 0x17, 0xb6, 0xb1, 0x05, 0xfe, 0x4c, 0xb1, 0x8d, 0x74, 0xef, 0x4d, 0x58,
		0xb1, 0x89, 0x2e, 0xbe, 0x86, 0x97, 0xfd, 0xc6, 0x54, 0x96, 0xc2, 0x0d, 0xd8, 0x75, 0x07, 0xb6,
		0xdc, 0x82, 0x75, 0xf7, 0x60, 0xdd, 0x4d, 0x58, 0x77, 0x17, 0x66, 0xdc, 0x86, 0x21, 0xf7, 0x61,
		0xdc, 0x8d, 0x3c, 0xf3, 0x06, 0xd3, 0x5d, 0x80, 0xf6, 0x2c, 0x75, 0x02, 0x7b, 0xed, 0x5c, 0x0c,
		0x37, 0x3f, 0x34, 0xde, 0x19, 0xcc, 0xa6, 0xb3, 0xa1, 0x71, 0x3a, 0xb6, 0x9d, 0x0f, 0x99, 0x13,
		0x22, 0x73, 0x46, 0x64, 0x4e, 0xc9, 0xac, 0x73, 0x32, 0xec, 0xa4, 0xe2, 0x59, 0xb8, 0xb4, 0xe1,
		0x5b, 0x16, 0xec, 0x5e, 0xf6, 0x84, 0xd2, 0x52, 0x3f, 0xae, 0x7f, 0x22, 0xff, 0x4d, 0x3c, 0xc6,
		0x42, 0xff, 0x53, 0xa7, 0x31, 0xbb, 0xf4, 0xcf, 0x5e, 0x68, 0x71, 0x69, 0xcd, 0x27, 0xea, 0xf2,
		0xea, 0xec, 0xec, 0xe4, 0xb4, 0x73, 0x72, 0xf6, 0xcb, 0xff, 0x67, 0xef, 0x5f, 0x9b, 0xdb, 0x36,
		0xb2, 0xae, 0x61, 0xf8, 0xbb, 0x7f, 0x05, 0x8b, 0x35, 0x55, 0xef, 0xa4, 0xee, 0xc0, 0x26, 0xa9,
		0xb3, 0xbf, 0xbc, 0x45, 0x49, 0x94, 0xc3, 0x27, 0x12, 0xc9, 0x4b, 0xa4, 0x9d, 0xe4, 0xb6, 0x35,
		0xaa, 0x16, 0xd0, 0xa4, 0xfa, 0x31, 0x08, 0x60, 0x80, 0xa6, 0x64, 0x5d, 0x89, 0xff, 0xfb, 0x53,
		0x04, 0x8f, 0x12, 0x75, 0x00, 0xfa, 0x00, 0xa0, 0xc1, 0x95, 0x9a, 0xa9, 0xc8, 0x8a, 0xd1, 0x40,
		0x1f, 0xf6, 0xde, 0x6b, 0xaf, 0xde, 0xbd, 0xba, 0xd9, 0xeb, 0x7f, 0x3e, 0x6f, 0x0e, 0xda, 0xdd,
		0xce, 0xf5, 0xe0, 0xaf, 0x5e, 0xab, 0xaa, 0xf3, 0x0e, 0xd9, 0x48, 0xf9, 0xe5, 0xcb, 0xeb, 0xff,
		0xfc, 0xad, 0xad, 0xe5, 0x47, 0x43, 0xd7, 0xbf, 0x1c, 0xb4, 0xae, 0x7b, 0xdd, 0xf3, 0xf6, 0xc9,
		0x5f, 0xd7, 0xb3, 0x61, 0xac, 0x6a, 0x7b, 0xf1, 0x4f, 0x2d, 0x2d, 0x5f, 0x6d, 0xcd, 0xad, 0xba,
		0xc5, 0x02, 0x6b, 0x8a, 0x6f, 0xd1, 0x5b, 0xa5, 0x80, 0xa2, 0xbb, 0x2c, 0xcf, 0x6d, 0x47, 0xcc,
		0x7f, 0x19, 0xcd, 0xff, 0xad, 0xe2, 0x72, 0x3d, 0x75, 0xb3, 0xa1, 0xe2, 0xb0, 0x5d, 0x34, 0xb9,
		0xe1, 0xee, 0x5d, 0xa4, 0x21, 0x65, 0x9e, 0x37, 0x5c, 0xf0, 0xa4, 0x19, 0x37, 0xdd, 0x22, 0x69,
		0x46, 0xd2, 0xac, 0xd6, 0x01, 0xc7, 0x96, 0xaf, 0x2f, 0x6d, 0x9e, 0xb7, 0xaf, 0x27, 0x71, 0xae,
		0x23, 0x71, 0x46, 0xe2, 0x8c, 0xc4, 0xb9, 0xc8, 0x89, 0xb3, 0x6a, 0x87, 0xb5, 0x6c, 0x38, 0xa4,
		0x63, 0x9f, 0x53, 0x8b, 0x7a, 0x4e, 0xe0, 0xb3, 0x99, 0x30, 0xb1, 0xe6, 0xc4, 0x73, 0xe3, 0x8d,
		0x9a, 0x16, 0x8e, 0x1e, 0xe7, 0xa6, 0xdd, 0xc9, 0x65, 0xe1, 0xec, 0xb2, 0x75, 0x7a, 0x59, 0x39,
		0xbf, 0xcc, 0x9d, 0x60, 0xe6, 0xce, 0x30, 0x73, 0xa7, 0xa8, 0x97, 0x85, 0xf8, 0xa9, 0xc9, 0x72,
		0x74, 0x39, 0xcb, 0x97, 0x9c, 0xa6, 0xfe, 0x15, 0xfd, 0x82, 0xef, 0xd4, 0xbd, 0xae, 0xf5, 0xba,
		0xd0, 0xcc, 0x5c, 0x69, 0x96, 0x2e, 0x35, 0x1f, 0xd7, 0x9a, 0xb5, 0x8b, 0xcd, 0xcd, 0xd5, 0xe6,
		0xe6, 0x72, 0x73, 0x73, 0xbd, 0x7a, 0x5d, 0xb0, 0x66, 0x57, 0x9c, 0x99, 0x4b, 0x5e, 0xbe, 0x28,
		0x33, 0x9f, 0xbc, 0x61, 0xe8, 0x19, 0x39, 0xe5, 0xa7, 0xce, 0xb9, 0x96, 0xd1, 0xeb, 0xb2, 0x72,
		0xd2, 0x79, 0x38, 0xeb, 0x7c, 0x9d, 0x76, 0x5e, 0xce, 0x3b, 0x77, 0x27, 0x9e, 0xbb, 0x33, 0xcf,
		0xdd, 0xa9, 0x67, 0xe3, 0xdc, 0x33, 0x72, 0xf2, 0xcb, 0xd1, 0xd4, 0xb6, 0xcb, 0xff, 0xa6, 0xdd,
		0xba, 0x94, 0x0c, 0xf5, 0xec, 0xfc, 0xbf, 0x89, 0x91, 0x0f, 0x32, 0x7c, 0x67, 0x6f, 0xbe, 0xd1,
		0xf7, 0xfe, 0xfd, 0x6c, 0x73, 0xee, 0xc3, 0x32, 0xf6, 0xbc, 0x2b, 0xc7, 0x6a, 0xcd, 0x60, 0xa5,
		0x2a, 0x2e, 0x9b, 0x4d, 0xbc, 0x44, 0x55, 0x96, 0xd5, 0x16, 0x24, 0x81, 0xdb, 0xc4, 0x08, 0x0d,
		0x60, 0x04, 0x60, 0x04, 0x60, 0x04, 0x60, 0x84, 0xdc, 0x13, 0xc2, 0xe5, 0x0b, 0x49, 0x94, 0xbd,
		0xd1, 0x2c, 0xaf, 0x5b, 0x8f, 0xb2, 0xb6, 0x96, 0x6c, 0x93, 0xc3, 0xdc, 0x92, 0xc4, 0x3c, 0x03,
		0x41, 0x31, 0x02, 0x42, 0xde, 0x81, 0xa1, 0x30, 0x01, 0xa2, 0x30, 0x81, 0xa2, 0x30, 0x01, 0x23,
		0xdb, 0xc0, 0x91, 0x71, 0x00, 0xc9, 0x2f, 0xd9, 0x7c, 0xc6, 0xbb, 0x5b, 0xde, 0x64, 0x7c, 0x43,
		0xc3, 0x3c, 0xcc, 0x5e, 0xfe, 0x1e, 0x0a, 0xe1, 0x57, 0xab, 0xb9, 0xbf, 0x42, 0xf4, 0x9f, 0x7c,
		0xdc, 0x5c, 0x45, 0xf5, 0x7d, 0x19, 0x86, 0x45, 0xf8, 0x8d, 0xcf, 0x50, 0x7c, 0x3f, 0x87, 0xf0,
		0x77, 0x68, 0xb8, 0x4b, 0xc2, 0x10, 0x0f, 0xf8, 0x78, 0x69, 0x92, 0x1f, 0x58, 0x9a, 0x4f, 0x96,
		0xa6, 0xea, 0x7b, 0x4b, 0x4a, 0xb1, 0x46, 0xdf, 0x6d, 0xc7, 0x5b, 0xaf, 0xde, 0x95, 0xb3, 0x7f,
		0x19, 0xfa, 0x98, 0xec, 0xb7, 0x54, 0x37, 0x10, 0x56, 0xc6, 0x5b, 0xab, 0xc8, 0xa2, 0x91, 0x45,
		0x23, 0x8b, 0x46, 0x16, 0x8d, 0x2c, 0x3a, 0x43, 0xbb, 0x57, 0x72, 0x2f, 0x92, 0xac, 0xa7, 0x97,
		0xb9, 0x4f, 0x49, 0x76, 0xec, 0xb7, 0x2e, 0x8d, 0xd6, 0x74, 0xef, 0x93, 0xf4, 0x1a, 0x38, 0xcc,
		0xf1, 0x1b, 0x54, 0x5f, 0x30, 0x22, 0xfc, 0x21, 0xa6, 0xdd, 0xaa, 0x24, 0x9c, 0x20, 0xe4, 0x39,
		0xd9, 0x3a, 0xae, 0x94, 0xc1, 0x8c, 0x17, 0x2a, 0x25, 0xcc, 0x99, 0x14, 0x2a, 0x86, 0x7b, 0xdf,
		0x87, 0x7b, 0x2f, 0xa6, 0x7b, 0xc7, 0xbd, 0x53, 0x46, 0xde, 0x3b, 0x85, 0x60, 0x87, 0xf5, 0x8f,
		0xf5, 0x6f, 0x4c, 0xe8, 0x07, 0xeb, 0x6d, 0xd4, 0x9b, 0xb2, 0x2a, 0x81, 0xd3, 0x24, 0x06, 0xf5,
		0xe6, 0x7b, 0xf5, 0x8a, 0x45, 0xcd, 0x24, 0x90, 0xe6, 0xff, 0xfe, 0xf0, 0xf4, 0xb0, 0xff, 0xd3,
		0x5f, 0xa8, 0x14, 0x97, 0xca, 0x7f, 0xf5, 0x98, 0x7d, 0x46, 0xef, 0x77, 0xfa, 0x90, 0xe1, 0x66,
		0x4b, 0xf5, 0x9c, 0x45, 0xbc, 0xc9, 0x79, 0x46, 0xe7, 0x02, 0x2f, 0x98, 0xd7, 0x72, 0xe9, 0x98,
		0xce, 0x24, 0x2e, 0x32, 0xd8, 0x58, 0xa9, 0x5e, 0x90, 0x1f, 0x6b, 0x6f, 0xac, 0x1f, 0xee, 0xee,
		0xee, 0x1f, 0xec, 0xee, 0xd6, 0x0e, 0x76, 0x0e, 0x6a, 0x47, 0x7b, 0x7b, 0xf5, 0xfd, 0x7a, 0x06,
		0xdb, 0xd1, 0xd5, 0x6e, 0xe8, 0xd0, 0x90, 0x3a, 0xc7, 0xd3, 0x99, 0xf5, 0x26, 0xae, 0x6b, 0xf4,
		0x02, 0xcd, 0xd8, 0x61, 0x16, 0xca, 0x51, 0x56, 0x33, 0x39, 0x11, 0x13, 0x4e, 0x6c, 0xee, 0xcd,
		0xf3, 0xf6, 0xe3, 0x51, 0x70, 0x7d, 0xc9, 0x6e, 0xae, 0xa7, 0x36, 0xda, 0xa7, 0xfc, 0x7a, 0x10,
		0x7f, 0x77, 0x6b, 0xbd, 0x4f, 0xf3, 0xdf, 0x5d, 0xf7, 0xe3, 0x3e, 0x5c, 0x5f, 0xc6, 0x9f, 0xdc,
		0xca, 0xe4, 0x2c, 0xd2, 0x4f, 0x68, 0x5d, 0x64, 0x69, 0x13, 0xb9, 0xda, 0x82, 0x9e, 0x95, 0xa4,
		0x7e, 0x9e, 0x35, 0xcc, 0x71, 0x35, 0xa2, 0xa3, 0x69, 0x08, 0xb1, 0x5c, 0x16, 0x65, 0x21, 0xce,
		0xf4, 0xf8, 0x75, 0x50, 0x66, 0x7a, 0x9e, 0xca, 0x80, 0x32, 0x93, 0x38, 0xc4, 0x84, 0x32, 0xd3,
		0x16, 0x47, 0x2b, 0xed, 0xca, 0x4c, 0xeb, 0xfe, 0x2b, 0x3b, 0x59, 0xa6, 0x47, 0x6f, 0x85, 0x26,
		0x53, 0xd1, 0x9c, 0x69, 0x3e, 0x4e, 0x35, 0x6b, 0xe7, 0x9a, 0x9b, 0x93, 0xcd, 0xcd, 0xd9, 0xe6,
		0xe6, 0x74, 0xcb, 0xc1, 0xf7, 0x64, 0xa6, 0xc9, 0xc4, 0xbc, 0x88, 0x13, 0xcf, 0xa6, 0x32, 0xd7,
		0xe9, 0x0b, 0xdb, 0xfa, 0xfa, 0xcb, 0xa1, 0xcc, 0x64, 0x9a, 0xcb, 0xce, 0xd7, 0x75, 0xe7, 0xe5,
		0xc2, 0x73, 0x77, 0xe5, 0xb9, 0xbb, 0xf4, 0xdc, 0x5d, 0x7b, 0x36, 0x2e, 0x3e, 0x23, 0x57, 0xbf,
		0x1c, 0x4d, 0x28, 0x33, 0xe9, 0x76, 0x8d, 0x4f, 0x95, 0x99, 0xd6, 0xc3, 0x0f, 0xc4, 0x99, 0xd2,
		0xe6, 0x71, 0x51, 0x0e, 0xfa, 0x4c, 0x8b, 0x37, 0x97, 0x5c, 0xa2, 0x09, 0x60, 0x01, 0x60, 0x01,
		0x60, 0x01, 0x60, 0x21, 0xff, 0xfc, 0xf0, 0xa9, 0xd3, 0xcf, 0xef, 0x9c, 0xe9, 0xe2, 0x03, 0xf2,
		0x39, 0x66, 0x5a, 0xc7, 0x31, 0xd3, 0x92, 0x87, 0x86, 0xbc, 0x43, 0x44, 0x61, 0x42, 0x45, 0x61,
		0x42, 0x46, 0x61, 0x42, 0x47, 0xb6, 0x21, 0x24, 0xe3, 0x50, 0x92, 0x5b, 0x48, 0x59, 0xbe, 0x98,
		0x79, 0x0e, 0xcd, 0x4f, 0x19, 0x65, 0x8d, 0x8c, 0x9c, 0x7e, 0x46, 0x4e, 0x4b, 0x3c, 0x5f, 0x59,
		0x96, 0xdc, 0xc2, 0x4d, 0x11, 0xc2, 0x4e, 0xb1, 0xc2, 0x4f, 0x51, 0xc2, 0x50, 0xe1, 0xc2, 0x51,
		0xe1, 0xc2, 0x52, 0xe1, 0xc2, 0x53, 0x3e, 0x61, 0x2a, 0xa7, 0x70, 0xb5, 0x1c, 0xfd, 0xdc, 0xd4,
		0x11, 0x36, 0xfc, 0x46, 0xf6, 0x34, 0xea, 0x8b, 0xd9, 0xca, 0x41, 0xbe, 0xe7, 0x28, 0x9f, 0xd2,
		0xac, 0xd3, 0xc0, 0xba, 0x25, 0xc7, 0x7b, 0x72, 0x30, 0x83, 0x8c, 0xd5, 0xf2, 0x5f, 0xce, 0xd0,
		0x33, 0x54, 0xcf, 0x2f, 0x48, 0x9e, 0xbe, 0x09, 0xa0, 0x1a, 0x00, 0x50, 0x00, 0x50, 0x00, 0x50,
		0x00, 0x50, 0xc6, 0x00, 0xa8, 0xbc, 0xf2, 0xfe, 0x82, 0xe4, 0xff, 0x85, 0xe2, 0x01, 0x0a, 0xc2,
		0x07, 0x14, 0x86, 0x17, 0x28, 0x52, 0x78, 0x2b, 0x66, 0x98, 0x2b, 0x5a, 0xb8, 0x2b, 0x6c, 0xd8,
		0x2b, 0x6c, 0xf8, 0x2b, 0x6c, 0x18, 0xcc, 0x37, 0x1c, 0xe6, 0x1c, 0x16, 0x8b, 0xc3, 0x2f, 0x6c,
		0xf8, 0x9d, 0x09, 0xf3, 0xf8, 0xfe, 0x6e, 0x11, 0x7c, 0xce, 0x3c, 0x4a, 0x1d, 0x16, 0xe0, 0x53,
		0xf2, 0xbd, 0xf0, 0xe0, 0xe9, 0x3f, 0xc5, 0xf0, 0xc1, 0x95, 0xa2, 0x5c, 0x88, 0x50, 0x50, 0x78,
		0xb3, 0xf1, 0x59, 0x05, 0xb9, 0x30, 0x61, 0xe3, 0xbb, 0x0a, 0x24, 0x4e, 0x5f, 0x30, 0xf7, 0xfc,
		0x78, 0xa9, 0x93, 0x1f, 0x58, 0xea, 0x29, 0x97, 0x7a, 0x3e, 0xda, 0x17, 0xa5, 0x59, 0xfd, 0xef,
		0xf0, 0x15, 0x95, 0xdc, 0xc4, 0xbb, 0xf2, 0xef, 0x7f, 0x9e, 0xd7, 0xc9, 0xb8, 0xbe, 0x4d, 0x5c,
		0x8b, 0x79, 0x9c, 0x86, 0x43, 0x92, 0xed, 0x01, 0xae, 0x37, 0x21, 0xea, 0x33, 0xdf, 0x06, 0x42,
		0x05, 0x84, 0x0a, 0x08, 0x15, 0x10, 0x2a, 0x20, 0x54, 0x40, 0xa8, 0x14, 0x90, 0x50, 0xd9, 0x69,
		0x14, 0x88, 0x50, 0x39, 0x00, 0xa1, 0x02, 0x42, 0x05, 0x84, 0x0a, 0x08, 0x15, 0x10, 0x2a, 0xc6,
		0x2d, 0xf5, 0xa2, 0xdc, 0x68, 0x09, 0x1a, 0x05, 0x34, 0x0a, 0x68, 0x94, 0xc4, 0x34, 0xca, 0xfa,
		0x3d, 0x57, 0x45, 0xa3, 0x51, 0x8a, 0x71, 0x07, 0x17, 0x68, 0x14, 0xd0, 0x28, 0xa0, 0x51, 0x40,
		0xa3, 0x80, 0x46, 0x01, 0x8d, 0xf2, 0xac, 0xdf, 0x29, 0x50, 0x9c, 0xaa, 0x14, 0xe4, 0x52, 0xb1,
		0x55, 0x9c, 0x28, 0xc8, 0xe5, 0x4a, 0xcb, 0x0f, 0xda, 0x96, 0x1b, 0x05, 0x97, 0xd0, 0xba, 0x08,
		0x8b, 0xa0, 0x48, 0xd7, 0x6c, 0x6d, 0xef, 0x4a, 0x40, 0x92, 0x95, 0x5f, 0x92, 0xb5, 0x5f, 0xe0,
		0x24, 0x6b, 0x1f, 0x49, 0x16, 0x92, 0x2c, 0x24, 0x59, 0x48, 0xb2, 0x90, 0x64, 0x21, 0xc9, 0x2a,
		0x70, 0x92, 0xb5, 0x8f, 0x24, 0xcb, 0xac, 0x24, 0x0b, 0x37, 0xd9, 0x6e, 0xd5, 0x4d, 0xb6, 0x48,
		0x39, 0x61, 0x17, 0xb0, 0x0b, 0x24, 0xe0, 0x45, 0x4a, 0xc0, 0xc7, 0x81, 0x1b, 0x59, 0x37, 0x7e,
		0x81, 0xd2, 0xee, 0xe5, 0x17, 0x21, 0xd9, 0x46, 0xb2, 0x8d, 0x64, 0x1b, 0xc9, 0x36, 0x92, 0x6d,
		0x24, 0xdb, 0x05, 0x4b, 0xb6, 0x6f, 0x7c, 0xdf, 0xa5, 0xc4, 0x2b, 0x52, 0x9e, 0x5d, 0x07, 0x78,
		0xca, 0x07, 0x3c, 0x71, 0xbb, 0x60, 0xd8, 0x89, 0xdb, 0x80, 0x4e, 0x80, 0x4e, 0x80, 0x4e, 0x80,
		0x4e, 0x80, 0x4e, 0x80, 0x4e, 0x45, 0x3c, 0x53, 0x77, 0x58, 0x20, 0xe0, 0xb4, 0x87, 0x23, 0x75,
		0x4f, 0xfe, 0xc1, 0x91, 0x3a, 0x13, 0xd0, 0xcd, 0xc6, 0x67, 0xe1, 0x48, 0x9d, 0x69, 0xde, 0xf9,
		0xf1, 0x52, 0xc7, 0x91, 0xba, 0xd4, 0x4b, 0xfd, 0x00, 0x4b, 0xdd, 0x0c, 0x18, 0x54, 0x9c, 0xaf,
		0xc0, 0x1e, 0x53, 0x5e, 0x34, 0x09, 0x77, 0x8b, 0xc6, 0x93, 0x70, 0x17, 0x44, 0x09, 0x88, 0x12,
		0x10, 0x25, 0x20, 0x4a, 0x40, 0x94, 0x80, 0x28, 0x01, 0x51, 0x02, 0xa2, 0x04, 0x44, 0x09, 0x88,
		0x12, 0x64, 0x8f, 0x20, 0x4a, 0xca, 0xb6, 0xd4, 0x1b, 0x7b, 0x10, 0x1d, 0x02, 0x55, 0x02, 0xaa,
		0xa4, 0xf0, 0x54, 0x49, 0x48, 0xc7, 0x3e, 0xa7, 0x05, 0x55, 0x1d, 0x7a, 0xee, 0xe3, 0x40, 0xa0,
		0x80, 0x40, 0x01, 0x81, 0x02, 0x02, 0x05, 0x04, 0x0a, 0x08, 0x14, 0xc8, 0x0e, 0x25, 0x89, 0x55,
		0x38, 0x11, 0xfb, 0xdc, 0x07, 0x41, 0x76, 0x28, 0x87, 0x45, 0x00, 0xd9, 0x21, 0x9c, 0x7a, 0xdc,
		0xf2, 0x34, 0x6b, 0xbf, 0xc8, 0x69, 0x16, 0x84, 0x87, 0x90, 0x66, 0x21, 0xcd, 0x42, 0x9a, 0x85,
		0x34, 0x0b, 0x69, 0x56, 0x91, 0xd3, 0x2c, 0x08, 0x0f, 0x19, 0x96, 0x66, 0x41, 0x60, 0x05, 0xc2,
		0x43, 0x48, 0x3a, 0x61, 0x17, 0xb0, 0x0b, 0xa4, 0xe0, 0x39, 0x59, 0x5c, 0x54, 0xa4, 0x6b, 0x69,
		0x23, 0xdc, 0x43, 0x8b, 0x14, 0x1b, 0x29, 0x36, 0x52, 0x6c, 0xa4, 0xd8, 0x48, 0xb1, 0x8b, 0x97,
		0x62, 0x47, 0xa1, 0x15, 0x31, 0xc7, 0xe2, 0xd3, 0x0f, 0x2b, 0x50, 0x86, 0x7d, 0x54, 0x80, 0x6f,
		0x99, 0x4f, 0x16, 0x0a, 0xc2, 0x5f, 0x58, 0x3a, 0xf1, 0x49, 0x37, 0x97, 0xdc, 0x50, 0xb7, 0x5a,
		0xa0, 0x1a, 0xde, 0x02, 0xad, 0xa0, 0x62, 0xae, 0xa4, 0xe2, 0xad, 0xa8, 0x8d, 0x95, 0x55, 0x98,
		0xcb, 0xb1, 0x5f, 0x5a, 0x5d, 0x07, 0x05, 0xfc, 0xb4, 0x62, 0x1d, 0x60, 0x29, 0xfe, 0x6a, 0x5b,
		0x0e, 0x5c, 0x11, 0x0f, 0xb8, 0x14, 0x34, 0x87, 0x7b, 0xf3, 0x33, 0x17, 0xa7, 0x02, 0xea, 0xfb,
		0x05, 0xff, 0xd0, 0x02, 0x1f, 0x12, 0x28, 0x18, 0x68, 0x7d, 0xdd, 0x76, 0x0a, 0x78, 0x62, 0xc6,
		0x78, 0xdb, 0xa9, 0xed, 0x1e, 0xee, 0x1d, 0xec, 0xc1, 0x80, 0xca, 0x91, 0x73, 0x9a, 0xf3, 0x55,
		0x57, 0xef, 0xe0, 0xf6, 0x4c, 0x84, 0xcb, 0xd4, 0x9b, 0x8c, 0x69, 0x48, 0xa6, 0xd6, 0x58, 0x60,
		0xcc, 0x5c, 0xdf, 0x2d, 0xe0, 0xb7, 0xb5, 0xbc, 0xc9, 0x78, 0x1a, 0xc0, 0x8a, 0x65, 0x8c, 0xc5,
		0xf9, 0x9a, 0x62, 0xb8, 0x84, 0x82, 0xb8, 0x82, 0x02, 0x72, 0x30, 0x05, 0xab, 0x90, 0xd9, 0xb0,
		0xf9, 0xc3, 0x02, 0x7d, 0x53, 0xd1, 0x2a, 0x03, 0x96, 0x1f, 0x86, 0x0a, 0x81, 0x6d, 0xae, 0x10,
		0x58, 0xba, 0xda, 0x22, 0x99, 0x4a, 0x11, 0x2b, 0x69, 0x60, 0x2f, 0xb0, 0x97, 0xe2, 0x41, 0x13,
		0x54, 0x18, 0x6d, 0x1f, 0x28, 0xac, 0xf2, 0x22, 0xec, 0xe3, 0x2e, 0x41, 0x60, 0x01, 0x36, 0x6f,
		0x51, 0x63, 0xf4, 0x34, 0x82, 0xa2, 0xc6, 0xe8, 0x8d, 0xaf, 0x42, 0x8d, 0x51, 0xc2, 0x0f, 0x43,
		0x8d, 0x91, 0x51, 0x31, 0x19, 0x35, 0x46, 0x4f, 0xfd, 0x4e, 0xb1, 0xf8, 0xc9, 0x22, 0xf1, 0x91,
		0x05, 0xe1, 0x1f, 0x73, 0x04, 0x71, 0xef, 0xb6, 0xc8, 0x44, 0xab, 0x4d, 0xcf, 0xf3, 0xf9, 0xcc,
		0x0e, 0xf2, 0x34, 0xd0, 0x6a, 0x64, 0xdf, 0xd2, 0x31, 0x09, 0x08, 0xbf, 0x9d, 0x9a, 0xe7, 0x07,
		0x3f, 0xa0, 0x9e, 0x1d, 0x03, 0xa7, 0xa9, 0xff, 0xfe, 0x30, 0xfd, 0x7f, 0xc8, 0x6e, 0x3e, 0x10,
		0xce, 0x43, 0x2b, 0xa2, 0x3c, 0x5a, 0xfe, 0xf4, 0x81, 0x4f, 0x3c, 0x8f, 0xba, 0x16, 0xf5, 0x6c,
		0x12, 0x44, 0x13, 0x37, 0xee, 0xca, 0xfc, 0x97, 0xd1, 0xfc, 0xdf, 0x1f, 0xa2, 0xc9, 0x0d, 0x77,
		0xef, 0xa2, 0xf9, 0xbf, 0x3f, 0x44, 0x74, 0x34, 0x8d, 0x11, 0x96, 0xcb, 0x22, 0x1e, 0x3d, 0xfa,
		0xd3, 0xe2, 0x0f, 0xcb, 0xdf, 0x7e, 0x88, 0x38, 0xe1, 0x34, 0x9f, 0xf8, 0x91, 0xfd, 0x42, 0xcc,
		0xf6, 0x8d, 0x19, 0x2f, 0xf9, 0x29, 0x9a, 0x8a, 0xf9, 0x69, 0xcf, 0xa1, 0x59, 0x03, 0xa9, 0xea,
		0x39, 0x8b, 0x78, 0x93, 0xf3, 0x30, 0x17, 0x23, 0xab, 0x5e, 0x30, 0xaf, 0xe5, 0xd2, 0x78, 0x61,
		0xe7, 0x93, 0x87, 0x54, 0x2f, 0xc8, 0x8f, 0xb5, 0x2f, 0xa8, 0x1f, 0xee, 0xee, 0xee, 0x1f, 0xec,
		0xee, 0xd6, 0x0e, 0x76, 0x0e, 0x6a, 0x47, 0x7b, 0x7b, 0xf5, 0xfd, 0x7a, 0x0e, 0xb5, 0x05, 0xd5,
		0x6e, 0xe8, 0xd0, 0x90, 0x3a, 0xc7, 0xd3, 0x65, 0xe1, 0x4d, 0x5c, 0xb7, 0xd4, 0xab, 0x3f, 0x67,
		0x47, 0x5f, 0x54, 0x07, 0x9f, 0x03, 0xfa, 0xab, 0x46, 0x3c, 0x9c, 0xd8, 0xdc, 0x9b, 0x43, 0xd1,
		0xe3, 0x51, 0x70, 0x7d, 0xc9, 0x6e, 0xae, 0xa7, 0xee, 0xa1, 0x4f, 0xf9, 0xf5, 0x20, 0xee, 0x52,
		0x6b, 0xbd, 0xbb, 0xf3, 0xdf, 0x5d, 0xf7, 0xe3, 0xee, 0x5d, 0xf7, 0x67, 0x9f, 0x3e, 0xf5, 0x29,
		0x8b, 0x9f, 0xb3, 0x8d, 0x50, 0xd9, 0xc5, 0x89, 0x6c, 0xde, 0x94, 0x91, 0x2d, 0xe6, 0x65, 0x83,
		0x45, 0xb3, 0xbd, 0x6c, 0x16, 0xab, 0xfe, 0xa5, 0x93, 0xc1, 0xb2, 0xa9, 0xce, 0xf0, 0x67, 0x56,
		0xab, 0x65, 0x75, 0x06, 0x27, 0x7e, 0x6d, 0x46, 0x66, 0xb1, 0xc8, 0x7e, 0x33, 0x7a, 0xdd, 0x92,
		0x90, 0x6d, 0x64, 0xf4, 0xc2, 0x1c, 0x88, 0xd7, 0x7c, 0x09, 0xd6, 0xbc, 0x88, 0xd4, 0xdc, 0x09,
		0xd3, 0xdc, 0x89, 0xd1, 0xdc, 0x09, 0xd0, 0x72, 0x05, 0xec, 0x53, 0x96, 0x6d, 0xc6, 0x56, 0x65,
		0x5e, 0xc4, 0x89, 0x67, 0x53, 0x2b, 0x07, 0xbd, 0x80, 0x55, 0x05, 0xd7, 0xda, 0x47, 0x64, 0x9d,
		0xa3, 0xe7, 0xb2, 0x67, 0x97, 0xdb, 0x1e, 0x5d, 0x9e, 0x7b, 0x72, 0xc5, 0xd8, 0x83, 0xcb, 0x7b,
		0xcf, 0xad, 0x30, 0x7b, 0x6c, 0x85, 0xd9, 0x53, 0x2b, 0xcc, 0x1e, 0x5a, 0xb9, 0xd9, 0xc8, 0xdc,
		0xf6, 0xc4, 0x1e, 0x1d, 0x69, 0xdd, 0xdf, 0xcd, 0xc3, 0xe6, 0xe7, 0x5e, 0x3e, 0x87, 0x4a, 0xdc,
		0x9c, 0x8f, 0xa4, 0xe6, 0xb8, 0xc1, 0x52, 0x84, 0x23, 0xa5, 0x45, 0x29, 0xc9, 0x29, 0xc8, 0x9d,
		0x68, 0x45, 0x3a, 0xb0, 0x96, 0x67, 0xe9, 0x5a, 0x11, 0x4e, 0x6c, 0x16, 0x6d, 0x69, 0x16, 0x63,
		0x8b, 0xa4, 0xb0, 0xab, 0x75, 0x4b, 0x36, 0x64, 0xaf, 0xca, 0x4a, 0xeb, 0x67, 0xc8, 0x45, 0xdd,
		0x53, 0x36, 0xba, 0xe5, 0xf9, 0x65, 0xd3, 0xf3, 0xf7, 0x23, 0x91, 0x46, 0x22, 0x8d, 0x44, 0x1a,
		0x89, 0x34, 0x12, 0xe9, 0x52, 0x26, 0xd2, 0xb9, 0x68, 0x43, 0xe5, 0xa8, 0xfd, 0x84, 0x44, 0x1a,
		0xd9, 0x0a, 0x12, 0x69, 0x24, 0xd2, 0x85, 0x5f, 0x9a, 0xbb, 0x8d, 0xa3, 0xdd, 0xa3, 0xfd, 0x83,
		0xc6, 0x11, 0xd2, 0x67, 0xa4, 0xcf, 0x65, 0x49, 0x9f, 0x51, 0x15, 0xa7, 0xe0, 0xbd, 0x45, 0xa9,
		0x8a, 0xcb, 0xee, 0x84, 0x41, 0x06, 0x25, 0x71, 0xef, 0x0c, 0x5e, 0x91, 0xab, 0x13, 0x02, 0x59,
		0xd5, 0x3f, 0x64, 0x7b, 0x2e, 0x20, 0xfb, 0x73, 0x00, 0x85, 0xa8, 0xfb, 0xcf, 0xb6, 0xce, 0x5f,
		0xf7, 0x1a, 0xcd, 0xd8, 0x5b, 0x16, 0xc4, 0x4b, 0x56, 0x33, 0x29, 0xb5, 0x55, 0x56, 0x96, 0xaf,
		0xd7, 0x9d, 0xeb, 0x73, 0xb2, 0x7a, 0x5a, 0xd6, 0x64, 0x12, 0x59, 0x99, 0x42, 0x7e, 0x26, 0xa0,
		0x67, 0x19, 0xa9, 0x9f, 0x64, 0x0d, 0x13, 0xac, 0xb9, 0xf0, 0x3d, 0x93, 0x42, 0x77, 0xcd, 0x85,
		0xed, 0xda, 0x0b, 0xd9, 0xb3, 0xd8, 0x54, 0xc9, 0x76, 0xf3, 0x24, 0xab, 0x4d, 0x92, 0xcc, 0x37,
		0x43, 0x32, 0xdf, 0xf4, 0xc8, 0x7c, 0x73, 0xc3, 0xac, 0xd0, 0xa4, 0xbb, 0x70, 0xbc, 0x7a, 0xc3,
		0x3c, 0x87, 0x79, 0x23, 0x2b, 0x8b, 0x8b, 0xe5, 0x96, 0x36, 0xba, 0xfe, 0x52, 0xdd, 0xa9, 0x58,
		0x26, 0x2c, 0x62, 0x66, 0xfb, 0xd5, 0x59, 0xee, 0x4f, 0xe7, 0xb3, 0x1f, 0x9d, 0xf5, 0xfe, 0x73,
		0x6e, 0xfb, 0xcd, 0xb9, 0xed, 0x2f, 0xe7, 0xb6, 0x9f, 0x6c, 0x36, 0xa9, 0x93, 0xd9, 0xfe, 0x70,
		0x4e, 0x17, 0x98, 0x65, 0x79, 0xbd, 0x54, 0xb6, 0xd7, 0x46, 0xe5, 0x70, 0x5c, 0x32, 0x97, 0x0b,
		0xc4, 0xf2, 0xb8, 0x20, 0x2c, 0x9f, 0x0b, 0xc0, 0x50, 0xa4, 0x91, 0xed, 0xab, 0x51, 0xa4, 0x91,
		0xe3, 0x3f, 0x85, 0x2b, 0x29, 0xdf, 0xc7, 0x0e, 0x78, 0x46, 0xa0, 0xe3, 0xf5, 0xb5, 0x89, 0x2a,
		0x8d, 0xcd, 0xb5, 0x59, 0x84, 0x0b, 0xa6, 0x50, 0xa2, 0x51, 0xfa, 0x12, 0x8d, 0x5f, 0xb7, 0x05,
		0xee, 0xe4, 0x2b, 0x70, 0x9a, 0xa7, 0xa0, 0x69, 0x4e, 0x02, 0xa6, 0xd9, 0xbd, 0xed, 0xaa, 0x4c,
		0xd5, 0x3f, 0x39, 0xe4, 0x78, 0x39, 0x5d, 0x50, 0x94, 0xc7, 0x05, 0x44, 0xb9, 0x5d, 0x30, 0x84,
		0x0b, 0x51, 0xb6, 0xe2, 0x42, 0x94, 0xab, 0x2c, 0x97, 0x72, 0x9e, 0x17, 0x00, 0x61, 0x3d, 0x6f,
		0xc7, 0x7a, 0x2e, 0x49, 0x19, 0xe6, 0x95, 0xa9, 0xf5, 0x47, 0x1a, 0xb7, 0xfe, 0x6d, 0xdf, 0xf5,
		0xc3, 0x28, 0xbb, 0xcd, 0xd2, 0xf9, 0xfb, 0xb0, 0x4f, 0x9a, 0xce, 0xcb, 0x63, 0x9f, 0x54, 0xf5,
		0x0a, 0xc1, 0x3e, 0x29, 0xf6, 0x49, 0x13, 0x8c, 0x5a, 0xf6, 0xfb, 0xa4, 0x99, 0x6d, 0xc9, 0x64,
		0xb8, 0x05, 0x93, 0xf1, 0x96, 0x4b, 0x86, 0xe9, 0x73, 0x1e, 0x5b, 0x2a, 0x79, 0xc9, 0x58, 0xe4,
		0x74, 0xae, 0x35, 0x4f, 0x02, 0x3a, 0x4b, 0x49, 0x96, 0x3c, 0x76, 0x40, 0xf2, 0x5e, 0x4a, 0x79,
		0x9d, 0x43, 0xcd, 0x75, 0x4d, 0x21, 0x9d, 0x2a, 0x40, 0x60, 0xc7, 0x19, 0xb3, 0xd2, 0x9d, 0x31,
		0x33, 0x32, 0x01, 0x9f, 0x66, 0x1f, 0x34, 0xa4, 0x5e, 0x16, 0xf5, 0xf7, 0x0b, 0x88, 0xb9, 0xf6,
		0x4e, 0xcd, 0x56, 0x76, 0x4a, 0x87, 0x64, 0xe2, 0xc6, 0x39, 0x47, 0xbd, 0x56, 0x43, 0xda, 0x8f,
		0xb4, 0x1f, 0x69, 0x3f, 0xd2, 0x7e, 0xa4, 0xfd, 0x48, 0xfb, 0x91, 0xf6, 0x23, 0xed, 0x47, 0xda,
		0x8f, 0xb4, 0x1f, 0x69, 0x3f, 0xd2, 0x7e, 0xe3, 0x93, 0x38, 0x9e, 0x05, 0x5c, 0x58, 0x42, 0x85,
		0x0c, 0x8e, 0x50, 0x21, 0x95, 0x42, 0x2a, 0x85, 0x54, 0x0a, 0xa9, 0x94, 0x91, 0xa9, 0x14, 0x73,
		0xa8, 0xc7, 0x19, 0x7f, 0x08, 0xe9, 0x30, 0xcb, 0x93, 0xa6, 0x59, 0x10, 0xaa, 0xed, 0x79, 0xd7,
		0x8e, 0x49, 0x94, 0xc3, 0xfd, 0xa7, 0x83, 0xcf, 0x9d, 0x4e, 0xeb, 0xfc, 0xba, 0xd5, 0x39, 0x69,
		0xf6, 0xfa, 0x9f, 0xcf, 0x9b, 0x83, 0x76, 0xb7, 0x73, 0xdd, 0xff, 0x7c, 0x3c, 0x38, 0xff, 0x72,
		0x3d, 0xf8, 0xab, 0xd7, 0xca, 0xca, 0x03, 0xc4, 0x30, 0x32, 0xca, 0xb4, 0xdc, 0x31, 0xa7, 0x6b,
		0x12, 0xe6, 0x23, 0x7e, 0xd2, 0x3d, 0xef, 0x5e, 0x56, 0xcb, 0x98, 0xfe, 0xe4, 0x34, 0xae, 0xfd,
		0xcb, 0x41, 0xeb, 0xba, 0xdf, 0xfa, 0x74, 0xd1, 0xea, 0x0c, 0xae, 0xcf, 0xdb, 0xfd, 0x01, 0x06,
		0x57, 0xf1, 0xe0, 0x1e, 0xb7, 0x3b, 0xa7, 0xed, 0xce, 0xa7, 0xeb, 0x7e, 0xfb, 0x14, 0x63, 0xab,
		0x78, 0x6c, 0x7b, 0x97, 0xad, 0xb3, 0xd6, 0x65, 0xab, 0x73, 0xd2, 0xc2, 0xd0, 0x2a, 0xf7, 0xb5,
		0x97, 0xad, 0x8b, 0xee, 0xa0, 0x75, 0xdd, 0xea, 0x9c, 0xf6, 0xba, 0xed, 0xce, 0xa0, 0x6c, 0x97,
		0x04, 0x5f, 0x99, 0x0e, 0x57, 0xa1, 0xa5, 0x55, 0x29, 0xad, 0xcc, 0xa3, 0x3e, 0xd1, 0x67, 0x33,
		0xe4, 0x1d, 0xb5, 0xf2, 0x48, 0x59, 0xf0, 0x47, 0x9a, 0x79, 0x23, 0xed, 0x7c, 0x11, 0xc4, 0x1d,
		0x8d, 0xe1, 0x83, 0x20, 0xee, 0x58, 0xac, 0x80, 0xa4, 0x9d, 0xe7, 0x59, 0xda, 0x8d, 0x4b, 0xc9,
		0x50, 0x2f, 0xb7, 0xb3, 0xe4, 0x74, 0x34, 0x6e, 0x92, 0x57, 0x7b, 0xf3, 0x98, 0xfa, 0xfe, 0xfd,
		0x2c, 0xf0, 0x7d, 0x88, 0xfd, 0xb2, 0x29, 0xd1, 0xef, 0x5d, 0x81, 0xd7, 0xe4, 0xe2, 0xca, 0x02,
		0x0d, 0x81, 0x4e, 0x6f, 0xdd, 0xa8, 0xfe, 0x3a, 0xd1, 0x5c, 0xea, 0x42, 0xf5, 0xd6, 0x81, 0xaa,
		0x5e, 0x3c, 0x9a, 0x91, 0x75, 0x96, 0x88, 0xba, 0xaa, 0x45, 0x82, 0x5c, 0xea, 0x42, 0x00, 0xb5,
		0x0e, 0x4e, 0x9d, 0x1b, 0x52, 0xd3, 0x92, 0xa2, 0xb5, 0xa8, 0x6b, 0x0d, 0x66, 0xb2, 0xf6, 0xd4,
		0xcc, 0xb0, 0xfc, 0x7c, 0x28, 0x98, 0x0b, 0xb5, 0x09, 0x99, 0x8e, 0x04, 0x4c, 0x71, 0xc2, 0xa5,
		0x3c, 0xc1, 0xd2, 0x91, 0x50, 0xe9, 0x4d, 0xa0, 0x74, 0x25, 0x4c, 0xda, 0x13, 0x24, 0xed, 0x09,
		0x91, 0xf6, 0x04, 0xa8, 0x58, 0x3e, 0x58, 0x79, 0x42, 0xa3, 0x31, 0x81, 0xd1, 0x91, 0xb0, 0xe8,
		0x4c, 0x50, 0x14, 0x78, 0xf7, 0x77, 0x39, 0xae, 0x11, 0x85, 0x09, 0x86, 0xda, 0x84, 0x42, 0x7d,
		0x02, 0x91, 0x49, 0xc2, 0xa0, 0x36, 0x41, 0x90, 0x9d, 0x5c, 0xc5, 0xe0, 0x4b, 0x2b, 0xe8, 0x52,
		0xe0, 0x43, 0x84, 0x11, 0xbd, 0x9c, 0x2b, 0x10, 0x37, 0x60, 0xb1, 0x27, 0x05, 0x57, 0x85, 0xaa,
		0xd5, 0xa0, 0x67, 0x15, 0x88, 0x4d, 0x41, 0xfa, 0x01, 0x4c, 0xf7, 0x44, 0xca, 0xa1, 0x96, 0x1d,
		0x62, 0xb5, 0x43, 0x2b, 0x60, 0x51, 0xe9, 0x2d, 0x28, 0xdd, 0xbc, 0x25, 0x1f, 0xfd, 0x64, 0x7f,
		0x33, 0xe1, 0xfc, 0xac, 0x6e, 0xfe, 0x74, 0x68, 0x52, 0xb0, 0x2a, 0x16, 0xce, 0xc4, 0xc3, 0x96,
		0xd2, 0xf0, 0x24, 0x16, 0x86, 0x92, 0x8e, 0xa6, 0xe0, 0x2a, 0x17, 0x5e, 0xdd, 0x29, 0x16, 0xf2,
		0xeb, 0x0b, 0x38, 0xd9, 0x62, 0x7d, 0x7b, 0xe9, 0xbd, 0xfe, 0x37, 0xde, 0x18, 0xc6, 0xb4, 0xc3,
		0x97, 0x76, 0xd8, 0x5e, 0xef, 0xe4, 0xcb, 0x9f, 0xfe, 0xca, 0x67, 0x57, 0x6d, 0x7f, 0x3c, 0x9e,
		0x78, 0x8c, 0x33, 0xfa, 0xb6, 0xc2, 0xda, 0x9a, 0x42, 0xda, 0xea, 0xa1, 0x37, 0x86, 0x24, 0xd9,
		0x4d, 0x7a, 0x89, 0x73, 0xfa, 0x34, 0xb9, 0xba, 0x58, 0x0e, 0x9e, 0x36, 0xb7, 0x16, 0xce, 0x99,
		0x85, 0x73, 0x61, 0xe1, 0x1c, 0x57, 0x6e, 0x71, 0x27, 0xbd, 0x19, 0x6d, 0xb9, 0x3a, 0x1e, 0x92,
		0x8f, 0xe1, 0xd3, 0x85, 0xf5, 0x90, 0x74, 0x0c, 0xd3, 0x5d, 0xd4, 0x98, 0x9a, 0x3a, 0x12, 0xa1,
		0x86, 0xe4, 0xa8, 0x1f, 0x51, 0x6a, 0x47, 0x9a, 0xba, 0x91, 0xa6, 0x66, 0xa4, 0xa9, 0x17, 0xb5,
		0xc0, 0x20, 0xed, 0x45, 0x7e, 0x73, 0x08, 0x91, 0x7a, 0xdc, 0x97, 0x15, 0xfd, 0x29, 0x10, 0x88,
		0x24, 0x33, 0x2a, 0xcc, 0x80, 0xca, 0x30, 0x9d, 0x6a, 0x18, 0x4d, 0x59, 0xe6, 0x52, 0x19, 0x43,
		0xa9, 0x8c, 0x89, 0x54, 0xc6, 0x38, 0xea, 0xcd, 0x5f, 0x84, 0x99, 0x42, 0x05, 0x8c, 0xa0, 0x0c,
		0xf3, 0xb7, 0xc9, 0xf0, 0xcd, 0x0c, 0x4d, 0x57, 0x72, 0x92, 0x0a, 0x90, 0x8a, 0x5c, 0x74, 0x2c,
		0x75, 0x81, 0xb1, 0xe0, 0xc5, 0xc4, 0xc2, 0x17, 0x0e, 0xc3, 0x61, 0x6c, 0xad, 0xc3, 0x10, 0xbd,
		0x08, 0x57, 0x00, 0xfe, 0x29, 0x83, 0x83, 0x8a, 0xe2, 0xab, 0x74, 0x9c, 0x55, 0x61, 0x3e, 0x6a,
		0xcd, 0x48, 0x95, 0x39, 0x29, 0x37, 0x2b, 0xe5, 0xe6, 0xa5, 0xdc, 0xcc, 0xf2, 0xa1, 0x74, 0xa5,
		0x77, 0xf6, 0x56, 0xaa, 0x3d, 0x9e, 0xdc, 0x55, 0x42, 0x2a, 0x2e, 0xb9, 0x54, 0x73, 0x69, 0xa5,
		0x82, 0x7d, 0x8e, 0xe5, 0x85, 0xd8, 0xa3, 0xc0, 0xba, 0xa7, 0xae, 0x6b, 0x7d, 0xf7, 0xfc, 0x7b,
		0xcf, 0x5a, 0x3a, 0x1a, 0x55, 0x77, 0xbf, 0xaa, 0x3c, 0x71, 0xab, 0xe7, 0x44, 0xed, 0x72, 0x28,
		0x8e, 0x3f, 0xf5, 0xae, 0xff, 0x68, 0x9d, 0x9f, 0x5f, 0xff, 0xde, 0xe9, 0xfe, 0xd1, 0xb9, 0xee,
		0x0f, 0x4e, 0xaf, 0x4f, 0xba, 0x17, 0x17, 0x9f, 0x3b, 0xed, 0xc1, 0x5f, 0xaa, 0x2a, 0x40, 0x34,
		0x9c, 0x86, 0x55, 0x5c, 0xf9, 0xb0, 0x18, 0x8d, 0x4e, 0xf7, 0xba, 0xf5, 0x67, 0xaf, 0x7b, 0xa9,
		0xf0, 0x50, 0x95, 0xc2, 0xe2, 0x3f, 0x7d, 0x9d, 0x6e, 0x9e, 0x7e, 0x69, 0x5d, 0x0e, 0xda, 0xfd,
		0xd6, 0x76, 0xf5, 0xbb, 0xd7, 0x6a, 0x5d, 0x6e, 0xd9, 0x4c, 0xcf, 0x96, 0xf7, 0x75, 0xff, 0xf3,
		0xf1, 0x49, 0xb7, 0x73, 0xd6, 0x3a, 0x2d, 0x5a, 0x6d, 0xcc, 0x95, 0xd9, 0x75, 0x17, 0x8a, 0x83,
		0x54, 0xc4, 0x1d, 0x8d, 0xd1, 0x49, 0xc1, 0xbd, 0xd5, 0x6a, 0xef, 0xa3, 0xd6, 0x50, 0xc9, 0xa4,
		0x5c, 0xb5, 0x50, 0x83, 0x3a, 0xa1, 0x26, 0x15, 0x42, 0x3d, 0xd5, 0xff, 0xfa, 0x4e, 0xff, 0x69,
		0x3e, 0x99, 0xa7, 0x59, 0x25, 0x30, 0x0b, 0xe5, 0xb6, 0x9f, 0x7a, 0x8e, 0x5b, 0x18, 0x3f, 0xa5,
		0xba, 0xd5, 0xfa, 0x32, 0x99, 0xdb, 0x82, 0x1e, 0x3b, 0xb8, 0x2a, 0x52, 0xc9, 0xab, 0x86, 0x00,
		0x11, 0xf1, 0x90, 0x79, 0x23, 0x1d, 0x95, 0xae, 0x87, 0x6a, 0x2b, 0x5d, 0xb5, 0x5c, 0xa0, 0x58,
		0xfd, 0xcf, 0xbf, 0xf7, 0xf7, 0xf6, 0x76, 0xbe, 0xd6, 0xac, 0xbd, 0xab, 0x7f, 0xf6, 0xf7, 0xf6,
		0xbe, 0xd6, 0xac, 0xc6, 0xd5, 0xd7, 0x9a, 0x75, 0x34, 0xfd, 0xd3, 0x6e, 0xfc, 0xc3, 0xdf, 0x8d,
		0x9f, 0xff, 0xec, 0x4f, 0xff, 0xc3, 0xee, 0xd5, 0xea, 0xcf, 0x6b, 0x7f, 0xdc, 0xf9, 0xf9, 0xcf,
		0xd7, 0xba, 0xb5, 0x37, 0xff, 0xd3, 0x6e, 0xfc, 0xa7, 0xa3, 0xf9, 0x9f, 0xe2, 0x4b, 0x0b, 0xe3,
		0x1f, 0x7f, 0xf9, 0x98, 0xd5, 0x8b, 0x14, 0xde, 0x3b, 0x78, 0xa5, 0x72, 0x06, 0x75, 0xde, 0x83,
		0x89, 0x69, 0xcc, 0xc0, 0x85, 0xbd, 0xcb, 0xf7, 0x3b, 0xc4, 0xdf, 0x7f, 0x95, 0x29, 0x77, 0xa9,
		0xa4, 0x5c, 0x5c, 0x5d, 0x99, 0xb8, 0xd6, 0xf2, 0x70, 0x35, 0x65, 0xe1, 0x02, 0xd5, 0xae, 0x02,
		0x5b, 0x69, 0x62, 0x15, 0x0e, 0x1b, 0xf1, 0x52, 0xa4, 0xd2, 0x41, 0x11, 0x1e, 0xc4, 0x8e, 0xcc,
		0x2b, 0x23, 0x8b, 0x1d, 0x19, 0xad, 0x5e, 0x4d, 0xe1, 0x8e, 0x0c, 0xf3, 0xf8, 0xfe, 0xae, 0x82,
		0x2d, 0x19, 0x09, 0x7c, 0xa9, 0x88, 0x71, 0x50, 0x73, 0x1c, 0x48, 0xdd, 0xa6, 0x86, 0xe2, 0xa3,
		0xa6, 0x8a, 0x19, 0x03, 0x1d, 0x59, 0xe4, 0x4f, 0x35, 0xe7, 0xa7, 0x0a, 0x3f, 0x05, 0xfa, 0x64,
		0x20, 0xb4, 0xcc, 0x8a, 0x59, 0x40, 0x6f, 0x2b, 0x0f, 0xdb, 0xac, 0x55, 0xb1, 0x2f, 0x7f, 0x7e,
		0x10, 0x11, 0x78, 0xc3, 0xd9, 0x97, 0x6c, 0xb0, 0xb7, 0xc9, 0x67, 0x5f, 0x9e, 0x5d, 0x6c, 0xf2,
		0xc7, 0x5f, 0x4e, 0x96, 0x4d, 0x95, 0xf8, 0x00, 0xcc, 0xfa, 0x71, 0x13, 0x0d, 0x47, 0x60, 0xe8,
		0x0f, 0x6e, 0x09, 0x1d, 0x83, 0x79, 0xfa, 0x20, 0x8e, 0xc2, 0xe0, 0x28, 0xcc, 0xcb, 0x4b, 0x4b,
		0xe0, 0x38, 0xcc, 0xe3, 0xc7, 0x71, 0x24, 0x06, 0x47, 0x62, 0xa4, 0x22, 0x1c, 0x8e, 0xc4, 0xa8,
		0x25, 0x84, 0x50, 0xe1, 0xae, 0x99, 0xe8, 0xc1, 0x91, 0x98, 0xe7, 0x97, 0x2c, 0x8e, 0xc4, 0x08,
		0xc7, 0xbb, 0x4d, 0x87, 0x81, 0x23, 0x31, 0x70, 0x18, 0x15, 0x2d, 0xf1, 0x53, 0x12, 0x06, 0x2a,
		0x85, 0x85, 0x8a, 0x69, 0x3a, 0x6c, 0xc4, 0xe8, 0x37, 0x2f, 0xe5, 0x66, 0xa6, 0xdc, 0xdc, 0xe4,
		0xf8, 0xca, 0xfc, 0x37, 0x62, 0x6e, 0x46, 0x81, 0xf5, 0xc8, 0x98, 0xac, 0x90, 0xda, 0x77, 0xb2,
		0x55, 0xb6, 0xa5, 0x3d, 0x30, 0xf3, 0x78, 0xa8, 0x50, 0x8b, 0x2c, 0x02, 0x70, 0x50, 0x6a, 0x96,
		0x4d, 0x8d, 0xd2, 0xb2, 0x20, 0x74, 0xf6, 0xb6, 0xc5, 0x1f, 0xbf, 0xd6, 0xac, 0xc3, 0xf9, 0x2b,
		0xe7, 0xbf, 0xfa, 0x5a, 0xb3, 0xea, 0xab, 0x77, 0xcd, 0x7e, 0xf9, 0xb5, 0x66, 0xed, 0xaf, 0x5e,
		0x18, 0xff, 0x2e, 0x6e, 0x66, 0xf9, 0xd6, 0xe9, 0xaf, 0x56, 0x4d, 0xfd, 0xbd, 0x17, 0xff, 0xe6,
		0x6b, 0xcd, 0xda, 0x99, 0xff, 0x62, 0xff, 0xe7, 0x3f, 0xbb, 0x6b, 0x0d, 0x1f, 0xc4, 0xdf, 0xb9,
		0xf8, 0x8f, 0x47, 0x4f, 0xbe, 0xfa, 0x10, 0x75, 0x6b, 0x58, 0x13, 0x59, 0xac, 0x09, 0xd4, 0xf1,
		0x96, 0xdb, 0xb9, 0xfe, 0x7b, 0xb6, 0x88, 0x57, 0x0b, 0xe9, 0x9f, 0x7a, 0xfc, 0xaf, 0xd9, 0xcf,
		0x8d, 0x95, 0xc9, 0xfc, 0xd3, 0xd8, 0x8b, 0xd7, 0xee, 0x2f, 0xdf, 0xbe, 0xbd, 0xff, 0xe5, 0xef,
		0x9d, 0x9f, 0xe9, 0x1f, 0x44, 0x2d, 0xaf, 0x5e, 0x9f, 0x88, 0xa9, 0x84, 0x2b, 0xdb, 0x66, 0x57,
		0x66, 0x62, 0xa8, 0x86, 0x4f, 0xd4, 0xeb, 0x13, 0xb1, 0x26, 0xe0, 0x5c, 0xe1, 0x5c, 0xe5, 0x0d,
		0x29, 0xf4, 0x27, 0x9c, 0x7e, 0xfb, 0x66, 0x71, 0x12, 0x8e, 0x28, 0xff, 0x88, 0xfc, 0x0b, 0x39,
		0x39, 0x96, 0x08, 0x52, 0x74, 0xb8, 0xde, 0xec, 0x5d, 0x2f, 0xd2, 0xbc, 0xb2, 0x7a, 0x4c, 0xcc,
		0x2c, 0x1c, 0x1d, 0x1c, 0xdd, 0xd2, 0x1c, 0x90, 0xbb, 0xc1, 0x63, 0x62, 0x89, 0xc0, 0xf5, 0xc2,
		0xf5, 0x66, 0xe6, 0x7a, 0xfd, 0x90, 0x8d, 0x98, 0x87, 0xdc, 0x0d, 0xe9, 0x3d, 0x96, 0x08, 0xd2,
		0x7b, 0xb8, 0xde, 0x1c, 0x5c, 0x2f, 0x92, 0xc0, 0xb2, 0x7a, 0x4c, 0xcc, 0x2c, 0x1c, 0x1d, 0x1c,
		0xdd, 0xd2, 0x1c, 0x90, 0xbb, 0xc1, 0x63, 0x62, 0x89, 0xc0, 0xf5, 0xc2, 0xf5, 0x6a, 0x77, 0xbd,
		0xb6, 0xef, 0xfa, 0xe1, 0xc7, 0x78, 0x2d, 0xff, 0xdd, 0xf8, 0x89, 0x94, 0xca, 0x1c, 0x8f, 0x88,
		0x99, 0xd3, 0xe1, 0xa8, 0xf2, 0xd6, 0x64, 0x2d, 0xce, 0x6d, 0x11, 0xcc, 0x23, 0xe1, 0x83, 0xc2,
		0x13, 0x59, 0x2a, 0x0e, 0x64, 0x9d, 0x53, 0x6f, 0x14, 0x1f, 0x56, 0x2f, 0xdc, 0x91, 0x2c, 0x1d,
		0x17, 0x19, 0x68, 0x52, 0xbb, 0x5f, 0x6a, 0xe0, 0x1d, 0x2a, 0x6e, 0x57, 0xa3, 0xa8, 0xbd, 0xc2,
		0x8b, 0x0a, 0xb4, 0x5c, 0x50, 0x80, 0xa9, 0x52, 0xe8, 0x42, 0x2b, 0x10, 0xc7, 0x4e, 0xee, 0x11,
		0x21, 0x8e, 0xad, 0x7d, 0x66, 0x21, 0x8e, 0x0d, 0x4d, 0x86, 0x27, 0x23, 0x0b, 0x4d, 0x06, 0xad,
		0x5e, 0x0d, 0xe2, 0xd8, 0x7a, 0xc0, 0x3d, 0xc4, 0xb1, 0xf3, 0x46, 0xa1, 0x10, 0xc7, 0x86, 0x38,
		0xb6, 0xd6, 0x27, 0x8a, 0x29, 0x8e, 0xfd, 0x44, 0xdb, 0xf6, 0xd1, 0x9f, 0x21, 0x92, 0xad, 0x16,
		0x93, 0x43, 0x24, 0x3b, 0xc9, 0xa2, 0x93, 0x17, 0xcb, 0x6e, 0xfd, 0xe0, 0x5b, 0xa1, 0x97, 0xfd,
		0x54, 0x97, 0x5a, 0x54, 0x33, 0xfb, 0x5d, 0x8a, 0x2e, 0x25, 0xed, 0x4a, 0xb2, 0x2e, 0xbc, 0x32,
		0xd7, 0xcf, 0xcf, 0xed, 0xf3, 0x7d, 0xdc, 0xec, 0xc1, 0xe3, 0xdf, 0x3c, 0xe9, 0xcb, 0x5b, 0x7d,
		0x78, 0xfb, 0xdb, 0x9f, 0xf9, 0xee, 0xcd, 0xef, 0x7d, 0xfc, 0xad, 0xab, 0x2f, 0x5a, 0xfb, 0x9a,
		0xaa, 0xed, 0x8f, 0x03, 0xdf, 0x9b, 0x3b, 0x84, 0xc7, 0x5f, 0xb2, 0x44, 0xca, 0x6b, 0x7f, 0xe7,
		0x49, 0x3f, 0x9e, 0x97, 0xc4, 0x7c, 0x31, 0x3f, 0x7c, 0x2d, 0xef, 0x5b, 0xcf, 0xe7, 0x02, 0x97,
		0xf0, 0xa1, 0x1f, 0x8e, 0x9f, 0xeb, 0xe5, 0x1b, 0x89, 0x5a, 0xe2, 0x04, 0x2c, 0x71, 0x62, 0xf5,
		0x34, 0x61, 0x5a, 0x7e, 0x5c, 0xca, 0x39, 0x7f, 0x49, 0xd4, 0x71, 0x35, 0xbc, 0x2f, 0x77, 0x6a,
		0x63, 0x26, 0x5e, 0xea, 0xd4, 0xeb, 0x1a, 0xa5, 0x6f, 0x26, 0xee, 0x49, 0x12, 0xf3, 0x84, 0x13,
		0x95, 0x36, 0xb3, 0x4e, 0x9d, 0x39, 0xa7, 0xce, 0x8c, 0x93, 0x4f, 0xa4, 0x98, 0x63, 0x7a, 0x4b,
		0xb5, 0xb3, 0x7a, 0x43, 0xec, 0xef, 0x81, 0x4b, 0x3c, 0x9a, 0x5c, 0xf9, 0x7f, 0xf5, 0x88, 0x19,
		0x9a, 0xff, 0x09, 0x16, 0x84, 0x28, 0xe5, 0x92, 0xbf, 0xe8, 0xff, 0xdb, 0x0b, 0x46, 0x4d, 0xb0,
		0x4e, 0xac, 0xfa, 0x6f, 0x2f, 0x66, 0x33, 0xa5, 0xdc, 0xff, 0xfc, 0xb9, 0x72, 0xe8, 0xfc, 0xa7,
		0x58, 0x72, 0xb2, 0x6c, 0x5f, 0xf1, 0x84, 0xfe, 0x93, 0x2f, 0x49, 0x3d, 0x49, 0x8f, 0x7a, 0x98,
		0xbe, 0xe8, 0xd1, 0x87, 0x15, 0xea, 0x58, 0xfd, 0xf8, 0x61, 0xe9, 0x0f, 0x3f, 0xcc, 0xd7, 0xb0,
		0x2a, 0x74, 0x9d, 0xc0, 0x5f, 0xa5, 0xd3, 0x1c, 0x17, 0xd2, 0x1a, 0x17, 0xb6, 0xb5, 0x06, 0x6c,
		0x0d, 0xb6, 0xa6, 0xcd, 0xd6, 0x52, 0xb0, 0x30, 0xe6, 0x24, 0xb2, 0x09, 0x3b, 0x5f, 0x4d, 0xe4,
		0x19, 0xd6, 0x33, 0xaf, 0x93, 0x45, 0x23, 0xd7, 0xc7, 0xcb, 0x46, 0x34, 0xdc, 0x26, 0x65, 0xdf,
		0x92, 0x28, 0x62, 0x29, 0x6e, 0x91, 0x5a, 0x3c, 0x00, 0x24, 0x09, 0x24, 0x09, 0x24, 0x89, 0xe8,
		0xb6, 0xdd, 0xd1, 0x6d, 0xee, 0x0d, 0x81, 0x23, 0x81, 0x23, 0x61, 0x69, 0x99, 0x58, 0xda, 0x16,
		0xa2, 0xc8, 0x64, 0x90, 0xeb, 0x55, 0x0c, 0x79, 0x32, 0x6f, 0x42, 0x07, 0x82, 0x4c, 0x16, 0xf4,
		0xd3, 0x05, 0x7b, 0xe0, 0xc7, 0x6d, 0xc4, 0x8f, 0xf3, 0x75, 0x9b, 0x32, 0xa4, 0xc5, 0x4f, 0xa5,
		0x8b, 0x68, 0x35, 0x60, 0x47, 0x44, 0xb4, 0xa7, 0x9f, 0x93, 0xba, 0x28, 0x50, 0xfc, 0x90, 0xdf,
		0xea, 0x10, 0xdf, 0x76, 0x05, 0xb2, 0x04, 0x28, 0x59, 0x30, 0x08, 0x05, 0x93, 0x14, 0x11, 0x28,
		0x98, 0x20, 0xfc, 0x20, 0xfc, 0x80, 0xbe, 0x40, 0x08, 0xda, 0xf6, 0xa4, 0x2a, 0x98, 0x80, 0xba,
		0x00, 0x75, 0x01, 0x2b, 0xd3, 0x6e, 0x65, 0xdb, 0x48, 0x5b, 0xbc, 0x09, 0xb3, 0x5e, 0xa7, 0x2c,
		0x82, 0x89, 0x0e, 0xa4, 0x38, 0x24, 0x37, 0x21, 0xb3, 0x93, 0x83, 0xc5, 0xf9, 0xdf, 0x07, 0x5e,
		0x04, 0x5e, 0x04, 0x5e, 0x44, 0x24, 0xdb, 0xee, 0x48, 0x36, 0x73, 0x86, 0x80, 0x8c, 0x80, 0x8c,
		0x30, 0xb4, 0x2c, 0x0c, 0x6d, 0x0b, 0x51, 0x63, 0x22, 0xbc, 0xf5, 0x2a, 0x70, 0x3c, 0x9b, 0xb5,
		0xa0, 0x05, 0x3b, 0x7a, 0x69, 0x80, 0xa3, 0x07, 0xd4, 0x08, 0xd4, 0x08, 0xd4, 0x88, 0x60, 0xb6,
		0xf5, 0xc1, 0xcc, 0x03, 0x64, 0x04, 0x64, 0x84, 0x95, 0x69, 0xb7, 0xb2, 0xad, 0xc4, 0x8b, 0x9e,
		0x1c, 0x58, 0xf4, 0x74, 0x20, 0x45, 0xe6, 0x71, 0x3a, 0x0a, 0x09, 0xa7, 0x8e, 0x65, 0xb3, 0xd0,
		0x9e, 0x30, 0x9e, 0x1c, 0x38, 0x3e, 0xf3, 0x2c, 0x70, 0x24, 0x70, 0x24, 0x70, 0x24, 0x22, 0xdc,
		0x76, 0x47, 0xb8, 0x4d, 0xc7, 0x08, 0x58, 0x09, 0x58, 0x09, 0xa3, 0xcb, 0xda, 0xe8, 0xb6, 0x10,
		0x65, 0xa6, 0xc6, 0x64, 0xaf, 0x82, 0xce, 0xf6, 0xb2, 0xb5, 0x93, 0x79, 0x63, 0x1a, 0x20, 0x68,
		0xa2, 0x62, 0xea, 0x34, 0x45, 0xd4, 0x09, 0x8b, 0xa7, 0x01, 0x33, 0x4d, 0x80, 0x99, 0x89, 0x8b,
		0x9d, 0x97, 0x23, 0xef, 0x52, 0x32, 0x0c, 0xe9, 0x30, 0xc9, 0xa8, 0x2f, 0xe2, 0xd7, 0x41, 0x82,
		0xbf, 0xdb, 0x9b, 0xdb, 0xe2, 0xfb, 0xf7, 0x33, 0xbf, 0xf2, 0x21, 0x5e, 0x89, 0x1a, 0xec, 0xc1,
		0x0f, 0x38, 0xb3, 0x89, 0x6b, 0xd9, 0xb7, 0xc4, 0xf3, 0xa8, 0x9b, 0xdc, 0x34, 0x9e, 0x3e, 0x68,
		0x46, 0x32, 0xe6, 0x07, 0xdc, 0xe2, 0xb4, 0xa4, 0x56, 0xb2, 0xec, 0x1c, 0x92, 0xb1, 0x02, 0x25,
		0x63, 0x29, 0x96, 0x5c, 0xf9, 0x70, 0x61, 0xf2, 0x25, 0xa9, 0x07, 0x17, 0x26, 0x5d, 0xaa, 0xcb,
		0x07, 0x86, 0x21, 0xfd, 0xef, 0x84, 0x7a, 0xf6, 0x43, 0xfa, 0xc1, 0x5f, 0x6e, 0x71, 0x2e, 0x9b,
		0x48, 0x39, 0x76, 0x62, 0xba, 0xc2, 0xc2, 0x8a, 0xf1, 0x32, 0x4a, 0xf1, 0x92, 0x0b, 0x5c, 0x76,
		0xa1, 0x2b, 0x5b, 0xf0, 0xca, 0x16, 0xbe, 0x3a, 0x03, 0x48, 0x67, 0x08, 0x29, 0x0d, 0x22, 0x3d,
		0xd2, 0x79, 0x7b, 0x99, 0x5b, 0x7c, 0xda, 0x96, 0xc0, 0xe4, 0x8b, 0x6b, 0xbc, 0x57, 0x3f, 0x7b,
		0x33, 0x1d, 0xeb, 0xea, 0xc5, 0x6f, 0xff, 0x2b, 0xf2, 0x6a, 0x39, 0x6d, 0x78, 0xb9, 0x3b, 0x3f,
		0x14, 0x5c, 0x84, 0xa0, 0x44, 0x80, 0x5c, 0x95, 0xf6, 0xbb, 0x4a, 0x75, 0xf1, 0x9f, 0x72, 0x97,
		0xa0, 0x14, 0x6e, 0x68, 0xd5, 0x6b, 0xba, 0x2b, 0x1d, 0xed, 0x8c, 0xb4, 0xd4, 0xaf, 0x74, 0x89,
		0x8c, 0xa7, 0x80, 0x54, 0x2e, 0xf3, 0xa8, 0x15, 0xf8, 0x21, 0x17, 0x0f, 0xec, 0xab, 0x26, 0x10,
		0xd8, 0x11, 0xd8, 0x4b, 0x1b, 0xd8, 0x93, 0x53, 0x1a, 0x32, 0x14, 0xc7, 0x8b, 0x94, 0xc7, 0x87,
		0x35, 0xbe, 0xe7, 0xe3, 0x1a, 0xed, 0xf8, 0xec, 0xaf, 0x1f, 0xfd, 0xf6, 0x6d, 0x8e, 0x24, 0x1b,
		0x57, 0xe3, 0x07, 0x34, 0x8c, 0xd9, 0x57, 0xe2, 0x5a, 0x63, 0xdf, 0xa1, 0xe2, 0x1e, 0x67, 0xa3,
		0x25, 0x38, 0x1e, 0x38, 0x9e, 0xd2, 0x3a, 0x9e, 0x09, 0xf3, 0x78, 0x7d, 0x5f, 0xc2, 0xef, 0xec,
		0x23, 0x13, 0x40, 0x26, 0x50, 0xd0, 0x4c, 0x60, 0x7f, 0x6f, 0x6f, 0x07, 0xd0, 0x3f, 0x97, 0x78,
		0xcc, 0x49, 0x38, 0xa2, 0xdc, 0xf2, 0x27, 0x3c, 0x98, 0x70, 0x2b, 0xf0, 0xef, 0x69, 0x28, 0x1e,
		0x92, 0x9f, 0x6b, 0x0c, 0x51, 0x19, 0x51, 0xb9, 0xb4, 0x51, 0xd9, 0xa1, 0x36, 0x1b, 0x13, 0x57,
		0xe8, 0x3a, 0xc7, 0x65, 0x42, 0xd0, 0x10, 0x78, 0x76, 0xc3, 0xdb, 0x35, 0xb6, 0x35, 0xbc, 0x37,
		0x10, 0xde, 0x75, 0x85, 0xf7, 0x9d, 0x12, 0x0e, 0xad, 0xe9, 0xa1, 0xdd, 0xe8, 0xca, 0xb0, 0x27,
		0x75, 0x11, 0xa8, 0xc5, 0xcc, 0xa3, 0x16, 0x13, 0x7b, 0xee, 0x26, 0xed, 0xb9, 0xdb, 0xb7, 0xa1,
		0x3f, 0x26, 0x9c, 0xd9, 0x96, 0xc3, 0xa2, 0x80, 0x86, 0x91, 0xc8, 0xb5, 0xa8, 0x6b, 0x57, 0x31,
		0x3c, 0xd3, 0x9a, 0x18, 0x42, 0xaf, 0x03, 0xa1, 0x03, 0xa1, 0xeb, 0x46, 0xe8, 0x69, 0xcd, 0x65,
		0xf9, 0x20, 0xb9, 0x1b, 0x89, 0x4f, 0xd7, 0x62, 0xd5, 0x4c, 0x1b, 0x11, 0x1c, 0x5f, 0x39, 0x82,
		0x44, 0xd8, 0x58, 0x54, 0x18, 0xcd, 0x8b, 0xc6, 0xf3, 0x10, 0xd0, 0x48, 0xe6, 0xda, 0x7a, 0x49,
		0x2b, 0x52, 0x6e, 0x4d, 0xca, 0xad, 0xea, 0x55, 0xeb, 0x8a, 0x47, 0x2f, 0x6b, 0xdc, 0x2a, 0xb8,
		0x7a, 0x84, 0x13, 0x63, 0xa5, 0x09, 0xb2, 0x8a, 0x44, 0x59, 0x69, 0xc2, 0xac, 0x28, 0x71, 0x96,
		0x4f, 0xa0, 0x95, 0x26, 0xd2, 0x8a, 0x13, 0x6a, 0xd5, 0xd9, 0x9f, 0x8e, 0x2c, 0x50, 0x41, 0xa2,
		0xad, 0x34, 0xe1, 0x56, 0x9c, 0x78, 0x1b, 0x35, 0x05, 0xef, 0xf2, 0x79, 0xfa, 0x2a, 0x23, 0x22,
		0x40, 0x60, 0x89, 0x55, 0x99, 0x17, 0x71, 0xe2, 0x71, 0x79, 0x00, 0xb3, 0x68, 0x08, 0x20, 0x06,
		0x20, 0x06, 0x20, 0x06, 0x20, 0x06, 0x20, 0x06, 0x20, 0x06, 0x20, 0x06, 0x20, 0x26, 0x1b, 0x10,
		0xc3, 0x69, 0x78, 0x47, 0x5c, 0x15, 0x28, 0x66, 0xde, 0x12, 0x60, 0xcc, 0x34, 0x10, 0x03, 0xc2,
		0x88, 0x42, 0x98, 0x2d, 0x85, 0x2f, 0x11, 0x27, 0xdc, 0x92, 0x34, 0xa2, 0x8a, 0xdc, 0x99, 0xa4,
		0x65, 0x13, 0xcb, 0xb3, 0x49, 0x1e, 0xf1, 0xfc, 0x88, 0xda, 0xbe, 0xe7, 0x48, 0xad, 0xe5, 0x52,
		0x83, 0x98, 0x1a, 0x40, 0x4c, 0xde, 0x20, 0x46, 0xf5, 0x14, 0xa8, 0x3f, 0xf3, 0x04, 0x5c, 0x93,
		0x2d, 0xae, 0x19, 0x4b, 0xac, 0xb2, 0xa5, 0x4b, 0x9e, 0x36, 0x02, 0x34, 0x03, 0x52, 0x06, 0xa4,
		0x0c, 0x48, 0x19, 0x90, 0x32, 0xc0, 0x33, 0x20, 0x65, 0x00, 0x5e, 0x32, 0x02, 0x2f, 0x16, 0x67,
		0x63, 0xaa, 0x04, 0xc1, 0xcc, 0x5a, 0x02, 0x8c, 0x01, 0x29, 0x03, 0x52, 0x26, 0xf5, 0x9a, 0x99,
		0xda, 0x0e, 0x67, 0xf6, 0xf7, 0x48, 0x09, 0x80, 0x01, 0x25, 0x03, 0x4a, 0x06, 0x94, 0x0c, 0x28,
		0x99, 0x2d, 0x45, 0x35, 0x12, 0x86, 0xbe, 0x02, 0x34, 0xcc, 0x03, 0x96, 0x01, 0x25, 0x03, 0x4a,
		0x06, 0x94, 0x0c, 0x28, 0x19, 0xe0, 0x19, 0x50, 0x32, 0x00, 0x2f, 0x59, 0x81, 0x17, 0x55, 0x94,
		0xcc, 0xa2, 0x25, 0xc0, 0x18, 0x50, 0x32, 0xa0, 0x64, 0x40, 0xc9, 0x80, 0x92, 0x01, 0x84, 0x01,
		0x25, 0x03, 0x54, 0x23, 0x8b, 0x6a, 0xb4, 0x1e, 0xf1, 0x16, 0xd4, 0x20, 0x59, 0x3e, 0xaf, 0x4a,
		0x8b, 0x64, 0x76, 0x95, 0x8c, 0x02, 0x81, 0x84, 0xca, 0x6b, 0xf7, 0x38, 0x75, 0x67, 0x6f, 0x3d,
		0x99, 0xbd, 0xf4, 0xfa, 0x64, 0xf1, 0xba, 0xd3, 0xd5, 0xdb, 0x0a, 0x20, 0x0a, 0x87, 0x8b, 0x1e,
		0xc4, 0x48, 0x33, 0xc8, 0x4b, 0xbc, 0xc2, 0x89, 0xe1, 0xa2, 0x07, 0xc5, 0x70, 0x11, 0x17, 0x3d,
		0x40, 0xde, 0x55, 0x0b, 0xbc, 0xc3, 0x45, 0x0f, 0x3a, 0x9e, 0x2a, 0x82, 0xda, 0xeb, 0x28, 0xf4,
		0x27, 0x81, 0xc5, 0x1c, 0xf1, 0xb8, 0xbe, 0x6c, 0x01, 0x61, 0x1d, 0x61, 0xbd, 0xd4, 0x6a, 0xeb,
		0x3b, 0x0d, 0x89, 0x70, 0x7e, 0x80, 0x70, 0x8c, 0x70, 0x5c, 0xd0, 0x70, 0xbc, 0xdb, 0x38, 0xda,
		0x3d, 0xda, 0x3f, 0x68, 0x1c, 0x21, 0x08, 0xe7, 0x12, 0x84, 0x99, 0xa7, 0x40, 0x6a, 0x7d, 0xbd,
		0x91, 0xed, 0x10, 0x70, 0xe4, 0x21, 0xf1, 0x22, 0x9b, 0xb2, 0xbb, 0xd4, 0x3d, 0xde, 0x8e, 0x68,
		0xbc, 0x3e, 0x3e, 0x90, 0x71, 0x84, 0x8c, 0xe3, 0x73, 0x26, 0x84, 0x2d, 0x51, 0x51, 0xe3, 0x42,
		0x45, 0x97, 0x2c, 0x7c, 0x41, 0x45, 0x97, 0x16, 0xe0, 0xfd, 0x74, 0x98, 0x51, 0xd1, 0x95, 0x39,
		0x40, 0x7f, 0x3a, 0x05, 0xa8, 0xe8, 0xd2, 0xfe, 0x34, 0xe4, 0x1b, 0x01, 0x5e, 0x00, 0x5e, 0x00,
		0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x94, 0x81, 0x17, 0xc8, 0x36,
		0x02, 0xbe, 0x00, 0xbe, 0x40, 0xb6, 0x71, 0xbd, 0x09, 0x14, 0xa4, 0xeb, 0xf7, 0x58, 0x00, 0x31,
		0xc5, 0x9d, 0x02, 0x14, 0xa4, 0x9b, 0x8e, 0x6b, 0x20, 0xdb, 0x08, 0x34, 0x03, 0x34, 0x03, 0x32,
		0x06, 0x64, 0x0c, 0xc8, 0x18, 0x90, 0x31, 0x00, 0x2d, 0xa6, 0x80, 0x16, 0xc8, 0x35, 0x02, 0xbe,
		0x00, 0xbe, 0x40, 0x1b, 0x00, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0xca, 0x80, 0x6a,
		0x20, 0xd7, 0x08, 0x2c, 0x03, 0x2c, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x00,
		0x2d, 0x86, 0x80, 0x16, 0xc8, 0x34, 0x02, 0xbe, 0x00, 0xbe, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a,
		0x06, 0x54, 0x0c, 0xa8, 0x98, 0xa2, 0xa1, 0x9a, 0x2d, 0x92, 0x69, 0x14, 0x57, 0x3f, 0xa8, 0xa4,
		0x50, 0x67, 0x6c, 0x4f, 0xdf, 0xd2, 0x8b, 0x5f, 0x52, 0x00, 0xd9, 0x08, 0x97, 0x44, 0x34, 0xb4,
		0x6e, 0x18, 0x89, 0x2c, 0x7b, 0x12, 0x86, 0x54, 0xe0, 0x84, 0xd9, 0x32, 0x86, 0x3e, 0xd3, 0x16,
		0x44, 0x24, 0xf4, 0x63, 0x4d, 0x88, 0x48, 0x48, 0x78, 0x20, 0x88, 0x48, 0x20, 0x61, 0x43, 0xc2,
		0x66, 0x60, 0xc2, 0x06, 0xbe, 0xd9, 0xb8, 0x64, 0x0d, 0x7c, 0x73, 0xee, 0xc9, 0x1a, 0xf8, 0xe6,
		0xf2, 0x64, 0x66, 0x10, 0x91, 0x00, 0x78, 0x01, 0x78, 0x01, 0x78, 0x01, 0x78, 0x01, 0x78, 0x01,
		0x78, 0x01, 0x78, 0x29, 0x3f, 0x78, 0x81, 0x88, 0x04, 0xe0, 0x0b, 0xe0, 0x0b, 0x44, 0x24, 0xd6,
		0x9b, 0xc0, 0x76, 0xb9, 0x7e, 0x8f, 0x05, 0x10, 0x53, 0xdc, 0x29, 0xc0, 0x76, 0xb9, 0xe9, 0xb8,
		0x06, 0x22, 0x12, 0x40, 0x33, 0x40, 0x33, 0x20, 0x63, 0x40, 0xc6, 0x80, 0x8c, 0x01, 0x19, 0x03,
		0xd0, 0x62, 0x0a, 0x68, 0x81, 0x88, 0x04, 0xe0, 0x0b, 0xe0, 0x0b, 0x4e, 0x2e, 0x80, 0x8a, 0x01,
		0x15, 0x03, 0x2a, 0x06, 0x54, 0x4c, 0x19, 0x50, 0x0d, 0x44, 0x24, 0x80, 0x65, 0x80, 0x65, 0x40,
		0xc5, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0xa0, 0xc5, 0x10, 0xd0, 0x02, 0x11, 0x09, 0xc0,
		0x17, 0xc0, 0x17, 0x50, 0x31, 0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x53, 0x34, 0x54,
		0xb3, 0x45, 0x22, 0x12, 0xd2, 0x22, 0x08, 0x95, 0x14, 0x5a, 0x12, 0xe7, 0xd3, 0x97, 0x1d, 0x33,
		0x12, 0x9d, 0xcc, 0x5f, 0x55, 0x04, 0x45, 0x09, 0xe6, 0x51, 0x2b, 0xf0, 0x43, 0x19, 0x21, 0x89,
		0x65, 0x13, 0x62, 0xfa, 0x11, 0x35, 0xc3, 0xf4, 0x23, 0xfc, 0x80, 0x5b, 0x9c, 0x86, 0x63, 0x88,
		0x47, 0x3c, 0x83, 0x25, 0x97, 0x83, 0x53, 0x30, 0xb7, 0x23, 0x0c, 0x1b, 0x57, 0xcb, 0x9c, 0x92,
		0x61, 0x48, 0x87, 0x22, 0xb3, 0xbe, 0xe0, 0xb8, 0x0e, 0x04, 0x9e, 0xed, 0x2d, 0x3d, 0x9d, 0xbd,
		0xf4, 0x70, 0x1f, 0xd7, 0x3c, 0xdc, 0xb3, 0xbf, 0x7e, 0xf4, 0xdb, 0xd8, 0x2f, 0x15, 0xc0, 0xd5,
		0xf8, 0x01, 0x0d, 0x63, 0xc7, 0x4f, 0x5c, 0x6b, 0xec, 0x3b, 0x54, 0xdc, 0xe3, 0x6c, 0xb4, 0x04,
		0xc7, 0x03, 0xc7, 0x53, 0x5a, 0xc7, 0x33, 0x61, 0x1e, 0xaf, 0xef, 0x4b, 0xf8, 0x9d, 0x7d, 0x81,
		0x47, 0xe5, 0x52, 0x48, 0x89, 0xec, 0x5c, 0x45, 0xca, 0xa8, 0x28, 0x4f, 0x51, 0x95, 0x22, 0xaa,
		0x4c, 0x42, 0x24, 0x52, 0x42, 0x25, 0xa9, 0xa0, 0xea, 0xa1, 0xdd, 0xdf, 0xdb, 0xdb, 0xd9, 0x2b,
		0xd0, 0xf0, 0x66, 0x94, 0x63, 0x5d, 0x15, 0x21, 0x1e, 0x4f, 0xf8, 0x4a, 0x41, 0x4f, 0x3c, 0x16,
		0xaf, 0xb7, 0x02, 0x01, 0x39, 0x84, 0x62, 0x08, 0xc8, 0xbd, 0xb8, 0x76, 0x20, 0x20, 0x87, 0xcd,
		0x1a, 0x69, 0xe3, 0x42, 0xad, 0x89, 0x2c, 0x76, 0x41, 0xad, 0x89, 0x16, 0xd4, 0xfd, 0x74, 0x98,
		0x51, 0x6b, 0x92, 0x39, 0x3a, 0x7f, 0x3a, 0x05, 0xa8, 0x35, 0xd1, 0xfe, 0x34, 0x04, 0xe4, 0x00,
		0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x94,
		0x81, 0x17, 0x08, 0xc8, 0x01, 0xbe, 0x00, 0xbe, 0x40, 0x40, 0x6e, 0xbd, 0x09, 0x94, 0xca, 0xea,
		0xf7, 0x58, 0x00, 0x31, 0xc5, 0x9d, 0x02, 0x94, 0xca, 0x9a, 0x8e, 0x6b, 0x20, 0x20, 0x07, 0x34,
		0x03, 0x34, 0x03, 0x32, 0x06, 0x64, 0x0c, 0xc8, 0x18, 0x90, 0x31, 0x00, 0x2d, 0xa6, 0x80, 0x16,
		0x08, 0xc8, 0x01, 0xbe, 0x00, 0xbe, 0xe0, 0xd4, 0x32, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0x40,
		0xc5, 0x94, 0x01, 0xd5, 0x40, 0x40, 0x0e, 0x58, 0x06, 0x58, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50,
		0x31, 0xa0, 0x62, 0x00, 0x5a, 0x0c, 0x01, 0x2d, 0x10, 0x90, 0x03, 0x7c, 0x01, 0x7c, 0x01, 0x15,
		0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x45, 0x43, 0x35, 0x5b, 0x24, 0x20, 0x27,
		0x21, 0x7f, 0x50, 0x49, 0x21, 0x1d, 0xd7, 0x8d, 0x5f, 0xd3, 0x8b, 0xdf, 0x52, 0x00, 0xe9, 0x88,
		0xc0, 0x77, 0x49, 0xc8, 0xfe, 0x37, 0x9e, 0x05, 0xcb, 0xa1, 0x01, 0xf5, 0x1c, 0xea, 0x71, 0xcb,
		0xf5, 0xa3, 0x48, 0x5c, 0x49, 0xe2, 0xb5, 0x46, 0xb7, 0x43, 0x58, 0x02, 0x02, 0x4f, 0xaf, 0x80,
		0xcc, 0xa2, 0x0a, 0x3c, 0x41, 0x52, 0x02, 0xe9, 0x1b, 0xd2, 0x37, 0x03, 0xd3, 0x37, 0xb0, 0xcf,
		0xc6, 0xa5, 0x6e, 0x60, 0x9f, 0x73, 0x4f, 0xdd, 0xc0, 0x3e, 0x97, 0x27, 0x4f, 0x83, 0xa4, 0x04,
		0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x4b, 0xf9, 0xc1,
		0x0b, 0x24, 0x25, 0x00, 0x5f, 0x00, 0x5f, 0x20, 0x29, 0xb1, 0xde, 0x04, 0x36, 0xcf, 0xf5, 0x7b,
		0x2c, 0x80, 0x98, 0xe2, 0x4e, 0x01, 0x36, 0xcf, 0x4d, 0xc7, 0x35, 0x90, 0x94, 0x00, 0x9a, 0x01,
		0x9a, 0x01, 0x19, 0x03, 0x32, 0x06, 0x64, 0x0c, 0xc8, 0x18, 0x80, 0x16, 0x53, 0x40, 0x0b, 0x24,
		0x25, 0x00, 0x5f, 0x00, 0x5f, 0x70, 0x8e, 0x01, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62,
		0xca, 0x80, 0x6a, 0x20, 0x29, 0x01, 0x2c, 0x03, 0x2c, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18,
		0x50, 0x31, 0x00, 0x2d, 0x86, 0x80, 0x16, 0x48, 0x4a, 0x00, 0xbe, 0x00, 0xbe, 0x80, 0x8a, 0x01,
		0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x98, 0xa2, 0xa1, 0x9a, 0x2d, 0x92, 0x94, 0x50, 0xa7,
		0x83, 0x50, 0x49, 0xa1, 0x30, 0xd1, 0x5b, 0x7b, 0xeb, 0xe9, 0xe2, 0xa5, 0xe7, 0xd3, 0x77, 0x16,
		0x4d, 0x6f, 0x62, 0xec, 0x3b, 0xd4, 0x72, 0x58, 0x14, 0xd0, 0x30, 0x12, 0x99, 0xb2, 0xe7, 0x05,
		0x27, 0x9e, 0xb6, 0x0a, 0xc5, 0x09, 0xcd, 0xd8, 0x14, 0x8a, 0x13, 0xa2, 0xee, 0x0a, 0x8a, 0x13,
		0xc5, 0xc8, 0xee, 0xe2, 0xf5, 0x81, 0x0c, 0x4f, 0xc6, 0xba, 0x40, 0x52, 0xcb, 0xe2, 0x5e, 0x90,
		0xd4, 0x99, 0x64, 0x78, 0x20, 0xa9, 0x73, 0xcf, 0xf0, 0x40, 0x52, 0x97, 0x27, 0x9d, 0x83, 0xf2,
		0x04, 0x40, 0x0c, 0x40, 0x0c, 0x40, 0x0c, 0x40, 0x0c, 0x40, 0x0c, 0x40, 0x0c, 0x40, 0xcc, 0xf6,
		0x80, 0x18, 0x28, 0x50, 0x68, 0x81, 0x31, 0x80, 0x30, 0xa2, 0x10, 0x06, 0x0a, 0x14, 0x50, 0xa0,
		0x30, 0x09, 0xc4, 0x60, 0xaf, 0x3d, 0x77, 0x10, 0x83, 0xbd, 0x76, 0xe0, 0x9a, 0xc7, 0xc3, 0x0c,
		0x05, 0x0a, 0x90, 0x32, 0x20, 0x65, 0x40, 0xca, 0x80, 0x94, 0x01, 0x29, 0x03, 0x52, 0x06, 0xa4,
		0x8c, 0x69, 0xe0, 0x05, 0x4a, 0x14, 0x20, 0x65, 0x40, 0xca, 0xe0, 0xf8, 0x03, 0x28, 0x19, 0x50,
		0x32, 0xa0, 0x64, 0x40, 0xc9, 0x94, 0x01, 0xd5, 0x40, 0x89, 0x02, 0x94, 0x0c, 0x28, 0x19, 0x50,
		0x32, 0xa0, 0x64, 0x40, 0xc9, 0x80, 0x92, 0x01, 0x78, 0x31, 0x0c, 0xbc, 0x40, 0x91, 0x02, 0x94,
		0x0c, 0x28, 0x19, 0x50, 0x32, 0xa0, 0x64, 0x40, 0xc9, 0x80, 0x92, 0x01, 0x25, 0x53, 0x34, 0x54,
		0xb3, 0xad, 0x8a, 0x14, 0x72, 0x42, 0x09, 0x15, 0x41, 0x49, 0x8a, 0x0b, 0xdf, 0xa1, 0xa7, 0xab,
		0x97, 0x16, 0x40, 0x93, 0x62, 0x16, 0x81, 0x2c, 0x3f, 0x74, 0x68, 0x68, 0xe9, 0x11, 0xa8, 0x48,
		0xfe, 0x0a, 0xa8, 0x55, 0x68, 0xc6, 0xad, 0x50, 0xab, 0x10, 0x75, 0x65, 0x50, 0xab, 0x00, 0x81,
		0x6d, 0x7e, 0xf6, 0x07, 0x02, 0x1b, 0x04, 0xb6, 0x39, 0xd9, 0x1f, 0x08, 0xec, 0xdc, 0xb3, 0x3f,
		0x10, 0xd8, 0xe5, 0x49, 0xf5, 0xa0, 0x56, 0x01, 0x10, 0x03, 0x10, 0x03, 0x10, 0x03, 0x10, 0x03,
		0x10, 0x03, 0x10, 0x03, 0x10, 0xb3, 0x3d, 0x20, 0x06, 0x6a, 0x15, 0x5a, 0x60, 0x0c, 0x20, 0x8c,
		0x28, 0x84, 0x81, 0x5a, 0x05, 0xd4, 0x2a, 0x4c, 0x02, 0x31, 0xd8, 0x87, 0xcf, 0x1d, 0xc4, 0x60,
		0x1f, 0x1e, 0xb8, 0xe6, 0xf1, 0x30, 0x43, 0xad, 0x02, 0xa4, 0x0c, 0x48, 0x19, 0x90, 0x32, 0x20,
		0x65, 0x40, 0xca, 0x80, 0x94, 0x01, 0x29, 0x63, 0x1a, 0x78, 0x81, 0x5a, 0x05, 0x48, 0x19, 0x90,
		0x32, 0x38, 0x1a, 0x01, 0x4a, 0x06, 0x94, 0x0c, 0x28, 0x19, 0x50, 0x32, 0x65, 0x40, 0x35, 0x50,
		0xab, 0x00, 0x25, 0x03, 0x4a, 0x06, 0x94, 0x0c, 0x28, 0x19, 0x50, 0x32, 0xa0, 0x64, 0x00, 0x5e,
		0x0c, 0x03, 0x2f, 0x50, 0xab, 0x00, 0x25, 0x03, 0x4a, 0x06, 0x94, 0x0c, 0x28, 0x19, 0x50, 0x32,
		0xa0, 0x64, 0x40, 0xc9, 0x14, 0x0d, 0xd5, 0x6c, 0x91, 0x5a, 0x85, 0x2e, 0xd5, 0x84, 0x4a, 0x0a,
		0xe9, 0x8a, 0x7e, 0xfc, 0x0d, 0xdd, 0xe9, 0x27, 0x14, 0x5b, 0xc5, 0x82, 0x93, 0x70, 0x44, 0xb9,
		0xe5, 0x4f, 0x78, 0x30, 0xe1, 0x56, 0xe0, 0xdf, 0xd3, 0x50, 0x5c, 0xaf, 0xe2, 0xb9, 0xc6, 0xc4,
		0x94, 0x29, 0x6a, 0x50, 0xa6, 0xc8, 0x1c, 0x9b, 0x6e, 0x9d, 0x32, 0x85, 0x30, 0xec, 0x54, 0xc2,
		0x96, 0xc9, 0xb0, 0x64, 0x4a, 0xd8, 0x31, 0x49, 0x48, 0x29, 0x81, 0xd6, 0x55, 0x40, 0x48, 0x45,
		0xec, 0x97, 0x2a, 0xc8, 0xa8, 0x12, 0x94, 0x48, 0x40, 0x44, 0x25, 0xd0, 0x50, 0x11, 0xab, 0x55,
		0xc8, 0xa1, 0xcd, 0x08, 0x6f, 0x5d, 0xe9, 0x0a, 0xed, 0xef, 0x14, 0x2e, 0x20, 0x51, 0xdc, 0xa6,
		0x16, 0xaf, 0x25, 0x8b, 0x0a, 0x6f, 0x77, 0xfc, 0xf5, 0xbf, 0xf1, 0xc6, 0x90, 0xa4, 0x1d, 0x0a,
		0x55, 0x43, 0x90, 0x20, 0x6e, 0x24, 0x84, 0x9c, 0xaf, 0x0f, 0xe3, 0xcb, 0x83, 0xf3, 0xca, 0xc0,
		0x54, 0x03, 0x3f, 0x7c, 0x5b, 0xc1, 0x60, 0x19, 0x0c, 0xe3, 0xbf, 0xfd, 0xc6, 0x30, 0x27, 0x13,
		0x1e, 0x4b, 0x0c, 0xe7, 0xd2, 0xc0, 0xb7, 0x75, 0xb8, 0xb6, 0x98, 0xa3, 0x24, 0xc3, 0x9f, 0x12,
		0x9e, 0x09, 0xc3, 0x31, 0x61, 0xf8, 0xf5, 0x14, 0x6e, 0x2d, 0x3b, 0xa7, 0xd9, 0x64, 0x92, 0x0a,
		0x7b, 0x55, 0x6f, 0x42, 0x4a, 0xbe, 0xfb, 0x13, 0x1e, 0xe7, 0x5f, 0xc9, 0x07, 0x72, 0x31, 0x5f,
		0x8f, 0x1f, 0x4f, 0x38, 0x26, 0xe9, 0x14, 0xee, 0x52, 0xe7, 0x0f, 0x22, 0x79, 0xc3, 0xa3, 0x05,
		0xf8, 0xb6, 0xad, 0xa8, 0xc8, 0x11, 0xa4, 0x73, 0x03, 0xe9, 0x9c, 0x60, 0x63, 0x71, 0x4e, 0x3b,
		0x9e, 0x53, 0xb8, 0x4b, 0xab, 0x44, 0x57, 0xb5, 0x17, 0xab, 0x42, 0x30, 0x1f, 0x9e, 0x3f, 0xbf,
		0x1d, 0xe2, 0x8c, 0x29, 0x97, 0xf4, 0xf6, 0xa4, 0xbf, 0xe9, 0x96, 0x7c, 0x36, 0xa9, 0xaf, 0xb0,
		0x28, 0xe3, 0x1c, 0xb7, 0x58, 0x51, 0x40, 0xa9, 0x23, 0xbf, 0xdf, 0xf9, 0xb8, 0x39, 0x6c, 0x7a,
		0x4a, 0x18, 0x92, 0x2a, 0x83, 0x52, 0x6e, 0x58, 0xca, 0x0d, 0x4c, 0xad, 0xa1, 0x49, 0xa6, 0x86,
		0xb9, 0x6f, 0x79, 0x32, 0x87, 0x7a, 0x9c, 0xf1, 0x87, 0x90, 0x0e, 0x55, 0xd4, 0x6c, 0x49, 0x6c,
		0xd2, 0x54, 0xdb, 0xf3, 0x4f, 0x39, 0x26, 0x91, 0x82, 0xf5, 0xb7, 0xe8, 0x60, 0x6b, 0xf0, 0x5b,
		0xeb, 0xb2, 0xd3, 0x1a, 0x5c, 0xf7, 0x7b, 0xad, 0xd6, 0x69, 0x55, 0x05, 0x29, 0x11, 0x49, 0x6f,
		0xa4, 0x56, 0x94, 0x6c, 0xa6, 0x3e, 0xea, 0x67, 0xdc, 0xbd, 0xeb, 0xc3, 0x5a, 0xed, 0xd3, 0x71,
		0xb5, 0x08, 0xdb, 0x8c, 0x5a, 0xba, 0xd7, 0xd8, 0x2b, 0x73, 0xef, 0xea, 0x25, 0x9f, 0xbc, 0x72,
		0x77, 0x6f, 0xaf, 0xdc, 0x86, 0x57, 0xab, 0x5d, 0x94, 0xda, 0xf4, 0xca, 0xed, 0x58, 0xca, 0x3c,
		0x77, 0x9f, 0x3b, 0xbf, 0x77, 0xba, 0x7f, 0x74, 0x4a, 0xec, 0x59, 0x4a, 0xbd, 0x38, 0x77, 0xcb,
		0x1d, 0x16, 0xf6, 0x6b, 0x25, 0x9f, 0xbd, 0x52, 0x3b, 0xce, 0x92, 0xc3, 0x4d, 0x25, 0x61, 0x41,
		0xaa, 0x85, 0xab, 0xc2, 0x6f, 0xc6, 0x8a, 0x94, 0xf4, 0x7b, 0x93, 0xf1, 0x62, 0x8f, 0x2e, 0x92,
		0xa7, 0xb9, 0x1e, 0xb5, 0x06, 0x96, 0x0b, 0x2c, 0x17, 0x58, 0xae, 0x94, 0x2b, 0x66, 0xc2, 0x3c,
		0x7e, 0xa8, 0x80, 0xdf, 0xda, 0x43, 0x09, 0xbe, 0x52, 0xbf, 0xf2, 0x3c, 0xbf, 0x86, 0x12, 0xfc,
		0x22, 0x4c, 0x41, 0x63, 0x0f, 0x15, 0xf7, 0x8a, 0xe0, 0x0a, 0x2a, 0xee, 0x67, 0xe5, 0x4b, 0xd3,
		0xe0, 0xf3, 0xe1, 0x51, 0x41, 0xc6, 0x87, 0xf9, 0x26, 0x77, 0x11, 0x6e, 0x64, 0x8c, 0xcb, 0xc9,
		0xc4, 0x6f, 0x5b, 0x8c, 0x1f, 0xcf, 0x78, 0xb3, 0xbe, 0x81, 0xcd, 0xfa, 0x5c, 0x51, 0x16, 0x36,
		0xeb, 0x93, 0xaf, 0x1b, 0x6c, 0xd6, 0x23, 0x8d, 0x41, 0x1a, 0x23, 0xb5, 0x62, 0xb0, 0x59, 0x9f,
		0x1e, 0xc9, 0x62, 0xb3, 0x3e, 0xaf, 0xee, 0x61, 0xb3, 0xde, 0xe4, 0xc9, 0xc3, 0x66, 0xbd, 0xc1,
		0x86, 0x87, 0xcd, 0x7a, 0x93, 0x7b, 0x87, 0xcd, 0x7a, 0x93, 0x3d, 0x0b, 0x36, 0xeb, 0xcd, 0xed,
		0x1e, 0x36, 0xeb, 0x4d, 0x76, 0x9c, 0xd8, 0xac, 0xd7, 0x94, 0xf9, 0x2e, 0xfe, 0xc1, 0x66, 0xfd,
		0xdb, 0xd3, 0x85, 0xcd, 0x7a, 0xb0, 0x5c, 0x60, 0xb9, 0x64, 0x56, 0x0c, 0x36, 0xeb, 0xd7, 0x3e,
		0x04, 0x9b, 0xf5, 0x79, 0x87, 0x73, 0x6c, 0xd6, 0xe7, 0x0b, 0x3a, 0xb0, 0x59, 0x5f, 0x98, 0xcd,
		0xfa, 0x14, 0x8a, 0x2b, 0xe9, 0xc7, 0xc6, 0x6c, 0x71, 0x9a, 0xcd, 0xd1, 0xaa, 0xa6, 0xaa, 0x3d,
		0x78, 0x5e, 0xa4, 0xa5, 0xe7, 0x87, 0xfc, 0xfa, 0x78, 0xde, 0xea, 0xc5, 0xb4, 0x51, 0x55, 0x72,
		0x37, 0x09, 0xa4, 0x4b, 0x52, 0xea, 0x17, 0x88, 0xe9, 0x16, 0x14, 0x5e, 0x6a, 0x23, 0xb9, 0xd6,
		0x8b, 0x2c, 0x5e, 0x2d, 0xa0, 0xdc, 0x46, 0x62, 0x2d, 0x98, 0x12, 0x19, 0x71, 0x9a, 0x8a, 0x24,
		0x35, 0x86, 0xb6, 0x50, 0x75, 0x4a, 0x24, 0x98, 0xb4, 0xb9, 0x48, 0xd7, 0x9f, 0x2e, 0x87, 0xd1,
		0xb9, 0xcc, 0xa3, 0x96, 0xed, 0x6f, 0xa7, 0xd1, 0x2d, 0x3b, 0x0f, 0x9d, 0x1b, 0x75, 0x4b, 0x58,
		0x9a, 0x1b, 0x51, 0x55, 0x3a, 0x27, 0xb0, 0xb4, 0x55, 0xf1, 0x20, 0xc5, 0x2f, 0x9f, 0x4b, 0xbf,
		0xf4, 0xb3, 0x81, 0xe0, 0xc2, 0x25, 0x74, 0xc4, 0x19, 0x33, 0xcf, 0x12, 0xab, 0x2c, 0xdd, 0x58,
		0x3d, 0xeb, 0x8d, 0x81, 0x58, 0x94, 0x34, 0x26, 0x90, 0x8b, 0xe2, 0xc6, 0x66, 0x3a, 0xc1, 0xb8,
		0x66, 0x48, 0xf1, 0x4d, 0x27, 0x2a, 0x6a, 0xe9, 0x76, 0x25, 0xda, 0x68, 0x79, 0x93, 0xf1, 0xb4,
		0x67, 0x3f, 0xc1, 0x57, 0xc8, 0x82, 0xf7, 0x75, 0x30, 0x8c, 0xb3, 0x05, 0x26, 0x9e, 0x2d, 0x00,
		0x40, 0x02, 0x40, 0x02, 0x40, 0x02, 0x40, 0x02, 0x40, 0x02, 0x40, 0xca, 0x0d, 0x20, 0x09, 0xc4,
		0x1e, 0xe6, 0x89, 0x5f, 0x81, 0xb3, 0x31, 0x01, 0xeb, 0x8d, 0xc9, 0x79, 0xb2, 0x3a, 0x3c, 0x19,
		0x3c, 0x99, 0x69, 0x9e, 0x4c, 0x14, 0x4e, 0xac, 0x60, 0xc5, 0xdd, 0x48, 0xdd, 0xa1, 0xa4, 0x69,
		0x63, 0xbf, 0x2a, 0xb9, 0x12, 0x45, 0xf6, 0x2a, 0x13, 0x59, 0xa3, 0x54, 0x69, 0x9c, 0xcf, 0x19,
		0xa9, 0xec, 0x85, 0xab, 0xaa, 0x2d, 0x55, 0x9b, 0xc5, 0x6a, 0xb3, 0xdc, 0x97, 0x2c, 0x58, 0xf2,
		0x42, 0x56, 0x39, 0x33, 0x96, 0x34, 0x67, 0x75, 0x00, 0x65, 0x63, 0xcd, 0xa9, 0xb8, 0x6f, 0x7e,
		0x23, 0x62, 0x2a, 0xb8, 0x11, 0x5d, 0xe9, 0xfd, 0xf3, 0xcb, 0x46, 0xd5, 0x14, 0xa5, 0x2d, 0xfe,
		0x51, 0x63, 0x5a, 0x15, 0xd5, 0x45, 0x6a, 0x4f, 0xa7, 0x43, 0xd1, 0xfd, 0xf4, 0xcb, 0x66, 0x15,
		0x17, 0xad, 0xbd, 0x3c, 0xe3, 0x35, 0x65, 0xed, 0xff, 0xfc, 0x55, 0xe1, 0x54, 0x29, 0x2c, 0x66,
		0x7b, 0x3a, 0x55, 0x3b, 0x98, 0xaa, 0x9f, 0xef, 0x8a, 0xd1, 0xca, 0x55, 0x4e, 0x25, 0x77, 0x32,
		0x97, 0xcf, 0x31, 0x2f, 0xe2, 0xc4, 0xe3, 0xea, 0x80, 0xdb, 0xa2, 0x41, 0x80, 0x37, 0x80, 0x37,
		0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x1d, 0xe0,
		0x8d, 0xd3, 0xf0, 0x8e, 0xb8, 0x2a, 0xd1, 0xdb, 0xbc, 0x45, 0xc0, 0x37, 0xc0, 0x37, 0xc0, 0xb7,
		0xc2, 0xc1, 0xb7, 0x88, 0x13, 0x6e, 0x29, 0x32, 0xd2, 0x75, 0x43, 0x3d, 0x54, 0xd0, 0xd4, 0x67,
		0x6f, 0x16, 0x1b, 0xaa, 0x1e, 0xf1, 0xfc, 0x88, 0xda, 0xbe, 0xe7, 0x28, 0xb1, 0x8d, 0xad, 0x04,
		0x71, 0x35, 0x20, 0x03, 0x53, 0x40, 0x9c, 0xae, 0xa9, 0xaa, 0x1f, 0xee, 0xee, 0xee, 0x1f, 0xec,
		0xee, 0xd6, 0x0e, 0x76, 0x0e, 0x6a, 0x47, 0x7b, 0x7b, 0xf5, 0xfd, 0xfa, 0x1e, 0x70, 0xdd, 0x36,
		0xe0, 0xba, 0xb1, 0x82, 0xd5, 0xba, 0x0c, 0x19, 0xd3, 0xc6, 0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6,
		0x40, 0xc6, 0x81, 0x8c, 0x03, 0x19, 0x07, 0x1c, 0x07, 0x32, 0x0e, 0xa0, 0x4d, 0x0b, 0x68, 0xb3,
		0x38, 0x1b, 0x53, 0xa5, 0xc8, 0x6d, 0xd6, 0x22, 0xe0, 0x1b, 0xe0, 0x1b, 0xe0, 0x5b, 0xe1, 0xe0,
		0xdb, 0xd4, 0x36, 0x39, 0xb3, 0xbf, 0x47, 0x4a, 0x01, 0x1c, 0xa8, 0x38, 0x50, 0x71, 0x80, 0x70,
		0xa0, 0xe2, 0x80, 0xea, 0x0a, 0x81, 0xea, 0x14, 0x38, 0x96, 0x15, 0xa0, 0x63, 0x1e, 0xb0, 0x1c,
		0xb0, 0x1c, 0xb0, 0x1c, 0xa8, 0x38, 0x50, 0x71, 0xa0, 0xe2, 0x80, 0xe3, 0x40, 0xc5, 0x01, 0xb4,
		0xe9, 0x01, 0x6d, 0xaa, 0xa9, 0xb8, 0x45, 0x8b, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0xa0, 0xe2,
		0x40, 0xc5, 0x81, 0x8a, 0x03, 0x84, 0x03, 0x15, 0x07, 0x54, 0x97, 0xc1, 0x93, 0xa2, 0x92, 0x26,
		0x92, 0xaa, 0x88, 0xcb, 0x76, 0xd4, 0xa9, 0x23, 0xc6, 0xf2, 0x4e, 0x1f, 0xe4, 0x95, 0x86, 0x2a,
		0x6f, 0x5e, 0x60, 0xd0, 0x9d, 0xbd, 0x36, 0xfe, 0xb9, 0x3d, 0x7d, 0x5f, 0x2f, 0x7e, 0x5d, 0x81,
		0xc5, 0x9c, 0xd6, 0x07, 0x6a, 0xa6, 0x80, 0x25, 0x2d, 0xe9, 0xb4, 0xd9, 0x24, 0x24, 0xea, 0x20,
		0xec, 0x24, 0x09, 0xc1, 0xb7, 0x57, 0xa2, 0xae, 0xf4, 0x57, 0xe1, 0x77, 0x7b, 0x83, 0xf6, 0x49,
		0xf3, 0xfc, 0xba, 0xd7, 0xbd, 0x1c, 0x5c, 0x0f, 0xfe, 0xea, 0xb5, 0xca, 0x7b, 0x1b, 0x7e, 0xf3,
		0xf4, 0xb4, 0x8c, 0x17, 0x77, 0xb6, 0x3b, 0x9f, 0x2e, 0x5b, 0xfd, 0x7e, 0x19, 0xbb, 0x76, 0xd1,
		0xed, 0xb4, 0x07, 0xdd, 0xcb, 0x32, 0x76, 0x6d, 0xd0, 0xba, 0xbc, 0x68, 0x77, 0x9a, 0xe7, 0xd7,
		0xe7, 0xed, 0x4e, 0xab, 0x8c, 0x1d, 0x6c, 0x95, 0x76, 0x55, 0x9e, 0x5e, 0x76, 0x7b, 0xa5, 0x5e,
		0x92, 0x27, 0xe7, 0xed, 0x56, 0x67, 0x80, 0x5b, 0x80, 0xb5, 0x40, 0xfe, 0x09, 0x57, 0x28, 0xe0,
		0xfa, 0xa8, 0x35, 0x28, 0xb8, 0x02, 0xe8, 0x6f, 0x19, 0xd0, 0x87, 0x82, 0xab, 0x1e, 0xa3, 0x54,
		0x69, 0x9c, 0xcf, 0x19, 0x29, 0x76, 0xcb, 0xb0, 0x5b, 0xa6, 0x33, 0x7f, 0xdf, 0x58, 0x73, 0x28,
		0x76, 0xca, 0x1b, 0x66, 0x56, 0x50, 0xec, 0xf4, 0xc2, 0x8c, 0xa3, 0xd8, 0x69, 0x1b, 0xa7, 0x0a,
		0xc5, 0x4e, 0xc2, 0xd3, 0x02, 0x05, 0x57, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0x80,
		0x37, 0x80, 0x37, 0x80, 0x37, 0x80, 0x37, 0xa3, 0xc0, 0x1b, 0x14, 0x5c, 0x01, 0xdf, 0x00, 0xdf,
		0xb6, 0x07, 0xbe, 0x41, 0xc1, 0x75, 0x4b, 0x40, 0x1c, 0x6a, 0xd5, 0x51, 0xab, 0x8e, 0x5a, 0x75,
		0x28, 0xb8, 0xca, 0x87, 0x0c, 0x28, 0xb8, 0x02, 0xcd, 0x01, 0xcd, 0x81, 0x8c, 0x03, 0x19, 0x07,
		0x32, 0x0e, 0x38, 0x0e, 0x64, 0x1c, 0x40, 0x9b, 0x36, 0xd0, 0x06, 0x05, 0x57, 0xc0, 0x37, 0xc0,
		0xb7, 0xad, 0x81, 0x6f, 0x90, 0x8d, 0x00, 0x15, 0x07, 0x08, 0x07, 0x2a, 0x0e, 0xa8, 0xae, 0xc4,
		0xa8, 0x0e, 0x0a, 0xae, 0xc0, 0x72, 0xc0, 0x72, 0xa0, 0xe2, 0x40, 0xc5, 0x81, 0x8a, 0x03, 0x8e,
		0x03, 0x15, 0x07, 0xd0, 0x66, 0x04, 0x68, 0x83, 0x82, 0x2b, 0xe0, 0x1b, 0xe0, 0x1b, 0xa8, 0x38,
		0x50, 0x71, 0xa0, 0xe2, 0x00, 0xe1, 0x40, 0xc5, 0x01, 0xd5, 0x15, 0x03, 0xd5, 0x41, 0xc1, 0x95,
		0xd3, 0x0f, 0x0a, 0xa4, 0x86, 0x2a, 0xa9, 0x24, 0x5c, 0xbb, 0xf1, 0x0b, 0x0b, 0xaf, 0xe1, 0xca,
		0x99, 0xcb, 0xe5, 0x85, 0x9c, 0xe2, 0x56, 0xa0, 0xd4, 0x0a, 0x01, 0x27, 0x49, 0xa8, 0xbd, 0xbd,
		0x4a, 0xad, 0x2a, 0xc8, 0x50, 0x15, 0x24, 0xa8, 0x52, 0xf2, 0x53, 0x11, 0x62, 0x56, 0x90, 0xb4,
		0xa8, 0x44, 0xc8, 0x8a, 0xc9, 0x4d, 0xd5, 0x88, 0x58, 0x07, 0x96, 0x52, 0x80, 0x80, 0x95, 0x22,
		0x5f, 0xc5, 0xa4, 0xa5, 0x11, 0x53, 0x90, 0x13, 0x7c, 0xbc, 0xca, 0x0a, 0xbc, 0xbc, 0xd3, 0xb8,
		0x20, 0x65, 0x61, 0xa9, 0x6a, 0x38, 0x9a, 0x2e, 0xbe, 0x25, 0x1f, 0x9a, 0x64, 0x7f, 0x33, 0xe1,
		0xe0, 0x89, 0x0e, 0x9a, 0xba, 0xc1, 0x4a, 0x11, 0x0b, 0x13, 0x03, 0xf3, 0x64, 0x43, 0xff, 0xf6,
		0x40, 0x26, 0x18, 0xc4, 0xea, 0x6c, 0xae, 0x93, 0x8e, 0xdd, 0xa3, 0x13, 0xa7, 0x49, 0x69, 0xef,
		0x94, 0xfa, 0xa7, 0x2b, 0xb8, 0x9c, 0x30, 0x7a, 0x89, 0xc0, 0xe3, 0x75, 0x38, 0xbc, 0x98, 0xf1,
		0x34, 0x53, 0x29, 0x08, 0x7f, 0xa5, 0xe1, 0xae, 0x34, 0xbc, 0x7d, 0x0a, 0x67, 0x97, 0x9d, 0xdf,
		0x26, 0x03, 0x4e, 0xe1, 0xe0, 0x12, 0x58, 0xd9, 0x3b, 0x89, 0x71, 0xa8, 0x36, 0x27, 0xa3, 0xe9,
		0x6c, 0x50, 0x27, 0x11, 0x04, 0x4d, 0x69, 0xa5, 0x1f, 0xd6, 0x26, 0xf8, 0xe3, 0xda, 0x70, 0x3c,
		0xfb, 0xeb, 0x47, 0xbf, 0x4d, 0xe1, 0xda, 0xaa, 0xa7, 0x34, 0xb2, 0x43, 0x16, 0xcc, 0xe7, 0xb0,
		0xda, 0x74, 0x1c, 0xe6, 0x8d, 0x2a, 0xd3, 0x16, 0x2a, 0x37, 0x21, 0x25, 0xdf, 0xfd, 0x09, 0xaf,
		0x38, 0x84, 0x93, 0x0a, 0xf7, 0x2b, 0xc1, 0xed, 0x43, 0x34, 0x75, 0x73, 0x95, 0xc5, 0x9b, 0xe2,
		0xff, 0xf2, 0xbe, 0x32, 0xb8, 0x65, 0x51, 0x25, 0x9a, 0xdc, 0xf0, 0x90, 0xd2, 0x6f, 0x1e, 0x8b,
		0x2a, 0xbe, 0xe7, 0x3e, 0x54, 0xee, 0x88, 0xcb, 0x9c, 0xca, 0xfd, 0x2d, 0xf5, 0x2a, 0xfc, 0x96,
		0x56, 0xf8, 0x43, 0x40, 0x2b, 0xfe, 0x30, 0xfe, 0x79, 0xf9, 0xd9, 0x15, 0x16, 0x55, 0x7a, 0xdd,
		0xcb, 0xc1, 0x7b, 0xdd, 0xde, 0xa8, 0x96, 0x91, 0x37, 0x4a, 0x19, 0x54, 0xca, 0xe3, 0x89, 0x12,
		0x47, 0x3e, 0xf5, 0x5e, 0x28, 0xad, 0xca, 0x71, 0x75, 0xb1, 0xb0, 0xad, 0xb1, 0xef, 0x08, 0x0c,
		0xfe, 0x62, 0xbe, 0x1f, 0x37, 0x93, 0x72, 0xfc, 0x9e, 0xd8, 0xdd, 0xc0, 0x0f, 0x2c, 0x97, 0xde,
		0x51, 0xb7, 0x62, 0xfb, 0x1e, 0x27, 0xcc, 0xa3, 0x61, 0x65, 0xe8, 0x87, 0xcf, 0x18, 0x62, 0xda,
		0x17, 0x89, 0xe9, 0x97, 0x0b, 0xd3, 0x5e, 0x32, 0x74, 0x97, 0x84, 0x25, 0xa9, 0xa2, 0xb6, 0x94,
		0x51, 0x5a, 0xca, 0xa8, 0x2c, 0x39, 0x4b, 0x13, 0xcc, 0x7e, 0x54, 0x5b, 0xb2, 0x0a, 0xb4, 0x6b,
		0x50, 0xf8, 0x9c, 0xe7, 0x18, 0x33, 0xeb, 0x5d, 0x46, 0xcf, 0x45, 0xd0, 0x5c, 0x7d, 0x4c, 0x65,
		0xea, 0x39, 0xdc, 0x92, 0xc4, 0x3e, 0x01, 0x62, 0xba, 0x3c, 0xf1, 0x2f, 0x3d, 0xb1, 0x9c, 0x73,
		0x0c, 0x7c, 0x94, 0x06, 0x0b, 0x87, 0x40, 0xc1, 0x64, 0xfa, 0x39, 0xd3, 0x39, 0x99, 0xc5, 0xbd,
		0x68, 0x66, 0x2f, 0x51, 0x40, 0x6d, 0x36, 0x64, 0x76, 0x6c, 0x38, 0x7e, 0xc8, 0xa7, 0x98, 0x72,
		0x69, 0x56, 0x3c, 0x24, 0x5e, 0x34, 0xfd, 0xed, 0x37, 0xcf, 0xa1, 0x77, 0xcc, 0xa6, 0xd1, 0xfb,
		0x2d, 0x89, 0x8a, 0x12, 0x9b, 0x3f, 0xe5, 0x8f, 0x8c, 0xe2, 0x9b, 0x3b, 0x85, 0x8f, 0x8e, 0xaf,
		0xfe, 0x8d, 0xab, 0xb7, 0xb2, 0xd4, 0x74, 0x59, 0xba, 0x54, 0x76, 0x5e, 0x4d, 0xc4, 0x5a, 0xbd,
		0xcc, 0xa4, 0xbd, 0x3e, 0x77, 0x2f, 0x8f, 0xc3, 0x2b, 0x7e, 0xb2, 0x1a, 0xef, 0xc9, 0x5b, 0xd1,
		0x24, 0x08, 0xdc, 0x87, 0x37, 0x47, 0x60, 0x69, 0x6d, 0x8f, 0x9e, 0x7a, 0x63, 0x84, 0x93, 0x79,
		0x93, 0xc4, 0xde, 0x23, 0x8d, 0xb7, 0x10, 0xe4, 0xc2, 0xd2, 0x7a, 0x03, 0x61, 0xeb, 0x17, 0xb6,
		0x76, 0x71, 0xae, 0x4b, 0x8e, 0xd3, 0x49, 0x1a, 0x49, 0xab, 0xf6, 0x62, 0x36, 0x53, 0x02, 0xd3,
		0xf9, 0x73, 0x25, 0x21, 0x3c, 0x40, 0xbf, 0x6e, 0x13, 0xfd, 0xba, 0x72, 0x89, 0x1f, 0xe6, 0xcb,
		0x18, 0xbb, 0x1d, 0xd8, 0xed, 0x80, 0xb9, 0xe9, 0x37, 0xb7, 0x22, 0xed, 0x7a, 0x64, 0x86, 0x27,
		0x13, 0x23, 0xb0, 0x37, 0x70, 0xe5, 0x3d, 0x0d, 0xfb, 0xb3, 0x66, 0x74, 0xc0, 0xcb, 0xd0, 0x0f,
		0x68, 0xc8, 0x59, 0x7c, 0xab, 0x73, 0x52, 0x70, 0xb9, 0x7a, 0x06, 0xd0, 0x12, 0xd0, 0xf2, 0x85,
		0x25, 0xf5, 0x90, 0x3e, 0xd8, 0x2d, 0x9f, 0x04, 0xbc, 0x44, 0xbc, 0xcb, 0x9a, 0x53, 0x4c, 0x99,
		0x11, 0xc9, 0x65, 0x46, 0xa6, 0x53, 0x79, 0x02, 0x4b, 0x7b, 0x7b, 0xa8, 0xbc, 0xf4, 0x4b, 0x5f,
		0x90, 0xca, 0x4b, 0xcb, 0x59, 0x0b, 0x5e, 0xa8, 0x5b, 0x9d, 0xa3, 0x12, 0xc9, 0x63, 0x10, 0x71,
		0x2b, 0x38, 0x06, 0x21, 0x69, 0x3e, 0xaa, 0xcc, 0x48, 0xb9, 0x39, 0x29, 0x37, 0x2b, 0xf5, 0xe6,
		0x25, 0x66, 0x66, 0x82, 0xe6, 0xb6, 0xfc, 0x7c, 0x75, 0xc7, 0x20, 0x22, 0x1e, 0x32, 0x6f, 0xa4,
		0xe2, 0x0c, 0xc4, 0x61, 0x81, 0x0f, 0x5d, 0xdd, 0xcd, 0xcb, 0xcd, 0x25, 0xdd, 0xcd, 0xac, 0x19,
		0xf8, 0x1b, 0xf8, 0x1b, 0xf8, 0x1b, 0xc1, 0x95, 0x33, 0xf1, 0x98, 0xef, 0xa9, 0x70, 0x37, 0x47,
		0x12, 0x6d, 0xcc, 0xbb, 0x93, 0xfb, 0x21, 0x29, 0x65, 0x4e, 0x58, 0x91, 0x33, 0x96, 0x5c, 0x26,
		0x1a, 0x46, 0xe6, 0xc6, 0xf7, 0x5d, 0x4a, 0x3c, 0x95, 0x43, 0x53, 0x2f, 0xc9, 0xd0, 0x30, 0x8f,
		0x2b, 0x15, 0x02, 0xd9, 0x85, 0x60, 0x87, 0xe0, 0x8a, 0xd2, 0xa4, 0x02, 0x71, 0xd4, 0x68, 0xec,
		0xec, 0x1c, 0x34, 0x6a, 0x3b, 0xfb, 0x87, 0x7b, 0xbb, 0x07, 0x07, 0x7b, 0x87, 0xb5, 0x43, 0x48,
		0x78, 0xa8, 0x9e, 0xbc, 0x5a, 0x66, 0x93, 0x77, 0x00, 0x05, 0x8f, 0xb4, 0xff, 0x5c, 0x95, 0xc4,
		0x55, 0x4f, 0x54, 0xfb, 0xea, 0x43, 0xf8, 0xea, 0x62, 0x99, 0x3b, 0xc4, 0x95, 0x8c, 0x99, 0x2a,
		0x88, 0x2b, 0xc1, 0x35, 0x43, 0x13, 0x79, 0x8b, 0x7c, 0x3e, 0x34, 0x91, 0xa1, 0x89, 0x0c, 0x07,
		0x9f, 0xb1, 0x83, 0x87, 0xfc, 0x49, 0x3e, 0xf2, 0x27, 0xcb, 0x3a, 0xaa, 0xc5, 0x8f, 0xe9, 0x0a,
		0x53, 0xd3, 0x8f, 0x4e, 0x8a, 0x91, 0x11, 0xdb, 0xf4, 0x95, 0xd9, 0xec, 0x15, 0xc4, 0x92, 0xa8,
		0x85, 0x40, 0x2d, 0x44, 0x7a, 0x9b, 0x17, 0xde, 0x24, 0x59, 0xce, 0xbc, 0x4b, 0xc9, 0x30, 0xa4,
		0x43, 0x91, 0x59, 0x5f, 0x40, 0x4f, 0x01, 0x96, 0xa9, 0xda, 0x9b, 0xbb, 0x99, 0xf7, 0xef, 0xe7,
		0xda, 0x9d, 0xb1, 0xa5, 0x15, 0xc0, 0x5f, 0xa4, 0x2b, 0x70, 0xdf, 0x18, 0xce, 0x34, 0x85, 0xee,
		0x1b, 0x03, 0x29, 0xea, 0x31, 0x1a, 0xf0, 0x18, 0xf0, 0x18, 0x09, 0x3f, 0x53, 0xb8, 0x7a, 0x6a,
		0x16, 0xd2, 0x27, 0x21, 0xb9, 0x71, 0x15, 0x94, 0x35, 0x3c, 0x6a, 0x0d, 0xd5, 0x0d, 0xa8, 0x6e,
		0xc8, 0xcd, 0xdc, 0xe4, 0xd2, 0x87, 0xfc, 0xab, 0x1b, 0xe4, 0xb7, 0xab, 0x25, 0xb7, 0xa9, 0xb3,
		0x29, 0xa7, 0x42, 0xf1, 0x26, 0xdc, 0x0d, 0xdc, 0x0d, 0x8a, 0x37, 0x51, 0xbc, 0x09, 0x7f, 0x03,
		0x7f, 0xb3, 0x3d, 0xfe, 0x06, 0xc5, 0x9b, 0x3a, 0x9c, 0xb0, 0x22, 0x67, 0x2c, 0xb9, 0x4c, 0x34,
		0x8c, 0x0c, 0x8a, 0x37, 0x5f, 0x1c, 0x1a, 0x14, 0x6f, 0xa6, 0xf8, 0x30, 0x14, 0x6f, 0x3e, 0xf7,
		0x26, 0x6c, 0x17, 0xa3, 0x78, 0x53, 0x1d, 0xb8, 0x50, 0xdf, 0x0a, 0x8a, 0x37, 0x5f, 0x58, 0xb5,
		0x28, 0xde, 0x2c, 0x98, 0xb9, 0xa3, 0x90, 0xc7, 0x98, 0xa9, 0x42, 0xf1, 0x26, 0x5c, 0x33, 0x8a,
		0x37, 0xb7, 0xc8, 0xe7, 0xa3, 0x78, 0x13, 0xc5, 0x9b, 0x70, 0xf0, 0x19, 0x3b, 0x78, 0x14, 0x6f,
		0x16, 0xa6, 0x78, 0xd3, 0xa0, 0xdb, 0xeb, 0x7e, 0xa7, 0x0f, 0x29, 0xb7, 0x75, 0xab, 0xe7, 0x2c,
		0xe2, 0x4d, 0xce, 0x53, 0xca, 0x6a, 0x5d, 0x30, 0xaf, 0xe5, 0xd2, 0xf1, 0x74, 0xf4, 0xd2, 0xb9,
		0x87, 0xa9, 0xfb, 0x5b, 0x7b, 0x52, 0x0e, 0x4c, 0x56, 0xbb, 0xa1, 0x43, 0x43, 0xea, 0x1c, 0x4f,
		0x7b, 0xed, 0x4d, 0x5c, 0xd7, 0x6c, 0x6d, 0xcd, 0xcd, 0xb5, 0xa7, 0xe4, 0x32, 0xc0, 0x45, 0x5b,
		0xdb, 0x25, 0xd4, 0xb9, 0x52, 0xb3, 0xd4, 0xa0, 0xaf, 0x99, 0xac, 0x2a, 0x32, 0x55, 0x15, 0x64,
		0x6a, 0x55, 0xcd, 0x06, 0x54, 0x35, 0x13, 0xd8, 0x70, 0xc1, 0x55, 0x35, 0x89, 0xeb, 0xfa, 0x36,
		0xe1, 0xd4, 0x99, 0xdf, 0xd2, 0x9f, 0x5a, 0x5c, 0xf3, 0x69, 0x03, 0xe9, 0x34, 0x36, 0x6b, 0xd0,
		0xd8, 0x84, 0xc6, 0xe6, 0xd3, 0xcf, 0x49, 0xbd, 0x59, 0xfd, 0x88, 0xa7, 0xdd, 0x69, 0xa4, 0x99,
		0xb4, 0xf9, 0x3a, 0x4c, 0xc1, 0xed, 0x0b, 0xe6, 0xe0, 0x02, 0x18, 0x52, 0x26, 0xa7, 0x96, 0xad,
		0x56, 0x91, 0x4c, 0xbc, 0x54, 0x24, 0x58, 0x22, 0x75, 0x42, 0x32, 0xb9, 0xad, 0xaa, 0x21, 0xdb,
		0x6d, 0x1c, 0xed, 0x1e, 0xed, 0x1f, 0x34, 0x8e, 0xf6, 0x72, 0x1c, 0x3b, 0x4d, 0xd9, 0xc2, 0x55,
		0x86, 0x57, 0x1b, 0x38, 0x8f, 0xee, 0xc2, 0x4a, 0x19, 0x96, 0xd6, 0x1f, 0x46, 0x48, 0x42, 0x48,
		0xca, 0x2d, 0x24, 0xa5, 0x2e, 0x0d, 0x4a, 0x59, 0x02, 0xa4, 0xc6, 0xd6, 0xe8, 0x38, 0x10, 0x51,
		0x56, 0x9f, 0x3d, 0x96, 0xf8, 0x5a, 0xc8, 0x21, 0x99, 0xb8, 0xf1, 0x8c, 0x0e, 0x89, 0x1b, 0x51,
		0xd8, 0x25, 0xec, 0x32, 0x3f, 0xbb, 0x4c, 0x5f, 0x98, 0x96, 0xb2, 0x00, 0x4d, 0x91, 0x61, 0xfe,
		0x77, 0xc2, 0x82, 0xe9, 0x80, 0x5b, 0x43, 0xc2, 0xdc, 0x49, 0x28, 0x70, 0xd7, 0xcf, 0x66, 0x13,
		0xdb, 0x6d, 0xb0, 0xc4, 0x25, 0xe1, 0x38, 0xda, 0x4a, 0x73, 0x9d, 0x77, 0x1d, 0xc6, 0xaa, 0xdb,
		0x58, 0xc7, 0x2c, 0x1a, 0x13, 0x6e, 0xdf, 0xca, 0x58, 0xeb, 0xb2, 0x0d, 0x98, 0x2b, 0xcc, 0x15,
		0xe6, 0xaa, 0xde, 0x5c, 0x87, 0x2c, 0x1c, 0xdf, 0x93, 0x90, 0x5a, 0x77, 0x34, 0x8c, 0x84, 0xb2,
		0xcc, 0x8d, 0x16, 0x00, 0x69, 0x01, 0x69, 0x91, 0x6a, 0xbe, 0xfa, 0xce, 0x5b, 0x12, 0x3a, 0x72,
		0x56, 0xb7, 0xd1, 0x02, 0xac, 0x0e, 0x56, 0x07, 0xab, 0x7b, 0xf5, 0x9d, 0xcc, 0x49, 0x6f, 0x67,
		0xcc, 0x81, 0x65, 0xc1, 0xb2, 0x60, 0x59, 0xaf, 0xbf, 0x33, 0xde, 0xfe, 0x16, 0x8a, 0x63, 0xcb,
		0x27, 0x61, 0x65, 0xb0, 0x32, 0x58, 0xd9, 0xab, 0xef, 0x1c, 0xd3, 0xb1, 0x1f, 0x0a, 0xec, 0x50,
		0xcc, 0x9f, 0xc3, 0xcd, 0xaf, 0xb0, 0x30, 0x49, 0x0b, 0x4b, 0x7d, 0xf3, 0x2b, 0xb9, 0x23, 0xcc,
		0x15, 0x52, 0x67, 0x5b, 0x15, 0x57, 0x2d, 0x9b, 0x80, 0xe6, 0xa9, 0xa6, 0x85, 0xae, 0x6c, 0xc1,
		0x2b, 0x5b, 0xf8, 0xea, 0x0c, 0x20, 0x9d, 0x21, 0xa4, 0x34, 0x08, 0xf1, 0xd0, 0xb3, 0x31, 0xf3,
		0xc2, 0xc7, 0x6b, 0x25, 0x8e, 0xd3, 0x4a, 0x1e, 0xa5, 0x92, 0x50, 0x52, 0x51, 0x71, 0x54, 0x4a,
		0xd1, 0x19, 0x4b, 0x55, 0xe7, 0x6b, 0x54, 0x9e, 0xa7, 0x91, 0x38, 0xea, 0xa4, 0xe4, 0x68, 0x93,
		0xea, 0xa1, 0x55, 0x7f, 0x5c, 0x55, 0xe9, 0x68, 0x67, 0x74, 0x5a, 0xe7, 0xaa, 0x00, 0x52, 0xc2,
		0x13, 0xce, 0x5c, 0xf6, 0xbf, 0xd4, 0x11, 0x8f, 0xc7, 0xcb, 0x16, 0x10, 0x8e, 0x11, 0x8e, 0x11,
		0x8e, 0x11, 0x8e, 0x11, 0x8e, 0x11, 0x8e, 0x11, 0x8e, 0x75, 0xa5, 0xdc, 0x59, 0x1f, 0x80, 0x9c,
		0xdd, 0x7c, 0x90, 0x8a, 0x32, 0xaa, 0xbc, 0x76, 0xf2, 0xf1, 0x62, 0xd6, 0x52, 0x96, 0x34, 0xd9,
		0x70, 0x64, 0x39, 0x69, 0x2e, 0x4c, 0x58, 0x11, 0x65, 0x8b, 0x27, 0x41, 0x46, 0x83, 0x2a, 0x93,
		0xb4, 0x5b, 0x71, 0x32, 0xda, 0x49, 0x77, 0x5b, 0xc7, 0x8a, 0x8a, 0x4e, 0xf1, 0x4c, 0x8f, 0x70,
		0x4e, 0x43, 0x2f, 0x35, 0xd6, 0xa8, 0xfe, 0xe7, 0x6b, 0xcd, 0x3a, 0xba, 0xfa, 0x7b, 0xf7, 0xe7,
		0xb7, 0x6f, 0xd6, 0xec, 0xc7, 0xc6, 0xfa, 0x8f, 0xff, 0x4a, 0x3e, 0xdc, 0x57, 0x69, 0x3e, 0xb7,
		0xdb, 0x6f, 0xff, 0x59, 0x84, 0x6f, 0xce, 0xd8, 0x8d, 0xa5, 0x12, 0x98, 0x7f, 0xe4, 0xc6, 0xd2,
		0xa8, 0x0f, 0xc0, 0x8d, 0xc1, 0x8d, 0xa9, 0x77, 0x63, 0x66, 0xec, 0xa9, 0x89, 0x59, 0x18, 0xac,
		0x0b, 0xd6, 0x05, 0xeb, 0x7a, 0xdb, 0xba, 0xfc, 0x80, 0x86, 0xd6, 0x34, 0xa3, 0x98, 0x44, 0xe9,
		0x8d, 0x6c, 0xfd, 0x61, 0xd8, 0x1a, 0x6c, 0x2d, 0x37, 0x5b, 0x63, 0x0e, 0xf5, 0x38, 0xe3, 0x0f,
		0xe9, 0xae, 0x24, 0x5c, 0x1a, 0x5c, 0x1a, 0x2d, 0xa5, 0xf6, 0xfc, 0x55, 0xc7, 0x24, 0x92, 0xd8,
		0x32, 0x3f, 0xe9, 0x5e, 0xf4, 0xba, 0x9d, 0x56, 0x67, 0x70, 0xdd, 0xed, 0xb5, 0x2e, 0xaf, 0xfb,
		0x83, 0xe6, 0xe0, 0x73, 0x3f, 0xed, 0xfc, 0xc7, 0x64, 0x51, 0x24, 0xc4, 0x46, 0x4a, 0xde, 0x50,
		0x72, 0xda, 0xee, 0x37, 0x8f, 0xcf, 0x5b, 0xa7, 0xd5, 0x2c, 0xe4, 0x12, 0x24, 0xbf, 0xb5, 0xdd,
		0x69, 0x9e, 0x0c, 0xda, 0x5f, 0x5a, 0x26, 0x7c, 0xab, 0xf0, 0x97, 0xbe, 0xd3, 0x43, 0xab, 0xfd,
		0xcc, 0x30, 0x12, 0x05, 0x24, 0x9c, 0xb9, 0xa2, 0x94, 0x41, 0x68, 0xfe, 0x1c, 0xe2, 0x0f, 0xe2,
		0x4f, 0x6e, 0xf1, 0x27, 0xfd, 0x75, 0xb8, 0x22, 0xd7, 0xe0, 0xae, 0x5f, 0x7f, 0x3b, 0xfb, 0xdf,
		0x53, 0x52, 0x38, 0xf9, 0x75, 0xb8, 0xca, 0x6c, 0x96, 0x5b, 0x9e, 0x2f, 0x64, 0xb4, 0xf1, 0x83,
		0xb0, 0x5a, 0x58, 0x2d, 0x32, 0xb4, 0x57, 0xdf, 0x19, 0xd2, 0xb1, 0x7f, 0x97, 0xaa, 0x40, 0x73,
		0xd9, 0xc1, 0xd5, 0xa3, 0xb0, 0x33, 0xd8, 0x59, 0x6e, 0x76, 0x66, 0xc8, 0x41, 0xeb, 0x88, 0x86,
		0x8c, 0xb8, 0x42, 0xe1, 0x6c, 0xf5, 0x28, 0x0c, 0x0d, 0x86, 0x86, 0x80, 0xf6, 0xba, 0x9d, 0xf9,
		0x43, 0x2e, 0x77, 0xb4, 0x7a, 0xa3, 0x05, 0x58, 0x1d, 0xac, 0x0e, 0x56, 0xf7, 0xea, 0x3b, 0x39,
		0x1d, 0x07, 0x34, 0x24, 0x5c, 0x48, 0x9c, 0x6b, 0xfd, 0x61, 0x1c, 0x52, 0x83, 0xad, 0x49, 0xda,
		0x5a, 0xfa, 0x43, 0x6a, 0x2e, 0x09, 0xc7, 0x56, 0x44, 0xef, 0x68, 0xc8, 0x52, 0x28, 0x40, 0x6e,
		0x4c, 0xfc, 0x93, 0x76, 0x50, 0x1f, 0xaf, 0x69, 0xc9, 0x2b, 0x5b, 0xfa, 0xca, 0x4c, 0x40, 0x9d,
		0x29, 0xa4, 0x33, 0x89, 0x94, 0xa6, 0x21, 0x1e, 0x8e, 0x36, 0x66, 0x5e, 0x6c, 0x4f, 0x6c, 0xc3,
		0x7f, 0x0b, 0x94, 0x1d, 0xcb, 0xed, 0x91, 0x6d, 0x74, 0xa4, 0xdb, 0x6b, 0x75, 0x4e, 0xba, 0x9d,
		0xb3, 0xf6, 0xa7, 0xeb, 0xe6, 0x79, 0xf3, 0xf2, 0xe2, 0xba, 0xdf, 0xfa, 0xd2, 0xba, 0x6c, 0x0f,
		0xfe, 0xaa, 0xca, 0x48, 0x60, 0x47, 0x52, 0xf7, 0x93, 0x49, 0x56, 0x8b, 0x2f, 0xba, 0x76, 0xd1,
		0xee, 0x74, 0x2f, 0xab, 0x79, 0x54, 0xbd, 0x2b, 0xea, 0xc0, 0xe7, 0xce, 0xef, 0x9d, 0xee, 0x1f,
		0x1d, 0x93, 0xbb, 0x70, 0xd1, 0xfc, 0x7f, 0xcc, 0x9e, 0x83, 0x93, 0xcb, 0xf6, 0xa0, 0x7d, 0xd2,
		0x3c, 0x37, 0xb9, 0x0f, 0x7f, 0x34, 0x2f, 0x3b, 0xed, 0xce, 0xa7, 0x6a, 0xc6, 0x47, 0x12, 0xae,
		0x0a, 0x23, 0x59, 0x9f, 0xe6, 0x84, 0xe0, 0x1c, 0xc5, 0xa4, 0x2b, 0xda, 0x79, 0x09, 0x0b, 0xa5,
		0xa9, 0xde, 0x01, 0x12, 0x02, 0x12, 0x32, 0x10, 0x09, 0xa5, 0xe7, 0x9f, 0x37, 0x50, 0x50, 0xbd,
		0x30, 0x66, 0xcf, 0x6f, 0x43, 0x1a, 0xdd, 0xfa, 0xae, 0x23, 0x6b, 0xf9, 0xab, 0x86, 0x60, 0xfc,
		0x30, 0xfe, 0x52, 0x1f, 0x13, 0x4e, 0x75, 0xd9, 0xd2, 0xd3, 0x75, 0x7e, 0x80, 0x63, 0xc2, 0x15,
		0xf1, 0x34, 0x0b, 0xc7, 0x84, 0x75, 0x0e, 0xad, 0xec, 0x25, 0x4e, 0x5a, 0xc6, 0x78, 0x8b, 0xb4,
		0x3a, 0xc8, 0xdd, 0x48, 0x46, 0x36, 0x6b, 0xb4, 0x65, 0xa1, 0xd7, 0xe2, 0x0f, 0x01, 0x8d, 0x10,
		0x80, 0x5f, 0x09, 0xc0, 0xf3, 0x21, 0x2a, 0x5d, 0x18, 0x76, 0xa8, 0xcd, 0xc6, 0xc4, 0x95, 0x12,
		0xec, 0xa8, 0x0b, 0x5c, 0xb1, 0xbf, 0xe9, 0xd9, 0xea, 0xdb, 0x1a, 0xcf, 0x1b, 0x88, 0xe7, 0xba,
		0xe2, 0xf9, 0x4e, 0x09, 0x87, 0x76, 0x8b, 0xc2, 0x38, 0xf3, 0x22, 0x4e, 0x52, 0x9c, 0x3d, 0xd8,
		0xf0, 0x6e, 0x8b, 0x06, 0x10, 0xce, 0x11, 0xce, 0x11, 0xce, 0x11, 0xce, 0x11, 0xce, 0x11, 0xce,
		0x11, 0xce, 0xf3, 0x0b, 0xe7, 0x9c, 0x86, 0x77, 0xc4, 0x95, 0x89, 0xe7, 0xf3, 0x16, 0xb6, 0x23,
		0xa0, 0x23, 0x8e, 0xbf, 0x14, 0xc7, 0x4b, 0x1a, 0xbe, 0x23, 0x4e, 0xb8, 0x25, 0xb8, 0xc8, 0x2b,
		0x92, 0x12, 0x9a, 0x9f, 0xbd, 0x99, 0x2f, 0xab, 0x7a, 0xc4, 0xf3, 0x23, 0x6a, 0xfb, 0x9e, 0x23,
		0xb4, 0xf6, 0xc0, 0xb1, 0x23, 0x88, 0x67, 0x31, 0xb4, 0x90, 0xe2, 0x2c, 0x4a, 0x5c, 0x1f, 0x0b,
		0xac, 0x8e, 0x95, 0xe4, 0x1a, 0xf9, 0x81, 0xf4, 0x1c, 0x61, 0x1d, 0xe9, 0x39, 0xd2, 0x73, 0xa4,
		0xe7, 0x48, 0xcf, 0x91, 0x9e, 0xe7, 0x19, 0xc6, 0x2d, 0xce, 0xc6, 0x54, 0x2a, 0x96, 0xcf, 0x5a,
		0x40, 0x7a, 0x8e, 0xf4, 0xbc, 0x84, 0xe1, 0x7b, 0xba, 0xb6, 0x39, 0xb3, 0xbf, 0x47, 0x99, 0xdf,
		0x6f, 0x81, 0xe4, 0x1c, 0xc9, 0x39, 0x92, 0x73, 0x44, 0x75, 0x81, 0xa8, 0x2e, 0x60, 0x78, 0xab,
		0x80, 0xce, 0x3c, 0x24, 0xe7, 0x08, 0xea, 0x48, 0xce, 0x91, 0x9c, 0x23, 0x39, 0x47, 0x72, 0x8e,
		0xe4, 0x3c, 0xcf, 0x30, 0x2e, 0x9b, 0x9c, 0x2f, 0x5a, 0x40, 0x72, 0x8e, 0xe4, 0x1c, 0xc9, 0x39,
		0x92, 0x73, 0x24, 0xe7, 0x48, 0xce, 0x91, 0x9c, 0xab, 0x8f, 0xea, 0x25, 0xb8, 0xc4, 0x32, 0xbd,
		0xae, 0x5c, 0xe5, 0xb5, 0x9b, 0x2c, 0x07, 0x6b, 0xcd, 0x65, 0x29, 0xad, 0x97, 0x26, 0xa6, 0xac,
		0xe2, 0xc8, 0xf4, 0x29, 0x08, 0x57, 0x42, 0x4c, 0x4f, 0xd2, 0x72, 0xc5, 0x85, 0x2b, 0x27, 0x5e,
		0x72, 0xed, 0xd4, 0x47, 0xe4, 0xc3, 0x51, 0x8a, 0x67, 0xe6, 0x9f, 0x97, 0x0e, 0x6b, 0x40, 0xf6,
		0xec, 0x91, 0xec, 0xd9, 0x6f, 0xcd, 0xcb, 0xd3, 0x3f, 0x9a, 0x97, 0xad, 0xeb, 0xe5, 0xb5, 0x41,
		0xe6, 0x4b, 0x9f, 0x9d, 0x74, 0x3b, 0x83, 0xcb, 0xee, 0xf9, 0x79, 0xeb, 0xf2, 0xfa, 0xa4, 0x79,
		0x79, 0x6a, 0xb2, 0x78, 0x55, 0xaf, 0x7b, 0x39, 0x30, 0xf9, 0xfb, 0xcf, 0x9a, 0xc7, 0x97, 0xed,
		0x13, 0xb3, 0x7b, 0x60, 0xb4, 0x04, 0x5d, 0xbf, 0xd5, 0xe9, 0x9b, 0xad, 0x41, 0x77, 0xdc, 0x3c,
		0xf9, 0xbd, 0x77, 0xde, 0xec, 0xb4, 0x8c, 0x5e, 0x45, 0x97, 0x9f, 0x4d, 0xfe, 0xfc, 0x6e, 0x2f,
		0x96, 0x01, 0xbc, 0x3e, 0xf9, 0xad, 0xd9, 0xe9, 0xb4, 0x8c, 0x96, 0x03, 0x6c, 0x77, 0x06, 0xad,
		0x4f, 0x97, 0xcd, 0x41, 0xeb, 0xf4, 0xfa, 0xa4, 0x7d, 0x79, 0xf2, 0xb9, 0x6d, 0xb4, 0x7f, 0xed,
		0x0f, 0xba, 0x97, 0xcd, 0x4f, 0x46, 0x9b, 0xc6, 0x49, 0xef, 0xb3, 0xd9, 0x11, 0xfa, 0x8f, 0xd6,
		0xe5, 0x75, 0xff, 0x73, 0xaf, 0x77, 0xfe, 0x97, 0xd1, 0xd3, 0xf0, 0x5b, 0xb3, 0xdf, 0x6f, 0xf7,
		0x4d, 0xee, 0xc2, 0x79, 0xbb, 0xd3, 0x32, 0x1d, 0xf0, 0x0d, 0x2e, 0x9b, 0x9d, 0xfe, 0x49, 0xab,
		0xfd, 0xa5, 0x75, 0x59, 0x3a, 0xc5, 0xd2, 0x5f, 0x91, 0xa8, 0x89, 0x27, 0x6a, 0xfd, 0xee, 0xd9,
		0xa0, 0x6c, 0x89, 0x5a, 0xb7, 0xd7, 0xba, 0x6c, 0x0e, 0xda, 0x9d, 0x4f, 0xd7, 0xfd, 0xbf, 0xfa,
		0x83, 0xd6, 0xc5, 0xf5, 0xe7, 0xde, 0x69, 0x73, 0xd0, 0x32, 0x1b, 0x29, 0x3d, 0xee, 0xd2, 0xf6,
		0xca, 0x0e, 0x5f, 0x65, 0x48, 0x93, 0x4e, 0x22, 0xea, 0x58, 0x81, 0x7f, 0x4f, 0xc3, 0xf4, 0x64,
		0xe9, 0xda, 0xb3, 0xa0, 0x4c, 0x41, 0x99, 0xca, 0x79, 0x16, 0x19, 0xca, 0x34, 0xad, 0x9a, 0xa8,
		0x80, 0x8a, 0xa8, 0xe0, 0xfe, 0xac, 0x40, 0x28, 0x96, 0xd9, 0x8f, 0x95, 0xdc, 0x2c, 0x94, 0xdd,
		0x7f, 0x55, 0xb1, 0x13, 0x28, 0x10, 0x88, 0xa4, 0xf6, 0x59, 0x55, 0x0d, 0x99, 0xac, 0xea, 0xa7,
		0x92, 0xb1, 0x2b, 0x7a, 0x40, 0x7a, 0x27, 0x31, 0xf3, 0xd5, 0xe6, 0x64, 0x34, 0x75, 0x57, 0xd4,
		0x49, 0x64, 0x85, 0x29, 0x63, 0xd9, 0x87, 0x35, 0x0f, 0xf8, 0x71, 0x6d, 0x73, 0xf4, 0xd9, 0x5f,
		0x3f, 0xfa, 0x6d, 0xbc, 0x69, 0x9a, 0x34, 0x00, 0x9e, 0xd2, 0xc8, 0x0e, 0x59, 0x30, 0xdf, 0xd2,
		0xad, 0x36, 0x1d, 0x27, 0xaa, 0x44, 0x01, 0xb5, 0xd9, 0x90, 0xd9, 0x95, 0x58, 0x02, 0x3c, 0xaa,
		0x84, 0xd4, 0x25, 0x9c, 0x3a, 0x15, 0xee, 0x57, 0x48, 0x65, 0xf9, 0xce, 0xf7, 0x25, 0xb9, 0xe3,
		0x6b, 0xd6, 0xc9, 0xad, 0x8c, 0xb0, 0xf3, 0xae, 0x9b, 0x72, 0xbf, 0x17, 0xfd, 0xef, 0x84, 0x05,
		0xd3, 0xcf, 0xb7, 0x86, 0x84, 0xb9, 0x69, 0xae, 0xa8, 0xdb, 0x98, 0xf7, 0xcd, 0xa6, 0x52, 0x8e,
		0xe4, 0x13, 0xbb, 0x69, 0x0f, 0x67, 0xd3, 0x51, 0xe1, 0xb7, 0xb4, 0x72, 0x4b, 0x42, 0xe7, 0x9e,
		0x84, 0xb4, 0xc2, 0x3c, 0x87, 0xd9, 0x84, 0xd3, 0xa8, 0xc2, 0x6f, 0x09, 0x8f, 0xff, 0xdb, 0xd2,
		0x7c, 0xfe, 0x7f, 0x51, 0x25, 0xb8, 0x7d, 0x88, 0x98, 0x4d, 0xdc, 0xca, 0xf2, 0x6b, 0xbe, 0x79,
		0xb7, 0x24, 0xaa, 0x4c, 0x3f, 0x89, 0x3a, 0xe9, 0xbf, 0x68, 0x48, 0x26, 0x6e, 0x3c, 0xb5, 0x43,
		0xe2, 0x46, 0xdb, 0x52, 0x59, 0x99, 0xda, 0x7c, 0x65, 0xcd, 0x58, 0x99, 0x39, 0x2b, 0x33, 0x6b,
		0x55, 0xe6, 0x9d, 0x09, 0x17, 0x84, 0x9b, 0x3a, 0x36, 0xdd, 0xd9, 0x98, 0x45, 0x63, 0xc2, 0xed,
		0x5b, 0x15, 0xfe, 0x6c, 0xd9, 0x56, 0xd6, 0x0e, 0xad, 0xc2, 0xbc, 0x88, 0x86, 0x53, 0x9c, 0xc0,
		0x3c, 0xee, 0x4f, 0xff, 0xdb, 0x37, 0x8f, 0x0c, 0x87, 0xd4, 0x9e, 0xfe, 0xea, 0x59, 0xb7, 0xe7,
		0xfa, 0x76, 0x5c, 0x4b, 0x56, 0x61, 0x51, 0xc5, 0x1f, 0x56, 0x48, 0xc5, 0x61, 0xc3, 0x21, 0x0d,
		0xa7, 0x6d, 0xf1, 0x87, 0x80, 0x4e, 0xdf, 0xe1, 0x55, 0xee, 0x6f, 0x09, 0xff, 0xe6, 0xb1, 0xa8,
		0x32, 0x2b, 0x18, 0x9b, 0x84, 0xf0, 0x8c, 0xf0, 0x8c, 0xf0, 0x8c, 0xe6, 0x79, 0xc6, 0x4c, 0x52,
		0xb6, 0xab, 0xb7, 0x52, 0xb6, 0x74, 0x05, 0xac, 0x72, 0x85, 0xab, 0xaf, 0xaf, 0xaf, 0x97, 0x3b,
		0xf2, 0xca, 0xba, 0xa9, 0x46, 0xdc, 0x0f, 0xc9, 0xe8, 0xed, 0x65, 0xb2, 0x26, 0xe2, 0x37, 0x7b,
		0xe0, 0x8d, 0x81, 0x49, 0x96, 0xa4, 0x25, 0xf6, 0x69, 0x69, 0x7c, 0x98, 0x20, 0xe1, 0x99, 0xd6,
		0x4b, 0x09, 0x7b, 0x25, 0x61, 0x2f, 0x24, 0x4e, 0x68, 0xca, 0xf1, 0x12, 0x49, 0x13, 0xab, 0xaa,
		0xbd, 0x98, 0xcd, 0x94, 0xdc, 0xc4, 0xfc, 0x39, 0xdc, 0xf1, 0x0d, 0x8e, 0x5d, 0x92, 0x03, 0xc8,
		0xfe, 0x40, 0x41, 0xec, 0x0d, 0x3f, 0xcc, 0x57, 0x70, 0x86, 0xfb, 0x5a, 0xb3, 0x88, 0x90, 0xda,
		0xd4, 0x52, 0x91, 0x79, 0xa2, 0x96, 0xd6, 0x80, 0xa5, 0xc1, 0xd2, 0x34, 0x59, 0x5a, 0x02, 0x24,
		0x94, 0x19, 0x5f, 0x9f, 0x19, 0xf8, 0x4b, 0x02, 0xb9, 0x2a, 0xaf, 0x9d, 0x51, 0xea, 0xcf, 0x9b,
		0xd0, 0x81, 0x20, 0x27, 0x37, 0xab, 0xaf, 0x4e, 0x81, 0x23, 0x1f, 0x3d, 0x06, 0x34, 0x09, 0x34,
		0xf9, 0xda, 0xc2, 0x12, 0x08, 0x74, 0xeb, 0x4f, 0x03, 0x59, 0x22, 0xde, 0x49, 0xc6, 0xbb, 0xd4,
		0xbb, 0x4b, 0x29, 0x93, 0x21, 0xb9, 0xa4, 0x48, 0x70, 0x09, 0x17, 0x86, 0x5b, 0xc4, 0x35, 0xc9,
		0x4a, 0x97, 0x7e, 0x36, 0xfc, 0x62, 0x5a, 0x93, 0x58, 0x3e, 0x38, 0xc7, 0x27, 0x92, 0x15, 0xb0,
		0x71, 0x2b, 0xbf, 0xe6, 0x52, 0x13, 0x23, 0x6a, 0x2e, 0x2a, 0xcc, 0x46, 0xb1, 0xf9, 0xa8, 0x32,
		0x23, 0xe5, 0xe6, 0xa4, 0xdc, 0xac, 0xd4, 0x9b, 0x97, 0x98, 0x99, 0x09, 0x9a, 0x9b, 0x3c, 0xad,
		0xbf, 0xb1, 0x72, 0x5c, 0x4a, 0x86, 0x62, 0x85, 0xf0, 0x1b, 0xf1, 0xe6, 0x40, 0xa2, 0x8d, 0xde,
		0x3c, 0x23, 0x7a, 0xff, 0xfe, 0xc3, 0xfa, 0xff, 0x9e, 0xca, 0x36, 0xc4, 0xf6, 0x9e, 0x91, 0x7c,
		0x86, 0x5e, 0xc7, 0x29, 0x98, 0x3b, 0xcb, 0x27, 0x92, 0xeb, 0x39, 0xd7, 0xa3, 0x3f, 0xa5, 0x22,
		0xb0, 0xd2, 0x0f, 0x52, 0x9a, 0x6d, 0x6c, 0xa1, 0xe0, 0x20, 0x13, 0x14, 0x4c, 0x17, 0xf5, 0x04,
		0x66, 0x32, 0x08, 0x33, 0xc9, 0xef, 0xc9, 0x8a, 0x3b, 0x6d, 0x19, 0x67, 0xbd, 0xee, 0xa4, 0x45,
		0xdd, 0xb1, 0x1e, 0x7f, 0x91, 0x8e, 0x08, 0x97, 0x22, 0xc4, 0x95, 0x65, 0x59, 0x0d, 0x78, 0x0c,
		0x78, 0x0c, 0x64, 0x59, 0xc8, 0xb2, 0x90, 0x65, 0x21, 0xcb, 0x42, 0x96, 0xb5, 0x35, 0x59, 0x56,
		0x8a, 0xcd, 0x4b, 0x01, 0xd0, 0xa4, 0x94, 0xef, 0xfe, 0x9d, 0x3e, 0xa4, 0x74, 0xff, 0xd5, 0x73,
		0x16, 0xf1, 0x26, 0xe7, 0x29, 0x79, 0xf2, 0x0b, 0xe6, 0xb5, 0x5c, 0x3a, 0x9e, 0xef, 0x1e, 0xa6,
		0x70, 0xf5, 0xd5, 0x0b, 0xf2, 0x63, 0xed, 0x49, 0x39, 0xdd, 0xcf, 0x6a, 0x37, 0x74, 0x68, 0x48,
		0x9d, 0xe3, 0x69, 0xaf, 0xbd, 0x89, 0xeb, 0x9a, 0xbd, 0x59, 0xfe, 0xe2, 0x12, 0x54, 0x21, 0x78,
		0xd9, 0x5f, 0x6f, 0x6f, 0xbb, 0x76, 0xe2, 0x1f, 0x6d, 0x5a, 0x6b, 0xd8, 0x4c, 0xe7, 0x21, 0xf1,
		0x22, 0x9b, 0xb2, 0xbb, 0x04, 0xc7, 0xd5, 0x57, 0x9a, 0x9e, 0x6b, 0x0f, 0x99, 0xb1, 0x91, 0x9e,
		0xfc, 0x8b, 0x2b, 0x46, 0xee, 0xa5, 0xaf, 0xf7, 0x0f, 0xc5, 0x99, 0x0a, 0x21, 0xbe, 0xec, 0x16,
		0x7a, 0xba, 0x85, 0x27, 0x8b, 0xda, 0x8b, 0xb7, 0x8b, 0x9e, 0x6a, 0x61, 0xea, 0x01, 0x16, 0xe9,
		0x8f, 0x69, 0x7a, 0xe4, 0xc6, 0x8d, 0x0f, 0x45, 0x8b, 0x1e, 0x66, 0x9a, 0x37, 0xb0, 0x25, 0x57,
		0x43, 0x08, 0x2d, 0xf1, 0xed, 0xe1, 0x79, 0x84, 0x4c, 0xc0, 0x14, 0x72, 0xb8, 0x2c, 0x47, 0x19,
		0xf9, 0x2d, 0x0d, 0x3d, 0xca, 0xad, 0x60, 0xec, 0x58, 0x41, 0x48, 0xa7, 0x31, 0x48, 0xc2, 0xfe,
		0x9f, 0x6b, 0x0d, 0xce, 0x00, 0xce, 0xa0, 0xe4, 0xce, 0xa0, 0x34, 0x5a, 0x77, 0xad, 0xc1, 0x6f,
		0xad, 0xcb, 0x4e, 0x6b, 0x70, 0xdd, 0xbb, 0x38, 0xbd, 0x1e, 0xfc, 0xd5, 0x6b, 0x99, 0xaf, 0x6f,
		0xd7, 0x1a, 0xfc, 0x76, 0x5d, 0xaf, 0xd5, 0x3e, 0x1d, 0x37, 0xfb, 0xad, 0xeb, 0x93, 0x3f, 0x4e,
		0x2f, 0x76, 0x4d, 0x96, 0xb6, 0x9b, 0xf6, 0x66, 0x77, 0xde, 0x99, 0xfe, 0x65, 0x69, 0xba, 0xd2,
		0x32, 0xbf, 0x2b, 0xf5, 0xe5, 0xac, 0x98, 0xde, 0x93, 0xcf, 0x9d, 0xd3, 0xd6, 0x59, 0xbb, 0xd3,
		0x3a, 0x2d, 0xcb, 0xea, 0x3a, 0x29, 0x8f, 0xa1, 0xf4, 0xfa, 0x17, 0x25, 0xb0, 0x94, 0xda, 0xa7,
		0xeb, 0xe6, 0xc9, 0x89, 0xf1, 0x73, 0xf2, 0xe7, 0xc2, 0xe6, 0xcf, 0x2f, 0xcb, 0x30, 0x27, 0xf3,
		0xae, 0x94, 0xc6, 0x56, 0xce, 0x2f, 0x77, 0x4b, 0x33, 0x2d, 0x65, 0xb1, 0xfb, 0x99, 0x3f, 0x3e,
		0x2f, 0x4f, 0xb8, 0x6f, 0x95, 0xc7, 0xf4, 0x5b, 0x25, 0xb2, 0x97, 0x7e, 0x79, 0x56, 0x58, 0x89,
		0x82, 0x4b, 0xff, 0xb2, 0x5e, 0x2b, 0x07, 0x7a, 0xe9, 0x9e, 0x94, 0x65, 0x79, 0xfd, 0xdf, 0xf2,
		0x2c, 0xaf, 0x32, 0xe0, 0xfc, 0x3f, 0xcb, 0x93, 0x47, 0xae, 0x1c, 0xd8, 0x16, 0x2b, 0xf0, 0xa7,
		0x21, 0xe3, 0x87, 0xd4, 0xb6, 0xc6, 0xbe, 0x23, 0x51, 0x63, 0xbd, 0x6c, 0x01, 0xa4, 0x7b, 0x82,
		0x96, 0x40, 0xba, 0x2b, 0xb4, 0x08, 0x90, 0xee, 0xa2, 0x1d, 0x39, 0x6b, 0x9d, 0x5c, 0x5f, 0x74,
		0x4f, 0x5b, 0x25, 0x21, 0xdc, 0xa7, 0xdd, 0x39, 0x6d, 0xf7, 0x9b, 0xc7, 0xe7, 0x66, 0x33, 0x88,
		0xd3, 0x7e, 0xb4, 0x3a, 0xa5, 0xe8, 0x46, 0xf3, 0xf3, 0xa0, 0x8b, 0x10, 0x9c, 0x28, 0x04, 0xfb,
		0xe1, 0xd8, 0x1a, 0x12, 0x9b, 0xfb, 0xa1, 0xfc, 0x76, 0xf8, 0x73, 0x8d, 0x21, 0x30, 0x23, 0x30,
		0x23, 0x30, 0x9b, 0x11, 0x98, 0xd7, 0xee, 0x01, 0xbc, 0x3e, 0xeb, 0x5e, 0x5e, 0x5c, 0x9f, 0x35,
		0x4f, 0x06, 0xdd, 0xcb, 0x92, 0xc4, 0xe9, 0xff, 0xe9, 0x9f, 0xf5, 0x1a, 0x87, 0x26, 0x87, 0xb6,
		0x3f, 0xcf, 0x7a, 0x66, 0x5f, 0xba, 0xda, 0xfc, 0xdd, 0xe8, 0x7b, 0x6f, 0xcd, 0x1e, 0xfe, 0xff,
		0x29, 0xc1, 0xf7, 0x5f, 0xf7, 0xce, 0x3f, 0x1b, 0x7d, 0x5d, 0xec, 0xc9, 0x59, 0x6f, 0xd7, 0x70,
		0x1b, 0x30, 0x7e, 0x0e, 0x3a, 0xdd, 0xce, 0xb4, 0x0f, 0x9f, 0x3e, 0x4d, 0x73, 0x1d, 0xa3, 0xe3,
		0x41, 0xc3, 0x70, 0x53, 0x30, 0xfc, 0xf3, 0x4d, 0x1f, 0xfe, 0xc6, 0x75, 0xf3, 0xa4, 0x6b, 0xf4,
		0xc5, 0xb7, 0x83, 0xdf, 0x4a, 0x78, 0x65, 0xf5, 0x96, 0xe8, 0x2e, 0xaf, 0xe5, 0x84, 0x39, 0xa8,
		0x9c, 0x2f, 0xee, 0xf6, 0xb1, 0xec, 0x5b, 0xe2, 0x79, 0xd4, 0x8d, 0xd2, 0x9f, 0x5f, 0xdb, 0x6c,
		0x02, 0x47, 0xd9, 0x70, 0x94, 0x4d, 0x89, 0x2d, 0xa6, 0xd7, 0x84, 0x9d, 0x2d, 0x41, 0x09, 0x51,
		0xd8, 0x79, 0x03, 0xdb, 0xa1, 0x0a, 0x0b, 0xbe, 0xce, 0x58, 0xbe, 0x4e, 0x58, 0xb5, 0x48, 0x50,
		0x36, 0x79, 0xd3, 0x52, 0x44, 0xe4, 0x93, 0x25, 0x0d, 0x46, 0xda, 0x70, 0x54, 0x18, 0x90, 0x7a,
		0x43, 0x52, 0x65, 0x50, 0xca, 0x0d, 0x4b, 0xb9, 0x81, 0x69, 0x31, 0x34, 0x39, 0x1c, 0x2b, 0xaa,
		0x5f, 0x24, 0x6a, 0x80, 0xcb, 0x06, 0x9c, 0x47, 0x17, 0x38, 0x2a, 0x4a, 0x05, 0xd6, 0x1b, 0x95,
		0x9c, 0x22, 0x39, 0x71, 0x31, 0x65, 0xa6, 0xaa, 0xd2, 0x64, 0xf5, 0x99, 0xae, 0x6a, 0x13, 0xd6,
		0x66, 0xca, 0xda, 0x4c, 0x5a, 0xab, 0x69, 0xcb, 0x99, 0xb8, 0x82, 0x4c, 0xbd, 0xa2, 0x44, 0xb2,
		0x6c, 0x63, 0xfd, 0x45, 0x3c, 0x64, 0xde, 0x48, 0xc5, 0xba, 0x5b, 0x04, 0xd4, 0xc3, 0x77, 0xf9,
		0x8c, 0xaf, 0xc4, 0xd8, 0x56, 0x99, 0xe7, 0xd0, 0x1f, 0xea, 0x7c, 0xe0, 0xac, 0x39, 0x78, 0x3f,
		0x78, 0x3f, 0x78, 0xbf, 0x42, 0x7b, 0xbf, 0x09, 0xf3, 0x78, 0x7d, 0x5f, 0xa1, 0xf7, 0xdb, 0x57,
		0xd0, 0xd4, 0x25, 0xf1, 0xe2, 0xeb, 0x5a, 0xbf, 0x2a, 0x59, 0x0f, 0x6a, 0xec, 0xa0, 0x32, 0xd7,
		0xf1, 0x53, 0x66, 0x58, 0x8a, 0xdd, 0xdc, 0x46, 0xb3, 0x71, 0xb9, 0x83, 0x86, 0x76, 0xcf, 0x42,
		0x62, 0x4f, 0xb1, 0xed, 0x29, 0x1b, 0xb1, 0x99, 0x9c, 0xa1, 0xb2, 0xf6, 0x7f, 0xfe, 0xaa, 0x70,
		0xaa, 0xc8, 0x0f, 0x6d, 0x53, 0xb5, 0x83, 0xa9, 0xfa, 0xf9, 0xae, 0x18, 0xad, 0x5c, 0x19, 0x88,
		0xb5, 0x38, 0x09, 0x47, 0x94, 0x5b, 0xfe, 0x84, 0x07, 0x13, 0x6e, 0x05, 0xfe, 0x3d, 0x0d, 0xd5,
		0x21, 0xaf, 0xe7, 0x1a, 0x07, 0x0e, 0x03, 0x0e, 0x03, 0x0e, 0x2b, 0x34, 0x0e, 0x73, 0xa8, 0xcd,
		0xc6, 0xc4, 0xdd, 0xdf, 0x55, 0x99, 0x88, 0x36, 0x14, 0xb4, 0xb5, 0x11, 0x43, 0x1a, 0x00, 0x78,
		0x62, 0xd3, 0xd1, 0x00, 0x6a, 0x00, 0xc0, 0x03, 0xc0, 0xdb, 0x06, 0x80, 0xf7, 0xc3, 0x72, 0x49,
		0xa4, 0x14, 0xd5, 0x2d, 0x5a, 0x04, 0x94, 0x03, 0x94, 0x03, 0x94, 0x2b, 0x34, 0x94, 0x13, 0xd7,
		0xa7, 0x7d, 0x11, 0xc8, 0xd5, 0xf3, 0x72, 0x82, 0x99, 0x6e, 0xe7, 0x4a, 0x5e, 0x66, 0xb2, 0x6c,
		0x47, 0x45, 0x19, 0xe0, 0x46, 0x45, 0xdd, 0x87, 0xf9, 0x0f, 0x42, 0xb7, 0x48, 0x8a, 0x8f, 0xa7,
		0xc0, 0x58, 0x4a, 0xee, 0xe5, 0x28, 0xd9, 0xc3, 0x29, 0xdb, 0xb5, 0x58, 0x28, 0x2e, 0x29, 0x40,
		0xc0, 0xc0, 0xe5, 0x58, 0xaa, 0x2e, 0xc7, 0x9a, 0x5d, 0x83, 0x35, 0x33, 0xf0, 0x02, 0x3b, 0x32,
		0xb1, 0x6b, 0x2f, 0x37, 0xc6, 0x5f, 0xe4, 0xfa, 0xcb, 0x8d, 0x91, 0x97, 0x75, 0x64, 0x0d, 0x38,
		0x32, 0x38, 0xb2, 0x5c, 0x1c, 0x19, 0xaa, 0xe4, 0x90, 0xd4, 0x22, 0xa9, 0x45, 0x52, 0x2b, 0x19,
		0x43, 0x51, 0x25, 0x87, 0x2a, 0x39, 0x78, 0x3f, 0x78, 0xbf, 0x6d, 0xf4, 0x7e, 0xa8, 0x92, 0x4b,
		0xf3, 0x61, 0xa8, 0x92, 0xc3, 0x26, 0x2a, 0x36, 0x51, 0x2b, 0xd8, 0x44, 0x95, 0xc4, 0x5a, 0x1a,
		0xaa, 0xe3, 0xd6, 0x1b, 0x55, 0x83, 0xbb, 0xea, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0x2a, 0x88,
		0xa6, 0x65, 0x43, 0xe4, 0x6e, 0xa4, 0x6e, 0x85, 0x2c, 0xd6, 0xf2, 0xb4, 0x51, 0x45, 0x53, 0xa8,
		0x16, 0x8b, 0x28, 0x73, 0x01, 0x3a, 0x5c, 0xc1, 0xb3, 0x2e, 0xe1, 0x21, 0xa0, 0x51, 0x55, 0x21,
		0x0a, 0x51, 0xec, 0x14, 0xb4, 0x3b, 0x07, 0xed, 0x4e, 0xe2, 0x45, 0x67, 0x11, 0x8f, 0x7c, 0xd1,
		0xe0, 0x89, 0xa2, 0x55, 0xab, 0x2c, 0x6d, 0xdb, 0x58, 0xb3, 0x2a, 0x8b, 0x6b, 0x37, 0xe2, 0xbf,
		0xc2, 0xb2, 0x4e, 0x2d, 0xc5, 0xb6, 0x9a, 0xf2, 0x45, 0xf5, 0x79, 0xa3, 0xd6, 0xfc, 0xf1, 0xe9,
		0xb4, 0x29, 0x2e, 0xc6, 0xd5, 0x9d, 0xa4, 0x64, 0x91, 0xac, 0x68, 0xc8, 0x2f, 0xb5, 0xe6, 0x99,
		0x9a, 0xf3, 0xcd, 0x52, 0x4d, 0xe9, 0xbb, 0x62, 0xb6, 0x76, 0x55, 0x90, 0xfc, 0x58, 0xc1, 0x92,
		0xaf, 0x32, 0x2f, 0xe2, 0x24, 0x8e, 0xd4, 0x8a, 0x81, 0xeb, 0xa2, 0x61, 0x80, 0x57, 0x80, 0x57,
		0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x20, 0x1d, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57,
		0x75, 0xe0, 0x95, 0xd3, 0xf0, 0x8e, 0xb8, 0x3a, 0xd0, 0xeb, 0xbc, 0x65, 0xc0, 0x57, 0xc0, 0x57,
		0xc0, 0xd7, 0xad, 0x83, 0xaf, 0x11, 0x27, 0xdc, 0x52, 0xec, 0x04, 0xd6, 0x1d, 0xc1, 0xa1, 0xc2,
		0x26, 0x3f, 0x7b, 0xb3, 0x18, 0x56, 0xf5, 0x88, 0xe7, 0x47, 0xd4, 0xf6, 0x3d, 0x47, 0xa9, 0xad,
		0x01, 0xc4, 0xea, 0xab, 0xe4, 0x01, 0x88, 0xcd, 0x1f, 0xc4, 0xea, 0x9e, 0xd2, 0xfa, 0xe1, 0xee,
		0xee, 0xfe, 0xc1, 0xee, 0x6e, 0xed, 0x60, 0xe7, 0xa0, 0x76, 0xb4, 0xb7, 0x57, 0xdf, 0x17, 0xb9,
		0xaa, 0x0e, 0xb8, 0x76, 0x7b, 0x70, 0xed, 0x58, 0xe1, 0xaa, 0x5f, 0x86, 0xb4, 0x69, 0xa3, 0x40,
		0xb3, 0x40, 0xb3, 0x40, 0xb3, 0x5b, 0x87, 0x66, 0x41, 0xc6, 0x02, 0xc7, 0x3e, 0x99, 0x36, 0x90,
		0xb1, 0xa5, 0xc3, 0xb1, 0x20, 0x63, 0x01, 0x5a, 0xf3, 0x05, 0xad, 0x16, 0x67, 0x63, 0xaa, 0x05,
		0xb9, 0xce, 0x5a, 0x06, 0x7c, 0x05, 0x7c, 0x05, 0x7c, 0xdd, 0x3a, 0xf8, 0x3a, 0xb5, 0x7d, 0xce,
		0xec, 0xef, 0x91, 0x16, 0x00, 0x0b, 0x2a, 0x16, 0x54, 0x2c, 0x20, 0x6c, 0x31, 0x20, 0x2c, 0xa8,
		0x58, 0xa0, 0xda, 0x82, 0xa1, 0x5a, 0x85, 0x8e, 0x6c, 0x05, 0x68, 0x99, 0x07, 0x2c, 0x0b, 0x2c,
		0x0b, 0x2c, 0xbb, 0x7d, 0x58, 0x16, 0x54, 0x2c, 0x70, 0xec, 0x93, 0x69, 0x03, 0x15, 0x5b, 0x3a,
		0x1c, 0x0b, 0x2a, 0x16, 0xa0, 0x35, 0x5f, 0xd0, 0xaa, 0x8b, 0x8a, 0x5d, 0xb4, 0x0c, 0xf8, 0x0a,
		0xf8, 0x0a, 0xf8, 0xba, 0x75, 0xf0, 0x15, 0x54, 0x2c, 0x20, 0xac, 0x3e, 0xff, 0x0d, 0x08, 0x5b,
		0x1c, 0x08, 0x0b, 0x2a, 0x16, 0xa8, 0x56, 0x21, 0xaa, 0xcd, 0x55, 0xe2, 0x4b, 0xd1, 0x15, 0x3d,
		0xcb, 0xf6, 0xf4, 0x5e, 0xd5, 0xb3, 0xb8, 0xe6, 0x42, 0x95, 0xe6, 0xdf, 0xec, 0x93, 0x79, 0x38,
		0xb1, 0xb9, 0x37, 0x0f, 0xe3, 0x27, 0x8b, 0x4f, 0xba, 0x1e, 0xac, 0x3e, 0xe9, 0xfa, 0x64, 0xf6,
		0x01, 0xd7, 0xed, 0xe9, 0xab, 0x7b, 0xf1, 0x9b, 0x0d, 0x54, 0x60, 0x8c, 0x6f, 0x9c, 0xb3, 0x6e,
		0x18, 0x89, 0x2c, 0x7b, 0x12, 0x86, 0x54, 0x81, 0xb8, 0xc5, 0xea, 0x4e, 0x94, 0xcd, 0xb6, 0xa1,
		0xc7, 0x98, 0x28, 0xd1, 0x81, 0x1e, 0x23, 0xf4, 0x18, 0x93, 0xf5, 0x0c, 0x7a, 0x8c, 0xe0, 0x3e,
		0xc0, 0x7d, 0x80, 0xfb, 0x28, 0x1c, 0xf7, 0x81, 0xad, 0x3b, 0xf0, 0x1e, 0x4f, 0xa6, 0x0d, 0x5b,
		0x77, 0xa5, 0xe3, 0x3d, 0xb0, 0x75, 0x07, 0x92, 0x23, 0xbf, 0x25, 0x0f, 0x3d, 0x46, 0x80, 0x57,
		0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57,
		0x93, 0xc0, 0x2b, 0xf4, 0x18, 0x01, 0x5f, 0x01, 0x5f, 0x01, 0x5f, 0x55, 0xaf, 0x59, 0xe8, 0x31,
		0x02, 0xc4, 0xea, 0xf4, 0xe0, 0x00, 0xb1, 0xc5, 0x01, 0xb1, 0xa8, 0x3c, 0x03, 0xae, 0x2d, 0x16,
		0xae, 0x85, 0x1e, 0x23, 0xd0, 0x2c, 0xd0, 0x2c, 0xd0, 0xac, 0xaa, 0x35, 0x0b, 0x32, 0x16, 0x38,
		0xf6, 0xc9, 0xb4, 0x81, 0x8c, 0x2d, 0x1d, 0x8e, 0x05, 0x19, 0x0b, 0xd0, 0x9a, 0x2f, 0x68, 0x85,
		0x1e, 0x23, 0xe0, 0x2b, 0xe0, 0x2b, 0xe0, 0xab, 0xe2, 0x35, 0x8b, 0x43, 0xc0, 0x80, 0xb0, 0xfa,
		0xfc, 0x37, 0x20, 0x6c, 0x71, 0x20, 0x2c, 0xa8, 0x58, 0xa0, 0xda, 0x82, 0xa1, 0x5a, 0xe8, 0x31,
		0x02, 0xcb, 0x02, 0xcb, 0x02, 0xcb, 0x2a, 0x5a, 0xb3, 0xa0, 0x62, 0x81, 0x63, 0x9f, 0x4c, 0x1b,
		0xa8, 0xd8, 0xd2, 0xe1, 0x58, 0x50, 0xb1, 0x00, 0xad, 0xf9, 0x82, 0x56, 0xe8, 0x31, 0x02, 0xbe,
		0x02, 0xbe, 0x02, 0xbe, 0x2a, 0x5e, 0xb3, 0xa0, 0x62, 0x01, 0x61, 0xf5, 0xf9, 0x6f, 0x40, 0xd8,
		0xe2, 0x40, 0x58, 0x50, 0xb1, 0x40, 0xb5, 0x0a, 0x51, 0x2d, 0xf4, 0x18, 0x53, 0xea, 0x31, 0x2a,
		0x97, 0xfe, 0xab, 0xa4, 0x95, 0x65, 0x3c, 0x9f, 0x7e, 0xc1, 0x31, 0x23, 0xd1, 0xc9, 0xfc, 0xfd,
		0x06, 0x8a, 0x33, 0xfa, 0x13, 0x1e, 0x4c, 0xb8, 0x35, 0x0c, 0xe9, 0x7f, 0x27, 0xd4, 0xb3, 0x1f,
		0xd4, 0x49, 0x33, 0x6e, 0xb4, 0xac, 0x46, 0x98, 0xb1, 0x06, 0x61, 0xc6, 0x1c, 0xf3, 0x1d, 0x08,
		0x33, 0x16, 0xc8, 0x6b, 0x2b, 0xcb, 0x62, 0x96, 0xeb, 0x6f, 0x69, 0xac, 0x71, 0xfa, 0xa7, 0x62,
		0xfd, 0xa9, 0x4b, 0x5c, 0x56, 0x09, 0xcb, 0xc5, 0x6f, 0xff, 0xab, 0xe2, 0xd3, 0xd4, 0x26, 0x28,
		0x0a, 0x73, 0x49, 0x1d, 0x09, 0x89, 0x26, 0xd4, 0xaa, 0x2b, 0x01, 0xd1, 0x09, 0x49, 0x15, 0x26,
		0x1c, 0x5a, 0x12, 0x0d, 0xdd, 0x53, 0xa5, 0x3f, 0xb1, 0xd0, 0x3a, 0x7b, 0x05, 0x01, 0xec, 0x57,
		0xe6, 0x82, 0xbd, 0x99, 0x86, 0xb9, 0x6a, 0xa0, 0xa7, 0x42, 0x19, 0x1d, 0xea, 0xdb, 0x00, 0x79,
		0x00, 0x79, 0x8f, 0x7a, 0x06, 0xf5, 0xed, 0x7c, 0x5d, 0x80, 0x0e, 0x57, 0xf0, 0xac, 0x4b, 0xc0,
		0x4e, 0x97, 0x66, 0x27, 0xf1, 0xa2, 0xb3, 0xc0, 0x4e, 0x97, 0xc8, 0x9a, 0x45, 0xa1, 0x16, 0x76,
		0xb9, 0x9e, 0x4c, 0x1b, 0x0a, 0xb5, 0xb2, 0x48, 0x3a, 0xb5, 0x26, 0x9f, 0x4f, 0xa7, 0x14, 0x85,
		0x5a, 0x9a, 0x1d, 0xbd, 0xfa, 0xd6, 0xa0, 0xbe, 0x9d, 0x20, 0x7a, 0x41, 0x7d, 0x1b, 0xe0, 0x15,
		0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x55,
		0x3d, 0x78, 0x85, 0xfa, 0x36, 0xe0, 0x2b, 0xe0, 0x2b, 0xe0, 0xab, 0xea, 0x35, 0x0b, 0xf5, 0x6d,
		0x80, 0x58, 0x9d, 0x1e, 0x1c, 0x20, 0xb6, 0x38, 0x20, 0x16, 0xe7, 0x0c, 0x80, 0x6b, 0x8b, 0x85,
		0x6b, 0xa1, 0xbe, 0x0d, 0x34, 0x0b, 0x34, 0x0b, 0x34, 0xab, 0x6a, 0xcd, 0x82, 0x8c, 0x05, 0x8e,
		0x7d, 0x32, 0x6d, 0x20, 0x63, 0x4b, 0x87, 0x63, 0x41, 0xc6, 0x02, 0xb4, 0xe6, 0x0b, 0x5a, 0xa1,
		0xbe, 0x0d, 0xf8, 0x0a, 0xf8, 0x0a, 0xf8, 0xaa, 0x78, 0xcd, 0x42, 0xf2, 0x05, 0x10, 0x56, 0x9f,
		0xff, 0x06, 0x84, 0x2d, 0x0e, 0x84, 0x05, 0x15, 0x0b, 0x54, 0x5b, 0x30, 0x54, 0x0b, 0xf5, 0x6d,
		0x60, 0x59, 0x60, 0x59, 0x60, 0x59, 0x45, 0x6b, 0x16, 0x54, 0x2c, 0x70, 0xec, 0x93, 0x69, 0x03,
		0x15, 0x5b, 0x3a, 0x1c, 0x0b, 0x2a, 0x16, 0xa0, 0x35, 0x5f, 0xd0, 0x0a, 0xf5, 0x6d, 0xc0, 0x57,
		0xc0, 0x57, 0xc0, 0x57, 0xc5, 0x6b, 0x16, 0x54, 0x2c, 0x20, 0xac, 0x3e, 0xff, 0x0d, 0x08, 0x5b,
		0x1c, 0x08, 0x0b, 0x2a, 0x16, 0xa8, 0x56, 0x21, 0xaa, 0x85, 0xfa, 0x76, 0x4a, 0xf5, 0x6d, 0x85,
		0xa2, 0x7f, 0x95, 0xb4, 0xba, 0xdb, 0xdd, 0xf8, 0xdd, 0xbd, 0xf8, 0xd5, 0x06, 0xaa, 0x30, 0x72,
		0x12, 0x8e, 0x28, 0xb7, 0xf4, 0x88, 0x31, 0x3e, 0xd7, 0x38, 0x84, 0xb7, 0x13, 0x25, 0x3b, 0xd0,
		0x64, 0x84, 0x26, 0x63, 0xc6, 0x09, 0x8c, 0x16, 0xde, 0x5d, 0x25, 0xdf, 0xae, 0x85, 0x67, 0xdf,
		0x4e, 0xe5, 0xed, 0x06, 0x94, 0xb7, 0x4d, 0x51, 0xde, 0xde, 0xc1, 0x54, 0x41, 0x66, 0x5b, 0x02,
		0xe0, 0xfd, 0xb0, 0xe2, 0xcb, 0x69, 0x14, 0xa2, 0xba, 0x45, 0x8b, 0x80, 0x72, 0x80, 0x72, 0x80,
		0x72, 0x85, 0x86, 0x72, 0x37, 0xbe, 0xef, 0x52, 0xe2, 0xa9, 0x04, 0x72, 0xf5, 0xbc, 0x9c, 0xe0,
		0xbb, 0x0c, 0xa7, 0x44, 0x15, 0x0d, 0x92, 0x05, 0xfd, 0x21, 0xb6, 0xea, 0xd3, 0x0f, 0x67, 0xba,
		0x27, 0x52, 0x0e, 0xfc, 0xd4, 0x0f, 0xcd, 0xc4, 0x84, 0x1c, 0x9a, 0xd6, 0x05, 0x55, 0xcf, 0x59,
		0xc4, 0x9b, 0x9c, 0x8b, 0xc5, 0xb8, 0x29, 0xce, 0x6e, 0xb9, 0x74, 0xea, 0x51, 0x22, 0xb1, 0x28,
		0x32, 0x85, 0x7f, 0x6b, 0x2d, 0xa8, 0x61, 0x6b, 0xab, 0xdd, 0xd0, 0xa1, 0x21, 0x75, 0x8e, 0xa7,
		0xc3, 0xe2, 0x4d, 0x5c, 0x57, 0xeb, 0xe8, 0x4b, 0x2e, 0x77, 0xbd, 0xcb, 0x5c, 0xc0, 0x7b, 0xa5,
		0xa1, 0xf0, 0xd2, 0xd9, 0x4f, 0x72, 0x2b, 0x48, 0xf6, 0x37, 0x13, 0xce, 0x94, 0xe8, 0x0c, 0xe9,
		0x99, 0x99, 0x64, 0x43, 0xf6, 0xf6, 0x00, 0x24, 0xe8, 0x7c, 0x75, 0xe6, 0xe3, 0x92, 0xf6, 0xf9,
		0x91, 0x2a, 0x51, 0xd2, 0xd2, 0x8b, 0x94, 0x37, 0xbd, 0xac, 0x20, 0x67, 0xc2, 0x34, 0x5a, 0x04,
		0x5a, 0xca, 0x43, 0x48, 0x51, 0xa8, 0x28, 0x0d, 0x09, 0xa5, 0xa1, 0x9f, 0x12, 0x88, 0xa7, 0xd6,
		0xfc, 0xd2, 0xde, 0x7c, 0x52, 0xb5, 0x7d, 0xcf, 0xa3, 0x36, 0xf7, 0xc3, 0xd9, 0xed, 0x75, 0xa9,
		0x27, 0x61, 0x31, 0xfd, 0x4f, 0xda, 0x49, 0x1b, 0x55, 0x85, 0x72, 0x2c, 0xe1, 0x9c, 0x4a, 0x26,
		0x87, 0x52, 0x97, 0x33, 0xc9, 0xe6, 0x48, 0xca, 0x72, 0x22, 0x65, 0x39, 0x90, 0xd2, 0x9c, 0x47,
		0x2f, 0x8e, 0x13, 0xce, 0x61, 0x56, 0x7a, 0x92, 0x0e, 0xf5, 0x38, 0xe3, 0x0f, 0x21, 0x1d, 0x8a,
		0x4c, 0xfe, 0xc2, 0x97, 0x8b, 0x60, 0xae, 0xf6, 0xfc, 0xd5, 0xc7, 0x24, 0x92, 0x58, 0x3e, 0x8b,
		0x8e, 0x9c, 0xb5, 0x8f, 0x5b, 0x97, 0xd7, 0x27, 0xdd, 0x4e, 0xa7, 0x75, 0x32, 0xe8, 0x5e, 0x5e,
		0x0f, 0xfe, 0xea, 0xb5, 0x44, 0x57, 0x52, 0xcc, 0xda, 0x45, 0x52, 0x34, 0xb5, 0x22, 0xfa, 0xa7,
		0x7f, 0xb2, 0xea, 0x52, 0x35, 0x0f, 0x4a, 0x4b, 0x51, 0x3f, 0x9a, 0xdd, 0x92, 0x74, 0xe4, 0xbc,
		0x24, 0xfd, 0x38, 0x6d, 0x96, 0xa4, 0x23, 0x17, 0xbd, 0xae, 0x92, 0x8e, 0x08, 0x3d, 0x79, 0xa5,
		0x3b, 0x1e, 0xbc, 0xd3, 0x30, 0x11, 0x55, 0x87, 0x70, 0x6a, 0xd9, 0xbe, 0x23, 0x01, 0x94, 0x56,
		0x4d, 0x00, 0x23, 0x01, 0x23, 0x95, 0x1c, 0x23, 0xc5, 0x8b, 0x9d, 0x78, 0x8e, 0xe8, 0x01, 0x83,
		0x25, 0x4a, 0x12, 0x28, 0x23, 0xae, 0xf6, 0x08, 0xe7, 0x34, 0xf4, 0x84, 0xc1, 0x48, 0xf5, 0x3f,
		0x5f, 0x6b, 0xd6, 0xd1, 0xd5, 0xdf, 0xbb, 0x3f, 0xbf, 0x7d, 0xb3, 0x66, 0x3f, 0x36, 0xd6, 0x7f,
		0x1c, 0x2c, 0x7e, 0xf8, 0xb8, 0xf1, 0xc3, 0xbf, 0xbf, 0x7d, 0x7b, 0x1f, 0xff, 0xfc, 0x7f, 0x7e,
		0xf9, 0xff, 0xff, 0xdf, 0xaf, 0xff, 0xc7, 0xba, 0xda, 0xf8, 0x1b, 0xff, 0x4a, 0x3f, 0xd9, 0x57,
		0x22, 0x63, 0xd0, 0xed, 0xb7, 0xff, 0x2c, 0xdd, 0x40, 0x14, 0x20, 0x12, 0x50, 0x8f, 0xdc, 0xb8,
		0xd4, 0x11, 0x8f, 0x03, 0x8b, 0x06, 0x10, 0x05, 0x10, 0x05, 0x4a, 0x1e, 0x05, 0xc4, 0x77, 0xf7,
		0x04, 0x77, 0xf3, 0x34, 0x99, 0x3c, 0xbf, 0xa5, 0xa1, 0x47, 0xb9, 0x15, 0x8c, 0x65, 0xec, 0x7e,
		0xbd, 0x15, 0x18, 0x3f, 0x8c, 0x1f, 0x34, 0x99, 0x19, 0x34, 0x59, 0x6b, 0xf0, 0x5b, 0xeb, 0xb2,
		0xd3, 0x1a, 0x5c, 0xf7, 0x2e, 0x4e, 0x4b, 0xc2, 0x91, 0xb5, 0x06, 0xbf, 0x5d, 0xd7, 0x6b, 0xb5,
		0x4f, 0xc7, 0xcd, 0x7e, 0xeb, 0xfa, 0xe4, 0x8f, 0xd3, 0x8b, 0x5d, 0x93, 0xf9, 0x8c, 0x69, 0x6f,
		0x76, 0xe7, 0x9d, 0xe9, 0x5f, 0x96, 0xa6, 0x2b, 0x2d, 0xf3, 0xbb, 0x52, 0x5f, 0xce, 0x8a, 0xe9,
		0x3d, 0xf9, 0xdc, 0x39, 0x6d, 0x9d, 0xb5, 0x3b, 0xad, 0xd3, 0xb2, 0xac, 0xae, 0x93, 0xf2, 0x18,
		0x4a, 0xaf, 0x7f, 0x51, 0x02, 0x4b, 0xa9, 0x7d, 0xba, 0x6e, 0x9e, 0x9c, 0x18, 0x3f, 0x27, 0x7f,
		0x2e, 0x6c, 0xfe, 0xfc, 0xb2, 0x0c, 0x73, 0x32, 0xef, 0x4a, 0x69, 0x6c, 0xe5, 0xfc, 0x72, 0xb7,
		0x34, 0xd3, 0x52, 0x16, 0xbb, 0x9f, 0xf9, 0xe3, 0xf3, 0xf2, 0x84, 0xfb, 0x56, 0x79, 0x4c, 0xbf,
		0x55, 0x22, 0x7b, 0xe9, 0x97, 0x67, 0x85, 0x95, 0x28, 0xb8, 0xf4, 0x2f, 0xeb, 0xb5, 0x72, 0xa0,
		0x97, 0xee, 0x49, 0x59, 0x96, 0xd7, 0xff, 0x2d, 0xcf, 0xf2, 0x2a, 0x03, 0xce, 0xff, 0xb3, 0x3c,
		0x79, 0xe4, 0xca, 0x81, 0x5d, 0xa0, 0xf2, 0x22, 0xc9, 0xe0, 0xad, 0xd3, 0xe6, 0x56, 0x10, 0x52,
		0xdb, 0xf7, 0x86, 0x6a, 0x48, 0xf8, 0x65, 0x6b, 0x20, 0xe3, 0x13, 0xb4, 0x04, 0x32, 0x5e, 0xa1,
		0xa5, 0x80, 0x8c, 0x97, 0xf0, 0xa1, 0x20, 0xe3, 0x4d, 0x21, 0x1b, 0x40, 0xc6, 0x17, 0x11, 0x7a,
		0x80, 0x8c, 0x07, 0x19, 0xaf, 0xaf, 0x2b, 0x20, 0xe3, 0x2b, 0x20, 0xe3, 0x75, 0x46, 0x48, 0x90,
		0xf1, 0x85, 0x9c, 0x16, 0x90, 0xf1, 0x05, 0x0d, 0xf7, 0x20, 0xe3, 0x0b, 0xd9, 0x17, 0x90, 0xf1,
		0xc5, 0x9c, 0x15, 0x90, 0xf1, 0x20, 0xe3, 0xf5, 0xc5, 0x15, 0x90, 0xf1, 0xc5, 0x74, 0x60, 0x20,
		0xe3, 0x13, 0x0d, 0xde, 0x90, 0x4c, 0x5c, 0x6e, 0xd9, 0xbe, 0xe7, 0x30, 0x21, 0x2d, 0x9e, 0xe5,
		0xe8, 0x3f, 0x6d, 0x08, 0x14, 0x7c, 0x82, 0x96, 0x40, 0xc1, 0x2b, 0xb4, 0x0f, 0x1c, 0x86, 0x11,
		0x74, 0x01, 0xd4, 0xb6, 0x6c, 0x3f, 0x0c, 0xa9, 0xcd, 0xa9, 0x63, 0xdd, 0xcc, 0xa4, 0x54, 0x45,
		0xbd, 0xc0, 0x66, 0x5b, 0x70, 0x04, 0x70, 0x04, 0x25, 0x77, 0x04, 0xb6, 0x3f, 0xf1, 0x38, 0x0d,
		0x85, 0xe4, 0xcb, 0x25, 0x6e, 0x57, 0x92, 0x14, 0x12, 0x97, 0xd0, 0x98, 0x54, 0x21, 0x14, 0xae,
		0x4a, 0x8d, 0x57, 0x91, 0xba, 0xb4, 0x4a, 0x35, 0x69, 0x19, 0xf5, 0x64, 0x15, 0xc2, 0xde, 0xaa,
		0x87, 0x56, 0xfd, 0x6d, 0x40, 0x4a, 0x47, 0x3b, 0x23, 0x35, 0xd2, 0xab, 0xe2, 0xc5, 0xea, 0x07,
		0x4e, 0xd5, 0x05, 0xeb, 0xb8, 0x31, 0x44, 0x6b, 0x44, 0x6b, 0x44, 0x6b, 0x44, 0x6b, 0x44, 0x6b,
		0x44, 0x6b, 0x44, 0x6b, 0x05, 0xd1, 0x7a, 0x2c, 0x25, 0x31, 0xb6, 0x6c, 0x01, 0x71, 0x19, 0x71,
		0x19, 0x15, 0xad, 0x49, 0x28, 0xb5, 0x02, 0xa8, 0xb0, 0xb6, 0x4e, 0xae, 0x2f, 0xba, 0xa7, 0xad,
		0x92, 0x54, 0xb3, 0x4e, 0xbb, 0x73, 0xda, 0xee, 0x37, 0x8f, 0xcf, 0xcd, 0x2e, 0xcf, 0x9b, 0xf6,
		0xa3, 0xd5, 0x29, 0x45, 0x37, 0x9a, 0x9f, 0x07, 0x5d, 0xec, 0x6f, 0x25, 0x0d, 0xc1, 0x11, 0x27,
		0x7c, 0x22, 0x99, 0x27, 0xcf, 0xdb, 0x40, 0x18, 0x46, 0x18, 0x46, 0x18, 0x36, 0x27, 0x0c, 0xf7,
		0x07, 0xcd, 0xc1, 0xe7, 0x7e, 0x89, 0x02, 0xf1, 0xbc, 0x43, 0x9f, 0x3b, 0xe7, 0xdd, 0x93, 0xdf,
		0xcd, 0x0f, 0x64, 0xf3, 0xee, 0x48, 0x77, 0x66, 0xcb, 0x22, 0xda, 0xc4, 0x9b, 0xf3, 0xb6, 0xe4,
		0xc6, 0xa5, 0xd6, 0x8d, 0xeb, 0xdb, 0xdf, 0x25, 0xe3, 0xdb, 0xb3, 0x2d, 0x22, 0xda, 0x21, 0xda,
		0x81, 0x0c, 0x7e, 0x73, 0xc1, 0x83, 0x0c, 0x96, 0x64, 0x2c, 0x41, 0x06, 0x6b, 0x1b, 0x5a, 0x90,
		0xc1, 0x95, 0x02, 0x91, 0xc1, 0x8f, 0xa3, 0xec, 0xd4, 0xed, 0x2b, 0x0d, 0xdb, 0xb3, 0x06, 0x11,
		0xb5, 0x11, 0xb5, 0x11, 0xb5, 0x11, 0xb5, 0x11, 0xb5, 0x11, 0xb5, 0x11, 0xb5, 0x65, 0xa3, 0xb6,
		0x1f, 0x8e, 0xad, 0x21, 0xb1, 0xb9, 0x1f, 0x4a, 0x44, 0xea, 0xb5, 0x46, 0x10, 0x9d, 0x11, 0x9d,
		0xc1, 0x20, 0x27, 0x58, 0xf2, 0x05, 0x60, 0x90, 0x07, 0x97, 0xcd, 0x4e, 0xff, 0xa4, 0xd5, 0xfe,
		0xd2, 0xba, 0xbc, 0x3e, 0xeb, 0x5e, 0x5e, 0x5c, 0x9f, 0x35, 0x4b, 0x74, 0xad, 0xe6, 0xff, 0xf4,
		0xcf, 0x7a, 0x8d, 0x43, 0x93, 0x19, 0xe4, 0x3f, 0xcf, 0x7a, 0x26, 0x7f, 0xfe, 0x49, 0xaf, 0xf9,
		0xbb, 0xc9, 0xdf, 0xdf, 0x37, 0x7b, 0xf8, 0xff, 0xa7, 0x04, 0xdf, 0x7f, 0xdd, 0x3b, 0xff, 0xdc,
		0x37, 0xda, 0x06, 0xce, 0x7a, 0xbb, 0x86, 0xdb, 0x80, 0xf1, 0x73, 0xd0, 0xe9, 0x76, 0xa6, 0x7d,
		0xf8, 0xf4, 0xa9, 0x79, 0x7c, 0xde, 0x32, 0x3a, 0x1e, 0x34, 0x0c, 0x37, 0x05, 0xc3, 0x3f, 0xdf,
		0xf4, 0xe1, 0x6f, 0x5c, 0x37, 0x4f, 0xba, 0x26, 0xf7, 0xa1, 0x3b, 0xf8, 0xad, 0x85, 0xfb, 0x9f,
		0xd3, 0x26, 0xf6, 0xf2, 0x22, 0xc4, 0xcf, 0x35, 0x86, 0x44, 0x1f, 0x89, 0x3e, 0x12, 0x7d, 0x24,
		0xfa, 0x48, 0xf4, 0x91, 0xe8, 0x23, 0xd1, 0x47, 0xa2, 0x8f, 0x44, 0x1f, 0x89, 0x3e, 0x12, 0x7d,
		0x24, 0xfa, 0x48, 0xf4, 0x91, 0xe8, 0x23, 0xd1, 0xcf, 0x2e, 0xd1, 0x67, 0x5e, 0x30, 0xe1, 0x56,
		0xe0, 0xdf, 0x53, 0x89, 0x1d, 0xfc, 0xf5, 0x46, 0xc4, 0x12, 0xfb, 0x3a, 0x12, 0x7b, 0x24, 0xf6,
		0xd9, 0x24, 0xf6, 0xa7, 0x2c, 0x14, 0x9b, 0x7e, 0x72, 0x37, 0x92, 0xcf, 0xa5, 0xa7, 0x8d, 0x08,
		0x0e, 0xb1, 0x5c, 0x15, 0x95, 0xb0, 0xc9, 0xa8, 0x30, 0x9d, 0x67, 0x4d, 0xe8, 0x21, 0x48, 0xad,
		0xa8, 0xa4, 0xd2, 0x88, 0x94, 0x1b, 0x93, 0x72, 0xa3, 0x7a, 0xd1, 0xb8, 0xe2, 0x91, 0xcb, 0xba,
		0x40, 0x4d, 0x70, 0xd5, 0x08, 0xf3, 0x68, 0x1b, 0x6b, 0xc6, 0xa1, 0x36, 0x1b, 0x13, 0x57, 0xa8,
		0xac, 0x75, 0x23, 0xde, 0x34, 0x24, 0xda, 0xd8, 0x28, 0x16, 0x94, 0x69, 0x4c, 0xae, 0x68, 0x56,
		0x0d, 0x70, 0xaa, 0xa8, 0x2a, 0xa2, 0x7d, 0x3a, 0xcc, 0x8d, 0x5f, 0xd5, 0x34, 0xa7, 0xa8, 0xa8,
		0xf6, 0xe5, 0x19, 0xac, 0x49, 0xb7, 0xfb, 0xf3, 0x57, 0x05, 0x53, 0xa0, 0xa0, 0xd8, 0xf6, 0xe9,
		0x14, 0xec, 0x6c, 0xd1, 0x14, 0xbc, 0xcb, 0xe7, 0xe9, 0xab, 0x8c, 0x2a, 0x7e, 0x05, 0x96, 0x58,
		0x95, 0x79, 0x11, 0x27, 0x71, 0xe4, 0x90, 0x04, 0x2e, 0x8b, 0x86, 0x00, 0x5e, 0x00, 0x5e, 0x00,
		0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0xf4, 0x82, 0x17, 0x4e, 0xc3,
		0x3b, 0xe2, 0xaa, 0x40, 0x2f, 0xf3, 0x96, 0x00, 0x5f, 0x00, 0x5f, 0x00, 0x5f, 0x52, 0xaf, 0x99,
		0x88, 0x13, 0x6e, 0x49, 0x1a, 0x51, 0x45, 0xee, 0x78, 0xf1, 0xb2, 0x89, 0xcf, 0xde, 0xcc, 0xe7,
		0x56, 0x3d, 0xe2, 0xf9, 0x11, 0xb5, 0x7d, 0xcf, 0x91, 0x5a, 0xcb, 0xa5, 0x06, 0x31, 0x35, 0x80,
		0x98, 0xbc, 0x41, 0x8c, 0xea, 0x29, 0x50, 0x7f, 0xfc, 0x19, 0xb8, 0x26, 0x5b, 0x5c, 0x33, 0x96,
		0x58, 0x65, 0x4b, 0x97, 0x3c, 0x6d, 0x04, 0x68, 0x06, 0x68, 0x06, 0x68, 0x06, 0x64, 0x0c, 0xc8,
		0x18, 0xe0, 0x18, 0x90, 0x31, 0x00, 0x2d, 0x9a, 0x41, 0x8b, 0xc5, 0xd9, 0x98, 0x2a, 0x41, 0x2e,
		0xb3, 0x96, 0x00, 0x5f, 0x00, 0x5f, 0x00, 0x5f, 0x52, 0xaf, 0x99, 0xa9, 0xed, 0x70, 0x66, 0x7f,
		0x8f, 0x94, 0x00, 0x18, 0x50, 0x31, 0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0xd9, 0x52, 0x54, 0x23,
		0x61, 0xe8, 0x2b, 0x40, 0xc3, 0x3c, 0x60, 0x19, 0x60, 0x19, 0x60, 0x19, 0x50, 0x31, 0xa0, 0x62,
		0x80, 0x63, 0x40, 0xc5, 0x00, 0xb4, 0xe8, 0x06, 0x2d, 0xaa, 0xa8, 0x98, 0x45, 0x4b, 0x80, 0x2f,
		0x80, 0x2f, 0x80, 0x2f, 0xa0, 0x62, 0x40, 0xc5, 0x00, 0xc2, 0x80, 0x8a, 0x01, 0xaa, 0x91, 0x45,
		0x35, 0x5a, 0x8f, 0x70, 0x37, 0x3d, 0xcf, 0xe7, 0x64, 0x3a, 0x25, 0x62, 0x27, 0xb9, 0x23, 0xfb,
		0x96, 0x8e, 0x49, 0x40, 0xf8, 0xed, 0xd4, 0x61, 0x7e, 0xf0, 0x03, 0xea, 0xd9, 0x31, 0x12, 0xb1,
		0x02, 0x97, 0xf0, 0xa1, 0x1f, 0x8e, 0x3f, 0xd8, 0xfe, 0x38, 0xf0, 0x3d, 0xea, 0xf1, 0x68, 0xf5,
		0xe3, 0x87, 0xb5, 0x53, 0xed, 0x1f, 0x22, 0x4e, 0x38, 0xfd, 0x20, 0xae, 0x7c, 0x30, 0xfb, 0x10,
		0x1e, 0x4e, 0x6c, 0xee, 0x2d, 0xa4, 0x37, 0x16, 0x2f, 0xba, 0x1e, 0xac, 0x5e, 0x74, 0xdd, 0x9e,
		0xbe, 0xa2, 0x17, 0xbf, 0xa1, 0x00, 0x7a, 0x11, 0x2e, 0x89, 0x68, 0x68, 0xdd, 0x30, 0x12, 0x59,
		0xf6, 0x24, 0x0c, 0xa9, 0xc0, 0xd1, 0xb2, 0x65, 0xf0, 0x7c, 0xa6, 0x2d, 0xa8, 0x47, 0xe8, 0x07,
		0x99, 0x50, 0x8f, 0x90, 0x70, 0x3d, 0x50, 0x8f, 0x40, 0xa6, 0x86, 0x4c, 0xcd, 0xc0, 0x4c, 0x0d,
		0x44, 0xb3, 0x71, 0x59, 0x1a, 0x88, 0xe6, 0xdc, 0xb3, 0x34, 0x10, 0xcd, 0xe5, 0x49, 0xc9, 0xa0,
		0x1e, 0x01, 0xf0, 0x02, 0xf0, 0x02, 0xf0, 0x02, 0xf0, 0x02, 0xf0, 0x02, 0xf0, 0x02, 0xf0, 0x52,
		0x7e, 0xf0, 0x02, 0xf5, 0x08, 0xc0, 0x17, 0xc0, 0x17, 0xa8, 0x47, 0xac, 0x37, 0x81, 0x7d, 0x72,
		0xfd, 0x1e, 0x0b, 0x20, 0xa6, 0xb8, 0x53, 0x80, 0x7d, 0x72, 0xd3, 0x71, 0x0d, 0xd4, 0x23, 0x80,
		0x66, 0x80, 0x66, 0x40, 0xc6, 0x80, 0x8c, 0x01, 0x19, 0x03, 0x32, 0x06, 0xa0, 0xc5, 0x14, 0xd0,
		0x02, 0xf5, 0x08, 0xc0, 0x17, 0xc0, 0x17, 0x1c, 0x59, 0x00, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c,
		0xa8, 0x98, 0x32, 0xa0, 0x1a, 0xa8, 0x47, 0x00, 0xcb, 0x00, 0xcb, 0x80, 0x8a, 0x01, 0x15, 0x03,
		0x2a, 0x06, 0x54, 0x0c, 0x40, 0x8b, 0x21, 0xa0, 0x05, 0xea, 0x11, 0x80, 0x2f, 0x80, 0x2f, 0xa0,
		0x62, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0xa6, 0x68, 0xa8, 0x66, 0x4b, 0xd4, 0x23,
		0xa4, 0x05, 0x10, 0x2a, 0x49, 0x45, 0x24, 0xce, 0xa7, 0x6f, 0x3a, 0x66, 0x24, 0x3a, 0x99, 0xbf,
		0xa7, 0x00, 0x52, 0x12, 0x3e, 0xf7, 0xac, 0xe9, 0xe8, 0xb8, 0x8c, 0x78, 0x36, 0xb5, 0x6c, 0xdf,
		0xa1, 0xe2, 0x5a, 0x12, 0xcf, 0x35, 0x26, 0x26, 0x26, 0x51, 0x83, 0x98, 0x44, 0x1e, 0x58, 0x73,
		0x1b, 0xc5, 0x24, 0x84, 0x91, 0xe4, 0xea, 0x64, 0x82, 0x43, 0x3d, 0xce, 0xf8, 0x43, 0x48, 0x87,
		0x22, 0x93, 0xbf, 0xa0, 0xbe, 0x04, 0x62, 0x5d, 0xb5, 0x3d, 0x7f, 0xf5, 0x31, 0x89, 0x14, 0xa4,
		0x92, 0xdd, 0x41, 0xe7, 0xba, 0xd9, 0xeb, 0x9d, 0xb7, 0x4f, 0x9a, 0x83, 0x76, 0xb7, 0x73, 0x7d,
		0xd2, 0x3d, 0x6d, 0x89, 0xae, 0xa4, 0x38, 0xa8, 0x47, 0x52, 0xe8, 0x53, 0x32, 0x01, 0x5b, 0xf4,
		0xaa, 0x57, 0x3f, 0xaf, 0x5f, 0x37, 0x4e, 0xeb, 0x12, 0xa9, 0xcd, 0xaf, 0x79, 0xf7, 0x61, 0x3a,
		0x33, 0x9f, 0x3b, 0xa7, 0xad, 0xb3, 0x76, 0xa7, 0x75, 0x6a, 0x72, 0x47, 0xe6, 0x93, 0xd1, 0x30,
		0xbb, 0x0f, 0x7d, 0xd9, 0x3e, 0xbc, 0xcb, 0x06, 0xf9, 0xfd, 0x2c, 0x02, 0xc2, 0x98, 0xf0, 0x95,
		0x3c, 0x97, 0x38, 0xb4, 0x58, 0x6f, 0x05, 0x02, 0x55, 0xc0, 0x14, 0x10, 0xa8, 0x7a, 0x71, 0xed,
		0x40, 0xa0, 0x0a, 0x64, 0xb0, 0xb4, 0x71, 0x61, 0x2f, 0x5b, 0x96, 0x1e, 0xc3, 0x5e, 0xf6, 0x26,
		0x0b, 0x89, 0xbd, 0x6c, 0x29, 0xd2, 0x10, 0x7b, 0xd9, 0xb9, 0x4f, 0x01, 0xf6, 0xb2, 0x37, 0x86,
		0x19, 0x02, 0x55, 0x00, 0x2f, 0x00, 0x2f, 0x00, 0x2f, 0x00, 0x2f, 0x00, 0x2f, 0x00, 0x2f, 0x00,
		0x2f, 0x86, 0x81, 0x17, 0x08, 0x54, 0x01, 0xbe, 0x00, 0xbe, 0x40, 0xa0, 0x6a, 0xbd, 0x09, 0x94,
		0xe2, 0xe9, 0xf7, 0x58, 0x00, 0x31, 0xc5, 0x9d, 0x02, 0x94, 0xe2, 0x99, 0x8e, 0x6b, 0x20, 0x50,
		0x05, 0x34, 0x03, 0x34, 0x03, 0x32, 0x06, 0x64, 0x0c, 0xc8, 0x18, 0x90, 0x31, 0x00, 0x2d, 0xa6,
		0x80, 0x16, 0x08, 0x54, 0x01, 0xbe, 0x00, 0xbe, 0xe0, 0x54, 0x24, 0xa8, 0x18, 0x50, 0x31, 0xa0,
		0x62, 0x40, 0xc5, 0x94, 0x01, 0xd5, 0x40, 0xa0, 0x0a, 0x58, 0x06, 0x58, 0x06, 0x54, 0x0c, 0xa8,
		0x18, 0x50, 0x31, 0xa0, 0x62, 0x00, 0x5a, 0x0c, 0x01, 0x2d, 0x10, 0xa8, 0x02, 0x7c, 0x01, 0x7c,
		0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x45, 0x43, 0x35, 0x5b, 0x22,
		0x50, 0x25, 0x21, 0x7d, 0x50, 0x49, 0x2a, 0x4d, 0xd5, 0x8d, 0xdf, 0xd1, 0x8b, 0x5f, 0x51, 0x00,
		0xcd, 0x88, 0xc0, 0x8f, 0xb8, 0x35, 0xa4, 0xb6, 0x75, 0x23, 0xa3, 0x19, 0xf1, 0xa8, 0x15, 0x68,
		0x46, 0xe8, 0x87, 0x96, 0xd0, 0x8c, 0x90, 0x70, 0x38, 0xd0, 0x8c, 0x28, 0x46, 0x7e, 0xe6, 0x07,
		0x1c, 0x39, 0x9a, 0xb0, 0x81, 0xad, 0x46, 0x0f, 0x34, 0xb3, 0x84, 0x31, 0xa9, 0xa5, 0x99, 0xeb,
		0x87, 0x48, 0xd2, 0x9e, 0x1f, 0x67, 0xf0, 0xcc, 0xb9, 0x27, 0x69, 0xe0, 0x99, 0xcb, 0x93, 0x91,
		0x41, 0x3c, 0x02, 0x28, 0x06, 0x28, 0x06, 0x28, 0x06, 0x28, 0x06, 0x28, 0x06, 0x28, 0x06, 0x28,
		0x66, 0x8b, 0x50, 0x0c, 0x54, 0x24, 0xb4, 0xe0, 0x18, 0x60, 0x18, 0x51, 0x0c, 0x03, 0x15, 0x09,
		0xa8, 0x48, 0x98, 0x04, 0x62, 0xb0, 0x5f, 0x9e, 0x3b, 0x88, 0xc1, 0x7e, 0x39, 0x70, 0xcd, 0xe3,
		0x61, 0x86, 0x8a, 0x04, 0x58, 0x19, 0xb0, 0x32, 0x60, 0x65, 0xc0, 0xca, 0x80, 0x95, 0x01, 0x2b,
		0x03, 0x56, 0xc6, 0x38, 0xf4, 0x02, 0x39, 0x09, 0xb0, 0x32, 0x60, 0x65, 0x70, 0x86, 0x01, 0x9c,
		0x0c, 0x38, 0x19, 0x70, 0x32, 0xe0, 0x64, 0xca, 0x80, 0x6a, 0x20, 0x27, 0x01, 0x4e, 0x06, 0x9c,
		0x0c, 0x38, 0x19, 0x70, 0x32, 0xe0, 0x64, 0xc0, 0xc9, 0x80, 0x93, 0x31, 0x0d, 0xbd, 0x40, 0x57,
		0x02, 0x9c, 0x0c, 0x38, 0x19, 0x70, 0x32, 0xe0, 0x64, 0xc0, 0xc9, 0x80, 0x93, 0x01, 0x27, 0x53,
		0x34, 0x54, 0xb3, 0x25, 0xba, 0x12, 0x12, 0xf2, 0x08, 0x95, 0xa4, 0xba, 0x12, 0x3d, 0x3f, 0xe2,
		0x67, 0xd4, 0x3e, 0x2e, 0x88, 0xac, 0x44, 0x48, 0x15, 0xa8, 0x4a, 0xac, 0x35, 0x02, 0x51, 0x09,
		0xfd, 0xb8, 0x12, 0xa2, 0x12, 0x12, 0xde, 0x06, 0xa2, 0x12, 0x20, 0x99, 0xcd, 0x4f, 0xd0, 0x40,
		0x32, 0x83, 0x64, 0x36, 0x28, 0x43, 0x03, 0xc9, 0x9c, 0x7b, 0x86, 0x06, 0x92, 0xb9, 0x3c, 0xe9,
		0x18, 0x44, 0x25, 0x80, 0x62, 0x80, 0x62, 0x80, 0x62, 0x80, 0x62, 0x80, 0x62, 0x80, 0x62, 0x80,
		0x62, 0xb6, 0x08, 0xc5, 0x40, 0x54, 0x42, 0x0b, 0x8e, 0x01, 0x86, 0x11, 0xc5, 0x30, 0x10, 0x95,
		0x80, 0xa8, 0x84, 0x49, 0x20, 0x06, 0x9b, 0xe5, 0xb9, 0x83, 0x18, 0x6c, 0x96, 0x03, 0xd7, 0x3c,
		0x1e, 0x66, 0x88, 0x4a, 0x80, 0x95, 0x01, 0x2b, 0x03, 0x56, 0x06, 0xac, 0x0c, 0x58, 0x19, 0xb0,
		0x32, 0x60, 0x65, 0x8c, 0x43, 0x2f, 0x10, 0x95, 0x00, 0x2b, 0x03, 0x56, 0x06, 0x07, 0x18, 0xc0,
		0xc9, 0x80, 0x93, 0x01, 0x27, 0x03, 0x4e, 0xa6, 0x0c, 0xa8, 0x06, 0xa2, 0x12, 0xe0, 0x64, 0xc0,
		0xc9, 0x80, 0x93, 0x01, 0x27, 0x03, 0x4e, 0x06, 0x9c, 0x0c, 0x38, 0x19, 0xd3, 0xd0, 0x0b, 0x44,
		0x25, 0xc0, 0xc9, 0x80, 0x93, 0x01, 0x27, 0x03, 0x4e, 0x06, 0x9c, 0x0c, 0x38, 0x19, 0x70, 0x32,
		0x45, 0x43, 0x35, 0xdb, 0x22, 0x2a, 0x21, 0xac, 0x8e, 0x50, 0x49, 0xac, 0x29, 0x11, 0xd2, 0x42,
		0x49, 0x4a, 0x44, 0x54, 0xe0, 0xa4, 0xd9, 0xba, 0x9c, 0x44, 0xdc, 0x80, 0x98, 0x94, 0x44, 0x0d,
		0x52, 0x12, 0x79, 0xa0, 0xc8, 0x6d, 0x94, 0x92, 0x10, 0xc6, 0x88, 0xcb, 0xf9, 0xa7, 0xde, 0x64,
		0x4c, 0xc3, 0x99, 0x9b, 0x12, 0x98, 0xfc, 0x05, 0xab, 0xb5, 0x2b, 0xf0, 0x6c, 0xcb, 0x9b, 0x8c,
		0xa7, 0x1f, 0xff, 0xb3, 0x00, 0x2e, 0x23, 0xa2, 0x21, 0x23, 0xae, 0xe5, 0xf9, 0xe2, 0x4e, 0x63,
		0xd5, 0x04, 0xdc, 0x06, 0xdc, 0x46, 0xc9, 0xdd, 0x46, 0xc4, 0x43, 0xe6, 0x8d, 0x64, 0x3c, 0x86,
		0x40, 0x1a, 0x59, 0x3d, 0xa7, 0xde, 0x28, 0x86, 0x43, 0x62, 0xf9, 0x9e, 0x44, 0x2a, 0xad, 0x22,
		0xbf, 0x53, 0x94, 0x54, 0xac, 0x92, 0x09, 0xc9, 0x76, 0x14, 0x66, 0x0c, 0x12, 0xf9, 0x9b, 0x92,
		0xbc, 0x4d, 0xf9, 0xd0, 0xee, 0x17, 0x68, 0x6c, 0x33, 0xca, 0x86, 0xae, 0x8a, 0x10, 0x86, 0x7d,
		0x8f, 0x72, 0x2b, 0x72, 0x6e, 0xad, 0x69, 0x3e, 0xe3, 0x32, 0xe2, 0xd9, 0xd4, 0xb2, 0x7d, 0x87,
		0x4a, 0x84, 0xe5, 0x17, 0x9b, 0x44, 0x98, 0x46, 0x98, 0x2e, 0x79, 0x98, 0x66, 0x0e, 0xf5, 0x38,
		0xe3, 0x0f, 0x21, 0x1d, 0xca, 0xc4, 0x6a, 0x01, 0x8e, 0xaa, 0xda, 0x9e, 0xbf, 0xfa, 0x98, 0x44,
		0x0a, 0xb6, 0x80, 0xfa, 0xdd, 0x4e, 0x6b, 0x70, 0xdd, 0xec, 0xf5, 0xce, 0xdb, 0x27, 0xcd, 0x41,
		0xbb, 0xdb, 0xb9, 0x3e, 0xe9, 0x9e, 0xb6, 0x44, 0xd7, 0x52, 0xec, 0xe6, 0x23, 0x29, 0xde, 0x58,
		0x32, 0x5e, 0x2d, 0xfa, 0xf5, 0xa5, 0x7f, 0xd9, 0xa8, 0xd5, 0x6a, 0xd7, 0x3b, 0x97, 0x3b, 0xd5,
		0x3c, 0xa2, 0xaf, 0xf2, 0x6e, 0x34, 0x4c, 0xee, 0xc6, 0x6c, 0x95, 0x7d, 0xee, 0x9c, 0xb6, 0xce,
		0xda, 0x9d, 0xd6, 0x69, 0x39, 0x66, 0x64, 0x2f, 0xeb, 0x0d, 0xaf, 0x2b, 0xdd, 0x6e, 0x54, 0x0b,
		0xf4, 0xb8, 0xa3, 0x9e, 0xe3, 0x4b, 0x48, 0xd0, 0xce, 0x9f, 0x07, 0xa8, 0x00, 0xa8, 0x40, 0xee,
		0x8f, 0xdc, 0x1f, 0xb9, 0x3f, 0x72, 0x7f, 0xe4, 0xfe, 0xe9, 0x03, 0xb0, 0x15, 0x90, 0x90, 0xcb,
		0x46, 0xe1, 0x59, 0x23, 0x08, 0xc5, 0x08, 0xc5, 0x08, 0xc5, 0x08, 0xc5, 0x08, 0xc5, 0x08, 0xc5,
		0x08, 0xc5, 0x02, 0xa1, 0x38, 0xa4, 0x77, 0xd2, 0x91, 0x78, 0xda, 0x06, 0x02, 0x31, 0x02, 0x31,
		0x02, 0x31, 0x02, 0x31, 0x02, 0xb1, 0xa9, 0x81, 0xb8, 0x81, 0x38, 0xac, 0x2c, 0x0e, 0xbf, 0x53,
		0xb8, 0x80, 0x44, 0x8b, 0x8c, 0xd5, 0x15, 0x17, 0x27, 0x73, 0xe5, 0x6f, 0x77, 0xfa, 0xf5, 0xbf,
		0xf1, 0xc6, 0x70, 0xa4, 0x1d, 0x06, 0x15, 0xdd, 0x4f, 0xe0, 0xeb, 0x93, 0x54, 0x4e, 0xbf, 0x3e,
		0x7e, 0x2f, 0x8f, 0xca, 0xf3, 0xff, 0xe5, 0x85, 0x71, 0x9a, 0x82, 0x83, 0xd9, 0xa9, 0x9b, 0x17,
		0x0f, 0xd1, 0x55, 0xcf, 0x59, 0xc4, 0x9b, 0x9c, 0xbf, 0xbe, 0x03, 0x32, 0xf5, 0xfb, 0x2d, 0x97,
		0x4e, 0xa3, 0x7a, 0xf4, 0xba, 0x7b, 0x99, 0xba, 0xb1, 0xb5, 0xbf, 0x99, 0xee, 0xe0, 0x43, 0xb5,
		0x1b, 0x3a, 0x34, 0xa4, 0xce, 0xf1, 0xf4, 0xab, 0xbd, 0x89, 0xeb, 0xa6, 0xea, 0x6c, 0x73, 0x32,
		0x9a, 0xbe, 0x96, 0x3a, 0xaf, 0x06, 0xc6, 0xd7, 0x57, 0xc9, 0x32, 0xb0, 0x7f, 0xf0, 0xed, 0xe5,
		0x9a, 0xf8, 0xb8, 0xb6, 0x26, 0x9e, 0xfd, 0xf5, 0x1b, 0x6b, 0xa2, 0x7a, 0x4a, 0x23, 0x3b, 0x64,
		0xc1, 0x7c, 0x9d, 0x56, 0x9b, 0x8e, 0xc3, 0xbc, 0x51, 0x65, 0x6d, 0x51, 0x55, 0x1c, 0xc2, 0x49,
		0x85, 0xfb, 0x95, 0xe0, 0xf6, 0x21, 0x62, 0x36, 0x71, 0x2b, 0xcc, 0xbb, 0xa3, 0x1e, 0xf7, 0xc3,
		0x87, 0xf7, 0x95, 0xc1, 0x2d, 0x8b, 0x2a, 0xd1, 0xe4, 0x86, 0x87, 0x94, 0x56, 0x58, 0xf4, 0xcd,
		0xf3, 0x3d, 0xf7, 0xa1, 0x72, 0x47, 0x5c, 0xe6, 0x54, 0xee, 0x6f, 0xa9, 0x57, 0xe1, 0xb7, 0xb4,
		0xc2, 0x1f, 0x02, 0x5a, 0xf1, 0x87, 0xf1, 0xcf, 0xcb, 0xef, 0xaa, 0xb0, 0xa8, 0x32, 0xb8, 0x6c,
		0x76, 0xfa, 0x27, 0xad, 0xf6, 0x97, 0xd6, 0xe5, 0xfb, 0xb7, 0xbe, 0x33, 0xd9, 0x9d, 0x88, 0x89,
		0x11, 0x77, 0x1a, 0x84, 0x2d, 0x8e, 0xa8, 0xd3, 0x22, 0x68, 0x61, 0xc4, 0x2c, 0x8c, 0x90, 0xa5,
		0x10, 0xb1, 0x9c, 0x83, 0x4c, 0x7a, 0xe7, 0x60, 0x75, 0xfd, 0x9b, 0x12, 0x8f, 0xe4, 0xf2, 0xa0,
		0x61, 0xea, 0x14, 0xe8, 0xa9, 0x49, 0x0c, 0xfc, 0xc0, 0x72, 0xe9, 0x1d, 0x75, 0x2b, 0xb6, 0xef,
		0x71, 0xc2, 0x3c, 0x1a, 0x56, 0x86, 0x7e, 0x58, 0xb1, 0x5d, 0x36, 0x5d, 0xc7, 0x81, 0x1f, 0xf2,
		0x0d, 0x7b, 0x49, 0xfa, 0xaa, 0x74, 0x37, 0x7d, 0xa6, 0xce, 0x27, 0x45, 0xf2, 0x48, 0xf9, 0xfc,
		0x51, 0x34, 0x6f, 0x94, 0xce, 0x17, 0xa5, 0xf3, 0x44, 0x25, 0xf9, 0xe1, 0xcf, 0x6c, 0xe0, 0xc7,
		0x3b, 0x01, 0xbb, 0x2b, 0x4e, 0x80, 0xf1, 0x03, 0x1e, 0xc7, 0x12, 0xfb, 0x96, 0x78, 0x1e, 0x75,
		0xdf, 0x0c, 0x32, 0xdf, 0x3c, 0x32, 0x0b, 0xa1, 0x31, 0xa2, 0x9a, 0x06, 0x8f, 0xc4, 0x91, 0xe6,
		0x9b, 0xc7, 0xa2, 0x4a, 0xb7, 0x37, 0x68, 0x9f, 0x34, 0xcf, 0xaf, 0x4f, 0x7e, 0x6b, 0x76, 0x3a,
		0xad, 0x73, 0x53, 0xc2, 0x4d, 0xac, 0x70, 0x43, 0xc3, 0x71, 0x29, 0x63, 0xcd, 0xb2, 0x73, 0x45,
		0x09, 0x34, 0xf3, 0x45, 0x69, 0xcd, 0x17, 0x65, 0xfa, 0x60, 0xf3, 0xb4, 0x01, 0xb1, 0x80, 0xd3,
		0xf2, 0x6c, 0xd7, 0x8f, 0xa6, 0x56, 0xf2, 0x38, 0xe0, 0x4c, 0x57, 0xb5, 0xcb, 0x22, 0x3e, 0x5d,
		0xe1, 0x4f, 0xec, 0x27, 0x2a, 0x49, 0xc0, 0x49, 0xb1, 0xde, 0xcb, 0x17, 0x6d, 0x92, 0xdb, 0x43,
		0x61, 0x42, 0xcd, 0xb3, 0xff, 0xe5, 0xea, 0xa5, 0x24, 0x28, 0x59, 0x46, 0x2c, 0x9a, 0x09, 0xbf,
		0x32, 0x7d, 0x2f, 0x65, 0xbd, 0xcf, 0x8f, 0xf4, 0x66, 0xaf, 0x1e, 0xff, 0xe6, 0x89, 0xbf, 0x79,
		0xab, 0x5f, 0xe9, 0xfa, 0xf3, 0xf8, 0x93, 0x56, 0x2f, 0x5e, 0x7b, 0xe9, 0xec, 0x9a, 0xa6, 0x21,
		0xb1, 0xe3, 0x7a, 0xe1, 0xc7, 0x2f, 0x7c, 0x7c, 0x95, 0xd3, 0xec, 0xef, 0x3c, 0xf9, 0xdc, 0xe7,
		0x5d, 0xc0, 0x8b, 0xa6, 0xfe, 0x9a, 0x49, 0xaf, 0x9b, 0x2e, 0x7b, 0xae, 0x9c, 0xfb, 0x2d, 0xe3,
		0x4c, 0x6c, 0x84, 0x89, 0x8d, 0xed, 0xa9, 0x51, 0xb1, 0x61, 0x35, 0xe5, 0x74, 0xbe, 0x14, 0x2e,
		0x56, 0x43, 0xfa, 0x72, 0x77, 0x36, 0x46, 0xff, 0xa5, 0xee, 0xbc, 0xee, 0x87, 0xdf, 0xf4, 0xbb,
		0x49, 0xfc, 0xec, 0x9b, 0x93, 0x93, 0xd6, 0x83, 0xa6, 0xf6, 0x98, 0xa9, 0x3d, 0x64, 0x92, 0xc9,
		0x13, 0x63, 0x9b, 0xde, 0xc2, 0x00, 0x55, 0x32, 0x1a, 0x85, 0x74, 0x94, 0x8c, 0xaf, 0x5b, 0x5d,
		0x5c, 0xbf, 0xf6, 0x90, 0x19, 0x80, 0xd2, 0x25, 0xa3, 0x52, 0x62, 0xc9, 0x69, 0xbf, 0x8a, 0x02,
		0x23, 0xed, 0xc5, 0x1c, 0xa6, 0x44, 0x8f, 0xf3, 0xe7, 0xca, 0x81, 0xe4, 0x92, 0x2d, 0xb4, 0xf2,
		0x81, 0xb8, 0x44, 0x0b, 0x51, 0xcf, 0xc6, 0x4b, 0xd2, 0x05, 0xba, 0x7c, 0xc0, 0x25, 0xa3, 0x58,
		0x7f, 0x4c, 0xbc, 0xa2, 0x62, 0xd9, 0xc2, 0x76, 0xd4, 0x53, 0xa4, 0x5b, 0xd4, 0xb2, 0x8b, 0x5b,
		0xd9, 0x22, 0x57, 0xb6, 0xd8, 0x95, 0x2c, 0xfa, 0x74, 0x8b, 0x3f, 0xa5, 0x11, 0x2c, 0xbf, 0x50,
		0xbe, 0x7e, 0x62, 0x2d, 0xb8, 0x8b, 0xac, 0xf1, 0x4a, 0x99, 0xb4, 0x48, 0xc6, 0xcc, 0xb3, 0x5c,
		0xe6, 0x7d, 0x8f, 0xc4, 0x5d, 0xc5, 0xaa, 0x09, 0xf8, 0x0a, 0xf8, 0x8a, 0x92, 0xf9, 0x8a, 0x09,
		0xf3, 0x78, 0x7d, 0x5f, 0xc2, 0x43, 0x08, 0x54, 0x95, 0x4a, 0x2a, 0x4d, 0x96, 0xac, 0xd2, 0xaa,
		0x86, 0x4a, 0x2b, 0x5d, 0x43, 0xbb, 0xbf, 0xb7, 0xb7, 0xb3, 0x87, 0x6a, 0x2b, 0x65, 0x71, 0xb7,
		0xe0, 0xd5, 0x56, 0x2b, 0xe6, 0xf0, 0xc3, 0x73, 0x3f, 0x7e, 0x58, 0xc3, 0x45, 0x1f, 0xe6, 0x29,
		0xab, 0x2a, 0x1a, 0x3a, 0x51, 0xfd, 0x12, 0xe1, 0x34, 0x7d, 0x6e, 0x3d, 0x7b, 0x4c, 0x73, 0x6a,
		0xdd, 0x40, 0x6a, 0x8d, 0xd4, 0x7a, 0x95, 0x5a, 0x47, 0x01, 0x8d, 0x0b, 0xbe, 0x24, 0x72, 0xeb,
		0x59, 0x13, 0x00, 0xcc, 0x00, 0xcc, 0x25, 0x04, 0xcc, 0x3b, 0x0d, 0x09, 0xc0, 0x7c, 0x00, 0xc0,
		0x0c, 0xc0, 0x5c, 0x50, 0xc0, 0xbc, 0xdb, 0x38, 0xda, 0x3d, 0xda, 0x3f, 0x68, 0x1c, 0x01, 0x35,
		0xe7, 0xc2, 0x56, 0x81, 0xd7, 0x46, 0xe8, 0x45, 0xe8, 0x7d, 0x69, 0xbe, 0xc1, 0x6b, 0xaf, 0xbe,
		0x65, 0x4c, 0xc7, 0x37, 0x54, 0x42, 0x61, 0x6b, 0xfe, 0x3c, 0xbc, 0x04, 0xbc, 0x44, 0xc9, 0xbc,
		0xc4, 0x0d, 0x89, 0xe8, 0x8a, 0x0a, 0xb2, 0x24, 0xd5, 0x3a, 0x45, 0xd0, 0x7a, 0x6f, 0xc9, 0x4d,
		0xd9, 0x16, 0x1b, 0x7e, 0x5c, 0xe3, 0xa2, 0x9e, 0xfc, 0x62, 0xfe, 0xe7, 0xb8, 0xba, 0x4f, 0xeb,
		0xa8, 0x26, 0x3a, 0x8f, 0xf6, 0x5a, 0x12, 0x90, 0xec, 0x9c, 0xda, 0x6b, 0x58, 0x57, 0xf8, 0xfc,
		0xda, 0x8b, 0x8d, 0x26, 0x3a, 0xd7, 0x96, 0xb1, 0x57, 0xc6, 0x6e, 0x23, 0x7c, 0x33, 0x7c, 0xf3,
		0xab, 0xe4, 0x09, 0x76, 0x1b, 0x41, 0x9e, 0x94, 0x92, 0x3c, 0xc1, 0x6e, 0xa3, 0xda, 0xb8, 0x5b,
		0xa2, 0xdd, 0x46, 0xb5, 0xea, 0x0e, 0x49, 0x36, 0x1b, 0xef, 0x19, 0xb7, 0x6f, 0xa9, 0x63, 0xdd,
		0xb9, 0xc4, 0x13, 0xd8, 0x74, 0x7c, 0xf4, 0x78, 0x39, 0xea, 0x7a, 0x53, 0x74, 0xa5, 0x52, 0xaa,
		0xdd, 0xc7, 0xb8, 0xe3, 0xa6, 0x6c, 0x3f, 0xa6, 0x2c, 0x41, 0xdf, 0x98, 0xe8, 0x54, 0xa5, 0xe8,
		0x82, 0x4b, 0xb7, 0x30, 0xd8, 0x39, 0xe5, 0x92, 0xde, 0x1e, 0xf0, 0x9c, 0x6e, 0xc9, 0x67, 0x83,
		0x9e, 0xd3, 0x9a, 0xc2, 0xf2, 0x41, 0x62, 0xdb, 0x34, 0x8a, 0xd2, 0x79, 0xf2, 0x97, 0x39, 0xd4,
		0xb5, 0xc6, 0x70, 0x03, 0xbc, 0x84, 0x11, 0xa9, 0x32, 0x26, 0xe5, 0x46, 0xa5, 0xdc, 0xb8, 0xd4,
		0x1a, 0x99, 0x24, 0x3c, 0xcd, 0xfd, 0xfe, 0xf7, 0x69, 0xaf, 0x2d, 0xe6, 0x28, 0xb8, 0xfb, 0x7d,
		0x1f, 0x77, 0xb5, 0x6b, 0x49, 0xc8, 0x36, 0x12, 0xb3, 0x3a, 0xee, 0x6a, 0xcf, 0x7b, 0x0a, 0x76,
		0x6b, 0x47, 0xbb, 0xb8, 0x9b, 0x5d, 0x2e, 0x75, 0x16, 0x7f, 0x9f, 0xc0, 0x2a, 0x5b, 0x1d, 0x04,
		0xb7, 0xc6, 0x22, 0x57, 0x06, 0x6e, 0xf8, 0xcd, 0x27, 0xed, 0x01, 0x7b, 0x00, 0x7b, 0x00, 0x7b,
		0x88, 0x60, 0x8f, 0xa9, 0xf9, 0x88, 0x96, 0x3f, 0x6c, 0x24, 0xbc, 0x12, 0x4e, 0x59, 0xb0, 0x1c,
		0x22, 0x5b, 0x2f, 0xe6, 0x11, 0xce, 0xee, 0xa8, 0xa2, 0xdc, 0x69, 0xbd, 0x31, 0xf8, 0x2f, 0xf8,
		0x2f, 0xf8, 0x2f, 0xe4, 0x4e, 0xc8, 0x9d, 0x90, 0x3b, 0x21, 0x77, 0x42, 0xee, 0xf4, 0x68, 0x98,
		0x79, 0x38, 0xf1, 0xbe, 0xc7, 0x3e, 0x3e, 0x92, 0x47, 0x1d, 0xeb, 0x8d, 0x01, 0x75, 0x00, 0x75,
		0x00, 0x75, 0xa4, 0x5c, 0x31, 0x13, 0xef, 0x6d, 0x95, 0xb3, 0x44, 0xc9, 0xd2, 0x91, 0x44, 0x1b,
		0xf3, 0xee, 0xe4, 0x8e, 0x39, 0xd4, 0x41, 0x31, 0x85, 0x90, 0x4c, 0x31, 0x34, 0x53, 0x37, 0x5c,
		0x5a, 0xa0, 0x9a, 0x26, 0xbc, 0xa0, 0x0b, 0xba, 0xe9, 0x04, 0x0f, 0x0a, 0xa1, 0x9c, 0x16, 0x48,
		0x97, 0xd5, 0x54, 0xa9, 0x83, 0x78, 0x99, 0xcc, 0xd6, 0xbb, 0x62, 0xb4, 0x72, 0xf5, 0x2e, 0xc7,
		0x35, 0xa7, 0xda, 0x17, 0x87, 0xb1, 0xeb, 0x53, 0xe7, 0x8e, 0x45, 0xee, 0x40, 0xdb, 0x04, 0x6e,
		0x84, 0x73, 0x1a, 0x7a, 0xca, 0x3c, 0x72, 0xf5, 0x3f, 0xff, 0xde, 0xad, 0x1d, 0x7d, 0xad, 0x59,
		0xbb, 0x57, 0xff, 0xec, 0xd6, 0xbe, 0xd6, 0xac, 0xc3, 0xab, 0xaf, 0x35, 0xeb, 0xe8, 0xea, 0x9f,
		0xaf, 0x75, 0x6b, 0x67, 0xf6, 0xe3, 0xdf, 0x3b, 0x3f, 0xa7, 0x7f, 0x3a, 0x9a, 0xff, 0xa9, 0xfe,
		0x6b, 0x63, 0xfe, 0xe7, 0x5f, 0xbe, 0x7d, 0x7b, 0xff, 0xed, 0xdb, 0x7b, 0x89, 0x06, 0xfe, 0x55,
		0x95, 0x5f, 0x72, 0x2a, 0x06, 0xb5, 0xdb, 0x6f, 0xff, 0x89, 0x91, 0x55, 0x6b, 0xcc, 0x59, 0xe7,
		0x91, 0x82, 0xa8, 0x56, 0xea, 0x20, 0xce, 0x3a, 0x1a, 0x91, 0x3b, 0x90, 0xb3, 0x1e, 0x2c, 0x95,
		0x1f, 0xcc, 0x59, 0x36, 0x2e, 0x75, 0x40, 0x47, 0x22, 0x63, 0xd7, 0x5a, 0xc6, 0x25, 0x58, 0x48,
		0xbc, 0x7c, 0x5e, 0x51, 0x41, 0xf1, 0x7a, 0x81, 0x6e, 0x2a, 0x31, 0xa3, 0xf4, 0xa3, 0x94, 0xe6,
		0x00, 0x54, 0x3a, 0x91, 0xa3, 0x8d, 0x48, 0x98, 0x46, 0xec, 0x68, 0x23, 0xe0, 0x89, 0x16, 0x6f,
		0x36, 0x50, 0xbc, 0x99, 0x2b, 0x5b, 0x81, 0xe2, 0xcd, 0xa4, 0xab, 0x06, 0xc5, 0x9b, 0xa0, 0x02,
		0x41, 0x05, 0xe6, 0xca, 0x7a, 0x61, 0x03, 0x32, 0x1b, 0x8a, 0x04, 0x1b, 0x90, 0xc5, 0x99, 0x02,
		0x6c, 0x40, 0x2a, 0x4c, 0x1c, 0x51, 0xbc, 0x09, 0xec, 0x01, 0xec, 0x81, 0xe2, 0x4d, 0x14, 0x6f,
		0xbe, 0xf9, 0x8d, 0x28, 0xde, 0x84, 0xff, 0x82, 0xff, 0x42, 0xee, 0x84, 0xdc, 0x09, 0xb9, 0x13,
		0x72, 0x27, 0xe4, 0x4e, 0x28, 0xde, 0x04, 0xea, 0x00, 0xea, 0xd8, 0x2e, 0xd4, 0x81, 0xe2, 0x4d,
		0x2d, 0x50, 0x4c, 0x21, 0x24, 0x53, 0x0c, 0xcd, 0xd4, 0x0d, 0x97, 0x16, 0xa8, 0xa6, 0x09, 0x2f,
		0xe8, 0x82, 0x6e, 0x3a, 0xc1, 0x83, 0x42, 0x28, 0xa7, 0x05, 0xd2, 0x65, 0x35, 0x55, 0x28, 0xde,
		0xcc, 0x0e, 0x02, 0x2a, 0x5a, 0x73, 0x28, 0xde, 0x14, 0x69, 0x10, 0xc5, 0x9b, 0x28, 0xde, 0xd4,
		0x62, 0xcc, 0x28, 0xde, 0x14, 0x0d, 0x96, 0x28, 0xde, 0x4c, 0x97, 0x52, 0x15, 0xb0, 0x78, 0x33,
		0x85, 0x36, 0x6c, 0xfa, 0x41, 0x2a, 0x95, 0x88, 0xae, 0x80, 0x28, 0xed, 0xec, 0xf5, 0x3c, 0x9c,
		0xd8, 0xdc, 0x9b, 0x07, 0xec, 0xf6, 0xa2, 0xf1, 0xeb, 0xe6, 0xaa, 0xf1, 0xeb, 0xfe, 0xbc, 0xf1,
		0x2f, 0x89, 0xb3, 0xec, 0x04, 0x42, 0xbd, 0xef, 0x24, 0x06, 0xbd, 0xda, 0x9c, 0x8c, 0xa6, 0xa6,
		0x1d, 0x5f, 0xc4, 0xf8, 0x76, 0x98, 0x49, 0x29, 0xf0, 0x9b, 0xe8, 0x6a, 0x0a, 0x97, 0x8c, 0x3e,
		0xae, 0x4d, 0x40, 0x52, 0x1d, 0xe0, 0x53, 0x1a, 0xd9, 0x21, 0x0b, 0xe6, 0xcb, 0xa4, 0xda, 0x74,
		0x9c, 0xa8, 0xf2, 0xe5, 0xbc, 0xd9, 0xa9, 0x44, 0x94, 0x73, 0xe6, 0x8d, 0xa2, 0x0a, 0xf7, 0x2b,
		0xa4, 0x72, 0xde, 0xfc, 0x54, 0x59, 0xbe, 0x0e, 0x1a, 0xc3, 0x99, 0x92, 0x57, 0xdb, 0xad, 0x31,
		0x2c, 0x26, 0x8e, 0xbd, 0x31, 0xdf, 0xa2, 0xfe, 0xe8, 0x39, 0x23, 0x69, 0x79, 0xb6, 0xeb, 0x47,
		0xcc, 0x1b, 0x55, 0x6c, 0xdf, 0xe3, 0x84, 0x79, 0x34, 0xac, 0x0c, 0xfd, 0x70, 0x66, 0x37, 0xab,
		0xea, 0x9b, 0x28, 0xa0, 0x36, 0x1b, 0x32, 0xfb, 0x9b, 0xe7, 0x10, 0x4e, 0x2a, 0xbe, 0x57, 0x69,
		0xf1, 0x5b, 0x1a, 0x7a, 0x94, 0xaf, 0xfe, 0x52, 0xf4, 0xbe, 0x52, 0x19, 0xdc, 0xd2, 0x88, 0x56,
		0x48, 0x48, 0xe3, 0x46, 0x22, 0x4e, 0x3c, 0x87, 0x84, 0xce, 0x37, 0xef, 0xbc, 0xf1, 0x6b, 0x65,
		0xf9, 0xd9, 0x11, 0x7f, 0x70, 0x69, 0xfc, 0x86, 0xe8, 0x3d, 0x04, 0x93, 0x75, 0x92, 0xce, 0xa8,
		0xb9, 0xd7, 0x82, 0x5a, 0x24, 0x03, 0xf0, 0xd5, 0x5b, 0x01, 0x38, 0x1d, 0xda, 0x51, 0x83, 0x72,
		0xaa, 0x89, 0x6e, 0x12, 0x7f, 0x13, 0xcf, 0xbc, 0x3e, 0x97, 0x2f, 0x8f, 0xcb, 0x2b, 0x3e, 0x37,
		0xa9, 0x34, 0x7b, 0x3a, 0x29, 0xf6, 0x84, 0x9e, 0x24, 0xb1, 0xe7, 0x48, 0xe3, 0x29, 0xd6, 0x3d,
		0x03, 0x4b, 0x72, 0x4b, 0x58, 0x5a, 0x3f, 0x20, 0x6c, 0xf7, 0xc2, 0x76, 0xfe, 0xd4, 0xae, 0xd9,
		0xb0, 0xaa, 0x19, 0xa6, 0x26, 0x8d, 0xbe, 0x55, 0xe7, 0x51, 0xc4, 0x4b, 0x89, 0x57, 0xd7, 0x1f,
		0x4e, 0x07, 0x15, 0x6b, 0x05, 0x85, 0x8a, 0x6c, 0xb8, 0x95, 0x40, 0x31, 0xc9, 0x82, 0xd4, 0x03,
		0x13, 0x53, 0xef, 0x49, 0xae, 0x9d, 0x4a, 0x0c, 0x99, 0x97, 0xe6, 0x4e, 0x89, 0x15, 0x8d, 0x9b,
		0xe1, 0x95, 0x2f, 0xd4, 0x23, 0x37, 0x6e, 0x8a, 0x6b, 0xfb, 0x97, 0xdd, 0x5b, 0x3c, 0x98, 0x38,
		0xbd, 0x1b, 0x92, 0x89, 0xcb, 0xe7, 0xd5, 0x0d, 0x14, 0xe6, 0x08, 0x73, 0xcc, 0xd6, 0x1c, 0x6f,
		0x7c, 0xdf, 0xa5, 0xe9, 0xf2, 0xec, 0x85, 0x3d, 0xd6, 0x33, 0xb4, 0x47, 0xd7, 0xf7, 0x83, 0x1b,
		0x62, 0x7f, 0x4f, 0x77, 0x04, 0x63, 0x75, 0x91, 0xf7, 0xa3, 0xc7, 0xd3, 0xdb, 0xe6, 0x90, 0xb8,
		0x11, 0x8c, 0x13, 0xc6, 0x09, 0xe3, 0x7c, 0xee, 0x9d, 0x63, 0x3e, 0x49, 0x6f, 0x92, 0xd3, 0x87,
		0x60, 0x50, 0x30, 0xa8, 0x4c, 0x0d, 0x2a, 0xf5, 0x95, 0xa9, 0x02, 0x25, 0x5d, 0x82, 0xa5, 0x5b,
		0x62, 0x57, 0x49, 0x4b, 0xb0, 0x68, 0x72, 0x95, 0xb0, 0x92, 0x57, 0xa0, 0xaa, 0x28, 0xca, 0xf9,
		0x29, 0x76, 0x77, 0x76, 0xee, 0x43, 0x26, 0x71, 0xb5, 0xa9, 0x92, 0x61, 0xd3, 0xc4, 0x33, 0x5e,
		0x65, 0x18, 0x71, 0xe6, 0x74, 0x5d, 0xca, 0x90, 0x13, 0x3f, 0x85, 0x98, 0x83, 0x98, 0x03, 0xc2,
		0x63, 0xe3, 0x9d, 0x3c, 0x60, 0x02, 0x6c, 0x47, 0xfc, 0x54, 0xfa, 0x74, 0x6a, 0xbe, 0x47, 0x12,
		0x9f, 0xdd, 0x8d, 0x3e, 0x0e, 0x7a, 0xed, 0xd3, 0xeb, 0xda, 0x9f, 0x87, 0xf5, 0x5a, 0xad, 0x24,
		0xd6, 0x89, 0x9d, 0x6b, 0xa3, 0x2c, 0x94, 0x39, 0xd4, 0xe3, 0x8c, 0x3f, 0x84, 0x74, 0x28, 0x62,
		0xa6, 0x29, 0x62, 0x79, 0xb5, 0x3d, 0x7f, 0xd5, 0x31, 0x89, 0x24, 0x94, 0xdd, 0x62, 0x8b, 0x19,
		0xfc, 0xd5, 0x6b, 0xf5, 0xd3, 0x4e, 0x78, 0x8c, 0x41, 0x22, 0xa1, 0x5a, 0x4b, 0xc9, 0xc3, 0x5b,
		0x73, 0x2b, 0x3f, 0x9a, 0x5a, 0x79, 0x16, 0x50, 0x4f, 0xd1, 0xe7, 0x36, 0x8c, 0xfa, 0xdc, 0xc3,
		0xc3, 0xe6, 0xa1, 0x49, 0x9f, 0x6b, 0xd2, 0x62, 0x68, 0x76, 0xfe, 0xd2, 0xbd, 0xa9, 0x7f, 0x95,
		0xfd, 0xa6, 0x7e, 0x12, 0x68, 0x90, 0xc6, 0xb1, 0xae, 0xa0, 0x41, 0x72, 0x5d, 0x0e, 0x80, 0x6d,
		0x80, 0xed, 0x6d, 0x0d, 0xe5, 0xab, 0x72, 0x34, 0x01, 0x21, 0x9b, 0x1c, 0xc3, 0x39, 0x23, 0x1e,
		0xb1, 0xa4, 0x3e, 0x5e, 0x45, 0x27, 0xe4, 0x3a, 0xb3, 0xd1, 0x29, 0x72, 0xc7, 0x6c, 0xd6, 0x0d,
		0x38, 0xb3, 0x89, 0x1b, 0xd7, 0x02, 0x4a, 0x1c, 0x11, 0xfe, 0x35, 0xef, 0xce, 0x38, 0xbe, 0x1d,
		0x9d, 0x90, 0x1b, 0x97, 0x76, 0x1c, 0xa3, 0xfb, 0xf1, 0xa3, 0xb1, 0x17, 0xb8, 0xd4, 0xe4, 0x1e,
		0xdc, 0xf9, 0xcc, 0xa6, 0xad, 0x0b, 0x93, 0xbb, 0x70, 0xbb, 0xd3, 0xd8, 0xe9, 0x85, 0xfe, 0x8f,
		0x07, 0x93, 0x3b, 0x41, 0xf8, 0xf8, 0x0b, 0x0b, 0xf9, 0x84, 0xb8, 0x26, 0xf7, 0x62, 0x1c, 0xd0,
		0xd1, 0x20, 0x24, 0x5e, 0x14, 0xf8, 0x21, 0x37, 0xda, 0xb0, 0x0f, 0xf7, 0xcf, 0x49, 0x10, 0x99,
		0xdc, 0x85, 0xd1, 0x41, 0x6d, 0x87, 0xf0, 0xfd, 0xdd, 0xef, 0x26, 0x77, 0xc2, 0xbe, 0x25, 0x9e,
		0x47, 0x8d, 0xb6, 0x09, 0x6f, 0x48, 0x8c, 0x5e, 0x47, 0x2c, 0x9a, 0x04, 0x26, 0x7f, 0x7f, 0x10,
		0xfa, 0x41, 0x93, 0x8f, 0x8d, 0x86, 0x4b, 0x51, 0xfd, 0xec, 0xf4, 0xdc, 0xe8, 0x49, 0x70, 0x6d,
		0xa3, 0xa3, 0xb3, 0x3b, 0x69, 0x05, 0xbe, 0xd7, 0xf5, 0x26, 0x46, 0xf7, 0xc2, 0x89, 0xdc, 0x46,
		0xe0, 0x4e, 0x8c, 0x76, 0x47, 0x84, 0xb8, 0x0d, 0x93, 0xbf, 0xff, 0xbf, 0xc4, 0x68, 0x57, 0x34,
		0x0c, 0xc9, 0x98, 0x5e, 0x52, 0x97, 0x3c, 0xf4, 0x69, 0x78, 0xc7, 0x6c, 0xa3, 0x93, 0x1f, 0xdb,
		0xe6, 0xad, 0xf1, 0xc4, 0x68, 0x74, 0xe1, 0xb8, 0xd1, 0xbd, 0xd9, 0xe8, 0xc2, 0x3f, 0x3c, 0xac,
		0x35, 0xf6, 0x4e, 0x2e, 0xcf, 0x7a, 0x6d, 0xcf, 0xe8, 0x9c, 0x61, 0xfc, 0x10, 0x32, 0x8f, 0x72,
		0xb3, 0xad, 0x7b, 0x58, 0xdf, 0xbf, 0x18, 0x86, 0xc7, 0x13, 0xcf, 0x31, 0x9c, 0xd7, 0x98, 0x25,
		0xd3, 0x83, 0x51, 0x09, 0x8c, 0x63, 0xe7, 0x24, 0x1a, 0x13, 0xdb, 0x31, 0x9a, 0xa3, 0x61, 0x01,
		0x0d, 0x5d, 0xe2, 0x19, 0x1d, 0xba, 0xfd, 0x19, 0xfb, 0x5a, 0x0a, 0x82, 0x23, 0xa4, 0xa3, 0x89,
		0x4b, 0xc2, 0xfa, 0x61, 0xa3, 0x51, 0x0a, 0x22, 0xf9, 0x73, 0x10, 0xf1, 0x90, 0x9a, 0x8d, 0xad,
		0x42, 0x4a, 0xec, 0xdb, 0xd3, 0xbe, 0xd1, 0x89, 0x1e, 0x0b, 0x66, 0x02, 0x2b, 0x46, 0xf7, 0xe1,
		0x66, 0xbc, 0x73, 0x50, 0x0b, 0x48, 0x78, 0x72, 0x2b, 0xa5, 0xc4, 0x5a, 0x0c, 0x72, 0xbf, 0x7b,
		0x47, 0xc3, 0xb3, 0x25, 0x6a, 0x37, 0x1a, 0x9d, 0x90, 0x88, 0xc7, 0x5b, 0x5f, 0x67, 0x7f, 0x1a,
		0x3d, 0x2b, 0xd3, 0x34, 0xdc, 0xe4, 0x0e, 0xd0, 0xb9, 0x14, 0xc9, 0xce, 0xc5, 0x0d, 0xe3, 0x65,
		0x48, 0x3e, 0x4e, 0xb9, 0xd1, 0xbb, 0x90, 0x7c, 0x62, 0x3a, 0x47, 0xee, 0xfa, 0x53, 0x5c, 0x45,
		0x5c, 0xb3, 0xf7, 0x2a, 0x68, 0x54, 0x02, 0x8e, 0xb3, 0x77, 0xfb, 0x10, 0x4d, 0x51, 0xee, 0x67,
		0x8f, 0x19, 0xce, 0xfa, 0x73, 0xea, 0x7b, 0x87, 0x35, 0xd3, 0x7d, 0xd4, 0x2d, 0x0b, 0x02, 0xb6,
		0x94, 0x7e, 0x29, 0x45, 0xf8, 0x36, 0x1a, 0xa3, 0x0f, 0xed, 0xfa, 0xee, 0xe1, 0x8e, 0xd1, 0x1b,
		0xc3, 0x47, 0x47, 0x87, 0x66, 0x53, 0xe8, 0xae, 0xd9, 0xbb, 0x49, 0xcb, 0xa4, 0xf5, 0xd4, 0xbf,
		0xf7, 0xcc, 0x4f, 0x5b, 0x67, 0x25, 0x44, 0x9e, 0x4d, 0x8c, 0xde, 0x26, 0x1e, 0x53, 0x87, 0x91,
		0x0b, 0xc2, 0xdc, 0x69, 0xbe, 0xd4, 0x36, 0xba, 0x2b, 0x24, 0x34, 0x7b, 0x2a, 0x9c, 0xbb, 0x9b,
		0x4b, 0xdb, 0xbe, 0x20, 0xf6, 0x39, 0x79, 0x30, 0x3b, 0x5a, 0x30, 0x4a, 0xe9, 0x61, 0xad, 0x51,
		0xdf, 0xdb, 0x35, 0x3a, 0x60, 0x84, 0x3b, 0xb5, 0x9d, 0xcb, 0xd3, 0x81, 0xd1, 0x78, 0xd0, 0xf1,
		0x62, 0xec, 0x71, 0xee, 0xfb, 0x81, 0xd1, 0xc1, 0xcf, 0x25, 0x81, 0x63, 0x7c, 0xb4, 0x38, 0xfb,
		0x74, 0xda, 0x6a, 0x76, 0x9a, 0x46, 0x67, 0x7b, 0x8f, 0x03, 0xf8, 0xe5, 0xb0, 0x67, 0xf8, 0x8e,
		0x00, 0x09, 0x6d, 0xc3, 0x77, 0x2f, 0xa7, 0xb8, 0xaa, 0x3b, 0x74, 0xc6, 0xe5, 0x80, 0x55, 0xe3,
		0xc0, 0x68, 0x90, 0x7b, 0xeb, 0xdc, 0x1a, 0xbf, 0xb9, 0x64, 0x76, 0xd5, 0xe0, 0x88, 0x8d, 0xc8,
		0x0d, 0xe3, 0x0b, 0xe1, 0x68, 0xa3, 0xa3, 0x77, 0x10, 0x5c, 0x4c, 0x5c, 0xce, 0x5c, 0xe6, 0x7d,
		0x37, 0xbf, 0x36, 0x61, 0xbe, 0x8f, 0x7c, 0x32, 0xab, 0x6d, 0xfe, 0x14, 0xfa, 0x66, 0x17, 0xd8,
		0xf2, 0xb0, 0x56, 0x3b, 0x34, 0xb9, 0x03, 0x37, 0xa3, 0x20, 0xf0, 0x5d, 0x66, 0x3f, 0x10, 0xdb,
		0xf6, 0x27, 0x1e, 0x67, 0xde, 0xc8, 0xf8, 0xf4, 0x29, 0x1a, 0x38, 0x63, 0x62, 0xf4, 0xa4, 0x30,
		0x1e, 0x99, 0x5d, 0xb3, 0x6d, 0x34, 0x49, 0xc8, 0x9c, 0xc8, 0xe8, 0x1d, 0xa5, 0x9b, 0x90, 0x39,
		0x23, 0xa3, 0xa3, 0x44, 0xe0, 0x7b, 0xfb, 0x66, 0xe3, 0xa7, 0x5b, 0x7f, 0x4c, 0x03, 0xcf, 0x68,
		0x2f, 0x74, 0x7f, 0x4f, 0xbc, 0x5e, 0xcf, 0xf0, 0x83, 0x85, 0xe6, 0x93, 0xcb, 0xc7, 0x7d, 0xd3,
		0x77, 0x56, 0xcf, 0x7b, 0x66, 0x43, 0x3c, 0xe2, 0x45, 0xc1, 0x6f, 0x8e, 0xd9, 0xfb, 0x2e, 0x34,
		0xb2, 0x7d, 0xcf, 0xec, 0xe2, 0xba, 0x33, 0x3f, 0xbc, 0x27, 0xa1, 0xd1, 0x04, 0x20, 0x19, 0xba,
		0xc4, 0xa3, 0x87, 0xb5, 0xc6, 0x9e, 0xd1, 0xf4, 0x1f, 0x8b, 0x6c, 0xbf, 0xdd, 0x3f, 0x97, 0xbc,
		0xac, 0xbd, 0x00, 0x34, 0x66, 0x70, 0x4f, 0x82, 0x3f, 0x78, 0x30, 0x3f, 0x7d, 0x7e, 0x49, 0x1c,
		0xe6, 0x1b, 0x4d, 0x9b, 0x31, 0xff, 0x87, 0xd9, 0x4b, 0x2b, 0x0c, 0xcc, 0xd6, 0xc4, 0xb8, 0xf1,
		0x7f, 0xfc, 0xc1, 0x42, 0xea, 0xd2, 0xc8, 0xe8, 0x04, 0x2e, 0xf2, 0x3d, 0xca, 0xbb, 0x77, 0x34,
		0xbc, 0xa5, 0xc4, 0x39, 0x31, 0xff, 0x1c, 0x3a, 0x71, 0x27, 0x9f, 0xcc, 0x3f, 0xc3, 0x1a, 0xb9,
		0x2c, 0x30, 0x1c, 0x8e, 0x9f, 0x4d, 0xcc, 0x2e, 0xad, 0x5b, 0x54, 0xcd, 0x0e, 0xfc, 0xef, 0xd4,
		0xbb, 0x34, 0x9c, 0x2c, 0x63, 0x43, 0x6b, 0x14, 0x99, 0x5d, 0xe4, 0x3f, 0xbe, 0x27, 0x21, 0x9d,
		0x87, 0xef, 0x0e, 0xb3, 0x8d, 0x3f, 0xa1, 0x6e, 0x74, 0xec, 0x8e, 0x1a, 0x3b, 0x8d, 0x92, 0x28,
		0x73, 0x0d, 0x0d, 0xf7, 0xb3, 0xc6, 0x43, 0xd9, 0x68, 0xec, 0x44, 0xa7, 0x3f, 0x8c, 0x8e, 0x15,
		0x23, 0x1e, 0x98, 0x5e, 0x2a, 0x5b, 0x37, 0xbf, 0xa8, 0xa3, 0x67, 0xb8, 0xe6, 0xc7, 0x6d, 0x14,
		0x19, 0x6d, 0x05, 0x51, 0x68, 0xb4, 0x15, 0xf8, 0xdc, 0xeb, 0xf2, 0x89, 0xf9, 0x34, 0xbe, 0xd1,
		0x81, 0x79, 0xe2, 0xf2, 0x90, 0x98, 0xbd, 0x1b, 0x14, 0xf1, 0x1e, 0x71, 0x4a, 0x70, 0xa8, 0xa8,
		0x6e, 0xfc, 0xa1, 0xa2, 0xbb, 0x1d, 0xa3, 0x19, 0xb2, 0x31, 0xb1, 0xfb, 0xd4, 0x3e, 0xf1, 0x3d,
		0x1e, 0xfa, 0xae, 0x4b, 0x9d, 0xf6, 0x59, 0x19, 0xf2, 0xe9, 0x33, 0x76, 0x63, 0x76, 0xb5, 0xfb,
		0x34, 0x4e, 0x38, 0x46, 0xc7, 0x89, 0xd1, 0x90, 0x44, 0xdc, 0xf4, 0x03, 0x07, 0xf5, 0x9d, 0x23,
		0xa3, 0x8f, 0x1b, 0x38, 0x8e, 0xf7, 0xa7, 0xd9, 0x0c, 0xbe, 0xd9, 0x14, 0x25, 0x8b, 0x1c, 0xcf,
		0x74, 0x12, 0xa9, 0x04, 0xf1, 0x60, 0x37, 0xe6, 0x57, 0x8f, 0x27, 0x51, 0x09, 0xfa, 0xd2, 0x30,
		0xfc, 0xc4, 0x66, 0x7c, 0x08, 0xdb, 0x68, 0x9b, 0x88, 0x1e, 0x3c, 0xdb, 0xfc, 0x33, 0x81, 0xe5,
		0x38, 0xd9, 0xe1, 0x9b, 0x7e, 0x08, 0x7e, 0x76, 0x86, 0xeb, 0xcf, 0xae, 0xd1, 0x6a, 0x04, 0x36,
		0x0b, 0xce, 0x99, 0xf7, 0xdd, 0xf8, 0x2d, 0x6a, 0xa3, 0x0f, 0x33, 0xee, 0xb0, 0xe0, 0x87, 0xe9,
		0x25, 0x34, 0x11, 0x0b, 0xfa, 0xcc, 0xec, 0x13, 0x03, 0x51, 0xad, 0x04, 0x5a, 0x9f, 0xed, 0xa0,
		0xe9, 0x38, 0xa1, 0xe1, 0x55, 0x27, 0x53, 0x8b, 0x30, 0xdd, 0x20, 0x86, 0x61, 0x09, 0xca, 0x14,
		0xa9, 0x6d, 0xba, 0x73, 0x9d, 0x0b, 0x3a, 0x9d, 0xfb, 0x23, 0x66, 0x13, 0xd7, 0xf4, 0x58, 0x17,
		0x84, 0x7e, 0x70, 0xe2, 0xb9, 0x66, 0x67, 0x43, 0x86, 0x1b, 0xf6, 0xd8, 0xb7, 0xc9, 0x17, 0x1a,
		0x46, 0xcc, 0xf7, 0x8c, 0xde, 0x15, 0xb5, 0x6f, 0xdc, 0x2f, 0xd4, 0xe6, 0xa4, 0xcf, 0x49, 0x68,
		0xf8, 0x11, 0xa1, 0xfa, 0x9e, 0xd9, 0x65, 0xd4, 0xfe, 0x70, 0x48, 0x8d, 0x3e, 0xa6, 0x15, 0x12,
		0x87, 0xf9, 0x17, 0xcd, 0x13, 0xa3, 0x41, 0xc7, 0xd8, 0xf8, 0x1b, 0x7e, 0x7a, 0x3e, 0xf3, 0xf8,
		0xc0, 0x8f, 0xff, 0xd5, 0xa7, 0x21, 0x33, 0xfb, 0x1e, 0xb5, 0x69, 0x8f, 0x4a, 0x70, 0x1d, 0xdc,
		0x90, 0xdd, 0x84, 0xb4, 0x04, 0xa5, 0xd3, 0x4e, 0x54, 0x33, 0x5f, 0x75, 0x60, 0x79, 0xee, 0x66,
		0xc7, 0xec, 0x64, 0xfb, 0xc7, 0xc0, 0x3f, 0xf3, 0x27, 0xa1, 0xe1, 0x8c, 0x81, 0xd9, 0x17, 0x53,
		0x04, 0x66, 0x1f, 0x2a, 0x0d, 0xfc, 0xc8, 0xfc, 0xf2, 0x87, 0xcf, 0x9e, 0x5d, 0x92, 0x02, 0x08,
		0x6e, 0xf8, 0xb9, 0xd2, 0xf9, 0x1d, 0xba, 0x67, 0x9f, 0x4e, 0x8d, 0x8e, 0x0f, 0x36, 0xa7, 0x2e,
		0x8b, 0x2e, 0x28, 0x27, 0xe7, 0xdd, 0x6e, 0xaf, 0x1c, 0x97, 0x94, 0xc5, 0xc2, 0xc9, 0xb6, 0xef,
		0x79, 0xd4, 0x36, 0x9a, 0xcb, 0x89, 0x6e, 0x0d, 0xdf, 0xd4, 0x0e, 0xa3, 0xf0, 0xc6, 0xec, 0x92,
		0x8e, 0xee, 0x1d, 0x0d, 0x4d, 0xbf, 0x47, 0x74, 0x71, 0xb8, 0xe3, 0xe2, 0x64, 0xcc, 0xa3, 0x72,
		0x6c, 0xa6, 0xfe, 0x68, 0xd4, 0x77, 0xca, 0xa0, 0x87, 0xd9, 0xed, 0x1b, 0x7e, 0x11, 0xfe, 0xed,
		0xc4, 0xe3, 0xc6, 0x6b, 0x99, 0x8d, 0x87, 0x7d, 0x36, 0x32, 0x9d, 0x2a, 0x77, 0x6c, 0xcf, 0xf4,
		0x7b, 0x02, 0x4c, 0x27, 0x6f, 0x4e, 0x7d, 0x3b, 0x5a, 0x1c, 0x82, 0xbf, 0x20, 0xb6, 0x6b, 0xba,
		0x90, 0xf5, 0xf8, 0xce, 0xec, 0x92, 0xba, 0xe1, 0x97, 0x21, 0x1b, 0x3c, 0x04, 0xd4, 0x6c, 0x41,
		0x58, 0x37, 0x1a, 0x18, 0x7f, 0xd5, 0xcf, 0xf2, 0x4e, 0xb2, 0x18, 0x88, 0x98, 0x6d, 0xe7, 0x6c,
		0x4c, 0xc2, 0x87, 0x76, 0xff, 0xb4, 0x53, 0x06, 0x8d, 0xfa, 0xfd, 0x3f, 0x2e, 0x9a, 0x46, 0x77,
		0x64, 0x1c, 0x19, 0x9e, 0x23, 0xcd, 0x4e, 0xf2, 0x77, 0x98, 0x3d, 0x30, 0x1c, 0x93, 0x2f, 0x84,
		0xb8, 0x49, 0x19, 0x6e, 0xe5, 0x8c, 0x38, 0xb1, 0xbf, 0x0f, 0xfc, 0xfe, 0xf4, 0x5f, 0x65, 0xb9,
		0x01, 0xa1, 0x6e, 0x7e, 0x2a, 0x7e, 0x62, 0x38, 0x69, 0xe8, 0xdc, 0xdd, 0x34, 0x23, 0xd6, 0x9d,
		0x18, 0x0d, 0x75, 0x39, 0x35, 0x3d, 0x57, 0x8a, 0xe1, 0xc8, 0x69, 0xfb, 0xd4, 0xec, 0x53, 0x6b,
		0x81, 0xf9, 0x12, 0x74, 0xa7, 0x3e, 0xaf, 0xd7, 0x7b, 0xa1, 0x3f, 0x64, 0x66, 0xa3, 0x42, 0x87,
		0x8d, 0x18, 0x27, 0x6e, 0xcf, 0xbf, 0xa7, 0xa1, 0xcb, 0x3c, 0xe3, 0x33, 0x0e, 0xf3, 0x95, 0xd0,
		0xcb, 0x70, 0x91, 0x54, 0x38, 0xb4, 0x0f, 0x0f, 0x0e, 0x0c, 0x17, 0x36, 0x34, 0x1d, 0x9f, 0x13,
		0x3e, 0xfe, 0x62, 0xb3, 0x96, 0xe7, 0xf4, 0xb8, 0xd9, 0x35, 0x77, 0xe3, 0xc0, 0x8f, 0x98, 0xf9,
		0xb1, 0x3b, 0x62, 0x41, 0x99, 0x78, 0xc2, 0x32, 0x24, 0x4b, 0x4b, 0x76, 0xc7, 0xf0, 0x9d, 0x32,
		0x52, 0x6f, 0x5c, 0x04, 0x41, 0xff, 0x9e, 0x71, 0xfb, 0xd6, 0x6c, 0x97, 0x6b, 0xb3, 0x52, 0xec,
		0x58, 0xf6, 0x6d, 0x4e, 0xf7, 0xf6, 0x9c, 0xc6, 0xe7, 0xa8, 0xeb, 0xdf, 0x18, 0x5e, 0x2f, 0x6c,
		0x76, 0x14, 0x1c, 0x05, 0x66, 0x8b, 0xa8, 0xdf, 0x90, 0x88, 0xd9, 0xa6, 0x93, 0xb6, 0x6b, 0x39,
		0xd3, 0xb1, 0xd9, 0x07, 0xde, 0xee, 0x76, 0xf6, 0xcd, 0x3e, 0x82, 0x3b, 0xe4, 0xf7, 0x24, 0xa4,
		0xe7, 0xbe, 0x1f, 0xdc, 0x18, 0xce, 0x10, 0xda, 0x5e, 0x29, 0x2e, 0xdb, 0xad, 0x1b, 0x9e, 0x63,
		0xdc, 0xf8, 0x9e, 0xd1, 0x27, 0x27, 0x5d, 0xe6, 0xd1, 0x91, 0xe9, 0x85, 0x20, 0x73, 0x89, 0x03,
		0xa3, 0x8b, 0x72, 0xee, 0xcc, 0x36, 0x85, 0x28, 0x3a, 0x28, 0x41, 0x31, 0x0e, 0x9d, 0x5f, 0xbf,
		0x79, 0x12, 0x8d, 0x89, 0xed, 0x18, 0x5e, 0xe3, 0x35, 0x76, 0x03, 0xc3, 0xaf, 0x11, 0x35, 0xfb,
		0xf8, 0xad, 0x43, 0xc7, 0xa6, 0xcb, 0x29, 0xef, 0x18, 0x7f, 0x13, 0x7e, 0xdb, 0xec, 0x9b, 0xf0,
		0xe7, 0xb2, 0x00, 0x66, 0x6f, 0x3b, 0x86, 0x63, 0xf3, 0xa5, 0x64, 0x67, 0x57, 0x1a, 0x07, 0x2e,
		0xfd, 0xe1, 0x1b, 0x8d, 0xbb, 0xdd, 0x86, 0xe9, 0x82, 0x25, 0xcc, 0x1b, 0x32, 0x8f, 0xdd, 0x10,
		0xb3, 0x71, 0x37, 0xe1, 0xe3, 0xb9, 0xd6, 0x47, 0x09, 0xb2, 0xb8, 0x1d, 0xe2, 0x9c, 0x93, 0x51,
		0x79, 0x6e, 0xf9, 0x2e, 0xd3, 0x46, 0x45, 0x39, 0x0e, 0x8e, 0xb0, 0xc8, 0x31, 0xfb, 0x2a, 0xac,
		0x49, 0x54, 0x82, 0x13, 0x55, 0x27, 0x2e, 0xb9, 0x2f, 0xd3, 0x06, 0x45, 0xfd, 0xec, 0xde, 0x31,
		0x7c, 0x87, 0xe2, 0xce, 0xf4, 0xab, 0xbf, 0xa3, 0x12, 0x28, 0x9d, 0x96, 0x61, 0x33, 0x78, 0x2e,
		0xfe, 0xbb, 0x7f, 0x61, 0xba, 0x9c, 0xdd, 0xe2, 0x34, 0xf1, 0x45, 0xaf, 0x6d, 0x34, 0x40, 0x24,
		0xee, 0x9e, 0xe9, 0x38, 0x64, 0x81, 0x41, 0x7a, 0x8d, 0x9e, 0xd9, 0xfb, 0xf2, 0xc6, 0x57, 0x2f,
		0x0f, 0x9c, 0x71, 0xa9, 0x2a, 0x0b, 0x4e, 0x4d, 0xaf, 0x2c, 0x20, 0x7c, 0xdc, 0x1e, 0x13, 0xb3,
		0x8f, 0xe9, 0xf5, 0xee, 0x4d, 0x3f, 0xa5, 0xe7, 0x44, 0x75, 0xe3, 0x25, 0xa5, 0x7b, 0x84, 0xdf,
		0x9a, 0x7e, 0x71, 0x62, 0xdb, 0x36, 0xfc, 0x16, 0x0e, 0x8f, 0xd3, 0xd0, 0xa5, 0xe4, 0xae, 0x0c,
		0xd5, 0xf0, 0x7f, 0x84, 0x24, 0x08, 0x68, 0x58, 0xa2, 0xdb, 0xb4, 0x63, 0x3b, 0xf9, 0x32, 0x28,
		0x45, 0xad, 0x66, 0xdb, 0xf8, 0x32, 0xda, 0xe3, 0x3f, 0x9a, 0x41, 0xe3, 0xc2, 0xec, 0x6e, 0x98,
		0xed, 0xae, 0xa8, 0xd9, 0x3b, 0x4a, 0x6c, 0x6c, 0x74, 0x49, 0xff, 0x7f, 0x1b, 0x47, 0x3b, 0x46,
		0xc3, 0x0e, 0xcf, 0xf0, 0x5a, 0x7e, 0x1a, 0xb8, 0x61, 0x64, 0xfe, 0x71, 0xd4, 0xb6, 0x67, 0xf8,
		0xce, 0xf6, 0xa7, 0xc0, 0xf7, 0x7a, 0xb7, 0x0f, 0x11, 0xb3, 0x89, 0xfb, 0xd9, 0x63, 0xa6, 0xcb,
		0xe0, 0x18, 0xce, 0xc4, 0xde, 0x3e, 0x04, 0x34, 0xb4, 0xcd, 0x07, 0x7b, 0x43, 0xc7, 0x31, 0x7a,
		0x29, 0xb9, 0x24, 0x18, 0x1a, 0x2e, 0xc1, 0x10, 0x9e, 0x9b, 0x4d, 0x22, 0xdf, 0xee, 0x34, 0x76,
		0x3e, 0x11, 0x4e, 0xbf, 0x53, 0x1a, 0x98, 0x7d, 0x14, 0x75, 0x49, 0x9c, 0x2d, 0xb6, 0x28, 0x2e,
		0x87, 0x3d, 0x3f, 0xe4, 0x86, 0xdb, 0x87, 0xd1, 0xcc, 0xdf, 0xe8, 0xa0, 0xb6, 0x43, 0x78, 0x63,
		0x7c, 0x53, 0xaa, 0x9d, 0xd4, 0x4b, 0xca, 0x0d, 0x67, 0x64, 0x59, 0xe4, 0x78, 0x51, 0xa9, 0x6c,
		0xbd, 0x04, 0xcc, 0xcd, 0xad, 0x13, 0xb9, 0x0d, 0xb3, 0xf7, 0x23, 0x4f, 0xdd, 0x12, 0x1c, 0x43,
		0x5f, 0x6d, 0xab, 0x96, 0x43, 0x52, 0xb7, 0x04, 0x2a, 0x8f, 0x77, 0x3b, 0x07, 0x46, 0x27, 0xe1,
		0xa6, 0x9f, 0xfc, 0x3a, 0xfd, 0xc1, 0x0c, 0xef, 0x41, 0x7f, 0x72, 0x13, 0x4b, 0xae, 0x0f, 0x89,
		0x4d, 0xcb, 0x70, 0x96, 0xb0, 0x61, 0x76, 0xa4, 0x33, 0xbb, 0xc8, 0x20, 0x20, 0xa1, 0xcc, 0x76,
		0xb6, 0xd0, 0x93, 0x57, 0xef, 0x32, 0x18, 0x27, 0xb1, 0xf1, 0x59, 0xd9, 0xd9, 0x1d, 0xb3, 0x59,
		0x77, 0x56, 0x5e, 0xdc, 0x12, 0xbb, 0x4b, 0x3a, 0xfb, 0x8f, 0x5e, 0x06, 0xca, 0x8e, 0x63, 0xc4,
		0xf7, 0xfe, 0x68, 0xec, 0x05, 0x22, 0x4a, 0x64, 0xd9, 0x7f, 0xe9, 0xfc, 0xfa, 0x11, 0x13, 0x3e,
		0xf5, 0x76, 0xa7, 0xb1, 0xd3, 0x0b, 0xfd, 0x1f, 0x0f, 0x26, 0x7c, 0x2c, 0xe1, 0x63, 0xe1, 0x3b,
		0xd8, 0xb2, 0xff, 0xda, 0x71, 0x40, 0x47, 0x83, 0x90, 0x78, 0x51, 0x20, 0x44, 0xc6, 0xe4, 0x60,
		0x60, 0x87, 0xfb, 0xe7, 0x24, 0x88, 0x4c, 0xf8, 0xd4, 0x19, 0xbf, 0xb2, 0xbf, 0xfb, 0xdd, 0x84,
		0x8f, 0x15, 0xe6, 0xdb, 0xb3, 0xff, 0x54, 0x6f, 0x48, 0x8c, 0x98, 0x7f, 0x16, 0x89, 0x88, 0x19,
		0x64, 0xff, 0x9d, 0x41, 0xe8, 0x07, 0x42, 0xc2, 0x5b, 0x39, 0xc0, 0x81, 0xa8, 0x7e, 0x76, 0x7a,
		0x6e, 0xc4, 0xa0, 0x8a, 0x80, 0xe8, 0x1c, 0xa2, 0xd5, 0xec, 0x58, 0x6f, 0x57, 0xe4, 0x4c, 0x53,
		0x0e, 0x5f, 0xeb, 0x44, 0x6e, 0x23, 0x70, 0x27, 0x46, 0x98, 0x3f, 0x21, 0x22, 0x84, 0x61, 0xf6,
		0xdf, 0xf9, 0x5f, 0x62, 0x84, 0xe9, 0xaf, 0x88, 0xbf, 0x3e, 0x0d, 0xef, 0x98, 0x6d, 0x04, 0xc8,
		0xb6, 0x6d, 0xde, 0x1a, 0x4f, 0x8c, 0x88, 0xaa, 0x8e, 0x1b, 0xdd, 0x9b, 0x11, 0x55, 0xe3, 0xe3,
		0x41, 0x7b, 0x27, 0x97, 0x67, 0xbd, 0xb6, 0x67, 0x04, 0x66, 0x1d, 0x3f, 0x84, 0xcc, 0xa3, 0xdc,
		0x0c, 0x2b, 0x1b, 0xd6, 0xf7, 0x2f, 0x86, 0xa1, 0xe8, 0xc5, 0xc5, 0x39, 0xe4, 0xb1, 0xb3, 0x64,
		0x4b, 0xe4, 0x66, 0xdc, 0xdc, 0x16, 0xef, 0x8e, 0xa8, 0xac, 0x4f, 0x0e, 0xb9, 0x37, 0x0b, 0x68,
		0xe8, 0x12, 0xcf, 0x88, 0x50, 0x36, 0x3f, 0x3c, 0x6f, 0x54, 0x42, 0x1b, 0xd2, 0xd1, 0xc4, 0x25,
		0x61, 0xfd, 0xb0, 0xd1, 0x30, 0x8a, 0x90, 0x13, 0x3f, 0x6a, 0x9a, 0xc7, 0x18, 0x13, 0xfb, 0xf6,
		0xb4, 0x6f, 0x44, 0xe2, 0xc0, 0x84, 0xf5, 0x83, 0x73, 0xf8, 0xd6, 0x9b, 0xf1, 0xce, 0x41, 0x2d,
		0x20, 0xe1, 0xc9, 0xad, 0x48, 0x9d, 0x55, 0x4e, 0xa4, 0x67, 0xf7, 0x8e, 0x86, 0x67, 0x12, 0xdb,
		0xc8, 0x39, 0x44, 0x65, 0x12, 0xf1, 0x98, 0xb2, 0x3f, 0xfb, 0xd3, 0x88, 0x51, 0x16, 0xab, 0x95,
		0xc8, 0xfe, 0x43, 0x17, 0x2a, 0x7b, 0x3b, 0x17, 0x37, 0x8c, 0x9b, 0x04, 0x7e, 0x4f, 0xb9, 0x11,
		0xbb, 0x21, 0x7c, 0x62, 0x0a, 0xa7, 0xe8, 0xfa, 0x53, 0xdc, 0x40, 0x5c, 0x33, 0xb8, 0x5a, 0x1a,
		0x19, 0xc4, 0x2d, 0x49, 0x15, 0xd6, 0xe7, 0xc2, 0x86, 0x72, 0xea, 0x7b, 0x87, 0x35, 0x53, 0x7c,
		0xc2, 0x2d, 0x0b, 0x02, 0x26, 0x51, 0x3e, 0x91, 0x63, 0x38, 0x33, 0x02, 0x3b, 0x0e, 0xed, 0xfa,
		0xae, 0x88, 0xfe, 0x64, 0x0e, 0x1b, 0x4e, 0x47, 0x47, 0x87, 0x66, 0x50, 0x8e, 0xae, 0x19, 0xec,
		0xf8, 0x32, 0xd9, 0x91, 0xd1, 0x2e, 0xcb, 0x6b, 0x6b, 0xdf, 0xb3, 0x89, 0x11, 0xdb, 0x4f, 0x63,
		0xea, 0x30, 0x72, 0x41, 0x98, 0x2b, 0x7a, 0xa8, 0x38, 0x87, 0xc8, 0x16, 0x9a, 0x31, 0xb4, 0x33,
		0x51, 0x28, 0xf1, 0x9b, 0xcc, 0x72, 0x00, 0xb8, 0xf3, 0x0a, 0xba, 0xbd, 0x5d, 0x23, 0x1c, 0x6e,
		0xb8, 0x53, 0xdb, 0xb9, 0x14, 0x11, 0xf6, 0xcd, 0x01, 0xd7, 0xac, 0x5d, 0xe4, 0x6a, 0x44, 0x90,
		0x70, 0x49, 0xe0, 0x18, 0xe3, 0x6d, 0xcf, 0x3e, 0x9d, 0xb6, 0x9a, 0x9d, 0xa6, 0x11, 0xd9, 0xc3,
		0xe3, 0x80, 0x26, 0x7a, 0x0e, 0x2b, 0x0f, 0xaf, 0x6b, 0x1b, 0xb2, 0x8b, 0xb2, 0xb8, 0xc9, 0xda,
		0x2c, 0xd8, 0x30, 0x0e, 0x8c, 0x00, 0x65, 0xb7, 0xce, 0xad, 0x31, 0x64, 0xb9, 0x19, 0x55, 0x35,
		0x23, 0x36, 0x22, 0x37, 0x6c, 0x96, 0x92, 0x19, 0x62, 0x61, 0x41, 0x30, 0xd3, 0x41, 0x77, 0x99,
		0xf7, 0xdd, 0x9c, 0xbd, 0xca, 0xc7, 0xe2, 0xce, 0x9f, 0xc4, 0x6e, 0xbb, 0xc9, 0x81, 0xc6, 0x0b,
		0x6b, 0xb5, 0x43, 0x13, 0x3e, 0xf4, 0x66, 0x14, 0x04, 0xbe, 0xcb, 0xec, 0x07, 0x62, 0xdb, 0xfe,
		0xc4, 0xe3, 0xcc, 0x1b, 0x19, 0x03, 0xd3, 0xa3, 0x81, 0x23, 0x22, 0xc3, 0x97, 0xc3, 0x20, 0x33,
		0x1e, 0x99, 0x51, 0x2b, 0x68, 0x04, 0x69, 0xc3, 0x84, 0xd4, 0x3a, 0x72, 0x98, 0xf6, 0x90, 0x39,
		0x23, 0x23, 0xbc, 0x6c, 0xe0, 0x7b, 0xfb, 0x66, 0xe0, 0x83, 0x5b, 0x7f, 0x4c, 0x03, 0xcf, 0x08,
		0xab, 0xbf, 0xbf, 0x27, 0x5e, 0xaf, 0x67, 0xc8, 0x01, 0x0c, 0x73, 0x48, 0xba, 0xe3, 0xbe, 0x29,
		0x3b, 0x39, 0xe7, 0x3d, 0x33, 0xa0, 0x0a, 0xf1, 0xa2, 0xe0, 0x37, 0xc7, 0x0c, 0x7e, 0x99, 0x46,
		0xb6, 0xef, 0x99, 0x51, 0x94, 0x72, 0xe6, 0x87, 0xf7, 0x24, 0x34, 0x82, 0x90, 0x21, 0x43, 0x97,
		0x78, 0xf4, 0xb0, 0xd6, 0xd8, 0x33, 0x82, 0x8e, 0x61, 0x91, 0xed, 0xb7, 0xfb, 0xe7, 0x62, 0xb7,
		0x21, 0xe5, 0x41, 0x1f, 0x05, 0xf7, 0x24, 0xf8, 0x83, 0x07, 0xf3, 0x53, 0x6e, 0x97, 0xc4, 0x61,
		0xbe, 0x11, 0xf4, 0x06, 0xf3, 0x7f, 0x98, 0xb1, 0x24, 0xc2, 0xc0, 0x8c, 0xb3, 0xae, 0x37, 0xfe,
		0x8f, 0x85, 0xb0, 0xbe, 0x09, 0xdf, 0x1b, 0x8b, 0xef, 0x4a, 0x8b, 0x09, 0xe7, 0x12, 0x7d, 0x3f,
		0x99, 0x73, 0x46, 0x27, 0x72, 0x59, 0x60, 0x08, 0x4c, 0x3c, 0x9b, 0x98, 0x51, 0x92, 0xb2, 0xa8,
		0xfa, 0x1a, 0xf8, 0xdf, 0xa9, 0x77, 0x69, 0x08, 0xa9, 0xc1, 0x86, 0xd6, 0x28, 0x32, 0xa3, 0x28,
		0x74, 0x7c, 0x4f, 0x42, 0x3a, 0x0f, 0x67, 0x1d, 0x66, 0x1b, 0x73, 0x12, 0xce, 0x88, 0x58, 0x16,
		0x35, 0x76, 0x1a, 0x86, 0x29, 0x4d, 0x0c, 0x0d, 0xf1, 0x5f, 0xc6, 0x40, 0xaf, 0x68, 0xec, 0x44,
		0x42, 0x2a, 0x45, 0x39, 0xec, 0x85, 0xf0, 0xc0, 0x94, 0x52, 0xaf, 0xba, 0x39, 0x9b, 0xb6, 0x3d,
		0x43, 0xce, 0xec, 0xde, 0x46, 0x91, 0x11, 0xab, 0x34, 0x0a, 0x8d, 0x58, 0xa5, 0x3e, 0xf7, 0xba,
		0x7c, 0x62, 0x0e, 0xbd, 0x69, 0x44, 0xa0, 0x9a, 0xb8, 0x3c, 0x24, 0x66, 0xb0, 0xdb, 0x11, 0x17,
		0xba, 0x6f, 0x3b, 0xb7, 0xa2, 0xef, 0xba, 0x31, 0x45, 0xdf, 0x77, 0x3b, 0x46, 0x30, 0x19, 0x63,
		0x62, 0xf7, 0xa9, 0x7d, 0xe2, 0x7b, 0x3c, 0xf4, 0x5d, 0x97, 0x3a, 0xed, 0x33, 0x93, 0xf2, 0xad,
		0x33, 0x76, 0x63, 0x46, 0xd5, 0xe4, 0xd4, 0xcf, 0x3a, 0x46, 0xf8, 0xd9, 0xd1, 0x90, 0x44, 0xdc,
		0x94, 0x42, 0xd4, 0xfa, 0xce, 0x91, 0x11, 0x65, 0xa8, 0x8e, 0xe3, 0xfd, 0x69, 0x06, 0xb3, 0x69,
		0x06, 0x35, 0xc4, 0x22, 0xc7, 0x33, 0x85, 0x04, 0x30, 0xc8, 0x9f, 0xee, 0xc6, 0xfc, 0xd5, 0xf1,
		0x24, 0x32, 0xe8, 0x9b, 0x1b, 0x86, 0x9c, 0x54, 0x89, 0x0f, 0x81, 0x19, 0xb1, 0x66, 0xa3, 0x07,
		0xcf, 0x36, 0xe7, 0xec, 0x84, 0x59, 0x15, 0xbc, 0xbe, 0x29, 0x87, 0xea, 0x66, 0x35, 0xf3, 0x7f,
		0x76, 0x8d, 0x38, 0xad, 0x68, 0xb3, 0xe0, 0x9c, 0x79, 0xdf, 0x8d, 0xd9, 0xe2, 0x32, 0xe2, 0x70,
		0xc7, 0x0e, 0x0b, 0x7e, 0x98, 0xb2, 0xe5, 0x1d, 0xb1, 0xa0, 0xcf, 0xcc, 0xa8, 0x24, 0x8d, 0x6a,
		0x06, 0x69, 0x36, 0xb5, 0x83, 0xa6, 0xe3, 0x84, 0x86, 0xec, 0x1e, 0x4f, 0x57, 0xac, 0x29, 0x0b,
		0x76, 0x18, 0x1a, 0x54, 0xae, 0x43, 0x6d, 0x53, 0x9c, 0xd6, 0x5c, 0xd0, 0xe0, 0xdc, 0x1f, 0x31,
		0x9b, 0xb8, 0xa6, 0xc4, 0x84, 0x20, 0xf4, 0x83, 0x13, 0xcf, 0x35, 0x03, 0x75, 0x1b, 0x62, 0x60,
		0x63, 0xdf, 0x26, 0x5f, 0x68, 0x18, 0x31, 0xdf, 0x33, 0x62, 0x17, 0xc6, 0xbe, 0x71, 0xbf, 0x50,
		0x9b, 0x93, 0x3e, 0x27, 0xa1, 0x21, 0x25, 0xdc, 0xf5, 0x3d, 0x33, 0xca, 0xf7, 0xfc, 0xe1, 0x90,
		0x1a, 0x51, 0x16, 0x1f, 0x12, 0x87, 0xf9, 0x17, 0xcd, 0x13, 0x23, 0x82, 0xed, 0xd8, 0x18, 0xe5,
		0xec, 0x9e, 0xcf, 0x3c, 0x3e, 0xf0, 0xe3, 0x7f, 0xf5, 0x69, 0xc8, 0xcc, 0xd0, 0xfd, 0x9f, 0x7e,
		0xb9, 0x41, 0xd7, 0x14, 0x0c, 0xd9, 0x4d, 0x48, 0x0d, 0x2a, 0xd9, 0x73, 0xa2, 0x9a, 0x39, 0xa7,
		0x12, 0x97, 0xf5, 0xd2, 0x3b, 0x66, 0x24, 0x63, 0x3f, 0x06, 0xfe, 0x99, 0x3f, 0x09, 0x0d, 0xc9,
		0x1c, 0xcd, 0x10, 0xa6, 0x0d, 0xcc, 0x38, 0x34, 0x13, 0xf8, 0x91, 0x39, 0xdb, 0x9e, 0x9f, 0x3d,
		0xdb, 0xb0, 0x8d, 0x4f, 0x6e, 0xc8, 0xb9, 0x99, 0xf9, 0xdd, 0x45, 0x67, 0x9f, 0x4e, 0x8d, 0xf0,
		0xaf, 0x36, 0xa7, 0x2e, 0x8b, 0x2e, 0x28, 0x27, 0xe7, 0xdd, 0x6e, 0xcf, 0x2c, 0xb1, 0xfd, 0x58,
		0x58, 0xce, 0xf6, 0x3d, 0x8f, 0xda, 0x46, 0xe4, 0xe8, 0xd1, 0xad, 0x21, 0x9b, 0x62, 0x61, 0x14,
		0xde, 0x98, 0xb1, 0x65, 0xdb, 0xbd, 0xa3, 0xa1, 0x29, 0xf7, 0xc3, 0x2c, 0xef, 0x55, 0x3d, 0x19,
		0xf3, 0xc8, 0xac, 0xcd, 0x9b, 0x1f, 0x8d, 0xfa, 0x8e, 0x49, 0x7a, 0x47, 0xdd, 0xbe, 0x21, 0x17,
		0xf2, 0xdd, 0x4e, 0x3c, 0x6e, 0x8c, 0xd6, 0xc6, 0x78, 0xd8, 0x67, 0x23, 0x53, 0xa8, 0x45, 0xc7,
		0xf6, 0x4c, 0xd1, 0x1b, 0x35, 0x25, 0x29, 0x3f, 0xf5, 0xed, 0x68, 0x71, 0xa8, 0x4e, 0xfc, 0x72,
		0xe8, 0x1c, 0xd6, 0xed, 0x9d, 0x19, 0xa5, 0x28, 0xc3, 0x2f, 0x43, 0x36, 0x78, 0x08, 0xa8, 0x19,
		0x82, 0x5c, 0x6e, 0x34, 0x30, 0x46, 0x42, 0x7b, 0xa9, 0xad, 0x1f, 0x07, 0x60, 0x33, 0xec, 0x8d,
		0x8d, 0x49, 0xf8, 0xd0, 0xee, 0x9f, 0x76, 0x4c, 0xd2, 0xc6, 0xdc, 0xff, 0xe3, 0xa2, 0x69, 0xc4,
		0x07, 0x8f, 0x23, 0x43, 0xb0, 0xf8, 0xec, 0x04, 0x60, 0x87, 0xd9, 0x03, 0x43, 0xb0, 0xe2, 0x42,
		0x60, 0x90, 0x98, 0x74, 0x0b, 0x4b, 0xc4, 0x89, 0xfd, 0x7d, 0xe0, 0xf7, 0xa7, 0xff, 0x32, 0x4d,
		0x31, 0xb5, 0x6e, 0x4e, 0xaa, 0x76, 0x62, 0x08, 0x89, 0xe3, 0xdc, 0xdd, 0x34, 0x23, 0xd6, 0x9d,
		0x18, 0x01, 0xcd, 0x38, 0x35, 0x05, 0x93, 0xc7, 0x61, 0xf8, 0xb4, 0x7d, 0x6a, 0xc6, 0x69, 0x80,
		0xc0, 0x1c, 0xc9, 0x93, 0x53, 0x9f, 0xd7, 0xeb, 0xbd, 0xd0, 0x1f, 0x32, 0x33, 0xd0, 0x8d, 0xc3,
		0x46, 0x8c, 0x13, 0xb7, 0xe7, 0xdf, 0xd3, 0xd0, 0x65, 0x9e, 0x31, 0x88, 0xd7, 0x1c, 0xc5, 0x46,
		0x93, 0x84, 0xd5, 0xc3, 0xa1, 0x7d, 0x78, 0x70, 0x60, 0x88, 0x00, 0x8e, 0x29, 0xb8, 0x91, 0xf0,
		0xf1, 0x17, 0x9b, 0xb5, 0x3c, 0xa7, 0xc7, 0xcd, 0xa8, 0x55, 0x19, 0x07, 0x7e, 0xc4, 0xcc, 0x89,
		0x65, 0x11, 0x0b, 0x4c, 0xe4, 0x6d, 0x4c, 0x02, 0xe5, 0xcb, 0xac, 0xdd, 0x10, 0x86, 0x9f, 0xd4,
		0x1b, 0x17, 0x81, 0x41, 0x57, 0x24, 0x46, 0x8e, 0xcd, 0x8c, 0xda, 0x39, 0xe9, 0xdb, 0x9c, 0xee,
		0xed, 0x39, 0x8d, 0xcf, 0x51, 0xd7, 0xbf, 0x31, 0xa4, 0xae, 0xcd, 0x8c, 0x68, 0x31, 0x0a, 0xcc,
		0x10, 0x7b, 0xbc, 0x21, 0x11, 0xb3, 0x4d, 0x21, 0xc5, 0xd6, 0xb0, 0xf9, 0xb1, 0x19, 0x07, 0x09,
		0xee, 0x76, 0xf6, 0xcd, 0x38, 0x4a, 0x34, 0xe4, 0xf7, 0x24, 0xa4, 0xe7, 0xbe, 0x1f, 0xdc, 0x18,
		0xc2, 0xd8, 0xd8, 0x9e, 0x51, 0x97, 0x1c, 0xd5, 0x0d, 0xc1, 0xb8, 0x37, 0xbe, 0x67, 0xc4, 0x49,
		0x92, 0x69, 0x96, 0x3b, 0x32, 0x65, 0xa3, 0x77, 0x7e, 0x04, 0xd2, 0x88, 0x4d, 0xf4, 0x3b, 0x33,
		0x96, 0x6a, 0x14, 0x1d, 0x18, 0xb4, 0x79, 0xbe, 0xb8, 0x7c, 0xf8, 0x24, 0x1a, 0x13, 0xdb, 0x31,
		0xa4, 0x96, 0x62, 0xec, 0x06, 0x86, 0x5c, 0x0f, 0x63, 0xc6, 0x31, 0x22, 0x87, 0x8e, 0x4d, 0x91,
		0x9b, 0xdb, 0x31, 0xe6, 0x46, 0xbe, 0xb6, 0x19, 0x37, 0xf2, 0xcd, 0x8f, 0x13, 0x9a, 0xb1, 0xfd,
		0x11, 0x8e, 0xcd, 0x91, 0xf2, 0x9a, 0x5d, 0x0d, 0x15, 0xb8, 0xf4, 0x87, 0x6f, 0x04, 0x1e, 0x74,
		0x1b, 0xa6, 0x1c, 0x2c, 0x66, 0xde, 0x90, 0x79, 0xec, 0x86, 0x98, 0x81, 0x07, 0x09, 0x1f, 0xcf,
		0xcf, 0xea, 0x1a, 0x94, 0x15, 0xec, 0x10, 0xe7, 0x9c, 0x8c, 0xcc, 0xbb, 0xcd, 0xcc, 0x44, 0xa2,
		0xd6, 0xac, 0x02, 0x61, 0x16, 0x39, 0x66, 0x48, 0xc0, 0x4f, 0x22, 0x83, 0x2a, 0xdb, 0x4f, 0x5c,
		0x72, 0x6f, 0x22, 0x41, 0x5b, 0x3f, 0xbb, 0x77, 0x0c, 0x61, 0x68, 0xef, 0x4c, 0xb9, 0xe2, 0x2c,
		0x32, 0x48, 0x99, 0xca, 0xa4, 0x4d, 0xa6, 0xb9, 0x98, 0xda, 0xfe, 0x85, 0x29, 0xf2, 0x29, 0x8b,
		0xd3, 0x4f, 0x17, 0xbd, 0xb6, 0x11, 0x40, 0x87, 0xb8, 0x7b, 0xa6, 0xc4, 0xdf, 0x45, 0xec, 0xed,
		0x35, 0x7a, 0x66, 0xec, 0xdf, 0x19, 0x53, 0x4d, 0x37, 0x70, 0xc6, 0x46, 0xee, 0x34, 0x9e, 0x9a,
		0xb2, 0xd3, 0x48, 0xf8, 0xb8, 0x6d, 0xc6, 0x1d, 0xad, 0x6c, 0xd8, 0xbb, 0x37, 0xe5, 0x94, 0x83,
		0x13, 0xd5, 0x8d, 0x91, 0xd6, 0xeb, 0x11, 0x7e, 0x6b, 0xca, 0x85, 0x1b, 0x6d, 0xdb, 0x10, 0xb5,
		0x5d, 0x8f, 0xd3, 0xd0, 0xa5, 0xe4, 0xce, 0xa4, 0xaa, 0xca, 0x3f, 0x42, 0x12, 0x04, 0x34, 0x34,
		0xf0, 0x36, 0xb1, 0x78, 0x1d, 0x7f, 0x19, 0x18, 0x55, 0x9b, 0xd4, 0x36, 0xa6, 0x0c, 0xec, 0xf8,
		0x8f, 0x66, 0xd0, 0xb8, 0x30, 0xe3, 0x73, 0xcd, 0x70, 0x0f, 0xd4, 0x90, 0x1b, 0x52, 0xc7, 0x46,
		0x94, 0x80, 0xfe, 0xb7, 0x71, 0xb4, 0x63, 0x44, 0xb8, 0xf5, 0x0c, 0xa9, 0xfd, 0xa4, 0x81, 0x1b,
		0x46, 0xe6, 0x1c, 0xb7, 0x69, 0x7b, 0x06, 0xdd, 0x78, 0xd9, 0xbb, 0x7d, 0x88, 0x98, 0x4d, 0xdc,
		0xcf, 0x66, 0x5c, 0xd3, 0x38, 0x24, 0x11, 0x37, 0x84, 0xe9, 0xba, 0x7d, 0x08, 0x68, 0x68, 0x9b,
		0x03, 0x5a, 0x86, 0x8e, 0x63, 0xc4, 0x12, 0x70, 0x49, 0x30, 0x34, 0xe4, 0x28, 0x66, 0x78, 0x6e,
		0x06, 0x19, 0x77, 0xbb, 0xd3, 0xd8, 0xf9, 0x44, 0x38, 0xfd, 0x4e, 0x69, 0x60, 0xc6, 0x51, 0x9b,
		0x25, 0xc1, 0xb1, 0xa0, 0x68, 0x2f, 0x87, 0x3d, 0x3f, 0xe4, 0x86, 0xac, 0x5f, 0x23, 0x98, 0x98,
		0xd1, 0x41, 0x6d, 0x87, 0xf0, 0xc6, 0xf8, 0xc6, 0xc8, 0x9d, 0x9b, 0x4b, 0xca, 0x0d, 0x61, 0xbc,
		0x58, 0xe4, 0x78, 0x91, 0x91, 0x36, 0x67, 0x50, 0x46, 0x7e, 0x6b, 0xca, 0x5d, 0xbe, 0xc3, 0xf0,
		0xd4, 0x35, 0xe8, 0xb8, 0xdb, 0x6a, 0x1b, 0xc7, 0x2c, 0xe9, 0x32, 0x83, 0x54, 0x7f, 0xee, 0x76,
		0x0e, 0x8c, 0x48, 0xd2, 0x4c, 0xa9, 0xb4, 0x37, 0xe4, 0x92, 0x64, 0xc2, 0xc7, 0xfd, 0xc9, 0x4d,
		0x2c, 0x0d, 0x39, 0x24, 0x36, 0x35, 0xe9, 0xcc, 0x45, 0xc3, 0x8c, 0x88, 0x60, 0xc6, 0xa6, 0x63,
		0x40, 0x84, 0x6e, 0xa2, 0x4d, 0xf5, 0xc4, 0xd5, 0x3b, 0xb5, 0xed, 0xbe, 0xfd, 0xb7, 0x5e, 0xff,
		0x1b, 0x6f, 0x8c, 0x72, 0xb5, 0xf5, 0x83, 0x47, 0xd5, 0x8f, 0x95, 0xaf, 0xef, 0xd4, 0x8c, 0x7d,
		0xf5, 0x77, 0xfa, 0x70, 0xef, 0x87, 0x4e, 0x5c, 0x70, 0x67, 0x5b, 0xf4, 0x07, 0xff, 0xc8, 0xa9,
		0x4b, 0xc7, 0x94, 0x87, 0x0f, 0x96, 0xef, 0x59, 0xd3, 0x24, 0x7e, 0x44, 0xab, 0xc9, 0xa6, 0xbe,
		0xfa, 0x1b, 0x89, 0x9a, 0xe1, 0x68, 0x32, 0xa6, 0x1e, 0xaf, 0x7e, 0xac, 0x0c, 0x89, 0x1b, 0xd1,
		0x84, 0x4f, 0xae, 0x3d, 0x56, 0xad, 0x4a, 0x0e, 0xe1, 0xd5, 0x1b, 0x43, 0xd8, 0x9c, 0x8c, 0xa6,
		0xaf, 0xa2, 0x8e, 0xca, 0x71, 0x5c, 0xac, 0xd9, 0x0f, 0xbe, 0x6d, 0xb1, 0xe1, 0x47, 0xb6, 0x70,
		0x5e, 0xd1, 0xd3, 0x5f, 0xcc, 0xff, 0x6c, 0xfb, 0xde, 0x90, 0x8d, 0x92, 0x0e, 0xec, 0x29, 0x8d,
		0xec, 0x90, 0x05, 0x9c, 0xf9, 0xde, 0xf4, 0x25, 0x4d, 0xc7, 0x89, 0x2a, 0x83, 0x5e, 0xfb, 0xb4,
		0xf2, 0xa1, 0x12, 0x9f, 0xf3, 0xe0, 0x0f, 0x01, 0xad, 0x44, 0x94, 0x73, 0xe6, 0x8d, 0x2a, 0x43,
		0x3f, 0xac, 0xf0, 0x5b, 0x5a, 0xb9, 0x21, 0x11, 0xad, 0x2c, 0xdf, 0x9b, 0xf4, 0x55, 0xbf, 0x33,
		0x6f, 0x3a, 0x30, 0xf5, 0x84, 0x7f, 0xfd, 0x64, 0xd6, 0x8f, 0x8f, 0x95, 0x5a, 0xc2, 0x07, 0x7a,
		0x21, 0x1d, 0xb2, 0x1f, 0xd5, 0x8f, 0x29, 0x9c, 0xc3, 0xaa, 0x24, 0xd4, 0xb6, 0xe2, 0x52, 0xe6,
		0xe4, 0x9e, 0xa8, 0xda, 0xf7, 0x27, 0xa1, 0x4d, 0x53, 0xbd, 0xee, 0xa9, 0x5d, 0x04, 0xb3, 0x2f,
		0x4e, 0xe7, 0xfe, 0x9e, 0xd8, 0x02, 0x0f, 0x27, 0x34, 0x65, 0x03, 0xeb, 0x26, 0xb1, 0xe8, 0xb8,
		0x6a, 0x67, 0x95, 0x74, 0xf9, 0xb1, 0x30, 0xdd, 0x84, 0xf1, 0x80, 0x39, 0xe9, 0xc7, 0x7c, 0x79,
		0x1c, 0x60, 0xfa, 0x74, 0xca, 0xd1, 0x7a, 0x62, 0x21, 0xdd, 0xf8, 0x27, 0xe2, 0xba, 0x0f, 0x53,
		0xb3, 0x88, 0xcd, 0x81, 0x93, 0x51, 0x25, 0x08, 0x7d, 0xee, 0xdb, 0xbe, 0x5b, 0x61, 0x0e, 0xf5,
		0x38, 0x1b, 0x32, 0x1a, 0x56, 0x86, 0x8c, 0xba, 0x4e, 0xe5, 0xdf, 0x53, 0x73, 0xfa, 0xa5, 0xc2,
		0x6f, 0x09, 0xff, 0xe6, 0xb1, 0xa8, 0x42, 0x6c, 0x9b, 0x06, 0x9c, 0x3a, 0x15, 0xdf, 0x8b, 0x9f,
		0xfe, 0x72, 0xde, 0xec, 0xa4, 0xff, 0xa6, 0x21, 0x99, 0xb8, 0xeb, 0x13, 0x68, 0x4d, 0x0d, 0x35,
		0xfa, 0x38, 0x7d, 0xd7, 0x75, 0xed, 0xcf, 0xc3, 0x7a, 0xad, 0x96, 0xb6, 0xcd, 0xb9, 0x79, 0xd6,
		0x52, 0x3e, 0x96, 0xd6, 0x4c, 0x65, 0xcc, 0x55, 0x81, 0xd9, 0xca, 0x9a, 0xaf, 0x32, 0x33, 0x56,
		0x66, 0xce, 0x6a, 0xcc, 0x5a, 0x0c, 0xe3, 0xa4, 0x44, 0x6e, 0xd5, 0xb8, 0xb4, 0x47, 0x6a, 0xc6,
		0x67, 0xe6, 0xc5, 0x1f, 0x42, 0x3a, 0x14, 0x99, 0xf5, 0x45, 0x0c, 0xda, 0x13, 0x78, 0xb6, 0x3d,
		0x7f, 0xf5, 0x31, 0x89, 0x24, 0xd6, 0xcd, 0xa2, 0x23, 0xb1, 0xa5, 0x0e, 0xfe, 0xea, 0xb5, 0xfa,
		0xa2, 0x0b, 0xe7, 0x0b, 0x71, 0x27, 0x34, 0x19, 0x64, 0x53, 0x0b, 0xa3, 0x9f, 0xef, 0x4b, 0xed,
		0xcf, 0xa3, 0xa9, 0xd7, 0x11, 0x6e, 0xf1, 0xe7, 0xaf, 0x45, 0xe9, 0x46, 0xa3, 0x14, 0xdd, 0x38,
		0x3c, 0x6c, 0x1e, 0x96, 0xa1, 0x1b, 0x65, 0x58, 0x54, 0xcd, 0xce, 0x5f, 0x12, 0x7d, 0x10, 0x7a,
		0xf2, 0x4a, 0xb7, 0xeb, 0x2f, 0x58, 0x7a, 0xfb, 0x66, 0x6e, 0xe6, 0x79, 0x3e, 0x27, 0x73, 0x14,
		0xf7, 0xf6, 0xdc, 0x56, 0x23, 0xfb, 0x96, 0x8e, 0x49, 0x40, 0xf8, 0xed, 0x2c, 0xf9, 0x0a, 0xa8,
		0x37, 0xcb, 0xac, 0xac, 0xb5, 0x0c, 0xec, 0xb9, 0x1f, 0x3f, 0xcc, 0x13, 0xb0, 0x77, 0x62, 0x7d,
		0x79, 0x65, 0xc5, 0x2e, 0x4f, 0xde, 0xbf, 0xd9, 0x83, 0x8d, 0xb3, 0xfa, 0x6f, 0xc4, 0x98, 0x84,
		0xb9, 0x59, 0x62, 0xb0, 0x97, 0x06, 0xdc, 0xad, 0x83, 0x39, 0xca, 0x6f, 0x13, 0x44, 0xc3, 0xb4,
		0xd8, 0x4d, 0x18, 0xab, 0x09, 0x63, 0xb3, 0xa7, 0x58, 0x8c, 0x26, 0xa9, 0xbe, 0x95, 0xa3, 0x6f,
		0x92, 0x66, 0x52, 0x55, 0x7b, 0x31, 0x87, 0x29, 0xf9, 0x87, 0x74, 0xbc, 0x42, 0xc1, 0x93, 0xfd,
		0x64, 0x0b, 0xad, 0x7c, 0xb9, 0x3e, 0x4d, 0x53, 0x06, 0x9e, 0x73, 0xaa, 0x4f, 0x46, 0xa3, 0x90,
		0x8e, 0x08, 0xa7, 0x96, 0x4c, 0xca, 0xff, 0xa8, 0x95, 0xed, 0x48, 0x89, 0x5d, 0x32, 0x42, 0x46,
		0xfc, 0xcc, 0xe2, 0x77, 0x85, 0x8e, 0xa7, 0x17, 0x3c, 0x21, 0x76, 0x29, 0x19, 0x4a, 0x26, 0xc3,
		0x07, 0x02, 0xcf, 0xf6, 0x96, 0xc0, 0x28, 0x19, 0x2b, 0xed, 0x4d, 0x3f, 0x57, 0x17, 0xc0, 0x4c,
		0xe1, 0xc9, 0xc9, 0x84, 0xfb, 0x96, 0x47, 0x47, 0x3e, 0x67, 0x84, 0x53, 0x09, 0xb7, 0xf2, 0xb8,
		0x1d, 0x71, 0xfe, 0x6e, 0xba, 0xbc, 0xb7, 0xc4, 0x2f, 0xa5, 0x0b, 0xba, 0xdb, 0xe3, 0x97, 0xa8,
		0xd0, 0xd9, 0xac, 0x82, 0xfb, 0xa5, 0x1b, 0xdf, 0x77, 0xa9, 0x18, 0x35, 0xbb, 0xf0, 0x4b, 0xf5,
		0x02, 0xf8, 0x0b, 0x67, 0x12, 0xb8, 0xf4, 0x87, 0x35, 0xf6, 0x1d, 0x09, 0x67, 0xb1, 0xde, 0x08,
		0x4c, 0x1d, 0xa6, 0x5e, 0x32, 0x53, 0xa7, 0xde, 0x64, 0x4c, 0xc3, 0x19, 0xb7, 0x22, 0x61, 0xee,
		0xbb, 0x02, 0xcf, 0xb6, 0xbc, 0xc9, 0x78, 0xfa, 0xf1, 0x3f, 0x0b, 0xe0, 0x2a, 0xa8, 0x47, 0x6e,
		0x5c, 0x6a, 0x0d, 0x5d, 0xff, 0xde, 0x9a, 0x5f, 0xa0, 0x2c, 0xee, 0x32, 0x9e, 0x6b, 0x4c, 0x1c,
		0x64, 0xc4, 0x05, 0x13, 0x70, 0x3d, 0x70, 0x3d, 0x40, 0x19, 0x85, 0x44, 0x19, 0x63, 0x62, 0x5b,
		0xc4, 0x71, 0x42, 0x1a, 0x45, 0xe2, 0x2e, 0x63, 0xbd, 0x11, 0x98, 0x3a, 0x4c, 0xbd, 0x64, 0xa6,
		0x2e, 0xbe, 0xbc, 0x1f, 0x99, 0xfb, 0xa1, 0x18, 0xd9, 0xc1, 0x69, 0xe8, 0x09, 0x6f, 0xb5, 0x57,
		0xff, 0xf3, 0xb5, 0x66, 0x1d, 0x11, 0x6b, 0xd8, 0xb4, 0xce, 0xae, 0xfe, 0x6e, 0xfc, 0xfc, 0xf7,
		0xc7, 0xc7, 0x7f, 0xfe, 0xe5, 0xef, 0xbd, 0x9f, 0xff, 0x4a, 0x3f, 0x63, 0x57, 0x22, 0x5d, 0xe9,
		0xf6, 0xdb, 0x7f, 0x16, 0xb5, 0x3f, 0x05, 0xf0, 0xc4, 0x81, 0x1f, 0x72, 0x2b, 0x0a, 0x28, 0x95,
		0xa0, 0x9c, 0xd7, 0xda, 0x80, 0x1f, 0x86, 0x1f, 0x2e, 0x99, 0x1f, 0x2e, 0x4d, 0x05, 0x56, 0x6b,
		0xf0, 0x5b, 0xeb, 0xb2, 0xd3, 0x1a, 0x5c, 0xf7, 0x7b, 0xad, 0xd6, 0xa9, 0xf9, 0x55, 0x58, 0x71,
		0x37, 0xae, 0x0f, 0x6b, 0xb5, 0x4f, 0xc7, 0x26, 0x17, 0xcc, 0xcc, 0xba, 0xd1, 0xd8, 0x2b, 0x43,
		0x2f, 0xea, 0x25, 0x99, 0x8c, 0x72, 0x74, 0x63, 0xaf, 0x1c, 0x86, 0x51, 0xab, 0x5d, 0x94, 0xc2,
		0x34, 0xca, 0x61, 0xe0, 0x65, 0x98, 0x8b, 0xcf, 0x9d, 0xdf, 0x3b, 0xdd, 0x3f, 0x3a, 0x25, 0xb0,
		0xf0, 0x52, 0x2c, 0xaa, 0xdd, 0x72, 0xb8, 0xdb, 0xfd, 0x5a, 0x49, 0x66, 0xa3, 0x14, 0x8e, 0xaa,
		0x24, 0x70, 0x4a, 0xca, 0xdd, 0x6e, 0x47, 0x21, 0x75, 0xd2, 0x12, 0xd5, 0x54, 0x87, 0x55, 0xc5,
		0xe6, 0x33, 0xdd, 0xe1, 0x55, 0xca, 0x6f, 0x3f, 0x2e, 0x0a, 0x96, 0x17, 0x7f, 0x4e, 0x55, 0x75,
		0xba, 0x7c, 0xed, 0x73, 0xa7, 0x5a, 0xcf, 0x9b, 0x9f, 0x16, 0x07, 0x59, 0xa3, 0x0a, 0xf7, 0x2b,
		0xcc, 0x73, 0xd8, 0x1d, 0x73, 0x26, 0xc4, 0xad, 0xb4, 0xe6, 0x2f, 0x5d, 0x9d, 0x69, 0x15, 0x65,
		0xd0, 0xeb, 0x28, 0x15, 0x2c, 0x05, 0x73, 0x53, 0xc0, 0x52, 0xc1, 0xb4, 0xf5, 0xb3, 0xcb, 0x07,
		0xa5, 0xea, 0x68, 0x37, 0x16, 0x8d, 0x44, 0x3d, 0xed, 0x4b, 0xe6, 0xd9, 0x0f, 0xa8, 0xcd, 0x86,
		0x0f, 0xf1, 0x69, 0x58, 0x77, 0x76, 0xef, 0x51, 0x65, 0xf9, 0x9a, 0x95, 0x4d, 0x4e, 0x8d, 0xf6,
		0xfe, 0x96, 0xd9, 0xb7, 0xdf, 0x3c, 0x7e, 0xcb, 0xa2, 0xb5, 0xff, 0x70, 0x43, 0x5d, 0xdf, 0x1b,
		0x45, 0xa2, 0x9f, 0x23, 0xc6, 0xba, 0x4a, 0xdb, 0xb0, 0x0a, 0x5b, 0x56, 0x67, 0xd3, 0xaa, 0x6c,
		0x5b, 0xb9, 0x8d, 0x2b, 0xb7, 0x75, 0xa5, 0x36, 0x2f, 0x87, 0x2d, 0x04, 0x81, 0x95, 0x38, 0x8b,
		0xbb, 0xb1, 0x5e, 0xc4, 0xcb, 0x87, 0x37, 0x42, 0xdf, 0x81, 0x44, 0x1b, 0xfa, 0xcb, 0x89, 0xc5,
		0x27, 0x2a, 0x5f, 0x38, 0x77, 0x95, 0x14, 0xce, 0xa5, 0x3b, 0xdf, 0xb6, 0x7c, 0x4e, 0xfc, 0x9c,
		0xdb, 0x12, 0xaa, 0x25, 0x39, 0xf0, 0x96, 0xbc, 0xd3, 0x09, 0x6c, 0xa2, 0x1a, 0xf1, 0x34, 0xc5,
		0xdb, 0xeb, 0xea, 0xa1, 0x5c, 0xbb, 0x5c, 0x49, 0x03, 0x27, 0x98, 0x54, 0x7a, 0x6d, 0x9c, 0x60,
		0xc2, 0x09, 0x26, 0xa4, 0x25, 0x38, 0xc1, 0xa4, 0x1a, 0x7a, 0xe0, 0x04, 0x13, 0x4e, 0x30, 0x69,
		0x0e, 0xba, 0xdb, 0xe3, 0x97, 0x50, 0x5b, 0xfc, 0xbc, 0x5f, 0x2a, 0x42, 0x6d, 0xb1, 0xed, 0x4f,
		0xa6, 0x9e, 0x4c, 0xa2, 0xb0, 0x78, 0xd9, 0xc2, 0x76, 0x70, 0xa2, 0x30, 0x72, 0x63, 0x8c, 0x5c,
		0x98, 0x13, 0x65, 0x9e, 0x75, 0x58, 0x6b, 0xd4, 0xff, 0x6b, 0xc5, 0x5a, 0xdb, 0x91, 0x3c, 0x2d,
		0xfa, 0xb4, 0x41, 0x50, 0x91, 0xe2, 0xa6, 0x04, 0x2a, 0x52, 0xc8, 0xd4, 0x4c, 0xa7, 0x22, 0xe7,
		0x61, 0x66, 0x7f, 0x57, 0x01, 0x19, 0x79, 0x28, 0xd1, 0xc4, 0x65, 0x2c, 0x4c, 0x2c, 0x53, 0xd0,
		0x59, 0x91, 0xde, 0xf8, 0x8e, 0x3f, 0xe4, 0x82, 0x79, 0xd2, 0x6b, 0x5f, 0x91, 0x67, 0xd9, 0x68,
		0x2e, 0x2e, 0x7b, 0x55, 0xd8, 0xde, 0x59, 0x48, 0x6c, 0xce, 0x7c, 0xef, 0x94, 0x8d, 0x58, 0xac,
		0x43, 0x5d, 0x93, 0x6e, 0xf7, 0xe7, 0xaf, 0x0a, 0xa6, 0x80, 0xfc, 0x28, 0xfc, 0x14, 0xd4, 0x0f,
		0x77, 0x77, 0xf7, 0x0f, 0x76, 0x77, 0x6b, 0x07, 0x3b, 0x07, 0xb5, 0xa3, 0xbd, 0xbd, 0xfa, 0xbe,
		0x48, 0x71, 0x75, 0x66, 0xb3, 0xf2, 0x2e, 0x9f, 0xa7, 0xaf, 0xb2, 0xda, 0x2d, 0xf8, 0x55, 0x08,
		0x8d, 0xdc, 0xb8, 0xbe, 0xfd, 0xdd, 0xa2, 0x61, 0xe8, 0x87, 0x6a, 0xd0, 0xc8, 0xa3, 0x06, 0x81,
		0x46, 0x80, 0x46, 0x80, 0x46, 0x80, 0x46, 0x80, 0x46, 0x80, 0x46, 0x80, 0x46, 0x80, 0x46, 0xde,
		0x42, 0x23, 0x76, 0x68, 0xab, 0xc4, 0x22, 0x6b, 0xcd, 0x01, 0x89, 0x00, 0x89, 0x00, 0x89, 0x00,
		0x89, 0x00, 0x89, 0x00, 0x89, 0x00, 0x89, 0x00, 0x89, 0xbc, 0x85, 0x44, 0x86, 0x21, 0x89, 0x8f,
		0xa9, 0xa8, 0xdc, 0xa8, 0x79, 0xda, 0x26, 0x30, 0x09, 0x30, 0x09, 0x30, 0x09, 0x30, 0x09, 0x30,
		0x09, 0x30, 0x09, 0x30, 0x09, 0x30, 0xc9, 0x5b, 0x98, 0xe4, 0xff, 0x25, 0x37, 0x37, 0x34, 0x54,
		0x89, 0x48, 0x1e, 0xb7, 0x08, 0x3c, 0x02, 0x3c, 0x02, 0x3c, 0x02, 0x3c, 0x02, 0x3c, 0x02, 0x3c,
		0x02, 0x3c, 0x02, 0x3c, 0xf2, 0x16, 0x1e, 0x19, 0x13, 0x7b, 0xa1, 0x11, 0xaf, 0x12, 0x94, 0x3c,
		0xd3, 0x2c, 0x90, 0x09, 0x90, 0x09, 0x90, 0x09, 0x90, 0x09, 0x90, 0x09, 0x90, 0x09, 0x90, 0x09,
		0x90, 0x49, 0x12, 0x64, 0x12, 0x90, 0x49, 0x44, 0x55, 0xe3, 0x92, 0x47, 0x8d, 0x02, 0x95, 0x00,
		0x95, 0x00, 0x95, 0x00, 0x95, 0x00, 0x95, 0x00, 0x95, 0x00, 0x95, 0x00, 0x95, 0xbc, 0x85, 0x4a,
		0xfc, 0x3b, 0x1a, 0x46, 0xec, 0x7f, 0x95, 0x82, 0x92, 0xa7, 0x6d, 0x02, 0x93, 0x00, 0x93, 0x00,
		0x93, 0x00, 0x93, 0x00, 0x93, 0x00, 0x93, 0x00, 0x93, 0x00, 0x93, 0xbc, 0x85, 0x49, 0x26, 0x9e,
		0xa3, 0x1e, 0x94, 0x6c, 0x34, 0x0a, 0x54, 0x02, 0x54, 0x02, 0x54, 0x02, 0x54, 0x02, 0x54, 0x02,
		0x54, 0x02, 0x54, 0x02, 0x54, 0xf2, 0xea, 0x30, 0xfb, 0x13, 0xae, 0x58, 0x24, 0x6d, 0xa3, 0x45,
		0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x91,
		0x37, 0xf1, 0x88, 0x8e, 0x52, 0xd7, 0x17, 0xda, 0x05, 0x36, 0x01, 0x36, 0x01, 0x36, 0x01, 0x36,
		0x01, 0x36, 0x01, 0x36, 0x01, 0x36, 0x01, 0x36, 0x49, 0x84, 0x4d, 0xd4, 0x16, 0xbb, 0x3e, 0xdb,
		0x2a, 0x70, 0x09, 0x70, 0x09, 0x70, 0x09, 0x70, 0x09, 0x70, 0x09, 0x70, 0x09, 0x70, 0xc9, 0x36,
		0xe1, 0x12, 0xad, 0x57, 0xe9, 0x08, 0xde, 0x1f, 0xbb, 0x7c, 0x5e, 0xc1, 0x3d, 0xb2, 0xf1, 0xf5,
		0xac, 0x1f, 0x04, 0x6f, 0x9b, 0x9a, 0x7d, 0x04, 0x0f, 0x27, 0x36, 0xf7, 0xe6, 0x6e, 0xbf, 0xbd,
		0x78, 0xc5, 0xf5, 0xe2, 0x82, 0xff, 0xeb, 0x93, 0x45, 0xe3, 0x05, 0xb8, 0x98, 0xcb, 0x99, 0x04,
		0x2e, 0xfd, 0x61, 0x8d, 0x7d, 0x47, 0xe2, 0x16, 0xbf, 0xf5, 0x46, 0x70, 0x07, 0x9f, 0x3e, 0xc4,
		0x87, 0xeb, 0xb9, 0x72, 0xb9, 0x83, 0x8f, 0x7a, 0x93, 0x31, 0x0d, 0x67, 0x6e, 0x49, 0xe2, 0x1e,
		0xbe, 0x5d, 0x81, 0x67, 0x5b, 0xde, 0x64, 0x3c, 0xfd, 0xf8, 0x9f, 0x05, 0x70, 0x15, 0xd4, 0x23,
		0x37, 0x2e, 0xb5, 0x86, 0xae, 0x7f, 0xbf, 0xa0, 0xa9, 0xc5, 0x5d, 0xc6, 0x73, 0x8d, 0x89, 0xdf,
		0xfe, 0x39, 0x24, 0x6e, 0x04, 0xd7, 0x03, 0xd7, 0x83, 0xeb, 0x3f, 0x37, 0xdd, 0x4e, 0x11, 0xae,
		0xff, 0xbc, 0xbd, 0x8f, 0x29, 0x24, 0xe2, 0x38, 0x21, 0x8d, 0x24, 0x2e, 0x01, 0x7d, 0xd2, 0x0e,
		0x0c, 0x1e, 0x06, 0x5f, 0x32, 0x83, 0x17, 0x5f, 0xde, 0x8f, 0x8c, 0xfe, 0x50, 0xec, 0x2e, 0x72,
		0x4e, 0x43, 0x4f, 0x98, 0x1a, 0xaa, 0xfe, 0xe7, 0x6b, 0xcd, 0x3a, 0x22, 0xd6, 0xb0, 0x69, 0x9d,
		0x5d, 0xfd, 0xdd, 0xf8, 0xf9, 0xef, 0x8f, 0x8f, 0xff, 0xfc, 0xcb, 0xdf, 0x7b, 0x3f, 0xff, 0x95,
		0x7e, 0xc6, 0xae, 0x44, 0xba, 0xd2, 0xed, 0xb7, 0xff, 0x2c, 0x6a, 0x7f, 0x0a, 0xe0, 0x8f, 0x95,
		0x38, 0x63, 0x78, 0x62, 0x78, 0x62, 0x78, 0x62, 0x78, 0x62, 0x78, 0x62, 0x09, 0x4f, 0xec, 0xd1,
		0x91, 0xcf, 0x19, 0xe1, 0xd4, 0xb1, 0x94, 0x50, 0x71, 0x2f, 0xb4, 0x07, 0xff, 0x0c, 0xff, 0x0c,
		0x56, 0xae, 0x8c, 0xac, 0xdc, 0x9a, 0xc1, 0x07, 0x7e, 0xc8, 0xad, 0x28, 0xa0, 0xd4, 0x51, 0xe2,
		0x3f, 0xd6, 0x9a, 0x83, 0xfb, 0x80, 0xfb, 0x28, 0x99, 0xfb, 0x60, 0x0e, 0xf5, 0x38, 0xe3, 0x0f,
		0x21, 0x1d, 0xca, 0xb8, 0x0f, 0x81, 0xad, 0xe8, 0x6a, 0x7b, 0xfe, 0xea, 0x63, 0x12, 0x51, 0xf9,
		0xfa, 0xac, 0xd6, 0xe0, 0xb7, 0xd6, 0x65, 0xa7, 0x35, 0xb8, 0xee, 0xf7, 0x5a, 0xad, 0x53, 0xd1,
		0xb5, 0x13, 0xef, 0xb6, 0x47, 0x52, 0x65, 0x21, 0x92, 0x55, 0x4c, 0x8b, 0xfe, 0xc4, 0xdd, 0xb8,
		0x3e, 0xac, 0xd5, 0x3e, 0x1d, 0x4b, 0x14, 0x09, 0xfd, 0x5a, 0x8c, 0x6e, 0x34, 0xf6, 0xca, 0xd0,
		0x8b, 0x7a, 0x49, 0x26, 0xa3, 0x1c, 0xdd, 0xd8, 0x2b, 0x87, 0x61, 0xd4, 0x6a, 0x17, 0xa5, 0x30,
		0x8d, 0x72, 0x18, 0x78, 0x19, 0xe6, 0xe2, 0x73, 0xe7, 0xf7, 0x4e, 0xf7, 0x8f, 0x4e, 0x09, 0x2c,
		0xbc, 0x14, 0x8b, 0x6a, 0xb7, 0x1c, 0xee, 0x76, 0xbf, 0x56, 0x92, 0xd9, 0x28, 0x85, 0xa3, 0x2a,
		0x09, 0x9c, 0x92, 0x72, 0xb7, 0x42, 0x4f, 0x5e, 0xe9, 0xce, 0xe0, 0xb4, 0xb0, 0x1b, 0x2a, 0x28,
		0x0d, 0xf0, 0x18, 0xe0, 0x31, 0xc0, 0x63, 0x80, 0xc7, 0x00, 0x8f, 0x01, 0x1e, 0x03, 0x3c, 0x06,
		0x78, 0x0c, 0xf0, 0x18, 0xe0, 0x31, 0xc0, 0x63, 0x80, 0xc7, 0x00, 0x8f, 0x01, 0x1e, 0x03, 0x3c,
		0x06, 0x78, 0x0c, 0x61, 0x1e, 0xe3, 0x9d, 0xc2, 0xc9, 0xaa, 0x36, 0x27, 0xa3, 0x69, 0xaa, 0x1a,
		0x13, 0x1d, 0xc9, 0x73, 0x17, 0x41, 0x4a, 0xe4, 0x83, 0x6f, 0x5b, 0x6c, 0xf8, 0x71, 0xed, 0x24,
		0xec, 0x93, 0x5f, 0x7c, 0x98, 0xa5, 0xcb, 0x1f, 0x97, 0xc7, 0x62, 0xe7, 0x7f, 0x8e, 0x4f, 0xc7,
		0xa6, 0x3f, 0xa8, 0x15, 0xd9, 0x21, 0x0b, 0xe6, 0xc7, 0x7a, 0xab, 0x4d, 0xc7, 0x89, 0x2a, 0xe7,
		0xcd, 0x4f, 0x95, 0x88, 0x72, 0xce, 0xbc, 0x51, 0x54, 0xe1, 0x7e, 0x85, 0x79, 0x0e, 0xbb, 0x63,
		0xce, 0x84, 0xb8, 0x95, 0xc5, 0x39, 0xd9, 0xca, 0xea, 0xf3, 0x04, 0x89, 0x9b, 0xba, 0x61, 0xc4,
		0x8d, 0x4b, 0x46, 0x20, 0x6e, 0x9e, 0x21, 0x6e, 0xa6, 0xe3, 0x52, 0x30, 0xe2, 0xe6, 0x94, 0x85,
		0x62, 0xd3, 0x4d, 0x46, 0xa3, 0x90, 0x8e, 0x08, 0xa7, 0x16, 0x73, 0xe4, 0x49, 0x93, 0x47, 0xad,
		0x09, 0x0e, 0xf6, 0x13, 0xf3, 0xec, 0x07, 0xd4, 0x66, 0xc3, 0x87, 0x0a, 0xbf, 0xa5, 0x15, 0xd7,
		0x1f, 0x31, 0x9b, 0xb8, 0x95, 0xe5, 0x6b, 0x56, 0x36, 0x39, 0x35, 0xda, 0xfb, 0x5b, 0x66, 0xdf,
		0x7e, 0xf3, 0xf8, 0x2d, 0x8b, 0xd6, 0xfe, 0xc3, 0x0d, 0x75, 0x7d, 0x6f, 0x04, 0x8d, 0x20, 0x19,
		0x9b, 0x56, 0x65, 0xdb, 0xca, 0x6d, 0x5c, 0xb9, 0xad, 0x2b, 0xb5, 0x79, 0x39, 0x68, 0x91, 0xbf,
		0x46, 0x90, 0x4b, 0xc9, 0x50, 0x8c, 0xc8, 0xdd, 0x08, 0x7d, 0x07, 0x12, 0x6d, 0xf4, 0x96, 0x02,
		0x1a, 0x09, 0x60, 0x02, 0x1b, 0x7e, 0x8c, 0xb5, 0x2e, 0x8a, 0x29, 0x40, 0xa2, 0x18, 0xcd, 0x5d,
		0x25, 0x45, 0x73, 0x62, 0x42, 0x26, 0xca, 0x04, 0x4c, 0x92, 0xcd, 0xc6, 0xdb, 0x7d, 0x4e, 0x60,
		0x12, 0xd5, 0xe8, 0x9e, 0x71, 0xfb, 0x96, 0x3a, 0xd6, 0x9d, 0x4b, 0x92, 0x77, 0x77, 0xb9, 0xe6,
		0x1f, 0x3f, 0x9e, 0x70, 0x7c, 0xd3, 0x01, 0xbc, 0xd4, 0x41, 0x41, 0x24, 0x08, 0xac, 0x3b, 0xfd,
		0x14, 0x5d, 0x91, 0xf1, 0xf2, 0xd2, 0x5e, 0x5d, 0xda, 0x8b, 0x3f, 0xf5, 0xda, 0x71, 0xc7, 0x73,
		0xca, 0xa0, 0xd2, 0x42, 0xb2, 0xaa, 0xbd, 0x58, 0x15, 0x82, 0x59, 0xd4, 0xfc, 0xf9, 0xed, 0xc8,
		0x4d, 0x52, 0x2e, 0xe9, 0xed, 0x49, 0x4e, 0xd2, 0x2d, 0xf9, 0xa2, 0x67, 0x27, 0xb6, 0x4d, 0xa3,
		0x28, 0x9d, 0x27, 0x7f, 0x39, 0x39, 0x59, 0x6b, 0x0c, 0xc9, 0x80, 0x84, 0x11, 0x21, 0x1b, 0x10,
		0x33, 0x32, 0xd3, 0xd3, 0x81, 0x69, 0xaf, 0xc5, 0x13, 0xfb, 0x75, 0x03, 0xda, 0x87, 0x60, 0xa8,
		0x52, 0xcf, 0xb2, 0xd1, 0xdc, 0x52, 0xad, 0x12, 0x82, 0xa1, 0x79, 0x4f, 0xc1, 0x6e, 0xed, 0x68,
		0x17, 0x02, 0xa1, 0x1b, 0x99, 0x6b, 0xa1, 0xaf, 0x9e, 0x9d, 0x67, 0xb1, 0x62, 0x87, 0xdf, 0x37,
		0xfc, 0xe6, 0x93, 0xf6, 0x80, 0x3d, 0x80, 0x3d, 0x80, 0x3d, 0x44, 0xb0, 0xc7, 0xd4, 0x7c, 0x2c,
		0x3e, 0x6d, 0x53, 0x01, 0x23, 0x29, 0xe1, 0x94, 0x05, 0x4f, 0xdc, 0x67, 0xeb, 0xc5, 0x3c, 0xc2,
		0xd9, 0x1d, 0x55, 0x94, 0x3b, 0xad, 0x37, 0x06, 0xff, 0x05, 0xff, 0x05, 0xff, 0x85, 0xdc, 0x09,
		0xb9, 0x13, 0x72, 0x27, 0xe4, 0x4e, 0xc8, 0x9d, 0x1e, 0x0d, 0x33, 0x0f, 0x27, 0xde, 0xf7, 0xd8,
		0xc7, 0x2b, 0xb8, 0xeb, 0x69, 0xbd, 0x31, 0xa0, 0x0e, 0xa0, 0x0e, 0xa0, 0x8e, 0x94, 0x2b, 0x66,
		0xe2, 0x89, 0xc9, 0x91, 0x6d, 0x24, 0x4b, 0x47, 0x12, 0x6d, 0xcc, 0xbb, 0x93, 0x3b, 0xe6, 0x50,
		0x07, 0xc5, 0x14, 0x42, 0x32, 0xc5, 0xd0, 0x4c, 0xdd, 0x70, 0x69, 0x81, 0x6a, 0x9a, 0xf0, 0x82,
		0x2e, 0xe8, 0xa6, 0x13, 0x3c, 0x28, 0x84, 0x72, 0x5a, 0x20, 0x5d, 0x56, 0x53, 0xa5, 0x0e, 0xe2,
		0x65, 0x32, 0x5b, 0xef, 0x8a, 0xd1, 0xca, 0xd5, 0xbb, 0x1c, 0xd7, 0x9c, 0x6a, 0x5f, 0x1c, 0xc6,
		0xae, 0x4f, 0x9d, 0x3b, 0xae, 0x1f, 0x2a, 0x68, 0x4b, 0x56, 0x24, 0x78, 0xa3, 0xc1, 0xff, 0xfc,
		0x7b, 0xb7, 0x76, 0xf4, 0xb5, 0x66, 0xed, 0x5e, 0xfd, 0xb3, 0x5b, 0xfb, 0x5a, 0xb3, 0x0e, 0xaf,
		0xbe, 0xd6, 0xac, 0xa3, 0xab, 0x7f, 0xbe, 0xd6, 0xad, 0x9d, 0xd9, 0x8f, 0x7f, 0xef, 0xfc, 0x9c,
		0xfe, 0xe9, 0x68, 0xfe, 0xa7, 0xfa, 0xaf, 0x8d, 0xf9, 0x9f, 0x7f, 0xf9, 0xf6, 0xed, 0xfd, 0xb7,
		0x6f, 0xef, 0x25, 0x1a, 0xf8, 0x57, 0x55, 0x7e, 0xc9, 0xa9, 0x18, 0x54, 0x15, 0xf2, 0xcb, 0xe5,
		0x1b, 0x59, 0xb3, 0xf2, 0x48, 0x41, 0x54, 0x7b, 0xce, 0x22, 0xde, 0xe4, 0x3c, 0x94, 0x43, 0xb6,
		0x17, 0xcc, 0x6b, 0xb9, 0x74, 0x0a, 0xec, 0x23, 0xb9, 0xa0, 0x34, 0x0d, 0x96, 0x6b, 0x2d, 0xa9,
		0xbd, 0xd6, 0xb1, 0xda, 0x0d, 0x1d, 0x1a, 0x52, 0xe7, 0xf8, 0xa1, 0xfa, 0xb1, 0xe2, 0x4d, 0x5c,
		0x17, 0xd7, 0x21, 0x2a, 0xaa, 0x26, 0x5e, 0xaf, 0xce, 0xfd, 0x30, 0xaf, 0x78, 0x2c, 0x80, 0x30,
		0xd0, 0xac, 0xca, 0x59, 0xb8, 0x74, 0x53, 0xe8, 0x1c, 0x9b, 0x6c, 0xe5, 0x66, 0x03, 0x95, 0x9b,
		0xb9, 0x52, 0x15, 0xa8, 0xdc, 0x4c, 0xba, 0x6a, 0x50, 0xb9, 0x09, 0x1e, 0x10, 0x3c, 0x60, 0xae,
		0x94, 0x17, 0x76, 0x1f, 0xb3, 0xe1, 0x47, 0xb0, 0xfb, 0x58, 0x9c, 0x29, 0xc0, 0xee, 0xa3, 0xc2,
		0xac, 0x11, 0x95, 0x9b, 0xc0, 0x1e, 0xc0, 0x1e, 0xa8, 0xdc, 0x44, 0xe5, 0xe6, 0x9b, 0xdf, 0x88,
		0xca, 0x4d, 0xf8, 0x2f, 0xf8, 0x2f, 0xe4, 0x4e, 0xc8, 0x9d, 0x90, 0x3b, 0x21, 0x77, 0x42, 0xee,
		0x84, 0xca, 0x4d, 0xa0, 0x0e, 0xa0, 0x8e, 0xed, 0x42, 0x1d, 0xa8, 0xdc, 0xd4, 0x02, 0xc5, 0x14,
		0x42, 0x32, 0xc5, 0xd0, 0x4c, 0xdd, 0x70, 0x69, 0x81, 0x6a, 0x9a, 0xf0, 0x82, 0x2e, 0xe8, 0xa6,
		0x13, 0x3c, 0x28, 0x84, 0x72, 0x5a, 0x20, 0x5d, 0x56, 0x53, 0x85, 0xca, 0xcd, 0xec, 0x20, 0xa0,
		0xa2, 0x35, 0x87, 0xca, 0x4d, 0x91, 0x06, 0x51, 0xb9, 0x89, 0xca, 0x4d, 0x2d, 0xc6, 0x8c, 0xca,
		0x4d, 0xd1, 0x60, 0x89, 0xca, 0xcd, 0x74, 0x29, 0x55, 0xd1, 0x2a, 0x37, 0x53, 0xa8, 0xc2, 0xa6,
		0x1f, 0x21, 0xc5, 0x37, 0x21, 0xe4, 0xa8, 0x9d, 0x2b, 0xa0, 0x45, 0x3b, 0x7b, 0x37, 0x0f, 0x27,
		0x36, 0xf7, 0xe6, 0xa1, 0xba, 0xbd, 0x68, 0xf9, 0x7a, 0x71, 0x97, 0xc1, 0x75, 0x7f, 0xde, 0xf2,
		0x97, 0xc4, 0xc9, 0x75, 0x02, 0x71, 0xde, 0x77, 0x12, 0xc3, 0x9d, 0xf2, 0xc2, 0x89, 0x94, 0xa2,
		0xbe, 0xa9, 0x2f, 0x98, 0x48, 0x2a, 0xfc, 0xfb, 0xdc, 0x5d, 0x12, 0x5f, 0xce, 0x9b, 0x1d, 0xf5,
		0x97, 0x49, 0x40, 0x63, 0x58, 0x0d, 0x7f, 0xb5, 0xdd, 0x1a, 0xc3, 0x62, 0xe2, 0xd8, 0x1b, 0xf3,
		0x2d, 0xea, 0x98, 0x9e, 0xb3, 0x99, 0x96, 0x67, 0xbb, 0x7e, 0xc4, 0xbc, 0x51, 0xc5, 0xf6, 0x3d,
		0x4e, 0x98, 0x47, 0xc3, 0xca, 0xd0, 0x0f, 0x67, 0x66, 0xb4, 0x2a, 0xc0, 0x89, 0xe2, 0x7b, 0x20,
		0x98, 0xfd, 0xcd, 0x73, 0x08, 0x27, 0x15, 0xdf, 0x7b, 0xce, 0x96, 0xde, 0x57, 0x2a, 0x83, 0x5b,
		0x1a, 0xd1, 0x0a, 0x09, 0x69, 0xdc, 0x48, 0xc4, 0x89, 0xe7, 0x90, 0xd0, 0xf9, 0xe6, 0x9d, 0x37,
		0x7e, 0xad, 0x2c, 0x3f, 0x3b, 0xe2, 0x0f, 0x2e, 0x8d, 0xdf, 0x10, 0xbd, 0x87, 0x60, 0xb2, 0x4e,
		0xde, 0x19, 0x65, 0xf7, 0x5a, 0xb0, 0x8b, 0x64, 0x30, 0xbe, 0x7a, 0x2b, 0x18, 0xa7, 0xc3, 0x3c,
		0x0a, 0xb0, 0x4e, 0x35, 0x89, 0xb2, 0xff, 0x1b, 0xa8, 0xe6, 0xf5, 0x59, 0x7c, 0x79, 0x44, 0x5e,
		0xf1, 0xb6, 0xd5, 0x5b, 0xdf, 0x75, 0x2c, 0xce, 0xc6, 0x6f, 0x5b, 0xc0, 0xd2, 0xd8, 0x56, 0x8f,
		0xbc, 0x31, 0xca, 0xc9, 0x3c, 0x49, 0x62, 0xcf, 0x91, 0xc6, 0x53, 0xac, 0x7b, 0x06, 0x96, 0xe4,
		0x82, 0x8f, 0xb4, 0x7e, 0x40, 0xd8, 0xee, 0x85, 0xed, 0xfc, 0xa9, 0x5d, 0xb3, 0x61, 0x55, 0x33,
		0x64, 0x4d, 0x1a, 0x7d, 0xd3, 0x2a, 0xfb, 0x8b, 0x29, 0xfa, 0x17, 0x1d, 0x20, 0xb2, 0xe1, 0x56,
		0xc2, 0xc3, 0x24, 0xcb, 0xb0, 0x20, 0xe0, 0xd0, 0xf1, 0xef, 0x25, 0x30, 0x61, 0xfc, 0x74, 0x6a,
		0x28, 0x38, 0x24, 0x13, 0x37, 0x1e, 0xaa, 0x9a, 0x20, 0x0e, 0xab, 0x19, 0x86, 0xc3, 0xd8, 0x10,
		0x28, 0x4c, 0xd2, 0x4c, 0xb2, 0xe1, 0xcc, 0x84, 0xf7, 0xf2, 0x57, 0x7b, 0xf8, 0xcc, 0xe3, 0x3b,
		0x0d, 0x91, 0xe9, 0x9e, 0xaf, 0x6d, 0x81, 0x4b, 0xb3, 0x24, 0x77, 0xa3, 0xe5, 0xf8, 0x5d, 0x05,
		0xd5, 0x29, 0x4a, 0xb6, 0x2c, 0x97, 0x5b, 0x94, 0xb2, 0xed, 0x28, 0xdc, 0x8f, 0xfc, 0x29, 0x47,
		0x78, 0x17, 0x6e, 0x68, 0x77, 0x1b, 0x47, 0xbb, 0x47, 0xfb, 0x07, 0x8d, 0xa3, 0xbd, 0x02, 0x8d,
		0x71, 0x46, 0x64, 0xfd, 0x55, 0x01, 0x14, 0x07, 0x26, 0x81, 0x78, 0xa8, 0x9e, 0x04, 0x08, 0xd4,
		0x08, 0xd4, 0x08, 0xd4, 0x08, 0xd4, 0x08, 0xd4, 0x08, 0xd4, 0x08, 0xd4, 0xba, 0x58, 0xda, 0x84,
		0x89, 0x7a, 0xeb, 0x47, 0x3c, 0x9c, 0xda, 0xae, 0xd9, 0x5f, 0x8b, 0x29, 0xbe, 0x6d, 0xd1, 0x1f,
		0xfc, 0x23, 0xa7, 0x2e, 0x1d, 0x53, 0x1e, 0x3e, 0x58, 0xbe, 0x67, 0xd9, 0xb7, 0x02, 0x55, 0x5c,
		0x4f, 0xe2, 0xcb, 0x90, 0xb8, 0x91, 0x0c, 0x51, 0x52, 0xdd, 0x9a, 0x8b, 0x71, 0x97, 0xec, 0x70,
		0x2a, 0xf5, 0x2a, 0x45, 0x57, 0xe3, 0xa6, 0x52, 0xa9, 0x12, 0x52, 0xa7, 0x12, 0x66, 0x21, 0x1b,
		0x60, 0x21, 0xc1, 0x42, 0x82, 0x85, 0x44, 0x72, 0x83, 0xe4, 0x06, 0xc9, 0x0d, 0x92, 0x1b, 0x24,
		0x37, 0x48, 0x6e, 0xc0, 0x42, 0x22, 0x50, 0x23, 0x50, 0x23, 0x50, 0x23, 0x50, 0x23, 0x50, 0x23,
		0x50, 0x23, 0x50, 0xeb, 0x4d, 0xd4, 0xf3, 0xa4, 0xc2, 0x52, 0x1c, 0x07, 0xd2, 0x7e, 0x0e, 0x25,
		0xb3, 0xd2, 0xd7, 0xa4, 0x75, 0xa2, 0x95, 0xd7, 0x6a, 0x5f, 0x7f, 0xf3, 0x5d, 0x67, 0x30, 0x6d,
		0x43, 0x43, 0xed, 0xeb, 0xfc, 0x6d, 0x09, 0xcb, 0x5e, 0xe3, 0xbf, 0x9d, 0xac, 0xe2, 0xb5, 0x86,
		0x8a, 0x57, 0x15, 0x20, 0x29, 0xfb, 0x8a, 0xd7, 0xc4, 0x20, 0x67, 0x39, 0xda, 0x2e, 0x25, 0xc3,
		0x90, 0x26, 0x1a, 0xef, 0x05, 0x73, 0x9c, 0x00, 0xc6, 0x54, 0x7b, 0x73, 0x7b, 0x7b, 0xff, 0x7e,
		0xe6, 0x3b, 0x3e, 0xc4, 0xab, 0x4f, 0x83, 0x0d, 0x84, 0xfe, 0x84, 0x27, 0x3d, 0x2e, 0xb3, 0xec,
		0xf4, 0xfa, 0x43, 0x66, 0xd4, 0x80, 0x27, 0x3c, 0x1d, 0x62, 0x9e, 0x4d, 0x24, 0x3b, 0xdd, 0x81,
		0x3a, 0x70, 0x1c, 0x14, 0x54, 0x9e, 0xbb, 0x1a, 0x7d, 0x50, 0x50, 0xee, 0x7c, 0xa0, 0xc8, 0xb1,
		0x40, 0x43, 0x09, 0x1a, 0x9c, 0xab, 0x53, 0xb2, 0xdc, 0x8d, 0x21, 0x69, 0x04, 0x75, 0xd9, 0x64,
		0xf4, 0xd8, 0xe4, 0x74, 0xd8, 0x54, 0x88, 0xd1, 0x31, 0x8f, 0xd7, 0xf7, 0xa1, 0x80, 0xab, 0x8e,
		0xb9, 0x52, 0x4c, 0xb3, 0xa8, 0x66, 0xb2, 0x74, 0xb0, 0x2d, 0x0a, 0x98, 0x2d, 0xa5, 0x0c, 0x97,
		0xee, 0x29, 0xd8, 0xdf, 0xdb, 0xdb, 0xd9, 0x83, 0x04, 0xae, 0x1c, 0x19, 0x26, 0xb9, 0x68, 0x14,
		0xf8, 0xbe, 0x88, 0x87, 0xcc, 0x1b, 0xa9, 0x50, 0xe2, 0x3c, 0x04, 0xdd, 0x98, 0x2b, 0xdd, 0xb8,
		0x96, 0x95, 0xe7, 0x50, 0x7b, 0xc7, 0x82, 0xbb, 0xdd, 0xf4, 0x99, 0x5f, 0xfc, 0x54, 0x49, 0xce,
		0xff, 0x06, 0xdb, 0x59, 0x79, 0x17, 0x18, 0x93, 0xf3, 0x11, 0xc7, 0x09, 0x69, 0x14, 0xd1, 0x48,
		0x3c, 0xf1, 0x5b, 0x35, 0xb1, 0x1d, 0xaa, 0x2a, 0x2c, 0x40, 0xee, 0x27, 0xb9, 0xe8, 0xb3, 0xc9,
		0xfc, 0xc4, 0x2f, 0x32, 0x9d, 0xad, 0x68, 0x05, 0x97, 0x98, 0xce, 0x1b, 0x92, 0x93, 0xc3, 0xaf,
		0x97, 0x44, 0x0e, 0x5f, 0xc8, 0x70, 0x54, 0x19, 0x90, 0x72, 0x43, 0x52, 0x6e, 0x50, 0x2a, 0x0d,
		0x4b, 0x0e, 0xb3, 0x8b, 0x8a, 0x86, 0x8a, 0x1a, 0xdc, 0xb2, 0x81, 0x94, 0x64, 0xf9, 0x9b, 0x8b,
		0x2e, 0x15, 0x89, 0xae, 0xc9, 0x0c, 0x95, 0x99, 0xa3, 0x4a, 0xb3, 0x54, 0x6e, 0x9e, 0xaa, 0xcd,
		0x54, 0x9b, 0xb9, 0x6a, 0x33, 0x5b, 0x1d, 0xe6, 0xab, 0x28, 0x71, 0x97, 0x5c, 0x6f, 0xb2, 0x66,
		0xbd, 0x96, 0x0f, 0xa9, 0x5b, 0x17, 0xab, 0x6c, 0x49, 0xd5, 0x82, 0x50, 0xcc, 0x09, 0xa9, 0x32,
		0x77, 0x1d, 0x66, 0xaf, 0xcd, 0xfc, 0x75, 0xb9, 0x01, 0xed, 0xee, 0x40, 0xbb, 0x5b, 0xd0, 0xe9,
		0x1e, 0xd4, 0xb8, 0x09, 0x45, 0xee, 0x62, 0xd9, 0x51, 0xe9, 0x8b, 0x71, 0x5e, 0x65, 0x48, 0x2c,
		0x39, 0x6c, 0xfd, 0x3a, 0x6b, 0xa7, 0xb0, 0x4d, 0xd5, 0xfa, 0xf9, 0xcb, 0x86, 0xff, 0xf3, 0xef,
		0x7f, 0x2f, 0x75, 0xef, 0xe7, 0x4a, 0xf7, 0xff, 0xd4, 0xe3, 0x7f, 0xcd, 0x7e, 0x6e, 0xc4, 0x12,
		0xf9, 0xf3, 0x9f, 0xf7, 0xbe, 0xd6, 0xac, 0xbd, 0x58, 0x3f, 0xff, 0x97, 0xbf, 0x77, 0x7e, 0xa6,
		0x7f, 0xf0, 0x5f, 0xea, 0x16, 0xe9, 0x95, 0xca, 0xc1, 0xd5, 0x71, 0x43, 0x81, 0xf9, 0x23, 0x5c,
		0x90, 0x6b, 0x4f, 0x54, 0xec, 0xfa, 0xcc, 0x9c, 0xbc, 0xe5, 0x52, 0x6f, 0x14, 0xb3, 0xbf, 0x8a,
		0xd1, 0xc3, 0xe3, 0xe6, 0x01, 0x24, 0x00, 0x24, 0x00, 0x24, 0xb6, 0x08, 0x48, 0x4c, 0x98, 0xc7,
		0x0f, 0x35, 0x20, 0x88, 0x3d, 0x85, 0x4d, 0xaa, 0xbd, 0x6a, 0x6e, 0xf1, 0x8f, 0x5a, 0x6b, 0xaa,
		0xe8, 0xba, 0x7a, 0x4e, 0x93, 0x4f, 0xdd, 0x68, 0x5e, 0x71, 0x0d, 0xc5, 0x46, 0xfb, 0x1a, 0x2f,
		0x39, 0x53, 0x6c, 0x6d, 0x8f, 0xa7, 0x54, 0xc3, 0x15, 0x75, 0x59, 0x4f, 0xe9, 0x4e, 0xc3, 0xe0,
		0x39, 0x7d, 0x57, 0xcc, 0xd6, 0x0a, 0x83, 0x30, 0x73, 0xe5, 0xc5, 0x24, 0x6f, 0x58, 0xda, 0x68,
		0x4f, 0x4d, 0x99, 0xc3, 0x34, 0x39, 0xfe, 0xb0, 0xdc, 0x93, 0x5d, 0xfc, 0x94, 0xaa, 0xfa, 0x41,
		0xfd, 0x70, 0xcb, 0x1c, 0x6d, 0x54, 0xc0, 0x1a, 0xaa, 0x63, 0x0b, 0x55, 0x9d, 0x91, 0xc4, 0x66,
		0x40, 0x91, 0x40, 0x3b, 0x36, 0x03, 0xb2, 0x07, 0xe3, 0x02, 0xc7, 0xc5, 0x12, 0x13, 0x78, 0x07,
		0x6a, 0xae, 0x14, 0x7d, 0x7c, 0xdc, 0x4c, 0x76, 0xee, 0xf2, 0xf1, 0x9e, 0xe9, 0xf4, 0xdf, 0xde,
		0x9c, 0xac, 0x34, 0xba, 0x70, 0x6f, 0x4e, 0x93, 0x2a, 0x1f, 0xda, 0x80, 0x0f, 0x85, 0x0f, 0x35,
		0xc8, 0x87, 0x62, 0x43, 0x35, 0x4f, 0xc8, 0xa4, 0xc3, 0xec, 0xb5, 0x99, 0xbf, 0x2e, 0x37, 0xa0,
		0xdd, 0x1d, 0x68, 0x77, 0x0b, 0x3a, 0xdd, 0x83, 0xda, 0x8c, 0x19, 0x1b, 0xaa, 0xd8, 0x50, 0xc5,
		0x86, 0x2a, 0x36, 0x54, 0x0b, 0xb1, 0xa1, 0xea, 0x87, 0x6c, 0xa4, 0xf2, 0x30, 0xe3, 0x32, 0xe0,
		0xcd, 0xda, 0x05, 0x74, 0x00, 0x74, 0x00, 0x74, 0xd8, 0x2a, 0xe8, 0xb0, 0x00, 0x0e, 0x96, 0x52,
		0x17, 0xf0, 0x08, 0x3f, 0xec, 0x2a, 0x6c, 0xb3, 0xe5, 0x4d, 0xc6, 0xd3, 0xa1, 0xf8, 0x89, 0x2a,
		0x99, 0xa4, 0x73, 0x8c, 0x2a, 0x19, 0xb8, 0x78, 0xb8, 0xf8, 0xad, 0x75, 0xf1, 0xa8, 0x92, 0x51,
		0xb8, 0x1e, 0x51, 0x25, 0xf3, 0x72, 0xfb, 0xa8, 0x92, 0xc9, 0x6d, 0x4a, 0x51, 0x25, 0xa3, 0xbe,
		0x35, 0x54, 0xc9, 0x18, 0x57, 0x25, 0x93, 0x42, 0x94, 0x58, 0xfd, 0x68, 0xcb, 0x6c, 0xf3, 0xde,
		0x85, 0xa1, 0xc2, 0x32, 0x99, 0xb8, 0x35, 0x9c, 0x9a, 0xcd, 0x0c, 0xc7, 0x63, 0x93, 0x17, 0x9b,
		0xbc, 0xaf, 0x9a, 0xb6, 0x35, 0x0a, 0xfd, 0x89, 0x86, 0xcd, 0xde, 0xb5, 0xb6, 0xd5, 0xa6, 0xf5,
		0x75, 0xa4, 0xf5, 0x48, 0xeb, 0x91, 0xd6, 0xcb, 0x77, 0x54, 0x95, 0x1b, 0x59, 0x36, 0xa8, 0x48,
		0x63, 0xe3, 0x45, 0x23, 0x50, 0xa2, 0xb9, 0xa1, 0xd9, 0xad, 0x68, 0x73, 0x2f, 0x3a, 0xdd, 0x8c,
		0x76, 0x77, 0xa3, 0xdb, 0xed, 0x64, 0xe6, 0x7e, 0x32, 0x73, 0x43, 0x59, 0xb8, 0x23, 0x4d, 0x59,
		0xae, 0xe2, 0xf5, 0xae, 0xda, 0x4d, 0x2d, 0x1b, 0x26, 0xb6, 0x4d, 0x03, 0x6e, 0x8d, 0x7d, 0x47,
		0xe3, 0x82, 0x5c, 0xea, 0x75, 0xad, 0xbd, 0x4c, 0xd3, 0x4a, 0x59, 0xbb, 0xcf, 0x2e, 0xbe, 0x40,
		0x5b, 0xd7, 0x7b, 0x34, 0xf3, 0x46, 0xba, 0x1c, 0x67, 0x16, 0x0e, 0x34, 0x33, 0x47, 0x9a, 0x95,
		0x43, 0xcd, 0xdc, 0xb1, 0x66, 0xee, 0x60, 0xb3, 0x74, 0xb4, 0x7a, 0x1c, 0xae, 0x26, 0xc7, 0xbb,
		0x1c, 0x18, 0xe5, 0xdb, 0x3f, 0x2f, 0x5a, 0xcb, 0x8d, 0xef, 0xbb, 0x94, 0x78, 0x3a, 0xed, 0x65,
		0x81, 0xf6, 0xea, 0xef, 0xcc, 0x98, 0x58, 0x1d, 0xbb, 0x0a, 0xc4, 0xb9, 0xa3, 0x21, 0x67, 0x11,
		0x9d, 0x2e, 0xf7, 0x19, 0xb7, 0x79, 0x47, 0xdc, 0x0c, 0x62, 0xe0, 0xf3, 0xef, 0xd5, 0x1f, 0x0e,
		0xeb, 0xb5, 0x1a, 0x82, 0x21, 0x82, 0x21, 0x82, 0x21, 0x82, 0xa1, 0x39, 0xc1, 0x50, 0xfa, 0x9a,
		0x94, 0xa4, 0xbe, 0x6b, 0x5f, 0xe3, 0x2b, 0xf4, 0x14, 0x4f, 0x3c, 0xfd, 0x47, 0xaf, 0xb9, 0x57,
		0x74, 0x17, 0x57, 0x64, 0x1c, 0x54, 0x36, 0x5e, 0xb7, 0xd8, 0xa9, 0xaf, 0x67, 0xf4, 0xbe, 0x0c,
		0x36, 0xee, 0x33, 0x72, 0x07, 0x8f, 0x97, 0x08, 0xf9, 0x51, 0xfa, 0x25, 0xb2, 0x5b, 0x3b, 0xda,
		0x2b, 0xf1, 0x2a, 0x79, 0x67, 0x66, 0xeb, 0x57, 0x5b, 0x9c, 0xcc, 0x04, 0x21, 0xa5, 0xe3, 0x80,
		0xeb, 0xcf, 0x5e, 0x16, 0x2f, 0xd2, 0x9f, 0xae, 0x4c, 0xf1, 0x1d, 0xf2, 0x15, 0xe4, 0x2b, 0xc8,
		0x57, 0x90, 0xaf, 0x98, 0x93, 0xaf, 0x80, 0xbc, 0xcb, 0x32, 0xde, 0x59, 0x0e, 0x75, 0xc9, 0x43,
		0x66, 0x51, 0x6f, 0xfe, 0x3a, 0xfd, 0xb1, 0x0f, 0x44, 0x1d, 0x02, 0x1f, 0x02, 0x1f, 0x02, 0x9f,
		0x41, 0x81, 0x0f, 0x44, 0x5d, 0xe2, 0x7f, 0x40, 0xd4, 0x29, 0x61, 0x61, 0x6a, 0x20, 0xea, 0xa4,
		0x96, 0xc8, 0x16, 0x10, 0x75, 0x3b, 0xfb, 0xb5, 0x1a, 0x88, 0xba, 0xa2, 0xb5, 0xbe, 0xdd, 0x44,
		0x1d, 0xf3, 0x43, 0xc6, 0x33, 0xc9, 0x59, 0xe6, 0x6f, 0x42, 0x65, 0x01, 0x12, 0x16, 0x24, 0x2c,
		0x48, 0x58, 0x90, 0xb0, 0x54, 0x74, 0xaa, 0x2e, 0xbc, 0xe4, 0xba, 0xf6, 0x90, 0xaf, 0x20, 0x5f,
		0x41, 0x61, 0x01, 0xf2, 0x95, 0x04, 0x4b, 0xa4, 0xb1, 0xb7, 0x8b, 0x74, 0x05, 0xe9, 0x4a, 0x71,
		0xd2, 0x95, 0x3b, 0x16, 0xf2, 0x09, 0x71, 0x2d, 0xd9, 0x1b, 0xfb, 0x13, 0x47, 0xe5, 0xa7, 0x2f,
		0x44, 0x5a, 0x81, 0xb4, 0x02, 0x69, 0x05, 0xd2, 0x0a, 0x63, 0xd2, 0x8a, 0x95, 0x5e, 0x67, 0x16,
		0x35, 0x00, 0x47, 0x1a, 0xdf, 0x31, 0x1f, 0x33, 0xe3, 0x73, 0x0b, 0xcd, 0x22, 0xec, 0x6f, 0xce,
		0xd1, 0x61, 0x06, 0xef, 0xd2, 0x25, 0x29, 0xfe, 0xe2, 0x0b, 0x4d, 0x95, 0x1a, 0x7f, 0x11, 0xe4,
		0x65, 0x31, 0x49, 0x3a, 0xc5, 0xdf, 0xb7, 0x67, 0xa6, 0xde, 0x19, 0x9c, 0xc9, 0x66, 0xeb, 0xee,
		0xf6, 0xe1, 0xee, 0xd4, 0x1a, 0x11, 0xb1, 0x86, 0x4d, 0xeb, 0xec, 0xea, 0xef, 0xfa, 0xaf, 0xbb,
		0x3f, 0x3f, 0xfe, 0xf2, 0xf7, 0xc1, 0xcf, 0xa7, 0xbf, 0xfc, 0xe7, 0xb9, 0xbf, 0x56, 0xff, 0xf5,
		0xe0, 0xe7, 0xc7, 0x17, 0xfe, 0xcb, 0xfe, 0xcf, 0x8f, 0x09, 0xdb, 0xd8, 0xfb, 0xf9, 0xef, 0x8d,
		0xbf, 0x3a, 0xfd, 0x7d, 0xe3, 0xa5, 0x07, 0x76, 0x5f, 0x78, 0x60, 0xe7, 0xa5, 0x07, 0x76, 0x5e,
		0x78, 0xe0, 0xc5, 0x4f, 0x6a, 0xbc, 0xf0, 0xc0, 0xde, 0xcf, 0x7f, 0x36, 0xfe, 0xfe, 0xbf, 0x9f,
		0xff, 0xab, 0xfb, 0x3f, 0x7f, 0xf9, 0xe7, 0xa5, 0xff, 0x76, 0xf0, 0xf3, 0x9f, 0x8f, 0xbf, 0xc0,
		0xf9, 0x63, 0xdd, 0x62, 0xdd, 0xe6, 0x12, 0x0a, 0x4d, 0x63, 0xd4, 0x34, 0xe5, 0x8e, 0xe7, 0x2c,
		0xe2, 0x4d, 0xce, 0x43, 0xbd, 0xf9, 0xe3, 0x05, 0xf3, 0x5a, 0x6e, 0xac, 0x09, 0x10, 0xe9, 0x25,
		0x9e, 0xab, 0x17, 0xe4, 0xc7, 0xda, 0x9b, 0xea, 0x87, 0xbb, 0xbb, 0xfb, 0x07, 0xbb, 0xbb, 0xb5,
		0x83, 0x9d, 0x83, 0xda, 0xd1, 0xde, 0x5e, 0x7d, 0xbf, 0xae, 0x73, 0xc7, 0xaa, 0x1b, 0x3a, 0x34,
		0xa4, 0xce, 0xf1, 0x43, 0xf5, 0x63, 0xc5, 0x9b, 0xb8, 0x2e, 0xb8, 0x55, 0x2b, 0x96, 0xcd, 0x0d,
		0x2d, 0xe6, 0x64, 0xc7, 0xae, 0xae, 0x5e, 0x09, 0x7e, 0x15, 0xfc, 0x2a, 0xf8, 0x55, 0xf0, 0xab,
		0xc6, 0xf0, 0xab, 0x28, 0xdb, 0x28, 0x10, 0xd7, 0x80, 0xb2, 0x0d, 0x75, 0xef, 0x43, 0xd9, 0x86,
		0xb1, 0x4b, 0xa4, 0xb1, 0x07, 0x39, 0x88, 0x6d, 0x49, 0x32, 0xb7, 0x4c, 0x77, 0x56, 0xf1, 0xed,
		0x22, 0x1b, 0xed, 0x6b, 0xbd, 0x6d, 0xe4, 0x2e, 0x0c, 0x83, 0x0f, 0x2b, 0x09, 0xfe, 0x0f, 0x73,
		0xe9, 0xec, 0x82, 0x5e, 0x67, 0xa3, 0x70, 0xea, 0xaa, 0xcb, 0x61, 0xb2, 0x78, 0x48, 0xec, 0xef,
		0xcc, 0xd3, 0x28, 0x48, 0xfe, 0xcc, 0xbb, 0x20, 0x4e, 0x0e, 0x71, 0xf2, 0xbc, 0xb3, 0x44, 0x88,
		0x93, 0x67, 0x16, 0x24, 0xb4, 0x89, 0x93, 0x6b, 0xba, 0x4b, 0x61, 0xc3, 0x98, 0xb4, 0xdc, 0xa9,
		0xa0, 0xd9, 0x7d, 0x81, 0x0c, 0x03, 0x19, 0x06, 0x32, 0xac, 0x88, 0x64, 0x98, 0x2e, 0x77, 0xb8,
		0x7c, 0xc1, 0xe2, 0x68, 0xa7, 0xe5, 0x50, 0x3b, 0xa4, 0xf3, 0x39, 0xd0, 0xbc, 0x9e, 0x9f, 0x1e,
		0x2b, 0x5d, 0x7b, 0xb7, 0xe6, 0x75, 0x96, 0x81, 0x2e, 0x4e, 0xc6, 0x04, 0x82, 0x76, 0x97, 0x9d,
		0xa5, 0xeb, 0xce, 0xdc, 0x85, 0x67, 0xed, 0xca, 0x73, 0x73, 0xe9, 0xb9, 0xb9, 0xf6, 0x3c, 0x5c,
		0x7c, 0x46, 0x74, 0x93, 0x66, 0x7b, 0xd3, 0xbe, 0x0f, 0xb2, 0x61, 0x6d, 0xba, 0xf7, 0x43, 0x9e,
		0xba, 0xc6, 0x0c, 0x98, 0xce, 0x8c, 0xf6, 0x47, 0x16, 0xff, 0x64, 0xe3, 0x3d, 0x2a, 0x59, 0xef,
		0x97, 0x64, 0x1c, 0xd3, 0x36, 0x5e, 0x9b, 0xb1, 0x4c, 0xcf, 0xf2, 0xbd, 0x39, 0x50, 0xe4, 0x19,
		0x79, 0x97, 0xc7, 0x4b, 0x29, 0xc3, 0x7d, 0x95, 0xa2, 0x2c, 0xa5, 0xcc, 0x8e, 0xc7, 0x16, 0x62,
		0x31, 0xbd, 0x2b, 0xc7, 0x5b, 0x4c, 0x2d, 0x52, 0xd4, 0x68, 0xcc, 0xff, 0x1f, 0x7b, 0xff, 0xfa,
		0xdb, 0x36, 0xce, 0x6d, 0x8f, 0xe3, 0xef, 0xfb, 0x57, 0x18, 0xc6, 0xf3, 0xa2, 0x39, 0xa8, 0x1a,
		0xdf, 0xe2, 0x5c, 0x80, 0x83, 0x83, 0x4c, 0xd3, 0xce, 0x27, 0xf8, 0xb6, 0xd3, 0xa0, 0xe9, 0xf4,
		0x99, 0x83, 0xd6, 0x4f, 0xc1, 0x48, 0x54, 0x2c, 0x54, 0x96, 0x74, 0x28, 0xca, 0x4d, 0x7e, 0xad,
		0xff, 0xf7, 0x1f, 0x7c, 0x93, 0x1d, 0x5f, 0x5a, 0x4b, 0xda, 0xa4, 0x44, 0x7b, 0xe5, 0xc5, 0x8c,
		0x93, 0x5a, 0xa4, 0x24, 0x92, 0x7b, 0xaf, 0xb5, 0xf6, 0xe6, 0x66, 0x7d, 0x22, 0x94, 0x2f, 0x22,
		0x1c, 0xfa, 0xd8, 0xdb, 0x6a, 0xc7, 0xa0, 0x53, 0xa0, 0x53, 0xa0, 0x53, 0xa0, 0x53, 0xa0, 0x53,
		0xb3, 0xd5, 0xe6, 0x73, 0xe6, 0x0a, 0xee, 0xea, 0xdc, 0x30, 0x75, 0xaa, 0x67, 0xc3, 0xd4, 0x2c,
		0xc0, 0x6e, 0x5b, 0x9e, 0x7b, 0xb1, 0x14, 0x50, 0x5f, 0xf9, 0xc3, 0xec, 0xf7, 0x60, 0xfc, 0x3a,
		0x8c, 0x9e, 0x3a, 0x5a, 0xb2, 0xf6, 0x97, 0x89, 0x9d, 0x9e, 0xec, 0xfd, 0x65, 0xfc, 0x5f, 0x5a,
		0x16, 0x7f, 0x7a, 0x13, 0x5a, 0xb2, 0xf9, 0x35, 0x40, 0x3d, 0xa3, 0xc2, 0x0b, 0x8a, 0x53, 0x72,
		0xd2, 0x7e, 0xb4, 0xa6, 0xe6, 0xac, 0x27, 0x91, 0x28, 0xc9, 0xd6, 0x51, 0x37, 0xe2, 0x2a, 0x76,
		0x88, 0xc4, 0x92, 0x49, 0x0d, 0xa7, 0x72, 0x4f, 0xbb, 0x31, 0x3c, 0xf8, 0xdd, 0x42, 0xf0, 0xbb,
		0x32, 0x10, 0x1f, 0xc1, 0xef, 0xc3, 0xf5, 0x4e, 0x08, 0x7e, 0xd3, 0xbe, 0x4e, 0x04, 0xbf, 0xa1,
		0xd6, 0x40, 0xad, 0x81, 0x5a, 0x03, 0xb5, 0x66, 0xc3, 0x6a, 0x43, 0xf0, 0xbb, 0xe8, 0x0f, 0x82,
		0xdf, 0x4a, 0xba, 0x45, 0xf0, 0x5b, 0xb5, 0xf8, 0x85, 0xe0, 0xf7, 0x5e, 0x4f, 0x26, 0x04, 0xbf,
		0x4b, 0xbd, 0x7f, 0x04, 0xbf, 0x41, 0xa7, 0x40, 0xa7, 0x40, 0xa7, 0x40, 0xa7, 0x0e, 0x89, 0x4e,
		0x21, 0xf8, 0x8d, 0xe0, 0x77, 0x3e, 0x62, 0x87, 0xe0, 0x37, 0x82, 0xdf, 0x3a, 0x66, 0xf8, 0xc1,
		0x04, 0xbf, 0xa7, 0x31, 0x59, 0x94, 0x30, 0xa9, 0xfe, 0x94, 0x29, 0x7b, 0xaa, 0xd4, 0x95, 0x24,
		0x1e, 0x88, 0xc4, 0x96, 0xc1, 0x0c, 0x16, 0x5c, 0xcf, 0xfb, 0xfc, 0xfa, 0x61, 0x72, 0xc3, 0x9f,
		0x7c, 0x16, 0x7c, 0xbd, 0x8e, 0x86, 0x9d, 0xaf, 0x97, 0xd3, 0xbb, 0xfc, 0xfa, 0x49, 0x88, 0xe8,
		0xcf, 0xf1, 0xfd, 0x7d, 0x4d, 0xbf, 0xfb, 0x71, 0x7e, 0x7b, 0x07, 0x50, 0x6d, 0x45, 0x4d, 0x9e,
		0x86, 0xd2, 0xfc, 0x0c, 0xe5, 0x35, 0x55, 0x5a, 0xa8, 0xa9, 0xa2, 0x8d, 0x5d, 0xa2, 0xa6, 0xca,
		0xfe, 0x79, 0x2d, 0x65, 0x35, 0x55, 0x98, 0x6d, 0xf3, 0x48, 0x5a, 0x83, 0xd0, 0xd1, 0x90, 0x5a,
		0xb6, 0xdc, 0x99, 0xfa, 0x73, 0xa8, 0x5d, 0xe6, 0xc7, 0x1c, 0x25, 0x8d, 0x4b, 0x93, 0xef, 0x90,
		0xc8, 0x66, 0x9c, 0x3c, 0x87, 0x44, 0xb6, 0xd2, 0xe4, 0xb7, 0x74, 0xb5, 0xdc, 0x85, 0xa1, 0xcf,
		0x59, 0xa0, 0xe3, 0xbc, 0xb8, 0xe6, 0x01, 0x67, 0x53, 0x33, 0x67, 0xc8, 0x85, 0xf4, 0xe2, 0x89,
		0x6e, 0x34, 0xe5, 0x66, 0x43, 0xe6, 0x6b, 0xf0, 0x81, 0x9b, 0xfb, 0x55, 0xef, 0x0e, 0x9b, 0x8d,
		0x06, 0x9c, 0x21, 0x9c, 0x21, 0x9c, 0x21, 0x9c, 0xa1, 0x39, 0xce, 0x30, 0xf1, 0x02, 0xd9, 0xec,
		0x6a, 0xf0, 0x85, 0x5d, 0x14, 0xf8, 0xff, 0xfd, 0x83, 0xa0, 0xc0, 0x3f, 0x5d, 0x7f, 0x28, 0xf0,
		0x6f, 0xec, 0x14, 0xe9, 0x34, 0xce, 0x51, 0xe1, 0xbf, 0x72, 0xad, 0xf7, 0x0e, 0x98, 0xcc, 0xd8,
		0x89, 0x10, 0x63, 0x3a, 0x31, 0xdf, 0x91, 0xa4, 0xa1, 0x46, 0xf2, 0x6a, 0x8f, 0xa0, 0x16, 0xa0,
		0x16, 0xa0, 0x16, 0xa0, 0x16, 0x46, 0x51, 0x0b, 0x1c, 0x1d, 0x06, 0x66, 0xa1, 0x0d, 0x36, 0x36,
		0xc0, 0x2c, 0xc0, 0x2c, 0x7e, 0x3d, 0x45, 0x70, 0x74, 0x18, 0x88, 0x45, 0xa5, 0x88, 0x45, 0x24,
		0x38, 0x1f, 0x44, 0x52, 0x3d, 0x9f, 0x98, 0x77, 0xa4, 0x3e, 0x0e, 0x32, 0x46, 0x77, 0x60, 0x2b,
		0x60, 0x2b, 0x60, 0x2b, 0x60, 0x2b, 0xe6, 0xb0, 0x15, 0x64, 0x05, 0xe8, 0xf4, 0x77, 0x96, 0xc3,
		0x7d, 0xf6, 0xa8, 0xcd, 0xeb, 0xcd, 0xba, 0x53, 0xef, 0xfb, 0x90, 0x01, 0x00, 0xc7, 0x07, 0xc7,
		0x07, 0xc7, 0x67, 0x90, 0xe3, 0x43, 0x06, 0xc0, 0xce, 0x3f, 0xd0, 0xe9, 0x48, 0x44, 0x18, 0xe8,
		0x74, 0xc5, 0xa6, 0xc8, 0x01, 0xe8, 0x74, 0xed, 0x6e, 0xa3, 0x01, 0xa1, 0xae, 0x6a, 0xad, 0x1f,
		0xb6, 0x50, 0xa7, 0x2b, 0xf2, 0xaf, 0x3a, 0xe2, 0x8f, 0x94, 0x65, 0x10, 0x16, 0x10, 0x16, 0x10,
		0x16, 0x93, 0x09, 0x0b, 0xf2, 0x0a, 0xc0, 0x57, 0xb4, 0x81, 0x51, 0x64, 0x2c, 0x83, 0xaf, 0xfc,
		0x66, 0x8a, 0x68, 0xab, 0x16, 0x0a, 0xba, 0x02, 0xba, 0xb2, 0xcb, 0x34, 0x19, 0x7a, 0x42, 0x26,
		0xcc, 0xb7, 0x66, 0x85, 0x6d, 0xd4, 0xb3, 0x96, 0xd5, 0x0e, 0x41, 0x2b, 0x40, 0x2b, 0x40, 0x2b,
		0x40, 0x2b, 0x8c, 0xa1, 0x15, 0x5e, 0xa4, 0xd8, 0x76, 0x2d, 0xdb, 0xaf, 0xe6, 0xb9, 0xc2, 0x3e,
		0x66, 0xef, 0xcc, 0x78, 0x6e, 0xb1, 0x18, 0x99, 0x61, 0x47, 0xc3, 0xd8, 0xac, 0x8d, 0xd1, 0x99,
		0x9e, 0x62, 0xa9, 0x92, 0x8b, 0x40, 0xdb, 0x01, 0x14, 0xf5, 0xff, 0x3c, 0x7f, 0xfe, 0xb9, 0x61,
		0x9d, 0xf7, 0x7e, 0x7e, 0x6e, 0x5a, 0xe7, 0xbd, 0xe9, 0xc7, 0xe6, 0xe4, 0x7f, 0xd3, 0xcf, 0xad,
		0xcf, 0x0d, 0xab, 0x33, 0xff, 0x7c, 0xf2, 0xb9, 0x61, 0x9d, 0xf4, 0x8e, 0xbe, 0x7c, 0x79, 0x79,
		0xf4, 0xa3, 0x3d, 0xca, 0x7e, 0xe1, 0xbf, 0xd4, 0x17, 0x1d, 0xee, 0xe9, 0x18, 0xa4, 0xf7, 0xb7,
		0xd7, 0xff, 0x60, 0xa4, 0x2a, 0x09, 0xc7, 0x35, 0x31, 0x59, 0xbd, 0xe6, 0xae, 0x0b, 0x73, 0x47,
		0xbb, 0x88, 0x98, 0xe5, 0x5e, 0x5a, 0x6f, 0x7a, 0x3f, 0x9a, 0x2f, 0x3a, 0xa3, 0x8b, 0xa3, 0x1f,
		0xa7, 0xa3, 0xd5, 0x3f, 0xfe, 0xdc, 0xf4, 0xb5, 0xe6, 0x8b, 0xd3, 0xd1, 0xc5, 0x96, 0x7f, 0xe9,
		0x8e, 0x2e, 0x76, 0x6c, 0xe3, 0x64, 0xf4, 0x7c, 0xed, 0xab, 0xe3, 0xbf, 0xb7, 0xb6, 0x5d, 0xd0,
		0xd9, 0x72, 0x41, 0x7b, 0xdb, 0x05, 0xed, 0x2d, 0x17, 0x6c, 0xbd, 0xa5, 0xd6, 0x96, 0x0b, 0x4e,
		0x46, 0x3f, 0xd7, 0xbe, 0xff, 0x7c, 0xf3, 0x57, 0xbb, 0xa3, 0xa3, 0x9f, 0xdb, 0xfe, 0xed, 0x74,
		0xf4, 0xf3, 0xe2, 0x08, 0xc6, 0x1f, 0xf3, 0x16, 0xf3, 0xb6, 0x14, 0x57, 0x68, 0x9a, 0xa2, 0xa6,
		0x88, 0x3b, 0x6a, 0x29, 0xcb, 0xaf, 0xaf, 0x1c, 0x7f, 0xa9, 0x65, 0xf8, 0xf5, 0x94, 0xdf, 0x37,
		0x4b, 0x5b, 0x9d, 0xd4, 0x13, 0x17, 0x96, 0xe7, 0xe8, 0x53, 0x57, 0x17, 0x5d, 0x42, 0x5f, 0x85,
		0xbe, 0x0a, 0x7d, 0x15, 0xfa, 0xaa, 0x31, 0xfa, 0x2a, 0xd2, 0x36, 0x2a, 0xa4, 0x35, 0x20, 0x6d,
		0x83, 0xae, 0x3f, 0xa4, 0x6d, 0x18, 0x3b, 0x45, 0x50, 0x0e, 0xe2, 0x70, 0x48, 0x26, 0x8e, 0x61,
		0x22, 0x6d, 0x5f, 0xeb, 0x31, 0x4c, 0x0a, 0x8e, 0xe7, 0xaa, 0xe6, 0xd1, 0x46, 0xea, 0xa9, 0xa5,
		0x36, 0x4a, 0xa9, 0xc8, 0xa6, 0x2b, 0xa3, 0x90, 0x38, 0xf2, 0xa8, 0x0a, 0x14, 0x11, 0x47, 0x1e,
		0x69, 0xf3, 0x10, 0xca, 0xa8, 0x9f, 0x86, 0x03, 0x6e, 0x55, 0x1e, 0x68, 0x9b, 0x1e, 0x60, 0xfb,
		0xf2, 0xe5, 0xd4, 0xf1, 0x1c, 0xaf, 0x9b, 0xca, 0xaa, 0xba, 0xa2, 0x67, 0x15, 0x9a, 0x68, 0x63,
		0x9b, 0xa1, 0xd2, 0xd1, 0xa8, 0xd1, 0xf7, 0xd5, 0xe9, 0xf9, 0x5a, 0xf5, 0x7b, 0x35, 0x7a, 0x3d,
		0xd5, 0xcc, 0x50, 0x04, 0x4e, 0xb5, 0x82, 0xd2, 0x3a, 0xe9, 0x89, 0x96, 0x39, 0x0f, 0x00, 0xa5,
		0x31, 0x44, 0xc5, 0xcd, 0x46, 0xb1, 0x16, 0x0a, 0x4e, 0x2b, 0xea, 0xe9, 0xa4, 0x7e, 0x1a, 0x15,
		0x1b, 0xb6, 0xfc, 0x2f, 0x3b, 0xdf, 0x95, 0x39, 0x87, 0x67, 0x6e, 0xff, 0x73, 0x03, 0x5e, 0x1a,
		0x03, 0x4f, 0x67, 0xd0, 0x95, 0x1a, 0x70, 0x1a, 0x83, 0x9d, 0x77, 0xa8, 0x2e, 0x93, 0xfb, 0xf1,
		0x63, 0x71, 0xa7, 0x90, 0xb8, 0x5d, 0x6c, 0xe9, 0xa5, 0xb0, 0xf1, 0x78, 0x0c, 0xc7, 0xdd, 0x8b,
		0xa5, 0x05, 0xb6, 0xf2, 0x87, 0xf1, 0xef, 0xe3, 0x25, 0x76, 0xb1, 0xbc, 0xdc, 0x26, 0x18, 0xfe,
		0x62, 0xb2, 0xe8, 0xa6, 0x1f, 0x17, 0x4b, 0xef, 0xc9, 0xef, 0x05, 0xed, 0x76, 0xfd, 0x8a, 0xc7,
		0xb6, 0xf0, 0xa2, 0x99, 0xb5, 0xa9, 0x5f, 0x3a, 0x8e, 0x37, 0xfe, 0xcc, 0xfc, 0xda, 0xf5, 0x4d,
		0x6d, 0xdc, 0x47, 0xcd, 0x65, 0x03, 0xcf, 0x7f, 0xac, 0x4d, 0x4d, 0x46, 0x22, 0x26, 0x86, 0xa9,
		0xe6, 0x86, 0xe2, 0x4b, 0xb0, 0x78, 0xa4, 0xa2, 0x77, 0x41, 0x73, 0x9e, 0x30, 0x19, 0x99, 0xa6,
		0x24, 0xcf, 0xe4, 0x64, 0x99, 0x9a, 0x1c, 0x2b, 0x23, 0xc3, 0xca, 0xc8, 0xaf, 0x0a, 0xb2, 0x5b,
		0xae, 0xcb, 0xa7, 0x3a, 0xaf, 0xb7, 0x3e, 0x71, 0xc7, 0x64, 0x33, 0x23, 0x15, 0xd7, 0xc6, 0xad,
		0x12, 0x8d, 0xdd, 0x8a, 0xc1, 0x79, 0x1d, 0xd8, 0x7e, 0x18, 0x7b, 0xc1, 0xfd, 0xd8, 0xc0, 0x48,
		0xe6, 0x05, 0x5c, 0x8c, 0x8d, 0x4b, 0xed, 0xd3, 0x87, 0x0f, 0x37, 0xb5, 0x09, 0x32, 0x8d, 0x6b,
		0x7d, 0x16, 0x38, 0x3e, 0x77, 0x6a, 0x77, 0x8f, 0x35, 0xd9, 0xf7, 0xe2, 0x2f, 0xc1, 0xf5, 0x4d,
		0x2d, 0xb5, 0x3d, 0x54, 0xf7, 0x45, 0x7b, 0xa4, 0x39, 0xb9, 0xae, 0xa7, 0x42, 0xcf, 0x53, 0xa6,
		0xe3, 0xa9, 0xd2, 0xef, 0x94, 0xeb, 0x76, 0xca, 0xf5, 0x3a, 0x95, 0x3a, 0xdd, 0x68, 0x3f, 0xd8,
		0x93, 0x66, 0x3a, 0xd0, 0xcb, 0x8b, 0x31, 0x69, 0x58, 0x9a, 0x52, 0x76, 0x56, 0x60, 0x75, 0x64,
		0x25, 0xf1, 0xf9, 0xa6, 0x71, 0xf6, 0x21, 0xcb, 0x76, 0x45, 0x46, 0xbf, 0x5c, 0x74, 0x50, 0x95,
		0x0c, 0x66, 0xb6, 0x37, 0xbb, 0xfb, 0xfb, 0xc9, 0xf0, 0x6e, 0xea, 0xf6, 0xdc, 0x9b, 0x65, 0x7b,
		0x27, 0x8b, 0xe3, 0xbf, 0xa6, 0xd7, 0x67, 0x1c, 0x8d, 0x7c, 0x2e, 0x39, 0xb7, 0xeb, 0x2d, 0xe2,
		0x62, 0x0b, 0xbb, 0xd2, 0xa2, 0x2e, 0x93, 0xcc, 0x35, 0x92, 0xb9, 0x40, 0x0a, 0x57, 0xa7, 0x76,
		0xb5, 0xe7, 0x45, 0xdd, 0x75, 0xa7, 0x6f, 0x47, 0x96, 0xed, 0x7b, 0xd3, 0x87, 0xcb, 0x39, 0x60,
		0xf3, 0x19, 0xb3, 0xdc, 0x58, 0xce, 0x37, 0xbd, 0x54, 0x03, 0xcf, 0x65, 0x7e, 0x9c, 0x17, 0x13,
		0x17, 0x8c, 0x71, 0x17, 0xc6, 0xbc, 0x14, 0x18, 0x97, 0x0c, 0xd3, 0x52, 0x61, 0x58, 0x72, 0xcc,
		0x4a, 0x8e, 0x51, 0x29, 0x31, 0xa9, 0x5e, 0x49, 0xb6, 0x70, 0xcc, 0x97, 0xf0, 0xbc, 0x84, 0x82,
		0xe7, 0x21, 0xe4, 0x40, 0x42, 0x39, 0x9c, 0x0c, 0x0f, 0xd8, 0x9d, 0xcf, 0x9d, 0xe2, 0x46, 0x6b,
		0xde, 0x50, 0x71, 0x83, 0x55, 0xe0, 0x7c, 0x1d, 0xd8, 0x2b, 0xd8, 0x2b, 0xd8, 0xab, 0x7d, 0xb6,
		0x57, 0x03, 0x99, 0x14, 0xb7, 0x55, 0xe3, 0x46, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x32, 0xcc,
		0x96, 0xc2, 0xe7, 0x68, 0x10, 0x9c, 0x93, 0x41, 0xb4, 0x41, 0x89, 0x20, 0xac, 0x42, 0xb9, 0xc1,
		0x88, 0x38, 0x93, 0x38, 0xdd, 0xfd, 0xd1, 0x25, 0xaa, 0x78, 0xa2, 0x62, 0x73, 0x07, 0x41, 0xa6,
		0x15, 0xe9, 0x0e, 0x9e, 0xf9, 0x18, 0xb4, 0x89, 0xc7, 0xa0, 0x51, 0xe1, 0x21, 0x28, 0x49, 0x95,
		0xef, 0x41, 0x18, 0xa6, 0x15, 0x86, 0x67, 0x5a, 0x6a, 0x05, 0x54, 0xe1, 0x80, 0x7b, 0xf7, 0xfd,
		0xbb, 0x50, 0xc4, 0xf9, 0x85, 0xe1, 0x45, 0x13, 0xd0, 0x86, 0x95, 0x21, 0x2f, 0x68, 0xc3, 0x1a,
		0xb5, 0xe1, 0xf9, 0x8c, 0x2e, 0xce, 0x5b, 0xd2, 0x96, 0x8a, 0x91, 0x97, 0x26, 0xc8, 0x0b, 0xc8,
		0x8b, 0x09, 0xe4, 0xa5, 0x68, 0x12, 0x54, 0xde, 0x28, 0xe5, 0xd6, 0x49, 0x97, 0x2b, 0x6a, 0x49,
		0xbc, 0x0c, 0xc9, 0x96, 0x23, 0xe5, 0xb2, 0x24, 0x5f, 0x9e, 0xd4, 0xcb, 0x54, 0xd9, 0x72, 0x55,
		0xb6, 0x6c, 0x55, 0x2c, 0x5f, 0x22, 0xe8, 0x5f, 0x95, 0xdc, 0x46, 0x4f, 0x41, 0x66, 0x23, 0x59,
		0xda, 0x1b, 0x35, 0xab, 0x47, 0xfe, 0x20, 0xf2, 0x07, 0x35, 0x99, 0x07, 0x1a, 0x33, 0x41, 0x28,
		0xf5, 0xd4, 0x94, 0xec, 0xe7, 0x55, 0x5d, 0x80, 0x5d, 0x45, 0xe5, 0x61, 0x65, 0x15, 0x86, 0x8d,
		0x2d, 0xc7, 0xdd, 0xa3, 0x7c, 0xb9, 0x2a, 0x6b, 0xe1, 0x9a, 0xfb, 0x86, 0xab, 0x92, 0x46, 0x4c,
		0x00, 0x27, 0x7d, 0x2f, 0xf8, 0x66, 0xf9, 0xec, 0x91, 0x0b, 0xf2, 0xa3, 0x83, 0x16, 0x65, 0x01,
		0xd6, 0xfb, 0x00, 0xa4, 0x00, 0xa4, 0x00, 0xa4, 0x38, 0x20, 0x48, 0x11, 0xf5, 0x1f, 0x63, 0x40,
		0x8a, 0x27, 0x55, 0xce, 0x57, 0x8b, 0x9b, 0xb7, 0x46, 0x47, 0xff, 0x75, 0xf4, 0x3f, 0x07, 0x8a,
		0x04, 0xf4, 0xbe, 0x18, 0x54, 0x51, 0xa8, 0x76, 0x15, 0x85, 0x34, 0xe8, 0x95, 0x7e, 0xca, 0x15,
		0xd4, 0xa3, 0x7b, 0xdf, 0x05, 0xde, 0x35, 0x85, 0x2a, 0x43, 0xa7, 0xc6, 0x10, 0x41, 0x26, 0x88,
		0xad, 0x95, 0x82, 0x42, 0x10, 0x5b, 0xf5, 0x43, 0x1c, 0x05, 0x55, 0xcf, 0x28, 0xab, 0x9c, 0xad,
		0x57, 0x35, 0xf3, 0x22, 0x13, 0xad, 0xe7, 0xb4, 0x14, 0x28, 0x99, 0x01, 0x9d, 0x36, 0x57, 0xb1,
		0x80, 0x55, 0x0b, 0x36, 0x14, 0x36, 0xd4, 0x20, 0x1b, 0x8a, 0x80, 0x15, 0xd4, 0x25, 0xa8, 0x4b,
		0x50, 0x97, 0x2a, 0xa3, 0x2e, 0x21, 0x60, 0x85, 0x80, 0x55, 0x0d, 0x01, 0xab, 0xca, 0xeb, 0x5d,
		0x08, 0x58, 0x01, 0x52, 0x00, 0x52, 0x00, 0x52, 0x20, 0x60, 0x85, 0x80, 0x95, 0xe1, 0x48, 0xe0,
		0x30, 0x03, 0x56, 0x04, 0x0e, 0x3c, 0x14, 0xde, 0x3d, 0xe5, 0x66, 0xd1, 0xd4, 0xbd, 0x4c, 0xdb,
		0x85, 0xa3, 0x86, 0xa3, 0x86, 0xa3, 0x3e, 0x20, 0x47, 0x3d, 0x8f, 0x10, 0x5b, 0xa4, 0x06, 0xe0,
		0x89, 0xaf, 0xee, 0x10, 0xb6, 0xf9, 0x3a, 0x48, 0x06, 0xe3, 0x17, 0x31, 0x42, 0x0e, 0x82, 0x71,
		0x39, 0x08, 0x04, 0xc7, 0xd2, 0xe1, 0x2c, 0x87, 0x4c, 0xad, 0xe0, 0x2c, 0x07, 0x6d, 0x6b, 0x48,
		0xed, 0xda, 0xd1, 0x51, 0x68, 0xf7, 0xaf, 0x79, 0x5f, 0x28, 0xa8, 0xa0, 0x68, 0x38, 0xab, 0x50,
		0x53, 0x21, 0x12, 0xe1, 0xc3, 0xa3, 0xc5, 0x72, 0x54, 0xf1, 0x5f, 0x70, 0xfb, 0xb4, 0x09, 0xd4,
		0x54, 0x50, 0x86, 0xda, 0x51, 0x53, 0x41, 0x63, 0x4d, 0x85, 0x82, 0x1b, 0xbb, 0x69, 0x36, 0x74,
		0xa3, 0x9e, 0x82, 0x02, 0xd2, 0x8b, 0x7a, 0x0a, 0xea, 0x90, 0x53, 0xe1, 0x7a, 0x0a, 0x83, 0xd0,
		0x21, 0xcc, 0x4d, 0x9b, 0xb4, 0x56, 0xf8, 0xb4, 0xaa, 0xb4, 0x6e, 0xec, 0xd5, 0xf5, 0xed, 0xe5,
		0x1f, 0x6f, 0x5f, 0x23, 0x61, 0x58, 0x9f, 0xe2, 0x85, 0x64, 0x37, 0x24, 0x0c, 0xff, 0x7e, 0xb6,
		0xf1, 0x20, 0x19, 0xf0, 0xe9, 0x31, 0x71, 0x94, 0x49, 0xc3, 0x04, 0x2a, 0x15, 0x91, 0x3a, 0x65,
		0x8a, 0xc8, 0x51, 0x41, 0xe6, 0x9c, 0x52, 0x93, 0x42, 0x1b, 0x5e, 0xf4, 0xd4, 0x1e, 0x2e, 0x96,
		0x9a, 0x4d, 0x92, 0x92, 0x4d, 0x06, 0x39, 0x5b, 0x80, 0x9c, 0x80, 0x9c, 0x80, 0x9c, 0x80, 0x9c,
		0x80, 0x9c, 0x80, 0x9c, 0x80, 0x9c, 0x80, 0x9c, 0x87, 0x08, 0x39, 0x0b, 0xc4, 0x37, 0x11, 0x3d,
		0xf9, 0xfd, 0xfb, 0xad, 0xe7, 0xc2, 0xd8, 0xbb, 0xc5, 0xbe, 0x6e, 0xc6, 0x9d, 0x5c, 0x8a, 0xa8,
		0x0a, 0x11, 0x9a, 0x7c, 0xbc, 0xa0, 0x10, 0x1f, 0x28, 0x1c, 0x99, 0x69, 0x21, 0x32, 0x53, 0xa2,
		0x4b, 0xdf, 0xeb, 0xc8, 0x4c, 0x32, 0x5e, 0xb4, 0x31, 0x45, 0x6c, 0x66, 0xd6, 0x12, 0xa2, 0x33,
		0xa0, 0xca, 0xa0, 0xca, 0xbf, 0x6f, 0xc0, 0x0b, 0x2c, 0xc7, 0x8b, 0x6d, 0x26, 0x1c, 0xee, 0x58,
		0xd1, 0x37, 0x19, 0x13, 0xd6, 0x61, 0x59, 0x6b, 0x1a, 0x94, 0x17, 0x94, 0x17, 0x94, 0xb7, 0x42,
		0x94, 0x77, 0xe6, 0x2e, 0xbb, 0x1d, 0x42, 0xc2, 0x4b, 0xb0, 0x69, 0x87, 0xe8, 0xc8, 0xae, 0xf9,
		0x0f, 0x61, 0x42, 0x35, 0xe5, 0x11, 0x5e, 0xc4, 0x76, 0x6d, 0xad, 0x59, 0xe2, 0xe3, 0xa4, 0xd2,
		0x76, 0x15, 0x1c, 0x2b, 0x45, 0xb4, 0x42, 0x9e, 0x0e, 0x15, 0x7b, 0x30, 0x6e, 0xa8, 0x68, 0x53,
		0x6e, 0xb5, 0x8f, 0x5e, 0x45, 0xd2, 0xf5, 0x7b, 0x26, 0x16, 0xc0, 0x0b, 0x2c, 0x2e, 0x44, 0x28,
		0xe8, 0x31, 0xd8, 0x52, 0xb3, 0xc0, 0x5f, 0xc0, 0x5f, 0xc0, 0x5f, 0xc0, 0x5f, 0xc0, 0x5f, 0xc0,
		0x5f, 0xc0, 0x5f, 0xc0, 0x5f, 0xc0, 0x5f, 0xcb, 0xf8, 0xcb, 0x0d, 0xc5, 0xf7, 0xa9, 0x58, 0x15,
		0xda, 0x92, 0x13, 0xa3, 0xb0, 0xb5, 0xc6, 0x81, 0xc5, 0x80, 0xc5, 0x80, 0xc5, 0x80, 0xc5, 0x80,
		0xc5, 0x80, 0xc5, 0x80, 0xc5, 0x80, 0xc5, 0x80, 0xc5, 0x36, 0x63, 0x31, 0x72, 0x3d, 0x6c, 0xa5,
		0x69, 0xe0, 0x30, 0xe0, 0x30, 0xe0, 0x30, 0xe0, 0x30, 0xe0, 0x30, 0xe0, 0x30, 0xe0, 0x30, 0xe0,
		0x30, 0xe0, 0xb0, 0x65, 0x1c, 0xa6, 0x40, 0x09, 0x83, 0xfe, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc,
		0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0xb5, 0x01, 0x77, 0x91, 0xab, 0x5e,
		0xd0, 0xba, 0x80, 0xb9, 0x80, 0xb9, 0x80, 0xb9, 0x80, 0xb9, 0x80, 0xb9, 0x80, 0xb9, 0x80, 0xb9,
		0x80, 0xb9, 0x9e, 0x0e, 0x4b, 0x98, 0x48, 0x65, 0x1b, 0x21, 0x37, 0xb4, 0x0d, 0x24, 0x06, 0x24,
		0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0xf6, 0x04,
		0x89, 0xa9, 0xd8, 0x0a, 0xb9, 0xd2, 0x2e, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10,
		0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0xd8, 0x13, 0x04, 0xa6, 0x6e, 0x33, 0xe4, 0xc6,
		0xd6, 0x81, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0x80,
		0xc6, 0x80, 0xc6, 0xb6, 0xa0, 0x31, 0x7a, 0x4d, 0x0c, 0xfb, 0x21, 0x81, 0xc4, 0x80, 0xc4, 0x80,
		0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x7e, 0x85, 0xc4, 0x54, 0xa8,
		0x61, 0xd0, 0xc0, 0x80, 0xbc, 0x80, 0xbc, 0x80, 0xbc, 0x80, 0xbc, 0x80, 0xbc, 0x80, 0xbc, 0x80,
		0xbc, 0x80, 0xbc, 0x36, 0x21, 0x2f, 0x7a, 0xe5, 0x0b, 0x7a, 0x17, 0x50, 0x17, 0x50, 0x17, 0x50,
		0x17, 0x50, 0x17, 0x50, 0x17, 0x50, 0x17, 0x50, 0xd7, 0x5e, 0xa2, 0xae, 0x43, 0x3f, 0xb9, 0x7b,
		0x72, 0x52, 0xf2, 0x71, 0xc1, 0x73, 0x61, 0x6b, 0x59, 0x8e, 0x99, 0x7e, 0x35, 0xef, 0x4b, 0xd7,
		0x21, 0xe1, 0x39, 0x4e, 0x47, 0x76, 0xfa, 0x76, 0x64, 0xd9, 0xbe, 0x37, 0x85, 0x22, 0x05, 0x0f,
		0xdd, 0x5d, 0x6e, 0x2c, 0xef, 0x39, 0xa6, 0xdc, 0x65, 0x89, 0x3f, 0x81, 0x45, 0x2e, 0xf3, 0x63,
		0x5e, 0xf0, 0xfc, 0xde, 0x06, 0xce, 0xef, 0xc5, 0xf9, 0xbd, 0x26, 0x18, 0xcc, 0xc2, 0xf0, 0x39,
		0x9d, 0x2d, 0x77, 0x61, 0xe8, 0x73, 0x16, 0x14, 0x99, 0x2f, 0xf3, 0xc3, 0xaf, 0x9b, 0x15, 0x36,
		0x5c, 0x3c, 0x60, 0x77, 0x3e, 0x77, 0x8a, 0x1b, 0xad, 0x79, 0x43, 0xc5, 0x0d, 0xd6, 0x78, 0xfe,
		0xc2, 0x5e, 0xc1, 0x5e, 0xc1, 0x5e, 0xc1, 0x5e, 0xad, 0xdd, 0xe3, 0x40, 0x26, 0xc5, 0x6d, 0xd5,
		0xb8, 0x11, 0x18, 0x18, 0x18, 0x18, 0x18, 0x98, 0x0c, 0xb3, 0x25, 0xf1, 0x02, 0xd9, 0xec, 0x12,
		0xd8, 0x97, 0x6e, 0x81, 0x26, 0x68, 0x44, 0x43, 0x02, 0x75, 0x95, 0x52, 0x24, 0x24, 0x56, 0x9c,
		0x52, 0xa5, 0xa9, 0x7b, 0x46, 0xd4, 0xa0, 0x02, 0x3d, 0x89, 0x40, 0x05, 0x24, 0x55, 0xff, 0xe6,
		0x63, 0xd0, 0x26, 0x1e, 0x83, 0x46, 0x85, 0x87, 0xa0, 0x24, 0x09, 0xad, 0xa7, 0x0b, 0x5e, 0x3c,
		0x53, 0x38, 0x21, 0x8b, 0x4a, 0x73, 0xe4, 0x92, 0x5c, 0x36, 0x87, 0xb4, 0xfb, 0xbb, 0xc9, 0xf0,
		0x5e, 0xea, 0x49, 0x10, 0x24, 0x83, 0x3b, 0x2e, 0x72, 0xf0, 0xc9, 0x85, 0x9b, 0x59, 0xb4, 0x91,
		0x71, 0x44, 0xe6, 0xf0, 0x35, 0xe3, 0x65, 0x79, 0x21, 0x59, 0x11, 0x28, 0xf6, 0x04, 0x82, 0xb9,
		0x39, 0x7c, 0x6a, 0x51, 0xe8, 0x45, 0x06, 0xb9, 0xc8, 0xa0, 0xd6, 0x1a, 0xc4, 0x72, 0xeb, 0x15,
		0x5b, 0xf1, 0x57, 0x9e, 0xc8, 0x37, 0xd8, 0xf6, 0x7c, 0x86, 0x15, 0xa4, 0x2d, 0xb3, 0x76, 0x8a,
		0x31, 0x97, 0xe6, 0xbe, 0x30, 0x17, 0x17, 0xcc, 0x45, 0xd3, 0xb2, 0x2a, 0x87, 0xb9, 0xe4, 0x5d,
		0x6e, 0x64, 0xd2, 0x26, 0xb1, 0xc4, 0xb9, 0x78, 0x30, 0x9a, 0xd8, 0x0c, 0x31, 0x7b, 0xa8, 0x7e,
		0xca, 0x94, 0x8b, 0x94, 0x29, 0x8a, 0x86, 0x09, 0x0d, 0x02, 0x11, 0x93, 0xa8, 0x5c, 0xca, 0x54,
		0x71, 0x2d, 0x75, 0xcd, 0xeb, 0x36, 0x0f, 0x22, 0x5f, 0xe1, 0xf5, 0xc3, 0x84, 0x9b, 0xe6, 0x57,
		0x67, 0xe8, 0xdc, 0x71, 0x68, 0x5b, 0xfc, 0x41, 0x5e, 0x48, 0xee, 0xf3, 0x01, 0x97, 0xe2, 0xd1,
		0x0a, 0x03, 0xcb, 0xee, 0x4f, 0xe4, 0x23, 0x52, 0x17, 0x3d, 0x31, 0xe1, 0x84, 0x3e, 0x5a, 0xb7,
		0x7b, 0xee, 0xed, 0x4f, 0x6a, 0xca, 0x82, 0x3a, 0x1e, 0xcf, 0xa0, 0x72, 0x85, 0x03, 0x19, 0xe9,
		0x73, 0x58, 0x82, 0xbb, 0xc5, 0xb9, 0xc1, 0xd3, 0xe6, 0x40, 0x11, 0x40, 0x11, 0x40, 0x11, 0x94,
		0x33, 0x73, 0x5a, 0x86, 0x4e, 0xb4, 0x0c, 0x01, 0xe8, 0x01, 0xe8, 0xcd, 0x06, 0xf4, 0x45, 0x97,
		0xf5, 0xba, 0x8f, 0xa5, 0x9b, 0x1e, 0x6b, 0xfe, 0x96, 0x6a, 0x7a, 0x10, 0xc7, 0x00, 0xa9, 0x16,
		0xbf, 0x0a, 0x23, 0xa0, 0xcc, 0x18, 0xa8, 0x32, 0x0a, 0xca, 0x8d, 0x83, 0x72, 0x23, 0xa1, 0xd2,
		0x58, 0xd0, 0x18, 0x0d, 0x22, 0xe3, 0x41, 0xaf, 0x0a, 0xac, 0xcd, 0x56, 0x9f, 0x33, 0x37, 0x3f,
		0xc8, 0xfe, 0xa5, 0xc7, 0x3f, 0x25, 0x6c, 0xf3, 0x26, 0xa5, 0x54, 0xe3, 0x61, 0xbe, 0x58, 0xa2,
		0x50, 0x2b, 0x7f, 0x98, 0xfd, 0x3e, 0x49, 0xc4, 0xaf, 0xc8, 0xee, 0x0e, 0x8a, 0xec, 0x80, 0x38,
		0xb9, 0x53, 0x68, 0xff, 0x9f, 0xb4, 0x0e, 0x17, 0x00, 0x17, 0x00, 0x17, 0x00, 0x17, 0x60, 0xac,
		0x0b, 0xf8, 0xbc, 0x70, 0x01, 0xff, 0x6d, 0x27, 0x42, 0xf0, 0x40, 0x3e, 0x3f, 0x3a, 0x7e, 0xf9,
		0x72, 0xa1, 0xb6, 0xf5, 0x66, 0x97, 0x2c, 0xdb, 0xbd, 0x78, 0xc3, 0xdf, 0xd2, 0x96, 0x1d, 0xfe,
		0x50, 0x19, 0x6f, 0x52, 0x2a, 0x9b, 0x29, 0xac, 0x89, 0xcf, 0x7f, 0xe8, 0x09, 0xae, 0x32, 0x8d,
		0x7c, 0x8b, 0x31, 0x23, 0xd0, 0xca, 0x37, 0x5a, 0xb1, 0xb2, 0x09, 0x6f, 0xaf, 0xa8, 0x00, 0x47,
		0xa3, 0xa5, 0x2f, 0xa0, 0x8f, 0x12, 0x4d, 0xfd, 0x89, 0xc4, 0x5c, 0x48, 0x61, 0x2f, 0xfe, 0xd6,
		0x47, 0x85, 0xf6, 0x9d, 0x32, 0xc9, 0xe9, 0x34, 0xbf, 0x69, 0x73, 0x15, 0x93, 0xfc, 0x5a, 0x90,
		0xfc, 0x20, 0xf9, 0x41, 0xf2, 0x83, 0xe4, 0x07, 0xbe, 0x07, 0xbe, 0x07, 0xbe, 0x07, 0xbe, 0x07,
		0xc9, 0x0f, 0x92, 0x1f, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x24, 0x3f, 0xc5, 0x6c,
		0xc6, 0x44, 0x3d, 0x27, 0xc7, 0x26, 0x42, 0x42, 0x39, 0xe7, 0xd0, 0xab, 0xaa, 0x6d, 0x1b, 0x16,
		0x1d, 0xf5, 0xd5, 0xfe, 0x4e, 0xfb, 0xfe, 0x9a, 0x7e, 0xe9, 0x03, 0x77, 0xab, 0x9c, 0x3c, 0x5b,
		0x4c, 0xc2, 0x23, 0x91, 0xee, 0xc8, 0x92, 0x65, 0x5b, 0x48, 0x96, 0x55, 0x07, 0xb5, 0x90, 0x2c,
		0x4b, 0x26, 0xb1, 0x61, 0x3f, 0x5d, 0x39, 0x5c, 0x0c, 0x5a, 0x7c, 0xa5, 0x39, 0x16, 0xf6, 0xd3,
		0xfd, 0x7e, 0xb6, 0x61, 0x3f, 0xdd, 0x5e, 0x22, 0xd5, 0x02, 0x94, 0x01, 0xd5, 0x5c, 0x76, 0x78,
		0xc1, 0xf5, 0x5c, 0xc8, 0x38, 0x2b, 0xe8, 0x57, 0x56, 0x38, 0xe6, 0x19, 0xe1, 0x40, 0xe5, 0x1d,
		0x20, 0xc2, 0x81, 0xc9, 0x30, 0x1a, 0xbb, 0x8e, 0xc2, 0x6e, 0xaf, 0xfe, 0xf7, 0x2f, 0x72, 0x87,
		0x97, 0x58, 0xf7, 0xa2, 0x61, 0x77, 0xe7, 0x57, 0xb7, 0x88, 0x79, 0x8e, 0xaf, 0xda, 0x71, 0x88,
		0xb2, 0x11, 0xa2, 0xcc, 0xf8, 0x28, 0x0f, 0x0e, 0xca, 0x5d, 0xea, 0x30, 0x2f, 0xae, 0x29, 0x8c,
		0x5f, 0x0a, 0xe3, 0x94, 0x22, 0xa5, 0x0a, 0x69, 0x97, 0x6c, 0x56, 0xc2, 0x51, 0x67, 0x8e, 0x23,
		0x78, 0x1c, 0xf3, 0x38, 0x7f, 0xf5, 0xa8, 0x45, 0x13, 0x07, 0x52, 0x3c, 0x2a, 0x42, 0xf1, 0x28,
		0xa2, 0xfa, 0x9c, 0x15, 0x2d, 0x1e, 0x35, 0x9b, 0xd1, 0xc5, 0xc5, 0xae, 0x79, 0x43, 0xd8, 0x1b,
		0x8e, 0xc2, 0xb7, 0x5a, 0x17, 0x96, 0xa1, 0x72, 0x17, 0xf6, 0x86, 0x97, 0x29, 0x4e, 0xe1, 0x7c,
		0x3c, 0x25, 0xe2, 0x54, 0x84, 0x44, 0xd1, 0x94, 0x0f, 0x29, 0xc8, 0x10, 0x8d, 0x90, 0x17, 0x54,
		0x9d, 0xe5, 0xaf, 0xca, 0x0c, 0x28, 0x37, 0x07, 0xca, 0xcd, 0x82, 0x4a, 0xf3, 0x40, 0x63, 0x26,
		0x88, 0xcc, 0x45, 0xfa, 0xa0, 0xea, 0xf2, 0x82, 0xbc, 0x68, 0xd8, 0xb5, 0x8a, 0x61, 0xeb, 0x5f,
		0x3a, 0xfa, 0x33, 0xda, 0xe4, 0x20, 0xc9, 0x45, 0x40, 0x76, 0xe8, 0x66, 0xda, 0xf0, 0x7f, 0x9e,
		0x3f, 0xff, 0xdc, 0xb0, 0xce, 0x99, 0xe5, 0x5e, 0x5a, 0x6f, 0x7a, 0x3f, 0x9a, 0x2f, 0x3a, 0xa3,
		0x8b, 0xa3, 0x1f, 0xa7, 0xa3, 0xd5, 0x3f, 0xfe, 0xdc, 0xf4, 0xb5, 0xe6, 0x8b, 0xd3, 0xd1, 0xc5,
		0x96, 0x7f, 0xe9, 0x8e, 0x2e, 0x76, 0x6c, 0xe3, 0x64, 0xf4, 0x7c, 0xed, 0xab, 0xe3, 0xbf, 0xb7,
		0xb6, 0x5d, 0xd0, 0xd9, 0x72, 0x41, 0x7b, 0xdb, 0x05, 0xed, 0x2d, 0x17, 0x6c, 0xbd, 0xa5, 0xd6,
		0x96, 0x0b, 0x4e, 0x46, 0x3f, 0xd7, 0xbe, 0xff, 0x7c, 0xf3, 0x57, 0xbb, 0xa3, 0xa3, 0x9f, 0xdb,
		0xfe, 0xed, 0x74, 0xf4, 0xf3, 0xe2, 0xe8, 0xe8, 0x5f, 0x74, 0x4b, 0xb6, 0x47, 0x39, 0xd5, 0xde,
		0xdf, 0x5e, 0xff, 0x83, 0xf9, 0x86, 0xf9, 0xf6, 0xab, 0xf9, 0xb6, 0x47, 0xa9, 0xe7, 0x53, 0x00,
		0x60, 0xf9, 0x3c, 0xb8, 0x9f, 0x84, 0x1a, 0x88, 0x91, 0xe5, 0xd3, 0xe6, 0x01, 0x32, 0x01, 0x32,
		0x01, 0x32, 0x0f, 0x08, 0x64, 0x26, 0x5e, 0x20, 0xcf, 0x14, 0xa0, 0x4b, 0xc2, 0x83, 0xa7, 0x89,
		0xcf, 0x73, 0x9f, 0xff, 0xd0, 0xae, 0xa6, 0x9a, 0xaa, 0xf3, 0xdd, 0x15, 0xd9, 0xd4, 0xb5, 0xe6,
		0x15, 0x9d, 0xf7, 0x9e, 0xb6, 0xaf, 0xf0, 0xe4, 0x70, 0xe2, 0xd5, 0xf6, 0x74, 0x48, 0x15, 0x9c,
		0x03, 0xaf, 0x7b, 0x48, 0x9b, 0xad, 0x33, 0x83, 0x07, 0xf5, 0x59, 0x35, 0x5b, 0xeb, 0x61, 0x3f,
		0x4a, 0x95, 0xf7, 0xa3, 0x74, 0x8f, 0xd3, 0x80, 0xfd, 0xfc, 0x93, 0xc1, 0x85, 0x45, 0x08, 0x24,
		0x65, 0x3a, 0x29, 0xf9, 0x60, 0xd2, 0x98, 0x11, 0x29, 0xaa, 0x2a, 0x4a, 0xdf, 0xb7, 0x34, 0x66,
		0xba, 0x2d, 0xa0, 0x94, 0x5b, 0x3f, 0xd3, 0x2d, 0x9f, 0x2f, 0x5f, 0x4e, 0x33, 0x72, 0x8f, 0x8b,
		0x8e, 0x1d, 0xca, 0x32, 0xad, 0x0e, 0xd3, 0xbe, 0x97, 0x65, 0x82, 0x0d, 0x85, 0x0d, 0xdd, 0xf4,
		0x40, 0x88, 0xb6, 0x97, 0x09, 0x99, 0x54, 0x2c, 0x7b, 0x65, 0xcb, 0x5f, 0x95, 0x19, 0x50, 0x6e,
		0x0e, 0x94, 0x9b, 0x05, 0x95, 0xe6, 0x81, 0x96, 0x31, 0x23, 0xda, 0x8e, 0x68, 0x3b, 0xa2, 0x9f,
		0x88, 0xb6, 0x63, 0xbe, 0x21, 0xda, 0xae, 0x4e, 0x0a, 0x25, 0xa0, 0x1a, 0xa1, 0xf0, 0xee, 0x09,
		0xa3, 0x38, 0x0b, 0x30, 0x34, 0x6d, 0x17, 0xb0, 0x12, 0xb0, 0x12, 0xb0, 0xf2, 0xa0, 0x60, 0xe5,
		0x1c, 0x54, 0x5a, 0xa4, 0x26, 0xe0, 0x09, 0xb6, 0xec, 0x10, 0xb6, 0xf9, 0x3a, 0x48, 0x06, 0xe3,
		0x57, 0x31, 0x42, 0x0a, 0xd5, 0xae, 0x63, 0x8c, 0x14, 0x2a, 0x98, 0x78, 0x98, 0xf8, 0x83, 0x35,
		0xf1, 0x48, 0xa1, 0x22, 0x9c, 0x8f, 0x48, 0xa1, 0xda, 0xde, 0x3e, 0x52, 0xa8, 0x4a, 0x1b, 0x52,
		0xa4, 0x50, 0x29, 0x68, 0x6d, 0x9f, 0x74, 0x83, 0x58, 0x32, 0x99, 0xc4, 0x0a, 0x4a, 0xc3, 0x4f,
		0xdb, 0x05, 0xa8, 0x04, 0xa8, 0x04, 0xa8, 0x3c, 0x20, 0x50, 0xc9, 0x83, 0x64, 0xc0, 0xc5, 0x34,
		0xb3, 0x12, 0x8a, 0x81, 0xc6, 0x16, 0x0e, 0x2a, 0x23, 0xb6, 0xdc, 0xd2, 0xec, 0x05, 0x52, 0xba,
		0x86, 0x42, 0x10, 0xa6, 0xc4, 0x4e, 0x5a, 0x43, 0xf9, 0x14, 0x6d, 0x2e, 0x14, 0x09, 0x5d, 0x48,
		0xe8, 0xfa, 0xe5, 0xd2, 0xb6, 0xee, 0x45, 0x98, 0x28, 0x48, 0xec, 0x5a, 0x6a, 0x9b, 0x16, 0x51,
		0x37, 0x81, 0xa8, 0x81, 0xa8, 0x81, 0xa8, 0x8b, 0x3f, 0x28, 0x95, 0x19, 0x49, 0x1b, 0x24, 0x2a,
		0xb6, 0xb6, 0x75, 0x11, 0x90, 0x14, 0x5f, 0x53, 0x6c, 0x56, 0x94, 0x99, 0x17, 0x95, 0x66, 0x46,
		0xb9, 0xb9, 0x51, 0x6d, 0x76, 0xb4, 0x99, 0x1f, 0x6d, 0x66, 0x48, 0x87, 0x39, 0xa2, 0x35, 0x4b,
		0xc4, 0xe6, 0x49, 0x99, 0x99, 0x4a, 0x1b, 0x66, 0xb6, 0xcd, 0x23, 0x69, 0x0d, 0x42, 0x47, 0xe1,
		0x84, 0x4c, 0x0b, 0xb7, 0x2e, 0x75, 0xa6, 0x68, 0xa6, 0x10, 0x1f, 0xa1, 0xf2, 0x3b, 0x83, 0xa9,
		0x2a, 0x0e, 0xa0, 0xca, 0x70, 0xea, 0x30, 0xa0, 0xda, 0x0c, 0xa9, 0x2e, 0x83, 0xaa, 0xdd, 0xb0,
		0x6a, 0x37, 0xb0, 0x3a, 0x0d, 0xad, 0x1a, 0x83, 0xab, 0xc8, 0xf0, 0xa6, 0x2f, 0x86, 0x5c, 0x79,
		0xdd, 0xba, 0x5a, 0xe8, 0x8e, 0x98, 0xf9, 0x2d, 0xda, 0x6b, 0x3e, 0x33, 0x63, 0x60, 0x55, 0x44,
		0x89, 0x99, 0x33, 0xe4, 0x42, 0x7a, 0x31, 0x1f, 0x4f, 0xf7, 0xa9, 0xb6, 0x39, 0x64, 0xbe, 0x06,
		0x1f, 0xb8, 0xb9, 0x5f, 0xf5, 0xee, 0xb0, 0xd9, 0x68, 0xc0, 0x19, 0xc2, 0x19, 0xc2, 0x19, 0xc2,
		0x19, 0x9a, 0xe3, 0x0c, 0x13, 0x2f, 0x90, 0xcd, 0xae, 0x06, 0x5f, 0xd8, 0x55, 0xd8, 0x85, 0x9a,
		0x64, 0xb8, 0xd5, 0x1f, 0xb5, 0xcb, 0xbd, 0xa6, 0x3a, 0x59, 0x4e, 0xb3, 0x53, 0x59, 0xeb, 0x2e,
		0xcd, 0xbc, 0xd2, 0xd4, 0x9f, 0x86, 0x3c, 0x2c, 0x4d, 0xe6, 0xe0, 0xe9, 0x14, 0x61, 0x0f, 0x7b,
		0x3f, 0x45, 0x3a, 0x8d, 0xf3, 0x93, 0x3d, 0x9e, 0x25, 0xcf, 0xcc, 0x6c, 0xbd, 0x77, 0xc0, 0x64,
		0x26, 0x12, 0x9c, 0x0f, 0x22, 0xa9, 0x9e, 0xbd, 0xcc, 0x3b, 0x52, 0x4f, 0x57, 0xc6, 0xf8, 0x0e,
		0x7c, 0x05, 0x7c, 0x05, 0x7c, 0x05, 0x7c, 0xc5, 0x1c, 0xbe, 0x02, 0xf1, 0x4e, 0xa7, 0xbf, 0xb3,
		0x1c, 0xee, 0xb3, 0x47, 0x6d, 0x5e, 0x6f, 0xd6, 0x9d, 0x7a, 0xdf, 0x07, 0xa1, 0x0e, 0x8e, 0x0f,
		0x8e, 0x0f, 0x8e, 0xcf, 0x20, 0xc7, 0x07, 0xa1, 0x6e, 0xe7, 0x1f, 0x08, 0x75, 0x24, 0x2a, 0x4c,
		0x03, 0x42, 0x5d, 0xa1, 0x29, 0x72, 0x00, 0x42, 0x5d, 0xbb, 0xdb, 0x68, 0x40, 0xa8, 0xab, 0x5a,
		0xeb, 0x87, 0x2d, 0xd4, 0x79, 0xa1, 0xf0, 0xa4, 0x16, 0xce, 0x32, 0xeb, 0x09, 0x99, 0x05, 0x20,
		0x2c, 0x20, 0x2c, 0x20, 0x2c, 0x20, 0x2c, 0x35, 0x95, 0x55, 0x74, 0xb6, 0x99, 0xae, 0x13, 0xf0,
		0x15, 0xf0, 0x15, 0x24, 0x16, 0x80, 0xaf, 0xec, 0x30, 0x45, 0x5a, 0x27, 0x1d, 0xd0, 0x15, 0xd0,
		0x95, 0xea, 0xd0, 0x95, 0xa1, 0x27, 0x64, 0xc2, 0xfc, 0xb4, 0x4e, 0xbd, 0x72, 0xd6, 0xb2, 0xda,
		0x21, 0x68, 0x05, 0x68, 0x05, 0x68, 0x05, 0x68, 0x85, 0x31, 0xb4, 0x62, 0x51, 0x7f, 0x59, 0x47,
		0x0e, 0xc0, 0xb9, 0xc2, 0x3e, 0x66, 0xef, 0xcc, 0x78, 0x6e, 0xb1, 0x74, 0xe0, 0x4a, 0x47, 0xc3,
		0xd8, 0xac, 0x8d, 0xd1, 0x99, 0x86, 0xbe, 0x54, 0x1d, 0x98, 0xb1, 0xb5, 0xc3, 0xd9, 0x41, 0x1a,
		0xbd, 0x9f, 0x9f, 0x9b, 0xd6, 0x79, 0x6f, 0xfa, 0xb1, 0x39, 0xf9, 0xdf, 0xf4, 0x73, 0xeb, 0x73,
		0xc3, 0xea, 0xcc, 0x3f, 0x9f, 0x7c, 0x6e, 0x58, 0x27, 0xbd, 0xa3, 0x2f, 0x5f, 0x5e, 0x1e, 0xfd,
		0x68, 0x8f, 0xb2, 0x5f, 0xf8, 0xaf, 0xba, 0xf2, 0x87, 0xea, 0xe9, 0x18, 0x24, 0x95, 0x47, 0x9b,
		0x1c, 0xce, 0x48, 0x3d, 0x33, 0x98, 0xc9, 0xea, 0x35, 0x77, 0x5d, 0x98, 0x3b, 0xda, 0x45, 0x84,
		0x73, 0x83, 0x8c, 0x3e, 0x37, 0xe8, 0x60, 0x8d, 0x3f, 0xe6, 0xed, 0x7e, 0xce, 0x5b, 0x28, 0x6a,
		0x1a, 0xb8, 0xe3, 0x5b, 0x2f, 0x96, 0x97, 0x52, 0x0a, 0xb5, 0xfc, 0xf1, 0x9d, 0x17, 0xbc, 0xf6,
		0x27, 0x35, 0x01, 0x62, 0xb5, 0xc2, 0x73, 0xfd, 0x1d, 0x7b, 0x58, 0xea, 0xa9, 0x79, 0xd6, 0xe9,
		0x74, 0x4f, 0x3b, 0x9d, 0xc6, 0x69, 0xfb, 0xb4, 0x71, 0x7e, 0x72, 0xd2, 0xec, 0x36, 0x55, 0x46,
		0xac, 0xde, 0x0b, 0x87, 0x0b, 0xee, 0xfc, 0xf1, 0x58, 0xbf, 0xa8, 0x05, 0x89, 0xef, 0x43, 0x5b,
		0xb5, 0x7c, 0x2f, 0xf8, 0x66, 0xf9, 0xa1, 0xad, 0xa3, 0xf8, 0xc4, 0x86, 0x3e, 0xa1, 0xb0, 0x42,
		0x61, 0x85, 0xc2, 0x0a, 0x85, 0x15, 0x0a, 0x2b, 0x14, 0x56, 0x28, 0xac, 0x50, 0x58, 0x41, 0xb2,
		0xa1, 0xb0, 0x42, 0x61, 0x85, 0xc2, 0x0a, 0xa5, 0x0a, 0x4a, 0x15, 0x8c, 0x3f, 0xe6, 0x2d, 0x14,
		0x56, 0x28, 0xac, 0x46, 0xea, 0x6a, 0x93, 0xe3, 0xa8, 0x84, 0xe5, 0x39, 0xfa, 0x64, 0xb5, 0x45,
		0x97, 0x50, 0xd5, 0xa0, 0xaa, 0x41, 0x55, 0x83, 0xaa, 0x66, 0x8c, 0xaa, 0x86, 0xed, 0x50, 0x15,
		0x62, 0x98, 0xd8, 0x0e, 0x45, 0xd7, 0x1f, 0xb6, 0x43, 0x19, 0x3b, 0x45, 0x5a, 0x27, 0x28, 0xb3,
		0x0a, 0x6a, 0x51, 0x89, 0x16, 0xa9, 0xcf, 0x73, 0xba, 0x4c, 0xee, 0xc7, 0x80, 0x87, 0x3b, 0x4a,
		0xdc, 0x95, 0x62, 0xba, 0x73, 0x3c, 0xc6, 0x68, 0xee, 0xc5, 0xd2, 0x21, 0xc0, 0x2b, 0x7f, 0x18,
		0xff, 0x3e, 0xf4, 0x59, 0x70, 0xb1, 0x7c, 0x24, 0xf0, 0x04, 0xd8, 0x5d, 0x4c, 0x0e, 0x06, 0x9e,
		0x7e, 0x5c, 0x1c, 0x0f, 0xfc, 0xe4, 0xf7, 0xe3, 0xa1, 0x10, 0xd1, 0xf1, 0xe2, 0xe4, 0xcc, 0x63,
		0x25, 0x27, 0xde, 0xa5, 0x0f, 0x75, 0xc5, 0x63, 0x5b, 0x78, 0xd1, 0xec, 0x00, 0xe5, 0xfa, 0xa5,
		0xe3, 0x78, 0xe3, 0xcf, 0xcc, 0xaf, 0x7d, 0xfa, 0xf0, 0xe1, 0xa6, 0xe6, 0x30, 0xc9, 0x6a, 0x6e,
		0x28, 0x6a, 0xd7, 0x37, 0xc3, 0x6e, 0x6d, 0xf1, 0xc8, 0x8a, 0x19, 0x5e, 0x13, 0x0c, 0x0f, 0x0c,
		0x0f, 0x0c, 0x6f, 0xff, 0x19, 0x9e, 0xaa, 0x83, 0xfd, 0xd6, 0xe4, 0x30, 0x0d, 0x69, 0x66, 0x5b,
		0x75, 0x31, 0xe5, 0xe9, 0x66, 0xdb, 0xac, 0xf9, 0x9b, 0x50, 0x4c, 0xcd, 0x78, 0x18, 0xac, 0x1a,
		0xf0, 0x17, 0xb5, 0x98, 0xcb, 0xb8, 0x26, 0xfb, 0xbc, 0x36, 0xbb, 0xcd, 0xda, 0xf8, 0x36, 0x6b,
		0x93, 0xdb, 0xfc, 0x12, 0xe8, 0x89, 0xeb, 0x69, 0x42, 0xd6, 0xca, 0xcd, 0xbe, 0x4e, 0xf3, 0xaf,
		0xdd, 0x0d, 0xe8, 0x76, 0x07, 0xa5, 0xb9, 0x85, 0xd2, 0xdc, 0x43, 0x19, 0x6e, 0x42, 0x13, 0x0f,
		0x53, 0xbc, 0xde, 0x94, 0x0b, 0x84, 0x6b, 0xab, 0x4d, 0x4b, 0xfa, 0xdd, 0x1a, 0x1c, 0x3e, 0xd7,
		0xd0, 0x97, 0x96, 0x74, 0x3c, 0xb5, 0x14, 0xed, 0x37, 0x23, 0xa7, 0x35, 0x3d, 0x6f, 0x6d, 0x0c,
		0xcf, 0x34, 0xf6, 0xa9, 0x3b, 0x0f, 0x20, 0xed, 0x78, 0xdf, 0x92, 0xc1, 0x52, 0xd9, 0x47, 0xe7,
		0xe0, 0x95, 0x91, 0xc9, 0xb1, 0xff, 0x23, 0xa8, 0xa5, 0xa7, 0xd1, 0x8b, 0x3d, 0x36, 0x9f, 0x5d,
		0x98, 0x4f, 0x3d, 0x8b, 0x0f, 0xe9, 0x54, 0x7b, 0x99, 0x4e, 0x75, 0xb0, 0xce, 0x04, 0xf3, 0x79,
		0xbf, 0xe7, 0xb3, 0x1e, 0xd7, 0x8a, 0x74, 0x47, 0xbd, 0x92, 0x6f, 0xc5, 0x63, 0x92, 0x3d, 0xea,
		0x98, 0x64, 0x10, 0x84, 0x92, 0xcd, 0xa4, 0x53, 0x7a, 0x80, 0x55, 0x8f, 0xed, 0x3e, 0x1f, 0xb0,
		0x88, 0xc9, 0xfe, 0x34, 0x88, 0x18, 0xf1, 0x60, 0x1a, 0xda, 0xb3, 0x96, 0x22, 0x89, 0x9b, 0x3e,
		0x1e, 0x2f, 0x87, 0x11, 0x27, 0x01, 0xc4, 0x45, 0xe8, 0xf0, 0x37, 0x41, 0xc3, 0x67, 0xd5, 0x1c,
		0x3e, 0x42, 0x94, 0x5c, 0x4f, 0x5f, 0x93, 0x25, 0x05, 0xb3, 0xbf, 0x79, 0xc1, 0x3d, 0xf9, 0xf0,
		0x2d, 0x30, 0xf0, 0x7a, 0x5f, 0xc4, 0x93, 0x50, 0x4d, 0xfc, 0x53, 0x99, 0x00, 0xae, 0x52, 0xf0,
		0x56, 0x2e, 0x70, 0xab, 0x16, 0xb4, 0xb5, 0x09, 0xd8, 0xda, 0x04, 0x6b, 0x1d, 0x02, 0x75, 0xb5,
		0x13, 0x57, 0x54, 0xc5, 0x2b, 0xeb, 0xf6, 0x7c, 0x85, 0x2a, 0x4e, 0x5e, 0x51, 0x9b, 0x4d, 0x82,
		0xf4, 0x8d, 0xf2, 0xcd, 0x9a, 0x2e, 0xf3, 0xa6, 0xdd, 0xcc, 0x69, 0x37, 0x77, 0x3a, 0xcd, 0x9e,
		0x62, 0x2c, 0x6f, 0x6a, 0xfa, 0xc6, 0xfc, 0x18, 0x27, 0xcb, 0xe1, 0xb6, 0xe0, 0xb3, 0x31, 0xd0,
		0x94, 0xbe, 0xb1, 0xa1, 0x6f, 0xe5, 0xe9, 0x1b, 0xca, 0xcf, 0xc0, 0x5d, 0x35, 0xd5, 0x48, 0xbd,
		0xa8, 0xb0, 0x09, 0xd7, 0x6d, 0xca, 0x4b, 0x33, 0xe9, 0xa5, 0x99, 0xf6, 0x32, 0x4c, 0xbc, 0x1e,
		0x41, 0x6b, 0xff, 0x52, 0x2f, 0x54, 0xef, 0xd1, 0x5a, 0x35, 0x8d, 0x1a, 0x76, 0x5f, 0x68, 0xda,
		0xb3, 0x35, 0xff, 0xd1, 0x18, 0x36, 0xd4, 0xb9, 0x87, 0x4b, 0xb3, 0x4f, 0x5b, 0xeb, 0x56, 0xf3,
		0x91, 0xbc, 0x69, 0xbf, 0x25, 0x6c, 0xdb, 0xd1, 0x64, 0x5d, 0x9e, 0x4e, 0x25, 0x8d, 0x7b, 0xbd,
		0xaa, 0x32, 0x95, 0xb4, 0x1d, 0x85, 0x55, 0x89, 0xc9, 0x84, 0xf8, 0x51, 0xa9, 0xf7, 0xaf, 0x70,
		0x31, 0xd7, 0x27, 0x42, 0xf9, 0x22, 0xc2, 0xa1, 0x8f, 0xbd, 0xad, 0x76, 0x0c, 0x3a, 0x05, 0x3a,
		0x05, 0x3a, 0x05, 0x3a, 0x05, 0x3a, 0x35, 0x5b, 0x6d, 0x3e, 0x67, 0xae, 0xe0, 0xae, 0xce, 0x34,
		0xf6, 0x53, 0x3d, 0xa5, 0xfb, 0xfa, 0x3b, 0xef, 0xd2, 0xf5, 0xdc, 0x8b, 0x60, 0xfc, 0x3a, 0x8c,
		0x9e, 0x3a, 0x5a, 0x2a, 0xf4, 0x2f, 0x13, 0x3b, 0x3d, 0x95, 0xfa, 0x97, 0xf1, 0x7f, 0x69, 0x15,
		0xfb, 0xd3, 0x9b, 0xd0, 0x52, 0xb9, 0x5f, 0x03, 0xd4, 0x33, 0x2a, 0xbc, 0xa0, 0x38, 0x25, 0x27,
		0xed, 0x47, 0x6b, 0x6a, 0xce, 0x7a, 0x12, 0x89, 0x92, 0x6c, 0x1d, 0x75, 0x23, 0xae, 0xa2, 0x6a,
		0x5d, 0x2c, 0x99, 0xe4, 0xea, 0xa3, 0xdf, 0xd3, 0x6e, 0x0c, 0x0f, 0x7e, 0xb7, 0x10, 0xfc, 0xae,
		0x0c, 0xc4, 0x47, 0xf0, 0xfb, 0x70, 0xbd, 0x13, 0x82, 0xdf, 0xb4, 0xaf, 0x13, 0xc1, 0x6f, 0xa8,
		0x35, 0x50, 0x6b, 0xa0, 0xd6, 0x40, 0xad, 0xd9, 0xb0, 0xda, 0x10, 0xfc, 0x2e, 0xfa, 0x83, 0xe0,
		0xb7, 0x92, 0x6e, 0x11, 0xfc, 0x56, 0x2d, 0x7e, 0x21, 0xf8, 0xbd, 0xd7, 0x93, 0x09, 0xc1, 0xef,
		0x52, 0xef, 0x1f, 0xc1, 0x6f, 0xd0, 0x29, 0xd0, 0x29, 0xd0, 0x29, 0xd0, 0xa9, 0x43, 0xa2, 0x53,
		0x08, 0x7e, 0x23, 0xf8, 0x9d, 0x8f, 0xd8, 0x21, 0xf8, 0x8d, 0xe0, 0xb7, 0x8e, 0x19, 0x7e, 0x30,
		0xc1, 0xef, 0x69, 0x4c, 0x16, 0xc7, 0x2a, 0x54, 0x7f, 0xca, 0x94, 0x3d, 0x55, 0xea, 0x4a, 0x12,
		0x0f, 0x44, 0x62, 0xcb, 0x60, 0x06, 0x0b, 0xae, 0xe7, 0x7d, 0x7e, 0xfd, 0x30, 0xb9, 0xe1, 0x4f,
		0x3e, 0x0b, 0xbe, 0x5e, 0x47, 0xc3, 0xee, 0xd7, 0xcb, 0xe9, 0x5d, 0x7e, 0xfd, 0x24, 0x44, 0xf4,
		0xe7, 0xf8, 0xfe, 0xbe, 0xa6, 0xdf, 0xfd, 0x38, 0xbf, 0xbd, 0x03, 0xa8, 0xb6, 0xa2, 0x26, 0x4f,
		0x43, 0x69, 0x7e, 0x86, 0xf2, 0x9a, 0x2a, 0x2d, 0xd4, 0x54, 0xd1, 0xc6, 0x2e, 0x51, 0x53, 0x65,
		0xff, 0xbc, 0x96, 0xb2, 0x9a, 0x2a, 0xcc, 0xb6, 0x79, 0x24, 0xad, 0x41, 0xe8, 0x68, 0x48, 0x2d,
		0x5b, 0xee, 0x4c, 0xd9, 0x59, 0x3d, 0x69, 0x86, 0x84, 0xcb, 0xfc, 0x98, 0xe3, 0x98, 0xd5, 0xd2,
		0xe4, 0x3b, 0x24, 0xb2, 0x19, 0x27, 0xcf, 0x21, 0x91, 0xad, 0x34, 0xf9, 0x2d, 0x5d, 0x2d, 0x77,
		0x61, 0xe8, 0x73, 0x16, 0x68, 0x38, 0x68, 0xb5, 0xd9, 0x3c, 0xe0, 0x6c, 0x6a, 0xe6, 0x0c, 0xb9,
		0x90, 0x5e, 0x3c, 0xd1, 0x8d, 0xa6, 0xdc, 0x6c, 0xa8, 0xf0, 0xe0, 0xa3, 0x85, 0x0f, 0xdc, 0xdc,
		0xaf, 0x7a, 0x77, 0xd8, 0x6c, 0x34, 0xe0, 0x0c, 0xe1, 0x0c, 0xe1, 0x0c, 0xe1, 0x0c, 0xcd, 0x71,
		0x86, 0x89, 0x17, 0xc8, 0x66, 0x57, 0x83, 0x2f, 0xec, 0xe2, 0xd0, 0xf1, 0xdf, 0x3f, 0x08, 0x0e,
		0x1d, 0xa7, 0xeb, 0x0f, 0x87, 0x8e, 0x1b, 0x3b, 0x45, 0x3a, 0x8d, 0x73, 0x9c, 0x3a, 0x5e, 0xb9,
		0xd6, 0x7b, 0x07, 0x4c, 0x66, 0xec, 0x44, 0x88, 0x31, 0x9d, 0x98, 0xef, 0x48, 0xd2, 0x50, 0x23,
		0x79, 0xb5, 0x47, 0x50, 0x0b, 0x50, 0x0b, 0x50, 0x0b, 0x50, 0x0b, 0xa3, 0xa8, 0xc5, 0x99, 0x06,
		0x66, 0x71, 0x02, 0x66, 0x01, 0x66, 0xa1, 0x71, 0xf7, 0x0f, 0x98, 0x85, 0xb9, 0x53, 0xa4, 0x75,
		0x02, 0x62, 0x01, 0x62, 0x51, 0x21, 0x62, 0x11, 0x09, 0xce, 0x07, 0x91, 0x54, 0xcf, 0x27, 0xe6,
		0x1d, 0xa9, 0x8f, 0x83, 0x8c, 0xd1, 0x1d, 0xd8, 0x0a, 0xd8, 0x0a, 0xd8, 0x0a, 0xd8, 0x8a, 0x39,
		0x6c, 0x05, 0x59, 0x01, 0x3a, 0xfd, 0x9d, 0xe5, 0x70, 0x9f, 0x3d, 0x6a, 0xf3, 0x7a, 0xb3, 0xee,
		0xd4, 0xfb, 0x3e, 0x64, 0x00, 0xc0, 0xf1, 0xc1, 0xf1, 0xc1, 0xf1, 0x19, 0xe4, 0xf8, 0x90, 0x01,
		0xb0, 0xf3, 0x0f, 0x74, 0x3a, 0x12, 0x11, 0x06, 0x3a, 0x5d, 0xb1, 0x29, 0x72, 0x00, 0x3a, 0x5d,
		0xbb, 0xdb, 0x68, 0x40, 0xa8, 0xab, 0x5a, 0xeb, 0x87, 0x2d, 0xd4, 0xe9, 0x8a, 0xfc, 0xab, 0x8e,
		0xf8, 0x23, 0x65, 0x19, 0x84, 0x05, 0x84, 0x05, 0x84, 0xc5, 0x64, 0xc2, 0x82, 0xbc, 0x02, 0xf0,
		0x15, 0x6d, 0x60, 0x14, 0x19, 0xcb, 0xe0, 0x2b, 0xbf, 0x99, 0x22, 0xda, 0xaa, 0x85, 0x82, 0xae,
		0x80, 0xae, 0xec, 0x32, 0x4d, 0x86, 0x9e, 0x90, 0x09, 0xf3, 0xad, 0x59, 0x61, 0x1b, 0xf5, 0xac,
		0x65, 0xb5, 0x43, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0x63, 0x68, 0x85, 0x17, 0x29,
		0xb6, 0x5d, 0xcb, 0xf6, 0xab, 0x79, 0xae, 0xb0, 0x8f, 0xd9, 0x3b, 0x33, 0x9e, 0x5b, 0x2c, 0x46,
		0x66, 0xd8, 0xd1, 0x30, 0x36, 0x6b, 0x63, 0x74, 0xa6, 0xa7, 0x58, 0xaa, 0xe4, 0x22, 0xd0, 0x76,
		0x00, 0x45, 0xfd, 0x3f, 0xcf, 0x9f, 0x7f, 0x6e, 0x58, 0xe7, 0xbd, 0x9f, 0x9f, 0x9b, 0xd6, 0x79,
		0x6f, 0xfa, 0xb1, 0x39, 0xf9, 0xdf, 0xf4, 0x73, 0xeb, 0x73, 0xc3, 0xea, 0xcc, 0x3f, 0x9f, 0x7c,
		0x6e, 0x58, 0x27, 0xbd, 0xa3, 0x2f, 0x5f, 0x5e, 0x1e, 0xfd, 0x68, 0x8f, 0xb2, 0x5f, 0xf8, 0x2f,
		0xf5, 0x45, 0x87, 0x7b, 0x3a, 0x06, 0xe9, 0xfd, 0xed, 0xf5, 0x3f, 0x18, 0xa9, 0x4a, 0xc2, 0x71,
		0x4d, 0x4c, 0x56, 0xaf, 0xb9, 0xeb, 0xc2, 0xdc, 0xd1, 0x2e, 0x22, 0x66, 0xb9, 0x97, 0xd6, 0x9b,
		0xde, 0x8f, 0xe6, 0x8b, 0xce, 0xe8, 0xe2, 0xe8, 0xc7, 0xe9, 0x68, 0xf5, 0x8f, 0x3f, 0x37, 0x7d,
		0xad, 0xf9, 0xe2, 0x74, 0x74, 0xb1, 0xe5, 0x5f, 0xba, 0xa3, 0x8b, 0x1d, 0xdb, 0x38, 0x19, 0x3d,
		0x5f, 0xfb, 0xea, 0xf8, 0xef, 0xad, 0x6d, 0x17, 0x74, 0xb6, 0x5c, 0xd0, 0xde, 0x76, 0x41, 0x7b,
		0xcb, 0x05, 0x5b, 0x6f, 0xa9, 0xb5, 0xe5, 0x82, 0x93, 0xd1, 0xcf, 0xb5, 0xef, 0x3f, 0xdf, 0xfc,
		0xd5, 0xee, 0xe8, 0xe8, 0xe7, 0xb6, 0x7f, 0x3b, 0x1d, 0xfd, 0xbc, 0x38, 0x82, 0xf1, 0xc7, 0xbc,
		0xc5, 0xbc, 0x2d, 0xc5, 0x15, 0x9a, 0xa6, 0xa8, 0x29, 0xe2, 0x8e, 0x5a, 0xca, 0xf2, 0xeb, 0x2b,
		0xc7, 0x5f, 0x6a, 0x19, 0x7e, 0x3d, 0xe5, 0xf7, 0xcd, 0xd2, 0x56, 0x7d, 0x2f, 0xf8, 0x66, 0xf9,
		0xa1, 0xad, 0xa3, 0xaa, 0xdd, 0x86, 0x3e, 0xa1, 0xb0, 0x42, 0x61, 0x85, 0xc2, 0x0a, 0x85, 0x15,
		0x0a, 0x2b, 0x14, 0x56, 0x28, 0xac, 0x50, 0x58, 0x41, 0xb2, 0xa1, 0xb0, 0x42, 0x61, 0x85, 0xc2,
		0x0a, 0xa5, 0x0a, 0x4a, 0x15, 0x8c, 0x3f, 0xe6, 0x2d, 0x14, 0x56, 0x28, 0xac, 0x46, 0xea, 0x6a,
		0x93, 0x73, 0xfa, 0x84, 0xe5, 0x39, 0xfa, 0x64, 0xb5, 0x45, 0x97, 0x50, 0xd5, 0xa0, 0xaa, 0x41,
		0x55, 0x83, 0xaa, 0x66, 0x8c, 0xaa, 0x86, 0xed, 0x50, 0x15, 0x62, 0x98, 0xd8, 0x0e, 0x45, 0xd7,
		0x1f, 0xb6, 0x43, 0x19, 0x3b, 0x45, 0x50, 0x66, 0x15, 0xd4, 0xa2, 0x22, 0x2d, 0x92, 0x1f, 0x6f,
		0x9e, 0xdc, 0x8f, 0x01, 0x0f, 0x77, 0x94, 0xb8, 0x2b, 0xc5, 0x74, 0xe7, 0x78, 0x8c, 0xd1, 0xdc,
		0x8b, 0xa5, 0xd3, 0xd1, 0x57, 0xfe, 0x30, 0xfe, 0x7d, 0xe8, 0xb3, 0xe0, 0x62, 0xf9, 0xac, 0xf4,
		0x09, 0xb0, 0xbb, 0x98, 0x9c, 0x98, 0x3e, 0xfd, 0xb8, 0x38, 0x37, 0xfd, 0xc9, 0xef, 0x6b, 0xa7,
		0xa7, 0xab, 0x38, 0x49, 0x3b, 0x7d, 0xa6, 0x2b, 0x1e, 0xdb, 0xc2, 0x8b, 0x66, 0x07, 0xcd, 0xd7,
		0x2f, 0x1d, 0xc7, 0x1b, 0x7f, 0x66, 0x7e, 0xed, 0xd3, 0x87, 0x0f, 0x37, 0x35, 0x87, 0x49, 0x56,
		0x73, 0x43, 0x51, 0xbb, 0xbe, 0x19, 0x76, 0x6b, 0x8b, 0x27, 0x56, 0x4c, 0xf0, 0x9a, 0x20, 0x78,
		0x20, 0x78, 0x20, 0x78, 0xfb, 0x4f, 0xf0, 0x54, 0x1d, 0x18, 0xbe, 0xa6, 0x86, 0x69, 0xc8, 0x32,
		0xdb, 0x2a, 0x8b, 0x29, 0xcf, 0x36, 0xdb, 0x66, 0xcd, 0xdf, 0x84, 0x62, 0x6a, 0xc6, 0xc3, 0x60,
		0xd5, 0x80, 0xbf, 0xa8, 0xc5, 0x5c, 0xc6, 0x35, 0xd9, 0xe7, 0xb5, 0xd9, 0x6d, 0xd6, 0xc6, 0xb7,
		0x59, 0x9b, 0xdc, 0xe6, 0x97, 0x40, 0x4f, 0x58, 0x4f, 0x13, 0xb0, 0x56, 0x6e, 0xf6, 0x75, 0x9a,
		0x7f, 0xed, 0x6e, 0x40, 0xb7, 0x3b, 0x28, 0xcd, 0x2d, 0x94, 0xe6, 0x1e, 0xca, 0x70, 0x13, 0x9a,
		0x68, 0x98, 0xe2, 0xf5, 0xa6, 0x5c, 0x1f, 0x5c, 0x5b, 0x6d, 0x5a, 0xb2, 0xef, 0xd6, 0xe0, 0xf0,
		0xb9, 0x86, 0xbe, 0xb4, 0x64, 0xe3, 0xa9, 0x65, 0x68, 0xbf, 0x19, 0x39, 0xad, 0xd9, 0x79, 0x6b,
		0x63, 0x78, 0xa6, 0xb1, 0x4f, 0xdd, 0x69, 0x00, 0x69, 0xc7, 0xfb, 0x96, 0x0b, 0x96, 0xaa, 0x3e,
		0x3a, 0x07, 0xaf, 0x8c, 0x44, 0x8e, 0xfd, 0x1f, 0x41, 0x2d, 0x3d, 0x8d, 0x5e, 0xec, 0xb1, 0xf9,
		0xec, 0xc2, 0x7c, 0xea, 0x59, 0x7c, 0xc8, 0xa6, 0xda, 0xcb, 0x6c, 0xaa, 0x83, 0x75, 0x26, 0x98,
		0xcf, 0xfb, 0x3d, 0x9f, 0xf5, 0xb8, 0x56, 0x64, 0x3b, 0xea, 0x95, 0x7c, 0x2b, 0x1e, 0x92, 0xec,
		0x51, 0x87, 0x24, 0x83, 0x20, 0x94, 0x6c, 0x26, 0x9d, 0xd2, 0x03, 0xac, 0x7a, 0x6c, 0xf7, 0xf9,
		0x80, 0x45, 0x4c, 0xf6, 0xa7, 0x31, 0xc4, 0x88, 0x07, 0xf6, 0x44, 0x97, 0xb4, 0x96, 0x02, 0x89,
		0x9b, 0x3e, 0x1e, 0x2f, 0x47, 0x11, 0x27, 0xf1, 0xc3, 0x45, 0xe4, 0xf0, 0xd7, 0x31, 0xc3, 0x67,
		0xd5, 0x1c, 0x3d, 0x42, 0x90, 0xac, 0x21, 0xdb, 0x55, 0x5b, 0x96, 0xab, 0x22, 0x35, 0x5c, 0x99,
		0xfa, 0xad, 0x52, 0xed, 0x56, 0xae, 0x6e, 0xab, 0x56, 0xb3, 0xb5, 0xa9, 0xd7, 0xda, 0xd4, 0x6a,
		0x1d, 0xea, 0x74, 0xb5, 0x93, 0x56, 0x94, 0xa9, 0xcd, 0xe9, 0x6c, 0xf7, 0x39, 0x73, 0x05, 0x77,
		0x55, 0xcc, 0xf7, 0x39, 0x8f, 0x3e, 0x55, 0xd0, 0xf6, 0xcd, 0xcc, 0xa9, 0xbd, 0x7c, 0x39, 0x75,
		0x3c, 0xc7, 0xeb, 0xa6, 0xb2, 0xaa, 0xae, 0xe8, 0x59, 0x85, 0x26, 0xda, 0xd8, 0x66, 0xa8, 0x74,
		0x34, 0x6a, 0x4a, 0xf9, 0xa8, 0x2b, 0xdd, 0xa3, 0xb5, 0x54, 0x8f, 0x9a, 0xd2, 0x3c, 0x54, 0x33,
		0x43, 0x11, 0x38, 0xd5, 0x0a, 0x4a, 0x09, 0xad, 0x5a, 0x3d, 0x96, 0x22, 0xb1, 0x65, 0x30, 0x33,
		0x9b, 0xd7, 0xf3, 0xbb, 0xfa, 0xfa, 0x61, 0x72, 0x57, 0x9f, 0x7c, 0x16, 0x7c, 0xbd, 0x8e, 0x86,
		0xdd, 0xaf, 0x97, 0xd3, 0x5b, 0xf9, 0xfa, 0x49, 0x88, 0xe8, 0xcf, 0xc9, 0x4d, 0x3c, 0xab, 0x86,
		0xd9, 0x28, 0xd6, 0x42, 0xc1, 0x69, 0x45, 0x3d, 0x9d, 0xd4, 0x4f, 0xa3, 0x62, 0xc3, 0x96, 0xff,
		0x65, 0xe7, 0xbb, 0x32, 0xe7, 0xf0, 0xcc, 0xed, 0x7f, 0x6e, 0xc0, 0x4b, 0x63, 0xe0, 0xe9, 0x0c,
		0xba, 0x52, 0x03, 0x4e, 0x63, 0xb0, 0xf3, 0x0e, 0x15, 0x4d, 0x02, 0x73, 0xb1, 0xa5, 0xa7, 0x29,
		0x21, 0xb9, 0xa0, 0xdd, 0xfe, 0x45, 0x8a, 0xf1, 0xf5, 0x4d, 0x6d, 0xdc, 0x47, 0xcd, 0x65, 0x03,
		0xcf, 0x7f, 0xac, 0x4d, 0x4d, 0x46, 0x22, 0x26, 0x86, 0xa9, 0xe6, 0x86, 0xe2, 0x4b, 0x40, 0x96,
		0x71, 0x4c, 0x94, 0x59, 0x4c, 0x46, 0xa6, 0x29, 0xc9, 0x33, 0x39, 0x59, 0xa6, 0x26, 0xc7, 0xca,
		0xc8, 0xb0, 0x32, 0xf2, 0xab, 0x82, 0xec, 0x96, 0xeb, 0xf2, 0xa9, 0x32, 0x6d, 0xeb, 0x13, 0x77,
		0x4c, 0x36, 0x33, 0x52, 0x71, 0x6d, 0xdc, 0x2a, 0xd1, 0xd8, 0xad, 0x18, 0x9c, 0xd7, 0x81, 0xed,
		0x87, 0xb1, 0x17, 0xdc, 0x8f, 0x0d, 0x8c, 0x64, 0x5e, 0xc0, 0xc5, 0x64, 0x4b, 0xc3, 0x24, 0x33,
		0x76, 0x82, 0x4c, 0xe3, 0x5a, 0x9f, 0x05, 0x8e, 0xcf, 0x9d, 0xda, 0xdd, 0x63, 0x4d, 0xf6, 0xbd,
		0xf8, 0x4b, 0x70, 0x7d, 0xb3, 0x48, 0x96, 0xa5, 0xba, 0x2f, 0xda, 0xcd, 0x0d, 0xe4, 0xba, 0x9e,
		0x0a, 0x3d, 0x4f, 0x99, 0x8e, 0xa7, 0x4a, 0xbf, 0x53, 0xae, 0xdb, 0x29, 0xd7, 0xeb, 0x54, 0xea,
		0x74, 0xa3, 0xfd, 0x60, 0x4f, 0x9a, 0xe9, 0x40, 0x2f, 0x2f, 0xc6, 0xa4, 0x61, 0x69, 0x4a, 0xd9,
		0x59, 0x81, 0xd5, 0x91, 0x95, 0xc4, 0xe7, 0x9b, 0xc6, 0xd9, 0x87, 0x2c, 0xdb, 0x15, 0x19, 0xfd,
		0x72, 0xd1, 0x41, 0x55, 0x32, 0x98, 0xd9, 0xde, 0xec, 0xee, 0xef, 0x27, 0xc3, 0xbb, 0xa9, 0xdb,
		0x73, 0x6f, 0x96, 0xed, 0x9d, 0xa4, 0x0e, 0x66, 0x76, 0x7d, 0xc6, 0xd1, 0xc8, 0xe7, 0x92, 0x73,
		0xbb, 0xde, 0x22, 0x2e, 0xb6, 0xb0, 0x2b, 0x2d, 0xea, 0x32, 0xc9, 0x5c, 0x23, 0x99, 0x0b, 0xa4,
		0x70, 0x75, 0x6a, 0x57, 0x7b, 0x5e, 0xd4, 0x5d, 0x77, 0xfa, 0x76, 0x64, 0xd9, 0xbe, 0x37, 0x7d,
		0xb8, 0x9c, 0x03, 0x36, 0x9f, 0x31, 0xcb, 0x8d, 0xe5, 0x7c, 0xd3, 0x4b, 0xc7, 0xdd, 0xbb, 0xcc,
		0x8f, 0xf3, 0x62, 0xe2, 0x82, 0x31, 0xee, 0xc2, 0x98, 0x97, 0x02, 0xe3, 0x92, 0x61, 0x5a, 0x2a,
		0x0c, 0x4b, 0x8e, 0x59, 0xc9, 0x31, 0x2a, 0x25, 0x26, 0xd5, 0x2b, 0xc9, 0x16, 0x8e, 0xf9, 0xa6,
		0xb3, 0xe5, 0x2e, 0x0c, 0x7d, 0xce, 0x82, 0x22, 0xf3, 0x65, 0xee, 0xad, 0x9a, 0xba, 0x90, 0x50,
		0x0e, 0x27, 0xe3, 0x24, 0xd3, 0x1d, 0x52, 0x96, 0xc3, 0x25, 0xb7, 0xa5, 0x25, 0x05, 0x0b, 0xe2,
		0xc1, 0xb4, 0xaa, 0x48, 0x51, 0x33, 0xb6, 0xb5, 0xe9, 0xe2, 0x46, 0xad, 0x09, 0x83, 0x06, 0x83,
		0x06, 0x83, 0x96, 0x65, 0xb6, 0x24, 0x5e, 0x20, 0xdb, 0x2d, 0x02, 0x7b, 0x56, 0x20, 0x25, 0x85,
		0xa8, 0xe6, 0x19, 0x81, 0x2c, 0x4a, 0x59, 0xb3, 0x8c, 0x38, 0x13, 0x30, 0x2d, 0x28, 0x45, 0xd5,
		0x9e, 0x82, 0x72, 0x51, 0x04, 0x89, 0x12, 0xa4, 0x35, 0xc1, 0x54, 0x0d, 0x41, 0xa7, 0x75, 0xde,
		0x39, 0xef, 0x9e, 0xb6, 0xce, 0x4f, 0x2a, 0x3c, 0x16, 0x25, 0xa9, 0x6b, 0xbd, 0x0a, 0xc3, 0x1a,
		0x1e, 0xb0, 0x3b, 0x9f, 0x3b, 0xc5, 0x41, 0xcc, 0xbc, 0xa1, 0xe2, 0x90, 0x65, 0xec, 0xc5, 0x80,
		0x5a, 0x80, 0x5a, 0x80, 0x5a, 0x40, 0xc3, 0xd6, 0xee, 0x71, 0x20, 0x93, 0xe2, 0xb6, 0x6a, 0xdc,
		0x08, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x68, 0xd1, 0x1e, 0xd3, 0xa2, 0x66, 0xeb, 0x0c, 0xcc,
		0x28, 0xf3, 0x28, 0xb4, 0x0f, 0x88, 0x9c, 0xee, 0x3b, 0x21, 0x3a, 0x94, 0x88, 0xf7, 0x2c, 0x48,
		0x5c, 0x81, 0x70, 0x77, 0xc0, 0xbd, 0xfb, 0xfe, 0x5d, 0x28, 0xe2, 0xfc, 0x11, 0xef, 0x45, 0x13,
		0x08, 0x7a, 0x2b, 0xc3, 0x5e, 0x08, 0x7a, 0x6b, 0x0c, 0x7a, 0xcf, 0x67, 0x74, 0x71, 0xe6, 0x92,
		0xb6, 0x54, 0x8c, 0xbe, 0x34, 0x41, 0x5f, 0x40, 0x5f, 0x4c, 0xa0, 0x2f, 0x45, 0xb3, 0xbb, 0xf3,
		0xa6, 0x5f, 0x6d, 0x9d, 0x74, 0xb9, 0xd2, 0xb1, 0x88, 0x97, 0x21, 0xd9, 0x72, 0xa4, 0x5c, 0x96,
		0xe4, 0xcb, 0x93, 0x7a, 0x99, 0x2a, 0x5b, 0xae, 0xca, 0x96, 0xad, 0x8a, 0xe5, 0x4b, 0x04, 0xfd,
		0xab, 0xb2, 0x69, 0xc3, 0x53, 0xb0, 0x65, 0x83, 0x2c, 0x9f, 0x9f, 0x9a, 0xd7, 0x63, 0x63, 0x04,
		0x36, 0x46, 0x68, 0x32, 0x0f, 0x34, 0x66, 0x82, 0x50, 0xea, 0xa9, 0x29, 0x29, 0x54, 0xa2, 0xba,
		0x0a, 0xa8, 0x8a, 0x2a, 0x9f, 0xca, 0xaa, 0x78, 0xa2, 0xaa, 0xe1, 0x5e, 0x54, 0x35, 0xec, 0x51,
		0x4e, 0x35, 0x95, 0x55, 0x36, 0x31, 0xdf, 0xf6, 0x63, 0xbe, 0x55, 0x65, 0xef, 0x1c, 0x01, 0xd5,
		0x98, 0x9e, 0x68, 0xc3, 0x1e, 0xb9, 0x48, 0x9d, 0x01, 0x39, 0xbc, 0xdc, 0xd0, 0x07, 0xe0, 0x26,
		0xe0, 0x26, 0xe0, 0xe6, 0x01, 0xc1, 0xcd, 0xa8, 0xff, 0x18, 0x03, 0x6e, 0x3e, 0xf1, 0x7f, 0xab,
		0x6e, 0xaf, 0x35, 0x3a, 0xfa, 0xaf, 0xa3, 0xff, 0x39, 0x50, 0x5c, 0xa4, 0xf7, 0xc5, 0xa0, 0x74,
		0x58, 0xb5, 0x4b, 0x87, 0xa5, 0x01, 0xd1, 0xf4, 0x53, 0xae, 0x80, 0x2f, 0xdd, 0xfb, 0x2e, 0xf0,
		0xae, 0x29, 0x14, 0x3b, 0x3a, 0xa5, 0x8e, 0x08, 0x32, 0x41, 0x88, 0xaf, 0x14, 0x14, 0x82, 0x10,
		0xaf, 0x1f, 0xe2, 0x28, 0x28, 0xf5, 0x4b, 0x59, 0xda, 0x77, 0xbd, 0x94, 0xaf, 0x17, 0x99, 0x68,
		0x3d, 0xa7, 0xf5, 0xef, 0xc9, 0x0c, 0x28, 0xc5, 0x11, 0xdc, 0xe4, 0xc1, 0xcc, 0x16, 0x6c, 0x28,
		0x6c, 0xa8, 0x41, 0x36, 0x14, 0xc1, 0x4c, 0xa8, 0x4b, 0x50, 0x97, 0xa0, 0x2e, 0x55, 0x46, 0x5d,
		0x42, 0x30, 0x13, 0xc1, 0x25, 0x04, 0x33, 0xb5, 0x8b, 0x76, 0x98, 0x6f, 0x08, 0x66, 0x92, 0x69,
		0xa1, 0x04, 0x54, 0xc3, 0x8b, 0x67, 0x27, 0xad, 0x28, 0x40, 0x95, 0x69, 0xd3, 0x00, 0x97, 0x00,
		0x97, 0x00, 0x97, 0x07, 0x04, 0x2e, 0x8b, 0xd7, 0x19, 0xd8, 0x8a, 0x2b, 0x9b, 0xc8, 0x24, 0xc9,
		0x26, 0xb5, 0x22, 0x93, 0x04, 0xe6, 0x18, 0xe6, 0xf8, 0xa0, 0xcd, 0x31, 0x32, 0x49, 0x90, 0x49,
		0x52, 0x9d, 0x17, 0xb3, 0x47, 0x0e, 0x7c, 0x9e, 0x6a, 0x61, 0xd1, 0x84, 0xdc, 0xd6, 0x16, 0xee,
		0x4a, 0xfb, 0x70, 0xdc, 0x70, 0xdc, 0x70, 0xdc, 0x07, 0xe4, 0xb8, 0x79, 0x90, 0x0c, 0xf8, 0xf4,
		0x48, 0x38, 0x15, 0x7e, 0xbb, 0x43, 0xd8, 0xe6, 0xeb, 0x20, 0x19, 0x8c, 0x5f, 0xc2, 0x68, 0x8f,
		0xcc, 0x7b, 0x28, 0xbc, 0x7b, 0xca, 0x12, 0x4e, 0xa9, 0x11, 0x9a, 0xb6, 0x0b, 0x73, 0x0e, 0x73,
		0x0e, 0x73, 0x7e, 0x40, 0xe6, 0x3c, 0x85, 0x73, 0xa4, 0x06, 0xe0, 0x70, 0x4c, 0x3a, 0x72, 0xbf,
		0x77, 0xce, 0xfd, 0x9e, 0x12, 0x06, 0x1c, 0x1c, 0xbd, 0x4b, 0x03, 0x38, 0x38, 0x5a, 0xd7, 0x50,
		0x55, 0xf0, 0x50, 0xbf, 0xf5, 0xb5, 0xa3, 0xe3, 0x54, 0xbf, 0xbf, 0xe6, 0x7d, 0xa1, 0xc8, 0xa1,
		0xa2, 0xe1, 0xac, 0x42, 0x9d, 0xc3, 0x69, 0xf8, 0xdb, 0x62, 0xce, 0x90, 0x0b, 0xe9, 0xc5, 0x7c,
		0x90, 0xe7, 0x40, 0xb3, 0x14, 0x3d, 0x6c, 0x6c, 0x0d, 0xd5, 0x0f, 0x95, 0x61, 0x79, 0x54, 0x3f,
		0xd4, 0x58, 0xfd, 0xb0, 0x60, 0x09, 0x36, 0x9a, 0xd2, 0x6b, 0xa8, 0x7c, 0xa8, 0x80, 0x0a, 0xa3,
		0xf2, 0xa1, 0x3a, 0x3c, 0x55, 0xb8, 0xf2, 0xe1, 0xc4, 0x93, 0x0e, 0x99, 0x4f, 0xb8, 0xdd, 0x72,
		0xde, 0x22, 0x36, 0x5d, 0x6a, 0x53, 0xaf, 0xb0, 0x61, 0x08, 0x9b, 0x2e, 0x7f, 0x3f, 0xdb, 0x0a,
		0x9f, 0xcd, 0xb0, 0xba, 0x36, 0x29, 0xb6, 0x5c, 0xd2, 0x9c, 0xd5, 0x30, 0xff, 0x21, 0xd4, 0xec,
		0x28, 0xcf, 0x6e, 0x20, 0x36, 0x6a, 0x6b, 0xcd, 0x12, 0x9f, 0x22, 0x90, 0xb6, 0xab, 0xe0, 0x34,
		0x01, 0xa2, 0xe5, 0xb1, 0xaa, 0x97, 0x18, 0x37, 0x54, 0xd4, 0x47, 0xe1, 0x69, 0x19, 0xb3, 0x8a,
		0xe8, 0xc0, 0x3d, 0x03, 0xf7, 0x64, 0xfb, 0x9e, 0xcb, 0xa5, 0x37, 0x20, 0xdc, 0x96, 0x9d, 0xb6,
		0x08, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0,
		0x75, 0xd8, 0x40, 0x2b, 0x4e, 0xa2, 0x88, 0x64, 0x27, 0xcd, 0xa2, 0xfe, 0xcd, 0xbc, 0xc5, 0xa2,
		0x25, 0x40, 0x16, 0xa7, 0x17, 0xbb, 0xcc, 0x8f, 0x01, 0xdc, 0x00, 0xdc, 0x00, 0xdc, 0x2a, 0x05,
		0xdc, 0xe8, 0xb6, 0x2d, 0x12, 0x6d, 0x57, 0x34, 0x25, 0x05, 0xa7, 0x82, 0x79, 0x1d, 0x9b, 0xa2,
		0xe5, 0x85, 0x2a, 0x62, 0xea, 0x39, 0xba, 0xba, 0xd8, 0x46, 0x12, 0x92, 0x9a, 0x6d, 0x64, 0x51,
		0xd0, 0x16, 0xa2, 0xa0, 0xea, 0x1c, 0x06, 0xa2, 0xa0, 0x0b, 0x60, 0x85, 0x28, 0x28, 0x30, 0x1e,
		0x30, 0x1e, 0x30, 0x1e, 0xc4, 0x39, 0x88, 0x73, 0x10, 0xe7, 0x20, 0xce, 0x41, 0x9c, 0xab, 0xa8,
		0x38, 0x87, 0x28, 0x28, 0x80, 0x16, 0x80, 0x16, 0x80, 0x16, 0x80, 0x16, 0x80, 0x16, 0x80, 0x16,
		0x80, 0x16, 0x80, 0x96, 0x22, 0xa0, 0x85, 0x28, 0x28, 0x80, 0x1b, 0x80, 0x1b, 0x80, 0x5b, 0x9e,
		0xd9, 0x86, 0x28, 0xe8, 0x9e, 0x47, 0x41, 0x0b, 0xd4, 0x86, 0xc0, 0xce, 0xf3, 0x4c, 0xaf, 0xba,
		0x9e, 0x2b, 0x02, 0xbc, 0x5b, 0x09, 0x81, 0xc9, 0xef, 0xe2, 0xf2, 0x49, 0x77, 0x15, 0xd8, 0xf3,
		0x9e, 0x2f, 0x80, 0x5d, 0x28, 0x70, 0x5d, 0x78, 0x57, 0x7b, 0x0b, 0xbb, 0xda, 0x4b, 0xf4, 0xd1,
		0x7b, 0xbd, 0xab, 0x3d, 0x19, 0xaf, 0xdf, 0x98, 0x62, 0x5f, 0xfb, 0xac, 0x25, 0xec, 0x6c, 0x47,
		0x4e, 0x47, 0x29, 0x70, 0xd7, 0xb8, 0x9c, 0x0e, 0xcb, 0xf1, 0x62, 0x9b, 0x09, 0x87, 0x3b, 0x56,
		0xf4, 0x4d, 0xc6, 0x94, 0xc9, 0x1d, 0xab, 0x4d, 0x83, 0xc3, 0x82, 0xc3, 0x82, 0xc3, 0x56, 0x88,
		0xc3, 0xce, 0xdc, 0x65, 0xb7, 0x43, 0xc8, 0x62, 0xcf, 0x10, 0x7f, 0x28, 0xc5, 0xae, 0xad, 0x35,
		0x8b, 0xf8, 0x83, 0x71, 0x43, 0x45, 0x5b, 0xc4, 0x50, 0xfb, 0xe8, 0x21, 0x12, 0x51, 0x04, 0x87,
		0x71, 0x21, 0x42, 0x41, 0x8f, 0xc1, 0x96, 0x9a, 0x05, 0xfe, 0x02, 0xfe, 0x02, 0xfe, 0x02, 0xfe,
		0x02, 0xfe, 0x02, 0xfe, 0x02, 0xfe, 0x02, 0xfe, 0x02, 0xfe, 0x5a, 0xc6, 0x5f, 0x6e, 0x28, 0xbe,
		0x4f, 0xc5, 0xaa, 0xd0, 0x96, 0x9c, 0x18, 0x85, 0xad, 0x35, 0x0e, 0x2c, 0x06, 0x2c, 0x06, 0x2c,
		0x06, 0x2c, 0x06, 0x2c, 0x06, 0x2c, 0x06, 0x2c, 0x06, 0x2c, 0x06, 0x2c, 0xb6, 0x19, 0x8b, 0x91,
		0xeb, 0x61, 0x2b, 0x4d, 0x03, 0x87, 0x01, 0x87, 0x01, 0x87, 0x01, 0x87, 0x01, 0x87, 0x01, 0x87,
		0x01, 0x87, 0x01, 0x87, 0x01, 0x87, 0x2d, 0xe3, 0x30, 0x05, 0x4a, 0x18, 0xf4, 0x2f, 0xe0, 0x2e,
		0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0xae, 0x0d, 0xb8,
		0x8b, 0x5c, 0xf5, 0x82, 0xd6, 0x05, 0xcc, 0x05, 0xcc, 0x05, 0xcc, 0x05, 0xcc, 0x05, 0xcc, 0x05,
		0xcc, 0x05, 0xcc, 0x05, 0xcc, 0xf5, 0x74, 0x58, 0xc2, 0x44, 0x2a, 0xdb, 0x08, 0xb9, 0xa1, 0x6d,
		0x20, 0x31, 0x20, 0x31, 0x20, 0x31, 0x20, 0x31, 0x20, 0x31, 0x20, 0x31, 0x20, 0x31, 0x20, 0x31,
		0x20, 0xb1, 0x27, 0x48, 0x4c, 0xc5, 0x56, 0xc8, 0x95, 0x76, 0x81, 0xc0, 0x80, 0xc0, 0x80, 0xc0,
		0x80, 0xc0, 0x80, 0xc0, 0x80, 0xc0, 0x80, 0xc0, 0x80, 0xc0, 0x80, 0xc0, 0x9e, 0x20, 0x30, 0x75,
		0x9b, 0x21, 0x37, 0xb6, 0x0e, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34,
		0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0xb6, 0x05, 0x8d, 0xd1, 0x6b, 0x62, 0xd8, 0x0f, 0x09, 0x24,
		0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0x06, 0x24, 0xf6, 0x2b,
		0x24, 0xa6, 0x42, 0x0d, 0x83, 0x06, 0x06, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4,
		0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0xb5, 0x09, 0x79, 0xd1, 0x2b, 0x5f, 0xd0, 0xbb, 0x80, 0xba,
		0x80, 0xba, 0x80, 0xba, 0x80, 0xba, 0x80, 0xba, 0x80, 0xba, 0x80, 0xba, 0xf6, 0x12, 0x75, 0x1d,
		0xfa, 0xd1, 0xde, 0x93, 0x93, 0x92, 0x8f, 0x0b, 0x9e, 0x0b, 0x5b, 0xcb, 0x72, 0xe2, 0xf4, 0xab,
		0x79, 0x5f, 0xba, 0x8e, 0x0e, 0xcf, 0x71, 0x3a, 0xb2, 0xd3, 0xb7, 0x23, 0xcb, 0xf6, 0xbd, 0x29,
		0x14, 0x29, 0x78, 0xe8, 0xee, 0x72, 0x63, 0x79, 0xcf, 0x31, 0xe5, 0x2e, 0x4b, 0xfc, 0x09, 0x2c,
		0x72, 0x99, 0x1f, 0xf3, 0x82, 0xe7, 0xf7, 0x36, 0x70, 0x7e, 0x2f, 0xce, 0xef, 0x35, 0xc1, 0x60,
		0x16, 0x86, 0xcf, 0xe9, 0x6c, 0xb9, 0x0b, 0x43, 0x9f, 0xb3, 0xa0, 0xc8, 0x7c, 0x99, 0x1f, 0x7e,
		0xdd, 0xac, 0xb2, 0xe1, 0x4a, 0x22, 0x8b, 0x39, 0x8e, 0xb0, 0x1c, 0x2e, 0xb9, 0x2d, 0x2d, 0x29,
		0x58, 0x10, 0x0f, 0x3c, 0x49, 0x70, 0x76, 0xf8, 0xf6, 0xa6, 0x8b, 0x1b, 0xb5, 0x26, 0x0c, 0x1a,
		0x0c, 0x1a, 0x0c, 0x5a, 0x96, 0xd9, 0x92, 0x78, 0x81, 0x6c, 0xb7, 0x08, 0xec, 0xd9, 0x69, 0x81,
		0x26, 0x68, 0x48, 0x3f, 0x81, 0x3a, 0x42, 0x49, 0xf2, 0x89, 0x19, 0x23, 0x35, 0xa9, 0x57, 0x41,
		0x07, 0x09, 0x48, 0x3c, 0x29, 0x79, 0x57, 0x35, 0x04, 0x9d, 0xd6, 0x79, 0xe7, 0xbc, 0x7b, 0xda,
		0x3a, 0x3f, 0xa9, 0xf0, 0x58, 0x94, 0x44, 0x85, 0x7b, 0x15, 0x86, 0x35, 0x3c, 0x60, 0x77, 0x3e,
		0x77, 0x8a, 0x83, 0x98, 0x79, 0x43, 0xc5, 0x21, 0xcb, 0xd8, 0x8b, 0x01, 0xb5, 0x00, 0xb5, 0x00,
		0xb5, 0x80, 0x86, 0xad, 0xdd, 0xe3, 0x40, 0x26, 0xc5, 0x6d, 0xd5, 0xb8, 0x11, 0x18, 0x18, 0x18,
		0x18, 0x18, 0x18, 0xd0, 0xa2, 0x3d, 0xa6, 0x45, 0xcd, 0xd6, 0x19, 0x98, 0x51, 0xe6, 0x51, 0x68,
		0x1f, 0x10, 0x39, 0xdd, 0x77, 0x42, 0xf4, 0x4c, 0xe1, 0x84, 0x2c, 0x1a, 0x73, 0x24, 0x8f, 0x35,
		0x66, 0x73, 0x49, 0xbb, 0xbf, 0x9b, 0x0c, 0xef, 0xa5, 0x9e, 0x04, 0x41, 0x32, 0xb8, 0xe3, 0x22,
		0x07, 0xa3, 0x5c, 0x38, 0x9a, 0x45, 0x1b, 0x19, 0x47, 0x64, 0x0e, 0x60, 0x33, 0x5e, 0x96, 0x17,
		0x94, 0x15, 0x01, 0x63, 0x4f, 0x40, 0x98, 0x9b, 0xc3, 0xab, 0x16, 0x05, 0x5f, 0x64, 0xa0, 0x8b,
		0x0c, 0x6c, 0xad, 0x81, 0x2c, 0xb7, 0x5e, 0xb1, 0x15, 0x7f, 0xe5, 0x89, 0x7c, 0x83, 0x6d, 0xcf,
		0x67, 0x58, 0x41, 0xe2, 0x32, 0x6b, 0xa7, 0x18, 0x77, 0x69, 0xee, 0x0b, 0x77, 0x71, 0xc1, 0x5d,
		0x34, 0x2d, 0xab, 0x72, 0xb8, 0x4b, 0xde, 0xe5, 0x46, 0x26, 0x6e, 0x12, 0x8b, 0x9c, 0x8b, 0x07,
		0xa3, 0x49, 0x3a, 0x21, 0xe6, 0x0f, 0xd5, 0xcf, 0x05, 0x77, 0x91, 0x0b, 0x4e, 0xd1, 0x30, 0xa1,
		0x41, 0x20, 0x62, 0x12, 0x95, 0xcb, 0x05, 0x2f, 0xae, 0xa6, 0xae, 0x79, 0xdd, 0xe6, 0x41, 0x24,
		0x62, 0xbe, 0x7e, 0x98, 0x70, 0xd3, 0xfc, 0xfa, 0x0c, 0x9d, 0x3b, 0x0e, 0x6d, 0x8b, 0x3f, 0xc8,
		0x0b, 0xc9, 0x7d, 0x3e, 0xe0, 0x52, 0x3c, 0x5a, 0x61, 0x60, 0xd9, 0xfd, 0x89, 0x80, 0x44, 0xea,
		0xa2, 0x27, 0x26, 0x9c, 0xd0, 0x47, 0xeb, 0x76, 0xcf, 0xbd, 0xfd, 0xc9, 0xb9, 0x5d, 0x50, 0xc7,
		0xe3, 0x19, 0x54, 0xae, 0x70, 0x28, 0x23, 0x7d, 0x0e, 0x4b, 0x70, 0xb7, 0x38, 0x37, 0x78, 0xda,
		0x1c, 0x28, 0x02, 0x28, 0x02, 0x28, 0x82, 0x72, 0x66, 0x4e, 0xcb, 0xd0, 0x89, 0x96, 0x21, 0x00,
		0x3d, 0x00, 0xbd, 0xd9, 0x80, 0xbe, 0xe8, 0xb2, 0x5e, 0xf7, 0xb1, 0x74, 0xd3, 0x63, 0xcd, 0xdf,
		0x52, 0x4d, 0x0f, 0xe2, 0x28, 0x20, 0xd5, 0xe2, 0x57, 0x61, 0x04, 0x94, 0x19, 0x03, 0x55, 0x46,
		0x41, 0xb9, 0x71, 0x50, 0x6e, 0x24, 0x54, 0x1a, 0x0b, 0x1a, 0xa3, 0x41, 0x64, 0x3c, 0xe8, 0x55,
		0x81, 0xb5, 0xd9, 0xea, 0x73, 0xe6, 0xe6, 0x07, 0xd9, 0xbf, 0xf4, 0xf8, 0xa7, 0x84, 0x6d, 0xde,
		0xa4, 0x94, 0x6a, 0x3c, 0xcc, 0x17, 0x4b, 0x14, 0x6a, 0xe5, 0x0f, 0xb3, 0xdf, 0x27, 0x3b, 0x0c,
		0x2b, 0xb2, 0x6d, 0x95, 0x22, 0x3b, 0x20, 0x4e, 0xee, 0x14, 0xda, 0xff, 0x27, 0xad, 0xc3, 0x05,
		0xc0, 0x05, 0xc0, 0x05, 0xc0, 0x05, 0x18, 0xeb, 0x02, 0x3e, 0x2f, 0x5c, 0xc0, 0x7f, 0xdb, 0x89,
		0x10, 0x3c, 0x90, 0xcf, 0x8f, 0x8e, 0x5f, 0xbe, 0x5c, 0xa8, 0x6d, 0xbd, 0xd9, 0x25, 0xcb, 0x76,
		0x2f, 0xde, 0xf0, 0xb7, 0xb4, 0x65, 0x87, 0x3f, 0x54, 0xc6, 0x9b, 0x94, 0xca, 0x66, 0x0a, 0x6b,
		0xe2, 0xf3, 0x1f, 0x7a, 0x82, 0xab, 0x4c, 0x23, 0xdf, 0x62, 0xcc, 0x08, 0xb4, 0xf2, 0x8d, 0x56,
		0xac, 0x6c, 0xc2, 0xdb, 0x2b, 0x2a, 0xc0, 0xd1, 0x68, 0xe9, 0x0b, 0xe8, 0xa3, 0x44, 0x53, 0x7f,
		0x22, 0x31, 0x17, 0x52, 0xd8, 0x8b, 0xbf, 0xf5, 0x51, 0xa1, 0x82, 0x1a, 0x4c, 0x72, 0x3a, 0xcd,
		0x6f, 0xda, 0x5c, 0xc5, 0x24, 0xbf, 0x16, 0x24, 0x3f, 0x48, 0x7e, 0x90, 0xfc, 0x20, 0xf9, 0x81,
		0xef, 0x81, 0xef, 0x81, 0xef, 0x81, 0xef, 0x41, 0xf2, 0x83, 0xe4, 0x07, 0x17, 0x00, 0x17, 0x00,
		0x17, 0x00, 0x17, 0x00, 0xc9, 0x4f, 0x31, 0x9b, 0x31, 0x51, 0xcf, 0xc9, 0xb1, 0x89, 0x90, 0x50,
		0xce, 0x39, 0xf4, 0x72, 0xb1, 0xdb, 0x86, 0x45, 0x47, 0xe1, 0xd8, 0xbf, 0xd3, 0xbe, 0xbf, 0xa6,
		0x5f, 0xfa, 0xc0, 0xdd, 0x2a, 0x27, 0xcf, 0x16, 0x93, 0xf0, 0x48, 0xa4, 0x3b, 0xb2, 0x64, 0xd9,
		0x16, 0x92, 0x65, 0xd5, 0x41, 0x2d, 0x24, 0xcb, 0x92, 0x49, 0x6c, 0xd8, 0x4f, 0x57, 0x0e, 0x17,
		0x83, 0x16, 0x5f, 0x69, 0x8e, 0x85, 0xfd, 0x74, 0xbf, 0x9f, 0x6d, 0xd8, 0x4f, 0xb7, 0x97, 0x48,
		0xb5, 0x00, 0x65, 0x40, 0x35, 0x97, 0x1d, 0x5e, 0x70, 0x3d, 0x17, 0x32, 0xce, 0x0a, 0xfa, 0x95,
		0x15, 0x8e, 0x79, 0x46, 0x38, 0x50, 0x79, 0x07, 0x88, 0x70, 0x60, 0x32, 0x8c, 0xc6, 0xae, 0xa3,
		0xb0, 0xdb, 0xab, 0xff, 0xfd, 0x8b, 0xdc, 0xe1, 0x25, 0x66, 0xa4, 0x4c, 0xb9, 0x28, 0x52, 0x46,
		0x4a, 0x94, 0x99, 0x02, 0xe5, 0x41, 0x42, 0xcb, 0x88, 0x67, 0x3c, 0x94, 0x59, 0x46, 0x31, 0x27,
		0xb6, 0x29, 0x8c, 0x61, 0x0a, 0x63, 0x95, 0x55, 0x4c, 0x32, 0x79, 0xf0, 0x92, 0x16, 0x6e, 0x56,
		0xda, 0x51, 0x9f, 0xdc, 0x6c, 0xee, 0xf2, 0x51, 0x19, 0xc7, 0xb8, 0x00, 0xe0, 0x2f, 0xbd, 0x70,
		0x54, 0x8e, 0x47, 0xad, 0x1d, 0x44, 0xe9, 0xa8, 0x6c, 0xd3, 0x5d, 0x0f, 0xc0, 0xc8, 0x0d, 0xaa,
		0x97, 0x0a, 0xa3, 0x8d, 0x9d, 0x5f, 0x8e, 0xf1, 0x9e, 0x5b, 0xe5, 0xf3, 0x1c, 0xd7, 0xce, 0x6e,
		0x3b, 0x5f, 0xf2, 0x2a, 0x51, 0xd9, 0xd1, 0x66, 0x97, 0xa0, 0xec, 0x68, 0x17, 0x65, 0x47, 0x95,
		0xc8, 0x1c, 0x69, 0x73, 0x38, 0x8d, 0xa1, 0x32, 0x43, 0xd0, 0x3d, 0x39, 0x69, 0xe3, 0x20, 0x86,
		0xb5, 0x9f, 0x9e, 0x4e, 0xea, 0x4e, 0x60, 0xfb, 0x62, 0x29, 0xbc, 0xe0, 0x9e, 0xa2, 0xa4, 0xfb,
		0x99, 0x26, 0x8e, 0xde, 0x03, 0x95, 0xfc, 0x2d, 0x95, 0xcc, 0x20, 0x9a, 0xec, 0x40, 0xfc, 0x9e,
		0x15, 0x78, 0x21, 0xf5, 0xcb, 0xe4, 0x7e, 0x8c, 0x9a, 0x26, 0x92, 0xfe, 0xef, 0x7d, 0x5b, 0x46,
		0xe2, 0xb8, 0x53, 0x0e, 0xda, 0xf8, 0x8d, 0x5c, 0x2c, 0xbd, 0x9d, 0x5d, 0x89, 0xe6, 0x15, 0x8f,
		0x6d, 0xe1, 0x45, 0xb3, 0x31, 0xac, 0x5f, 0xdf, 0x0c, 0x3b, 0x35, 0xe6, 0x38, 0x82, 0xc7, 0x71,
		0xcd, 0x65, 0x03, 0xcf, 0x7f, 0xac, 0x4d, 0x87, 0x26, 0x11, 0x93, 0x81, 0xae, 0xb9, 0xa1, 0xf8,
		0x12, 0x2c, 0xee, 0x45, 0x35, 0xa1, 0x6d, 0xe8, 0x21, 0xb4, 0x99, 0xea, 0xf7, 0xef, 0x0f, 0x9d,
		0xcd, 0x52, 0x7f, 0xbf, 0x64, 0x32, 0xeb, 0x45, 0xc3, 0x4e, 0x7e, 0x32, 0x3b, 0xb9, 0x3a, 0x6b,
		0x95, 0xda, 0xa7, 0x4b, 0xe3, 0x86, 0x09, 0x36, 0xe0, 0x92, 0x8b, 0x78, 0xbc, 0x06, 0x6a, 0xb2,
		0xcf, 0x6b, 0x1b, 0x56, 0xcb, 0xcb, 0x43, 0xa9, 0xb5, 0x1c, 0x81, 0x30, 0x13, 0x1d, 0x68, 0x31,
		0x2a, 0xd7, 0xd7, 0x53, 0x68, 0xa2, 0xd5, 0xf6, 0x68, 0x5d, 0x78, 0x34, 0x78, 0xb4, 0x4a, 0x7a,
		0xb4, 0x6e, 0x21, 0x8f, 0xd6, 0x55, 0xe2, 0xd1, 0xba, 0xf0, 0x68, 0xf0, 0x68, 0x7b, 0xee, 0xd1,
		0x7e, 0xf9, 0x8d, 0xde, 0xef, 0xc8, 0x5e, 0x36, 0xd6, 0x4b, 0xc3, 0x76, 0xeb, 0x3b, 0x05, 0x26,
		0x7f, 0x17, 0x2b, 0xfd, 0xf5, 0x50, 0x6e, 0x7f, 0x2d, 0xbf, 0xb0, 0x81, 0xf5, 0x38, 0x0c, 0xb8,
		0xfc, 0xed, 0x9b, 0x58, 0x68, 0x31, 0x93, 0xaf, 0xff, 0xe6, 0x15, 0xef, 0x66, 0x42, 0x76, 0x36,
		0x19, 0x59, 0x4c, 0xc4, 0xb2, 0x49, 0xf0, 0xbd, 0x80, 0x5b, 0x76, 0x38, 0xd8, 0xe5, 0xe5, 0x67,
		0x34, 0x04, 0xb9, 0x17, 0x7e, 0xee, 0x85, 0xbe, 0xba, 0xb0, 0xd3, 0x87, 0x53, 0xad, 0x8d, 0x68,
		0x5b, 0x2e, 0xbb, 0x4c, 0xad, 0x5f, 0x2e, 0x94, 0xdb, 0x49, 0x03, 0x2a, 0xd6, 0xc8, 0x4e, 0x29,
		0x03, 0x99, 0x52, 0x05, 0x32, 0xaf, 0x91, 0x96, 0x9a, 0x35, 0xb2, 0x53, 0xf2, 0xa3, 0x79, 0xab,
		0x63, 0x97, 0xe4, 0xc3, 0x62, 0xeb, 0x62, 0x57, 0xbc, 0x58, 0x67, 0xce, 0xc0, 0x0b, 0xac, 0xf1,
		0x9c, 0x48, 0xe2, 0xec, 0x69, 0x27, 0x4f, 0xae, 0xce, 0x46, 0x6d, 0x1a, 0x55, 0xa5, 0x36, 0xee,
		0x61, 0x52, 0x1b, 0xb7, 0x2c, 0x6a, 0x93, 0x39, 0xe4, 0xbe, 0x94, 0x98, 0x9e, 0x0c, 0xf8, 0x94,
		0x67, 0x67, 0x19, 0xb3, 0xb9, 0x6d, 0xeb, 0x64, 0xb8, 0xe6, 0x75, 0x90, 0x0c, 0xc6, 0x37, 0x49,
		0xfb, 0xe8, 0x99, 0x6b, 0x4e, 0xe5, 0x9f, 0x65, 0x64, 0x35, 0xa4, 0x8a, 0xd7, 0x8a, 0xca, 0x59,
		0x13, 0x2a, 0x43, 0x84, 0xaf, 0xf0, 0x6b, 0x0a, 0xa3, 0xd9, 0xbc, 0x62, 0xbe, 0x31, 0xaf, 0x67,
		0xa7, 0x6f, 0xf6, 0x48, 0x92, 0x14, 0xed, 0x30, 0x19, 0xc3, 0x9a, 0x1c, 0x0e, 0x23, 0xbd, 0x72,
		0x4f, 0x74, 0x30, 0x38, 0x8b, 0x8a, 0xeb, 0x60, 0x36, 0x13, 0xc2, 0xe3, 0xc2, 0x92, 0x82, 0x05,
		0xb1, 0x37, 0x5e, 0xd2, 0x71, 0x7e, 0x59, 0x6c, 0x53, 0x63, 0x87, 0x91, 0xc4, 0x88, 0xd3, 0x2f,
		0x0b, 0x2f, 0x84, 0x9c, 0xfa, 0x95, 0xf6, 0x04, 0xc6, 0x99, 0x89, 0xee, 0x76, 0x0a, 0x24, 0x31,
		0x9e, 0xe5, 0xb8, 0xb4, 0x58, 0xfa, 0x5e, 0x81, 0x44, 0x1e, 0x8a, 0x74, 0x3d, 0xaa, 0xdd, 0x88,
		0x44, 0xe9, 0x79, 0x94, 0xf9, 0x60, 0x45, 0x6a, 0x38, 0x52, 0xa4, 0xe1, 0x51, 0xbf, 0xda, 0xe6,
		0x59, 0xa7, 0xd3, 0x3d, 0xed, 0x74, 0x1a, 0xa7, 0xed, 0xd3, 0xc6, 0xf9, 0xc9, 0x49, 0xb3, 0xdb,
		0x3c, 0xa9, 0xd0, 0xdb, 0xae, 0x66, 0x0e, 0x58, 0x46, 0x2b, 0x94, 0xbb, 0x98, 0x6e, 0x71, 0x47,
		0x41, 0x5e, 0x2c, 0x97, 0xae, 0x38, 0x6e, 0xc1, 0x62, 0xb8, 0xd9, 0x06, 0xb9, 0xa7, 0xe4, 0xe8,
		0x70, 0x2f, 0xb0, 0xee, 0x44, 0xc8, 0x1c, 0x9b, 0xc5, 0xd2, 0x8a, 0xbe, 0xc9, 0x02, 0x60, 0x6a,
		0xbd, 0x29, 0x40, 0x29, 0x40, 0x29, 0x40, 0x29, 0x40, 0x29, 0x40, 0x29, 0x40, 0xa9, 0xfd, 0x85,
		0x52, 0xaa, 0xfc, 0xb2, 0xe3, 0xc5, 0x36, 0x13, 0x4e, 0x31, 0x8f, 0x9c, 0x36, 0x02, 0x5f, 0x0c,
		0x5f, 0x0c, 0x5f, 0x0c, 0x5f, 0x0c, 0x5f, 0x0c, 0x5f, 0x0c, 0x5f, 0x9c, 0xd5, 0x17, 0x73, 0x21,
		0x42, 0x51, 0xcc, 0x13, 0xcf, 0x9a, 0x80, 0x1f, 0x86, 0x1f, 0x86, 0x1f, 0x86, 0x1f, 0x86, 0x1f,
		0x86, 0x1f, 0x86, 0x1f, 0xce, 0xea, 0x87, 0x5d, 0x3b, 0xa6, 0xf0, 0xc5, 0x4b, 0xcd, 0xc0, 0x1f,
		0xc3, 0x1f, 0xc3, 0x1f, 0xc3, 0x1f, 0xc3, 0x1f, 0xc3, 0x1f, 0xc3, 0x1f, 0x67, 0xf5, 0xc7, 0x83,
		0xc4, 0x97, 0x1e, 0x4d, 0xec, 0x78, 0xa5, 0x29, 0xf8, 0x65, 0xf8, 0x65, 0xf8, 0x65, 0xf8, 0x65,
		0xf8, 0x65, 0xf8, 0x65, 0xf8, 0xe5, 0xac, 0x7e, 0x39, 0xb4, 0x25, 0x2f, 0xe8, 0x8f, 0x67, 0x4d,
		0xc0, 0x0f, 0xc3, 0x0f, 0xc3, 0x0f, 0xc3, 0x0f, 0xc3, 0x0f, 0xc3, 0x0f, 0xc3, 0x0f, 0x67, 0xf5,
		0xc3, 0x85, 0x59, 0x31, 0xb8, 0x30, 0x7c, 0x30, 0x7c, 0x30, 0x7c, 0x30, 0x7c, 0x30, 0x7c, 0x30,
		0x7c, 0x70, 0x2e, 0x1f, 0x9c, 0x04, 0x44, 0x0a, 0xf5, 0x93, 0x86, 0xe0, 0x93, 0xe1, 0x93, 0xe1,
		0x93, 0xe1, 0x93, 0xe1, 0x93, 0xe1, 0x93, 0xe1, 0x93, 0xb3, 0xfb, 0xe4, 0x6f, 0x41, 0xf8, 0x3d,
		0xb0, 0x22, 0x11, 0xca, 0xb0, 0xa8, 0x57, 0x7e, 0xd2, 0x14, 0xfc, 0x32, 0xfc, 0x32, 0xfc, 0x32,
		0xfc, 0x32, 0xfc, 0x32, 0xfc, 0x32, 0xfc, 0x72, 0x26, 0xbf, 0xec, 0x8f, 0xc9, 0xad, 0xed, 0x73,
		0x26, 0xf2, 0x3b, 0xe4, 0xa5, 0x36, 0xe0, 0x89, 0xe1, 0x89, 0xf7, 0xca, 0x13, 0x4b, 0x6f, 0xc0,
		0xa5, 0x67, 0x7f, 0x8b, 0xb5, 0xfb, 0xe2, 0xbf, 0x83, 0xa9, 0x1d, 0xab, 0x07, 0x2c, 0x08, 0x63,
		0x6e, 0x87, 0x41, 0xe6, 0x1d, 0xfd, 0xf0, 0xe9, 0xf0, 0xe9, 0xf0, 0xe9, 0x55, 0xf6, 0xe9, 0x28,
		0xc9, 0x86, 0x92, 0x6c, 0xe3, 0x27, 0x08, 0x13, 0x49, 0x56, 0x93, 0x6d, 0x43, 0x5b, 0x80, 0x65,
		0x80, 0x65, 0x10, 0x48, 0x20, 0x90, 0x00, 0x4c, 0x01, 0x4c, 0x41, 0x20, 0xc9, 0xec, 0x99, 0x8b,
		0x57, 0x65, 0x7b, 0xd2, 0x0a, 0xbc, 0x31, 0xbc, 0x31, 0xbc, 0x31, 0xbc, 0x31, 0xbc, 0x31, 0xbc,
		0x31, 0xbc, 0x71, 0x66, 0x6f, 0x5c, 0xb4, 0x16, 0xcc, 0x52, 0x1b, 0xf0, 0xc4, 0xf0, 0xc4, 0xf0,
		0xc4, 0xf0, 0xc4, 0xf0, 0xc4, 0xf0, 0xc4, 0xf0, 0xc4, 0x99, 0x3d, 0x31, 0x55, 0x25, 0x98, 0x0d,
		0x6d, 0xc1, 0x33, 0xc3, 0x33, 0xc3, 0x33, 0xc3, 0x33, 0xc3, 0x33, 0xc3, 0x33, 0xc3, 0x33, 0x67,
		0xf6, 0xcc, 0x45, 0x6b, 0xc1, 0x2c, 0xb5, 0x01, 0x4f, 0x0c, 0x4f, 0x0c, 0x4f, 0x0c, 0x4f, 0x0c,
		0x4f, 0x0c, 0x4f, 0x0c, 0x4f, 0x9c, 0xd9, 0x13, 0x17, 0x67, 0xc6, 0xe0, 0xc3, 0xf0, 0xc2, 0xf0,
		0xc2, 0xf0, 0xc2, 0xf0, 0xc2, 0xf0, 0xc2, 0xf0, 0xc2, 0xf9, 0xbc, 0x30, 0x4d, 0x3d, 0x98, 0xb5,
		0x96, 0xe0, 0x95, 0xe1, 0x95, 0xe1, 0x95, 0xe1, 0x95, 0xe1, 0x95, 0xe1, 0x95, 0xe1, 0x95, 0x77,
		0xfc, 0xe6, 0x8e, 0x73, 0x2a, 0xfb, 0x66, 0xb7, 0x8c, 0x5e, 0x7d, 0x7d, 0x73, 0x5b, 0x18, 0x71,
		0xc1, 0xc6, 0x63, 0xc9, 0xfc, 0xac, 0xae, 0xbd, 0xf0, 0x66, 0xb6, 0x9c, 0x9b, 0xd8, 0x76, 0x7b,
		0xe5, 0xbd, 0x1d, 0x5f, 0xf9, 0x65, 0x10, 0x84, 0x72, 0xf2, 0x06, 0x32, 0xad, 0xdc, 0x7a, 0x6c,
		0xf7, 0xf9, 0x80, 0x45, 0x4c, 0xf6, 0xc7, 0x77, 0x7f, 0x1c, 0x46, 0x3c, 0xb0, 0x27, 0xa0, 0xc5,
		0xf2, 0xc6, 0xee, 0xc4, 0x65, 0x36, 0x8f, 0x8f, 0x37, 0x7d, 0x3c, 0x8e, 0x25, 0x93, 0xfc, 0x78,
		0xe6, 0x76, 0xb2, 0x00, 0xaa, 0x7a, 0x2c, 0x45, 0x62, 0xcb, 0x60, 0xe6, 0xb8, 0xae, 0xe7, 0x2d,
		0x7e, 0x7d, 0x35, 0x6f, 0xeb, 0x19, 0xcd, 0xfb, 0xdb, 0x61, 0xba, 0xd6, 0x1d, 0x1e, 0xdb, 0xc2,
		0x8b, 0x32, 0xbd, 0xb8, 0xd4, 0xe7, 0x2e, 0x5f, 0xbc, 0xe3, 0x38, 0x65, 0xb3, 0x8a, 0x99, 0x01,
		0x64, 0x1e, 0xe0, 0x98, 0x1b, 0x30, 0xe6, 0x05, 0x8a, 0x85, 0x01, 0x62, 0x61, 0x60, 0x58, 0x04,
		0x10, 0xd2, 0x9a, 0xca, 0xcc, 0xc0, 0x2f, 0x1d, 0xad, 0x58, 0x0a, 0x2f, 0xb8, 0xcf, 0x32, 0x5c,
		0xb3, 0xb9, 0xd7, 0x3c, 0xd3, 0xb8, 0xbe, 0x78, 0xc0, 0xee, 0x7c, 0xee, 0x64, 0x5f, 0x5b, 0xf3,
		0x0b, 0x77, 0x7c, 0x8f, 0x57, 0xdc, 0x65, 0x89, 0x3f, 0x19, 0xcf, 0xf1, 0x74, 0xc0, 0x72, 0xc4,
		0x72, 0xd4, 0xbb, 0x1c, 0xef, 0xc2, 0xd0, 0xe7, 0x2c, 0xc8, 0xb3, 0x1e, 0x9b, 0x1a, 0xd7, 0x63,
		0x9f, 0x09, 0xe7, 0x3b, 0x13, 0xdc, 0x8a, 0x42, 0x21, 0xb3, 0xaf, 0xca, 0xa7, 0x97, 0xef, 0xc7,
		0x22, 0xcb, 0xf0, 0x28, 0xfb, 0xb5, 0xcc, 0x26, 0x0f, 0x6e, 0xdc, 0x42, 0xf3, 0x39, 0x73, 0x05,
		0x77, 0xf3, 0x2c, 0xb4, 0xd3, 0x0c, 0xd7, 0xdc, 0xa4, 0x90, 0xd8, 0xb6, 0x22, 0x9f, 0x49, 0x37,
		0x14, 0x83, 0x0b, 0x3b, 0x1c, 0x44, 0x61, 0xc0, 0x03, 0x19, 0x6f, 0xfe, 0xf3, 0x93, 0xbf, 0x4e,
		0x00, 0xae, 0xc6, 0xa5, 0xed, 0xb9, 0x5e, 0xe0, 0xf0, 0x87, 0xec, 0x8b, 0x7a, 0x7e, 0x21, 0x7c,
		0x26, 0x7c, 0xa6, 0xd6, 0xa5, 0x9c, 0x78, 0x81, 0x6c, 0xb7, 0x72, 0xac, 0xe4, 0x2c, 0x0b, 0x39,
		0x9f, 0x40, 0x99, 0x43, 0x89, 0x2d, 0x22, 0x48, 0x16, 0x54, 0xcb, 0x8a, 0x0a, 0x90, 0x14, 0x52,
		0x58, 0x0e, 0xc1, 0xb1, 0x90, 0xd0, 0x48, 0xf5, 0xca, 0x3a, 0xad, 0xf3, 0xce, 0x79, 0xf7, 0xb4,
		0x75, 0x7e, 0x52, 0xe2, 0xbb, 0x53, 0x24, 0xeb, 0xf5, 0x0c, 0x97, 0xf5, 0x8a, 0xd7, 0xac, 0x2a,
		0x4f, 0xde, 0x7b, 0x01, 0xf5, 0xb3, 0xb8, 0xfa, 0x49, 0x02, 0x8c, 0xa6, 0x55, 0x4e, 0xfb, 0x33,
		0x3f, 0x90, 0x11, 0x1c, 0x2d, 0x5f, 0x0c, 0x80, 0x04, 0x80, 0xa4, 0x15, 0x20, 0xe5, 0xab, 0x61,
		0x9a, 0x23, 0x9c, 0x5b, 0xb4, 0x66, 0x29, 0x50, 0x16, 0x50, 0xd6, 0x2f, 0x5f, 0x19, 0x5d, 0xf8,
		0x16, 0x78, 0x0b, 0x78, 0x0b, 0x78, 0xab, 0xd2, 0x78, 0x2b, 0xbc, 0xf7, 0x6c, 0xe6, 0xe7, 0xc0,
		0x5a, 0xb3, 0x0b, 0x81, 0xb3, 0x80, 0xb3, 0xb4, 0xe2, 0x2c, 0xf5, 0xc1, 0x1b, 0x98, 0x7c, 0x98,
		0xfc, 0xbd, 0x36, 0xf9, 0x61, 0x74, 0xc7, 0xec, 0x6f, 0xd6, 0x20, 0x74, 0xf2, 0x90, 0xec, 0x27,
		0x97, 0x67, 0x0f, 0xf9, 0x4f, 0x5e, 0x2a, 0xdc, 0x06, 0xdc, 0xc6, 0xbe, 0xb9, 0x0d, 0x92, 0xc5,
		0x39, 0x90, 0x49, 0xf6, 0x25, 0x39, 0xbe, 0x08, 0x0b, 0x0a, 0x0b, 0x4a, 0xeb, 0x82, 0x4a, 0xbc,
		0x40, 0x36, 0xbb, 0x39, 0xd6, 0x53, 0x17, 0x52, 0x15, 0xa4, 0x2a, 0xa2, 0x57, 0xd6, 0x3d, 0x39,
		0x69, 0x1f, 0xae, 0x36, 0x45, 0xe2, 0x71, 0x66, 0xb9, 0xdd, 0x19, 0x5d, 0xce, 0xe4, 0x2a, 0xf8,
		0x1c, 0xf8, 0x1c, 0xad, 0x3e, 0xc7, 0x8c, 0x3c, 0xea, 0x31, 0xff, 0xb4, 0x62, 0xc9, 0x64, 0x12,
		0x67, 0x5f, 0x58, 0xcb, 0x17, 0x63, 0x7d, 0x61, 0x7d, 0x69, 0x5d, 0x5f, 0x3c, 0x48, 0x06, 0x33,
		0xed, 0x24, 0xcf, 0x22, 0xeb, 0x64, 0xb8, 0xe6, 0x75, 0x90, 0x0c, 0xc6, 0x37, 0x39, 0x82, 0x26,
		0x07, 0x4d, 0xee, 0xe0, 0x35, 0xb9, 0xa8, 0xff, 0x18, 0x7b, 0x36, 0xf3, 0x27, 0x33, 0x28, 0xe0,
		0x39, 0xe2, 0x31, 0x6b, 0x2d, 0xec, 0x87, 0xf3, 0x90, 0x82, 0x05, 0xb1, 0xcd, 0xbd, 0x21, 0x17,
		0x07, 0xe9, 0x45, 0x96, 0x9f, 0x1f, 0xe9, 0xff, 0x5b, 0xa6, 0x58, 0x9e, 0xf4, 0xff, 0xcf, 0xab,
		0xe9, 0xff, 0xff, 0x6d, 0x27, 0x42, 0xf0, 0x40, 0x3e, 0x3f, 0x3a, 0x7e, 0xf9, 0xf2, 0xf8, 0xe9,
		0xab, 0xbf, 0x58, 0xfa, 0xdc, 0xfb, 0xc5, 0xbf, 0xad, 0xfe, 0xd3, 0xea, 0xa2, 0x8c, 0x57, 0xbf,
		0x30, 0xfb, 0xfb, 0xea, 0x9f, 0xa7, 0x39, 0xfe, 0xa4, 0xa3, 0xf8, 0xd6, 0x8b, 0xe5, 0xa5, 0x94,
		0xd9, 0x0e, 0x20, 0xaf, 0xbf, 0xf3, 0x82, 0xd7, 0x63, 0xff, 0x16, 0x4c, 0x09, 0x72, 0x86, 0x41,
		0x79, 0xc7, 0x1e, 0x96, 0xae, 0x2c, 0x96, 0x52, 0x52, 0x7f, 0x2f, 0x1c, 0x2e, 0xb8, 0xf3, 0xc7,
		0x63, 0xfd, 0xa2, 0x16, 0x24, 0xbe, 0xaf, 0x11, 0xcc, 0xcb, 0xc8, 0xcb, 0xb1, 0x23, 0x72, 0x72,
		0x55, 0xf6, 0xd8, 0x48, 0x68, 0x5b, 0x43, 0x9f, 0x05, 0x96, 0x7c, 0x8c, 0x78, 0x7c, 0xf1, 0xf1,
		0xe6, 0xfa, 0xea, 0x6b, 0xe3, 0x9f, 0xb3, 0x66, 0xa3, 0xb1, 0x27, 0xd6, 0x7c, 0xfc, 0x70, 0x07,
		0x69, 0xc6, 0x27, 0x0f, 0x6e, 0x9c, 0xfd, 0xf6, 0x1c, 0x1e, 0x48, 0x4f, 0x3e, 0xe6, 0xb4, 0xe1,
		0x59, 0x56, 0xf8, 0xf5, 0xac, 0xab, 0x3f, 0x58, 0xcc, 0xf3, 0x97, 0x8e, 0x9a, 0xac, 0x98, 0x8f,
		0xff, 0x7b, 0xf3, 0xfa, 0x36, 0xeb, 0x80, 0x4f, 0x04, 0x45, 0xad, 0xa7, 0x3e, 0x3f, 0xb9, 0xe7,
		0xc6, 0x3f, 0xe7, 0xe3, 0x55, 0xae, 0x43, 0xb7, 0x25, 0xba, 0xdd, 0x96, 0x51, 0xb7, 0x7b, 0x76,
		0x76, 0x79, 0x66, 0xd2, 0xed, 0x9a, 0x34, 0x19, 0x2e, 0xff, 0xfa, 0xdf, 0x0a, 0x1d, 0x07, 0xae,
		0x13, 0x1a, 0x2c, 0x61, 0xf3, 0xec, 0x08, 0x21, 0x33, 0xb1, 0x01, 0x55, 0x03, 0x55, 0x03, 0x55,
		0xdb, 0x48, 0xd5, 0xa2, 0x50, 0xc8, 0x8b, 0x27, 0xf5, 0x0e, 0x7a, 0x4f, 0x9a, 0x8a, 0x93, 0xbb,
		0x2d, 0x9d, 0x2c, 0xff, 0x4b, 0xa9, 0x3b, 0xc2, 0x65, 0x96, 0xa1, 0x5b, 0x58, 0x91, 0xf1, 0x55,
		0x08, 0x13, 0x20, 0x4c, 0x00, 0x5e, 0xf0, 0xcb, 0x1b, 0x9e, 0xd7, 0x2d, 0xb3, 0x32, 0x2c, 0x98,
		0x0a, 0x70, 0x03, 0x8f, 0x05, 0xcc, 0x2a, 0x74, 0xf3, 0x14, 0x0f, 0x51, 0xec, 0x61, 0xd6, 0x1e,
		0x8a, 0x0d, 0x3d, 0xdb, 0x7b, 0x1f, 0x49, 0xcf, 0x66, 0xfe, 0x6b, 0xd9, 0xcf, 0xe2, 0x2d, 0x09,
		0x10, 0x2f, 0xf1, 0xc3, 0x38, 0xa1, 0x1d, 0xbf, 0x62, 0x77, 0x3e, 0xff, 0xcb, 0x31, 0xfa, 0x39,
		0x1e, 0x5a, 0x27, 0x91, 0xcf, 0x4d, 0x7e, 0x82, 0x61, 0xe8, 0xd9, 0xfc, 0xf5, 0x3b, 0x93, 0x1f,
		0xa1, 0xdf, 0x6e, 0xb5, 0x6f, 0x44, 0xf8, 0xf0, 0x68, 0xf2, 0x43, 0x30, 0x39, 0xf8, 0xe4, 0x09,
		0x99, 0x30, 0xdf, 0xe4, 0xa7, 0x18, 0x44, 0xfc, 0xfe, 0xe3, 0x18, 0xd0, 0x67, 0x2b, 0xbc, 0x54,
		0xc1, 0x85, 0x7d, 0xd6, 0x7d, 0xcb, 0xa2, 0xd8, 0xe4, 0x47, 0xb8, 0x3f, 0x6d, 0xb4, 0x99, 0xec,
		0x76, 0xbe, 0x99, 0xfc, 0x10, 0xf3, 0xb0, 0xac, 0xc1, 0x8f, 0x10, 0xb8, 0xcc, 0xe8, 0x79, 0xe4,
		0xc5, 0x49, 0x64, 0xf2, 0xfd, 0x47, 0x22, 0x8c, 0x2e, 0xe5, 0xc0, 0x68, 0xb8, 0x14, 0x37, 0xdf,
		0x5c, 0xbd, 0x35, 0x7a, 0x10, 0x7c, 0xdb, 0x68, 0xef, 0xec, 0x27, 0xaf, 0xa3, 0x30, 0x78, 0x1f,
		0x24, 0x46, 0x3f, 0x85, 0x13, 0xfb, 0xad, 0xc8, 0x4f, 0x8c, 0x36, 0x47, 0x8c, 0xf9, 0x2d, 0x93,
		0xef, 0xff, 0xff, 0x98, 0xd1, 0xa6, 0xc8, 0x15, 0x6c, 0xc0, 0x3f, 0x70, 0x9f, 0x3d, 0xde, 0x72,
		0x31, 0xf4, 0x6c, 0xa3, 0xc9, 0x8f, 0x6d, 0xcb, 0xd7, 0x83, 0xc4, 0x68, 0x74, 0xe1, 0xf8, 0xf1,
		0x77, 0xb3, 0xd1, 0x45, 0x78, 0x76, 0xd6, 0x68, 0x9d, 0xbc, 0xfa, 0xf0, 0xe6, 0xe6, 0x3a, 0x30,
		0x9a, 0x33, 0x0c, 0x1e, 0x85, 0x17, 0x70, 0x69, 0xf6, 0xea, 0x76, 0x9b, 0xdd, 0x77, 0xae, 0xf8,
		0x23, 0x09, 0x1c, 0xc3, 0x75, 0x8d, 0x29, 0x99, 0xfe, 0x78, 0xbf, 0x07, 0x8b, 0xa3, 0xfd, 0x2a,
		0x1e, 0x30, 0xdb, 0x31, 0x5a, 0xa3, 0xf1, 0x22, 0x2e, 0x7c, 0x16, 0x18, 0xed, 0xba, 0xc3, 0xa9,
		0xfa, 0xba, 0x17, 0x02, 0x87, 0xe0, 0xf7, 0x89, 0xcf, 0x44, 0xf3, 0xac, 0xd5, 0xda, 0x0b, 0x21,
		0xf9, 0xef, 0x28, 0x96, 0x82, 0x9b, 0x8d, 0xad, 0x04, 0x67, 0x76, 0xff, 0xea, 0xd6, 0x68, 0xa2,
		0xe7, 0x45, 0xb7, 0xdf, 0x3d, 0x69, 0xf7, 0x8d, 0x7e, 0x86, 0xbb, 0x41, 0xfb, 0xb4, 0x11, 0x31,
		0xf1, 0xaa, 0x9f, 0x25, 0xff, 0xb0, 0x82, 0x4e, 0x30, 0xf4, 0x6c, 0xfe, 0x7e, 0xc8, 0xc5, 0x9b,
		0x14, 0xb5, 0x1b, 0x8d, 0x4e, 0x58, 0x2c, 0x27, 0xa1, 0xaf, 0x37, 0xff, 0x18, 0x3d, 0x2a, 0x63,
		0x1a, 0x6e, 0xf2, 0x03, 0xf0, 0xf1, 0x18, 0x04, 0x5c, 0xb6, 0xdf, 0xdd, 0x79, 0x72, 0x1f, 0xc8,
		0xc7, 0x95, 0x34, 0x3a, 0x0a, 0x29, 0x13, 0xd3, 0x35, 0x72, 0x3f, 0x1c, 0xe3, 0x2a, 0xe6, 0x9b,
		0x1d, 0xab, 0xe0, 0xf1, 0x1e, 0x68, 0x9c, 0x37, 0xb3, 0xcd, 0x37, 0x7f, 0x07, 0x9e, 0xe1, 0xaa,
		0xbf, 0xe4, 0x61, 0x70, 0xd6, 0x30, 0xdd, 0x46, 0xf5, 0xbd, 0x28, 0xf2, 0xd2, 0x13, 0x04, 0xf7,
		0xc2, 0x7d, 0x1b, 0x8d, 0xd1, 0x5d, 0xbb, 0xd9, 0x39, 0x6b, 0x1b, 0x1d, 0x18, 0x3e, 0x3f, 0x3f,
		0x33, 0x5b, 0x42, 0xf7, 0xcd, 0x8e, 0x26, 0xa5, 0xa4, 0xf5, 0x2a, 0xfc, 0x1e, 0x98, 0x4f, 0x5b,
		0xa7, 0x29, 0x44, 0x81, 0xcd, 0x8c, 0x0e, 0x13, 0x0f, 0xb8, 0xe3, 0xb1, 0x77, 0xcc, 0xf3, 0xc7,
		0x7c, 0xe9, 0xda, 0xe8, 0x47, 0x61, 0xc2, 0xec, 0xa1, 0x70, 0x86, 0x77, 0x1f, 0x6c, 0xfb, 0x1d,
		0xb3, 0xdf, 0xb2, 0x47, 0xb3, 0xbd, 0x85, 0xc7, 0x39, 0x3f, 0x6b, 0xb4, 0x9a, 0x27, 0x1d, 0xa3,
		0x1d, 0x86, 0x68, 0x37, 0xda, 0x1f, 0xae, 0x3e, 0x1a, 0x8d, 0x07, 0x9d, 0x60, 0x82, 0x3d, 0xde,
		0x86, 0x61, 0x64, 0xb4, 0xf3, 0xf3, 0x59, 0xe4, 0x18, 0xef, 0x2d, 0xde, 0xfc, 0x79, 0xf5, 0xfa,
		0xf2, 0xaf, 0x4b, 0xa3, 0xd9, 0xde, 0x53, 0x07, 0xfe, 0xc1, 0xbd, 0x31, 0x3c, 0x22, 0xc0, 0x84,
		0x6d, 0x78, 0xf4, 0x72, 0x8c, 0xab, 0xde, 0xbb, 0xce, 0x60, 0x3f, 0x60, 0xd5, 0x20, 0x32, 0x1a,
		0xe4, 0xf6, 0x9d, 0xbe, 0xf1, 0xc1, 0x25, 0xb3, 0xb3, 0x06, 0xef, 0xbd, 0x7b, 0x76, 0xe7, 0x4d,
		0x29, 0xb7, 0xe1, 0x2b, 0x3b, 0x8a, 0xa2, 0x77, 0x89, 0x2f, 0x3d, 0xdf, 0x0b, 0xbe, 0x99, 0x9f,
		0x9b, 0x30, 0x8b, 0x23, 0xbf, 0x9a, 0xe6, 0x36, 0xff, 0x29, 0x42, 0xb3, 0x13, 0x6c, 0xa5, 0x68,
		0x34, 0xce, 0x4c, 0x7e, 0x80, 0xbb, 0xfb, 0x28, 0x0a, 0x7d, 0xcf, 0x7e, 0x64, 0xb6, 0x1d, 0x26,
		0x81, 0xf4, 0x82, 0x7b, 0xe3, 0xe9, 0x53, 0xfc, 0xd1, 0x19, 0x30, 0xa3, 0x07, 0xc5, 0x93, 0xb1,
		0xd9, 0x39, 0xdb, 0x46, 0x8b, 0x84, 0x9e, 0x13, 0x1b, 0x1d, 0x51, 0xba, 0x13, 0x9e, 0x73, 0x6f,
		0xb4, 0x97, 0x88, 0xc2, 0xa0, 0x6b, 0x36, 0x7e, 0xea, 0x87, 0x03, 0x1e, 0x05, 0x46, 0x5b, 0xa1,
		0xef, 0xdf, 0x59, 0x70, 0x73, 0x63, 0xf8, 0xc6, 0x42, 0xf3, 0xc5, 0xe5, 0x3f, 0x6e, 0x4d, 0x8f,
		0xac, 0xbe, 0xbd, 0x31, 0x1b, 0xe2, 0xb1, 0x20, 0x8e, 0xfe, 0x9f, 0x63, 0x76, 0xdc, 0x85, 0xc7,
		0x76, 0x18, 0x98, 0x9d, 0x5c, 0xf7, 0x26, 0x14, 0xdf, 0x99, 0x30, 0x5a, 0x00, 0x64, 0xae, 0xcf,
		0x02, 0x7e, 0xd6, 0x68, 0x9d, 0x18, 0x2d, 0xff, 0x79, 0xb1, 0x1d, 0x5e, 0xdf, 0xbe, 0xcd, 0x56,
		0xa2, 0xb0, 0x82, 0xcf, 0xc1, 0xa2, 0xef, 0x2c, 0xfa, 0xb7, 0x8c, 0x66, 0xbb, 0xcf, 0x3f, 0x30,
		0xc7, 0x0b, 0x8d, 0x96, 0xcd, 0xbc, 0xf0, 0xc1, 0xec, 0xa9, 0x25, 0x22, 0xb3, 0x6b, 0x62, 0xdc,
		0x85, 0x0f, 0xff, 0xf6, 0x04, 0xf7, 0x79, 0x6c, 0x34, 0x81, 0x8b, 0xc3, 0x80, 0xcb, 0xf7, 0x43,
		0x2e, 0xfa, 0x9c, 0x39, 0xaf, 0xcc, 0xdf, 0x87, 0xce, 0xfc, 0xe4, 0x4f, 0xf3, 0xf7, 0xb0, 0xc6,
		0xbe, 0x17, 0x19, 0x0e, 0xc7, 0xdf, 0x24, 0x66, 0xa7, 0xd6, 0xcd, 0xb3, 0x66, 0x3f, 0x86, 0xdf,
		0x78, 0xf0, 0xc1, 0x70, 0xb1, 0xcc, 0x73, 0xad, 0xfb, 0xd8, 0xec, 0x24, 0xff, 0xc1, 0x77, 0x26,
		0xf8, 0xcc, 0x7d, 0xff, 0xe5, 0xd9, 0xc6, 0xef, 0x50, 0x37, 0xda, 0x77, 0xc7, 0xad, 0x76, 0x6b,
		0x4f, 0x2a, 0x73, 0xb9, 0x86, 0xdb, 0x59, 0xe3, 0xa1, 0x6c, 0x3c, 0x70, 0xe2, 0xab, 0x07, 0xa3,
		0x7d, 0xc5, 0xbd, 0x8c, 0x4c, 0x4f, 0x95, 0x6d, 0x9a, 0x9f, 0xd4, 0x71, 0x63, 0x78, 0xcd, 0x8f,
		0x7e, 0x1c, 0x1b, 0xbd, 0x0a, 0x62, 0x61, 0xf4, 0x2a, 0x08, 0x65, 0xf0, 0x5e, 0x26, 0xe6, 0xcb,
		0xf8, 0x46, 0x3b, 0xe6, 0xc4, 0x97, 0x82, 0x99, 0x1d, 0x0d, 0x8a, 0xe5, 0x0d, 0x73, 0xf6, 0x60,
		0x53, 0x51, 0xd3, 0xf8, 0x4d, 0x45, 0xc3, 0xb6, 0xd1, 0x0a, 0xd9, 0x80, 0xd9, 0xb7, 0xdc, 0x7e,
		0x15, 0x06, 0x52, 0x84, 0xbe, 0xcf, 0x9d, 0xeb, 0x37, 0xfb, 0xc0, 0xa7, 0xdf, 0x78, 0x77, 0x66,
		0x67, 0xbb, 0x8f, 0xfd, 0x84, 0x63, 0xb4, 0x9f, 0xb8, 0x77, 0x59, 0x2c, 0x4d, 0xdf, 0x70, 0xd0,
		0x6c, 0x9f, 0x1b, 0xbd, 0xdd, 0xc0, 0x71, 0x82, 0x7f, 0xcc, 0x56, 0xf0, 0xcd, 0x96, 0x28, 0xbd,
		0xd8, 0x09, 0x4c, 0x17, 0x91, 0xf6, 0xc0, 0x1f, 0x74, 0x26, 0xfa, 0xea, 0x1f, 0x49, 0xbc, 0x07,
		0xcf, 0xd2, 0x32, 0x7c, 0xc7, 0xe6, 0x64, 0x13, 0xb6, 0xd1, 0x6b, 0x22, 0x7e, 0x0c, 0x6c, 0xf3,
		0xf7, 0x04, 0xee, 0xc7, 0xce, 0x8e, 0xd0, 0xf4, 0x4d, 0xf0, 0xd3, 0x3d, 0x5c, 0xff, 0xbc, 0x37,
		0xba, 0x1a, 0x81, 0xed, 0x45, 0x6f, 0xbd, 0xe0, 0x9b, 0xf1, 0x21, 0x6a, 0xa3, 0x37, 0x33, 0xb6,
		0xbd, 0xe8, 0xc1, 0xf4, 0x14, 0x9a, 0xd8, 0x8b, 0x6e, 0x3d, 0xb3, 0x77, 0x0c, 0xc4, 0x8d, 0x3d,
		0xa8, 0xf5, 0x79, 0x1d, 0x5d, 0x3a, 0x8e, 0x30, 0x3c, 0xeb, 0x64, 0xbc, 0x22, 0x4c, 0x5f, 0x10,
		0xae, 0xd8, 0x83, 0x34, 0x45, 0x6e, 0x9b, 0x6e, 0x5c, 0x67, 0x05, 0x9d, 0xde, 0x86, 0xf7, 0x9e,
		0xcd, 0x7c, 0xd3, 0x7d, 0x5d, 0x24, 0xc2, 0xe8, 0x55, 0xe0, 0x9b, 0xcd, 0x86, 0x0c, 0x5f, 0xd8,
		0x83, 0xd0, 0x66, 0x9f, 0xb8, 0x88, 0xbd, 0x30, 0x30, 0x3a, 0x2a, 0x6a, 0xdf, 0xf9, 0x9f, 0xb8,
		0x2d, 0xd9, 0xad, 0x64, 0xc2, 0xf0, 0x2d, 0x42, 0xcd, 0x13, 0xb3, 0xd3, 0xa8, 0x43, 0xd7, 0xe5,
		0x46, 0x6f, 0xd3, 0x12, 0xcc, 0xf1, 0xc2, 0x77, 0x97, 0xaf, 0x8c, 0x06, 0x1d, 0x03, 0xe3, 0x4f,
		0xf8, 0xb9, 0x09, 0xbd, 0x40, 0x7e, 0x0c, 0x27, 0xff, 0xbb, 0xe5, 0xc2, 0x33, 0xfb, 0x1c, 0xb5,
		0xf1, 0x13, 0xed, 0xc1, 0x71, 0x70, 0xae, 0x77, 0x27, 0xf8, 0x1e, 0xa4, 0x4e, 0x3b, 0x71, 0xc3,
		0xfc, 0xaa, 0x03, 0xe9, 0xbe, 0x9b, 0xb6, 0xd9, 0x64, 0xfb, 0xe1, 0x63, 0xf8, 0x26, 0x4c, 0x84,
		0xe1, 0x8a, 0x81, 0xd9, 0x07, 0x53, 0x44, 0x66, 0x6f, 0x2a, 0x8d, 0xc2, 0xd8, 0xfc, 0xf4, 0x87,
		0xbf, 0x03, 0x7b, 0x4f, 0x12, 0x20, 0xa4, 0xe1, 0xfb, 0x4a, 0x67, 0x67, 0xe8, 0xbe, 0xf9, 0xf3,
		0xca, 0x68, 0xff, 0x60, 0x4b, 0xee, 0x7b, 0xf1, 0x3b, 0x2e, 0xd9, 0xdb, 0xf7, 0xef, 0x6f, 0xf6,
		0xe3, 0x90, 0xb2, 0x49, 0xe1, 0x64, 0x3b, 0x0c, 0x02, 0x6e, 0x1b, 0xad, 0xe5, 0xc4, 0x7d, 0xc3,
		0x83, 0xda, 0x22, 0x16, 0x77, 0x66, 0xa7, 0x74, 0xbc, 0x1f, 0x72, 0x61, 0xfa, 0x39, 0xa2, 0xf3,
		0xcd, 0x1d, 0xef, 0x5e, 0x0d, 0x64, 0xbc, 0x1f, 0xc1, 0xd4, 0x87, 0x56, 0xb3, 0xbd, 0x0f, 0xf5,
		0x30, 0xdf, 0xdf, 0x1a, 0x7e, 0x10, 0x7e, 0x3f, 0x09, 0xa4, 0xf1, 0xb5, 0xcc, 0x06, 0xee, 0xad,
		0x77, 0x6f, 0xba, 0x54, 0xee, 0xd8, 0x81, 0xe9, 0xe7, 0x04, 0x98, 0x2e, 0xde, 0x5c, 0x85, 0x76,
		0x3c, 0xdf, 0x04, 0xff, 0x8e, 0xd9, 0xbe, 0xe9, 0x85, 0xac, 0x07, 0x43, 0xb3, 0x53, 0xea, 0xdc,
		0x4f, 0xae, 0xf7, 0xf1, 0x31, 0xe2, 0x66, 0x17, 0x84, 0xf5, 0xe3, 0x8f, 0xc6, 0x1f, 0xf5, 0x93,
		0x9e, 0x49, 0x36, 0x01, 0x22, 0x66, 0xaf, 0x73, 0x6f, 0xc0, 0xc4, 0xe3, 0xf5, 0xed, 0xd5, 0x5f,
		0xfb, 0x50, 0xa3, 0xbe, 0xfb, 0xef, 0x77, 0x97, 0x46, 0x3f, 0xc8, 0x20, 0x36, 0x9c, 0x23, 0x4d,
		0x77, 0xf2, 0xff, 0xe5, 0xd9, 0x1f, 0x0d, 0xc7, 0xe4, 0xf3, 0x42, 0xdc, 0x6c, 0x1f, 0x4e, 0xe5,
		0x8c, 0x25, 0xb3, 0xbf, 0x7d, 0x0c, 0x6f, 0xc7, 0xff, 0xdb, 0x97, 0x13, 0x10, 0x9a, 0xe6, 0x53,
		0xf1, 0x57, 0x86, 0x8b, 0x86, 0xce, 0xf0, 0xee, 0x32, 0xf6, 0xde, 0x27, 0x46, 0x43, 0x5d, 0xc9,
		0x4d, 0xe7, 0x4a, 0x13, 0x38, 0x72, 0x75, 0x7d, 0x65, 0xf6, 0xae, 0xb5, 0xc8, 0xfc, 0x12, 0x74,
		0x57, 0xa1, 0x6c, 0x36, 0x6f, 0x44, 0xe8, 0x7a, 0x66, 0xa3, 0x42, 0xc7, 0xbb, 0xf7, 0x24, 0xf3,
		0x6f, 0xc2, 0xef, 0x5c, 0xf8, 0x5e, 0x60, 0x3c, 0xe3, 0x30, 0xbf, 0x12, 0xfa, 0x3e, 0x1c, 0x24,
		0x25, 0x5c, 0xfb, 0xec, 0xf4, 0xd4, 0xf0, 0xc2, 0x86, 0xa6, 0xe3, 0x73, 0x26, 0x07, 0x9f, 0x6c,
		0xef, 0x75, 0xe0, 0xdc, 0x48, 0xb3, 0x73, 0xee, 0x06, 0x51, 0x18, 0x7b, 0xe6, 0xfb, 0xee, 0xd8,
		0x8b, 0xf6, 0x49, 0x27, 0xdc, 0x07, 0xb2, 0x94, 0xaa, 0x3b, 0x86, 0x47, 0xca, 0x58, 0xb3, 0xf5,
		0x2e, 0x8a, 0x6e, 0xbf, 0x7b, 0xd2, 0xee, 0x9b, 0x6d, 0x72, 0x6d, 0x6f, 0x2f, 0x22, 0x96, 0xb7,
		0xb6, 0xe4, 0x27, 0x27, 0x4e, 0xeb, 0xef, 0xf8, 0x7d, 0x78, 0x67, 0x78, 0xbe, 0xb0, 0xd9, 0x5e,
		0xf0, 0x3e, 0x32, 0xbb, 0x88, 0xfa, 0x1d, 0x8b, 0x3d, 0xdb, 0x74, 0xd1, 0x76, 0x89, 0x33, 0xfd,
		0x61, 0xf6, 0x86, 0xb7, 0x61, 0xbb, 0x6b, 0xf6, 0x16, 0x5c, 0x57, 0x7e, 0x67, 0x82, 0xbf, 0x0d,
		0xc3, 0xe8, 0xce, 0x70, 0x85, 0xd0, 0x0e, 0xf6, 0xe2, 0xb0, 0xdd, 0xa6, 0xe1, 0x1c, 0xe3, 0x2e,
		0x0c, 0x8c, 0xde, 0x39, 0xe9, 0x7b, 0x01, 0xbf, 0x37, 0x3d, 0x11, 0x64, 0x56, 0xe2, 0xc0, 0xe8,
		0xa4, 0x9c, 0xa1, 0xd9, 0x4b, 0x21, 0x8e, 0x4f, 0xf7, 0x20, 0x19, 0x87, 0xcf, 0x8e, 0xdf, 0x7c,
		0x15, 0x0f, 0x98, 0xed, 0x18, 0x9e, 0xe3, 0x35, 0xf0, 0x23, 0xc3, 0x8f, 0x11, 0x35, 0x7b, 0xfb,
		0xad, 0xc3, 0x07, 0xa6, 0x97, 0x53, 0x6e, 0x1b, 0x7f, 0x12, 0xfe, 0xb5, 0xd9, 0x27, 0xe1, 0xcf,
		0xca, 0x02, 0x98, 0x1d, 0x76, 0x14, 0x03, 0xf3, 0x4b, 0xc9, 0x4e, 0x8f, 0x34, 0x8e, 0x7c, 0xfe,
		0x10, 0x1a, 0x8d, 0xbb, 0xfd, 0x96, 0xe9, 0x05, 0x4b, 0xbc, 0xc0, 0xf5, 0x02, 0xef, 0x8e, 0x99,
		0x8d, 0xbb, 0x99, 0x1c, 0xcc, 0x6a, 0x7d, 0xec, 0x01, 0x8b, 0x6b, 0x33, 0xe7, 0x2d, 0xbb, 0xdf,
		0x9f, 0x53, 0xbe, 0xf7, 0x29, 0x50, 0xb1, 0x1f, 0x1b, 0x47, 0xbc, 0xd8, 0x31, 0xfb, 0x28, 0xac,
		0x24, 0xde, 0x83, 0x1d, 0x55, 0xaf, 0x7c, 0xf6, 0x7d, 0x9f, 0x02, 0x14, 0xcd, 0x37, 0xdf, 0x1d,
		0xc3, 0x23, 0x14, 0x43, 0xd3, 0x8f, 0xfe, 0x8e, 0xf7, 0xa0, 0xd2, 0xe9, 0x3e, 0x04, 0x83, 0x67,
		0xc5, 0x7f, 0xbb, 0xef, 0x4c, 0x2f, 0x67, 0x37, 0xdf, 0x4d, 0xfc, 0xee, 0xe6, 0xda, 0x68, 0x80,
		0xc8, 0xfc, 0x13, 0xd3, 0x71, 0xc8, 0x1c, 0x83, 0xdc, 0xb4, 0x6e, 0xcc, 0x8e, 0xcb, 0x1b, 0x9f,
		0xbd, 0xfc, 0xd1, 0x19, 0xec, 0x55, 0x66, 0xc1, 0x95, 0xe9, 0x99, 0x05, 0x4c, 0x0e, 0xae, 0x07,
		0xcc, 0xec, 0x6d, 0x7a, 0x37, 0xdf, 0x4d, 0xdf, 0xa5, 0xe7, 0xc4, 0x4d, 0xe3, 0x4b, 0x4a, 0xdf,
		0x30, 0xd9, 0x37, 0xfd, 0xe0, 0xc4, 0x6b, 0xdb, 0xf0, 0x53, 0x38, 0x02, 0xc9, 0x85, 0xcf, 0xd9,
		0x70, 0x1f, 0xb2, 0xe1, 0xff, 0x2d, 0x58, 0x14, 0x71, 0xb1, 0x47, 0xa7, 0x69, 0x4f, 0xd6, 0xc9,
		0xa7, 0x8f, 0x7b, 0x91, 0xab, 0x79, 0x6d, 0x7c, 0x1a, 0xed, 0x1f, 0xff, 0xbe, 0x8c, 0x5a, 0xef,
		0xcc, 0x7e, 0x0c, 0xb3, 0xcd, 0x15, 0x37, 0x3b, 0xa2, 0xe4, 0x0d, 0x8c, 0x4e, 0xe9, 0xff, 0xbf,
		0xd6, 0x79, 0xdb, 0x68, 0xd8, 0x11, 0x18, 0x9e, 0xcb, 0xcf, 0x23, 0x5f, 0xc4, 0xe6, 0x6f, 0x47,
		0xbd, 0x0e, 0x0c, 0x8f, 0x6c, 0xff, 0x19, 0x85, 0xc1, 0x4d, 0xff, 0x31, 0xf6, 0x6c, 0xe6, 0xff,
		0x1d, 0x78, 0xa6, 0x97, 0xc1, 0x31, 0x5c, 0x89, 0xed, 0x3f, 0x46, 0x5c, 0xd8, 0xe6, 0x83, 0x3d,
		0xd7, 0x71, 0x8c, 0x9e, 0x4a, 0x3e, 0x8b, 0x5c, 0xc3, 0x4b, 0x30, 0x88, 0xb7, 0x66, 0x8b, 0xc8,
		0xfd, 0x76, 0xab, 0xfd, 0x27, 0x93, 0xfc, 0x1b, 0xe7, 0x91, 0xd9, 0x5b, 0x51, 0x53, 0xe1, 0x6c,
		0x1e, 0xa2, 0xf8, 0xe0, 0xde, 0x84, 0x42, 0x1a, 0xbe, 0x3e, 0x8c, 0x56, 0xfe, 0xee, 0x4f, 0x1b,
		0x6d, 0x26, 0x5b, 0x83, 0xbb, 0xbd, 0x8a, 0xa4, 0x7e, 0xe0, 0xd2, 0x70, 0x45, 0xd6, 0x8b, 0x9d,
		0x20, 0xde, 0xab, 0xb5, 0xbe, 0x07, 0xca, 0x4d, 0xdf, 0x89, 0xfd, 0x96, 0xd9, 0xf1, 0xc8, 0x2b,
		0x7f, 0x0f, 0xb6, 0xa1, 0x2f, 0xc2, 0xaa, 0xfb, 0x51, 0x52, 0x77, 0x0f, 0xaa, 0x3c, 0x0e, 0xdb,
		0xa7, 0x46, 0x93, 0x70, 0xd3, 0x77, 0x7e, 0x5d, 0x3d, 0x78, 0x86, 0x3f, 0xc1, 0x6d, 0x72, 0x37,
		0x29, 0xb9, 0xee, 0x32, 0x9b, 0xef, 0xc3, 0x5e, 0xc2, 0x96, 0xd9, 0x9e, 0xce, 0xec, 0x24, 0x83,
		0x88, 0x89, 0x22, 0xe1, 0xec, 0x5c, 0x57, 0xf6, 0x9e, 0x69, 0x78, 0x4f, 0xf9, 0xde, 0xcf, 0x62,
		0x9d, 0x0d, 0x3d, 0xdb, 0x7b, 0x3f, 0x4d, 0x2f, 0x7e, 0x9d, 0xef, 0x2c, 0x69, 0xfd, 0x37, 0x9d,
		0x3a, 0xca, 0xbf, 0x1c, 0x23, 0xee, 0xf7, 0xa1, 0x75, 0x12, 0xe5, 0xa9, 0x44, 0xa6, 0xff, 0x4e,
		0x67, 0xc7, 0x8f, 0x98, 0x70, 0xab, 0xfd, 0x76, 0xab, 0x7d, 0x23, 0xc2, 0x87, 0x47, 0x13, 0x6e,
		0x96, 0xc9, 0x41, 0xee, 0x33, 0xd8, 0xf4, 0xdf, 0xed, 0x20, 0xe2, 0xf7, 0x1f, 0x05, 0x0b, 0xe2,
		0x28, 0x97, 0x18, 0x53, 0xc2, 0x02, 0x3b, 0xeb, 0xbe, 0x65, 0x51, 0x6c, 0xc2, 0xad, 0x4e, 0xf5,
		0x95, 0x6e, 0xe7, 0x9b, 0x09, 0x37, 0x9b, 0x5b, 0x6f, 0xd7, 0x7f, 0xab, 0x81, 0xcb, 0x8c, 0x18,
		0x7f, 0x2f, 0xce, 0x53, 0xcc, 0x40, 0xff, 0x7d, 0x46, 0x22, 0x8c, 0x72, 0x15, 0xde, 0x2a, 0x01,
		0x0e, 0xc4, 0xcd, 0x37, 0x57, 0x6f, 0x8d, 0x78, 0xa9, 0x79, 0x40, 0x74, 0x09, 0xde, 0x6a, 0xba,
		0xad, 0xf7, 0x7d, 0x9e, 0x3d, 0x4d, 0x25, 0xdc, 0xad, 0x13, 0xfb, 0xad, 0xc8, 0x4f, 0x8c, 0x58,
		0xfe, 0x8c, 0xe5, 0x11, 0x0c, 0xf5, 0xdf, 0xe7, 0xff, 0x31, 0x23, 0x96, 0xfe, 0x42, 0xf8, 0xbb,
		0xe5, 0x62, 0xe8, 0xd9, 0x46, 0x80, 0x6c, 0xdb, 0x96, 0xaf, 0x07, 0x89, 0x11, 0x5e, 0xd5, 0xf1,
		0xe3, 0xef, 0x66, 0x78, 0xd5, 0xc9, 0xf6, 0xa0, 0x93, 0x57, 0x1f, 0xde, 0xdc, 0x5c, 0x07, 0x46,
		0x60, 0xd6, 0xc1, 0xa3, 0xf0, 0x02, 0x2e, 0xcd, 0x58, 0x65, 0x6e, 0xb3, 0xfb, 0xce, 0x15, 0x79,
		0x0f, 0x2e, 0x2e, 0x81, 0xc7, 0x4e, 0xc9, 0x56, 0x9e, 0x93, 0x71, 0x4b, 0x9b, 0xbc, 0xed, 0xbc,
		0x65, 0x7d, 0x4a, 0xe0, 0xde, 0x5e, 0xc4, 0x85, 0xcf, 0x02, 0x23, 0x5c, 0xd9, 0x6c, 0xf3, 0xbc,
		0x51, 0x84, 0x56, 0xf0, 0xfb, 0xc4, 0x67, 0xa2, 0x79, 0xd6, 0x6a, 0x19, 0x25, 0xc8, 0xe5, 0xdf,
		0x6a, 0x5a, 0xc6, 0x3b, 0x66, 0x76, 0xff, 0xea, 0xd6, 0x08, 0xe2, 0xe0, 0xe5, 0xae, 0x1f, 0x5c,
		0xc2, 0xbd, 0xde, 0x0d, 0xda, 0xa7, 0x8d, 0x88, 0x89, 0x57, 0xfd, 0x3c, 0x79, 0x56, 0x25, 0x89,
		0x9e, 0xef, 0x87, 0x5c, 0xbc, 0x29, 0x10, 0x46, 0x2e, 0xc1, 0x2b, 0xb3, 0x58, 0x4e, 0x24, 0xfb,
		0x37, 0xff, 0x18, 0xf1, 0x96, 0xf3, 0xe5, 0x4a, 0xe8, 0xbf, 0xd1, 0x79, 0x95, 0xbd, 0xf6, 0xbb,
		0x3b, 0x4f, 0x9a, 0x04, 0x7e, 0xaf, 0xa4, 0x11, 0xd1, 0x10, 0x99, 0x98, 0xa2, 0x29, 0xfa, 0xe1,
		0x18, 0x37, 0x30, 0xdf, 0x0c, 0xad, 0x96, 0xc7, 0x06, 0x69, 0x4b, 0x85, 0x12, 0xeb, 0x4b, 0x51,
		0x43, 0x25, 0x0f, 0x83, 0xb3, 0x86, 0x29, 0x36, 0xa1, 0xef, 0x45, 0x91, 0x57, 0x20, 0x7d, 0xa2,
		0x44, 0x77, 0x66, 0x04, 0x76, 0x74, 0xed, 0x66, 0x27, 0x4f, 0xfd, 0xc9, 0x12, 0x02, 0x4e, 0xe7,
		0xe7, 0x67, 0x66, 0x48, 0x8e, 0xbe, 0x19, 0xea, 0x78, 0x4a, 0x76, 0x8a, 0xd4, 0x2e, 0x2b, 0x2b,
		0xb4, 0x1f, 0xd8, 0xcc, 0x88, 0xf0, 0xd3, 0x80, 0x3b, 0x1e, 0x7b, 0xc7, 0x3c, 0x3f, 0xef, 0xa6,
		0xe2, 0x12, 0x3c, 0x9b, 0x30, 0xe3, 0xd5, 0x4e, 0x8b, 0x42, 0xe5, 0x3f, 0xc9, 0xac, 0x04, 0x80,
		0x3b, 0xcb, 0xa0, 0x3b, 0xe9, 0x18, 0x61, 0x70, 0x45, 0xbb, 0xd1, 0xfe, 0x90, 0xa7, 0xb0, 0x6f,
		0x09, 0xb8, 0x66, 0xe9, 0x20, 0x57, 0x23, 0x9c, 0x84, 0xcf, 0x22, 0xc7, 0x18, 0x6b, 0xfb, 0xe6,
		0xcf, 0xab, 0xd7, 0x97, 0x7f, 0x5d, 0x1a, 0xc1, 0x1e, 0x9e, 0x3a, 0xb4, 0xbc, 0xfb, 0xb0, 0xca,
		0xb0, 0xba, 0xb6, 0x21, 0x51, 0x94, 0xf9, 0x49, 0xd6, 0x66, 0xc1, 0x86, 0x41, 0x64, 0x04, 0x28,
		0xeb, 0x3b, 0x7d, 0x63, 0xc4, 0x72, 0x33, 0xb2, 0x6a, 0xee, 0xbd, 0x7b, 0x76, 0xe7, 0x4d, 0x29,
		0x99, 0x21, 0x2b, 0x2c, 0x8a, 0xa6, 0x75, 0xd0, 0x7d, 0x2f, 0xf8, 0x66, 0x4e, 0xac, 0xf2, 0x69,
		0x71, 0xe7, 0x3f, 0xf3, 0x9d, 0x76, 0x53, 0x82, 0x8c, 0x27, 0x1a, 0x8d, 0x33, 0x13, 0x6e, 0xf4,
		0xee, 0x3e, 0x8a, 0x42, 0xdf, 0xb3, 0x1f, 0x99, 0x6d, 0x87, 0x49, 0x20, 0xbd, 0xe0, 0xde, 0x18,
		0x98, 0x1e, 0x7f, 0x74, 0xf2, 0x94, 0xe1, 0x2b, 0xe1, 0x25, 0x7b, 0x32, 0x36, 0x23, 0x57, 0xd0,
		0x08, 0xd1, 0xc6, 0xcb, 0x55, 0xad, 0xa3, 0x84, 0x61, 0x17, 0x9e, 0x73, 0x6f, 0x84, 0x95, 0x8d,
		0xc2, 0xa0, 0x6b, 0x06, 0x3e, 0xe8, 0x87, 0x03, 0x1e, 0x05, 0x46, 0xac, 0xfa, 0xef, 0xdf, 0x59,
		0x70, 0x73, 0x63, 0xc8, 0x06, 0x0c, 0x73, 0x44, 0xba, 0x3f, 0x6e, 0x4d, 0x89, 0xe4, 0xbc, 0xbd,
		0x31, 0x03, 0xaa, 0xb0, 0x20, 0x8e, 0xfe, 0x9f, 0x63, 0x86, 0xbe, 0xcc, 0x63, 0x3b, 0x0c, 0xcc,
		0x48, 0x4a, 0x79, 0x13, 0x8a, 0xef, 0x4c, 0x18, 0x21, 0xc8, 0x30, 0xd7, 0x67, 0x01, 0x3f, 0x6b,
		0xb4, 0x4e, 0x8c, 0x90, 0x63, 0xbc, 0xd8, 0x0e, 0xaf, 0x6f, 0xdf, 0xe6, 0x3b, 0x0d, 0xa9, 0x0c,
		0xf9, 0x28, 0xfa, 0xce, 0xa2, 0x7f, 0xcb, 0x68, 0xb6, 0xcb, 0xed, 0x03, 0x73, 0xbc, 0xd0, 0x08,
		0x79, 0xc3, 0x0b, 0x1f, 0xcc, 0x98, 0x12, 0x22, 0x32, 0x63, 0xaf, 0xeb, 0x5d, 0xf8, 0x30, 0x2f,
		0xac, 0x6f, 0xc2, 0xfd, 0x4e, 0x8a, 0xef, 0x16, 0x2e, 0x26, 0x5c, 0x8a, 0xf7, 0xfd, 0xd3, 0x9c,
		0x3d, 0x3a, 0xb1, 0xef, 0x45, 0x86, 0xc0, 0xc4, 0x37, 0x89, 0x19, 0x29, 0x29, 0xf3, 0xac, 0xaf,
		0x8f, 0xe1, 0x37, 0x1e, 0x7c, 0x30, 0x44, 0xd4, 0xf0, 0x5c, 0xeb, 0x3e, 0x36, 0x23, 0x29, 0x74,
		0xf0, 0x9d, 0x09, 0x3e, 0x73, 0x67, 0x7f, 0x79, 0xb6, 0x31, 0x3b, 0xe1, 0x8c, 0xf0, 0x65, 0x71,
		0xab, 0xdd, 0x32, 0xac, 0xd2, 0x84, 0x6b, 0x88, 0xfd, 0x32, 0x06, 0x7a, 0xc5, 0x03, 0x27, 0xce,
		0x55, 0xa5, 0xa8, 0x84, 0x58, 0x88, 0x8c, 0x4c, 0x49, 0xf5, 0x6a, 0x9a, 0x13, 0xb4, 0xbd, 0x31,
		0x64, 0xcf, 0x6e, 0x3f, 0x8e, 0x8d, 0x98, 0xa5, 0xb1, 0x30, 0x62, 0x96, 0x86, 0x32, 0x78, 0x2f,
		0x13, 0x73, 0xe4, 0x4d, 0x23, 0x1c, 0x55, 0xe2, 0x4b, 0xc1, 0xcc, 0x50, 0xb7, 0x63, 0x99, 0xeb,
		0xbc, 0xed, 0xd2, 0x92, 0xbe, 0x9b, 0xc6, 0x24, 0x7d, 0x0f, 0xdb, 0x46, 0x28, 0x19, 0x03, 0x66,
		0xdf, 0x72, 0xfb, 0x55, 0x18, 0x48, 0x11, 0xfa, 0x3e, 0x77, 0xae, 0xdf, 0x98, 0xc4, 0xb7, 0xde,
		0x78, 0x77, 0x66, 0x64, 0x4d, 0x8e, 0xed, 0xac, 0x63, 0x84, 0x9d, 0xbd, 0x77, 0x59, 0x2c, 0x4d,
		0x49, 0x44, 0x6d, 0xb6, 0xcf, 0x8d, 0x48, 0x43, 0x75, 0x9c, 0xe0, 0x1f, 0x33, 0x94, 0x4d, 0x33,
		0xa4, 0x21, 0x2f, 0x76, 0x02, 0x53, 0x44, 0x00, 0x83, 0xec, 0x69, 0x67, 0xa2, 0x5f, 0xfd, 0x91,
		0xc4, 0x06, 0xdd, 0x73, 0xcb, 0x90, 0x9d, 0x2a, 0x93, 0x4d, 0x60, 0x46, 0xcc, 0xd9, 0xf8, 0x31,
		0xb0, 0xcd, 0xd9, 0x3b, 0x61, 0x56, 0x06, 0x6f, 0x68, 0xca, 0xa6, 0xba, 0x69, 0xce, 0xfc, 0x3f,
		0xef, 0x8d, 0xd8, 0xad, 0x68, 0x7b, 0xd1, 0x5b, 0x2f, 0xf8, 0x66, 0x4c, 0x88, 0xcb, 0x88, 0xcd,
		0x1d, 0x6d, 0x2f, 0x7a, 0x30, 0x25, 0xe4, 0x1d, 0x7b, 0xd1, 0xad, 0x67, 0x46, 0x26, 0x69, 0xdc,
		0x30, 0xa8, 0x66, 0xd3, 0x75, 0x74, 0xe9, 0x38, 0xc2, 0x90, 0xe8, 0xf1, 0x78, 0xc6, 0x9a, 0x32,
		0x61, 0x5d, 0x61, 0x50, 0xba, 0x0e, 0xb7, 0x4d, 0x31, 0x5a, 0xb3, 0x82, 0x06, 0x6f, 0xc3, 0x7b,
		0xcf, 0x66, 0xbe, 0x29, 0x3e, 0x21, 0x12, 0x61, 0xf4, 0x2a, 0xf0, 0xcd, 0x40, 0xdd, 0x86, 0x2c,
		0xb0, 0x41, 0x68, 0xb3, 0x4f, 0x5c, 0xc4, 0x5e, 0x18, 0x18, 0x11, 0x85, 0xb1, 0xef, 0xfc, 0x4f,
		0xdc, 0x96, 0xec, 0x56, 0x32, 0x61, 0x48, 0x0a, 0x77, 0xf3, 0xc4, 0x8c, 0xf4, 0xbd, 0xd0, 0x75,
		0xb9, 0x11, 0x69, 0xf1, 0x82, 0x39, 0x5e, 0xf8, 0xee, 0xf2, 0x95, 0x11, 0xce, 0x76, 0x60, 0x4c,
		0xe5, 0xec, 0x9b, 0xd0, 0x0b, 0xe4, 0xc7, 0x70, 0xf2, 0xbf, 0x5b, 0x2e, 0x3c, 0x33, 0xea, 0xfe,
		0x8f, 0xef, 0xdc, 0xa0, 0x63, 0x0a, 0x5c, 0xef, 0x4e, 0x70, 0x83, 0x52, 0xf6, 0x9c, 0xb8, 0x61,
		0xce, 0xae, 0xc4, 0x34, 0x5f, 0xba, 0x6d, 0x06, 0x19, 0x7b, 0xf8, 0x18, 0xbe, 0x09, 0x13, 0x61,
		0x08, 0x73, 0x34, 0xa3, 0x30, 0x6d, 0x64, 0xc6, 0xa6, 0x99, 0x28, 0x8c, 0xcd, 0x09, 0x7b, 0xfe,
		0x1d, 0xd8, 0x86, 0x05, 0x3e, 0xa5, 0x21, 0xfb, 0x66, 0x66, 0x67, 0x17, 0xbd, 0xf9, 0xf3, 0xca,
		0x08, 0xfb, 0x6a, 0x4b, 0xee, 0x7b, 0xf1, 0x3b, 0x2e, 0xd9, 0xdb, 0xf7, 0xef, 0x6f, 0xcc, 0x2a,
		0xb6, 0x3f, 0x29, 0x2c, 0x67, 0x87, 0x41, 0xc0, 0x6d, 0x23, 0x38, 0x7a, 0xdc, 0x37, 0x24, 0x28,
		0x26, 0x62, 0x71, 0x67, 0x46, 0xc8, 0xf6, 0xfd, 0x90, 0x0b, 0x53, 0xce, 0x87, 0x49, 0xcf, 0x55,
		0x7d, 0x35, 0x90, 0xb1, 0x59, 0xc1, 0x9b, 0x87, 0x56, 0xb3, 0x6d, 0x52, 0xbd, 0xa3, 0xf7, 0xb7,
		0x86, 0x1c, 0xc8, 0xd7, 0x4f, 0x02, 0x69, 0x4c, 0xad, 0x8d, 0x81, 0x7b, 0xeb, 0xdd, 0x9b, 0x22,
		0x2d, 0x3a, 0x76, 0x60, 0x4a, 0xbd, 0x51, 0x53, 0x48, 0xf9, 0x55, 0x68, 0xc7, 0xf3, 0x4d, 0x75,
		0xf9, 0x0f, 0x87, 0x2e, 0x61, 0xde, 0x0e, 0xcd, 0x48, 0x45, 0x71, 0x3f, 0xb9, 0xde, 0xc7, 0xc7,
		0x88, 0x9b, 0x51, 0x90, 0xcb, 0x8f, 0x3f, 0x1a, 0x53, 0x42, 0x3b, 0xad, 0xad, 0x3f, 0x71, 0xc0,
		0x66, 0xac, 0x37, 0x6f, 0xc0, 0xc4, 0xe3, 0xf5, 0xed, 0xd5, 0x5f, 0x26, 0xd5, 0xc6, 0xec, 0xfe,
		0xfb, 0xdd, 0xa5, 0x11, 0x37, 0x3c, 0x88, 0x0d, 0xc1, 0xe2, 0xd3, 0x1d, 0x80, 0x7f, 0x79, 0xf6,
		0x47, 0x43, 0xb0, 0xe2, 0xbc, 0xc0, 0x20, 0x33, 0xe9, 0x14, 0x96, 0x58, 0x32, 0xfb, 0xdb, 0xc7,
		0xf0, 0x76, 0xfc, 0x3f, 0xd3, 0x2a, 0xa6, 0x36, 0xcd, 0xa1, 0x6a, 0xaf, 0x0c, 0x11, 0x71, 0x9c,
		0xe1, 0xdd, 0x65, 0xec, 0xbd, 0x4f, 0x8c, 0x80, 0x66, 0x92, 0x9b, 0x82, 0xc9, 0x27, 0x6e, 0xf8,
		0xea, 0xfa, 0xca, 0x8c, 0xdd, 0x00, 0x91, 0x39, 0x25, 0x4f, 0xae, 0x42, 0xd9, 0x6c, 0xde, 0x88,
		0xd0, 0xf5, 0xcc, 0x40, 0x37, 0x8e, 0x77, 0xef, 0x49, 0xe6, 0xdf, 0x84, 0xdf, 0xb9, 0xf0, 0xbd,
		0xc0, 0x18, 0xc4, 0x6b, 0x4e, 0xc5, 0x46, 0x93, 0x0a, 0xab, 0x0b, 0xd7, 0x3e, 0x3b, 0x3d, 0x35,
		0xa4, 0x00, 0x8e, 0x29, 0xb8, 0x91, 0xc9, 0xc1, 0x27, 0xdb, 0x7b, 0x1d, 0x38, 0x37, 0xd2, 0x8c,
		0x5c, 0x95, 0x41, 0x14, 0xc6, 0x9e, 0x39, 0xbe, 0x2c, 0xf6, 0x22, 0x13, 0x75, 0x1b, 0x93, 0x40,
		0x79, 0xca, 0xda, 0x0d, 0x51, 0xf8, 0x59, 0xb3, 0xf5, 0x2e, 0x32, 0xe8, 0x88, 0xc4, 0xd8, 0xb1,
		0x3d, 0xa3, 0x22, 0x27, 0xb7, 0xb6, 0xe4, 0x27, 0x27, 0x4e, 0xeb, 0xef, 0xf8, 0x7d, 0x78, 0x67,
		0x48, 0x5e, 0x9b, 0x19, 0xde, 0xe2, 0x3e, 0x32, 0xa3, 0xd8, 0xe3, 0x1d, 0x8b, 0x3d, 0xdb, 0x14,
		0x51, 0x6c, 0x09, 0x9b, 0xff, 0x61, 0xc6, 0x46, 0x82, 0x61, 0xbb, 0x6b, 0xc6, 0x56, 0x22, 0x57,
		0x7e, 0x67, 0x82, 0xbf, 0x0d, 0xc3, 0xe8, 0xce, 0x10, 0xc5, 0xc6, 0x0e, 0x8c, 0x3a, 0xe4, 0xa8,
		0x69, 0x08, 0xc6, 0xbd, 0x0b, 0x03, 0x23, 0x76, 0x92, 0x8c, 0x59, 0xee, 0xbd, 0x29, 0x81, 0xde,
		0xd9, 0x16, 0x48, 0x23, 0x82, 0xe8, 0x43, 0x33, 0xa6, 0x6a, 0x1c, 0x9f, 0x1a, 0x14, 0x3c, 0x9f,
		0x1f, 0x3e, 0xfc, 0x2a, 0x1e, 0x30, 0xdb, 0x31, 0x24, 0x97, 0x62, 0xe0, 0x47, 0x86, 0x1c, 0x0f,
		0x63, 0xc6, 0x36, 0x22, 0x87, 0x0f, 0x4c, 0x29, 0x37, 0xd7, 0x36, 0xe6, 0x44, 0xbe, 0x6b, 0x33,
		0x4e, 0xe4, 0x9b, 0x6d, 0x27, 0x34, 0x23, 0xfc, 0x21, 0x06, 0xe6, 0x94, 0xf2, 0x9a, 0x1e, 0x0d,
		0x15, 0xf9, 0xfc, 0x21, 0x34, 0x02, 0x0f, 0xfa, 0x2d, 0x53, 0x36, 0x16, 0x7b, 0x81, 0xeb, 0x05,
		0xde, 0x1d, 0x33, 0x03, 0x0f, 0x32, 0x39, 0x98, 0xed, 0xd5, 0x35, 0x88, 0x15, 0xb4, 0x99, 0xf3,
		0x96, 0xdd, 0x9b, 0x77, 0x9a, 0x99, 0x89, 0x42, 0xad, 0x59, 0x09, 0xc2, 0x5e, 0xec, 0x98, 0x51,
		0x02, 0x3e, 0x89, 0x0d, 0xca, 0x6c, 0x7f, 0xe5, 0xb3, 0xef, 0x26, 0x0a, 0xb4, 0xcd, 0x37, 0xdf,
		0x1d, 0x43, 0x14, 0xda, 0xa1, 0x29, 0x47, 0x9c, 0xc5, 0x06, 0x55, 0xa6, 0x32, 0x29, 0xc8, 0x34,
		0x2b, 0xa6, 0xd6, 0x7d, 0x67, 0x4a, 0xf9, 0x94, 0xf9, 0xee, 0xa7, 0x77, 0x37, 0xd7, 0x46, 0x00,
		0x1d, 0xe6, 0x9f, 0x98, 0xe2, 0x7f, 0xe7, 0xbe, 0xf7, 0xa6, 0x75, 0x63, 0x46, 0xfc, 0xce, 0x98,
		0x6c, 0xba, 0x8f, 0xce, 0xc0, 0xc8, 0x48, 0xe3, 0x95, 0x29, 0x91, 0x46, 0x26, 0x07, 0xd7, 0x66,
		0x9c, 0xd1, 0xea, 0xb9, 0x37, 0xdf, 0x4d, 0xd9, 0xe5, 0xe0, 0xc4, 0x4d, 0x63, 0x4a, 0xeb, 0xdd,
		0x30, 0xd9, 0x37, 0xe5, 0xc0, 0x8d, 0x6b, 0xdb, 0x90, 0x6a, 0xbb, 0x81, 0xe4, 0xc2, 0xe7, 0x6c,
		0x68, 0x52, 0x56, 0xe5, 0xbf, 0x05, 0x8b, 0x22, 0x2e, 0x0c, 0x3c, 0x4d, 0x6c, 0x32, 0x8f, 0x3f,
		0x7d, 0x34, 0x2a, 0x37, 0xe9, 0xda, 0x98, 0x34, 0xb0, 0x3f, 0xfe, 0x7d, 0x19, 0xb5, 0xde, 0x99,
		0x71, 0xbb, 0x66, 0x98, 0x07, 0x6e, 0xc8, 0x09, 0xa9, 0x03, 0x23, 0x52, 0x40, 0xff, 0xaf, 0x75,
		0xde, 0x36, 0xc2, 0xdd, 0x06, 0x86, 0xe4, 0x7e, 0xf2, 0xc8, 0x17, 0xb1, 0x39, 0xdb, 0x6d, 0xae,
		0x03, 0x83, 0x4e, 0xbc, 0xbc, 0xe9, 0x3f, 0xc6, 0x9e, 0xcd, 0xfc, 0xbf, 0xcd, 0x38, 0xa6, 0xd1,
		0x65, 0xb1, 0x34, 0x44, 0xe9, 0xea, 0x3f, 0x46, 0x5c, 0xd8, 0xe6, 0x80, 0x16, 0xd7, 0x71, 0x8c,
		0x98, 0x02, 0x3e, 0x8b, 0x5c, 0x43, 0xb6, 0x62, 0x8a, 0xb7, 0x66, 0x88, 0x71, 0xfd, 0x76, 0xab,
		0xfd, 0x27, 0x93, 0xfc, 0x1b, 0xe7, 0x91, 0x19, 0x5b, 0x6d, 0x52, 0x81, 0x63, 0x2e, 0xd1, 0x7e,
		0x70, 0x6f, 0x42, 0x21, 0x0d, 0x99, 0xbf, 0x46, 0x28, 0x31, 0xf7, 0xa7, 0x8d, 0x36, 0x93, 0xad,
		0xc1, 0x9d, 0x91, 0x91, 0x9b, 0x0f, 0x5c, 0x1a, 0xa2, 0x78, 0x79, 0xb1, 0x13, 0xc4, 0x46, 0xae,
		0x39, 0x83, 0x18, 0x79, 0xdf, 0x94, 0xb3, 0x7c, 0x5d, 0x71, 0xe5, 0x1b, 0xb4, 0xdd, 0x6d, 0x11,
		0xc6, 0x31, 0xab, 0x74, 0x99, 0x41, 0x55, 0x7f, 0x86, 0xed, 0x53, 0x23, 0x48, 0x9a, 0x29, 0x99,
		0xf6, 0x86, 0x1c, 0x92, 0xcc, 0xe4, 0xe0, 0x36, 0xb9, 0x9b, 0x94, 0x86, 0x74, 0x99, 0xcd, 0x4d,
		0xda, 0x73, 0xd1, 0x32, 0xc3, 0x23, 0x98, 0x11, 0x74, 0x8c, 0x58, 0xae, 0x93, 0x68, 0x33, 0x5d,
		0xd1, 0x7b, 0x46, 0xdb, 0xee, 0xef, 0xbf, 0xf5, 0xeb, 0x6f, 0xfc, 0xe6, 0x2d, 0xd7, 0x2f, 0x93,
		0xfb, 0x01, 0x0f, 0x24, 0x77, 0xea, 0x17, 0xb5, 0xcf, 0xcf, 0x68, 0x06, 0x20, 0x7d, 0xe1, 0xc7,
		0xa1, 0x6d, 0x79, 0xee, 0x85, 0x37, 0x5f, 0x79, 0xf1, 0xea, 0x1f, 0x66, 0xbf, 0xc7, 0x92, 0x49,
		0x5e, 0xdf, 0x6d, 0x3e, 0xd4, 0xaf, 0x78, 0x6c, 0x0b, 0x2f, 0x92, 0x5e, 0x18, 0x8c, 0xfb, 0xb8,
		0x74, 0x9c, 0xb8, 0xc6, 0x6a, 0x82, 0xbb, 0x5c, 0xf0, 0xc0, 0xe6, 0x35, 0x57, 0x84, 0x83, 0x1a,
		0x0b, 0x6a, 0x69, 0x27, 0x35, 0x19, 0xd6, 0x64, 0x9f, 0xd7, 0xec, 0x50, 0x08, 0x1e, 0x47, 0x61,
		0xe0, 0x78, 0xc1, 0xfd, 0x97, 0x40, 0x0a, 0x16, 0xc4, 0x36, 0xf7, 0x86, 0x5c, 0xd4, 0x26, 0x5b,
		0xcd, 0x03, 0x1e, 0xc8, 0x97, 0xbb, 0xde, 0xc5, 0xff, 0xe7, 0x05, 0xe3, 0x57, 0xd6, 0xdc, 0xf1,
		0xeb, 0xaf, 0xc2, 0xc0, 0xf5, 0xee, 0xeb, 0x17, 0xb5, 0xc6, 0x8e, 0x17, 0xdc, 0x08, 0xee, 0x7a,
		0x0f, 0xf5, 0x8b, 0x0c, 0x73, 0x7e, 0x91, 0xe9, 0x68, 0x5b, 0x4b, 0x0f, 0x57, 0xdf, 0x7d, 0x9d,
		0xd5, 0x6f, 0xc3, 0x44, 0xd8, 0x3c, 0x53, 0xaf, 0xd3, 0xb7, 0xc1, 0x1f, 0xbf, 0x87, 0xc2, 0x99,
		0x86, 0x15, 0x26, 0x37, 0x9e, 0x6d, 0x71, 0xd7, 0xff, 0x1f, 0x8b, 0x2f, 0xc5, 0x7d, 0x32, 0x9e,
		0x8a, 0xf5, 0x8b, 0x9a, 0x14, 0x09, 0xcf, 0xd8, 0xc0, 0xd2, 0xd5, 0xab, 0xcf, 0x4f, 0xbd, 0x22,
		0x77, 0x9d, 0xa7, 0x9e, 0xc8, 0x36, 0x7c, 0xcb, 0xf7, 0x9c, 0x79, 0x04, 0xd2, 0xd4, 0xf7, 0x5c,
		0x03, 0xbf, 0x69, 0x61, 0xdd, 0x88, 0x70, 0xe8, 0x39, 0xfc, 0xe9, 0xe2, 0x9a, 0x2d, 0xa5, 0xe5,
		0xb5, 0x13, 0x27, 0x77, 0xe9, 0xf2, 0xa9, 0xc9, 0x3e, 0x93, 0x5f, 0x82, 0xc5, 0x4a, 0x8b, 0xe7,
		0x57, 0x44, 0x33, 0x71, 0xb4, 0x16, 0x85, 0x42, 0x2e, 0xd6, 0x5b, 0xcd, 0x0d, 0x45, 0x4d, 0xf6,
		0xbd, 0x78, 0xb1, 0x5c, 0x5f, 0x7e, 0x09, 0x3e, 0xf6, 0x79, 0xcd, 0xe1, 0x43, 0xcf, 0xe6, 0xb5,
		0x41, 0x12, 0xcb, 0x5a, 0x18, 0xf8, 0x8f, 0xb5, 0x28, 0x8c, 0x12, 0x9f, 0x49, 0x3e, 0xfd, 0xba,
		0xcf, 0x99, 0x5b, 0xfb, 0xee, 0xc9, 0xfe, 0xca, 0xed, 0x7d, 0x09, 0xd8, 0x52, 0xeb, 0xa1, 0x5b,
		0x93, 0x8f, 0x11, 0xaf, 0x7d, 0xfc, 0x70, 0xf9, 0xd7, 0xed, 0xab, 0xd7, 0xd7, 0x9f, 0x5e, 0x7f,
		0x78, 0x99, 0xf5, 0xb5, 0xcc, 0x56, 0x7a, 0x23, 0xe3, 0x65, 0x59, 0x57, 0x7c, 0x91, 0x95, 0x4f,
		0x67, 0x01, 0x8a, 0x5a, 0x02, 0x32, 0x8b, 0x40, 0x66, 0x19, 0x48, 0x2d, 0x44, 0x3e, 0x4c, 0x90,
		0x11, 0xe9, 0xd4, 0x27, 0xa9, 0x30, 0x85, 0xc6, 0x7f, 0xbc, 0x3a, 0x04, 0x77, 0xf3, 0x0c, 0xfc,
		0xdc, 0xb1, 0x9d, 0xe6, 0xb8, 0x76, 0x92, 0x6f, 0x32, 0xf3, 0xfb, 0x91, 0xcf, 0xa4, 0x1b, 0x8a,
		0xc1, 0x45, 0xba, 0x1a, 0xe3, 0xcd, 0x7f, 0xfe, 0xbc, 0xfc, 0xd7, 0x80, 0x0d, 0xf8, 0x7f, 0xdb,
		0x89, 0x10, 0x3c, 0x90, 0xcf, 0x8f, 0x8e, 0x5f, 0xbe, 0x9c, 0x5c, 0x13, 0x0a, 0x79, 0xd1, 0x67,
		0xc2, 0xf9, 0xce, 0x04, 0x9f, 0xfc, 0xd6, 0x7b, 0xd2, 0xd4, 0xb2, 0x05, 0x8a, 0xb7, 0xfe, 0xcb,
		0xf1, 0x6a, 0x3f, 0xd9, 0x86, 0x7d, 0xa4, 0x1f, 0xd8, 0xbd, 0xd8, 0x1f, 0x3c, 0x36, 0x76, 0x01,
		0x77, 0x2c, 0xe6, 0x4f, 0x51, 0x99, 0x27, 0xe3, 0x55, 0x54, 0x96, 0xfa, 0x89, 0x59, 0xb8, 0x27,
		0x06, 0x22, 0x03, 0x22, 0x2b, 0x0b, 0x91, 0xcd, 0x27, 0xa3, 0x35, 0x8f, 0x3d, 0xe6, 0x86, 0x65,
		0x6b, 0x2d, 0x15, 0xc3, 0x66, 0x6f, 0x42, 0x51, 0x63, 0xf3, 0x25, 0xe2, 0xfd, 0xff, 0xb8, 0xb3,
		0x58, 0x57, 0x2f, 0x6a, 0xbe, 0x17, 0x4f, 0x90, 0x4f, 0xba, 0x04, 0xe7, 0x20, 0x6c, 0xc3, 0xea,
		0xaa, 0x3d, 0xf7, 0x59, 0xc0, 0xe3, 0xa3, 0xa7, 0xcb, 0x70, 0x0e, 0xda, 0x56, 0x31, 0xd9, 0xfa,
		0xe5, 0x4c, 0xf0, 0x1a, 0xf7, 0xf9, 0x78, 0x9c, 0xe3, 0x71, 0x9f, 0xac, 0xb6, 0x91, 0x56, 0x7d,
		0x09, 0xbc, 0x60, 0x0a, 0x03, 0x67, 0x06, 0xb8, 0x36, 0x08, 0x1d, 0xee, 0x03, 0x8b, 0x01, 0x8b,
		0x01, 0x8b, 0x19, 0x85, 0xc5, 0x96, 0x86, 0xea, 0x62, 0xe9, 0x73, 0xef, 0x17, 0xff, 0xb6, 0xfa,
		0x4f, 0xab, 0xb6, 0x30, 0x5e, 0xfd, 0xc2, 0xec, 0xef, 0xab, 0x7f, 0xf6, 0x02, 0x87, 0x3f, 0xd4,
		0x95, 0x8e, 0xf6, 0x5b, 0x2f, 0x96, 0x97, 0x52, 0x8a, 0x7c, 0x23, 0xfe, 0xce, 0x0b, 0x5e, 0xcf,
		0x6c, 0x61, 0x76, 0x5b, 0x33, 0x6d, 0x81, 0x3d, 0x2c, 0xb5, 0xd0, 0x3c, 0xeb, 0x74, 0xba, 0xa7,
		0x9d, 0x4e, 0xe3, 0xb4, 0x7d, 0xda, 0x38, 0x3f, 0x39, 0x69, 0x76, 0x9b, 0x27, 0x39, 0x1a, 0x7d,
		0x2f, 0x1c, 0x2e, 0xb8, 0xf3, 0xc7, 0x63, 0xfd, 0xa2, 0x16, 0x24, 0xbe, 0x0f, 0xd8, 0x5b, 0x32,
		0xec, 0xdd, 0x20, 0x46, 0xae, 0xa8, 0x22, 0x33, 0x6f, 0x39, 0xd3, 0x40, 0xbc, 0x60, 0xc8, 0x03,
		0x19, 0x8a, 0xc7, 0x7d, 0xc1, 0xc2, 0xe3, 0xa7, 0x3d, 0x48, 0x10, 0x1c, 0x65, 0x4a, 0xac, 0x29,
		0x19, 0xfd, 0x3e, 0x61, 0xdc, 0xf9, 0xa1, 0xef, 0xd3, 0x66, 0x8a, 0xe3, 0xde, 0x20, 0x0c, 0xac,
		0x8d, 0xc8, 0x37, 0x7e, 0xf1, 0x04, 0xf2, 0xf6, 0x79, 0x6d, 0xde, 0xf5, 0x44, 0x74, 0x5c, 0x96,
		0x25, 0x97, 0x30, 0xee, 0xd3, 0xe5, 0x79, 0x28, 0x88, 0x34, 0xc7, 0x58, 0x1c, 0x06, 0x14, 0x8d,
		0xf2, 0xa5, 0xbe, 0x01, 0x83, 0x92, 0x61, 0x50, 0xe8, 0x74, 0xfa, 0x00, 0xcb, 0xc7, 0x9b, 0xeb,
		0xab, 0xda, 0x71, 0x6d, 0x52, 0xdb, 0x6d, 0x12, 0x28, 0x09, 0xa3, 0x49, 0x9b, 0xb3, 0xb0, 0xcc,
		0xaa, 0x75, 0xdc, 0x13, 0xf8, 0x31, 0x29, 0x5f, 0x74, 0x88, 0xf0, 0x23, 0x5b, 0xdd, 0xa6, 0xb2,
		0xc3, 0xa1, 0x91, 0xe7, 0x14, 0x88, 0x83, 0x8e, 0xaf, 0x2e, 0x06, 0x36, 0xde, 0x4f, 0x3e, 0x31,
		0xdf, 0x7f, 0xac, 0xc5, 0x5c, 0x4e, 0xe3, 0x9e, 0xec, 0xbe, 0x16, 0x89, 0x50, 0x86, 0x76, 0xe8,
		0xd7, 0x3c, 0x87, 0x07, 0xd2, 0x73, 0x3d, 0x2e, 0x6a, 0xae, 0xc7, 0x7d, 0xa7, 0xf6, 0x7c, 0xbc,
		0x9c, 0x8e, 0x66, 0x31, 0x50, 0x2f, 0xae, 0x31, 0xdb, 0xe6, 0x91, 0xe4, 0x4e, 0x2d, 0x9c, 0xc2,
		0xf9, 0x4f, 0x6f, 0x2f, 0xff, 0xca, 0x7e, 0x4f, 0x2e, 0x4b, 0xfc, 0xe5, 0x01, 0xb4, 0xc6, 0x0b,
		0x35, 0xbe, 0x18, 0xf7, 0xf5, 0xb5, 0xf1, 0xcf, 0x59, 0xb3, 0xd1, 0x38, 0x10, 0xcc, 0x92, 0x71,
		0xd9, 0x1e, 0x0e, 0x66, 0xc9, 0x59, 0x8e, 0xad, 0xe2, 0x98, 0x65, 0xba, 0xbc, 0xe4, 0x63, 0x41,
		0xdc, 0x92, 0x47, 0x31, 0xb9, 0x9e, 0x75, 0xfd, 0x07, 0x8b, 0x0b, 0xcc, 0x9b, 0xf9, 0x83, 0x4c,
		0x56, 0xea, 0xc7, 0xff, 0xbd, 0x79, 0x7d, 0x9b, 0x77, 0xe2, 0x7c, 0x62, 0x7e, 0xc2, 0xe3, 0x9d,
		0x32, 0xb4, 0x8a, 0x21, 0x90, 0xdd, 0x9e, 0xa5, 0xf1, 0xcf, 0xf9, 0xd8, 0xea, 0xe4, 0x6e, 0x71,
		0xf4, 0xa2, 0x2a, 0x8f, 0xd1, 0xda, 0x8b, 0xc7, 0x38, 0x3b, 0xbb, 0x3c, 0xdb, 0x87, 0xc7, 0xd8,
		0x87, 0x49, 0x75, 0xf9, 0xd7, 0xff, 0x16, 0x78, 0x86, 0x5c, 0x57, 0xf6, 0x54, 0x9b, 0xfe, 0x8a,
		0xa5, 0xb4, 0xf6, 0x7e, 0x97, 0xd2, 0x1a, 0x04, 0xa1, 0x64, 0x33, 0x14, 0xf7, 0xfb, 0xb1, 0xad,
		0xc7, 0x76, 0x9f, 0x0f, 0x58, 0x94, 0x72, 0xd5, 0x88, 0x07, 0xf6, 0x04, 0xea, 0x58, 0x4b, 0x04,
		0x6c, 0xd3, 0xc7, 0xe3, 0x29, 0xff, 0x7a, 0x96, 0xef, 0x51, 0x7e, 0x31, 0x61, 0xeb, 0x71, 0x72,
		0xb7, 0xe8, 0xf0, 0xb7, 0x4f, 0xb1, 0xd8, 0x27, 0xf9, 0xe4, 0xb2, 0xdf, 0xbc, 0xa6, 0xdd, 0x48,
		0xda, 0xce, 0xa8, 0x2f, 0x0b, 0xca, 0x5b, 0x46, 0x75, 0xde, 0x2e, 0xde, 0x3d, 0x2b, 0x86, 0xcb,
		0x8d, 0xd9, 0x72, 0x63, 0xb4, 0x55, 0x4c, 0xe6, 0xed, 0xb0, 0xb1, 0xb6, 0x58, 0xe6, 0xf6, 0xae,
		0x84, 0xea, 0xc9, 0xac, 0xd8, 0xfd, 0x0d, 0x6e, 0x9a, 0x53, 0x7b, 0xc2, 0xff, 0x3d, 0xf7, 0x20,
		0xd9, 0xbf, 0xe7, 0x1a, 0xc3, 0xfd, 0xed, 0xf9, 0x8c, 0xc8, 0xc9, 0xfe, 0x67, 0xd7, 0xe7, 0xe3,
		0xc5, 0x4d, 0xc3, 0x78, 0xb1, 0xe7, 0x82, 0x15, 0x17, 0x9c, 0xee, 0x7a, 0x38, 0x71, 0xd6, 0x65,
		0x90, 0x5e, 0xe8, 0x3c, 0x11, 0xa6, 0x8a, 0xee, 0xdc, 0x5c, 0x6a, 0x2c, 0xe7, 0x9b, 0xce, 0x27,
		0x20, 0x15, 0x5e, 0x30, 0x14, 0x0b, 0x87, 0x6c, 0x01, 0x51, 0x2d, 0x24, 0xf2, 0x05, 0x45, 0xbe,
		0xb0, 0x28, 0x17, 0x58, 0x31, 0xa6, 0x93, 0x93, 0xe3, 0xe5, 0x17, 0xa3, 0xd6, 0xd1, 0x90, 0x14,
		0x5e, 0x70, 0x5f, 0x64, 0xba, 0xcc, 0x9d, 0xcc, 0xd9, 0x33, 0x3d, 0xef, 0x2d, 0xc7, 0x3b, 0xab,
		0xf3, 0x80, 0xdd, 0xf9, 0xdc, 0x29, 0x6e, 0x6b, 0xe6, 0x0d, 0xe5, 0x1c, 0xb7, 0x25, 0xf1, 0x7b,
		0x3c, 0x7d, 0x61, 0xae, 0x60, 0xae, 0x60, 0xae, 0xb2, 0xcc, 0x96, 0xbb, 0x30, 0xf4, 0x39, 0x0b,
		0x28, 0xec, 0x55, 0xb3, 0xc2, 0xf6, 0x6a, 0x9a, 0x19, 0x7a, 0x51, 0xbc, 0xb4, 0xeb, 0xb8, 0x99,
		0xe2, 0xb6, 0xaa, 0x01, 0x43, 0x05, 0x43, 0x05, 0x43, 0x95, 0x65, 0xb6, 0x24, 0x5e, 0x20, 0xdb,
		0x2d, 0x02, 0x3b, 0x75, 0x5a, 0xa0, 0x89, 0x0f, 0x2c, 0xb8, 0xe7, 0x85, 0xa2, 0x6c, 0xb5, 0xc2,
		0xd1, 0x84, 0xda, 0x2c, 0x91, 0xbc, 0xf0, 0xbc, 0x27, 0x32, 0x2a, 0x6b, 0xcd, 0x4d, 0x62, 0x91,
		0x84, 0xed, 0xbd, 0x11, 0xcc, 0x1e, 0x73, 0xd1, 0x2b, 0xef, 0xde, 0x9b, 0xe6, 0xcd, 0x17, 0x6e,
		0x77, 0xf4, 0x82, 0x60, 0x08, 0xd8, 0x43, 0xe5, 0x87, 0xa0, 0xd3, 0x3a, 0xef, 0x9c, 0x77, 0x4f,
		0x5b, 0xe7, 0x27, 0x15, 0x1e, 0x8b, 0x67, 0xe5, 0x5c, 0xdd, 0xd3, 0x05, 0x57, 0x94, 0x2a, 0x46,
		0xaf, 0x1f, 0x64, 0xbe, 0xb0, 0x7f, 0x71, 0x51, 0x2f, 0xb4, 0x2d, 0xfe, 0x20, 0x2f, 0xe4, 0x64,
		0x77, 0x9f, 0x14, 0x8f, 0xd6, 0x2c, 0xed, 0xfa, 0x9e, 0xd3, 0x08, 0x7d, 0x2e, 0xf3, 0x63, 0x0a,
		0xa5, 0x4f, 0x79, 0x41, 0x9f, 0xac, 0xa2, 0x7b, 0xb6, 0xe8, 0xe3, 0xda, 0xf5, 0x05, 0xa2, 0x91,
		0xcb, 0xd1, 0xbf, 0x27, 0xbf, 0x1d, 0xcf, 0xf4, 0x70, 0x55, 0x61, 0xdf, 0x0c, 0xd1, 0x94, 0x7c,
		0x50, 0xbd, 0x10, 0x44, 0x37, 0x35, 0xdf, 0x0d, 0xba, 0x3e, 0x19, 0x3c, 0x46, 0x7e, 0xfe, 0xe6,
		0x89, 0x3a, 0xb3, 0x32, 0x2f, 0x5f, 0x4e, 0x53, 0x19, 0x8e, 0xf3, 0x6c, 0xb1, 0x54, 0x63, 0x26,
		0xa2, 0x61, 0xa7, 0x80, 0x95, 0x18, 0x5f, 0x7d, 0x20, 0xc1, 0xbf, 0x08, 0x46, 0x62, 0x93, 0x91,
		0x88, 0xf6, 0x26, 0xf8, 0xc7, 0x1c, 0x47, 0xf0, 0x38, 0xde, 0x21, 0x0f, 0xe8, 0xb7, 0xf3, 0x65,
		0xd1, 0x54, 0x31, 0x81, 0xaa, 0xb9, 0x2f, 0x02, 0x55, 0x04, 0x81, 0x4a, 0xd3, 0xe2, 0x2a, 0x47,
		0xa0, 0xca, 0xbb, 0xe8, 0x56, 0x17, 0x5f, 0xf1, 0x41, 0x5e, 0x59, 0x82, 0x45, 0x87, 0xb8, 0xd8,
		0x42, 0x24, 0x5b, 0x90, 0x94, 0x0b, 0x93, 0x7c, 0x81, 0x52, 0x2f, 0x54, 0x65, 0x0b, 0x56, 0xd9,
		0xc2, 0x55, 0xb1, 0x80, 0x89, 0x84, 0x9d, 0x82, 0xf3, 0xad, 0xe8, 0xc2, 0x4e, 0x1b, 0xca, 0x99,
		0x69, 0xf6, 0xdb, 0xc9, 0x9b, 0x2b, 0x03, 0x4d, 0xf1, 0x72, 0x27, 0x5f, 0xf6, 0x2a, 0x96, 0xbf,
		0x32, 0x33, 0xa0, 0xca, 0x1c, 0x28, 0x37, 0x0b, 0xca, 0xcd, 0x83, 0x4a, 0x33, 0x41, 0x63, 0x2e,
		0x88, 0xcc, 0x06, 0xb9, 0xf9, 0x58, 0xe2, 0xab, 0xf4, 0xf3, 0x69, 0xc1, 0x66, 0xa9, 0x27, 0x12,
		0x6d, 0x3c, 0x42, 0x99, 0x59, 0x51, 0x69, 0x5e, 0x94, 0x9b, 0x19, 0xd5, 0xe6, 0x46, 0x9b, 0xd9,
		0xd1, 0x66, 0x7e, 0x74, 0x98, 0x21, 0x5a, 0x73, 0x44, 0x6c, 0x96, 0x8a, 0x0b, 0x8a, 0x99, 0x14,
		0x32, 0x8b, 0x86, 0x8b, 0xfc, 0x12, 0xb0, 0x9c, 0x29, 0x68, 0xfb, 0x86, 0x49, 0xc9, 0x45, 0x50,
		0x38, 0x50, 0xbf, 0xb5, 0x83, 0xff, 0x3c, 0x7f, 0xfe, 0xb9, 0x61, 0x9d, 0xf7, 0x7e, 0x7e, 0x6e,
		0x5a, 0xe7, 0xbd, 0xe9, 0xc7, 0xe6, 0xe4, 0x7f, 0xd3, 0xcf, 0xad, 0xcf, 0x0d, 0xab, 0x33, 0xff,
		0x7c, 0xf2, 0xb9, 0x61, 0x9d, 0xf4, 0x8e, 0xbe, 0x7c, 0x79, 0x79, 0xf4, 0xa3, 0x3d, 0xca, 0x7e,
		0xe1, 0xbf, 0xe8, 0x27, 0x77, 0x4f, 0xc5, 0x4b, 0x7f, 0x7f, 0x7b, 0xfd, 0x0f, 0xde, 0xfc, 0xef,
		0xde, 0xfc, 0xb3, 0x6a, 0x1a, 0x29, 0x42, 0x03, 0x35, 0x73, 0x32, 0x96, 0xcf, 0x83, 0xfb, 0x49,
		0xf4, 0x40, 0x11, 0xea, 0x79, 0xda, 0x0d, 0x00, 0x10, 0x00, 0x10, 0x00, 0x10, 0x00, 0x10, 0xd9,
		0x6c, 0x4f, 0xbc, 0x40, 0x9e, 0x29, 0x44, 0x3e, 0x27, 0x0a, 0x9a, 0xa6, 0xc9, 0x4f, 0xdc, 0xf6,
		0xa3, 0x66, 0x75, 0xd6, 0xa8, 0xf3, 0x19, 0x35, 0xdb, 0xf4, 0xb5, 0x6e, 0x88, 0xf3, 0x1f, 0xb7,
		0xf6, 0xa3, 0x20, 0x17, 0x4f, 0xd3, 0xea, 0x7d, 0x3a, 0xf4, 0xec, 0x61, 0xef, 0x86, 0xbe, 0xdd,
		0xda, 0xa3, 0xb1, 0x7f, 0x66, 0x46, 0xab, 0x95, 0x45, 0xd6, 0x95, 0xd2, 0x35, 0x0b, 0x26, 0x1f,
		0x6e, 0x6d, 0x57, 0x49, 0x52, 0xa2, 0x17, 0x0d, 0x3b, 0xc7, 0x69, 0x4a, 0xc2, 0xfc, 0x53, 0xae,
		0x5c, 0x45, 0x75, 0xa3, 0x43, 0x91, 0x4b, 0x4e, 0x28, 0x0e, 0xd3, 0x8b, 0xc2, 0xd4, 0xc9, 0xe9,
		0x88, 0x2d, 0x21, 0xb6, 0xa4, 0x99, 0xd3, 0x54, 0xcb, 0x06, 0x93, 0x73, 0x17, 0x82, 0x2c, 0xd1,
		0xdf, 0x2d, 0xfe, 0xe6, 0x29, 0x61, 0x9b, 0xeb, 0x59, 0xa5, 0xd1, 0x3e, 0x59, 0xf3, 0x69, 0xd1,
		0x2f, 0x72, 0x83, 0x9e, 0xa5, 0x96, 0xf3, 0xce, 0xc3, 0x4a, 0x6d, 0xd3, 0x5b, 0xb0, 0xe9, 0xb0,
		0xe9, 0x07, 0x68, 0xd3, 0x91, 0x2f, 0x00, 0xb9, 0x5c, 0xb1, 0x99, 0x51, 0x6d, 0x6e, 0xb4, 0x99,
		0x1d, 0x6d, 0xe6, 0x47, 0x87, 0x19, 0x52, 0x23, 0x68, 0x20, 0x5f, 0x60, 0x1b, 0x60, 0x41, 0xbe,
		0x00, 0xf2, 0x05, 0x0e, 0xe9, 0xcd, 0x1f, 0x40, 0xbe, 0x40, 0x28, 0xbc, 0x7b, 0x05, 0xf1, 0x9f,
		0x85, 0x23, 0x9e, 0xb6, 0x0f, 0xc8, 0x03, 0xc8, 0x03, 0xc8, 0x03, 0xc8, 0x43, 0x08, 0x79, 0xe6,
		0x80, 0xc7, 0x52, 0x62, 0x62, 0x9e, 0xe0, 0x9e, 0x8e, 0x82, 0xb6, 0x5f, 0x07, 0xc9, 0x60, 0xfc,
		0x8a, 0x46, 0x48, 0x4a, 0xa3, 0x9a, 0x13, 0x48, 0x4a, 0x83, 0xcb, 0x81, 0xcb, 0x81, 0xcb, 0x51,
		0x34, 0xdb, 0x91, 0x94, 0xb6, 0xfa, 0x83, 0xa4, 0xb4, 0x9d, 0xba, 0x41, 0x52, 0x5a, 0xb6, 0xa1,
		0x47, 0x52, 0x5a, 0xb5, 0xc7, 0x1e, 0x49, 0x69, 0x15, 0x68, 0x09, 0x49, 0x69, 0x8b, 0xa4, 0xb4,
		0x1d, 0x4e, 0xfa, 0xd2, 0x37, 0x38, 0x14, 0x59, 0x0c, 0x43, 0x21, 0x14, 0x64, 0xa5, 0x4d, 0x5a,
		0x45, 0xcd, 0x83, 0xca, 0xd1, 0x1e, 0xe4, 0x30, 0x94, 0x41, 0x6b, 0xf6, 0x3c, 0x87, 0x61, 0xbc,
		0xd8, 0xad, 0x7b, 0x11, 0x26, 0x0a, 0x73, 0x19, 0x96, 0xfa, 0x50, 0xa3, 0xb6, 0x34, 0xa1, 0xb6,
		0x40, 0x6d, 0x81, 0xda, 0x52, 0x3d, 0xb5, 0x85, 0xda, 0x5c, 0xa5, 0x0d, 0x13, 0x57, 0x7c, 0xda,
		0xba, 0x98, 0x48, 0x2b, 0x40, 0x69, 0x32, 0x5f, 0xca, 0xcd, 0x98, 0x0e, 0x73, 0xa6, 0xcd, 0xac,
		0xe9, 0x32, 0x6f, 0xda, 0xcd, 0x9c, 0x76, 0x73, 0xa7, 0xd3, 0xec, 0x29, 0x16, 0x19, 0x14, 0xad,
		0x17, 0x55, 0xe6, 0x30, 0xed, 0x80, 0xd9, 0x36, 0x8f, 0xa4, 0x35, 0x08, 0x1d, 0x0d, 0x13, 0x39,
		0xad, 0x86, 0xb9, 0xd4, 0xa9, 0xe2, 0x99, 0xb5, 0x74, 0x3e, 0xd3, 0xe4, 0xe8, 0x01, 0xd5, 0xfd,
		0x69, 0x92, 0xff, 0x54, 0x1b, 0x6a, 0x9d, 0x06, 0x5b, 0xbb, 0xe1, 0xd6, 0x6d, 0xc0, 0x4b, 0x33,
		0xe4, 0xa5, 0x19, 0xf4, 0x32, 0x0c, 0xbb, 0x5a, 0x03, 0xaf, 0xd8, 0xd0, 0xa7, 0x2f, 0x4c, 0x59,
		0xb4, 0x71, 0xeb, 0x6a, 0x2b, 0x7e, 0x58, 0x60, 0x66, 0xf4, 0xda, 0x7c, 0x66, 0xe6, 0x04, 0x50,
		0x19, 0x9c, 0x62, 0xce, 0x90, 0x0b, 0xe9, 0xc5, 0x7c, 0xbc, 0x5c, 0xa6, 0x52, 0xf6, 0x90, 0xf9,
		0x1a, 0x7d, 0xf2, 0xe6, 0xfe, 0xf5, 0xb9, 0xe7, 0x66, 0xa3, 0x01, 0xe7, 0x0c, 0xe7, 0x0c, 0xe7,
		0x0c, 0xe7, 0x0c, 0xe7, 0xbc, 0x9c, 0x1a, 0xd4, 0xec, 0x6a, 0xf4, 0xcd, 0x5d, 0x0d, 0x5d, 0xa9,
		0xcd, 0x1d, 0x5a, 0xfd, 0xd1, 0x63, 0x3e, 0x6a, 0xba, 0x72, 0x8b, 0x4a, 0x72, 0x6a, 0x6b, 0xdd,
		0xce, 0x13, 0x50, 0x9a, 0x9a, 0xfb, 0xd5, 0x98, 0x8f, 0xa2, 0xd9, 0xbc, 0x3c, 0x9d, 0x4a, 0xec,
		0xe1, 0xe0, 0xa6, 0x52, 0xa7, 0x71, 0x7e, 0x72, 0x40, 0xb3, 0xe9, 0xd9, 0x7e, 0xf4, 0xd2, 0x03,
		0x99, 0x5b, 0x9b, 0x56, 0x91, 0xe0, 0x7c, 0x10, 0x49, 0x7d, 0xec, 0x6d, 0xde, 0xa1, 0x3e, 0xba,
		0x36, 0xc6, 0xa9, 0xe0, 0x6b, 0xe0, 0x6b, 0xe0, 0x6b, 0xe0, 0x6b, 0xe0, 0x6b, 0x10, 0x53, 0xab,
		0xe8, 0x7f, 0x2d, 0x87, 0xfb, 0xec, 0x51, 0xbb, 0x17, 0x9e, 0x75, 0xab, 0xcf, 0x17, 0x43, 0x38,
		0x85, 0x23, 0x86, 0x23, 0x86, 0x23, 0x86, 0x23, 0x86, 0x70, 0x4a, 0xf7, 0x03, 0xe1, 0x54, 0x49,
		0xb7, 0x9a, 0x36, 0x6d, 0xae, 0xf5, 0x0b, 0xe1, 0x74, 0x6f, 0xa7, 0x52, 0xbb, 0xdb, 0x68, 0x40,
		0x38, 0x35, 0xad, 0x17, 0x08, 0xa7, 0x9b, 0x88, 0x9b, 0x17, 0x0a, 0x4f, 0x6a, 0xe5, 0x6c, 0xb3,
		0x1e, 0x91, 0xe9, 0x02, 0xc2, 0x06, 0xc2, 0x06, 0xc2, 0x06, 0xc2, 0x56, 0x1a, 0x61, 0x3b, 0xd3,
		0xc8, 0xd7, 0x4e, 0xc0, 0xd7, 0xc0, 0xd7, 0xb2, 0x80, 0x6c, 0x24, 0xba, 0x80, 0xaf, 0x11, 0x4d,
		0xa5, 0xd6, 0x49, 0x07, 0x74, 0x0d, 0x74, 0xcd, 0x7c, 0xba, 0x36, 0xf4, 0x84, 0x4c, 0x98, 0x9f,
		0x96, 0x88, 0xd7, 0xc6, 0xda, 0x56, 0x3b, 0x06, 0x9d, 0x02, 0x9d, 0x02, 0x9d, 0x02, 0x9d, 0x02,
		0x9d, 0x5a, 0x2b, 0x63, 0xad, 0x33, 0x17, 0xe5, 0x5c, 0x43, 0x5f, 0xb3, 0x77, 0xb9, 0x77, 0x9c,
		0x4a, 0xd3, 0x99, 0x2b, 0xbf, 0x1d, 0xc3, 0x33, 0x8d, 0x7d, 0xaa, 0x3e, 0x29, 0x64, 0x6b, 0xc7,
		0xa6, 0x9f, 0x20, 0xb2, 0x15, 0xa4, 0xea, 0x1c, 0x3c, 0x1d, 0x67, 0xbd, 0x1c, 0xde, 0x08, 0x3e,
		0xdb, 0x23, 0x86, 0x5f, 0x8e, 0xf9, 0xec, 0xc2, 0x7c, 0xea, 0x59, 0x7c, 0xcc, 0x72, 0x2f, 0xad,
		0x37, 0xbd, 0x1f, 0xcd, 0x17, 0x9d, 0xd1, 0xc5, 0xd1, 0x8f, 0xd3, 0xd1, 0xea, 0x1f, 0x7f, 0x6e,
		0xfa, 0x5a, 0xf3, 0xc5, 0xe9, 0xe8, 0x62, 0xcb, 0xbf, 0x74, 0x47, 0x17, 0x3b, 0xb6, 0x71, 0x32,
		0x7a, 0xbe, 0xf6, 0xd5, 0xf1, 0xdf, 0x5b, 0xdb, 0x2e, 0xe8, 0x6c, 0xb9, 0xa0, 0xbd, 0xed, 0x82,
		0xf6, 0x96, 0x0b, 0xb6, 0xde, 0x52, 0x6b, 0xcb, 0x05, 0x27, 0xa3, 0x9f, 0x6b, 0xdf, 0x7f, 0xbe,
		0xf9, 0xab, 0xdd, 0xd1, 0xd1, 0xcf, 0x6d, 0xff, 0x76, 0x3a, 0xfa, 0x79, 0x71, 0x04, 0x67, 0x82,
		0xf9, 0x8c, 0xf9, 0x5c, 0x69, 0xd7, 0x6a, 0xba, 0x12, 0xa9, 0x98, 0x0b, 0xbf, 0xf5, 0x62, 0x79,
		0x29, 0xa5, 0xd0, 0xc3, 0x87, 0xdf, 0x79, 0xc1, 0x6b, 0x7f, 0x52, 0xd3, 0x24, 0xd6, 0x23, 0xf8,
		0xd7, 0xdf, 0xb1, 0x87, 0xa5, 0x1e, 0x9b, 0x67, 0x9d, 0x4e, 0xf7, 0xb4, 0xd3, 0x69, 0x9c, 0xb6,
		0x4f, 0x1b, 0xe7, 0x27, 0x27, 0xcd, 0x6e, 0x53, 0x47, 0xe4, 0xf1, 0xbd, 0x70, 0xb8, 0xe0, 0xce,
		0x1f, 0x8f, 0xf5, 0x8b, 0x5a, 0x90, 0xf8, 0x3e, 0xb4, 0xeb, 0xb5, 0x57, 0x34, 0x97, 0x90, 0x45,
		0x98, 0x48, 0x2e, 0x2c, 0xcf, 0xd1, 0xaf, 0x5e, 0x2f, 0xba, 0x86, 0x7e, 0x9d, 0x0d, 0x2d, 0x40,
		0xbf, 0x26, 0x9c, 0x1c, 0xd0, 0xaf, 0xa1, 0x5f, 0xef, 0xa4, 0xb9, 0x22, 0x1d, 0xa8, 0x50, 0x57,
		0x48, 0x07, 0x32, 0xcf, 0xa7, 0xad, 0x75, 0x8b, 0x74, 0x20, 0xd5, 0xe8, 0xf9, 0x00, 0xd3, 0x81,
		0x50, 0xf6, 0x06, 0x24, 0x5c, 0x17, 0xa5, 0x32, 0xaa, 0xfe, 0xb9, 0xa2, 0x43, 0xc4, 0xd6, 0xfa,
		0xd1, 0x79, 0xa8, 0xd8, 0x50, 0x88, 0xe8, 0x78, 0x71, 0xc2, 0xcd, 0xf1, 0xec, 0xc4, 0x08, 0x43,
		0x0e, 0xbf, 0x53, 0x30, 0xd2, 0xf5, 0xf4, 0x95, 0x59, 0x52, 0x30, 0xfb, 0x9b, 0x17, 0x68, 0x38,
		0xa7, 0x63, 0x43, 0x9f, 0x38, 0xb3, 0xa3, 0x2c, 0xb2, 0x8d, 0x33, 0x3b, 0x8c, 0x23, 0xd3, 0x38,
		0xb3, 0x63, 0xdb, 0x8b, 0x51, 0x7e, 0x66, 0x87, 0xe2, 0xa3, 0x8c, 0xd6, 0x16, 0xa5, 0xd2, 0x23,
		0x8d, 0x34, 0x99, 0x49, 0x6d, 0xe6, 0x52, 0xa7, 0xd9, 0xd4, 0x6e, 0x3e, 0x75, 0x9b, 0xd1, 0xd2,
		0xcc, 0x69, 0x69, 0x66, 0xb5, 0x0c, 0xf3, 0xaa, 0x87, 0x34, 0xa9, 0xd6, 0x28, 0x55, 0x9b, 0xdd,
		0xb4, 0xa3, 0xf9, 0x8e, 0x71, 0xcb, 0xe1, 0xb6, 0xe0, 0xb3, 0x31, 0xd2, 0xb4, 0x0e, 0x56, 0x77,
		0xad, 0x2f, 0xdd, 0x83, 0xa6, 0x79, 0xa9, 0xb1, 0xec, 0x58, 0x49, 0xfa, 0x8c, 0x36, 0x17, 0x51,
		0x86, 0xab, 0x28, 0xcd, 0x65, 0x94, 0xe5, 0x3a, 0x4a, 0x77, 0x21, 0xa5, 0xbb, 0x92, 0x32, 0x5d,
		0x8a, 0x1e, 0xd7, 0xa2, 0xc9, 0xc5, 0xa4, 0x2f, 0x52, 0x5b, 0x38, 0x6c, 0x6d, 0xb5, 0xea, 0x0a,
		0x8b, 0xad, 0x9a, 0x5e, 0x8d, 0x02, 0xb5, 0xe6, 0x30, 0xd9, 0xfc, 0x47, 0xaf, 0x35, 0xaa, 0x95,
		0x15, 0x36, 0x2b, 0xc9, 0xa7, 0xae, 0x75, 0x5f, 0x52, 0x15, 0xb4, 0xb4, 0xff, 0x12, 0x23, 0x20,
		0x9a, 0xad, 0xd5, 0xd3, 0x29, 0x57, 0x42, 0x78, 0xad, 0x6a, 0x53, 0x4e, 0xfb, 0xee, 0xfb, 0x4a,
		0x4d, 0xba, 0x67, 0xfb, 0xd9, 0xdb, 0xbe, 0xe4, 0xf6, 0x6a, 0x30, 0x0a, 0xf5, 0x49, 0xc0, 0x63,
		0x11, 0xd8, 0xd2, 0xcf, 0x5e, 0x57, 0x6f, 0x00, 0x34, 0x12, 0x34, 0x12, 0x34, 0x12, 0x34, 0x12,
		0x34, 0x52, 0xd3, 0x6a, 0xf5, 0x39, 0x73, 0x05, 0x77, 0xcb, 0xd8, 0x1f, 0x79, 0xaa, 0x77, 0x7f,
		0xe4, 0x2c, 0x9f, 0xc3, 0xb6, 0x3c, 0xf7, 0x62, 0x29, 0x4f, 0x63, 0xe5, 0x0f, 0xb3, 0xdf, 0x83,
		0xf1, 0xeb, 0xd9, 0xab, 0x29, 0xa6, 0x75, 0xb3, 0xcd, 0x32, 0xb1, 0xd5, 0xbb, 0xe9, 0x66, 0x99,
		0xdf, 0x94, 0xbe, 0xf9, 0x26, 0xbd, 0x19, 0xad, 0x9b, 0x70, 0x34, 0x42, 0x54, 0xa3, 0xc3, 0x44,
		0x9a, 0x32, 0xca, 0xd2, 0xfe, 0xca, 0xcc, 0x2c, 0x5b, 0xcf, 0x71, 0x52, 0x9a, 0x6c, 0xa6, 0x7e,
		0x82, 0xa8, 0xdc, 0x0f, 0x16, 0x4b, 0x26, 0xb9, 0xbe, 0xa4, 0x8a, 0x69, 0x77, 0x7b, 0x96, 0x53,
		0xd1, 0x42, 0x4e, 0x85, 0x31, 0x8c, 0x06, 0x39, 0x15, 0xc8, 0xa9, 0xf8, 0xdd, 0x0b, 0x43, 0x4e,
		0x85, 0x96, 0x3b, 0x40, 0x4e, 0x05, 0xc4, 0x30, 0x88, 0x61, 0x10, 0xc3, 0x20, 0x86, 0x21, 0xa7,
		0x42, 0x4d, 0x97, 0xc8, 0xa9, 0xd8, 0x3f, 0x9f, 0xba, 0xd6, 0x3d, 0x72, 0x2a, 0x90, 0x53, 0x51,
		0xd2, 0x94, 0x43, 0x4e, 0xc5, 0x1e, 0xf6, 0x86, 0x9c, 0x8a, 0xdd, 0xa7, 0x21, 0x72, 0x2a, 0x40,
		0x23, 0x41, 0x23, 0x41, 0x23, 0x41, 0x23, 0x0f, 0x95, 0x46, 0x22, 0xa7, 0x02, 0x39, 0x15, 0x6a,
		0x89, 0x2d, 0x72, 0x2a, 0x90, 0x53, 0x51, 0xc5, 0x95, 0x71, 0xe8, 0x39, 0x15, 0xd3, 0x50, 0x3e,
		0xea, 0x41, 0xa9, 0x9f, 0x71, 0x07, 0x51, 0x0f, 0x4a, 0x5b, 0x65, 0xa2, 0xe9, 0x93, 0x4a, 0x91,
		0xd8, 0x32, 0x98, 0x81, 0x98, 0xeb, 0x79, 0xdf, 0x5f, 0x6f, 0x97, 0xee, 0xfc, 0xeb, 0x75, 0x34,
		0xec, 0x7c, 0xbd, 0x9c, 0xde, 0xef, 0xd7, 0x4f, 0x42, 0x44, 0x7f, 0x8e, 0xef, 0xf4, 0x6b, 0xfa,
		0xed, 0x8f, 0xf3, 0x1b, 0x3d, 0xe0, 0x22, 0x56, 0x6a, 0xf3, 0x87, 0xb4, 0xe4, 0x0d, 0x69, 0x2b,
		0x55, 0xd5, 0x42, 0xa9, 0xaa, 0xca, 0xb0, 0x71, 0x94, 0xaa, 0x3a, 0x5c, 0x77, 0xaa, 0xbc, 0x54,
		0x15, 0xb3, 0x6d, 0x1e, 0x49, 0x6b, 0x10, 0x3a, 0x1a, 0x53, 0x2b, 0x97, 0x3b, 0x55, 0x9d, 0x20,
		0xb5, 0xc8, 0xdc, 0x71, 0x99, 0x1f, 0x73, 0x14, 0xf2, 0xaf, 0x9c, 0xc1, 0xd6, 0x6e, 0xb8, 0x75,
		0x1b, 0xf0, 0xd2, 0x0c, 0x79, 0x69, 0x06, 0xbd, 0x0c, 0xc3, 0xbe, 0x1f, 0x4c, 0x5d, 0x7f, 0x21,
		0xff, 0xbb, 0x30, 0xf4, 0x39, 0x0b, 0x74, 0x9e, 0x42, 0xdb, 0xc4, 0xee, 0x86, 0x75, 0x47, 0xec,
		0x0c, 0xb9, 0x90, 0x5e, 0x3c, 0xd1, 0xf1, 0xa6, 0x24, 0x76, 0xc8, 0x7c, 0x8d, 0x3e, 0x79, 0x73,
		0xff, 0xfa, 0xdc, 0x73, 0xb3, 0xd1, 0x80, 0x73, 0x86, 0x73, 0x86, 0x73, 0x86, 0x73, 0x86, 0x73,
		0x5e, 0x4e, 0x7d, 0x6d, 0x76, 0x35, 0xfa, 0xe6, 0x2e, 0x8e, 0xd9, 0xc9, 0xff, 0x60, 0x38, 0x66,
		0x47, 0x7d, 0xbf, 0x38, 0x66, 0x67, 0x6f, 0xa7, 0x52, 0xa7, 0x71, 0x8e, 0x73, 0x76, 0x8c, 0xeb,
		0xa5, 0x07, 0x32, 0xb7, 0x36, 0xad, 0xec, 0x44, 0x88, 0x31, 0x8d, 0x9a, 0xef, 0x58, 0xd4, 0x78,
		0x14, 0xc0, 0x6a, 0xcf, 0xa0, 0x54, 0xa0, 0x54, 0xa0, 0x54, 0xa0, 0x54, 0xa0, 0x54, 0x38, 0xb8,
		0x14, 0x8c, 0xca, 0x04, 0x18, 0xdc, 0x00, 0xa3, 0x02, 0xa3, 0xa2, 0x99, 0x4a, 0x38, 0xb8, 0x14,
		0x84, 0x6a, 0x2f, 0x08, 0x55, 0x24, 0x38, 0x1f, 0x44, 0x52, 0x1f, 0x8f, 0x9a, 0x77, 0xa8, 0x2f,
		0xfe, 0x35, 0x46, 0xa9, 0x60, 0x6b, 0x60, 0x6b, 0x60, 0x6b, 0x60, 0x6b, 0x60, 0x6b, 0xc8, 0x4e,
		0xa9, 0xa2, 0xff, 0xb5, 0x1c, 0xee, 0xb3, 0x47, 0xed, 0x5e, 0x78, 0xd6, 0xad, 0x3e, 0x5f, 0x8c,
		0x4c, 0x14, 0x38, 0x62, 0x38, 0x62, 0x38, 0x62, 0x38, 0x62, 0x64, 0xa2, 0xd0, 0xfd, 0x40, 0x37,
		0x55, 0xd2, 0x2d, 0x74, 0x53, 0xb5, 0x53, 0xe9, 0x00, 0x75, 0xd3, 0x76, 0xb7, 0xd1, 0x80, 0x70,
		0x6a, 0x5a, 0x2f, 0x10, 0x4e, 0x37, 0x11, 0x37, 0xdd, 0x19, 0x28, 0xba, 0x32, 0x4f, 0xb0, 0x75,
		0x00, 0x84, 0x0d, 0x84, 0x0d, 0x84, 0x0d, 0x84, 0x6d, 0x3b, 0x61, 0x43, 0x9e, 0x0b, 0xf8, 0x5a,
		0x65, 0x41, 0x36, 0x76, 0x0e, 0x80, 0xaf, 0x11, 0x4d, 0x25, 0xed, 0xd5, 0xad, 0x41, 0xd7, 0x40,
		0xd7, 0x54, 0x4c, 0xab, 0xa1, 0x27, 0x64, 0xc2, 0x7c, 0x6b, 0x56, 0x7a, 0x4c, 0x1f, 0x6b, 0x5b,
		0xed, 0x18, 0x74, 0x0a, 0x74, 0x0a, 0x74, 0x0a, 0x74, 0x0a, 0x74, 0x6a, 0xb6, 0xda, 0xbc, 0x48,
		0x93, 0x6d, 0x5c, 0xb6, 0x8f, 0xcd, 0x73, 0x0d, 0x7d, 0xcd, 0xde, 0xe5, 0xde, 0x71, 0xaa, 0xc5,
		0xc8, 0x0d, 0x3b, 0x1a, 0xc7, 0x6e, 0x6d, 0x0c, 0xcf, 0xf4, 0x16, 0xff, 0x96, 0x5c, 0x04, 0xda,
		0x0f, 0x92, 0xaa, 0xff, 0xe7, 0xf9, 0xf3, 0xcf, 0x0d, 0xeb, 0xbc, 0xf7, 0xf3, 0x73, 0xd3, 0x3a,
		0xef, 0x4d, 0x3f, 0x36, 0x27, 0xff, 0x9b, 0x7e, 0x6e, 0x7d, 0x6e, 0x58, 0x9d, 0xf9, 0xe7, 0x93,
		0xcf, 0x0d, 0xeb, 0xa4, 0x77, 0xf4, 0xe5, 0xcb, 0xcb, 0xa3, 0x1f, 0xed, 0x51, 0xf6, 0x0b, 0xff,
		0xa5, 0xaf, 0xf8, 0x7e, 0x4f, 0xe7, 0xe0, 0xbd, 0xbf, 0xbd, 0xfe, 0x07, 0x23, 0x68, 0x14, 0xcd,
		0xd0, 0xcc, 0xf0, 0xcb, 0x31, 0x9f, 0x5d, 0x98, 0x4f, 0x3d, 0x8b, 0x8f, 0x59, 0xee, 0xa5, 0xf5,
		0xa6, 0xf7, 0xa3, 0xf9, 0xa2, 0x33, 0xba, 0x38, 0xfa, 0x71, 0x3a, 0x5a, 0xfd, 0xe3, 0xcf, 0x4d,
		0x5f, 0x6b, 0xbe, 0x38, 0x1d, 0x5d, 0x6c, 0xf9, 0x97, 0xee, 0xe8, 0x62, 0xc7, 0x36, 0x4e, 0x46,
		0xcf, 0xd7, 0xbe, 0x3a, 0xfe, 0x7b, 0x6b, 0xdb, 0x05, 0x9d, 0x2d, 0x17, 0xb4, 0xb7, 0x5d, 0xd0,
		0xde, 0x72, 0xc1, 0xd6, 0x5b, 0x6a, 0x6d, 0xb9, 0xe0, 0x64, 0xf4, 0x73, 0xed, 0xfb, 0xcf, 0x37,
		0x7f, 0xb5, 0x3b, 0x3a, 0xfa, 0xb9, 0xed, 0xdf, 0x4e, 0x47, 0x3f, 0x2f, 0x8e, 0xe0, 0x4c, 0x30,
		0x9f, 0x31, 0x9f, 0x2b, 0xed, 0x5a, 0x4d, 0x57, 0x22, 0x15, 0x73, 0x61, 0xad, 0xc7, 0xdd, 0xe8,
		0x3f, 0xe6, 0xa6, 0x12, 0xc7, 0xdb, 0xe8, 0x3d, 0xd6, 0xc6, 0x6c, 0xed, 0x5a, 0x84, 0x89, 0xe4,
		0xc2, 0xf2, 0x1c, 0xfd, 0xea, 0xf5, 0xa2, 0x6b, 0xe8, 0xd7, 0xd9, 0xd0, 0x02, 0xf4, 0x6b, 0xc2,
		0xc9, 0x01, 0xfd, 0x1a, 0xfa, 0xf5, 0x4e, 0x9a, 0x2b, 0xd2, 0x81, 0x0a, 0x75, 0x85, 0x74, 0x20,
		0xf3, 0x7c, 0xda, 0x5a, 0xb7, 0x48, 0x07, 0x52, 0x8d, 0x9e, 0x51, 0xf6, 0x66, 0xaf, 0x27, 0x13,
		0x48, 0x78, 0xb9, 0x94, 0x0a, 0xe7, 0x33, 0x6e, 0xe8, 0xa7, 0xcc, 0xf3, 0x19, 0x15, 0x1e, 0xf7,
		0x69, 0xc6, 0x49, 0x87, 0xfa, 0x98, 0xb8, 0x76, 0x06, 0xae, 0xd8, 0xb5, 0x28, 0x67, 0xdc, 0x38,
		0x01, 0xd1, 0x04, 0x46, 0x8d, 0x13, 0x10, 0x2b, 0xe3, 0xb0, 0x94, 0x33, 0xe5, 0x74, 0xb5, 0xf8,
		0x9c, 0xb9, 0x82, 0xbb, 0x2a, 0xd7, 0xcb, 0x3c, 0xa6, 0x7d, 0xaa, 0xb0, 0x8f, 0xf9, 0xf9, 0xff,
		0x2f, 0x5f, 0x4e, 0x1d, 0xe1, 0xf1, 0xba, 0x69, 0x36, 0xc5, 0x35, 0x3e, 0xab, 0xf0, 0x04, 0x1d,
		0xdb, 0x24, 0x1d, 0x8e, 0x4f, 0x6d, 0x78, 0x47, 0x7d, 0x38, 0xa7, 0x94, 0xf0, 0x8d, 0xda, 0x70,
		0x0d, 0xf5, 0x4c, 0x52, 0x8c, 0xc9, 0xcb, 0xc4, 0xe2, 0x75, 0x25, 0xe7, 0x78, 0xe7, 0x3e, 0x10,
		0x9d, 0xd6, 0xf2, 0xd1, 0xd9, 0x27, 0x9a, 0x96, 0x88, 0xe6, 0xa5, 0xaa, 0xf9, 0xa8, 0x7d, 0x1e,
		0xd2, 0x8c, 0x76, 0xf1, 0xb1, 0x29, 0xd6, 0x42, 0xc1, 0x51, 0x9d, 0xfb, 0xa9, 0xc2, 0x44, 0x80,
		0xd6, 0x11, 0xd1, 0x3b, 0x1e, 0x2d, 0x8e, 0x86, 0xd6, 0xb1, 0x14, 0x1d, 0xda, 0xcb, 0xe4, 0x7e,
		0xfc, 0xb8, 0xdc, 0x21, 0x89, 0x81, 0xd0, 0xac, 0xf4, 0x14, 0x4e, 0x1f, 0x8f, 0x69, 0x8c, 0x7b,
		0xb1, 0xb4, 0x6e, 0x57, 0xfe, 0x30, 0xfb, 0xfd, 0xe9, 0xda, 0x5e, 0xff, 0xdb, 0xe4, 0x4f, 0xd1,
		0xc5, 0x64, 0x9d, 0x4f, 0x3f, 0x2e, 0x56, 0xfb, 0x93, 0xdf, 0x89, 0x7c, 0x4d, 0xfd, 0x8a, 0xc7,
		0xb6, 0xf0, 0xa2, 0x99, 0xfd, 0xab, 0x5f, 0x3a, 0x8e, 0x37, 0xfe, 0xcc, 0xfc, 0xda, 0xf5, 0x4d,
		0x6d, 0xdc, 0x57, 0xcd, 0x65, 0x03, 0xcf, 0x7f, 0xac, 0x4d, 0x8d, 0x57, 0x22, 0x26, 0xa6, 0xb2,
		0xe6, 0x86, 0xe2, 0x4b, 0xb0, 0x78, 0x12, 0xaa, 0xbb, 0x99, 0x53, 0x06, 0xa2, 0xe6, 0xa8, 0xf5,
		0x0d, 0x15, 0x7a, 0x86, 0x32, 0xfd, 0x42, 0x95, 0x5e, 0xa1, 0x5c, 0x9f, 0x50, 0xae, 0x47, 0xa8,
		0xd4, 0x1f, 0xaa, 0x05, 0x6e, 0xae, 0x3c, 0x5a, 0x26, 0x55, 0x9f, 0x20, 0x0d, 0xf2, 0x19, 0x95,
		0xea, 0xaa, 0xe3, 0xd6, 0x89, 0xc7, 0x7a, 0xc5, 0xc0, 0xbd, 0x0e, 0x6c, 0x3f, 0x8c, 0xbd, 0xe0,
		0x7e, 0x6c, 0xd0, 0x24, 0xf3, 0x02, 0x2e, 0xc6, 0xc6, 0xac, 0xf6, 0xe9, 0xc3, 0x87, 0x9b, 0xda,
		0x04, 0xc5, 0xc7, 0xb5, 0x3e, 0x0b, 0x1c, 0x9f, 0x3b, 0xb5, 0xbb, 0xc7, 0x9a, 0xec, 0x7b, 0xf1,
		0x97, 0xe0, 0xfa, 0xa6, 0x96, 0xda, 0x3a, 0xea, 0xfb, 0xa3, 0x35, 0x79, 0xca, 0x4c, 0x9f, 0x4a,
		0x13, 0xa8, 0xdc, 0x14, 0xaa, 0x36, 0x89, 0xda, 0x4c, 0xa3, 0x36, 0x13, 0xa9, 0xc3, 0x54, 0x2a,
		0x52, 0xbe, 0xaa, 0x66, 0xca, 0x4b, 0x66, 0x54, 0xbd, 0xa2, 0xb0, 0x9b, 0x96, 0x1f, 0xeb, 0xe4,
		0xc5, 0x04, 0x8b, 0x2f, 0xbb, 0xfe, 0x52, 0x6c, 0x7d, 0xe4, 0x1f, 0xeb, 0x7c, 0x57, 0xe6, 0x04,
		0x1a, 0x54, 0xb3, 0x42, 0xc7, 0x6c, 0xc8, 0x37, 0x20, 0xd9, 0x5f, 0x67, 0x8e, 0x57, 0x59, 0xb7,
		0xe7, 0x5e, 0x3a, 0xdf, 0x2b, 0x5c, 0x1c, 0x84, 0x3a, 0x6d, 0x27, 0xe7, 0x60, 0x16, 0x83, 0x20,
		0x85, 0xa1, 0x06, 0x05, 0xa4, 0x20, 0x83, 0x0e, 0x54, 0x10, 0x81, 0x1c, 0x0a, 0x90, 0xbb, 0x7c,
		0x4a, 0xd7, 0xae, 0xd7, 0xf8, 0x14, 0x65, 0x35, 0x75, 0xa7, 0x6f, 0x47, 0x96, 0xed, 0x7b, 0xd3,
		0x87, 0x2f, 0x38, 0xd0, 0xf3, 0x99, 0xb7, 0xdc, 0x68, 0xc1, 0x91, 0x59, 0xaa, 0xf6, 0xea, 0x32,
		0x3f, 0x2e, 0xca, 0x39, 0x88, 0xd2, 0x48, 0xc8, 0x38, 0x05, 0x25, 0x87, 0x20, 0xe7, 0x0c, 0xd4,
		0x1c, 0x41, 0x19, 0x27, 0x50, 0xc6, 0x01, 0x54, 0x60, 0xfe, 0x72, 0xa3, 0x02, 0x64, 0x69, 0x15,
		0x0a, 0x4e, 0x6a, 0x22, 0x3a, 0x89, 0xa9, 0x00, 0x70, 0x2c, 0xe0, 0x2c, 0x79, 0xc0, 0xee, 0x7c,
		0xee, 0xd0, 0x19, 0xd1, 0x79, 0x83, 0x74, 0x06, 0x94, 0xe0, 0xa4, 0x41, 0xd8, 0x4f, 0xd8, 0x4f,
		0xd8, 0x4f, 0xd8, 0x4f, 0x7a, 0xfb, 0x39, 0x90, 0x09, 0x9d, 0xed, 0x1c, 0x37, 0x06, 0x43, 0x07,
		0x43, 0x07, 0x43, 0x57, 0x21, 0x43, 0x47, 0x76, 0x92, 0x18, 0xe1, 0x49, 0x61, 0xc4, 0x5b, 0x49,
		0x09, 0xc3, 0x8b, 0x2a, 0xb6, 0x82, 0x2a, 0xda, 0x44, 0x91, 0xee, 0xbf, 0xeb, 0x12, 0xd7, 0xec,
		0x52, 0xb9, 0xbd, 0x8e, 0x30, 0x99, 0x53, 0xc9, 0x5e, 0xcb, 0xf9, 0x58, 0xb5, 0x15, 0x8d, 0x55,
		0xc3, 0xa0, 0xa1, 0xaa, 0x48, 0xf4, 0xa9, 0x87, 0x78, 0x46, 0x86, 0x76, 0xd4, 0xc5, 0x33, 0x66,
		0x12, 0x7f, 0x85, 0x83, 0x19, 0x01, 0xf7, 0xee, 0xfb, 0x77, 0xa1, 0x88, 0x8b, 0xc7, 0x33, 0x16,
		0x4d, 0x21, 0xa4, 0x81, 0x90, 0x46, 0x29, 0x80, 0xd4, 0xb0, 0x90, 0xc6, 0x7c, 0xc5, 0xd0, 0xd1,
		0xc9, 0xb4, 0x45, 0x1a, 0x4e, 0xd9, 0x04, 0xa7, 0x04, 0xa7, 0x3c, 0x44, 0x4e, 0x49, 0x95, 0x83,
		0x59, 0x34, 0x59, 0x60, 0xeb, 0xe4, 0x2d, 0x94, 0x3c, 0xa0, 0x68, 0xb9, 0x93, 0x2f, 0x7b, 0x15,
		0xcb, 0x5f, 0x99, 0x19, 0x50, 0x65, 0x0e, 0x94, 0x9b, 0x05, 0xe5, 0xe6, 0x41, 0xa5, 0x99, 0x20,
		0x66, 0x5e, 0x55, 0x4d, 0xe1, 0xf6, 0x14, 0x26, 0x70, 0x93, 0x67, 0xed, 0xaa, 0x12, 0x6f, 0x90,
		0x1e, 0xad, 0xd1, 0xdc, 0x68, 0x33, 0x3b, 0xda, 0xcc, 0x8f, 0x0e, 0x33, 0x44, 0x6b, 0x8e, 0x14,
		0x28, 0x80, 0x35, 0xa5, 0x15, 0x2b, 0x74, 0x9d, 0x68, 0xa3, 0xf2, 0xe8, 0x05, 0xe5, 0x47, 0x2c,
		0x18, 0x7f, 0x8e, 0x49, 0x4f, 0xc5, 0x4b, 0xd7, 0x71, 0x18, 0x80, 0xf9, 0x6f, 0xbe, 0xaa, 0xbb,
		0x2e, 0x08, 0xe1, 0xb3, 0xef, 0x05, 0xdf, 0x2c, 0x9f, 0x3d, 0x72, 0xa1, 0xec, 0x8c, 0xc9, 0x45,
		0x41, 0x9d, 0xf5, 0xbe, 0x00, 0x85, 0x00, 0x85, 0x00, 0x85, 0x00, 0x85, 0xc8, 0x66, 0x7b, 0xd4,
		0x7f, 0x8c, 0x01, 0x85, 0xb6, 0x3a, 0xe4, 0xe5, 0x63, 0x62, 0x56, 0x4f, 0x9f, 0x69, 0x8d, 0x8e,
		0xfe, 0xeb, 0xe8, 0x7f, 0x80, 0x60, 0x2a, 0xf0, 0xc2, 0x50, 0x96, 0x68, 0x17, 0x6b, 0x6a, 0x5c,
		0x59, 0xa2, 0x34, 0x66, 0x9b, 0x7e, 0x2a, 0x14, 0xb3, 0xa6, 0x1f, 0x1e, 0x82, 0xa1, 0xa1, 0x14,
		0xcf, 0xe8, 0x45, 0x33, 0x62, 0x84, 0x08, 0xed, 0x1d, 0xda, 0xbb, 0x6e, 0xa4, 0x57, 0x2d, 0x23,
		0x4c, 0x8e, 0xe8, 0x14, 0x96, 0x5f, 0x55, 0x51, 0x6e, 0x75, 0xbd, 0xbc, 0xaa, 0x17, 0xed, 0x93,
		0x35, 0x9f, 0xd6, 0x4e, 0x27, 0x37, 0xe8, 0xd3, 0x66, 0x2b, 0x1e, 0x4f, 0x6d, 0xc1, 0xa6, 0xc3,
		0xa6, 0x1f, 0xa0, 0x4d, 0x47, 0x3c, 0x15, 0x22, 0xa2, 0x62, 0x33, 0xa3, 0xda, 0xdc, 0x68, 0x33,
		0x3b, 0xda, 0xcc, 0x8f, 0x0e, 0x33, 0x44, 0xaf, 0x18, 0xd4, 0x10, 0x4f, 0xfd, 0x05, 0x60, 0x41,
		0x3c, 0x15, 0xf1, 0xd4, 0x43, 0x7a, 0xf3, 0x88, 0xa7, 0xd2, 0x32, 0x64, 0xc4, 0x53, 0x01, 0x85,
		0x00, 0x85, 0x00, 0x85, 0x10, 0x4f, 0x2d, 0x0b, 0x0a, 0x21, 0x9e, 0x6a, 0xc4, 0x0b, 0x3b, 0x00,
		0xe0, 0x11, 0x0a, 0xef, 0x5e, 0x45, 0x69, 0x80, 0xd4, 0xed, 0x4d, 0xdb, 0x07, 0xc0, 0x00, 0xc0,
		0x00, 0xc0, 0x00, 0xc0, 0x20, 0x9b, 0xed, 0xf3, 0x4c, 0x08, 0x4b, 0x89, 0x81, 0x79, 0x82, 0x31,
		0x3a, 0x0a, 0xda, 0x7e, 0x1d, 0x24, 0x83, 0xf1, 0x0b, 0x1a, 0x21, 0x65, 0x67, 0x97, 0xf5, 0xb4,
		0x0f, 0x29, 0x3b, 0x84, 0xc7, 0x49, 0xe3, 0x2c, 0xb1, 0x59, 0x43, 0x38, 0x4b, 0xac, 0x72, 0x67,
		0x89, 0x19, 0x73, 0xa8, 0xc1, 0xfa, 0x12, 0xd5, 0x7b, 0xaa, 0xc1, 0x5f, 0xf3, 0x5e, 0x51, 0x06,
		0xa8, 0x5a, 0xf3, 0xa1, 0xca, 0x95, 0x80, 0x22, 0x11, 0x3e, 0x3c, 0x5a, 0xac, 0xc0, 0x51, 0x51,
		0x0b, 0x89, 0x26, 0x6d, 0x0a, 0x95, 0x80, 0x50, 0x09, 0xa8, 0x14, 0x72, 0x63, 0x58, 0x25, 0x20,
		0xa2, 0x32, 0x21, 0xb4, 0xe5, 0x41, 0x50, 0x05, 0xa8, 0x44, 0x2d, 0x03, 0x55, 0x80, 0x6a, 0xfb,
		0x53, 0x05, 0x68, 0x10, 0x3a, 0x0a, 0x52, 0x56, 0x27, 0xad, 0x92, 0x1d, 0x29, 0x9b, 0x16, 0xdf,
		0xbf, 0xba, 0xbe, 0xbd, 0xfc, 0xe3, 0xed, 0x6b, 0xec, 0x6f, 0xa8, 0x9e, 0x70, 0x8a, 0x5c, 0xd8,
		0x32, 0x84, 0xd1, 0x43, 0xd9, 0xdf, 0xc0, 0x83, 0x64, 0xc0, 0xa7, 0x67, 0x45, 0xab, 0xd8, 0xe3,
		0x40, 0x28, 0x76, 0x12, 0x8b, 0x9c, 0xa6, 0x8b, 0x5e, 0xe6, 0x28, 0x23, 0x29, 0x33, 0x24, 0xd9,
		0x66, 0x58, 0xce, 0xf9, 0x0f, 0x34, 0x1b, 0x50, 0x48, 0x37, 0x9e, 0x90, 0x23, 0xf5, 0x16, 0x90,
		0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90,
		0xfa, 0xc1, 0x22, 0x75, 0x82, 0xec, 0x02, 0x84, 0x12, 0xc9, 0x87, 0xa5, 0x5e, 0x88, 0xc1, 0xec,
		0x1a, 0x49, 0xbe, 0x19, 0x77, 0x77, 0x29, 0xa2, 0x2a, 0x07, 0x2e, 0x8b, 0xf1, 0x31, 0x12, 0x1e,
		0x46, 0x16, 0xb0, 0x6c, 0x21, 0x60, 0xa9, 0x0e, 0xea, 0x20, 0x60, 0x49, 0xc6, 0x97, 0xea, 0x76,
		0x98, 0x8c, 0x2d, 0x45, 0x4c, 0x19, 0xb2, 0x9c, 0xb5, 0x88, 0xa0, 0x25, 0xa4, 0x10, 0x48, 0x21,
		0xe5, 0x4b, 0x21, 0x5e, 0x60, 0x39, 0x5e, 0x6c, 0x33, 0xe1, 0x70, 0xc7, 0x8a, 0xbe, 0xc9, 0x58,
		0x41, 0x15, 0xb5, 0xb5, 0x2e, 0x20, 0x65, 0x40, 0xca, 0x80, 0x94, 0x71, 0x40, 0x52, 0xc6, 0xcc,
		0xed, 0x77, 0x3b, 0x0a, 0x84, 0x0c, 0xc2, 0x2d, 0x9c, 0xc4, 0xc7, 0xef, 0xce, 0x7f, 0x14, 0x6c,
		0x63, 0x51, 0x71, 0x1c, 0xaf, 0x22, 0xbb, 0xba, 0xd6, 0xbc, 0xa2, 0x23, 0x5f, 0xd3, 0xf6, 0x15,
		0x1e, 0xfd, 0x4a, 0xbc, 0xe2, 0x9e, 0x0e, 0x29, 0x7b, 0x30, 0x7e, 0x48, 0xd5, 0xec, 0x50, 0x28,
		0x6d, 0x94, 0x2b, 0xba, 0xb9, 0xaa, 0xb7, 0x4f, 0x65, 0x7b, 0x03, 0x8b, 0x0b, 0x11, 0x0a, 0x75,
		0xd8, 0x73, 0xa9, 0x79, 0xe0, 0x4e, 0xe0, 0x4e, 0xe0, 0x4e, 0xe0, 0x4e, 0xe0, 0x4e, 0xe0, 0x4e,
		0xe0, 0x4e, 0xe0, 0x4e, 0xe0, 0xce, 0x43, 0xc6, 0x9d, 0x6e, 0x28, 0xbe, 0x4f, 0x45, 0xc9, 0xd0,
		0x96, 0x5c, 0x11, 0xfa, 0x5c, 0xeb, 0x04, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18,
		0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x54, 0x69, 0xec, 0x7d, 0xa5, 0x0b,
		0xe0, 0x4f, 0xe0, 0x4f, 0xe0, 0x4f, 0xe0, 0x4f, 0xe0, 0x4f, 0xe0, 0x4f, 0xe0, 0x4f, 0xe0, 0x4f,
		0xe0, 0xcf, 0x43, 0xc6, 0x9f, 0x0a, 0x95, 0x4f, 0xe8, 0x9d, 0xc0, 0x9b, 0xc0, 0x9b, 0xc0, 0x9b,
		0xc0, 0x9b, 0xc0, 0x9b, 0xc0, 0x9b, 0xc0, 0x9b, 0xc0, 0x9b, 0xc0, 0x9b, 0xea, 0x54, 0x4e, 0x68,
		0x9b, 0xc0, 0x9a, 0xc0, 0x9a, 0xc0, 0x9a, 0xc0, 0x9a, 0xc0, 0x9a, 0xc0, 0x9a, 0xc0, 0x9a, 0xc0,
		0x9a, 0x87, 0x8d, 0x35, 0xc3, 0x44, 0x2a, 0xdf, 0xd8, 0xbe, 0xa1, 0x0f, 0x20, 0x50, 0x20, 0x50,
		0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0xd0, 0x83, 0x46,
		0xa0, 0x2a, 0xb7, 0xb6, 0xaf, 0xb4, 0x0f, 0xe4, 0x09, 0xe4, 0x09, 0xe4, 0x09, 0xe4, 0x09, 0xe4,
		0x09, 0xe4, 0x09, 0xe4, 0x09, 0xe4, 0x09, 0xe4, 0x79, 0xd0, 0xc8, 0x53, 0xfd, 0xe6, 0xf6, 0x8d,
		0xbd, 0x00, 0x85, 0x02, 0x85, 0x02, 0x85, 0x02, 0x85, 0x02, 0x85, 0x02, 0x85, 0x02, 0x85, 0x02,
		0x85, 0x02, 0x85, 0x02, 0x85, 0x2a, 0x8e, 0xc0, 0x63, 0x7f, 0x3b, 0x10, 0x28, 0x10, 0x28, 0x10,
		0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0xe8, 0x02, 0x81, 0xaa,
		0x54, 0x3f, 0xa1, 0x79, 0x02, 0x71, 0x02, 0x71, 0x02, 0x71, 0x02, 0x71, 0x02, 0x71, 0x02, 0x71,
		0x02, 0x71, 0x02, 0x71, 0x02, 0x71, 0x4a, 0x85, 0x4a, 0x27, 0xf4, 0x4d, 0xa0, 0x4d, 0xa0, 0x4d,
		0xa0, 0x4d, 0xa0, 0x4d, 0xa0, 0x4d, 0xa0, 0x4d, 0xa0, 0x4d, 0xa0, 0x4d, 0x83, 0xd1, 0x66, 0xa9,
		0xc7, 0xc7, 0x5f, 0x06, 0x41, 0x28, 0xd9, 0x78, 0x0a, 0xd0, 0x9c, 0x22, 0x1f, 0xdb, 0x7d, 0x3e,
		0x60, 0x11, 0x93, 0xfd, 0xb1, 0xc7, 0x3a, 0x0e, 0x23, 0x1e, 0xd8, 0x13, 0x44, 0x68, 0x79, 0x63,
		0xdf, 0xe5, 0x32, 0x9b, 0xc7, 0xc7, 0x9b, 0x3e, 0x1e, 0xc7, 0xc9, 0xdd, 0xd2, 0xdf, 0x97, 0x7f,
		0x3b, 0xf6, 0xa2, 0x61, 0xe7, 0x38, 0x96, 0x4c, 0xf2, 0xe3, 0x99, 0x0f, 0xa4, 0x40, 0xbf, 0xf5,
		0x58, 0x8a, 0xc4, 0x96, 0xc1, 0xcc, 0xbb, 0x5e, 0xcf, 0xbb, 0xfb, 0x7a, 0xbb, 0xd4, 0xf7, 0xd7,
		0xeb, 0x68, 0xd8, 0xf9, 0xfa, 0x6a, 0xde, 0xeb, 0xb3, 0x72, 0x46, 0xba, 0xc0, 0x28, 0xd7, 0x9d,
		0xbe, 0x1d, 0x59, 0xb6, 0xef, 0x4d, 0xb1, 0x57, 0xb1, 0x21, 0x4e, 0xa1, 0xc8, 0x72, 0xa3, 0x05,
		0x67, 0xe0, 0x15, 0x77, 0x59, 0xe2, 0x4f, 0x70, 0xa1, 0xcb, 0xfc, 0x98, 0x17, 0x6d, 0x8f, 0xc6,
		0x48, 0x93, 0xf1, 0x18, 0x4a, 0xfe, 0x42, 0xce, 0x5b, 0xa8, 0xf9, 0x8a, 0x32, 0x9e, 0xa2, 0x8c,
		0x9f, 0xa8, 0xe0, 0x25, 0xe5, 0x5a, 0x74, 0x32, 0xfe, 0x91, 0xce, 0xb6, 0xbb, 0x30, 0xf4, 0x39,
		0x0b, 0x28, 0xe6, 0xdb, 0x6c, 0x71, 0x36, 0x9b, 0x06, 0x1a, 0x52, 0x1e, 0xb0, 0x3b, 0x9f, 0x3b,
		0x74, 0x46, 0x74, 0xde, 0x20, 0x9d, 0x01, 0x1d, 0xaf, 0x0b, 0xd8, 0x4f, 0xd8, 0x4f, 0xd8, 0x4f,
		0xd8, 0xcf, 0xca, 0xd9, 0xcf, 0x81, 0x4c, 0xe8, 0x6c, 0xe7, 0xb8, 0x31, 0x18, 0x3a, 0x18, 0x3a,
		0x18, 0xba, 0x0a, 0x19, 0xba, 0xc4, 0x0b, 0x64, 0xb3, 0x4b, 0x68, 0xe7, 0xba, 0x04, 0x4d, 0xd1,
		0xaa, 0xd1, 0x84, 0xb2, 0xbe, 0x0a, 0xf5, 0x59, 0x91, 0x44, 0x99, 0x4a, 0x93, 0xdd, 0x33, 0xe2,
		0x86, 0x15, 0x0a, 0x90, 0x84, 0xf2, 0xb2, 0x12, 0x59, 0x79, 0x3e, 0x56, 0x6d, 0x45, 0x63, 0xd5,
		0x30, 0x68, 0xa8, 0x2a, 0xa2, 0xc5, 0xf6, 0xca, 0x82, 0x55, 0xcf, 0x34, 0x4e, 0x70, 0x2a, 0xcd,
		0x57, 0xb5, 0xd6, 0x9b, 0xcf, 0xbf, 0x66, 0x7f, 0x95, 0x39, 0x5e, 0x63, 0x3d, 0x09, 0x82, 0x64,
		0x70, 0xc7, 0x45, 0x01, 0x39, 0x60, 0xe1, 0x35, 0x17, 0x6d, 0xe5, 0x1c, 0xd0, 0x39, 0x2b, 0xc8,
		0x79, 0x79, 0x51, 0x04, 0x4b, 0x81, 0x5c, 0x9f, 0x20, 0x56, 0xb7, 0x00, 0x84, 0xa0, 0x42, 0xaa,
		0xe4, 0x08, 0x95, 0x1c, 0x99, 0xae, 0x21, 0x52, 0xb7, 0x6e, 0x88, 0x01, 0xba, 0xf2, 0x44, 0xb1,
		0xc9, 0x62, 0xcf, 0x67, 0x2c, 0x11, 0x9b, 0x9c, 0xb5, 0x47, 0x43, 0x28, 0x9b, 0xfb, 0x4e, 0x28,
		0x5d, 0x10, 0x4a, 0x15, 0x84, 0xd2, 0x35, 0x9d, 0x50, 0x16, 0x5d, 0xd6, 0x69, 0x43, 0x54, 0x4a,
		0xfb, 0xda, 0xec, 0xa5, 0x51, 0xdc, 0x17, 0x0f, 0x4c, 0x1b, 0xba, 0x54, 0x44, 0xe2, 0xcc, 0x4b,
		0xc9, 0x74, 0x91, 0x92, 0x59, 0x46, 0x4a, 0xa6, 0x8b, 0x94, 0xcc, 0xac, 0xb3, 0x95, 0x4e, 0xda,
		0x5f, 0x43, 0x11, 0x4d, 0xe4, 0x27, 0xd5, 0x6a, 0xf5, 0xd7, 0x0f, 0x13, 0xa9, 0xa1, 0xb8, 0x78,
		0x47, 0x0f, 0x33, 0x42, 0xdb, 0xe2, 0x0f, 0xf2, 0x42, 0x72, 0x9f, 0x0f, 0xb8, 0x14, 0x8f, 0x56,
		0x18, 0x58, 0x76, 0x7f, 0xa2, 0x36, 0x2a, 0x81, 0x1e, 0x13, 0x17, 0xa3, 0x00, 0x7b, 0x94, 0x0d,
		0x3b, 0x7a, 0x07, 0x93, 0xc2, 0xb6, 0x60, 0xfa, 0xc7, 0x33, 0xc6, 0x61, 0x60, 0x18, 0x2f, 0x7d,
		0x26, 0x4b, 0x70, 0x97, 0x8e, 0x82, 0x3d, 0x6d, 0x16, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0xac, 0x7c,
		0x26, 0x46, 0x24, 0xb4, 0xa8, 0x11, 0x5c, 0x88, 0x97, 0x3b, 0xf8, 0x12, 0xf8, 0x12, 0xf8, 0x12,
		0xa5, 0xf9, 0x58, 0xc7, 0x0c, 0xf4, 0xd3, 0x6a, 0x0d, 0x3f, 0x50, 0x4f, 0x2b, 0x45, 0x11, 0x75,
		0x6a, 0x23, 0xa3, 0xd2, 0xd8, 0x28, 0x37, 0x3a, 0xaa, 0x8d, 0x8f, 0x36, 0x23, 0xa4, 0xcd, 0x18,
		0xe9, 0x30, 0x4a, 0xb4, 0xc6, 0x89, 0xd8, 0x48, 0xa9, 0x13, 0x77, 0xd6, 0x66, 0xbb, 0xcf, 0x99,
		0x5b, 0x9c, 0x94, 0xfc, 0x12, 0xb9, 0x9c, 0x2a, 0x68, 0xfb, 0x26, 0x65, 0xb0, 0xe3, 0x69, 0x71,
		0xb1, 0xc4, 0x4c, 0x57, 0xfe, 0x30, 0xfb, 0x7d, 0xb2, 0x11, 0xaa, 0xa2, 0x9b, 0xf5, 0x28, 0x73,
		0x79, 0x96, 0x79, 0xb9, 0x3a, 0x7f, 0xf4, 0xa4, 0x17, 0xb8, 0x24, 0xb8, 0x24, 0xb8, 0x24, 0xb8,
		0x24, 0xb8, 0xa4, 0x1d, 0x5d, 0xd2, 0xe7, 0x85, 0x4b, 0xfa, 0x6f, 0x3b, 0x11, 0x82, 0x07, 0xf2,
		0xf9, 0xd1, 0xf1, 0xcb, 0x97, 0x0b, 0xb1, 0xb5, 0x37, 0xbb, 0xe4, 0xa9, 0xe6, 0xba, 0xfe, 0xb7,
		0xb4, 0x65, 0x87, 0x3f, 0x54, 0xd6, 0xbb, 0x55, 0x8a, 0xfd, 0x91, 0x85, 0x5c, 0xe6, 0x3f, 0xea,
		0x84, 0x04, 0xe5, 0x21, 0x98, 0x2d, 0xc6, 0x93, 0x30, 0x14, 0xb3, 0xd1, 0x6a, 0x56, 0x4d, 0x58,
		0xe8, 0x51, 0x09, 0xad, 0xb4, 0xa1, 0x9a, 0x05, 0xa4, 0xd3, 0x11, 0xb2, 0x79, 0x12, 0xa1, 0x20,
		0x09, 0xe0, 0xd0, 0x0d, 0xd2, 0x88, 0xa4, 0x1c, 0x02, 0x93, 0x9c, 0x5e, 0xea, 0x9d, 0x36, 0x5b,
		0x71, 0xa5, 0xb7, 0x05, 0xa5, 0xd7, 0x1c, 0x44, 0x0b, 0xa5, 0x17, 0x4a, 0x2f, 0x68, 0x35, 0x68,
		0x35, 0x68, 0x35, 0x68, 0x35, 0x68, 0x35, 0x94, 0xde, 0xed, 0x88, 0x16, 0x4a, 0x2f, 0x5c, 0x12,
		0x5c, 0x12, 0x5c, 0x12, 0x5c, 0x52, 0x65, 0x5d, 0x12, 0x94, 0xde, 0xf2, 0xd8, 0xdf, 0x1e, 0xc9,
		0x71, 0x05, 0x76, 0x8c, 0x2b, 0x50, 0xe3, 0x50, 0xd2, 0xb5, 0xd0, 0x68, 0xea, 0x2d, 0xee, 0xfa,
		0x77, 0x7a, 0x17, 0x5f, 0xd3, 0xaf, 0x7d, 0xe0, 0xae, 0x89, 0xb9, 0xf9, 0x34, 0x12, 0x2e, 0xa9,
		0x74, 0x4b, 0x9e, 0x8b, 0xdf, 0x42, 0x2e, 0x7e, 0xf9, 0x90, 0x13, 0xb9, 0xf8, 0x3b, 0x3f, 0x10,
		0x76, 0x45, 0x63, 0x57, 0x74, 0xe5, 0x38, 0x2f, 0x62, 0x3f, 0x65, 0x70, 0x5a, 0xec, 0x8a, 0x2e,
		0x8c, 0x22, 0xb0, 0x2b, 0xda, 0x58, 0x88, 0x4f, 0x40, 0xd1, 0x50, 0x61, 0x8d, 0x7e, 0x5c, 0xea,
		0x85, 0xf8, 0x46, 0x76, 0x92, 0xa5, 0xad, 0xac, 0xdb, 0x33, 0x85, 0x23, 0x5d, 0x74, 0x84, 0xd5,
		0x8d, 0x6c, 0x8e, 0xe1, 0xdc, 0x7d, 0x18, 0xb3, 0x8d, 0xdd, 0xee, 0x23, 0x90, 0xe1, 0xed, 0xd7,
		0xbd, 0x68, 0xd8, 0xcd, 0xfc, 0xce, 0x17, 0xc9, 0x03, 0xe3, 0xab, 0x33, 0x8e, 0x75, 0x3e, 0x06,
		0x9b, 0x1b, 0x60, 0x16, 0x01, 0x92, 0x85, 0x0b, 0x3f, 0x17, 0x05, 0x86, 0x64, 0x00, 0x90, 0x0c,
		0xe8, 0x51, 0x14, 0x6e, 0x56, 0x6b, 0x4b, 0xf2, 0x32, 0xc4, 0x3a, 0x73, 0x1c, 0xc1, 0xe3, 0x98,
		0xc7, 0xc5, 0x8b, 0x50, 0x2e, 0x9a, 0x42, 0x0d, 0xca, 0xc2, 0x55, 0xd3, 0x0f, 0xb8, 0x06, 0x65,
		0x74, 0x30, 0x35, 0x28, 0x67, 0x2b, 0x86, 0x4e, 0x6d, 0x9d, 0x37, 0x88, 0xda, 0x27, 0xca, 0x17,
		0x28, 0xf4, 0x56, 0x15, 0x0b, 0x78, 0xcf, 0xf4, 0x56, 0xd4, 0x3e, 0x31, 0x41, 0x15, 0xc5, 0xf1,
		0xdd, 0x38, 0xbe, 0xbb, 0x56, 0xe9, 0x8c, 0xf8, 0x48, 0x61, 0x2a, 0x7c, 0x84, 0x84, 0x43, 0x3d,
		0x09, 0x87, 0x11, 0x12, 0x0e, 0x4b, 0x34, 0x3f, 0x3a, 0xcc, 0x10, 0xad, 0x39, 0x22, 0x36, 0x4b,
		0xe9, 0x0b, 0x50, 0x9f, 0x70, 0xe8, 0x45, 0xc3, 0xae, 0x45, 0xc3, 0x45, 0x7e, 0x09, 0x58, 0xce,
		0xd4, 0x64, 0x1d, 0x4a, 0x2e, 0x02, 0xd2, 0xdd, 0xcb, 0x4f, 0x3a, 0xf8, 0xcf, 0xf3, 0xe7, 0x9f,
		0x1b, 0xd6, 0x39, 0xb3, 0xdc, 0x4b, 0xeb, 0x4d, 0xef, 0x47, 0xf3, 0x45, 0x67, 0x74, 0x71, 0xf4,
		0xe3, 0x74, 0xb4, 0xfa, 0xc7, 0x9f, 0x9b, 0xbe, 0xd6, 0x7c, 0x71, 0x3a, 0xba, 0xd8, 0xf2, 0x2f,
		0xdd, 0xd1, 0xc5, 0x8e, 0x6d, 0x9c, 0x8c, 0x9e, 0xaf, 0x7d, 0x75, 0xfc, 0xf7, 0xd6, 0xb6, 0x0b,
		0x3a, 0x5b, 0x2e, 0x68, 0x6f, 0xbb, 0xa0, 0xbd, 0xe5, 0x82, 0xad, 0xb7, 0xd4, 0xda, 0x72, 0xc1,
		0xc9, 0xe8, 0xe7, 0xda, 0xf7, 0x9f, 0x6f, 0xfe, 0x6a, 0x77, 0x74, 0xf4, 0x73, 0xdb, 0xbf, 0x9d,
		0x8e, 0x7e, 0x5e, 0x1c, 0x1d, 0xfd, 0x8b, 0x7e, 0xa9, 0xf7, 0x54, 0x4c, 0xc1, 0xf7, 0xb7, 0xd7,
		0xff, 0x60, 0x1e, 0x62, 0x1e, 0x66, 0x99, 0x87, 0x07, 0xb0, 0x17, 0x67, 0x0a, 0x40, 0x2c, 0x9f,
		0x07, 0xf7, 0x93, 0x98, 0x97, 0x22, 0x44, 0xfc, 0xb4, 0x1b, 0x80, 0x63, 0x80, 0x63, 0x80, 0x63,
		0x80, 0x63, 0xb2, 0xd9, 0x9e, 0x78, 0x81, 0x3c, 0x53, 0x88, 0x8a, 0x4f, 0x14, 0x34, 0x4d, 0x7b,
		0x00, 0xea, 0xea, 0x8f, 0x9a, 0xd5, 0x59, 0x53, 0x75, 0x40, 0xaa, 0x26, 0x9b, 0xbe, 0xd6, 0x8d,
		0xa2, 0x43, 0x39, 0xd7, 0xfa, 0x51, 0x78, 0x48, 0xa7, 0xe2, 0xd5, 0xfb, 0x74, 0xe8, 0xd9, 0xc3,
		0xde, 0x0d, 0x7d, 0xb3, 0x75, 0xb6, 0x47, 0x83, 0xff, 0xcc, 0x8c, 0x56, 0x7b, 0xd8, 0x08, 0xb8,
		0x0b, 0x72, 0x30, 0x6c, 0x23, 0x60, 0xf7, 0x38, 0xcd, 0x57, 0x99, 0x7f, 0xda, 0xc3, 0x82, 0x5c,
		0x84, 0x91, 0x03, 0xfa, 0x88, 0xc1, 0xc1, 0x6f, 0xc7, 0x40, 0xe0, 0x11, 0x81, 0xc7, 0x9a, 0x11,
		0xdb, 0x31, 0xe8, 0x4b, 0x08, 0xa8, 0x28, 0x1d, 0x90, 0x96, 0x0c, 0x78, 0xf9, 0x72, 0xba, 0x55,
		0xe0, 0x98, 0x6a, 0xac, 0x51, 0x5e, 0x31, 0xeb, 0xb0, 0x1e, 0x6a, 0x79, 0x45, 0xd8, 0x74, 0xd8,
		0xf4, 0x1a, 0x92, 0x49, 0xaa, 0x4d, 0xb0, 0xa1, 0x97, 0xeb, 0x34, 0x37, 0xda, 0xcc, 0x8e, 0x36,
		0xf3, 0xa3, 0xc3, 0x0c, 0xa9, 0x11, 0x34, 0x90, 0x4c, 0xb2, 0x0d, 0xb0, 0x20, 0x99, 0x04, 0x41,
		0x7c, 0x24, 0x93, 0x60, 0x1e, 0x62, 0x1e, 0x1e, 0x44, 0x32, 0x49, 0x28, 0xbc, 0x7b, 0x05, 0xc1,
		0xc1, 0x05, 0x48, 0x9b, 0xb6, 0x0f, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x4c, 0x08, 0x87,
		0xe7, 0x60, 0xd8, 0x52, 0x62, 0x62, 0x9e, 0x60, 0xe2, 0x8e, 0x82, 0xb6, 0x5f, 0x07, 0xc9, 0x60,
		0xfc, 0x8a, 0x46, 0xc8, 0x58, 0xa4, 0x9a, 0x13, 0xc8, 0x58, 0x84, 0xcb, 0x81, 0xcb, 0x81, 0xcb,
		0x51, 0x34, 0xdb, 0x91, 0xb1, 0xb8, 0xfa, 0x83, 0x8c, 0xc5, 0x9d, 0xba, 0x41, 0xc6, 0x62, 0xb6,
		0xa1, 0x47, 0xc6, 0x62, 0xc5, 0x07, 0x1f, 0x19, 0x8b, 0x95, 0x81, 0xd6, 0xb1, 0x64, 0x32, 0x89,
		0x15, 0x1e, 0xc9, 0x33, 0x6d, 0x1f, 0x60, 0x1a, 0x60, 0x1a, 0x60, 0x1a, 0x60, 0x9a, 0x6c, 0xb6,
		0xf3, 0x20, 0x19, 0x70, 0x31, 0x4d, 0x94, 0x86, 0x72, 0x83, 0x84, 0xf8, 0xec, 0x8e, 0x4f, 0x63,
		0x42, 0x7c, 0xb5, 0x8e, 0xc4, 0x21, 0xc8, 0xa0, 0x1c, 0x0a, 0xa1, 0x20, 0x23, 0x7e, 0xd2, 0x2a,
		0x8a, 0x71, 0x55, 0x0e, 0x09, 0x20, 0x7f, 0xb2, 0x0c, 0x4f, 0xbf, 0xe7, 0xf9, 0x93, 0xe3, 0xc5,
		0x6e, 0xdd, 0x8b, 0x30, 0x51, 0x98, 0x47, 0xb9, 0xd4, 0x87, 0x1a, 0x02, 0xd2, 0x04, 0x01, 0x01,
		0x01, 0x01, 0x01, 0xa9, 0x1e, 0x01, 0xa1, 0x36, 0x57, 0x69, 0xc3, 0xc4, 0xa5, 0x48, 0xb7, 0x2e,
		0x26, 0xd2, 0xd2, 0xa4, 0x9a, 0xcc, 0x97, 0x72, 0x33, 0xa6, 0xc3, 0x9c, 0x69, 0x33, 0x6b, 0xba,
		0xcc, 0x9b, 0x76, 0x33, 0xa7, 0xdd, 0xdc, 0xe9, 0x34, 0x7b, 0x6a, 0xcc, 0x9f, 0x22, 0x33, 0xa8,
		0xdc, 0x1c, 0xa6, 0x1d, 0x30, 0xdb, 0xe6, 0x91, 0xb4, 0x06, 0xa1, 0xa3, 0x61, 0x22, 0xa7, 0x65,
		0xda, 0x97, 0x3a, 0x55, 0x3c, 0xb3, 0x14, 0x9d, 0xa4, 0xf7, 0x3b, 0x03, 0xad, 0x3a, 0xbc, 0xa4,
		0xda, 0x50, 0xeb, 0x34, 0xd8, 0xda, 0x0d, 0xb7, 0x6e, 0x03, 0x5e, 0x9a, 0x21, 0x2f, 0xcd, 0xa0,
		0x97, 0x61, 0xd8, 0xd5, 0x1a, 0x78, 0xc5, 0x86, 0x3e, 0x7d, 0x61, 0xca, 0x04, 0xf8, 0xad, 0xab,
		0x8d, 0xfe, 0xa4, 0xc1, 0xdf, 0xa2, 0xd7, 0xe6, 0x33, 0x33, 0x27, 0x80, 0xca, 0xe4, 0x07, 0xe6,
		0x0c, 0xb9, 0x90, 0x5e, 0xcc, 0xc7, 0xcb, 0x65, 0x2a, 0x65, 0x0f, 0x99, 0xaf, 0xd1, 0x27, 0x6f,
		0xee, 0x5f, 0x9f, 0x7b, 0x6e, 0x36, 0x1a, 0x70, 0xce, 0x70, 0xce, 0x70, 0xce, 0x70, 0xce, 0x70,
		0xce, 0xcb, 0xa9, 0xa7, 0xcd, 0xae, 0x46, 0xdf, 0xdc, 0xd5, 0xd0, 0x95, 0xda, 0xdc, 0xd4, 0xd5,
		0x1f, 0x3d, 0xe6, 0xa3, 0xa6, 0x2b, 0x77, 0xb5, 0x24, 0xa7, 0xb6, 0xd6, 0x6d, 0x9a, 0xe0, 0xa8,
		0xb9, 0x5f, 0x8d, 0xe9, 0x8e, 0x9a, 0xcd, 0xcb, 0xd3, 0xa9, 0xc4, 0x1e, 0x0e, 0x6e, 0x2a, 0x75,
		0x1a, 0xe7, 0x27, 0x07, 0x34, 0x9b, 0x9e, 0xed, 0x47, 0x2f, 0x3d, 0x90, 0xb9, 0xb5, 0x69, 0x15,
		0x09, 0xce, 0x07, 0x91, 0xd4, 0xc7, 0xde, 0xe6, 0x1d, 0xea, 0xa3, 0x6b, 0x63, 0x9c, 0x0a, 0xbe,
		0x06, 0xbe, 0x06, 0xbe, 0x06, 0xbe, 0x06, 0xbe, 0x06, 0x31, 0xb5, 0x8a, 0xfe, 0xd7, 0x72, 0xb8,
		0xcf, 0x1e, 0xb5, 0x7b, 0xe1, 0x59, 0xb7, 0xfa, 0x7c, 0x31, 0x84, 0x53, 0x38, 0x62, 0x38, 0x62,
		0x38, 0x62, 0x38, 0x62, 0x08, 0xa7, 0x74, 0x3f, 0x10, 0x4e, 0x95, 0x74, 0xab, 0xa9, 0x28, 0xc0,
		0x5a, 0xbf, 0x10, 0x4e, 0xf7, 0x76, 0x2a, 0xb5, 0xbb, 0x8d, 0x06, 0x84, 0x53, 0xd3, 0x7a, 0x81,
		0x70, 0xba, 0x89, 0xb8, 0x79, 0xa1, 0xf0, 0xa4, 0x56, 0xce, 0x36, 0xeb, 0x11, 0x99, 0x2e, 0x20,
		0x6c, 0x20, 0x6c, 0x20, 0x6c, 0x20, 0x6c, 0xa5, 0x11, 0xb6, 0x33, 0x8d, 0x7c, 0xed, 0x04, 0x7c,
		0x0d, 0x7c, 0x2d, 0x0b, 0xc8, 0x46, 0xa2, 0x0b, 0xf8, 0x1a, 0xd1, 0x54, 0x6a, 0x9d, 0x74, 0x40,
		0xd7, 0x40, 0xd7, 0xcc, 0xa7, 0x6b, 0x43, 0x4f, 0xc8, 0x84, 0xf9, 0xe9, 0xf1, 0x34, 0xda, 0x58,
		0xdb, 0x6a, 0xc7, 0xa0, 0x53, 0xa0, 0x53, 0xa0, 0x53, 0xa0, 0x53, 0xa0, 0x53, 0x6b, 0xc7, 0x24,
		0xe8, 0xcc, 0x45, 0x39, 0xd7, 0xd0, 0xd7, 0xec, 0x5d, 0xee, 0x1d, 0xa7, 0x5a, 0x3a, 0xef, 0xad,
		0xa3, 0x71, 0xec, 0xd6, 0xc6, 0xf0, 0x4c, 0x63, 0x9f, 0xaa, 0xcf, 0xe5, 0xda, 0xda, 0xf1, 0xec,
		0xbc, 0xae, 0xde, 0xcf, 0xcf, 0x4d, 0xeb, 0xbc, 0x37, 0xfd, 0xd8, 0x9c, 0xfc, 0x6f, 0xfa, 0xb9,
		0xf5, 0xb9, 0x61, 0x75, 0xe6, 0x9f, 0x4f, 0x3e, 0x37, 0xac, 0x93, 0xde, 0xd1, 0x97, 0x2f, 0x2f,
		0x8f, 0x7e, 0xb4, 0x47, 0xd9, 0x2f, 0xfc, 0x57, 0x5d, 0xdb, 0xc3, 0xf5, 0x74, 0x0e, 0x9e, 0x8e,
		0x93, 0xd5, 0x0e, 0x6f, 0x04, 0x9f, 0xed, 0x11, 0xc3, 0x2f, 0xc7, 0x7c, 0x76, 0x61, 0x3e, 0xf5,
		0x2c, 0x3e, 0x1c, 0x77, 0xb8, 0x17, 0xc7, 0x1d, 0xc2, 0x99, 0x60, 0x3e, 0x1f, 0xc4, 0x7c, 0x86,
		0x12, 0x59, 0x01, 0x2e, 0xfc, 0xd6, 0x8b, 0xe5, 0xa5, 0x94, 0x42, 0x0f, 0x1f, 0x7e, 0xe7, 0x05,
		0xaf, 0xfd, 0x49, 0x4d, 0x93, 0x58, 0x8f, 0xe0, 0x5f, 0x7f, 0xc7, 0x1e, 0x96, 0x7a, 0x6c, 0x9e,
		0x75, 0x3a, 0xdd, 0xd3, 0x4e, 0xa7, 0x71, 0xda, 0x3e, 0x6d, 0x9c, 0x9f, 0x9c, 0x34, 0xbb, 0x4d,
		0x1d, 0x91, 0xc7, 0xf7, 0xc2, 0xe1, 0x82, 0x3b, 0x7f, 0x3c, 0xd6, 0x2f, 0x6a, 0x41, 0xe2, 0xfb,
		0xd0, 0xae, 0xd7, 0x5e, 0xd1, 0x5c, 0x42, 0xf6, 0xbd, 0xe0, 0x9b, 0xe5, 0x87, 0xb6, 0xce, 0x62,
		0x3b, 0x1b, 0xfa, 0x86, 0x82, 0x9d, 0x0d, 0x2f, 0x40, 0xc1, 0x26, 0x9c, 0x1c, 0x50, 0xb0, 0xa1,
		0x60, 0xef, 0xa4, 0xba, 0x42, 0xc1, 0xa6, 0x7b, 0x97, 0x50, 0xb0, 0x21, 0xc1, 0x40, 0xff, 0x3c,
		0x78, 0xd1, 0x01, 0x0a, 0x76, 0x15, 0x1d, 0x5e, 0xb9, 0xe6, 0x13, 0x0a, 0x36, 0x14, 0x3f, 0x28,
		0x7e, 0x70, 0x26, 0x98, 0xcf, 0x98, 0xcf, 0x25, 0xb8, 0x56, 0xe4, 0xd2, 0x96, 0xa8, 0x47, 0x8a,
		0x30, 0x91, 0x5c, 0x58, 0x9e, 0xa3, 0x5f, 0x8e, 0x5c, 0x74, 0x0d, 0x35, 0x12, 0x6a, 0x24, 0xd4,
		0x48, 0xa8, 0x91, 0x50, 0x23, 0xb1, 0x3d, 0xd1, 0x3c, 0x26, 0x8d, 0xed, 0x89, 0xea, 0xfb, 0xc5,
		0xf6, 0xc4, 0xbd, 0x9d, 0x4a, 0xad, 0x13, 0x94, 0xe1, 0x06, 0xa5, 0xd2, 0x45, 0xa9, 0x8c, 0x3a,
		0x8f, 0xf1, 0x32, 0xb9, 0x1f, 0x03, 0x35, 0xee, 0x28, 0x75, 0x9b, 0x9a, 0x68, 0xdf, 0xf1, 0x18,
		0x6b, 0xba, 0x17, 0x93, 0xb3, 0x9e, 0x5c, 0x66, 0xf3, 0x78, 0xf5, 0x0f, 0xb3, 0xdf, 0xe3, 0xe4,
		0x6e, 0xed, 0x3b, 0xcb, 0x7f, 0x9b, 0xfc, 0x29, 0xba, 0xf0, 0xa2, 0x61, 0x77, 0xf6, 0x71, 0xa6,
		0x5e, 0xcf, 0xbe, 0x9d, 0xfe, 0x7e, 0x3c, 0x14, 0x22, 0x3a, 0x5e, 0x1c, 0xee, 0x7d, 0xac, 0xf4,
		0xb0, 0xdc, 0xf4, 0x79, 0xaf, 0x78, 0x6c, 0x0b, 0x2f, 0x1a, 0x1b, 0x98, 0xf1, 0x63, 0x5f, 0x3a,
		0x8e, 0x37, 0xfe, 0xcc, 0xfc, 0xda, 0xa7, 0x0f, 0x1f, 0x6e, 0x6a, 0x0e, 0x93, 0xac, 0xe6, 0x86,
		0xa2, 0x76, 0x7d, 0x33, 0xec, 0xd6, 0x16, 0x4f, 0xaa, 0x89, 0x04, 0x37, 0x41, 0x82, 0x41, 0x82,
		0x41, 0x82, 0x41, 0x82, 0x33, 0x9b, 0x35, 0x4f, 0x53, 0x0e, 0x6d, 0x09, 0x99, 0x92, 0x6b, 0x0b,
		0x5d, 0x7b, 0xc6, 0xe4, 0x36, 0xef, 0xf1, 0x26, 0x14, 0x53, 0xb7, 0x11, 0x06, 0xab, 0x0e, 0xe3,
		0x45, 0x2d, 0xe6, 0x32, 0xae, 0xc9, 0x3e, 0xaf, 0xcd, 0x6e, 0xb7, 0x36, 0xbe, 0xdd, 0xda, 0xe4,
		0x76, 0xbf, 0x04, 0x7a, 0x43, 0xba, 0x9a, 0x49, 0x84, 0x36, 0x37, 0x53, 0x86, 0xbb, 0x29, 0xcd,
		0xed, 0x94, 0xe5, 0x7e, 0x4a, 0x77, 0x43, 0xa5, 0xbb, 0xa3, 0x32, 0xdd, 0x92, 0x66, 0x6a, 0xaa,
		0x69, 0xbd, 0x6a, 0xd3, 0x6c, 0xd7, 0x56, 0xab, 0xd6, 0x4c, 0xd2, 0x35, 0x78, 0x7f, 0xae, 0xb1,
		0x4f, 0xad, 0x99, 0xa5, 0x7a, 0xd8, 0xea, 0x6f, 0x46, 0xb6, 0x94, 0x4c, 0xd3, 0xb5, 0x31, 0x3e,
		0x2b, 0xa1, 0xef, 0xb2, 0x52, 0x4d, 0xd2, 0x1b, 0xd8, 0xd7, 0xfc, 0xc5, 0x54, 0x51, 0x2b, 0x63,
		0x50, 0xcb, 0x4c, 0x22, 0x3a, 0x9c, 0x91, 0xd5, 0xda, 0xe3, 0xe8, 0xc5, 0x01, 0x99, 0xe3, 0x2e,
		0xcc, 0x71, 0xb9, 0x8b, 0x16, 0x19, 0x80, 0x7b, 0x9d, 0x01, 0x08, 0xe7, 0x84, 0x79, 0x7e, 0x50,
		0xf3, 0x5c, 0xaf, 0xab, 0x46, 0x26, 0x6f, 0xa5, 0x7a, 0x30, 0x2d, 0xec, 0xdc, 0x53, 0x15, 0x76,
		0x0e, 0x82, 0x50, 0xb2, 0x99, 0x04, 0xad, 0x0e, 0xe0, 0xd5, 0x63, 0xbb, 0xcf, 0x07, 0x2c, 0x62,
		0xb2, 0x3f, 0x8d, 0x0f, 0x47, 0x3c, 0x98, 0x86, 0x68, 0xad, 0xa5, 0x00, 0xf0, 0xa6, 0x8f, 0xc7,
		0x4f, 0x63, 0xc4, 0x4f, 0xa2, 0xc3, 0x93, 0xb8, 0xf0, 0x22, 0x22, 0xfc, 0x9b, 0x58, 0xf0, 0x33,
		0x33, 0x46, 0x5b, 0x01, 0xa8, 0xaf, 0xa7, 0xaf, 0xcc, 0x92, 0x82, 0xd9, 0xdf, 0xbc, 0xe0, 0x5e,
		0xd9, 0x68, 0x2f, 0x20, 0xfb, 0x7a, 0x9f, 0x8a, 0xe6, 0xb0, 0xda, 0x70, 0xb7, 0xf2, 0xf8, 0x83,
		0x8e, 0x78, 0x83, 0xb6, 0xf8, 0x82, 0xae, 0x78, 0x82, 0xf6, 0xf8, 0x81, 0xf6, 0x78, 0x81, 0xce,
		0xf8, 0x80, 0x59, 0xa9, 0x52, 0xaa, 0xc3, 0xd3, 0x75, 0x7b, 0xbe, 0xe2, 0x35, 0xa5, 0x4b, 0xe9,
		0x49, 0x56, 0x42, 0x56, 0x50, 0xf5, 0xcd, 0xa7, 0x6e, 0x33, 0x5a, 0x9a, 0x39, 0x2d, 0xcd, 0xac,
		0x96, 0x61, 0x5e, 0x35, 0x51, 0x9a, 0x7d, 0xc9, 0x0a, 0x9a, 0x1f, 0x9c, 0x68, 0x39, 0xdc, 0x16,
		0x7c, 0x36, 0x46, 0x9a, 0xb3, 0x82, 0x36, 0xdc, 0x83, 0xb6, 0xac, 0x20, 0x6d, 0xa7, 0xef, 0xaf,
		0xba, 0x06, 0x64, 0xf4, 0x18, 0xec, 0x32, 0xca, 0x72, 0x1d, 0xa5, 0xbb, 0x90, 0xd2, 0x5d, 0x49,
		0x99, 0x2e, 0x45, 0x8f, 0x6b, 0xd1, 0xe4, 0x62, 0xd2, 0x17, 0x59, 0x5e, 0x46, 0x8f, 0xae, 0xdd,
		0x98, 0xab, 0xa6, 0x57, 0xe3, 0xbe, 0x28, 0xcd, 0xbb, 0x33, 0xe7, 0x3f, 0x25, 0x44, 0x8f, 0xcb,
		0xd8, 0xad, 0x59, 0x92, 0x4f, 0x5d, 0xeb, 0x7e, 0xbe, 0xe5, 0xae, 0xac, 0xfe, 0x4b, 0xdc, 0x78,
		0xa7, 0xd9, 0x5a, 0x3d, 0x9d, 0x72, 0x25, 0xec, 0xea, 0xac, 0xda, 0x94, 0xd3, 0x7e, 0x08, 0x65,
		0xa5, 0x26, 0x1d, 0xc2, 0x8a, 0x95, 0x7e, 0x1e, 0x0d, 0x46, 0xa1, 0x3e, 0x09, 0x78, 0x2c, 0x02,
		0x5b, 0xfa, 0xd9, 0xeb, 0xea, 0x0d, 0x80, 0x46, 0x82, 0x46, 0x82, 0x46, 0x82, 0x46, 0x82, 0x46,
		0x6a, 0x5a, 0xad, 0x3e, 0x67, 0xae, 0xe0, 0x6e, 0x19, 0xbb, 0x42, 0x4e, 0xf5, 0x16, 0x59, 0xed,
		0x67, 0xd9, 0xef, 0x1f, 0x8c, 0x5f, 0xcf, 0x5e, 0x4d, 0x31, 0xad, 0x67, 0xce, 0x2c, 0x13, 0x5b,
		0xbd, 0x67, 0xcf, 0x2c, 0xf3, 0x9b, 0xd2, 0xcf, 0xa0, 0x49, 0x6f, 0x46, 0xeb, 0x59, 0x34, 0x1a,
		0x21, 0xaa, 0xd1, 0x61, 0x22, 0x4d, 0x19, 0x65, 0x69, 0x7f, 0x65, 0x66, 0x96, 0xad, 0xe7, 0x38,
		0x29, 0x4d, 0x36, 0x53, 0x3f, 0x41, 0x54, 0x96, 0x21, 0x8d, 0x25, 0x93, 0x5c, 0x5f, 0x52, 0xc5,
		0xb4, 0xbb, 0x3d, 0xcb, 0xa9, 0x68, 0x21, 0xa7, 0xc2, 0x18, 0x46, 0x83, 0x9c, 0x0a, 0xe4, 0x54,
		0xfc, 0xee, 0x85, 0x21, 0xa7, 0x42, 0xcb, 0x1d, 0x20, 0xa7, 0x02, 0x62, 0x18, 0xc4, 0x30, 0x88,
		0x61, 0x10, 0xc3, 0x90, 0x53, 0xa1, 0xa6, 0x4b, 0xe4, 0x54, 0xec, 0x9f, 0x4f, 0x5d, 0xeb, 0x1e,
		0x39, 0x15, 0xc8, 0xa9, 0x28, 0x69, 0xca, 0x21, 0xa7, 0x62, 0x0f, 0x7b, 0x43, 0x4e, 0xc5, 0xee,
		0xd3, 0x10, 0x39, 0x15, 0xa0, 0x91, 0xa0, 0x91, 0xa0, 0x91, 0xa0, 0x91, 0x87, 0x4a, 0x23, 0x91,
		0x53, 0x81, 0x9c, 0x0a, 0xb5, 0xc4, 0x16, 0x39, 0x15, 0xc8, 0xa9, 0xa8, 0xe2, 0xca, 0x38, 0xf4,
		0x9c, 0x8a, 0x69, 0x28, 0x1f, 0xf5, 0xa0, 0xd4, 0xcf, 0xb8, 0x83, 0xa8, 0x07, 0xa5, 0xad, 0x32,
		0xd1, 0xf4, 0x49, 0xa5, 0x48, 0x6c, 0x19, 0xcc, 0x40, 0xcc, 0xf5, 0xbc, 0xef, 0xaf, 0xb7, 0x4b,
		0x77, 0xfe, 0xf5, 0x3a, 0x1a, 0x76, 0xbf, 0x5e, 0x4e, 0xef, 0xf7, 0xeb, 0x27, 0x21, 0xa2, 0x3f,
		0xc7, 0x77, 0xfa, 0x35, 0xfd, 0xf6, 0xc7, 0xf9, 0x8d, 0x1e, 0x70, 0x11, 0x2b, 0xb5, 0xf9, 0x43,
		0x5a, 0xf2, 0x86, 0xb4, 0x95, 0xaa, 0x6a, 0xa1, 0x54, 0x55, 0x65, 0xd8, 0x38, 0x4a, 0x55, 0x1d,
		0xae, 0x3b, 0x55, 0x5e, 0xaa, 0x8a, 0xd9, 0x36, 0x8f, 0xa4, 0x35, 0x08, 0x1d, 0x8d, 0xa9, 0x95,
		0xcb, 0x9d, 0x2a, 0x3f, 0x61, 0x2f, 0xcd, 0xdc, 0x71, 0x99, 0x1f, 0x73, 0x9c, 0x1f, 0x5f, 0x39,
		0x83, 0xad, 0xdd, 0x70, 0xeb, 0x36, 0xe0, 0xa5, 0x19, 0xf2, 0xd2, 0x0c, 0x7a, 0x19, 0x86, 0x7d,
		0x3f, 0x98, 0xba, 0xfe, 0xf3, 0xe3, 0xef, 0xc2, 0xd0, 0xe7, 0x2c, 0xd0, 0x78, 0x82, 0x7c, 0xb3,
		0x89, 0xdd, 0x0d, 0xeb, 0x8e, 0xd8, 0x19, 0x72, 0x21, 0xbd, 0x78, 0xa2, 0xe3, 0x4d, 0x49, 0xec,
		0x50, 0xc3, 0x71, 0x86, 0x0b, 0x9f, 0xbc, 0xb9, 0x7f, 0x7d, 0xee, 0xb9, 0xd9, 0x68, 0xc0, 0x39,
		0xc3, 0x39, 0xc3, 0x39, 0xc3, 0x39, 0xc3, 0x39, 0x2f, 0xa7, 0xbe, 0x36, 0xbb, 0x1a, 0x7d, 0x73,
		0x57, 0x43, 0x57, 0x7a, 0x73, 0x5d, 0xf5, 0x86, 0x00, 0x4b, 0xc8, 0xcd, 0x28, 0x25, 0xc1, 0x30,
		0x4d, 0x2c, 0x6c, 0x6a, 0xee, 0xb7, 0xc4, 0x74, 0xc2, 0x91, 0xde, 0x98, 0xee, 0xc1, 0x4d, 0xa5,
		0x4e, 0xe3, 0xfc, 0xe4, 0x80, 0x66, 0xd3, 0x9e, 0x44, 0xc6, 0x7b, 0x20, 0x73, 0x6b, 0xd3, 0xca,
		0x4e, 0x84, 0x18, 0xd3, 0xa8, 0xf9, 0x8e, 0x45, 0x8d, 0x47, 0x01, 0xac, 0xf6, 0x0c, 0x4a, 0x05,
		0x4a, 0x05, 0x4a, 0x05, 0x4a, 0x05, 0x4a, 0xa5, 0x79, 0x37, 0xa1, 0xc6, 0x5d, 0x84, 0x60, 0x54,
		0xfb, 0x04, 0x83, 0x1b, 0x60, 0x54, 0x60, 0x54, 0x34, 0x53, 0xa9, 0x75, 0x02, 0x42, 0x05, 0x42,
		0xb5, 0x07, 0x84, 0x2a, 0x12, 0x9c, 0x0f, 0x22, 0xa9, 0x8f, 0x47, 0xcd, 0x3b, 0xd4, 0x17, 0xff,
		0x1a, 0xa3, 0x54, 0xb0, 0x35, 0xb0, 0x35, 0xb0, 0x35, 0xb0, 0x35, 0xb0, 0x35, 0x64, 0xa7, 0x54,
		0xd1, 0xff, 0x5a, 0x0e, 0xf7, 0xd9, 0xa3, 0x76, 0x2f, 0x3c, 0xeb, 0x56, 0x9f, 0x2f, 0x46, 0x26,
		0x0a, 0x1c, 0x31, 0x1c, 0x31, 0x1c, 0x31, 0x1c, 0x31, 0x32, 0x51, 0xe8, 0x7e, 0xa0, 0x9b, 0x2a,
		0xe9, 0x16, 0xba, 0xa9, 0xda, 0xa9, 0x74, 0x80, 0xba, 0x69, 0xbb, 0xdb, 0x68, 0x40, 0x38, 0x35,
		0xad, 0x17, 0x08, 0xa7, 0x9b, 0x88, 0x9b, 0xee, 0x0c, 0x14, 0x5d, 0x99, 0x27, 0xd8, 0x3a, 0x00,
		0xc2, 0x06, 0xc2, 0x06, 0xc2, 0x06, 0xc2, 0xb6, 0x9d, 0xb0, 0x21, 0xcf, 0x05, 0x7c, 0xad, 0xb2,
		0x20, 0x1b, 0x3b, 0x07, 0xc0, 0xd7, 0x88, 0xa6, 0x92, 0xf6, 0xea, 0xd6, 0xa0, 0x6b, 0xa0, 0x6b,
		0x2a, 0xa6, 0xd5, 0xd0, 0x13, 0x32, 0x61, 0xbe, 0x35, 0x2b, 0x3d, 0xa6, 0x8f, 0xb5, 0xad, 0x76,
		0x0c, 0x3a, 0x05, 0x3a, 0x05, 0x3a, 0x05, 0x3a, 0x05, 0x3a, 0x35, 0x5b, 0x6d, 0x5e, 0xa4, 0xc9,
		0x36, 0x2e, 0xdb, 0xc7, 0xe6, 0xb9, 0x86, 0xbe, 0x66, 0xef, 0x72, 0xef, 0x38, 0xd5, 0x62, 0xe4,
		0x86, 0x1d, 0x8d, 0x63, 0xb7, 0x36, 0x86, 0x67, 0x7a, 0x8b, 0x7f, 0x4b, 0x2e, 0x02, 0xed, 0x07,
		0x49, 0xd5, 0xff, 0xf3, 0xfc, 0xf9, 0xe7, 0x86, 0x75, 0xde, 0xfb, 0xf9, 0xb9, 0x69, 0x9d, 0xf7,
		0xa6, 0x1f, 0x9b, 0x93, 0xff, 0x4d, 0x3f, 0xb7, 0x3e, 0x37, 0xac, 0xce, 0xfc, 0xf3, 0xc9, 0xe7,
		0x86, 0x75, 0xd2, 0x3b, 0xfa, 0xf2, 0xe5, 0xe5, 0xd1, 0x8f, 0xf6, 0x28, 0xfb, 0x85, 0xff, 0xd2,
		0x57, 0x7c, 0xbf, 0xa7, 0x73, 0xf0, 0xde, 0xdf, 0x5e, 0xff, 0x83, 0x11, 0x34, 0x8a, 0x66, 0x68,
		0x66, 0xf8, 0xe5, 0x98, 0xcf, 0x2e, 0xcc, 0xa7, 0x9e, 0xc5, 0xc7, 0x2c, 0xf7, 0xd2, 0x7a, 0xd3,
		0xfb, 0xd1, 0x7c, 0xd1, 0x19, 0x5d, 0x1c, 0xfd, 0x38, 0x1d, 0xad, 0xfe, 0xf1, 0xe7, 0xa6, 0xaf,
		0x35, 0x5f, 0x9c, 0x8e, 0x2e, 0xb6, 0xfc, 0x4b, 0x77, 0x74, 0xb1, 0x63, 0x1b, 0x27, 0xa3, 0xe7,
		0x6b, 0x5f, 0x1d, 0xff, 0xbd, 0xb5, 0xed, 0x82, 0xce, 0x96, 0x0b, 0xda, 0xdb, 0x2e, 0x68, 0x6f,
		0xb9, 0x60, 0xeb, 0x2d, 0xb5, 0xb6, 0x5c, 0x70, 0x32, 0xfa, 0xb9, 0xf6, 0xfd, 0xe7, 0x9b, 0xbf,
		0xda, 0x1d, 0x1d, 0xfd, 0xdc, 0xf6, 0x6f, 0xa7, 0xa3, 0x9f, 0x17, 0x47, 0x70, 0x26, 0x98, 0xcf,
		0x98, 0xcf, 0x95, 0x76, 0xad, 0xa6, 0x2b, 0x91, 0x8a, 0xb9, 0xb0, 0xd6, 0xe3, 0x6e, 0xf4, 0x1f,
		0x73, 0x53, 0x89, 0xe3, 0x6d, 0xf4, 0x1e, 0x6b, 0x63, 0xb6, 0x76, 0xed, 0x7b, 0xc1, 0x37, 0xcb,
		0x0f, 0x6d, 0x9d, 0xd5, 0x4b, 0x37, 0xf4, 0x0d, 0x05, 0x3b, 0x1b, 0x5e, 0x80, 0x82, 0x4d, 0x38,
		0x39, 0xa0, 0x60, 0x43, 0xc1, 0xde, 0x49, 0x75, 0x85, 0x82, 0x4d, 0xf7, 0x2e, 0xa1, 0x60, 0x43,
		0x82, 0x81, 0xfe, 0x79, 0xf0, 0xa2, 0x03, 0x14, 0xec, 0x2a, 0x3a, 0xbc, 0x72, 0xcd, 0x27, 0x14,
		0x6c, 0x28, 0x7e, 0x50, 0xfc, 0xe0, 0x4c, 0x30, 0x9f, 0x31, 0x9f, 0x4b, 0x70, 0xad, 0xc8, 0xa5,
		0x2d, 0x51, 0x8f, 0x14, 0x61, 0x22, 0xb9, 0xb0, 0x3c, 0x47, 0xbf, 0x1c, 0xb9, 0xe8, 0x1a, 0x6a,
		0x24, 0xd4, 0x48, 0xa8, 0x91, 0x50, 0x23, 0xa1, 0x46, 0x62, 0x7b, 0xa2, 0x79, 0x4c, 0x1a, 0xdb,
		0x13, 0xd5, 0xf7, 0x8b, 0xed, 0x89, 0x7b, 0x3b, 0x95, 0x50, 0x86, 0x1b, 0x94, 0x4a, 0x1f, 0xa5,
		0x32, 0xea, 0x80, 0xfb, 0xcb, 0xe4, 0x7e, 0x0c, 0xd4, 0xb8, 0xa3, 0xd4, 0x6d, 0x6a, 0xa2, 0x7d,
		0xc7, 0x63, 0xac, 0xe9, 0x5e, 0x4c, 0x0e, 0xcf, 0x75, 0x99, 0xcd, 0xe3, 0xd5, 0x3f, 0xcc, 0x7e,
		0x8f, 0x93, 0xbb, 0xb5, 0xef, 0x2c, 0xff, 0x6d, 0xf2, 0xa7, 0xe8, 0xc2, 0x8b, 0x86, 0xdd, 0xd9,
		0xc7, 0x99, 0x7a, 0x3d, 0xfb, 0x76, 0xfa, 0xfb, 0xf1, 0x50, 0x88, 0x68, 0xf2, 0x1f, 0xeb, 0x5e,
		0x84, 0x49, 0x74, 0x1c, 0x4b, 0x26, 0x35, 0x9c, 0xa9, 0x1f, 0xdb, 0xc2, 0x8b, 0xc6, 0xf6, 0x65,
		0xfc, 0xd4, 0x97, 0x8e, 0xe3, 0x8d, 0x3f, 0x33, 0xbf, 0xf6, 0xe9, 0xc3, 0x87, 0x9b, 0x9a, 0xc3,
		0x24, 0xab, 0xb9, 0xa1, 0xa8, 0x5d, 0xdf, 0x0c, 0xbb, 0xb5, 0xc5, 0x83, 0x6a, 0xe2, 0xc0, 0x4d,
		0x70, 0x60, 0x70, 0x60, 0x70, 0x60, 0x70, 0xe0, 0xcc, 0x66, 0xcd, 0xd3, 0x94, 0x42, 0x5b, 0x42,
		0xa2, 0xe4, 0xda, 0x42, 0xd7, 0x9e, 0x30, 0xb9, 0xcd, 0x7b, 0xbc, 0x09, 0xc5, 0xd4, 0x6d, 0x84,
		0xc1, 0xaa, 0xc3, 0x78, 0x51, 0x8b, 0xb9, 0x8c, 0x6b, 0xb2, 0xcf, 0x6b, 0xb3, 0xdb, 0xad, 0x8d,
		0x6f, 0xb7, 0x36, 0xb9, 0xdd, 0x2f, 0x81, 0xde, 0x88, 0xae, 0x66, 0x0e, 0xa1, 0xcd, 0xcd, 0x94,
		0xe1, 0x6e, 0x4a, 0x73, 0x3b, 0x65, 0xb9, 0x9f, 0xd2, 0xdd, 0x50, 0xe9, 0xee, 0xa8, 0x4c, 0xb7,
		0xa4, 0x99, 0x99, 0x6a, 0x5a, 0xaf, 0xda, 0x24, 0xdb, 0xb5, 0xd5, 0xaa, 0x35, 0x91, 0x74, 0x0d,
		0xde, 0x9f, 0x6b, 0xec, 0x53, 0x6b, 0x62, 0xa9, 0x1e, 0xb2, 0xfa, 0x9b, 0x91, 0x2d, 0x25, 0xd1,
		0x74, 0x6d, 0x8c, 0xcf, 0x4a, 0xe8, 0xbb, 0xac, 0x4c, 0x93, 0xf4, 0x06, 0xf6, 0x35, 0x7d, 0x31,
		0x15, 0xd4, 0xca, 0x18, 0xd4, 0x32, 0x73, 0x88, 0x0e, 0x67, 0x64, 0xb5, 0xf6, 0x38, 0x7a, 0x71,
		0x40, 0xe6, 0xb8, 0x0b, 0x73, 0x5c, 0xee, 0xa2, 0x45, 0x02, 0xe0, 0x5e, 0x27, 0x00, 0xc2, 0x39,
		0x61, 0x9e, 0x1f, 0xd4, 0x3c, 0xd7, 0xeb, 0xaa, 0x91, 0xc8, 0x5b, 0xa9, 0x1e, 0x4c, 0x8b, 0x3a,
		0xf7, 0x54, 0x45, 0x9d, 0x83, 0x20, 0x94, 0x6c, 0x26, 0x41, 0xab, 0x03, 0x78, 0xf5, 0xd8, 0xee,
		0xf3, 0x01, 0x8b, 0x98, 0xec, 0x4f, 0xc3, 0xc3, 0x11, 0x0f, 0xec, 0x89, 0xae, 0x6b, 0x2d, 0xc5,
		0x7f, 0x37, 0x7d, 0x3c, 0x7e, 0x1a, 0x22, 0x7e, 0x12, 0x1c, 0x9e, 0x84, 0x85, 0x17, 0x01, 0xe1,
		0x5f, 0x87, 0x82, 0x9f, 0x99, 0x31, 0xd8, 0x0a, 0x30, 0xbd, 0xc6, 0xfc, 0x6f, 0xed, 0x79, 0xdf,
		0x8a, 0x83, 0x11, 0xca, 0x83, 0x0f, 0x3a, 0x82, 0x0d, 0xda, 0x82, 0x0b, 0xba, 0x82, 0x09, 0xda,
		0x83, 0x07, 0xda, 0x83, 0x05, 0x3a, 0x83, 0x03, 0x66, 0xa5, 0x49, 0x29, 0x17, 0xfb, 0xd3, 0xd5,
		0xe2, 0x73, 0xe6, 0x0a, 0xee, 0xaa, 0x5c, 0x2f, 0x73, 0x59, 0xe1, 0x54, 0x61, 0x1f, 0x37, 0x33,
		0x9f, 0xfb, 0xf2, 0xe5, 0xd4, 0x11, 0x1e, 0xaf, 0x9b, 0x66, 0x53, 0x5c, 0xe3, 0xb3, 0x0a, 0x4f,
		0xd0, 0xb1, 0x4d, 0xd2, 0xe1, 0xf8, 0xd4, 0x16, 0x39, 0x53, 0x5f, 0xd4, 0xac, 0x94, 0x22, 0x66,
		0x6a, 0x8b, 0x96, 0x51, 0xcf, 0x24, 0xc5, 0x98, 0xbc, 0x4c, 0x2c, 0xae, 0xc0, 0x98, 0xd6, 0x63,
		0x29, 0x12, 0x5b, 0x06, 0x33, 0xab, 0x7d, 0x3d, 0xbf, 0xa3, 0xaf, 0xb7, 0x4b, 0xb7, 0xf7, 0xf5,
		0x3a, 0x1a, 0x76, 0xbf, 0x5e, 0x4e, 0x6f, 0xea, 0xeb, 0x27, 0x21, 0xa2, 0x3f, 0x27, 0xb7, 0xf3,
		0xac, 0x9a, 0xf6, 0x89, 0xa6, 0x25, 0xa2, 0x79, 0xa9, 0x6a, 0x3e, 0x6a, 0x9f, 0x87, 0x34, 0xa3,
		0x5d, 0x7c, 0x6c, 0x8a, 0xb5, 0x50, 0x70, 0x54, 0xe7, 0x7e, 0xaa, 0x30, 0x11, 0xa0, 0x75, 0x44,
		0xf4, 0x8e, 0x47, 0x8b, 0xa3, 0xa1, 0x75, 0x2c, 0x45, 0x87, 0x96, 0x76, 0x0b, 0x01, 0xcd, 0x4a,
		0x2f, 0x6f, 0x4b, 0x00, 0x91, 0xaf, 0xf9, 0x45, 0x92, 0xff, 0xf5, 0x4d, 0x6d, 0xdc, 0x57, 0xcd,
		0x65, 0x03, 0xcf, 0x7f, 0xac, 0x4d, 0x8d, 0x57, 0x22, 0x26, 0xa6, 0xb2, 0xe6, 0x86, 0xe2, 0x4b,
		0x40, 0x9e, 0xf3, 0x4f, 0x9c, 0xdb, 0x4f, 0xae, 0x6f, 0xa8, 0xd0, 0x33, 0x94, 0xe9, 0x17, 0xaa,
		0xf4, 0x0a, 0xe5, 0xfa, 0x84, 0x72, 0x3d, 0x42, 0xa5, 0xfe, 0x50, 0x2d, 0x70, 0x43, 0x9d, 0xeb,
		0x5e, 0x9f, 0x20, 0x0d, 0xf2, 0x19, 0x95, 0xea, 0xaa, 0xe3, 0xd6, 0x89, 0xc7, 0x7a, 0xc5, 0xc0,
		0xbd, 0x0e, 0x6c, 0x3f, 0x8c, 0xbd, 0xe0, 0x7e, 0x6c, 0xd0, 0x24, 0xf3, 0x02, 0x2e, 0x26, 0x9b,
		0x98, 0x26, 0xb9, 0xe9, 0x13, 0x14, 0x1f, 0xd7, 0xfa, 0x2c, 0x70, 0x7c, 0xee, 0xd4, 0xee, 0x1e,
		0x6b, 0xb2, 0xef, 0xc5, 0x5f, 0x82, 0xeb, 0x9b, 0x45, 0xba, 0x3a, 0xf5, 0xfd, 0xa9, 0xd9, 0xce,
		0xa4, 0x4c, 0xda, 0x55, 0x29, 0xe9, 0x2a, 0x97, 0x72, 0x55, 0x4b, 0xb8, 0xda, 0xa4, 0x5b, 0x6d,
		0x92, 0xad, 0x0e, 0xa9, 0x76, 0xb4, 0xdf, 0x3c, 0xb5, 0x64, 0x46, 0xd5, 0x2b, 0x0a, 0xbb, 0x69,
		0xf9, 0xb1, 0x4e, 0x5e, 0x4c, 0xb0, 0xf8, 0xb2, 0xeb, 0x2f, 0xc5, 0xd6, 0x47, 0xfe, 0xb1, 0xce,
		0x77, 0x65, 0x4e, 0xa0, 0x41, 0x35, 0x2b, 0x74, 0xcc, 0x86, 0x7c, 0x03, 0x92, 0xfd, 0x75, 0xe6,
		0x78, 0x95, 0x75, 0x96, 0xc8, 0x70, 0xfc, 0xbc, 0xb9, 0x5f, 0x62, 0xea, 0x32, 0xd3, 0x96, 0x72,
		0x0e, 0x68, 0x31, 0x18, 0x52, 0x18, 0x6e, 0x50, 0xc0, 0x8a, 0xa7, 0xf0, 0xc1, 0xe2, 0x0f, 0xb2,
		0x80, 0x01, 0xa0, 0x82, 0x0a, 0xe4, 0x90, 0x80, 0xdc, 0xf5, 0xaf, 0xbb, 0xf8, 0xc9, 0xab, 0x33,
		0xc4, 0x10, 0x15, 0x65, 0x38, 0x75, 0x7b, 0x3e, 0x73, 0x0b, 0x8e, 0xf3, 0x7c, 0xf2, 0xcd, 0xda,
		0x2b, 0xaa, 0x63, 0x92, 0xb0, 0x02, 0x32, 0x16, 0x40, 0x89, 0xfa, 0x49, 0x97, 0xa9, 0x2a, 0x64,
		0xaf, 0x0c, 0xc9, 0x2b, 0x43, 0xee, 0xd4, 0xcb, 0x98, 0x06, 0x7d, 0x16, 0x15, 0x7d, 0xa9, 0x04,
		0x8c, 0xba, 0x2d, 0x38, 0x93, 0xdc, 0xba, 0xf7, 0xc3, 0xbb, 0xc5, 0xf1, 0xf7, 0x9c, 0xee, 0xe4,
		0xfd, 0xc5, 0xfa, 0xdf, 0xd2, 0x11, 0x99, 0x5e, 0xeb, 0xb2, 0xc4, 0x9f, 0x0c, 0xf2, 0x78, 0xee,
		0x10, 0x0b, 0xaf, 0x8d, 0x83, 0x15, 0x5e, 0x89, 0xec, 0x90, 0x6a, 0xa5, 0x61, 0x1f, 0xc5, 0x57,
		0x1a, 0x3b, 0x45, 0xcc, 0xda, 0x89, 0xe6, 0x2d, 0x79, 0x42, 0x57, 0x3a, 0x6b, 0xef, 0xc2, 0xd0,
		0xe7, 0x2c, 0xa0, 0x9c, 0xb3, 0x73, 0xd0, 0xd1, 0xac, 0x8a, 0xf0, 0xf1, 0x82, 0xcc, 0xee, 0x4b,
		0x3e, 0x88, 0x42, 0xc1, 0xc4, 0xa3, 0x06, 0xd3, 0xbf, 0xa9, 0x2f, 0x7a, 0xeb, 0xef, 0x32, 0x3f,
		0x86, 0xf9, 0x87, 0xf9, 0x87, 0xf9, 0x87, 0xf9, 0x87, 0xf9, 0xdf, 0xf6, 0x4c, 0x0b, 0x5b, 0x3c,
		0x5e, 0x2e, 0x5c, 0x08, 0xee, 0x58, 0xbe, 0xe7, 0x72, 0xe9, 0x0d, 0x38, 0xbd, 0x03, 0xf8, 0x65,
		0x6f, 0xf4, 0x2e, 0xe0, 0xac, 0xdb, 0x69, 0x34, 0xe0, 0x02, 0xe0, 0x02, 0xe0, 0x02, 0x0e, 0xd1,
		0x05, 0x24, 0x5e, 0x20, 0xdb, 0x2d, 0x05, 0x1e, 0x80, 0x70, 0xc3, 0x86, 0xa2, 0x5a, 0xf9, 0x6a,
		0xf6, 0x06, 0x28, 0xcc, 0x0b, 0x50, 0xbb, 0x8f, 0x6f, 0x5e, 0x80, 0x5c, 0x55, 0xfb, 0x1a, 0xca,
		0x8c, 0x8f, 0xd4, 0x6c, 0xc6, 0x30, 0x7e, 0x48, 0x3b, 0xad, 0xf3, 0xce, 0x79, 0xf7, 0xb4, 0x75,
		0x7e, 0x62, 0xf0, 0xd8, 0x56, 0x34, 0xc1, 0xa3, 0xb7, 0x97, 0x40, 0x77, 0xc8, 0x7c, 0x4f, 0x0f,
		0xc8, 0x5d, 0xe9, 0x89, 0x1e, 0xe0, 0x76, 0x1b, 0x9d, 0x33, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c,
		0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x13, 0x11, 0x6e, 0xb9,
		0x3b, 0x07, 0xcd, 0x49, 0x61, 0x9e, 0x65, 0x71, 0x1e, 0xcf, 0xb2, 0xc8, 0xca, 0xca, 0x25, 0x2e,
		0x90, 0x37, 0x39, 0xad, 0x47, 0x45, 0x96, 0x4e, 0x47, 0x71, 0xd2, 0x11, 0x79, 0x36, 0x5d, 0x0b,
		0xd9, 0x74, 0xd5, 0x40, 0xf4, 0xc8, 0xa6, 0xcb, 0x46, 0xad, 0x91, 0x4d, 0xb7, 0x55, 0x6b, 0x40,
		0x36, 0x1d, 0x94, 0x06, 0x28, 0x0d, 0x87, 0xaa, 0x34, 0x20, 0x9d, 0x22, 0x8b, 0xdd, 0x47, 0x36,
		0x1d, 0xcc, 0x3f, 0xcc, 0x3f, 0xcc, 0x3f, 0xcc, 0xff, 0x61, 0x99, 0x7f, 0x64, 0xd3, 0xc1, 0x05,
		0xc0, 0x05, 0xc0, 0x05, 0xec, 0xa3, 0x0b, 0x40, 0xac, 0x91, 0x72, 0x52, 0x22, 0xd6, 0xb8, 0xbd,
		0x7d, 0xc4, 0x1a, 0x4b, 0x1b, 0x52, 0xc4, 0x1a, 0xd5, 0xb5, 0x86, 0x6c, 0xba, 0x62, 0x20, 0x17,
		0xd9, 0x74, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8,
		0x40, 0xb8, 0x40, 0xb8, 0x2a, 0x5a, 0x38, 0xc0, 0x6c, 0x3a, 0x82, 0x33, 0x12, 0x51, 0x98, 0x93,
		0x7a, 0x54, 0xea, 0x85, 0x92, 0x0c, 0x77, 0xae, 0xca, 0x3a, 0xef, 0xad, 0xc2, 0x55, 0x40, 0x0b,
		0x96, 0x20, 0xa4, 0x29, 0x3d, 0xb8, 0x7f, 0x15, 0x40, 0x51, 0xfd, 0x33, 0x17, 0xb9, 0x3a, 0x98,
		0xca, 0x9f, 0x4e, 0xdf, 0x8e, 0x2c, 0xdb, 0xf7, 0xa6, 0x0f, 0x4f, 0x94, 0xaf, 0xbc, 0xdc, 0x68,
		0xd1, 0x6c, 0x4d, 0xda, 0xf4, 0x14, 0x22, 0x04, 0x6a, 0x40, 0x4d, 0x51, 0x64, 0x40, 0x2b, 0x51,
		0x5d, 0x4c, 0xcf, 0x7e, 0x26, 0x53, 0x56, 0x14, 0xa4, 0x8d, 0x10, 0xa5, 0x8b, 0x94, 0xb3, 0xe5,
		0xc3, 0x49, 0xa2, 0x49, 0x72, 0x9e, 0xe5, 0x70, 0xc9, 0x6d, 0x69, 0x49, 0xc1, 0x82, 0x78, 0x30,
		0x65, 0x87, 0x54, 0x66, 0x75, 0x6b, 0x17, 0x74, 0x46, 0xb6, 0x09, 0x03, 0x0b, 0x03, 0x0b, 0x03,
		0x5b, 0x25, 0x03, 0x4b, 0x26, 0x59, 0x13, 0x4a, 0xd5, 0xc4, 0x12, 0x35, 0xa1, 0xd0, 0xaf, 0x42,
		0x92, 0x56, 0xa4, 0x5b, 0xaa, 0x92, 0xa0, 0x55, 0xca, 0x93, 0x84, 0x92, 0xb3, 0x12, 0xa9, 0x59,
		0xf5, 0x50, 0xa9, 0x92, 0x96, 0x95, 0x8e, 0x59, 0x45, 0x24, 0xdb, 0x9e, 0x81, 0xb0, 0x8e, 0x07,
		0xec, 0xce, 0x9f, 0x1c, 0xb7, 0x4a, 0x04, 0xe2, 0xe6, 0x0d, 0xd2, 0x41, 0x36, 0x82, 0x4d, 0x7b,
		0x40, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0xa0, 0xc5, 0xf4, 0xf6, 0x73, 0x20, 0x13, 0x3a, 0xdb, 0x39,
		0x6e, 0x0c, 0x86, 0x0e, 0x86, 0x0e, 0x86, 0x0e, 0xf4, 0x14, 0xf4, 0x54, 0x1b, 0xe7, 0x69, 0xb6,
		0xce, 0xc0, 0x50, 0xc9, 0x47, 0xab, 0x0d, 0x31, 0xe1, 0xe0, 0x89, 0x29, 0xb2, 0x62, 0x9e, 0x64,
		0xc5, 0x14, 0x29, 0xf8, 0xa5, 0x27, 0x4b, 0x25, 0xe0, 0xde, 0x7d, 0xff, 0x2e, 0x14, 0x71, 0xf1,
		0x44, 0x95, 0x45, 0x53, 0xc8, 0x55, 0x41, 0xae, 0x4a, 0x29, 0x90, 0xd4, 0xb0, 0x5c, 0x95, 0xf9,
		0x8a, 0xa1, 0x23, 0x94, 0x69, 0x8b, 0x38, 0xa9, 0x16, 0xac, 0x12, 0xac, 0x32, 0xf7, 0x03, 0xd1,
		0xd5, 0xd4, 0xa3, 0x39, 0x88, 0x7a, 0x6d, 0xf2, 0x92, 0x1c, 0x48, 0x4d, 0xbc, 0xdc, 0xc9, 0x97,
		0xbd, 0x8a, 0xe5, 0xaf, 0xcc, 0x0c, 0xa8, 0x32, 0x07, 0xca, 0xcd, 0x82, 0x72, 0xf3, 0xa0, 0xd2,
		0x4c, 0x10, 0x33, 0x2f, 0xaa, 0xfd, 0xb9, 0x44, 0xe6, 0x23, 0x6d, 0xd0, 0x8b, 0xe8, 0xe7, 0xd3,
		0x7c, 0x01, 0x90, 0xce, 0x7e, 0x95, 0xf2, 0x0d, 0xb5, 0x59, 0x51, 0x69, 0x5e, 0x94, 0x9b, 0x19,
		0xd5, 0xe6, 0x46, 0x9b, 0xd9, 0xd1, 0x66, 0x7e, 0x74, 0x98, 0x21, 0x5a, 0x73, 0xa4, 0x40, 0x01,
		0xac, 0x29, 0xd9, 0x8d, 0xbc, 0xc1, 0xa6, 0x0c, 0xbb, 0xf3, 0xd2, 0x8e, 0x2a, 0x26, 0xfd, 0x1c,
		0xb0, 0x9c, 0x29, 0x68, 0xfb, 0x86, 0x49, 0xc9, 0x45, 0x40, 0xbe, 0x5d, 0x39, 0xed, 0xe0, 0x3f,
		0xcf, 0x9f, 0x7f, 0x6e, 0x58, 0xe7, 0xcc, 0x72, 0x2f, 0xad, 0x37, 0xbd, 0x1f, 0xcd, 0x17, 0x9d,
		0xd1, 0xc5, 0xd1, 0x8f, 0xd3, 0xd1, 0xea, 0x1f, 0x7f, 0x6e, 0xfa, 0x5a, 0xf3, 0xc5, 0xe9, 0xe8,
		0x62, 0xcb, 0xbf, 0x74, 0x47, 0x17, 0x3b, 0xb6, 0x71, 0x32, 0x7a, 0xbe, 0xf6, 0xd5, 0xf1, 0xdf,
		0x5b, 0xdb, 0x2e, 0xe8, 0x6c, 0xb9, 0xa0, 0xbd, 0xed, 0x82, 0xf6, 0x96, 0x0b, 0xb6, 0xde, 0x52,
		0x6b, 0xcb, 0x05, 0x27, 0xa3, 0x9f, 0x6b, 0xdf, 0x7f, 0xbe, 0xf9, 0xab, 0xdd, 0xd1, 0xd1, 0xcf,
		0x6d, 0xff, 0x76, 0x3a, 0xfa, 0x79, 0x71, 0x74, 0xf4, 0x2f, 0xfa, 0xa5, 0xde, 0x53, 0x31, 0x05,
		0xdf, 0xdf, 0x5e, 0xff, 0x83, 0x79, 0x88, 0x79, 0x98, 0x65, 0x1e, 0x56, 0x74, 0x7f, 0x35, 0x65,
		0xf8, 0xca, 0xf7, 0x82, 0x6f, 0x96, 0xcf, 0x1e, 0xb9, 0x48, 0x9d, 0x8b, 0x32, 0x58, 0xbc, 0xa1,
		0x2f, 0xc0, 0x64, 0xc0, 0x64, 0xc0, 0x64, 0xc0, 0x64, 0xb2, 0xd9, 0x1e, 0xf5, 0x1f, 0x63, 0xc0,
		0xe4, 0xad, 0xf0, 0x64, 0xd9, 0x7f, 0xae, 0xba, 0xe5, 0xd6, 0xe8, 0xe8, 0xbf, 0x8e, 0xfe, 0x07,
		0x78, 0xae, 0x02, 0x2f, 0xac, 0xaa, 0xc0, 0xa3, 0x52, 0x92, 0x20, 0x71, 0x81, 0x95, 0xb4, 0x5d,
		0x75, 0xc9, 0x0b, 0x69, 0x3c, 0x3f, 0xfd, 0x44, 0x72, 0x80, 0x19, 0xdd, 0xf0, 0x50, 0xd4, 0x84,
		0x24, 0x14, 0x56, 0xe9, 0x05, 0x55, 0x94, 0x63, 0x44, 0x5c, 0x06, 0x71, 0x19, 0x23, 0xca, 0x30,
		0xfa, 0x9c, 0xb9, 0x82, 0xbb, 0x2a, 0xce, 0x9a, 0xa0, 0x2c, 0xc4, 0x78, 0x33, 0xf3, 0x13, 0x2f,
		0x5f, 0x4e, 0xcb, 0x67, 0x1d, 0x53, 0x8d, 0x75, 0x35, 0xac, 0x39, 0xcd, 0x31, 0x95, 0x6b, 0x83,
		0x4b, 0x71, 0x5c, 0xe5, 0xda, 0xb0, 0x52, 0xdb, 0xf4, 0x16, 0x6c, 0x3a, 0x6c, 0xfa, 0x01, 0xda,
		0x74, 0xc4, 0xda, 0x21, 0x22, 0x2a, 0x36, 0x33, 0xaa, 0xcd, 0x8d, 0x36, 0xb3, 0xa3, 0xcd, 0xfc,
		0xe8, 0x30, 0x43, 0xf4, 0x8a, 0x41, 0x0d, 0xb1, 0xf6, 0x5f, 0x00, 0x16, 0xc4, 0xda, 0x11, 0xe3,
		0x44, 0xac, 0x1d, 0xf3, 0x10, 0xf3, 0xf0, 0x20, 0x62, 0xed, 0x5e, 0x6c, 0x89, 0x30, 0x91, 0x5c,
		0x28, 0x44, 0xc3, 0x69, 0x17, 0x00, 0xc5, 0x00, 0xc5, 0x00, 0xc5, 0x00, 0xc5, 0x64, 0xb3, 0x9d,
		0xfe, 0xec, 0xdf, 0x35, 0x3c, 0xdc, 0x44, 0xc2, 0x15, 0xe9, 0x90, 0x21, 0xe1, 0x0a, 0x6e, 0x01,
		0x6e, 0x01, 0x6e, 0x01, 0x09, 0x57, 0xa5, 0x69, 0x25, 0x48, 0xb8, 0x32, 0xe2, 0x85, 0x1d, 0x00,
		0xf0, 0x98, 0xa7, 0x1c, 0x59, 0xb4, 0x21, 0xdd, 0x35, 0x83, 0xb0, 0xd2, 0x0f, 0x00, 0x07, 0x00,
		0x07, 0x00, 0x07, 0x00, 0x07, 0xd9, 0x6c, 0xe7, 0x41, 0x32, 0xe0, 0x62, 0x9a, 0xf7, 0xa9, 0x10,
		0x6f, 0x74, 0x14, 0xb4, 0xfd, 0x3a, 0x48, 0x06, 0xe3, 0x97, 0x33, 0x3a, 0x00, 0x77, 0x13, 0x0a,
		0xef, 0x5e, 0x45, 0x21, 0xc3, 0xd4, 0xe8, 0x4d, 0xdb, 0x87, 0x7b, 0x81, 0x7b, 0x81, 0x7b, 0x81,
		0x7b, 0xa1, 0x87, 0xaf, 0x4a, 0x0c, 0x0c, 0x5c, 0x0c, 0xb6, 0x90, 0x50, 0x6f, 0x21, 0x21, 0x38,
		0xb5, 0x97, 0x6e, 0x74, 0xca, 0x2d, 0x32, 0xf6, 0xff, 0xf1, 0x47, 0x92, 0x9c, 0xc0, 0xfa, 0x5b,
		0x2f, 0x96, 0x97, 0x52, 0x12, 0x95, 0x2c, 0x7b, 0xe7, 0x05, 0xaf, 0x7d, 0x3e, 0x36, 0xdc, 0x31,
		0x0d, 0x06, 0xa8, 0xbf, 0x63, 0x0f, 0x4b, 0x2d, 0x36, 0xcf, 0x3a, 0x9d, 0xee, 0x69, 0xa7, 0xd3,
		0x38, 0x6d, 0x9f, 0x36, 0xce, 0x4f, 0x4e, 0x9a, 0xdd, 0x26, 0xc1, 0xd9, 0x33, 0xf5, 0xf7, 0xc2,
		0xe1, 0x82, 0x3b, 0x7f, 0x8c, 0xdf, 0x69, 0x90, 0xf8, 0x3e, 0x8e, 0xd3, 0xce, 0xb9, 0x44, 0xeb,
		0x24, 0x89, 0xf8, 0xbb, 0x1e, 0xe5, 0xfc, 0xd7, 0xbc, 0x57, 0x94, 0x2c, 0xae, 0xd6, 0x7c, 0xa8,
		0x72, 0xd5, 0xe2, 0x69, 0xd6, 0x88, 0xc5, 0x9c, 0x21, 0x17, 0xd2, 0x8b, 0xf9, 0xa0, 0xc8, 0x69,
		0xbf, 0x29, 0x98, 0xda, 0xd8, 0x2a, 0x6a, 0x19, 0xa3, 0x96, 0x71, 0x29, 0x94, 0xc7, 0xb0, 0x5a,
		0xc6, 0x44, 0x85, 0x4e, 0x69, 0x0b, 0x9c, 0xa2, 0x8e, 0x71, 0x89, 0x0a, 0x07, 0xea, 0x18, 0xd7,
		0xf6, 0xa7, 0x8e, 0xf1, 0x04, 0x25, 0x0c, 0x99, 0xaf, 0x60, 0xb7, 0xfc, 0xbc, 0x65, 0xec, 0x99,
		0xaf, 0x9c, 0xf8, 0x89, 0xfd, 0x95, 0x65, 0x88, 0x9b, 0x87, 0xb2, 0x67, 0x9e, 0xec, 0xa0, 0xad,
		0xd5, 0xb5, 0x4f, 0xb9, 0x63, 0x9e, 0xf6, 0xe0, 0xad, 0xf9, 0x8f, 0x02, 0x49, 0x58, 0xc5, 0x41,
		0x5c, 0x8a, 0x8c, 0xea, 0x5a, 0xf3, 0x8a, 0x8e, 0x7a, 0x4a, 0xdb, 0x57, 0x78, 0xe4, 0x13, 0xf1,
		0x72, 0x5b, 0xd5, 0xcd, 0x8c, 0x1f, 0x52, 0x55, 0xe7, 0x4b, 0x6b, 0x1d, 0xdb, 0x8a, 0x86, 0x27,
		0x7a, 0x7b, 0x54, 0xba, 0xc3, 0xf7, 0x5c, 0x2e, 0xbd, 0x81, 0x82, 0xea, 0x1d, 0x69, 0xcb, 0x00,
		0x98, 0x00, 0x98, 0x00, 0x98, 0x00, 0x98, 0x00, 0x98, 0x00, 0x98, 0x00, 0x98, 0x00, 0x98, 0x00,
		0x98, 0x87, 0x04, 0x30, 0xe3, 0x24, 0x8a, 0x48, 0x37, 0x30, 0x2e, 0xca, 0xc3, 0xcd, 0x5b, 0xa6,
		0xaa, 0x68, 0xc5, 0x5d, 0x96, 0xf8, 0x13, 0xc7, 0xef, 0x32, 0x3f, 0x06, 0x70, 0x05, 0x70, 0x05,
		0x70, 0x3d, 0x28, 0xe0, 0x4a, 0xbf, 0x7b, 0x9d, 0x78, 0xd7, 0xba, 0xe9, 0xa9, 0x77, 0xe6, 0xe4,
		0x67, 0x6d, 0x4a, 0x4a, 0x21, 0xa9, 0xc3, 0x5d, 0x20, 0x65, 0xaa, 0x40, 0x2a, 0x08, 0xcd, 0x76,
		0x3e, 0xd2, 0xca, 0xac, 0xe4, 0x49, 0x02, 0x2d, 0x24, 0x09, 0x94, 0xef, 0xef, 0x90, 0x24, 0xb0,
		0x3b, 0xde, 0x44, 0x92, 0x00, 0xa0, 0x30, 0xa0, 0x30, 0xa0, 0x70, 0x15, 0xa1, 0x30, 0x34, 0x5c,
		0x52, 0xc1, 0x0f, 0x1a, 0x6e, 0xa9, 0x3a, 0x1f, 0x34, 0xdc, 0x8d, 0x43, 0x0a, 0x0d, 0x57, 0x5d,
		0x6b, 0x48, 0x12, 0xd8, 0xc5, 0xcd, 0x20, 0x49, 0x00, 0x00, 0x13, 0x00, 0x13, 0x00, 0x13, 0x00,
		0x13, 0x00, 0x13, 0x00, 0x13, 0x00, 0x13, 0x00, 0xf3, 0x20, 0x01, 0x26, 0x92, 0x04, 0x00, 0x5c,
		0x01, 0x5c, 0x01, 0x5c, 0x91, 0x24, 0x50, 0x0d, 0x93, 0x8e, 0x24, 0x81, 0xfc, 0x49, 0x02, 0x04,
		0x95, 0x96, 0x50, 0x56, 0x45, 0xe5, 0x08, 0xd5, 0x0b, 0xe5, 0x51, 0xec, 0x5a, 0x60, 0xe7, 0xc3,
		0xa4, 0xe7, 0xcb, 0x27, 0x1d, 0x57, 0xb8, 0xb4, 0x4b, 0xb1, 0x04, 0x11, 0x92, 0xc4, 0x10, 0xb2,
		0xe2, 0x2d, 0x2d, 0x14, 0x6f, 0x51, 0x87, 0x59, 0x50, 0xbc, 0x65, 0xc1, 0x05, 0x8a, 0x17, 0x6f,
		0x49, 0xc6, 0x46, 0x23, 0xa6, 0x2c, 0xdf, 0x32, 0x6b, 0x11, 0x05, 0x5c, 0xb4, 0xd1, 0x0e, 0xe4,
		0x66, 0x21, 0x37, 0x6b, 0x6b, 0x43, 0x5e, 0x60, 0x39, 0x5e, 0x6c, 0x33, 0xe1, 0x70, 0xc7, 0x8a,
		0xbe, 0xc9, 0x58, 0x45, 0x92, 0xd6, 0x6a, 0x17, 0xd0, 0x24, 0xa0, 0x49, 0x40, 0x93, 0x38, 0x20,
		0x4d, 0x62, 0xe6, 0xf6, 0xbb, 0x1d, 0x05, 0xaa, 0xc4, 0x19, 0xe2, 0x69, 0xc4, 0x8d, 0x23, 0x9e,
		0xa6, 0x69, 0xc5, 0x3d, 0x1d, 0xd2, 0x3d, 0x88, 0xa7, 0xa9, 0xa9, 0xe1, 0x5c, 0xda, 0x28, 0x23,
		0xb2, 0xa6, 0x7a, 0x15, 0x8c, 0xc1, 0x21, 0x17, 0x22, 0x14, 0xea, 0xb0, 0xe7, 0x52, 0xf3, 0xc0,
		0x9d, 0xc0, 0x9d, 0xc0, 0x9d, 0xc0, 0x9d, 0xc0, 0x9d, 0xc0, 0x9d, 0xc0, 0x9d, 0xc0, 0x9d, 0xc0,
		0x9d, 0x87, 0x8c, 0x3b, 0xdd, 0x50, 0x7c, 0x9f, 0x8a, 0x92, 0xa1, 0x2d, 0xb9, 0x22, 0xf4, 0xb9,
		0xd6, 0x09, 0x30, 0x28, 0x30, 0x28, 0x30, 0x28, 0x30, 0x28, 0x30, 0x28, 0x30, 0x28, 0x30, 0x28,
		0x30, 0x28, 0x30, 0x28, 0x30, 0xa8, 0xd2, 0xd8, 0xfb, 0x4a, 0x17, 0xc0, 0x9f, 0xc0, 0x9f, 0xc0,
		0x9f, 0xc0, 0x9f, 0xc0, 0x9f, 0xc0, 0x9f, 0xc0, 0x9f, 0xc0, 0x9f, 0xc0, 0x9f, 0x87, 0x8c, 0x3f,
		0x15, 0x2a, 0x9f, 0xd0, 0x3b, 0x81, 0x37, 0x81, 0x37, 0x81, 0x37, 0x81, 0x37, 0x81, 0x37, 0x81,
		0x37, 0x81, 0x37, 0x81, 0x37, 0x81, 0x37, 0xd5, 0xa9, 0x9c, 0xd0, 0x36, 0x81, 0x35, 0x81, 0x35,
		0x81, 0x35, 0x81, 0x35, 0x81, 0x35, 0x81, 0x35, 0x81, 0x35, 0x81, 0x35, 0x0f, 0x1b, 0x6b, 0x86,
		0x89, 0x54, 0xbe, 0xb1, 0x7d, 0x43, 0x1f, 0x40, 0xa0, 0x40, 0xa0, 0x40, 0xa0, 0x40, 0xa0, 0x40,
		0xa0, 0x40, 0xa0, 0x40, 0xa0, 0x40, 0xa0, 0x40, 0xa0, 0x07, 0x8d, 0x40, 0x55, 0x6e, 0x6d, 0x5f,
		0x69, 0x1f, 0xc8, 0x13, 0xc8, 0x13, 0xc8, 0x13, 0xc8, 0x13, 0xc8, 0x13, 0xc8, 0x13, 0xc8, 0x13,
		0xc8, 0x13, 0xc8, 0xf3, 0xa0, 0x91, 0xa7, 0xfa, 0xcd, 0xed, 0x1b, 0x7b, 0x01, 0x0a, 0x05, 0x0a,
		0x05, 0x0a, 0x05, 0x0a, 0x05, 0x0a, 0x05, 0x0a, 0x05, 0x0a, 0x05, 0x0a, 0x05, 0x0a, 0x05, 0x0a,
		0x55, 0x1c, 0x81, 0xc7, 0xfe, 0x76, 0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0x50,
		0x20, 0x50, 0x20, 0x50, 0x20, 0x50, 0x20, 0xd0, 0x05, 0x02, 0x55, 0xa9, 0x7e, 0x42, 0xf3, 0x04,
		0xe2, 0x04, 0xe2, 0x04, 0xe2, 0x04, 0xe2, 0x04, 0xe2, 0x04, 0xe2, 0x04, 0xe2, 0x04, 0xe2, 0x04,
		0xe2, 0x94, 0x0a, 0x95, 0x4e, 0xe8, 0x9b, 0x40, 0x9b, 0x40, 0x9b, 0x40, 0x9b, 0x40, 0x9b, 0x40,
		0x9b, 0x40, 0x9b, 0x40, 0x9b, 0x40, 0x9b, 0x06, 0xa3, 0xcd, 0x52, 0x8f, 0x8f, 0xbf, 0x0c, 0x82,
		0x50, 0xb2, 0xf1, 0x14, 0xa0, 0x39, 0x45, 0x3e, 0xb6, 0xfb, 0x7c, 0xc0, 0x22, 0x26, 0xfb, 0x63,
		0x8f, 0x75, 0x1c, 0x46, 0x3c, 0xb0, 0x27, 0x88, 0xd0, 0xf2, 0xc6, 0xbe, 0xcb, 0x65, 0x36, 0x8f,
		0x8f, 0x37, 0x7d, 0x3c, 0x8e, 0x93, 0xbb, 0xa5, 0xbf, 0x2f, 0xff, 0x76, 0xec, 0x45, 0xc3, 0xee,
		0x71, 0x2c, 0x99, 0xe4, 0xc7, 0x33, 0x1f, 0x48, 0x81, 0x7e, 0xeb, 0xb1, 0x14, 0x89, 0x2d, 0x83,
		0x99, 0x77, 0xbd, 0x9e, 0x77, 0xf7, 0xf5, 0x76, 0xa9, 0xef, 0xaf, 0xd7, 0xd1, 0xb0, 0xfb, 0xf5,
		0xd5, 0xbc, 0xd7, 0x67, 0xe5, 0x8c, 0x74, 0x81, 0x51, 0xae, 0x3b, 0x7d, 0x3b, 0xb2, 0x6c, 0xdf,
		0x9b, 0x62, 0xaf, 0x62, 0x43, 0x9c, 0x42, 0x91, 0xe5, 0x46, 0x0b, 0xce, 0xc0, 0x2b, 0xee, 0xb2,
		0xc4, 0x9f, 0xe0, 0x42, 0x97, 0xf9, 0x31, 0x2f, 0xda, 0x1e, 0x8d, 0x91, 0x26, 0xe3, 0x31, 0x94,
		0xfc, 0x85, 0x9c, 0xb7, 0x50, 0xf3, 0x15, 0x65, 0x3c, 0x45, 0x19, 0x3f, 0x51, 0xc1, 0x4b, 0xca,
		0xb5, 0xe8, 0x64, 0xfc, 0x23, 0x9d, 0x6d, 0x77, 0x61, 0xe8, 0x73, 0x16, 0x50, 0xcc, 0xb7, 0xd9,
		0xe2, 0x6c, 0x36, 0x4d, 0x34, 0xa4, 0x49, 0x64, 0x31, 0xc7, 0x11, 0x96, 0xc3, 0x25, 0xb7, 0xa5,
		0x25, 0x05, 0x0b, 0xe2, 0x81, 0x47, 0xa0, 0xf1, 0x2c, 0xcc, 0xea, 0xd6, 0x2e, 0xe8, 0x8c, 0x6c,
		0x13, 0x06, 0x16, 0x06, 0x16, 0x06, 0xb6, 0x4a, 0x06, 0x36, 0xf1, 0x02, 0xd9, 0x6e, 0x11, 0xda,
		0xd7, 0x53, 0x82, 0xa6, 0x68, 0x55, 0x1c, 0x42, 0x39, 0x4c, 0x85, 0x6a, 0xa3, 0x88, 0xda, 0xab,
		0x52, 0x69, 0x54, 0xf2, 0x76, 0x42, 0x55, 0x46, 0x89, 0x1a, 0xa3, 0x7a, 0xa8, 0x3a, 0xad, 0xf3,
		0xce, 0x79, 0xf7, 0xb4, 0x75, 0x7e, 0x62, 0xd0, 0x98, 0x55, 0x44, 0xcb, 0xe8, 0x19, 0x08, 0xeb,
		0x78, 0xc0, 0xee, 0x7c, 0xee, 0xd0, 0x81, 0xb8, 0x79, 0x83, 0x74, 0x90, 0x6d, 0xec, 0x8d, 0x81,
		0xda, 0x80, 0xda, 0x80, 0xda, 0x40, 0x8b, 0x2b, 0x67, 0x3f, 0x07, 0x32, 0xa1, 0xb3, 0x9d, 0xe3,
		0xc6, 0x60, 0xe8, 0x60, 0xe8, 0x60, 0xe8, 0x40, 0x4f, 0x41, 0x4f, 0xb5, 0x71, 0x9e, 0x66, 0xeb,
		0x0c, 0x0c, 0x95, 0x7c, 0xb4, 0xda, 0x10, 0x13, 0x0e, 0x9e, 0x98, 0x3e, 0xd3, 0x38, 0xc1, 0xa9,
		0x82, 0xf9, 0xaa, 0x83, 0xf8, 0xf9, 0x3c, 0x6c, 0xf6, 0x57, 0x99, 0xe3, 0x35, 0xd6, 0x93, 0x20,
		0x48, 0x06, 0x77, 0x5c, 0x14, 0x10, 0x04, 0x16, 0x7e, 0x73, 0xd1, 0x56, 0xce, 0x01, 0x9d, 0xf3,
		0x82, 0x9c, 0x97, 0x17, 0xc5, 0xb0, 0x14, 0xd8, 0xf5, 0x09, 0x66, 0x75, 0x0b, 0x80, 0x08, 0x2a,
		0xac, 0x4a, 0x8e, 0x51, 0xc9, 0xb1, 0xe9, 0x1a, 0x26, 0x75, 0xeb, 0x86, 0x18, 0xa0, 0x2b, 0x4f,
		0x14, 0x9b, 0x2c, 0xf6, 0x7c, 0xc6, 0x12, 0xf1, 0xc9, 0x59, 0x7b, 0x34, 0x94, 0xb2, 0xb9, 0xef,
		0x94, 0xd2, 0x05, 0xa5, 0x54, 0x41, 0x29, 0x5d, 0xd3, 0x29, 0x65, 0xd1, 0x65, 0x9d, 0x36, 0x44,
		0xa5, 0xb5, 0xaf, 0xcd, 0x5e, 0x1a, 0xcd, 0x7d, 0xf1, 0xc0, 0xb4, 0x39, 0x69, 0x8a, 0x68, 0x9c,
		0x79, 0x7b, 0x6d, 0x5c, 0xec, 0xb5, 0x29, 0x63, 0xaf, 0x8d, 0x8b, 0xbd, 0x36, 0x59, 0x67, 0x2b,
		0x9d, 0xb8, 0xbf, 0x86, 0x22, 0x9a, 0x48, 0x3c, 0xaf, 0xd5, 0xea, 0xaf, 0x1f, 0x26, 0x52, 0x43,
		0x71, 0xf9, 0x8e, 0x1e, 0x66, 0x84, 0xb6, 0xc5, 0x1f, 0xe4, 0x85, 0xe4, 0x3e, 0x1f, 0x70, 0x29,
		0x1e, 0xad, 0x30, 0xb0, 0xec, 0xfe, 0x44, 0x6f, 0x54, 0x02, 0x3d, 0x26, 0x2e, 0x46, 0x01, 0xf6,
		0x28, 0x1b, 0x76, 0xf4, 0x0e, 0x66, 0x6f, 0xc2, 0x82, 0xe9, 0x1f, 0xcf, 0x18, 0x87, 0x81, 0x81,
		0xbc, 0xf4, 0x99, 0x2c, 0xc1, 0x5d, 0x3a, 0x0a, 0xf6, 0xb4, 0x59, 0x30, 0x31, 0x30, 0x31, 0x30,
		0xb1, 0xf2, 0x99, 0x18, 0x91, 0xd0, 0xa2, 0x46, 0x70, 0x21, 0x5e, 0xee, 0xe0, 0x4b, 0xe0, 0x4b,
		0xe0, 0x4b, 0x94, 0xe6, 0x63, 0x1d, 0x33, 0xd0, 0x4f, 0xab, 0x35, 0xfc, 0x40, 0x3d, 0xad, 0x14,
		0xc5, 0xd4, 0xa9, 0x8d, 0x8c, 0x4a, 0x63, 0xa3, 0xdc, 0xe8, 0xa8, 0x36, 0x3e, 0xda, 0x8c, 0x90,
		0x36, 0x63, 0xa4, 0xc3, 0x28, 0xd1, 0x1a, 0x27, 0x62, 0x23, 0xa5, 0x4e, 0xdc, 0x59, 0x9b, 0xed,
		0x3e, 0x67, 0x6e, 0x71, 0x52, 0xf2, 0x4b, 0xe4, 0x72, 0xaa, 0xa0, 0xed, 0x9b, 0x94, 0xc1, 0x8e,
		0xa7, 0xc5, 0xc5, 0x12, 0x33, 0x5d, 0xf9, 0xc3, 0xec, 0xf7, 0xc9, 0x0e, 0xf7, 0x8a, 0x56, 0x61,
		0xa0, 0xcc, 0xe5, 0x59, 0xe6, 0xe5, 0xea, 0xfc, 0xd1, 0x93, 0x5e, 0xe0, 0x92, 0xe0, 0x92, 0xe0,
		0x92, 0xe0, 0x92, 0xe0, 0x92, 0x76, 0x74, 0x49, 0x9f, 0x17, 0x2e, 0xe9, 0xbf, 0xed, 0x44, 0x08,
		0x1e, 0xc8, 0xe7, 0x47, 0xc7, 0x2f, 0x5f, 0x2e, 0xc4, 0xd6, 0xde, 0xec, 0x92, 0xa7, 0x9a, 0xeb,
		0xfa, 0xdf, 0xd2, 0x96, 0x1d, 0xfe, 0x50, 0x59, 0xef, 0x56, 0x29, 0xf6, 0x47, 0x16, 0x72, 0x99,
		0xff, 0xa8, 0x13, 0x12, 0x94, 0x87, 0x60, 0xb6, 0x18, 0x4f, 0xc2, 0x50, 0xcc, 0x46, 0xab, 0x59,
		0x35, 0x61, 0xa1, 0x47, 0x25, 0xb4, 0xd2, 0x86, 0x6a, 0x16, 0x90, 0x4e, 0x47, 0xc8, 0xe6, 0x49,
		0x84, 0x82, 0x24, 0x80, 0x43, 0x37, 0x48, 0x23, 0x92, 0x3a, 0x57, 0x4c, 0x72, 0x7a, 0xa9, 0x77,
		0xda, 0x6c, 0xc5, 0x95, 0xde, 0x16, 0x94, 0x5e, 0x73, 0x10, 0x2d, 0x94, 0x5e, 0x28, 0xbd, 0xa0,
		0xd5, 0xa0, 0xd5, 0xa0, 0xd5, 0xa0, 0xd5, 0xa0, 0xd5, 0x50, 0x7a, 0xb7, 0x23, 0x5a, 0x28, 0xbd,
		0x70, 0x49, 0x70, 0x49, 0x70, 0x49, 0x70, 0x49, 0x95, 0x75, 0x49, 0x50, 0x7a, 0xcb, 0x63, 0x7f,
		0x7b, 0x24, 0xc7, 0x15, 0xd8, 0x31, 0xae, 0x40, 0x8d, 0x43, 0xad, 0xfe, 0x42, 0xa3, 0xa9, 0xb7,
		0x6a, 0xff, 0xdf, 0xe9, 0x5d, 0x7c, 0x4d, 0xbf, 0xf6, 0x81, 0xbb, 0x26, 0xe6, 0xe6, 0xd3, 0x48,
		0xb8, 0xa4, 0xd2, 0x2d, 0x79, 0x2e, 0x7e, 0x0b, 0xb9, 0xf8, 0xe5, 0x43, 0x4e, 0xe4, 0xe2, 0xef,
		0xfc, 0x40, 0xd8, 0x15, 0x8d, 0x5d, 0xd1, 0x95, 0xe3, 0xbc, 0x88, 0xfd, 0x94, 0xc1, 0x69, 0xb1,
		0x2b, 0xba, 0x30, 0x8a, 0xc0, 0xae, 0x68, 0x63, 0x21, 0x3e, 0x01, 0x45, 0x43, 0x85, 0x35, 0xfa,
		0x71, 0xa9, 0x17, 0xe2, 0x1b, 0xd9, 0x49, 0x96, 0xb6, 0xb2, 0x6e, 0xcf, 0x14, 0x8e, 0x74, 0xfd,
		0x32, 0xb9, 0x1f, 0x3b, 0x89, 0x09, 0x1c, 0xcb, 0x9e, 0x29, 0x57, 0xb0, 0x62, 0xdc, 0xae, 0x71,
		0x9e, 0x9d, 0x14, 0xb3, 0xe8, 0x62, 0x3c, 0x21, 0xf2, 0x96, 0x9e, 0xbb, 0xe2, 0xb1, 0x2d, 0xbc,
		0x68, 0x36, 0xd5, 0xeb, 0x97, 0x8e, 0x13, 0xd7, 0x98, 0xe3, 0x08, 0x1e, 0xc7, 0x35, 0x96, 0xc8,
		0x70, 0x3a, 0x5d, 0x13, 0x31, 0x59, 0x0c, 0x35, 0x19, 0xd6, 0x64, 0x9f, 0xd7, 0xee, 0x58, 0xcc,
		0x6b, 0xd7, 0x37, 0xb5, 0x41, 0xe8, 0x70, 0x1f, 0x45, 0xef, 0x66, 0x15, 0x85, 0x2d, 0xfe, 0x20,
		0x51, 0xf8, 0x2e, 0x0f, 0x44, 0x9b, 0xbe, 0xba, 0x43, 0x29, 0x7e, 0x37, 0x5f, 0x56, 0x74, 0x3a,
		0x4f, 0xda, 0x62, 0xe1, 0xb3, 0x28, 0x9e, 0x18, 0x83, 0x8f, 0x61, 0x64, 0xf9, 0x7c, 0xc8, 0xfd,
		0x9a, 0x1d, 0x06, 0x92, 0x79, 0x01, 0x17, 0x35, 0x37, 0x14, 0xb5, 0xeb, 0x9b, 0x61, 0xb7, 0x46,
		0xd5, 0xe7, 0xa1, 0x94, 0x7a, 0x28, 0x6a, 0x1e, 0x20, 0x31, 0xa9, 0x32, 0x1f, 0x44, 0x94, 0x40,
		0xb7, 0xf9, 0x52, 0x0c, 0xa8, 0x7a, 0x59, 0x01, 0x55, 0x31, 0xc8, 0xac, 0x0e, 0x2a, 0xe7, 0x98,
		0xce, 0xbb, 0xe3, 0xe2, 0x6c, 0xb3, 0x6e, 0xf7, 0x11, 0xc8, 0xe0, 0x9c, 0x72, 0x06, 0x0d, 0x0a,
		0x05, 0x09, 0x72, 0x5a, 0xed, 0xdc, 0x41, 0x80, 0x22, 0x56, 0xb9, 0xb0, 0x06, 0x57, 0xd4, 0xe2,
		0x92, 0x59, 0x58, 0x32, 0x8b, 0x4a, 0xa1, 0x91, 0xa9, 0xa5, 0x67, 0x79, 0x41, 0x56, 0x9d, 0x39,
		0x03, 0x2f, 0xb0, 0xc6, 0x73, 0x3a, 0x89, 0x8b, 0x97, 0xf6, 0x7e, 0xd2, 0x5a, 0x31, 0x9e, 0xd3,
		0x40, 0x71, 0x6f, 0x14, 0xf7, 0x36, 0x81, 0xdf, 0x14, 0x96, 0x95, 0x97, 0xe2, 0x52, 0xc9, 0x80,
		0x4f, 0x95, 0x83, 0x22, 0x73, 0x66, 0xee, 0x6b, 0x3a, 0x05, 0xda, 0x78, 0x1d, 0x24, 0x83, 0xf1,
		0x43, 0xe9, 0x7d, 0x95, 0x85, 0x77, 0x62, 0xd2, 0xad, 0x12, 0x65, 0x3b, 0x2d, 0xe9, 0x77, 0x56,
		0x12, 0xed, 0xa4, 0x2c, 0xa0, 0xd1, 0x93, 0xbf, 0xf6, 0x30, 0x9a, 0xad, 0x03, 0xe6, 0xe3, 0x75,
		0xe3, 0x75, 0x53, 0xbc, 0xee, 0x5c, 0x57, 0xf6, 0xb4, 0x1c, 0xae, 0x62, 0x87, 0xc9, 0x98, 0x24,
		0x11, 0xe0, 0xaf, 0xb4, 0x25, 0x68, 0xcc, 0xc0, 0x5e, 0x07, 0x80, 0xbd, 0x8a, 0x1f, 0xac, 0xc2,
		0x84, 0xf0, 0xb8, 0xb0, 0xa4, 0x60, 0x41, 0xec, 0x8d, 0x4d, 0x60, 0x4c, 0x78, 0xca, 0xca, 0x86,
		0xc6, 0x71, 0x8a, 0xa7, 0xf2, 0x85, 0x4b, 0xbd, 0x80, 0x95, 0x2d, 0x64, 0x65, 0x0b, 0x5a, 0xc5,
		0xc2, 0x2e, 0xb6, 0xc0, 0x09, 0x50, 0x4f, 0x4d, 0xcd, 0x29, 0x9e, 0x33, 0x97, 0xd9, 0xed, 0x10,
		0x1e, 0xe4, 0x79, 0x86, 0x83, 0x3c, 0x4b, 0xb1, 0x6b, 0x6b, 0xcd, 0x9a, 0x78, 0x34, 0xa4, 0x21,
		0xa7, 0x78, 0x2a, 0x3b, 0x73, 0xf5, 0xac, 0xd3, 0xe9, 0x9e, 0x76, 0x3a, 0x8d, 0xd3, 0xf6, 0x69,
		0xe3, 0xfc, 0xe4, 0xa4, 0xd9, 0x6d, 0x9e, 0xe0, 0x60, 0x4f, 0xf5, 0xc4, 0x85, 0xd2, 0x4a, 0xe3,
		0x10, 0x93, 0xfd, 0x3f, 0xc4, 0xa4, 0xa4, 0xb3, 0x38, 0xac, 0x3b, 0x11, 0x32, 0xc7, 0x66, 0xb1,
		0xb4, 0xa2, 0x6f, 0x32, 0xa6, 0x3c, 0x8f, 0x63, 0xb5, 0x69, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75,
		0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0xf5, 0x6a, 0x42, 0xf5, 0xb2, 0x70, 0x98,
		0xe3, 0xc5, 0x36, 0x13, 0x0e, 0x2d, 0x02, 0x4b, 0x1b, 0x05, 0xf6, 0x02, 0xf6, 0x02, 0xf6, 0x02,
		0xf6, 0x02, 0xf6, 0x02, 0xf6, 0x02, 0xf6, 0x02, 0xf6, 0x02, 0xf6, 0x5a, 0xc6, 0x5e, 0x5c, 0x88,
		0x50, 0xd0, 0x22, 0xaf, 0x59, 0x93, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d,
		0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xcb, 0xb8, 0xcb, 0xb5, 0x63, 0x15, 0xd8, 0x6b,
		0xa9, 0x59, 0xe0, 0x2f, 0xe0, 0x2f, 0xe0, 0x2f, 0xe0, 0x2f, 0xe0, 0x2f, 0xe0, 0x2f, 0xe0, 0x2f,
		0xe0, 0x2f, 0xe0, 0xaf, 0x65, 0xfc, 0x35, 0x48, 0x7c, 0xe9, 0xa9, 0xc9, 0xfd, 0x5a, 0x69, 0x1a,
		0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c,
		0x38, 0x6c, 0x19, 0x87, 0x85, 0xff, 0x7f, 0xf6, 0xfe, 0xbc, 0xb7, 0x71, 0x63, 0x69, 0x1b, 0x87,
		0xff, 0xf7, 0xa7, 0x10, 0x84, 0xf3, 0x00, 0xf6, 0xb9, 0x87, 0x63, 0x49, 0x96, 0x57, 0xe0, 0xc6,
		0x81, 0xc6, 0x56, 0x12, 0xbd, 0xc7, 0x1b, 0x6c, 0x27, 0x27, 0x79, 0x3d, 0x8a, 0x40, 0x4b, 0x6d,
		0x0f, 0x9f, 0xc8, 0x94, 0x0e, 0x49, 0x4d, 0xc6, 0xcf, 0x8c, 0xbf, 0xfb, 0x0f, 0xda, 0xa8, 0x85,
		0x5a, 0xd8, 0xdd, 0x55, 0x4d, 0x52, 0xba, 0x8c, 0x20, 0xe3, 0x45, 0x6c, 0x92, 0xdd, 0x55, 0x57,
		0x5d, 0x55, 0x5d, 0x5d, 0xd5, 0x0c, 0x04, 0x31, 0xff, 0x1a, 0x0d, 0x09, 0xde, 0x05, 0xde, 0x05,
		0xde, 0x05, 0xde, 0x05, 0xde, 0x05, 0xde, 0x05, 0xde, 0x05, 0xde, 0x05, 0xde, 0x35, 0xcd, 0xbb,
		0xc8, 0xa3, 0x5e, 0x88, 0x75, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81,
		0x73, 0x81, 0x73, 0x81, 0x73, 0x45, 0x38, 0x57, 0xcf, 0x65, 0xda, 0x71, 0x9c, 0x19, 0x18, 0x1c,
		0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c,
		0x6c, 0x96, 0x83, 0xfd, 0xe5, 0x76, 0xfe, 0x76, 0xad, 0xae, 0xd7, 0x09, 0x3a, 0xd4, 0x2c, 0x6c,
		0x66, 0x68, 0xf0, 0x30, 0xf0, 0x30, 0xf0, 0x30, 0xf0, 0x30, 0xf0, 0x30, 0xf0, 0x30, 0xf0, 0x30,
		0xf0, 0x30, 0xf0, 0xb0, 0x70, 0x59, 0xda, 0xb6, 0x1f, 0x58, 0xcd, 0xb6, 0xb0, 0x3d, 0x3a, 0x02,
		0x36, 0x35, 0x26, 0x98, 0x17, 0x98, 0x17, 0x98, 0x57, 0x8a, 0x98, 0x57, 0xe0, 0xbc, 0x8a, 0xc0,
		0x69, 0xfe, 0xe5, 0xa7, 0x8e, 0x7b, 0xfd, 0xea, 0x0e, 0xed, 0x42, 0xde, 0xb5, 0xdd, 0x8e, 0x2f,
		0x9a, 0x1d, 0x57, 0xbb, 0x62, 0x20, 0x38, 0x1d, 0x38, 0x1d, 0x38, 0x1d, 0x38, 0x5d, 0x72, 0x9c,
		0x0e, 0x2d, 0x17, 0xa8, 0x68, 0x02, 0x5a, 0x2e, 0x50, 0xd2, 0xfe, 0x4e, 0x2f, 0x60, 0xeb, 0xb9,
		0xb0, 0x60, 0x6c, 0xb8, 0x01, 0x70, 0x03, 0xe0, 0x06, 0xa4, 0xc8, 0x0d, 0x40, 0x00, 0x16, 0x64,
		0x1d, 0x64, 0x1d, 0x64, 0x1d, 0x64, 0x9d, 0xe2, 0xfe, 0xba, 0x4c, 0x8c, 0xbe, 0xeb, 0xc2, 0xcc,
		0xa8, 0x60, 0x5f, 0x60, 0x5f, 0x60, 0x5f, 0x60, 0x5f, 0x60, 0x5f, 0x60, 0x5f, 0x60, 0x5f, 0x60,
		0x5f, 0x60, 0x5f, 0x33, 0xec, 0x8b, 0xba, 0xf6, 0xef, 0xd4, 0x98, 0x60, 0x5e, 0x60, 0x5e, 0x60,
		0x5e, 0x60, 0x5e, 0x60, 0x5e, 0x60, 0x5e, 0x60, 0x5e, 0x60, 0x5e, 0x60, 0x5e, 0x33, 0xcc, 0x8b,
		0xab, 0xf2, 0xef, 0x82, 0xb1, 0xc1, 0xc4, 0xc0, 0xc4, 0xc0, 0xc4, 0xc0, 0xc4, 0xc0, 0xc4, 0xc0,
		0xc4, 0xc0, 0xc4, 0xc0, 0xc4, 0xc0, 0xc4, 0x66, 0x98, 0x18, 0x75, 0xed, 0xdf, 0xa9, 0x31, 0xc1,
		0xbc, 0xc0, 0xbc, 0xc0, 0xbc, 0xc0, 0xbc, 0xc0, 0xbc, 0xc0, 0xbc, 0xc0, 0xbc, 0xc0, 0xbc, 0xc0,
		0xbc, 0x66, 0x98, 0x17, 0x7d, 0xe4, 0x0b, 0xf1, 0x2e, 0xb0, 0x2e, 0xb0, 0x2e, 0xb0, 0x2e, 0xb0,
		0x2e, 0xb0, 0x2e, 0xb0, 0x2e, 0xb0, 0x2e, 0xb0, 0xae, 0x28, 0xeb, 0xe2, 0xa9, 0xff, 0x1b, 0x19,
		0x19, 0x2c, 0x0c, 0x2c, 0x0c, 0x2c, 0x0c, 0x2c, 0x0c, 0x2c, 0x0c, 0x2c, 0x0c, 0x2c, 0x0c, 0x2c,
		0x6c, 0xd3, 0x58, 0xd8, 0x8e, 0x41, 0x99, 0xd7, 0x2f, 0x86, 0xa2, 0xc9, 0xf2, 0xa2, 0xc5, 0x4f,
		0x3a, 0x5d, 0xe1, 0xd9, 0x7d, 0xd9, 0xb2, 0xdb, 0xba, 0x54, 0x8f, 0xbc, 0xd8, 0x09, 0x51, 0x91,
		0x13, 0x0d, 0x80, 0xc2, 0x74, 0x9b, 0xd2, 0xa8, 0xba, 0xa2, 0x46, 0x55, 0x5c, 0xb7, 0x13, 0x0c,
		0x66, 0x54, 0xcb, 0x70, 0xe4, 0xfd, 0xe6, 0x17, 0xf1, 0x6a, 0x77, 0xed, 0xe0, 0x4b, 0xff, 0xed,
		0xf7, 0x3b, 0x5d, 0xe1, 0x36, 0x07, 0x3e, 0x87, 0xe5, 0xf4, 0xd9, 0xd6, 0xb3, 0xdd, 0x14, 0xfe,
		0xfe, 0xa2, 0x6f, 0xf7, 0xfd, 0xde, 0xd3, 0xd4, 0xef, 0xa7, 0x7f, 0xda, 0xf7, 0x03, 0x3b, 0x10,
		0xfb, 0x23, 0xc2, 0xa6, 0xe3, 0x4a, 0xe5, 0xfd, 0xc0, 0xeb, 0x35, 0x03, 0x77, 0x44, 0x01, 0x6b,
		0xe3, 0x3b, 0x34, 0xee, 0xa7, 0x6e, 0xd7, 0x38, 0x1f, 0xdf, 0x68, 0xc7, 0xcc, 0xba, 0x29, 0x28,
		0x56, 0xbe, 0x25, 0xfc, 0xa6, 0xe7, 0x74, 0xb5, 0x16, 0x2c, 0xa4, 0xc2, 0xd3, 0x83, 0x29, 0xca,
		0x8f, 0x1e, 0x39, 0xd0, 0xf6, 0x4b, 0x29, 0xfc, 0x51, 0x32, 0x3f, 0x94, 0xca, 0xff, 0x24, 0xf7,
		0x3b, 0xc9, 0xfd, 0x4d, 0x4a, 0x3f, 0xd3, 0x2c, 0x83, 0xd0, 0xf6, 0x27, 0x43, 0x69, 0xf1, 0x03,
		0xcf, 0x71, 0x5f, 0x74, 0xc4, 0x65, 0xa4, 0x3b, 0xc5, 0x93, 0x14, 0xe3, 0x8d, 0x70, 0xed, 0xa7,
		0xb6, 0x68, 0xe9, 0x63, 0xcd, 0x78, 0x20, 0xc5, 0x75, 0xbb, 0x10, 0xcf, 0x76, 0xaf, 0x3d, 0x90,
		0xb7, 0xbe, 0xf8, 0x02, 0xae, 0x00, 0x57, 0x80, 0x2b, 0x19, 0x69, 0x79, 0xea, 0x74, 0xda, 0xc2,
		0x76, 0x29, 0xf0, 0xaa, 0x98, 0x62, 0xbc, 0x72, 0x9e, 0x1d, 0xb7, 0x25, 0xbe, 0xe9, 0xe3, 0xd5,
		0x78, 0x20, 0x00, 0x0d, 0x80, 0x06, 0x40, 0x23, 0x21, 0x2d, 0x3d, 0xc7, 0x0d, 0x0e, 0x4a, 0x04,
		0x38, 0x73, 0xac, 0x31, 0x04, 0x4d, 0x30, 0x9d, 0x60, 0xd7, 0x81, 0x32, 0x78, 0x4e, 0x1c, 0x89,
		0xa5, 0x0e, 0x96, 0x73, 0x84, 0x59, 0x09, 0x82, 0xe3, 0xa4, 0x41, 0x71, 0xae, 0x25, 0x28, 0x97,
		0x4e, 0xcb, 0xa7, 0x47, 0xc7, 0xa5, 0xd3, 0xc3, 0x14, 0xaf, 0x45, 0x42, 0x21, 0xe6, 0xfa, 0x96,
		0x87, 0x98, 0xe9, 0xeb, 0x6b, 0x23, 0xd4, 0x1c, 0x63, 0xda, 0x11, 0xd9, 0xc7, 0x74, 0x13, 0x4f,
		0xf7, 0x8e, 0x19, 0xf8, 0x53, 0xf2, 0x9b, 0x88, 0xbc, 0x26, 0x1d, 0x9f, 0x69, 0x2a, 0xc6, 0x53,
		0x80, 0xdf, 0x05, 0xbf, 0x0b, 0x7e, 0x17, 0xfc, 0x2e, 0xf8, 0x5d, 0xf0, 0xbb, 0xe0, 0x77, 0x65,
		0xc9, 0xef, 0x32, 0x42, 0x57, 0x86, 0xfd, 0x25, 0xbf, 0x8c, 0xd0, 0x46, 0x93, 0xb4, 0x4c, 0x0f,
		0x06, 0xda, 0x01, 0xda, 0x01, 0xda, 0x21, 0x21, 0x2d, 0x34, 0xdd, 0x24, 0x09, 0x12, 0xa9, 0xa9,
		0xbb, 0x47, 0x82, 0xcb, 0x80, 0xcb, 0x64, 0x8a, 0xcb, 0xf0, 0x25, 0x52, 0x83, 0xd5, 0x20, 0x9a,
		0x9c, 0xc5, 0x78, 0x1b, 0xc2, 0x9b, 0x98, 0x6e, 0x44, 0x93, 0x35, 0xe1, 0x4f, 0xc9, 0x3d, 0xeb,
		0xbc, 0x38, 0x4d, 0xbb, 0x4d, 0xe0, 0x9a, 0x8d, 0x06, 0x82, 0x5b, 0x06, 0xb7, 0x0c, 0x6e, 0x99,
		0x84, 0xb4, 0x24, 0x9f, 0xee, 0x07, 0xc6, 0x04, 0x13, 0x0e, 0x13, 0x8e, 0xe9, 0x06, 0x63, 0x8a,
		0xf3, 0x86, 0xa3, 0xa3, 0x69, 0x9a, 0x74, 0x69, 0x30, 0x0a, 0xb8, 0x12, 0xb8, 0x12, 0xb8, 0x92,
		0x84, 0xb4, 0x24, 0x7e, 0x92, 0x0b, 0x54, 0x09, 0xb6, 0x1b, 0xb6, 0x3b, 0xb3, 0xb6, 0xbb, 0x3f,
		0xfd, 0x96, 0x1f, 0xd8, 0x41, 0xcf, 0xd7, 0x37, 0xe1, 0xd3, 0x83, 0xc1, 0x92, 0xc3, 0x92, 0xc3,
		0x92, 0x4b, 0x48, 0x8b, 0x70, 0x7b, 0xaf, 0x23, 0x28, 0xa4, 0x30, 0xe7, 0x65, 0x8d, 0x31, 0xaa,
		0x6e, 0xef, 0xb5, 0xff, 0x52, 0xef, 0xa0, 0x04, 0xa0, 0x04, 0xa0, 0x04, 0x98, 0x6e, 0x30, 0x30,
		0x8e, 0xfb, 0x48, 0x0a, 0x81, 0x6e, 0xbd, 0x23, 0xc6, 0x3a, 0x47, 0x72, 0x2b, 0x13, 0x7f, 0x96,
		0x24, 0x66, 0x28, 0xff, 0xb5, 0x6d, 0xcb, 0xcf, 0x4b, 0x68, 0x7d, 0x07, 0x57, 0x4b, 0xae, 0xc7,
		0xd8, 0xd4, 0x4a, 0x5e, 0xa6, 0xca, 0x51, 0x75, 0xb8, 0xe9, 0x34, 0x27, 0x55, 0x78, 0x55, 0x0a,
		0x36, 0x4a, 0xc6, 0x42, 0xc9, 0xd8, 0xe7, 0x3c, 0xeb, 0x1c, 0x4c, 0x4c, 0xca, 0x74, 0xfe, 0xc2,
		0xf1, 0xd4, 0x16, 0xbc, 0x39, 0x96, 0x32, 0x4d, 0x9f, 0x6e, 0x34, 0x8e, 0x9e, 0x3b, 0x57, 0xdc,
		0x10, 0x77, 0x4e, 0x51, 0x75, 0xe0, 0xd0, 0xa9, 0xa9, 0x56, 0x32, 0x2e, 0x9d, 0xaa, 0xca, 0xcd,
		0x58, 0x22, 0xcb, 0x69, 0xd1, 0x15, 0x66, 0x1f, 0x0f, 0x88, 0x7a, 0xec, 0x06, 0x94, 0x94, 0x5a,
		0x59, 0xd9, 0x94, 0x96, 0x4d, 0x79, 0x79, 0x94, 0x58, 0x4f, 0x99, 0x09, 0x1c, 0xa7, 0x1c, 0x4f,
		0x4d, 0xf6, 0x9e, 0xab, 0x17, 0xb1, 0x89, 0xd8, 0xca, 0x53, 0x82, 0xb1, 0x46, 0xaf, 0x99, 0xba,
		0x7a, 0xec, 0xb4, 0x88, 0xb6, 0x68, 0xfa, 0x8e, 0x08, 0x87, 0xa4, 0x2d, 0x6b, 0x4f, 0x3f, 0x9d,
		0xe1, 0x83, 0x72, 0x94, 0xb9, 0x27, 0x36, 0x1b, 0x4b, 0x87, 0x0f, 0x8f, 0x00, 0x30, 0x8d, 0xcf,
		0x58, 0x40, 0x9d, 0x08, 0x94, 0x16, 0x2f, 0x29, 0x43, 0x39, 0x7c, 0xd3, 0x4b, 0x5a, 0x2e, 0x9c,
		0x96, 0x33, 0xbc, 0xaa, 0x3b, 0xe9, 0x1c, 0xad, 0xbe, 0x93, 0x22, 0x99, 0x65, 0xb0, 0x0d, 0xff,
		0x75, 0xdc, 0xff, 0xf2, 0xd8, 0x86, 0xe2, 0x09, 0xe1, 0x98, 0xb7, 0x76, 0x10, 0x08, 0xcf, 0x25,
		0x37, 0x0f, 0xf9, 0x3f, 0x77, 0xcb, 0x85, 0xd3, 0xc7, 0x82, 0x55, 0xae, 0xff, 0x28, 0x17, 0x1e,
		0x0b, 0xd6, 0x49, 0xfd, 0xb1, 0x60, 0x9d, 0xd6, 0x7f, 0x3c, 0x16, 0xad, 0x83, 0xe1, 0xb7, 0xdf,
		0x0f, 0xde, 0xfb, 0x3f, 0x9d, 0x8e, 0x7e, 0x2a, 0x7e, 0x28, 0x8d, 0x7e, 0xde, 0xfb, 0xfc, 0xf9,
		0xe3, 0xae, 0xc6, 0xe5, 0x3f, 0x3e, 0x7f, 0xfe, 0xe7, 0xde, 0x3f, 0xf2, 0x74, 0xa2, 0x4a, 0x39,
		0xdf, 0x37, 0xf7, 0xb5, 0xdf, 0x31, 0xe9, 0xc6, 0xf0, 0x01, 0x6d, 0x3d, 0xe2, 0xf9, 0x48, 0x69,
		0x6e, 0x42, 0xd0, 0xa7, 0xd9, 0xfb, 0xa3, 0x08, 0x5e, 0x9a, 0x0b, 0x75, 0xbf, 0x78, 0xc2, 0xf7,
		0xad, 0x57, 0xbb, 0xdb, 0x75, 0x5c, 0x82, 0x98, 0xe5, 0xdc, 0x78, 0x88, 0x5d, 0x22, 0x76, 0x89,
		0xd8, 0x65, 0xbc, 0x01, 0x34, 0xb7, 0x0d, 0x22, 0x82, 0xa7, 0xb5, 0x7d, 0x40, 0xa4, 0x8a, 0x88,
		0x5c, 0x22, 0x72, 0x99, 0xfd, 0xc8, 0xa5, 0xae, 0x6a, 0x87, 0x03, 0x05, 0x5d, 0x82, 0xbd, 0x89,
		0x88, 0xf8, 0x0e, 0x46, 0xfd, 0x90, 0xca, 0x22, 0x13, 0x54, 0x6a, 0xcf, 0xa1, 0xfe, 0x8c, 0x30,
		0xc0, 0x05, 0x07, 0xec, 0xb0, 0xc0, 0x0e, 0x0f, 0xbc, 0x30, 0x41, 0x1b, 0xf1, 0x21, 0x8a, 0xd3,
		0xd0, 0x6d, 0x7c, 0x44, 0x24, 0xd6, 0x69, 0x09, 0x37, 0x70, 0x82, 0x37, 0x4f, 0x3c, 0x73, 0xc4,
		0x6c, 0x08, 0x1b, 0x6a, 0xe6, 0x6b, 0xa3, 0x47, 0xfd, 0x64, 0xfb, 0x0c, 0xfa, 0x30, 0x9e, 0x90,
		0x87, 0xdb, 0xda, 0x45, 0xe3, 0xe1, 0x8f, 0xdb, 0xea, 0x7d, 0x9e, 0xa3, 0xef, 0xa8, 0x4f, 0x1e,
		0xfd, 0xc8, 0xb1, 0xec, 0x4a, 0x44, 0xe7, 0xa4, 0xf0, 0xfb, 0x69, 0xb1, 0x50, 0xc8, 0x67, 0x21,
		0xfe, 0x6e, 0x68, 0x3a, 0x4a, 0x98, 0x8e, 0xa9, 0xe9, 0x38, 0x39, 0xa9, 0x9c, 0x60, 0x3a, 0x26,
		0xd3, 0x01, 0x65, 0x99, 0x4c, 0x47, 0xe5, 0xfa, 0x8f, 0x7c, 0xca, 0xb7, 0x78, 0xea, 0x1b, 0xd7,
		0x99, 0x99, 0xa2, 0xfc, 0x1c, 0x55, 0x36, 0x54, 0x44, 0x2c, 0x68, 0x73, 0x08, 0xe0, 0x74, 0xc0,
		0xe9, 0x80, 0xd3, 0x91, 0x19, 0xa7, 0x03, 0x09, 0x44, 0xa4, 0x32, 0x89, 0x04, 0xa2, 0xe5, 0xe3,
		0x23, 0x81, 0x28, 0xb1, 0x25, 0x45, 0x02, 0x11, 0xc7, 0x68, 0xf5, 0x4d, 0x63, 0x97, 0x7e, 0x60,
		0x37, 0xff, 0xb2, 0x86, 0xeb, 0xc9, 0xc4, 0x33, 0x67, 0x6e, 0x01, 0xc6, 0x09, 0xc6, 0x09, 0xc6,
		0xb9, 0x8d, 0x8c, 0x93, 0x01, 0x06, 0x72, 0x44, 0x55, 0x1b, 0x22, 0x63, 0xea, 0x55, 0x71, 0x60,
		0x80, 0xfb, 0x44, 0xb7, 0x4f, 0x89, 0xf2, 0xb4, 0xc2, 0xf1, 0xf8, 0xf2, 0xb5, 0x66, 0xb3, 0x97,
		0xb4, 0xd2, 0xb7, 0xf4, 0xa7, 0x5e, 0x63, 0xda, 0xf3, 0xc3, 0xa3, 0xe1, 0x64, 0xa9, 0x24, 0xc3,
		0xe1, 0x52, 0x96, 0x49, 0x52, 0x42, 0x26, 0x49, 0x1a, 0x6c, 0x29, 0x32, 0x49, 0x24, 0x5e, 0x09,
		0x99, 0x24, 0xa0, 0xd8, 0xa0, 0xd8, 0xa0, 0xd8, 0xa9, 0xa3, 0xd8, 0xc8, 0x24, 0x99, 0x9b, 0x10,
		0x64, 0x92, 0x2c, 0x99, 0x13, 0x64, 0x92, 0x20, 0x93, 0x64, 0xd5, 0x74, 0x20, 0x93, 0x04, 0x99,
		0x24, 0xcb, 0xa6, 0x03, 0x99, 0x24, 0x49, 0x04, 0x7f, 0x90, 0x49, 0x02, 0xa7, 0x03, 0x4e, 0x07,
		0x9c, 0x8e, 0xd4, 0x39, 0x1d, 0xc8, 0x24, 0x21, 0x95, 0x49, 0x64, 0x92, 0x2c, 0x1f, 0x1f, 0x99,
		0x24, 0x89, 0x2d, 0x29, 0x32, 0x49, 0x38, 0x46, 0x43, 0x26, 0x89, 0xbc, 0xa9, 0x41, 0x26, 0x09,
		0x18, 0x27, 0x18, 0xe7, 0xd6, 0x33, 0x4e, 0x64, 0x92, 0x24, 0x35, 0xc2, 0xd6, 0x66, 0x92, 0x28,
		0x94, 0xea, 0xa7, 0x9b, 0x79, 0x54, 0x65, 0x5a, 0xb5, 0x36, 0x79, 0xad, 0x34, 0x1b, 0xaf, 0xd7,
		0x0c, 0x46, 0x4d, 0x38, 0xf3, 0xb5, 0xf1, 0x6d, 0x1a, 0xf7, 0x53, 0xf7, 0x6c, 0xfc, 0xd6, 0xb6,
		0xdd, 0x46, 0x75, 0x70, 0xcf, 0xab, 0xd1, 0x2d, 0x53, 0x5c, 0x10, 0xca, 0x71, 0x89, 0x2b, 0x42,
		0xcd, 0x0f, 0x88, 0x92, 0x50, 0x28, 0x09, 0x95, 0x18, 0xef, 0x41, 0x49, 0x28, 0x94, 0x84, 0x32,
		0xec, 0xda, 0x20, 0x91, 0x0f, 0x89, 0x7c, 0x2b, 0x06, 0x42, 0x22, 0x1f, 0x22, 0x1c, 0x88, 0x70,
		0x20, 0xc2, 0x41, 0x25, 0xb1, 0x48, 0xe4, 0x9b, 0x9b, 0x10, 0x24, 0xf2, 0x2d, 0x99, 0x13, 0x24,
		0xf2, 0x21, 0x91, 0x6f, 0xd5, 0x74, 0x20, 0x91, 0x0f, 0x89, 0x7c, 0xcb, 0xa6, 0x03, 0x89, 0x7c,
		0x09, 0x8c, 0x82, 0x44, 0x3e, 0x38, 0x1d, 0x70, 0x3a, 0xe0, 0x74, 0xa4, 0xcf, 0xe9, 0x40, 0x22,
		0x1f, 0xa9, 0x4c, 0x22, 0x91, 0x6f, 0xf9, 0xf8, 0x48, 0xe4, 0x4b, 0x6c, 0x49, 0x91, 0xc8, 0xc7,
		0x31, 0x1a, 0x12, 0xf9, 0xe4, 0x4d, 0x0d, 0x12, 0xf9, 0xc0, 0x38, 0xc1, 0x38, 0xb7, 0x9e, 0x71,
		0x22, 0x91, 0x2f, 0xa9, 0x11, 0xb6, 0x27, 0x91, 0x6f, 0x2e, 0x7d, 0x09, 0x35, 0xa1, 0x50, 0x13,
		0x2a, 0x31, 0xe3, 0x8a, 0x54, 0x12, 0xa4, 0x92, 0xac, 0x18, 0x08, 0xa9, 0x24, 0xe0, 0xd8, 0xe0,
		0xd8, 0xe0, 0xd8, 0x54, 0x12, 0x8b, 0x54, 0x92, 0xb9, 0x09, 0x41, 0x2a, 0xc9, 0x92, 0x39, 0x41,
		0x2a, 0x09, 0x52, 0x49, 0x56, 0x4d, 0x07, 0x52, 0x49, 0x90, 0x4a, 0xb2, 0x6c, 0x3a, 0x90, 0x4a,
		0x92, 0x44, 0xf4, 0x07, 0xa9, 0x24, 0x70, 0x3a, 0xe0, 0x74, 0xc0, 0xe9, 0x48, 0x9d, 0xd3, 0x81,
		0x54, 0x12, 0x52, 0x99, 0x44, 0x2a, 0xc9, 0xf2, 0xf1, 0x91, 0x4a, 0x92, 0xd8, 0x92, 0x22, 0x95,
		0x84, 0x63, 0x34, 0xa4, 0x92, 0xc8, 0x9b, 0x1a, 0xa4, 0x92, 0x80, 0x71, 0x82, 0x71, 0x6e, 0x3d,
		0xe3, 0x44, 0x2a, 0x49, 0x52, 0x23, 0x6c, 0x6f, 0x2a, 0x09, 0x8a, 0x42, 0xa5, 0x77, 0x71, 0xcc,
		0x54, 0x85, 0xaa, 0xb9, 0x59, 0x29, 0x0b, 0xf5, 0x6a, 0x07, 0xcd, 0x2f, 0xfa, 0xc5, 0xa0, 0x86,
		0xc3, 0xa0, 0x04, 0x14, 0x4a, 0x40, 0x25, 0x46, 0x73, 0x32, 0x56, 0x02, 0xaa, 0xd5, 0xe9, 0x3d,
		0xb5, 0x85, 0x15, 0xd8, 0x2f, 0x2f, 0xa2, 0x45, 0x97, 0xbd, 0x37, 0x3b, 0x2c, 0x0a, 0x42, 0x19,
		0xf4, 0x6b, 0x90, 0xc5, 0x87, 0x2c, 0xbe, 0x15, 0x03, 0x11, 0xd5, 0x7c, 0x8b, 0x08, 0x30, 0x49,
		0xed, 0x37, 0x62, 0x95, 0x47, 0x88, 0x03, 0x21, 0x0e, 0x84, 0x38, 0xa8, 0x21, 0x24, 0x1c, 0xd0,
		0x71, 0x5d, 0xe1, 0x59, 0xd4, 0xfb, 0xf4, 0x11, 0x7d, 0x98, 0xbd, 0x0d, 0xf1, 0xfa, 0xf3, 0x6c,
		0x48, 0x90, 0x03, 0x0e, 0x27, 0xf0, 0x18, 0x00, 0x20, 0x6e, 0x20, 0x32, 0x06, 0x48, 0xc6, 0x80,
		0xc9, 0x0c, 0x40, 0xd1, 0x02, 0x15, 0x31, 0x60, 0x85, 0x53, 0x40, 0x1e, 0x9b, 0x8d, 0x48, 0x3c,
		0x0f, 0xb8, 0xe4, 0x78, 0xb2, 0x03, 0xc2, 0xa1, 0x79, 0xb2, 0x04, 0xc6, 0x5f, 0x3c, 0x1a, 0x9a,
		0xe3, 0xce, 0x1a, 0x60, 0x46, 0xf6, 0xc8, 0x6d, 0x98, 0xb3, 0x08, 0xc2, 0xfb, 0x18, 0xd8, 0x77,
		0x66, 0xd2, 0xdf, 0xd9, 0xa5, 0x67, 0xcc, 0x2e, 0x48, 0x6a, 0xe9, 0xf9, 0xb2, 0x0d, 0x12, 0x59,
		0xfd, 0x9d, 0x6c, 0x8c, 0x5a, 0x4f, 0x69, 0x96, 0x04, 0xa1, 0xf6, 0xe4, 0x3b, 0xbd, 0xc0, 0x04,
		0xc3, 0x9e, 0xbd, 0x0d, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36,
		0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x76, 0xba, 0x18, 0x76, 0xaa, 0xc2, 0xea, 0xc4, 0x09,
		0x62, 0xe1, 0xb8, 0x7c, 0xb9, 0x48, 0x83, 0x2c, 0x99, 0xfd, 0x99, 0x2d, 0x7a, 0x92, 0xba, 0x43,
		0x74, 0xeb, 0x43, 0x91, 0xe1, 0x4d, 0x53, 0x8f, 0x28, 0x42, 0x64, 0x28, 0xea, 0x12, 0xcd, 0xc3,
		0x28, 0xf9, 0x36, 0x67, 0x09, 0xdb, 0x9c, 0x59, 0xf2, 0x79, 0xb0, 0xcd, 0x89, 0x6d, 0x4e, 0x6c,
		0x73, 0x22, 0x08, 0x83, 0x20, 0x0c, 0x82, 0x30, 0x08, 0xc2, 0x20, 0x08, 0x83, 0x20, 0x0c, 0x82,
		0x30, 0x08, 0xc2, 0x20, 0x08, 0x93, 0xc3, 0x36, 0x27, 0x29, 0xe1, 0xc3, 0x36, 0x27, 0x18, 0x36,
		0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36,
		0xb6, 0x39, 0x63, 0xd2, 0x87, 0x8d, 0xd8, 0xe6, 0x24, 0xa8, 0x89, 0x41, 0xb7, 0x3c, 0x28, 0x6c,
		0xa2, 0xbc, 0x90, 0x79, 0x92, 0x0d, 0xe2, 0xb8, 0x75, 0x34, 0xae, 0xfa, 0x0f, 0xd0, 0xb8, 0x18,
		0x3c, 0xc0, 0xc3, 0xf0, 0xfe, 0x19, 0x6c, 0xd0, 0x33, 0x33, 0x81, 0xd6, 0x70, 0xbb, 0xa9, 0xed,
		0xf8, 0x01, 0xd3, 0xa9, 0xff, 0xe9, 0x3b, 0xa0, 0x00, 0x80, 0x41, 0x5f, 0x19, 0x05, 0x00, 0x50,
		0x00, 0x60, 0xc5, 0x40, 0x28, 0x00, 0x90, 0xd2, 0xf0, 0x19, 0x32, 0x63, 0x12, 0x08, 0x8f, 0x21,
		0x33, 0x46, 0x63, 0xc0, 0x99, 0x94, 0x15, 0xdf, 0x50, 0x6a, 0x8c, 0x8f, 0xc8, 0x3d, 0x22, 0xf7,
		0x09, 0x42, 0x92, 0x31, 0x68, 0x32, 0x03, 0x51, 0x3c, 0x71, 0x15, 0x44, 0xee, 0xa3, 0x00, 0x83,
		0xc8, 0xfd, 0xd4, 0x83, 0x23, 0x72, 0x2f, 0x7f, 0x1f, 0x44, 0xee, 0x53, 0xbb, 0xf4, 0x88, 0xdc,
		0x27, 0x31, 0x6a, 0x3d, 0xd5, 0x36, 0xeb, 0xd2, 0xf1, 0x83, 0x4a, 0x10, 0x78, 0x3c, 0x76, 0xeb,
		0xca, 0x71, 0xab, 0x6d, 0xd1, 0xa7, 0x05, 0x3e, 0x8f, 0x9c, 0xf7, 0xf5, 0x74, 0xea, 0x0e, 0xc5,
		0x93, 0x72, 0xf9, 0xe8, 0xb8, 0x5c, 0x2e, 0x1c, 0x1f, 0x1c, 0x17, 0x4e, 0x0f, 0x0f, 0x8b, 0x47,
		0x94, 0x1d, 0x36, 0xc3, 0x9b, 0xde, 0x78, 0x2d, 0xe1, 0x89, 0xd6, 0xa7, 0xb7, 0xfc, 0x59, 0xce,
		0xed, 0xb5, 0xdb, 0xc8, 0x7e, 0x22, 0xa3, 0xf4, 0xc8, 0x7e, 0x82, 0x0f, 0x05, 0x1f, 0x0a, 0x3e,
		0x14, 0x7c, 0x28, 0xf8, 0x50, 0xf0, 0xa1, 0xe0, 0x43, 0xc1, 0x87, 0x82, 0x0f, 0x85, 0xec, 0xa7,
		0x98, 0xf4, 0x61, 0x13, 0xb2, 0x9f, 0xa6, 0x32, 0x32, 0x50, 0xef, 0x21, 0x2e, 0xa7, 0x41, 0xbd,
		0x87, 0xd4, 0xba, 0x43, 0xd8, 0xd5, 0x4e, 0xc6, 0xdd, 0xc1, 0xae, 0x36, 0x89, 0x42, 0x60, 0x57,
		0x1b, 0x11, 0x19, 0x44, 0x64, 0x10, 0x91, 0x41, 0x44, 0x06, 0x11, 0x19, 0x44, 0x64, 0x10, 0x91,
		0x41, 0x44, 0x06, 0x11, 0x99, 0x1c, 0x76, 0xb5, 0xb1, 0xab, 0x9d, 0x5c, 0xcc, 0x0d, 0xbb, 0xda,
		0xf0, 0xa1, 0xe0, 0x43, 0xc1, 0x87, 0x82, 0x0f, 0x05, 0x1f, 0x0a, 0x3e, 0x14, 0x7c, 0x28, 0xf8,
		0x50, 0xf0, 0xa1, 0xe0, 0x43, 0x61, 0x57, 0x5b, 0x72, 0xdc, 0xc4, 0x76, 0xb5, 0x51, 0xde, 0x83,
		0x6b, 0x6d, 0x13, 0x5b, 0xd3, 0xa4, 0x2b, 0x7d, 0xd4, 0xfa, 0x4f, 0x72, 0xd9, 0x7f, 0x90, 0x0d,
		0x29, 0xf9, 0x31, 0xf4, 0x98, 0xbd, 0x11, 0x3d, 0x64, 0xac, 0xfc, 0x31, 0x7d, 0x23, 0x14, 0x00,
		0x31, 0xe8, 0x58, 0xa3, 0x00, 0x08, 0x0a, 0x80, 0xac, 0x18, 0x08, 0x05, 0x40, 0x52, 0x1a, 0x6b,
		0x43, 0xaa, 0x54, 0x02, 0xb1, 0x34, 0xa4, 0x4a, 0x69, 0x0c, 0x38, 0x34, 0xf4, 0x5f, 0x9c, 0x97,
		0x2f, 0xa6, 0xfa, 0xe3, 0xcc, 0xdc, 0x0b, 0xe1, 0x7e, 0x84, 0xfb, 0x93, 0x83, 0x26, 0x63, 0x10,
		0x65, 0x06, 0xaa, 0x78, 0x82, 0x31, 0x08, 0xf7, 0x47, 0x01, 0x06, 0xe1, 0xfe, 0xa9, 0x07, 0x47,
		0xb8, 0x5f, 0xfe, 0x3e, 0x08, 0xf7, 0xa7, 0x76, 0xe9, 0x11, 0xee, 0x4f, 0x62, 0xd4, 0x6d, 0x68,
		0x92, 0x33, 0x0a, 0x89, 0x76, 0xfe, 0x36, 0x45, 0xb5, 0xa7, 0x6f, 0x05, 0xa6, 0x0d, 0xa6, 0x0d,
		0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0xbd,
		0xb1, 0x4c, 0x7b, 0xb8, 0x71, 0x6d, 0x26, 0xaa, 0xbd, 0xe0, 0x5e, 0xe0, 0xda, 0xe0, 0xda, 0xe0,
		0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0x1b,
		0xce, 0xb5, 0x8d, 0x44, 0xb5, 0xa3, 0xb7, 0x02, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06,
		0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x4e, 0x17, 0xd3, 0xc6, 0x71,
		0x51, 0xa6, 0xa3, 0x85, 0x53, 0x87, 0xd3, 0x50, 0x0b, 0x39, 0x2e, 0xb5, 0x41, 0x2d, 0xe4, 0xd4,
		0x7a, 0x45, 0x38, 0xe0, 0x93, 0x8c, 0xd7, 0x83, 0x03, 0x3e, 0x64, 0x4a, 0x81, 0x03, 0x3e, 0x08,
		0xd0, 0x20, 0x40, 0x83, 0x00, 0x0d, 0x02, 0x34, 0x08, 0xd0, 0x20, 0x40, 0x83, 0x00, 0x0d, 0x02,
		0x34, 0x08, 0xd0, 0xa4, 0x3e, 0x40, 0x83, 0x03, 0x3e, 0x60, 0xda, 0x60, 0xda, 0x60, 0xda, 0x60,
		0xda, 0x60, 0xda, 0x60, 0xda, 0x60, 0xda, 0x60, 0xda, 0x60, 0xda, 0x60, 0xda, 0x29, 0x67, 0xda,
		0x38, 0xe0, 0x03, 0xae, 0x0d, 0xae, 0x0d, 0xae, 0x0d, 0xae, 0x0d, 0xae, 0x0d, 0xae, 0x0d, 0xae,
		0x0d, 0xae, 0x0d, 0xae, 0x0d, 0xae, 0xcd, 0xc9, 0xb5, 0x71, 0xc0, 0x07, 0x4c, 0x1b, 0x4c, 0x1b,
		0x4c, 0x1b, 0x4c, 0x1b, 0x4c, 0x1b, 0x4c, 0x1b, 0x4c, 0x1b, 0x4c, 0x1b, 0x4c, 0x1b, 0x4c, 0x1b,
		0x07, 0x7c, 0xcc, 0x1c, 0xf0, 0x41, 0x5b, 0x38, 0xae, 0x25, 0x4e, 0x7a, 0x69, 0x53, 0xd1, 0x1d,
		0xee, 0xa6, 0xff, 0x3c, 0x43, 0x7e, 0xb5, 0x21, 0x3d, 0xe2, 0x0c, 0x74, 0x87, 0x43, 0x5f, 0x38,
		0xe3, 0x0e, 0x36, 0xfa, 0xc2, 0xa1, 0x2f, 0xdc, 0x8a, 0x81, 0xd0, 0x17, 0x2e, 0xa5, 0x31, 0x37,
		0x1c, 0x1b, 0x4d, 0x20, 0xa6, 0x86, 0x63, 0xa3, 0x1a, 0x03, 0xe2, 0xd8, 0x68, 0x02, 0xd0, 0xc3,
		0x09, 0x41, 0x06, 0xa0, 0x88, 0x1b, 0x92, 0x8c, 0x41, 0x93, 0x31, 0x88, 0x32, 0x03, 0x55, 0x3c,
		0x41, 0x19, 0x84, 0xfd, 0xa3, 0x00, 0x83, 0xb0, 0xff, 0xd4, 0x83, 0x23, 0xec, 0x2f, 0x7f, 0x1f,
		0x84, 0xfd, 0x53, 0xbb, 0xf4, 0x08, 0xfb, 0x27, 0x31, 0x2a, 0x8e, 0x8d, 0x32, 0x50, 0x6d, 0x24,
		0xd8, 0x80, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83,
		0x69, 0x83, 0x69, 0x6f, 0x51, 0x2a, 0xbb, 0xa1, 0x34, 0x76, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c,
		0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0xec, 0x14, 0xdb,
		0xac, 0x4b, 0xc7, 0x0f, 0x2a, 0x41, 0xe0, 0xf1, 0xd8, 0xad, 0x2b, 0xc7, 0xad, 0xb6, 0x45, 0x9f,
		0x16, 0xf8, 0x3c, 0x72, 0xde, 0xd7, 0xd3, 0xa9, 0x3b, 0x14, 0x4f, 0xca, 0xe5, 0xa3, 0xe3, 0x72,
		0xb9, 0x70, 0x7c, 0x70, 0x5c, 0x38, 0x3d, 0x3c, 0x2c, 0x1e, 0x15, 0x0f, 0x19, 0x6e, 0x7a, 0xe3,
		0xb5, 0x84, 0x27, 0x5a, 0x9f, 0xde, 0xf2, 0x67, 0x39, 0xb7, 0xd7, 0x6e, 0xe3, 0x90, 0x42, 0x1c,
		0x82, 0xb8, 0x41, 0x87, 0x14, 0xd0, 0x7f, 0x44, 0x8a, 0xb6, 0xa2, 0xff, 0x48, 0x6a, 0x3d, 0x5e,
		0x24, 0x92, 0x26, 0xe3, 0xd1, 0x22, 0x91, 0x94, 0x4c, 0x29, 0x90, 0x48, 0x8a, 0xe0, 0x1b, 0x82,
		0x6f, 0x08, 0xbe, 0x21, 0xf8, 0x86, 0xe0, 0x1b, 0x82, 0x6f, 0x08, 0xbe, 0x21, 0xf8, 0x86, 0xe0,
		0x1b, 0x53, 0xf0, 0x0d, 0x89, 0xa4, 0x48, 0x24, 0x05, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3,
		0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0xde, 0x1a, 0xa6, 0x8d, 0x44, 0x52,
		0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c, 0x30, 0x6c,
		0x30, 0xec, 0xcc, 0x32, 0x6c, 0x24, 0x92, 0xce, 0xeb, 0x29, 0x12, 0x49, 0x59, 0x47, 0x42, 0x22,
		0xe9, 0xb2, 0x44, 0x52, 0xd4, 0xb9, 0xe6, 0x5a, 0xdc, 0xe4, 0x16, 0x35, 0x15, 0x15, 0xae, 0x37,
		0xa4, 0xb8, 0xf5, 0xa8, 0x41, 0x94, 0xe3, 0x07, 0x5c, 0xb5, 0xad, 0xa7, 0xee, 0x80, 0xd2, 0xd6,
		0x06, 0xe3, 0x25, 0x28, 0x6d, 0x8d, 0xd2, 0xd6, 0x2b, 0x06, 0x42, 0x69, 0x6b, 0x8a, 0x01, 0x71,
		0x22, 0x21, 0x87, 0x13, 0x09, 0x19, 0x23, 0xf9, 0x4c, 0x27, 0x12, 0x0c, 0x65, 0x48, 0x61, 0xef,
		0x26, 0x87, 0xbd, 0x9b, 0xc4, 0x01, 0xc9, 0x18, 0x30, 0x99, 0x01, 0x28, 0x9e, 0xc8, 0x1a, 0xf6,
		0x6e, 0xa2, 0x00, 0x83, 0xbd, 0x9b, 0xd9, 0xd0, 0x23, 0xf6, 0x6e, 0x24, 0xef, 0x83, 0xbd, 0x9b,
		0xd4, 0x2e, 0x3d, 0xf6, 0x6e, 0x92, 0x18, 0x75, 0xeb, 0xb2, 0xa3, 0x7c, 0x43, 0xe9, 0x51, 0x3e,
		0x38, 0x36, 0x38, 0x36, 0x38, 0x36, 0x38, 0x36, 0x38, 0x36, 0x38, 0x36, 0x38, 0x36, 0x38, 0x36,
		0x38, 0x36, 0x38, 0x76, 0x1a, 0x6d, 0x16, 0xf2, 0xa3, 0x14, 0x6e, 0x8a, 0xfc, 0x28, 0x15, 0x82,
		0xb8, 0x11, 0xf9, 0x51, 0x93, 0x8c, 0x0c, 0xd4, 0xd9, 0x8b, 0xcb, 0x5a, 0x51, 0x67, 0x2f, 0xb5,
		0x0e, 0x2f, 0x76, 0xb5, 0x93, 0x71, 0x68, 0xb1, 0xab, 0x4d, 0xa1, 0x0f, 0xd8, 0xd5, 0x46, 0xc4,
		0x0d, 0x11, 0x37, 0x44, 0xdc, 0x10, 0x71, 0x43, 0xc4, 0x0d, 0x11, 0x37, 0x44, 0xdc, 0x10, 0x71,
		0x43, 0xc4, 0x0d, 0xbb, 0xda, 0xb4, 0x8c, 0x0f, 0xbb, 0xda, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8,
		0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xd8, 0xd5, 0xc6, 0xae,
		0x76, 0x72, 0x5e, 0x14, 0x76, 0xb5, 0x39, 0x77, 0xb5, 0x51, 0xf4, 0x83, 0x6b, 0x6d, 0x13, 0x5b,
		0xd3, 0xa4, 0x6b, 0x7e, 0xdc, 0xf4, 0x9f, 0xa4, 0x0f, 0xc9, 0x9b, 0x52, 0xf2, 0xc3, 0x1b, 0x51,
		0x7f, 0xc6, 0x9a, 0x1f, 0x14, 0xc5, 0x5a, 0x50, 0xf4, 0x23, 0xd1, 0xf0, 0x08, 0x8a, 0x7e, 0xa4,
		0x01, 0xc4, 0x51, 0xf4, 0x23, 0x0d, 0xaa, 0xcf, 0x01, 0x01, 0x8c, 0x50, 0xc0, 0x05, 0x09, 0xec,
		0xd0, 0xc0, 0x0e, 0x11, 0xbc, 0x50, 0x91, 0x4e, 0x8e, 0x8f, 0xf4, 0x28, 0x63, 0x51, 0x1e, 0x6c,
		0xdd, 0x98, 0x05, 0x22, 0x63, 0x80, 0x64, 0x0c, 0x98, 0xcc, 0x00, 0x14, 0x4f, 0x60, 0x0d, 0x5b,
		0x37, 0x51, 0x80, 0xc1, 0xd6, 0xcd, 0x6c, 0xe4, 0x11, 0x5b, 0x37, 0x92, 0xf7, 0xc1, 0xd6, 0x4d,
		0x6a, 0x97, 0x1e, 0x5b, 0x37, 0x49, 0x8c, 0xba, 0x3d, 0xe9, 0x51, 0x66, 0x1a, 0xfd, 0x2f, 0xb8,
		0x17, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8,
		0x36, 0xb8, 0x36, 0xb8, 0xf6, 0x86, 0x73, 0x6d, 0x23, 0x8d, 0xfe, 0xa3, 0xb7, 0x02, 0xd3, 0x06,
		0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06,
		0xd3, 0x4e, 0x17, 0xd3, 0x46, 0xba, 0x3a, 0x53, 0x6a, 0xf3, 0xb0, 0x49, 0x25, 0xaa, 0xb0, 0xc5,
		0x24, 0x35, 0xa8, 0xc2, 0x96, 0x5a, 0x7f, 0x08, 0x69, 0x86, 0xc9, 0xf8, 0x3b, 0x48, 0x33, 0xa4,
		0xd0, 0x07, 0xa4, 0x19, 0x22, 0x20, 0x83, 0x80, 0x0c, 0x02, 0x32, 0x08, 0xc8, 0x20, 0x20, 0x83,
		0x80, 0x0c, 0x02, 0x32, 0x08, 0xc8, 0x20, 0x20, 0x83, 0x34, 0x43, 0x7a, 0xd6, 0x87, 0x34, 0x43,
		0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d,
		0x70, 0xed, 0xad, 0xe3, 0xda, 0x48, 0x33, 0x04, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06,
		0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x06, 0xd3, 0x46, 0x9a, 0x21, 0x77, 0x9a,
		0x21, 0xca, 0xe2, 0x72, 0x2d, 0x6e, 0x72, 0x8b, 0x9a, 0x8a, 0xba, 0xb8, 0x43, 0x3a, 0x95, 0xc1,
		0xc2, 0xb8, 0xbe, 0xe3, 0xbe, 0x84, 0xd3, 0x4a, 0x57, 0x0c, 0x77, 0x76, 0x58, 0x14, 0xc0, 0x35,
		0xe8, 0x37, 0xa3, 0x00, 0x2e, 0x0a, 0xe0, 0xae, 0x18, 0x08, 0x05, 0x70, 0x53, 0x1a, 0x4a, 0x43,
		0x66, 0x7a, 0x02, 0xa1, 0x32, 0x64, 0xa6, 0x6b, 0x0c, 0xc8, 0x1e, 0xc1, 0x47, 0xdc, 0x3e, 0x87,
		0xb8, 0x7d, 0xe2, 0x20, 0x64, 0x0c, 0x8c, 0xcc, 0x80, 0x12, 0x4f, 0x54, 0x05, 0x71, 0xfb, 0x28,
		0xc0, 0x20, 0x6e, 0x3f, 0xf5, 0xe0, 0x88, 0xdb, 0xcb, 0xdf, 0x07, 0x71, 0xfb, 0xd4, 0x2e, 0x3d,
		0xe2, 0xf6, 0x49, 0x8c, 0x8a, 0xb8, 0x7d, 0x2c, 0xfa, 0x90, 0xd1, 0xb8, 0xfd, 0x4c, 0xd0, 0x10,
		0x25, 0x01, 0xe2, 0x12, 0x19, 0x94, 0x04, 0x40, 0xe0, 0x05, 0x81, 0x17, 0x04, 0x5e, 0x10, 0x78,
		0x41, 0xe0, 0x05, 0x81, 0x17, 0x04, 0x5e, 0x10, 0x78, 0x41, 0xe0, 0x05, 0x81, 0x17, 0x04, 0x5e,
		0x10, 0x78, 0x41, 0xe0, 0x05, 0x81, 0x17, 0x04, 0x5e, 0x64, 0x03, 0x2f, 0x48, 0x92, 0xe4, 0x5a,
		0x50, 0xb3, 0x0b, 0x99, 0x44, 0x62, 0xe4, 0xfd, 0xe0, 0x01, 0x86, 0x89, 0x91, 0x99, 0x4f, 0x87,
		0xb4, 0xda, 0x8e, 0x1f, 0x30, 0xe5, 0x44, 0x0e, 0xc7, 0x46, 0x62, 0xa4, 0x41, 0xff, 0x18, 0x89,
		0x91, 0x48, 0x8c, 0x5c, 0x31, 0x10, 0x12, 0x23, 0x53, 0x1a, 0x32, 0x43, 0x7c, 0x3e, 0x81, 0x90,
		0x18, 0xe2, 0xf3, 0x1a, 0x03, 0x8e, 0x22, 0x5c, 0x3e, 0x7b, 0x80, 0xde, 0x47, 0x84, 0x1e, 0x11,
		0xfa, 0x04, 0x61, 0xc8, 0x18, 0x1c, 0x99, 0x81, 0x25, 0x9e, 0xf8, 0x09, 0x22, 0xf4, 0x51, 0x80,
		0x41, 0x84, 0x7e, 0xea, 0xc1, 0x11, 0xa1, 0x97, 0xbf, 0x0f, 0x22, 0xf4, 0xa9, 0x5d, 0x7a, 0x44,
		0xe8, 0x93, 0x18, 0xb5, 0x9e, 0x6a, 0x9b, 0x75, 0xe9, 0xf8, 0x41, 0x25, 0x08, 0x3c, 0x1e, 0xbb,
		0x75, 0xe5, 0xb8, 0xd5, 0xb6, 0xe8, 0xd3, 0x02, 0x9f, 0x47, 0xce, 0xfb, 0x7a, 0x3a, 0x75, 0x87,
		0xe2, 0x49, 0xb9, 0x7c, 0x74, 0x5c, 0x2e, 0x17, 0x8e, 0x0f, 0x8e, 0x0b, 0xa7, 0x87, 0x87, 0xc5,
		0xa3, 0xe2, 0x21, 0xc3, 0x4d, 0x6f, 0xbc, 0x96, 0xf0, 0x44, 0xeb, 0xd3, 0x5b, 0xfe, 0x2c, 0xe7,
		0xf6, 0xda, 0x6d, 0xec, 0xc1, 0xc4, 0x21, 0x88, 0x9b, 0xb0, 0x07, 0x33, 0x88, 0x0e, 0x23, 0x03,
		0x36, 0x2e, 0x5f, 0x45, 0x06, 0x2c, 0x22, 0x6c, 0x88, 0xb0, 0x21, 0xc2, 0x86, 0x08, 0x1b, 0x22,
		0x6c, 0x88, 0xb0, 0x21, 0xc2, 0x86, 0x08, 0x1b, 0x22, 0x6c, 0x88, 0xb0, 0x21, 0xc2, 0x86, 0x08,
		0x1b, 0x22, 0x6c, 0x88, 0xb0, 0x21, 0xc2, 0x86, 0x08, 0x1b, 0x22, 0x6c, 0x0b, 0x23, 0x6c, 0x48,
		0x75, 0xe6, 0x5a, 0xd5, 0x04, 0x56, 0x33, 0xe9, 0x7c, 0xe7, 0x3e, 0x02, 0x67, 0x3f, 0xe7, 0xd9,
		0x1b, 0x71, 0x7c, 0x96, 0xa4, 0x67, 0x8a, 0x82, 0xbd, 0xc8, 0x7a, 0x4e, 0x34, 0x02, 0x82, 0xac,
		0xe7, 0x34, 0xa0, 0x35, 0xb2, 0x9e, 0xd3, 0xa0, 0xfa, 0x1c, 0x10, 0xc0, 0x08, 0x05, 0x5c, 0x90,
		0xc0, 0x0e, 0x0d, 0xec, 0x10, 0xc1, 0x0b, 0x15, 0xe9, 0xa4, 0xf1, 0xe4, 0x7b, 0x32, 0x66, 0x1a,
		0x28, 0xa3, 0x75, 0x32, 0x2b, 0xec, 0x18, 0x80, 0x1f, 0x6e, 0x18, 0x32, 0x06, 0x47, 0xc6, 0x60,
		0xc9, 0x0c, 0x3c, 0xf1, 0x44, 0xce, 0xb0, 0x37, 0x13, 0x05, 0x18, 0xec, 0xcd, 0xcc, 0x86, 0x16,
		0xb1, 0x37, 0x23, 0x79, 0x1f, 0xec, 0xcd, 0xa4, 0x76, 0xe9, 0xb1, 0x37, 0x93, 0xc4, 0xa8, 0xdb,
		0xd0, 0x3a, 0xd9, 0x48, 0xd3, 0x64, 0xb4, 0x4b, 0x06, 0xbb, 0x06, 0xbb, 0x06, 0xbb, 0x06, 0xbb,
		0x06, 0xbb, 0x06, 0xbb, 0x06, 0xbb, 0x06, 0xbb, 0x06, 0xbb, 0x46, 0xf5, 0xbf, 0x78, 0xf4, 0x61,
		0x23, 0xf2, 0x62, 0x86, 0x8d, 0x92, 0x71, 0xf4, 0x2c, 0x26, 0x9d, 0xc1, 0xd1, 0xb3, 0xd4, 0x7a,
		0x42, 0xd8, 0xe6, 0x4c, 0xc6, 0xd3, 0xc1, 0x36, 0x27, 0x81, 0x3a, 0x60, 0x9b, 0x13, 0x81, 0x18,
		0x04, 0x62, 0x10, 0x88, 0x41, 0x20, 0x06, 0x81, 0x18, 0x04, 0x62, 0x10, 0x88, 0x41, 0x20, 0x06,
		0x81, 0x18, 0x6c, 0x73, 0x92, 0x19, 0x3f, 0x6c, 0x73, 0x82, 0x5d, 0x83, 0x5d, 0x83, 0x5d, 0x83,
		0x5d, 0x83, 0x5d, 0x83, 0x5d, 0x83, 0x5d, 0x83, 0x5d, 0x83, 0x5d, 0x63, 0x9b, 0x33, 0x1e, 0x7d,
		0xd8, 0xa0, 0x6d, 0x4e, 0x9c, 0xff, 0xe7, 0x5a, 0xd6, 0x24, 0x96, 0x33, 0xe9, 0x02, 0x00, 0x43,
		0xf6, 0x94, 0x54, 0x05, 0x80, 0x1d, 0x83, 0x52, 0x43, 0x25, 0x2d, 0xdc, 0x52, 0x92, 0xd7, 0x29,
		0x8b, 0x20, 0x27, 0x09, 0x6a, 0xeb, 0x2e, 0xbf, 0x6a, 0x0a, 0x2b, 0xa6, 0x99, 0xfb, 0x40, 0x92,
		0xeb, 0xa0, 0x99, 0xdb, 0xa0, 0x9d, 0xcb, 0x40, 0x11, 0xe6, 0x20, 0x0c, 0x67, 0x50, 0x85, 0x2d,
		0xc8, 0xc3, 0x13, 0xe4, 0x61, 0x08, 0xda, 0x70, 0x83, 0x59, 0x94, 0xd3, 0xcd, 0x1d, 0xc8, 0x53,
		0xc5, 0x31, 0x89, 0xc3, 0x0a, 0x44, 0xee, 0x0c, 0x4a, 0xa8, 0xa4, 0x2c, 0xa6, 0x88, 0x12, 0x2a,
		0x49, 0xc4, 0x00, 0x43, 0x89, 0xeb, 0xb9, 0x7d, 0x3e, 0x44, 0x20, 0x6f, 0x63, 0x5b, 0x79, 0x4a,
		0x30, 0xd6, 0xe8, 0x35, 0x69, 0x22, 0x7a, 0x0c, 0x79, 0x7f, 0xf4, 0x81, 0x52, 0x86, 0x00, 0x29,
		0x53, 0x60, 0x94, 0xa7, 0x50, 0x23, 0xe3, 0x5e, 0x08, 0x6b, 0x14, 0x8c, 0x3b, 0xf0, 0x69, 0x22,
		0xe4, 0xf5, 0xce, 0x53, 0x19, 0x33, 0xf3, 0x4b, 0xca, 0x17, 0xd0, 0x34, 0xb2, 0xaa, 0x29, 0x0d,
		0x0c, 0xd6, 0xd3, 0x14, 0x18, 0x64, 0xb0, 0x0d, 0xff, 0x75, 0xdc, 0xff, 0xf2, 0xd8, 0x86, 0xe2,
		0x09, 0xe1, 0x98, 0xb7, 0x76, 0x10, 0x08, 0xcf, 0x25, 0x37, 0x0f, 0xf9, 0x3f, 0x77, 0xcb, 0x85,
		0xd3, 0xc7, 0x82, 0x55, 0xae, 0xff, 0x28, 0x17, 0x1e, 0x0b, 0xd6, 0x49, 0xfd, 0xb1, 0x60, 0x9d,
		0xd6, 0x7f, 0x3c, 0x16, 0xad, 0x83, 0xe1, 0xb7, 0xdf, 0x0f, 0xde, 0xfb, 0x3f, 0x9d, 0x8e, 0x7e,
		0x2a, 0x7e, 0x28, 0x8d, 0x7e, 0xde, 0xfb, 0xfc, 0xf9, 0xe3, 0xae, 0xc6, 0xe5, 0x3f, 0x3e, 0x7f,
		0xfe, 0xe7, 0xde, 0x3f, 0xe8, 0xf6, 0x85, 0xeb, 0x94, 0xf3, 0x7d, 0x73, 0x5f, 0xfb, 0x1d, 0x93,
		0x6e, 0x0c, 0x1f, 0x76, 0x92, 0x7d, 0x0e, 0xc4, 0x44, 0xa9, 0x62, 0xa2, 0x1a, 0xdb, 0x1d, 0x0a,
		0x81, 0xca, 0x1d, 0xc6, 0x49, 0xd7, 0x9d, 0x6c, 0xbe, 0x49, 0xce, 0x2b, 0xc5, 0x67, 0x63, 0x86,
		0x9a, 0xe5, 0xd6, 0x2e, 0xfe, 0x0a, 0xc4, 0xfb, 0x64, 0xcc, 0x35, 0xca, 0xff, 0x5b, 0xbc, 0xf5,
		0xdf, 0xc3, 0x71, 0x5b, 0x22, 0x6e, 0x64, 0x43, 0xad, 0x7c, 0xbd, 0x7a, 0x59, 0x7a, 0xd2, 0x72,
		0xf3, 0x6a, 0x65, 0xe4, 0xe3, 0xce, 0x66, 0xa5, 0xf7, 0xd2, 0x7f, 0x4c, 0xd1, 0x92, 0x32, 0x75,
		0x72, 0x2a, 0x11, 0x32, 0xae, 0xfd, 0x4e, 0xd3, 0x72, 0x9e, 0xcf, 0xa6, 0x04, 0x7c, 0xee, 0x17,
		0xa3, 0x9f, 0x67, 0x95, 0x20, 0xfa, 0x3b, 0x49, 0x2d, 0xc8, 0x5f, 0x08, 0xbf, 0xe9, 0x39, 0xdd,
		0x91, 0x3e, 0xe7, 0x6b, 0xb7, 0x5f, 0xcb, 0x39, 0xbb, 0xd5, 0xf2, 0x84, 0xef, 0xe7, 0x9e, 0xed,
		0x57, 0xa7, 0xfd, 0x96, 0x1b, 0xaa, 0x67, 0xcf, 0x1b, 0x28, 0x7d, 0xee, 0xb9, 0xe3, 0x7d, 0x76,
		0x27, 0x8f, 0x20, 0x7b, 0x3f, 0xb5, 0xdd, 0x08, 0xe5, 0x80, 0xa7, 0x4e, 0x80, 0x73, 0x3a, 0xa0,
		0xe9, 0x74, 0x55, 0xe0, 0x45, 0x33, 0x7c, 0x49, 0x16, 0xae, 0x24, 0x0b, 0x4f, 0xce, 0x87, 0x23,
		0x9d, 0x6e, 0x3e, 0x65, 0xe6, 0x49, 0x75, 0xe7, 0x20, 0xef, 0x74, 0xbf, 0x96, 0xf5, 0x77, 0xea,
		0x06, 0xa3, 0xa8, 0x6e, 0x7a, 0xcc, 0xaa, 0xe2, 0xad, 0xed, 0xd9, 0xaf, 0x22, 0x10, 0x9e, 0xdf,
		0xd7, 0xb9, 0x5c, 0xf0, 0x45, 0xe4, 0x16, 0x68, 0xe7, 0xc7, 0xa4, 0xb7, 0x05, 0x0b, 0xe9, 0xd8,
		0x16, 0x54, 0x52, 0x50, 0x2a, 0x45, 0x25, 0x57, 0x58, 0x72, 0xc5, 0xa5, 0x54, 0x60, 0x4d, 0x92,
		0xcf, 0x0d, 0x18, 0x3b, 0x0c, 0xd0, 0x92, 0x79, 0xa3, 0x7e, 0x04, 0xa3, 0x0e, 0xa3, 0xbe, 0x95,
		0x46, 0xfd, 0x88, 0xc4, 0xa8, 0x1f, 0xb1, 0x1a, 0xf5, 0x23, 0x18, 0x75, 0x18, 0x75, 0x18, 0x75,
		0x18, 0x75, 0x09, 0x24, 0xa9, 0xb4, 0x5a, 0x7e, 0xee, 0xb7, 0xcb, 0xca, 0x75, 0xce, 0x17, 0x41,
		0xe0, 0xb8, 0x2f, 0x7e, 0x2e, 0xe8, 0xe4, 0x1c, 0xb7, 0xe5, 0x7c, 0x75, 0x5a, 0x3d, 0xbb, 0x9d,
		0x9b, 0xb9, 0xff, 0x96, 0x58, 0x74, 0xd5, 0x38, 0xe0, 0xc6, 0xdb, 0x74, 0xb5, 0xbc, 0xa1, 0x94,
		0x5a, 0xf5, 0xc1, 0xcb, 0x68, 0x5b, 0x75, 0x8d, 0x1c, 0xb5, 0x79, 0x5d, 0xac, 0xba, 0xcd, 0x76,
		0xc7, 0x77, 0xdc, 0x97, 0x3e, 0xad, 0x0e, 0x6c, 0xc7, 0x15, 0xde, 0xc0, 0xbc, 0x0f, 0xd4, 0x33,
		0x54, 0x42, 0xcb, 0xef, 0x8a, 0xa6, 0xf3, 0xec, 0x34, 0x3f, 0xbb, 0x2d, 0x3b, 0xb0, 0x73, 0x1d,
		0x57, 0x4b, 0x47, 0x37, 0xd5, 0xe8, 0x23, 0xc1, 0xd7, 0xa8, 0x8e, 0x6f, 0x8c, 0xe1, 0x8f, 0xf5,
		0xc9, 0x7a, 0xdc, 0xd8, 0xbf, 0xda, 0x2e, 0x17, 0xcb, 0xee, 0x96, 0x84, 0xdc, 0xc5, 0xda, 0xd0,
		0x8a, 0x27, 0x23, 0xeb, 0xe7, 0x73, 0xf5, 0x27, 0xd6, 0x58, 0x03, 0xd9, 0x19, 0xa6, 0x9a, 0xd9,
		0xd5, 0x2f, 0xbf, 0xfc, 0x95, 0x16, 0xff, 0x65, 0xc9, 0x4b, 0x8e, 0x37, 0xe2, 0x06, 0xeb, 0xb0,
		0xe4, 0x23, 0xb1, 0xf6, 0xdd, 0xe2, 0xef, 0xb3, 0x69, 0xed, 0xab, 0xc5, 0xdb, 0x47, 0x5b, 0xf6,
		0xb2, 0xf1, 0xf6, 0xc9, 0x56, 0x2f, 0x71, 0x7c, 0x76, 0xbd, 0x46, 0x1b, 0x16, 0xd2, 0x64, 0xbb,
		0xd5, 0xea, 0xff, 0x6c, 0xb7, 0x73, 0xd5, 0xe0, 0x8b, 0xf0, 0x5c, 0x11, 0x84, 0xb6, 0x78, 0x2e,
		0x10, 0x16, 0x74, 0xa6, 0xe3, 0x60, 0xb9, 0xd7, 0x4e, 0x4b, 0xb4, 0xd7, 0xdd, 0x31, 0x9e, 0xfd,
		0x8d, 0x6d, 0x67, 0x65, 0xec, 0xe9, 0xb4, 0xdd, 0x14, 0x41, 0x9c, 0x53, 0x57, 0xb2, 0xe6, 0x51,
		0xd9, 0x0c, 0x2a, 0x9b, 0xbb, 0x79, 0xb3, 0xd6, 0x7f, 0x2f, 0x66, 0x2c, 0x8a, 0xcb, 0x44, 0xf3,
		0x62, 0x24, 0x3e, 0xf1, 0xa7, 0x6f, 0xbc, 0x40, 0xe1, 0x95, 0x31, 0x27, 0x61, 0x4e, 0x8c, 0x1f,
		0x3a, 0x5d, 0xab, 0x2d, 0xbe, 0x8a, 0xf6, 0x1c, 0xc3, 0x1c, 0x0f, 0x3b, 0x2b, 0xc6, 0x9f, 0x5d,
		0xdb, 0x6d, 0xe5, 0x64, 0x4e, 0x8d, 0x49, 0x92, 0x48, 0x69, 0xd2, 0xa8, 0x42, 0x12, 0xe5, 0x85,
		0x5b, 0x97, 0x03, 0x6a, 0x73, 0x3e, 0x6d, 0x8e, 0xa7, 0x24, 0xfc, 0x72, 0x14, 0x48, 0xdb, 0xb0,
		0xef, 0x28, 0xa8, 0x59, 0x92, 0xe8, 0x7f, 0x59, 0xf9, 0x39, 0x82, 0xf2, 0x83, 0xc8, 0x6b, 0x38,
		0x6a, 0x1f, 0xe7, 0x7b, 0x6d, 0x91, 0x11, 0xa0, 0x6f, 0xdb, 0x2f, 0x1b, 0x09, 0xf4, 0xfd, 0xf7,
		0x4a, 0x0b, 0xd0, 0xdb, 0x2f, 0x2f, 0x9e, 0x78, 0x91, 0x73, 0x00, 0xc2, 0x35, 0x9a, 0xbe, 0x58,
		0x0d, 0xee, 0x6f, 0x06, 0xdf, 0x0d, 0xf7, 0x08, 0xda, 0x9d, 0x17, 0xa7, 0x69, 0xb7, 0x73, 0x53,
		0xb4, 0xc4, 0x13, 0x5d, 0x4f, 0xf8, 0xc2, 0x0d, 0x1c, 0xf7, 0xe5, 0xb3, 0x3b, 0xbe, 0x5d, 0xec,
		0x08, 0x42, 0xda, 0xc1, 0x3e, 0x9e, 0x80, 0x6f, 0x1e, 0xd8, 0xc7, 0x52, 0x00, 0x80, 0xfd, 0x3a,
		0xaa, 0xef, 0x8c, 0xb8, 0xfe, 0xfd, 0xcd, 0x75, 0xf5, 0x61, 0xff, 0xfe, 0xe2, 0x97, 0x09, 0xd9,
		0x1f, 0xc4, 0xdd, 0xfa, 0x1c, 0xbf, 0xe3, 0x37, 0x33, 0x45, 0xee, 0xdb, 0x8e, 0x2b, 0xac, 0x66,
		0xe7, 0x75, 0x33, 0x81, 0x7f, 0xfc, 0x72, 0x69, 0x41, 0x7f, 0xbf, 0xa3, 0xc4, 0xf1, 0x87, 0x97,
		0xa9, 0x21, 0xfe, 0x45, 0x5f, 0x32, 0x3d, 0xd1, 0xb6, 0x03, 0xd1, 0xea, 0xf3, 0x93, 0x50, 0x78,
		0x73, 0xd2, 0x01, 0xe2, 0xd4, 0xc3, 0x7b, 0x7c, 0x59, 0xde, 0x40, 0x8c, 0x8f, 0x2d, 0xeb, 0x00,
		0xfa, 0x95, 0x40, 0x3f, 0xcb, 0xe8, 0x43, 0x7f, 0x77, 0x40, 0x99, 0xbc, 0x4e, 0xaf, 0xaf, 0x46,
		0xb3, 0xdb, 0x2f, 0x7e, 0x46, 0xa0, 0x3e, 0xe6, 0xfe, 0x47, 0xf6, 0x60, 0x3e, 0xde, 0xfe, 0x84,
		0x21, 0x88, 0x1f, 0x8a, 0x88, 0x25, 0xb5, 0x95, 0x18, 0xae, 0xd2, 0xf4, 0xc5, 0xb4, 0xf1, 0x9c,
		0x91, 0xe4, 0xf6, 0x47, 0x9e, 0x92, 0xdc, 0x8f, 0xb9, 0xdc, 0xc3, 0x17, 0xe1, 0x8b, 0xcf, 0xee,
		0x02, 0x67, 0xc0, 0xf6, 0x44, 0xce, 0x6e, 0xfb, 0x9d, 0xdc, 0x5f, 0x6e, 0xe7, 0x6f, 0x37, 0x67,
		0xfb, 0xb9, 0xfb, 0xdf, 0x6a, 0xb9, 0x5d, 0xff, 0x6f, 0x27, 0x68, 0x7e, 0xe9, 0x8f, 0xe5, 0x78,
		0x41, 0xcf, 0x6e, 0x4f, 0xc5, 0x35, 0xf7, 0x3e, 0xe4, 0x6a, 0x77, 0x9f, 0x72, 0xbb, 0xfd, 0x5f,
		0xbc, 0x78, 0x03, 0x8b, 0xd3, 0xbf, 0xaf, 0xe3, 0xbe, 0x0c, 0xf4, 0xe8, 0xc9, 0x73, 0x5a, 0x2f,
		0x8e, 0xfb, 0xb2, 0xf7, 0x21, 0x77, 0xf7, 0x5b, 0xed, 0xb3, 0xbb, 0xbb, 0x50, 0x9d, 0xf6, 0x36,
		0xc4, 0x1a, 0x49, 0x6e, 0x37, 0x6e, 0x8e, 0x25, 0x92, 0xdb, 0x2e, 0x4c, 0xdc, 0x0a, 0x2d, 0xfc,
		0x4b, 0x7d, 0xd9, 0x96, 0x44, 0xbc, 0xcd, 0x25, 0xf5, 0x4d, 0xa5, 0x15, 0x8b, 0xb7, 0x6c, 0x0f,
		0x6e, 0xf1, 0x5c, 0x47, 0xdf, 0x6b, 0xf6, 0x37, 0x73, 0x80, 0xb7, 0xee, 0xcd, 0x64, 0xdf, 0x68,
		0xf6, 0xa1, 0x26, 0xb7, 0x9e, 0xba, 0x6d, 0xbe, 0x6d, 0x37, 0xbb, 0x91, 0x9b, 0x4d, 0x0a, 0xba,
		0xf7, 0xff, 0x3a, 0xf7, 0x90, 0x8b, 0x55, 0x7e, 0xa9, 0x6a, 0xaf, 0x52, 0xe1, 0xd9, 0xb8, 0x40,
		0x73, 0x51, 0x42, 0xe0, 0x3a, 0x95, 0x8c, 0xad, 0x7a, 0xb1, 0x55, 0x2c, 0xea, 0xb8, 0x37, 0x17,
		0xa4, 0xdc, 0xad, 0x5e, 0xc8, 0x65, 0x96, 0x2a, 0xdf, 0x1c, 0xcf, 0xd2, 0x92, 0xb7, 0x19, 0x4f,
		0xc8, 0xe8, 0x73, 0xcb, 0x76, 0x20, 0x57, 0xa2, 0xee, 0x5a, 0x94, 0x8d, 0x83, 0xaa, 0x31, 0x96,
		0x46, 0x16, 0x35, 0xa5, 0x51, 0x52, 0x1a, 0x15, 0xe3, 0x2d, 0xdd, 0x6a, 0xd4, 0x59, 0xb6, 0x11,
		0xba, 0x8e, 0x7c, 0xe4, 0xfd, 0x37, 0x3f, 0x10, 0xaf, 0x56, 0xd7, 0x73, 0x3a, 0x9e, 0x13, 0xbc,
		0xad, 0x9f, 0x8e, 0xd0, 0xb3, 0x9c, 0xbb, 0x30, 0x1e, 0x93, 0x2d, 0x24, 0x1e, 0xa8, 0x6e, 0x76,
		0x37, 0x34, 0x52, 0xdd, 0xec, 0x72, 0x33, 0xd9, 0xd8, 0x55, 0xb2, 0x26, 0x55, 0xb0, 0x1c, 0x37,
		0x28, 0xc6, 0x49, 0x54, 0x97, 0xa8, 0xd3, 0x24, 0x59, 0x7f, 0x49, 0xee, 0x04, 0xb1, 0x02, 0x89,
		0x52, 0x2a, 0x9a, 0x13, 0x16, 0xc3, 0x91, 0xbd, 0x4e, 0xa3, 0xc2, 0xcd, 0xbb, 0xdc, 0x91, 0x68,
		0xe3, 0x53, 0x71, 0x74, 0x78, 0x78, 0x70, 0x68, 0x70, 0x3a, 0x88, 0xe8, 0x63, 0xdd, 0x48, 0xfa,
		0x8e, 0x3e, 0x7d, 0xec, 0x23, 0xc4, 0xfe, 0xe0, 0x7f, 0xab, 0x1a, 0xfa, 0x2e, 0x20, 0x7f, 0x0b,
		0xe8, 0xcd, 0x14, 0x5b, 0x5b, 0x4b, 0x0a, 0xd6, 0x46, 0x3b, 0x40, 0x0c, 0xd2, 0x48, 0x0c, 0x26,
		0x7e, 0x45, 0x6c, 0x4a, 0x10, 0x3b, 0x78, 0x96, 0x9a, 0x5d, 0x6b, 0x90, 0x01, 0xfe, 0xb0, 0xd6,
		0x1a, 0xe7, 0x41, 0xcd, 0x99, 0xc8, 0xdc, 0x06, 0x43, 0x3c, 0x51, 0xdb, 0xc0, 0xcd, 0x85, 0x58,
		0xa2, 0x28, 0x69, 0x93, 0xe3, 0x06, 0x38, 0x25, 0x4f, 0x73, 0x0c, 0x01, 0xec, 0xab, 0xdd, 0x96,
		0x9f, 0xf7, 0x19, 0x08, 0xec, 0x8f, 0x20, 0x7d, 0x92, 0xea, 0xd9, 0xee, 0xb5, 0x07, 0x93, 0x76,
		0x7f, 0x79, 0xf3, 0x1f, 0xc5, 0xb3, 0x51, 0x85, 0x8c, 0x9d, 0x8d, 0x92, 0xd4, 0x0a, 0x5d, 0xed,
		0x20, 0xd3, 0x12, 0x32, 0x6d, 0xa1, 0xd1, 0x1a, 0x39, 0xed, 0x51, 0x70, 0x07, 0x72, 0x5a, 0x35,
		0x92, 0x67, 0xe2, 0x72, 0x56, 0x57, 0x78, 0x4e, 0xa7, 0x65, 0x05, 0xfd, 0xd1, 0x14, 0x96, 0x7e,
		0x8c, 0xf3, 0x0a, 0x15, 0x44, 0xf3, 0x55, 0xb7, 0xf7, 0xda, 0x7f, 0x83, 0x14, 0x1c, 0xf4, 0x1c,
		0xce, 0xc5, 0x6b, 0xa7, 0x25, 0xd4, 0xb1, 0x66, 0x32, 0x84, 0x3a, 0xd8, 0x54, 0xce, 0x1f, 0x6a,
		0xbf, 0x55, 0x01, 0x37, 0x80, 0x9b, 0x0d, 0x85, 0x1b, 0xbb, 0x19, 0x38, 0x5f, 0x9d, 0xe0, 0x6d,
		0xeb, 0x01, 0x67, 0xb4, 0xf9, 0xa3, 0x88, 0x35, 0x2b, 0x8e, 0x0d, 0x01, 0x25, 0x80, 0x12, 0x19,
		0x46, 0x89, 0x27, 0xdb, 0x17, 0x93, 0x8d, 0x48, 0xcb, 0x13, 0xcf, 0x3a, 0x28, 0x71, 0xac, 0x70,
		0xed, 0x6d, 0x18, 0xac, 0x8b, 0x57, 0xc5, 0x61, 0xa0, 0x8b, 0x29, 0x40, 0x94, 0xd1, 0x0e, 0x90,
		0xd3, 0xb2, 0x5e, 0xed, 0xa6, 0x3a, 0xb4, 0xcc, 0x0e, 0x03, 0x8c, 0x01, 0xc6, 0x6c, 0x1c, 0xc6,
		0xbc, 0xda, 0x4d, 0x6b, 0x54, 0x4e, 0x49, 0x07, 0x5c, 0x4e, 0xd4, 0xc0, 0x45, 0xab, 0x34, 0x7a,
		0xfe, 0xcf, 0xc7, 0x82, 0x75, 0x6a, 0x5b, 0xcf, 0x15, 0xeb, 0xa7, 0xfa, 0xf7, 0xd2, 0xfb, 0xee,
		0xd9, 0xec, 0xcf, 0x7b, 0xdf, 0x0f, 0xdf, 0x15, 0xaa, 0x94, 0xd7, 0x55, 0x5e, 0x85, 0xa2, 0xd4,
		0x3b, 0xd7, 0xfb, 0xa4, 0x07, 0x8f, 0x63, 0x6f, 0xe5, 0xaf, 0x43, 0xe4, 0x98, 0x5b, 0xfb, 0xc0,
		0x64, 0x60, 0x72, 0x06, 0x31, 0x39, 0x76, 0x6a, 0xc2, 0x32, 0xf9, 0x56, 0x68, 0x29, 0xa5, 0xd9,
		0x3a, 0x4a, 0xa3, 0x98, 0x0d, 0x45, 0x2b, 0x28, 0xaa, 0x4e, 0x81, 0x8a, 0xa9, 0x0f, 0x91, 0x71,
		0x08, 0x9b, 0xfd, 0x68, 0xb4, 0xbd, 0x21, 0x69, 0xc9, 0x44, 0x3d, 0xb5, 0x0a, 0xa9, 0x14, 0xac,
		0xd3, 0x6b, 0xa8, 0x90, 0x4f, 0x3d, 0x13, 0x2d, 0x11, 0xe8, 0x0b, 0xf9, 0x4c, 0x52, 0x3b, 0x16,
		0x56, 0x9b, 0x59, 0x95, 0xef, 0x21, 0xff, 0xaa, 0x31, 0x5e, 0x33, 0xff, 0x2a, 0x5e, 0x9f, 0x84,
		0xe7, 0xcb, 0x6f, 0xfa, 0x8e, 0x2f, 0x64, 0xde, 0xf5, 0x2d, 0x61, 0xd7, 0x97, 0x94, 0x3a, 0x64,
		0x7a, 0xd7, 0x77, 0x28, 0x73, 0xea, 0x74, 0x79, 0x74, 0xfd, 0x76, 0x94, 0xb3, 0x04, 0x4b, 0xce,
		0x10, 0x4b, 0x56, 0x2f, 0x52, 0x1d, 0x3b, 0xf9, 0x6b, 0xad, 0xcc, 0xa8, 0x16, 0x97, 0x25, 0xa2,
		0x46, 0xa9, 0xab, 0x25, 0xa9, 0xa8, 0x40, 0x54, 0x8a, 0x44, 0xae, 0x50, 0xe4, 0x8a, 0x45, 0xab,
		0x60, 0x9a, 0x14, 0x54, 0x51, 0x66, 0xb4, 0xfb, 0x49, 0x4f, 0x36, 0x31, 0x85, 0xfd, 0xac, 0xb6,
		0x27, 0x11, 0xb1, 0x34, 0xc7, 0x1a, 0x63, 0x8c, 0xf7, 0x28, 0x3e, 0x7e, 0x1c, 0x36, 0x8e, 0xdb,
		0x97, 0x2c, 0xdd, 0xa8, 0xbf, 0x1c, 0xef, 0x4a, 0xbd, 0xd4, 0xec, 0x80, 0x00, 0xc2, 0x64, 0xaa,
		0x96, 0x11, 0xd9, 0x79, 0x65, 0xca, 0x0a, 0xf8, 0x02, 0x7c, 0x69, 0xc3, 0x97, 0x2a, 0x6f, 0x08,
		0x07, 0x18, 0x67, 0x5d, 0xe8, 0xaf, 0x73, 0x58, 0xc0, 0x6a, 0x3c, 0xe2, 0x87, 0x54, 0x04, 0x5a,
		0x74, 0x59, 0x05, 0xa5, 0x7a, 0x32, 0xa8, 0x29, 0xb5, 0xba, 0xb2, 0xa9, 0x2d, 0x9b, 0xfa, 0xf2,
		0xa8, 0xb1, 0x9e, 0x3a, 0x13, 0x44, 0x2b, 0x69, 0xd8, 0x49, 0x94, 0xa5, 0x50, 0xa4, 0x5a, 0x2d,
		0x35, 0x9d, 0x04, 0xdd, 0xe2, 0x15, 0x53, 0xb1, 0xe8, 0xd6, 0x4d, 0x27, 0xc2, 0x3c, 0xae, 0xa6,
		0x67, 0x3f, 0xb5, 0x05, 0x21, 0xa2, 0x4e, 0x8f, 0x0a, 0x54, 0x05, 0xaa, 0x02, 0x55, 0x53, 0x86,
		0xaa, 0x4f, 0x9d, 0x4e, 0x5b, 0x68, 0x75, 0x9e, 0x88, 0x40, 0x69, 0x31, 0x83, 0xf0, 0xd7, 0xec,
		0xb4, 0xdb, 0xa2, 0x19, 0x38, 0xee, 0x0b, 0x1d, 0xf8, 0x4d, 0x8d, 0x09, 0xe8, 0x03, 0xf4, 0x01,
		0xfa, 0x00, 0x7d, 0xe9, 0x84, 0xbe, 0x9e, 0x1b, 0xc8, 0x6c, 0xa4, 0xc6, 0x00, 0xbe, 0xd1, 0x88,
		0x34, 0xb0, 0x57, 0x04, 0xec, 0x01, 0xf6, 0xb6, 0x15, 0xf6, 0x74, 0xc3, 0x64, 0xe1, 0x40, 0x03,
		0xf7, 0x59, 0x78, 0x5e, 0x87, 0x40, 0xd3, 0x17, 0xfb, 0xe6, 0xa3, 0xc1, 0x89, 0xd6, 0x92, 0x86,
		0xf3, 0x90, 0x83, 0x00, 0x07, 0x18, 0x30, 0x82, 0x02, 0x17, 0x38, 0xb0, 0x83, 0x04, 0x3b, 0x58,
		0xf0, 0x82, 0x06, 0x0d, 0x78, 0x10, 0x81, 0x08, 0x3d, 0x87, 0x5a, 0x66, 0xf2, 0x8f, 0xca, 0x94,
		0x32, 0x3b, 0x82, 0x80, 0x13, 0xc2, 0x21, 0xf5, 0x92, 0x63, 0x97, 0x7d, 0xd1, 0xea, 0x54, 0x8e,
		0x2a, 0x99, 0xd6, 0x10, 0xb6, 0x46, 0x86, 0x27, 0x4a, 0xbe, 0x5d, 0x3a, 0x3e, 0x61, 0xd6, 0x28,
		0xb3, 0xc6, 0xcd, 0x2e, 0xa9, 0xfd, 0x2d, 0xf3, 0x4b, 0x2a, 0xd7, 0x60, 0x2f, 0xf5, 0xab, 0xbc,
		0x93, 0xce, 0xd1, 0xea, 0x3b, 0xe9, 0x78, 0x1e, 0x02, 0x2d, 0x18, 0x52, 0x43, 0xc7, 0xb5, 0xba,
		0x7f, 0x05, 0x5c, 0xc4, 0x73, 0x3c, 0x3a, 0x98, 0x27, 0x98, 0x27, 0x98, 0x27, 0x98, 0x27, 0x98,
		0x27, 0x98, 0x27, 0x98, 0x27, 0x98, 0x27, 0x98, 0x27, 0x98, 0x67, 0xa7, 0x17, 0x70, 0x52, 0xcf,
		0x70, 0x78, 0x70, 0x4f, 0x70, 0x4f, 0x70, 0x4f, 0x70, 0x4f, 0x70, 0x4f, 0x70, 0x4f, 0x70, 0x4f,
		0x70, 0x4f, 0x70, 0x4f, 0x70, 0x4f, 0xef, 0x1b, 0xef, 0x86, 0xfb, 0x64, 0x7c, 0xb0, 0x4f, 0xb0,
		0x4f, 0xb0, 0x4f, 0xb0, 0x4f, 0xb0, 0x4f, 0xb0, 0x4f, 0xb0, 0x4f, 0xb0, 0x4f, 0xb0, 0x4f, 0xb0,
		0xcf, 0x80, 0x99, 0x7d, 0x06, 0x60, 0x9f, 0x60, 0x9f, 0x60, 0x9f, 0x60, 0x9f, 0x60, 0x9f, 0x60,
		0x9f, 0x60, 0x9f, 0x60, 0x9f, 0x60, 0x9f, 0x60, 0x9f, 0x21, 0xfb, 0xec, 0xb9, 0x7f, 0xb9, 0x9d,
		0xbf, 0x5d, 0x5e, 0x0a, 0x3a, 0x77, 0x13, 0xf0, 0x50, 0xf0, 0x50, 0xf0, 0x50, 0xf0, 0x50, 0xf0,
		0x50, 0xf0, 0x50, 0xf0, 0x50, 0xf0, 0x50, 0xf0, 0xd0, 0xec, 0xf2, 0xd0, 0x44, 0x0f, 0xdd, 0x2b,
		0x76, 0x4f, 0x58, 0x3a, 0x9e, 0x72, 0x57, 0x85, 0x51, 0xab, 0x82, 0xd1, 0xbf, 0xa3, 0xb2, 0xb8,
		0x44, 0xe5, 0x35, 0x86, 0x4f, 0x16, 0x78, 0xbd, 0x66, 0x30, 0xea, 0xdb, 0x99, 0xbf, 0xb4, 0x9b,
		0xdd, 0x46, 0x6d, 0x7c, 0xf7, 0xc6, 0xd5, 0xe0, 0xae, 0x8d, 0xf3, 0xf1, 0xfd, 0x32, 0x58, 0xdc,
		0xa4, 0xe5, 0xf8, 0x81, 0xe7, 0x3c, 0xf5, 0x68, 0x2b, 0x3b, 0xcd, 0x8c, 0x8a, 0xda, 0x4e, 0x06,
		0xbd, 0x0a, 0x14, 0x39, 0x41, 0x6d, 0xa7, 0x38, 0x12, 0x87, 0xda, 0x4e, 0x39, 0x9a, 0x1e, 0x0b,
		0x91, 0x99, 0xd5, 0xed, 0xb5, 0x00, 0xe0, 0x03, 0xf0, 0x01, 0xf8, 0xf8, 0x80, 0x8f, 0xa2, 0xd5,
		0xf4, 0x52, 0x0c, 0x3c, 0x26, 0x18, 0x8b, 0xbf, 0x15, 0x75, 0x3a, 0xb0, 0xb7, 0xd3, 0x15, 0x9e,
		0xf5, 0x97, 0x20, 0xac, 0x4f, 0x1f, 0x8e, 0x08, 0xe4, 0x05, 0xf2, 0x02, 0x79, 0x53, 0x86, 0xbc,
		0xca, 0xcd, 0x5e, 0x97, 0xe9, 0xe7, 0x11, 0xc1, 0x50, 0xb4, 0x51, 0x67, 0xc2, 0xf0, 0x3d, 0x47,
		0x94, 0x99, 0x29, 0x14, 0xc9, 0x15, 0x55, 0xe6, 0x8c, 0x33, 0x12, 0x46, 0x91, 0x59, 0xa2, 0xc7,
		0xdc, 0x4b, 0x45, 0xd0, 0x9c, 0xd6, 0xe8, 0x72, 0xa5, 0x24, 0xec, 0x5a, 0xcf, 0x20, 0xcf, 0xea,
		0xda, 0x5e, 0xe0, 0x0a, 0xcf, 0x72, 0x5a, 0x74, 0x4c, 0x6b, 0x6a, 0x4c, 0x70, 0x2d, 0x70, 0x2d,
		0x70, 0xad, 0x94, 0x71, 0xad, 0x57, 0xbb, 0x69, 0xd9, 0xad, 0x96, 0x27, 0x7c, 0x9f, 0xd2, 0xbd,
		0x3d, 0xa1, 0x71, 0x6f, 0x03, 0xe1, 0xb9, 0x64, 0x9c, 0x2b, 0xff, 0xe7, 0x63, 0xc1, 0x3a, 0xb5,
		0xad, 0xe7, 0x8a, 0xf5, 0x53, 0xfd, 0x7b, 0xe9, 0x7d, 0xf7, 0x6c, 0xf6, 0xe7, 0xbd, 0xef, 0x87,
		0xef, 0xff, 0xd0, 0x97, 0x90, 0x3a, 0xc5, 0xab, 0xdf, 0xdc, 0xd7, 0x7e, 0xcf, 0xea, 0xfb, 0x67,
		0xd8, 0xf2, 0x91, 0x06, 0x19, 0xa6, 0x07, 0x85, 0xed, 0x83, 0xed, 0x83, 0xed, 0x43, 0x9c, 0x01,
		0x71, 0x06, 0xc4, 0x19, 0x10, 0x67, 0x40, 0x9c, 0x01, 0x71, 0x06, 0xe1, 0x59, 0xdd, 0x8e, 0x17,
		0x58, 0xa3, 0x4e, 0x9f, 0xb4, 0x94, 0x2b, 0x1c, 0x19, 0xbc, 0x0b, 0xbc, 0x0b, 0xbc, 0x0b, 0xbc,
		0x0b, 0xbc, 0x0b, 0xbc, 0x0b, 0xbc, 0x0b, 0xbc, 0x6b, 0xbb, 0x79, 0x17, 0x3d, 0xdf, 0x02, 0xcf,
		0x02, 0xcf, 0x02, 0xcf, 0x02, 0xcf, 0x02, 0xcf, 0x02, 0xcf, 0x02, 0xcf, 0x02, 0xcf, 0x02, 0xcf,
		0xca, 0xe5, 0xf2, 0xfe, 0x9b, 0xdb, 0xfc, 0xe2, 0x75, 0x5c, 0xe7, 0xff, 0xd1, 0x9c, 0x7c, 0x0c,
		0x01, 0x7d, 0x7e, 0x60, 0xb0, 0x2e, 0xb0, 0x2e, 0xb0, 0xae, 0x94, 0xb1, 0xae, 0x41, 0x3d, 0x9d,
		0x39, 0x4d, 0xb5, 0x82, 0xfe, 0x6d, 0x08, 0xf3, 0x6b, 0xca, 0x04, 0x63, 0x55, 0x47, 0xae, 0xe0,
		0x7b, 0x26, 0x21, 0xd6, 0x0f, 0xc4, 0x2b, 0x69, 0xa6, 0xe2, 0x64, 0x48, 0xc0, 0x2a, 0x60, 0x15,
		0xb0, 0x9a, 0x32, 0x58, 0x45, 0xa2, 0x22, 0x12, 0x15, 0x91, 0xa8, 0x18, 0x38, 0xaf, 0xa2, 0xd3,
		0x0b, 0xe8, 0xac, 0xde, 0x78, 0x40, 0xd8, 0x3c, 0xd8, 0x3c, 0xd8, 0xbc, 0x34, 0xba, 0x12, 0x23,
		0x0d, 0x85, 0x0b, 0x41, 0x76, 0xa5, 0xe2, 0x42, 0x53, 0x15, 0xb3, 0xa2, 0x2d, 0x62, 0xa5, 0xa6,
		0x35, 0xf2, 0x13, 0x27, 0x77, 0x85, 0xe4, 0x14, 0xf7, 0x01, 0x4c, 0xa7, 0x24, 0x4a, 0xfe, 0xd2,
		0xf1, 0x83, 0x4a, 0x10, 0x78, 0x4a, 0x0b, 0x93, 0xbf, 0x72, 0xdc, 0x6a, 0x5b, 0xf4, 0xe1, 0xc8,
		0x57, 0xb3, 0x3d, 0xf9, 0x2b, 0xfb, 0xdb, 0xd4, 0x08, 0x34, 0x15, 0xf6, 0xf2, 0x37, 0x5e, 0x4b,
		0x78, 0xa2, 0xf5, 0xa9, 0x3f, 0x35, 0x6e, 0xaf, 0xdd, 0x66, 0x5d, 0x01, 0x4d, 0xe1, 0xa6, 0x12,
		0x6a, 0x05, 0x84, 0x8b, 0x53, 0x7a, 0x4d, 0x4e, 0x4b, 0xe2, 0xcb, 0x7a, 0xbc, 0x4f, 0xc6, 0x5c,
		0x0b, 0xd5, 0x35, 0xd0, 0x9e, 0xfb, 0x78, 0xb3, 0xb3, 0xfe, 0x5d, 0x63, 0xbc, 0x67, 0x7e, 0xb4,
		0x4c, 0xf1, 0xde, 0x2e, 0xb4, 0x84, 0x83, 0xab, 0x62, 0xce, 0xa2, 0x1c, 0x17, 0x95, 0xe6, 0x9c,
		0x2a, 0xdc, 0x52, 0x83, 0x43, 0xaa, 0x72, 0x45, 0x6d, 0x4e, 0xa8, 0xcd, 0xfd, 0xf4, 0x38, 0x1e,
		0xad, 0x66, 0x49, 0x73, 0xb3, 0x09, 0x07, 0x13, 0xf6, 0xb3, 0x5c, 0xed, 0x1f, 0x95, 0x1a, 0x3f,
		0x61, 0x2d, 0x9f, 0x8f, 0x1f, 0x47, 0xb5, 0x29, 0xe3, 0x17, 0xeb, 0xa1, 0xd1, 0xcb, 0x21, 0x99,
		0x90, 0x56, 0xcc, 0xe1, 0x65, 0x72, 0x9a, 0x59, 0x94, 0xd5, 0xcc, 0x12, 0x34, 0x73, 0x63, 0x35,
		0xf3, 0xc2, 0x91, 0x23, 0x6d, 0x43, 0x8e, 0xf8, 0xd5, 0x6e, 0xcb, 0xcf, 0xfb, 0x4c, 0xe1, 0xbd,
		0xfe, 0x08, 0x92, 0xb3, 0x76, 0x21, 0x9e, 0xed, 0x5e, 0x7b, 0x30, 0x69, 0xf7, 0x97, 0x37, 0xff,
		0x91, 0xbd, 0x5c, 0x2d, 0x46, 0xa2, 0x1c, 0x13, 0xd1, 0x89, 0x81, 0x10, 0xc4, 0x3c, 0x74, 0x63,
		0x1c, 0x64, 0x31, 0x0d, 0xb2, 0x18, 0x06, 0x4d, 0xcc, 0x82, 0xd7, 0x8f, 0x52, 0x8e, 0x41, 0xcc,
		0xc6, 0x1c, 0xba, 0xc2, 0x73, 0x3a, 0x2d, 0xd5, 0x90, 0x83, 0x4e, 0x88, 0x41, 0x31, 0xa4, 0x20,
		0xc1, 0xd8, 0x25, 0x00, 0x7e, 0x30, 0x17, 0xaf, 0x9d, 0x96, 0x50, 0xc7, 0x9a, 0xc9, 0x10, 0xea,
		0x60, 0x53, 0x39, 0x7f, 0xa8, 0xfd, 0x56, 0x05, 0xdc, 0x00, 0x6e, 0x36, 0x14, 0x6e, 0xec, 0x66,
		0xe0, 0x7c, 0x75, 0x82, 0xb7, 0xad, 0x07, 0x1c, 0x29, 0xe7, 0x58, 0xc7, 0x49, 0x06, 0x4a, 0x00,
		0x25, 0x32, 0x84, 0x12, 0x24, 0xb5, 0x78, 0x75, 0x6a, 0xef, 0x1a, 0xa8, 0xb5, 0xcb, 0x83, 0x28,
		0x61, 0x56, 0x93, 0xf5, 0x6a, 0x37, 0xd5, 0xa1, 0x65, 0x76, 0x18, 0x60, 0x0c, 0x30, 0x66, 0xe3,
		0x30, 0x46, 0x2f, 0xc1, 0x48, 0x27, 0xa1, 0x48, 0x3b, 0x81, 0x88, 0x29, 0x61, 0xa6, 0xae, 0xf2,
		0x2a, 0x14, 0x09, 0x41, 0x5c, 0xef, 0x93, 0x1e, 0x3c, 0xee, 0x7a, 0x4e, 0xc7, 0x73, 0x82, 0x37,
		0x6d, 0x44, 0x0e, 0x07, 0x02, 0x26, 0x03, 0x93, 0x37, 0x0e, 0x93, 0x95, 0x4f, 0x30, 0x6a, 0x9c,
		0x58, 0xd4, 0x3c, 0xa1, 0xa8, 0x91, 0x17, 0x42, 0x71, 0x02, 0x91, 0x2a, 0x13, 0x8f, 0xe8, 0x84,
		0x21, 0xe5, 0x11, 0x35, 0x9d, 0xbc, 0x49, 0x8a, 0x13, 0x83, 0xd4, 0x53, 0x4b, 0x70, 0x22, 0x90,
		0x74, 0x7a, 0x0d, 0x25, 0x12, 0xd5, 0x91, 0x8a, 0xb1, 0x28, 0x15, 0x43, 0x22, 0x99, 0x2b, 0xc6,
		0x86, 0xef, 0x8e, 0xc6, 0x1c, 0x8c, 0x93, 0xb1, 0x62, 0x84, 0x93, 0xe4, 0xf2, 0xae, 0xe4, 0xf3,
		0xac, 0x48, 0xf2, 0xaa, 0xe4, 0xf2, 0xa8, 0xd6, 0x4d, 0x8e, 0xa4, 0x60, 0x28, 0x0b, 0x44, 0x3e,
		0xd6, 0x9e, 0xfd, 0xf2, 0xc4, 0xa7, 0xd5, 0xa2, 0xb4, 0x5c, 0x40, 0x16, 0xff, 0x65, 0xc9, 0xac,
		0xc4, 0x9d, 0x0d, 0xc9, 0x59, 0x58, 0xfc, 0xec, 0xd1, 0x27, 0x5b, 0xf0, 0x54, 0x6b, 0xf2, 0x18,
		0x62, 0xe5, 0x2d, 0xac, 0xc9, 0x53, 0x58, 0x9b, 0x97, 0x10, 0x87, 0xec, 0x4a, 0x90, 0xda, 0xb8,
		0xe4, 0x55, 0x9a, 0xa4, 0x4a, 0x93, 0x51, 0x39, 0xd2, 0x29, 0x27, 0x49, 0xeb, 0xf2, 0x00, 0xa4,
		0x3d, 0x27, 0x45, 0x4f, 0x29, 0xa6, 0x95, 0x8f, 0xed, 0x09, 0xc9, 0x78, 0x3e, 0x0a, 0x9e, 0x8e,
		0xac, 0x67, 0xa3, 0xec, 0xc9, 0x28, 0x7b, 0x2e, 0x6a, 0x9e, 0x8a, 0x9e, 0x05, 0x8b, 0xed, 0x79,
		0xc8, 0x7b, 0x1a, 0x12, 0x9e, 0x85, 0xa4, 0x27, 0x21, 0xc1, 0x32, 0x54, 0x3c, 0x05, 0x55, 0x97,
		0x5f, 0xd1, 0x13, 0xd0, 0xa1, 0xa6, 0x32, 0x01, 0x15, 0x15, 0x66, 0xaf, 0x3b, 0x15, 0x0a, 0xcc,
		0x5d, 0x6b, 0x3a, 0x88, 0x58, 0x61, 0x3d, 0x73, 0x94, 0x60, 0x05, 0x29, 0x5e, 0xc0, 0x06, 0x76,
		0x56, 0x3c, 0xde, 0xba, 0xc7, 0x8a, 0xf3, 0x38, 0xf9, 0x85, 0x74, 0x63, 0x9e, 0x82, 0xcd, 0x3e,
		0xee, 0xe4, 0xa1, 0xa6, 0x1e, 0x28, 0xdf, 0x6e, 0xb7, 0xba, 0x91, 0xc7, 0x98, 0xec, 0x89, 0xf7,
		0xff, 0x3a, 0xf7, 0xf8, 0x8b, 0x29, 0xc9, 0x52, 0x2b, 0xb4, 0xca, 0xea, 0xcc, 0x58, 0x99, 0xe8,
		0xad, 0xe2, 0x58, 0x95, 0xd8, 0x56, 0x24, 0xb6, 0xd5, 0x88, 0x58, 0x89, 0xfe, 0x83, 0x49, 0x2e,
		0xf1, 0x32, 0x0a, 0x91, 0x6f, 0x8e, 0x67, 0x69, 0x0d, 0x29, 0x1c, 0x7d, 0x4e, 0x93, 0x15, 0x16,
		0x88, 0x58, 0xe1, 0xe2, 0xa5, 0xc9, 0x00, 0x2b, 0x5c, 0xb8, 0x74, 0x4c, 0xac, 0xb0, 0xf9, 0xc5,
		0xf6, 0x7d, 0xc7, 0x8f, 0x53, 0x09, 0x62, 0xb2, 0xcc, 0x93, 0x6b, 0x32, 0xc2, 0x05, 0x57, 0x8b,
		0x42, 0x86, 0xb9, 0xe0, 0x4a, 0x51, 0x49, 0x8a, 0x0b, 0xfa, 0x81, 0xe7, 0xb8, 0x2f, 0x12, 0x5c,
		0xb0, 0x78, 0xa2, 0x6a, 0x59, 0x3f, 0xc4, 0x91, 0xec, 0x61, 0x5a, 0x94, 0x82, 0x78, 0xc7, 0xc9,
		0xa7, 0x82, 0x8c, 0x6f, 0xa5, 0x8c, 0xcb, 0x09, 0x49, 0x4e, 0x32, 0xc9, 0x2e, 0x66, 0x52, 0x9d,
		0x9a, 0x62, 0x08, 0xd7, 0x7e, 0x6a, 0x0b, 0x09, 0xbc, 0x1f, 0x5f, 0xb0, 0x66, 0x12, 0xa7, 0x32,
		0x6e, 0xfb, 0xab, 0x0d, 0xbd, 0x81, 0xde, 0x44, 0x67, 0xfc, 0xa9, 0xd3, 0x69, 0x0b, 0xdb, 0x95,
		0xd1, 0x97, 0x22, 0x83, 0x0e, 0x7c, 0x11, 0xed, 0x76, 0x67, 0x50, 0x1a, 0xc0, 0x8b, 0xaf, 0x07,
		0xd3, 0x17, 0x41, 0xb8, 0x21, 0xdc, 0x0b, 0x83, 0x60, 0x47, 0x65, 0x09, 0xd9, 0x3e, 0x41, 0x10,
		0x6c, 0x6b, 0x83, 0x60, 0xfa, 0x45, 0x0e, 0x32, 0x1d, 0x13, 0x5b, 0x01, 0xce, 0x7e, 0xaf, 0xdb,
		0xf5, 0x84, 0xef, 0x5b, 0x41, 0xfb, 0xab, 0x65, 0xb7, 0xbe, 0x0a, 0x2f, 0x70, 0x7c, 0x31, 0xd2,
		0xfe, 0xb8, 0x9b, 0x16, 0xcb, 0xc7, 0x00, 0x74, 0x03, 0xba, 0x23, 0x33, 0xee, 0xb4, 0x84, 0x1b,
		0x38, 0xc1, 0x5b, 0xbc, 0xd4, 0xf8, 0x90, 0x9b, 0xc4, 0xd9, 0x3e, 0xaf, 0x8d, 0x86, 0xfe, 0x64,
		0xfb, 0x0a, 0x07, 0xc4, 0x2f, 0x2f, 0x2f, 0x6e, 0x1b, 0x0f, 0x97, 0xbf, 0xc5, 0x5d, 0xa6, 0x01,
		0xbc, 0xf8, 0x52, 0xe9, 0x57, 0x8a, 0x19, 0x94, 0xf7, 0x7f, 0xdc, 0x3f, 0x54, 0xaf, 0x1a, 0x17,
		0xd5, 0xfb, 0xf3, 0xbb, 0xda, 0xed, 0x43, 0xed, 0xe6, 0x3a, 0xcf, 0x01, 0xce, 0x8a, 0x4f, 0x77,
		0xfe, 0x4b, 0xe5, 0xfe, 0xbe, 0x76, 0xdf, 0xa8, 0x5d, 0xa4, 0xe9, 0xa9, 0x6e, 0x6f, 0xee, 0x1e,
		0xd2, 0x3a, 0x63, 0xa3, 0xf5, 0xbc, 0xae, 0x5c, 0x55, 0xd3, 0xf4, 0x58, 0x57, 0x95, 0xeb, 0xca,
		0xcf, 0xd5, 0xab, 0xea, 0xf5, 0x43, 0xa3, 0x72, 0x71, 0x71, 0x57, 0xbd, 0xbf, 0x4f, 0xdd, 0x82,
		0xa6, 0x4b, 0xc6, 0x46, 0xeb, 0x78, 0x5e, 0xb9, 0xad, 0x7c, 0xaa, 0x5d, 0xd6, 0x1e, 0x6a, 0xd5,
		0x7b, 0xea, 0xe2, 0x04, 0x75, 0x66, 0xfc, 0xde, 0xc0, 0xb4, 0x28, 0x35, 0x26, 0x34, 0x4c, 0xbd,
		0x68, 0x09, 0xbf, 0xe9, 0x39, 0xdd, 0x58, 0x49, 0x53, 0xf3, 0x69, 0x1b, 0xd3, 0xd7, 0x82, 0xf9,
		0x80, 0xf9, 0x50, 0x44, 0xeb, 0x63, 0x7c, 0xf6, 0x52, 0xb8, 0x2f, 0x83, 0xad, 0x60, 0xb8, 0xad,
		0x9b, 0xe5, 0xb6, 0x96, 0x0e, 0xe1, 0xa5, 0x4e, 0x63, 0x73, 0xac, 0x23, 0xe7, 0xf3, 0xa0, 0x1c,
		0x27, 0x35, 0x18, 0x68, 0x0c, 0x34, 0x06, 0x1a, 0x03, 0x8d, 0x81, 0xc6, 0xab, 0xff, 0xc2, 0x98,
		0x47, 0xd7, 0x6e, 0x75, 0xf7, 0x07, 0xff, 0x1b, 0x25, 0x36, 0x69, 0xa4, 0xd5, 0x4f, 0x25, 0xe7,
		0xaf, 0x4d, 0xa3, 0x9a, 0xfa, 0x2c, 0x52, 0xa9, 0xb2, 0x93, 0x4a, 0x35, 0x39, 0x7a, 0x12, 0x9b,
		0x0e, 0xc4, 0x3d, 0xad, 0x12, 0xb3, 0xf2, 0x23, 0xc8, 0x40, 0x9a, 0xc9, 0x40, 0xdc, 0x4a, 0x8d,
		0xeb, 0xd2, 0x2d, 0x97, 0x2e, 0xd0, 0xca, 0xf4, 0x4b, 0x45, 0x91, 0x92, 0x16, 0x2d, 0x15, 0x11,
		0xd3, 0x10, 0x35, 0x55, 0x91, 0xd3, 0x16, 0x3d, 0x6d, 0x11, 0xd4, 0x13, 0x45, 0x49, 0x9b, 0xcc,
		0x55, 0x4c, 0x34, 0x6e, 0x2e, 0xd1, 0xd2, 0x95, 0x8e, 0x97, 0x5b, 0x14, 0x7d, 0x50, 0xa9, 0x5c,
		0x23, 0x2a, 0xd6, 0x95, 0x78, 0xf5, 0x06, 0x39, 0x9d, 0xd0, 0xd5, 0x0d, 0x32, 0x1d, 0x21, 0xd3,
		0x15, 0x1a, 0x9d, 0x91, 0xd3, 0x1d, 0x05, 0x57, 0x20, 0x47, 0x54, 0xb5, 0x2b, 0x76, 0xae, 0xd4,
		0x52, 0x70, 0x2f, 0xa2, 0x28, 0x1f, 0xd4, 0x1b, 0xea, 0x9d, 0x4e, 0xf5, 0x46, 0x51, 0x3e, 0x36,
		0x22, 0xc3, 0x50, 0x7e, 0x22, 0x0c, 0x06, 0x2c, 0x2c, 0x3f, 0xb1, 0x2a, 0x42, 0x20, 0xff, 0xaa,
		0x68, 0x04, 0x02, 0x0f, 0x21, 0x9d, 0x1e, 0x02, 0x1a, 0x81, 0xac, 0xd5, 0x4b, 0xe1, 0xbc, 0x7c,
		0x79, 0xea, 0x78, 0xbe, 0x82, 0x72, 0x86, 0x97, 0x6e, 0x48, 0x43, 0x10, 0x68, 0x68, 0x06, 0x7c,
		0xf8, 0xb1, 0xd4, 0x69, 0x70, 0xf4, 0xf1, 0x08, 0x6a, 0x3c, 0xbd, 0x08, 0x9e, 0x0e, 0x9e, 0xce,
		0xc5, 0xd3, 0x65, 0xd5, 0x61, 0x12, 0x85, 0xb5, 0xbb, 0xf6, 0x93, 0xd3, 0x76, 0x02, 0x47, 0xf8,
		0xea, 0x6b, 0x16, 0xc6, 0x66, 0xa7, 0x47, 0x53, 0x9c, 0x6d, 0x35, 0x75, 0x51, 0x46, 0x7f, 0x4a,
		0xf5, 0x21, 0x54, 0x23, 0x2a, 0x75, 0x22, 0x57, 0x2b, 0x72, 0xf5, 0xa2, 0x55, 0x33, 0x35, 0x75,
		0x53, 0x54, 0x3b, 0x6d, 0xf5, 0x8b, 0xaa, 0xe1, 0x1b, 0x5d, 0xd3, 0xee, 0xa9, 0x31, 0x69, 0xfa,
		0x76, 0x17, 0x37, 0xbd, 0x6f, 0xb7, 0x9e, 0xaa, 0x52, 0xab, 0x2c, 0x9b, 0xea, 0xb2, 0xa9, 0x30,
		0x8f, 0x2a, 0xeb, 0xa9, 0xb4, 0xa6, 0x6a, 0x93, 0xa9, 0xf8, 0x44, 0xd5, 0xe5, 0xf6, 0x3d, 0xe3,
		0xab, 0xbb, 0xcc, 0xbe, 0xa8, 0x21, 0x95, 0x27, 0x57, 0x7d, 0x0e, 0x08, 0x60, 0x84, 0x02, 0x2e,
		0x48, 0x60, 0x87, 0x06, 0x76, 0x88, 0xe0, 0x85, 0x0a, 0x1a, 0xc8, 0x20, 0x82, 0x0e, 0xdd, 0x70,
		0xed, 0xda, 0x71, 0x95, 0xc3, 0xb9, 0x61, 0x24, 0x26, 0xfc, 0x6e, 0x7f, 0x9a, 0xc1, 0x4f, 0x7e,
		0x78, 0x93, 0x8a, 0xfc, 0xf2, 0xaf, 0x0a, 0xc1, 0x8a, 0xa8, 0x6d, 0xd8, 0xad, 0x0f, 0x12, 0xc8,
		0x6f, 0xe4, 0xad, 0xc3, 0xe0, 0x02, 0x30, 0x18, 0x18, 0x0c, 0x0c, 0xa6, 0x91, 0x59, 0xe5, 0x0d,
		0xcd, 0xb5, 0x12, 0x2b, 0x1f, 0xf9, 0x8f, 0x4d, 0xc2, 0x8e, 0x09, 0xc7, 0xd4, 0xd8, 0x39, 0xc8,
		0x06, 0xae, 0xcb, 0xb5, 0x28, 0x8f, 0xbd, 0xbc, 0x32, 0x2d, 0xcc, 0x13, 0x63, 0xd7, 0x25, 0x20,
		0x3b, 0x90, 0x7d, 0x4b, 0x91, 0x9d, 0xca, 0x41, 0x0f, 0x07, 0x54, 0xcd, 0xfa, 0x8c, 0xad, 0x09,
		0x6a, 0x59, 0xa1, 0x86, 0x69, 0x23, 0x1b, 0x7d, 0xe4, 0x04, 0x1b, 0x03, 0xa0, 0xc3, 0x0d, 0x3e,
		0xc6, 0x40, 0xc8, 0x18, 0x18, 0x99, 0x01, 0x25, 0x5a, 0x70, 0x22, 0x06, 0x29, 0x3e, 0x1a, 0x1a,
		0x91, 0x78, 0xf5, 0xb4, 0xda, 0xd8, 0xec, 0xa5, 0xb8, 0x93, 0xce, 0x05, 0x23, 0x5c, 0x2c, 0xda,
		0x28, 0x01, 0x67, 0xb4, 0x00, 0xf0, 0x0f, 0xf8, 0x07, 0xfc, 0x03, 0xfe, 0x95, 0x2a, 0xbd, 0x29,
		0x9b, 0x80, 0x43, 0x86, 0xb1, 0x95, 0x2a, 0xc9, 0x29, 0x4f, 0xd4, 0xa0, 0xf2, 0xdc, 0x7c, 0x31,
		0xa9, 0x3f, 0xb8, 0x94, 0x4c, 0xa1, 0x6e, 0x9d, 0xec, 0xd7, 0x77, 0xb6, 0x91, 0x67, 0xe6, 0xed,
		0x3f, 0x97, 0x95, 0xeb, 0x46, 0xe5, 0xfc, 0xbc, 0x7a, 0x7f, 0xdf, 0xb8, 0xbd, 0xa9, 0x5d, 0x3f,
		0xe4, 0xd9, 0xee, 0xfb, 0xfe, 0x21, 0xeb, 0x93, 0xf5, 0xf0, 0x9f, 0x9b, 0xc6, 0xa0, 0x86, 0xda,
		0x55, 0xe5, 0xbc, 0x71, 0x57, 0xbd, 0xac, 0xfc, 0x81, 0xd9, 0x5a, 0x3e, 0x5b, 0x77, 0x37, 0xbf,
		0x3e, 0x54, 0xef, 0x30, 0x43, 0xcb, 0x67, 0xe8, 0xbe, 0xf1, 0xdb, 0x65, 0xe5, 0x1a, 0x33, 0xb4,
		0x42, 0x86, 0xaa, 0xb7, 0xd5, 0x0a, 0xa4, 0x68, 0xb5, 0x14, 0x3d, 0x54, 0x1e, 0x6a, 0x37, 0xd7,
		0x8d, 0x9b, 0xeb, 0x4b, 0xe0, 0xd1, 0x2a, 0xf4, 0xae, 0x5e, 0x56, 0x6f, 0x7f, 0xb9, 0xb9, 0xae,
		0x62, 0x92, 0x96, 0x4f, 0x52, 0xdf, 0xb2, 0x7d, 0xba, 0xab, 0x5d, 0xfc, 0x8c, 0x59, 0x5a, 0x31,
		0x4b, 0x17, 0x37, 0xe7, 0xf7, 0xb5, 0xfb, 0xc6, 0x79, 0xe5, 0xd3, 0x65, 0xb5, 0x71, 0x51, 0xfd,
		0xad, 0x76, 0x8e, 0xe9, 0x5a, 0x31, 0x5d, 0xe7, 0xb0, 0x73, 0x6b, 0x66, 0xe8, 0xe6, 0xe1, 0x17,
		0x56, 0x23, 0xc7, 0x32, 0x72, 0x3d, 0xed, 0xee, 0x3e, 0x12, 0xd0, 0xa4, 0xc6, 0x35, 0x91, 0x80,
		0x26, 0xd1, 0xf9, 0x9e, 0x7f, 0x51, 0x92, 0x4d, 0x45, 0x8e, 0xdf, 0x79, 0x7f, 0xed, 0x50, 0x52,
		0x25, 0xa8, 0xd7, 0x8e, 0x26, 0x5d, 0xa2, 0x7a, 0xfd, 0x88, 0x04, 0x25, 0xac, 0xd7, 0xde, 0x44,
		0xaa, 0xc4, 0x35, 0xf7, 0xe2, 0x12, 0xeb, 0xa8, 0x09, 0xdd, 0xcc, 0x93, 0x64, 0xed, 0xcc, 0x74,
		0xc8, 0x6d, 0xb7, 0xba, 0x8d, 0xda, 0xf8, 0x51, 0x1a, 0xd7, 0xa3, 0x07, 0x68, 0x9c, 0x4f, 0xee,
		0xb9, 0x93, 0x8c, 0xfe, 0x9a, 0x3d, 0x57, 0x44, 0x24, 0x0c, 0x6c, 0x42, 0xa0, 0xb6, 0x0a, 0xf2,
		0x73, 0xa8, 0x30, 0x7f, 0xba, 0xe7, 0x2c, 0x68, 0xce, 0x55, 0x90, 0x9d, 0x66, 0x2c, 0xe0, 0x34,
		0xe3, 0x9c, 0x09, 0xc4, 0x69, 0xc6, 0xad, 0x42, 0x1d, 0x8d, 0xf3, 0x07, 0x86, 0xf0, 0xa6, 0xe7,
		0x07, 0x9d, 0x57, 0x2b, 0x68, 0x7f, 0xa5, 0x38, 0x48, 0x3d, 0x35, 0x18, 0xce, 0x51, 0x03, 0x79,
		0xb6, 0x04, 0x79, 0xb4, 0xcf, 0x51, 0x07, 0xed, 0xaf, 0x74, 0x07, 0xa8, 0xfb, 0x83, 0xe1, 0xe4,
		0xb4, 0x01, 0xe5, 0xa4, 0x56, 0x52, 0x36, 0x65, 0x65, 0x53, 0x5a, 0x1e, 0xe5, 0x4d, 0x47, 0xb8,
		0x02, 0x27, 0xa7, 0xd3, 0xa0, 0xfa, 0x1c, 0x10, 0xc0, 0x08, 0x05, 0x5c, 0x90, 0xc0, 0x0e, 0x0d,
		0xec, 0x10, 0xc1, 0x0b, 0x15, 0x74, 0x31, 0xd2, 0xdc, 0xb6, 0x05, 0xae, 0x27, 0x94, 0x7d, 0x3f,
		0x68, 0x7f, 0xdd, 0xc0, 0x13, 0xd3, 0x9d, 0x9e, 0x43, 0x0f, 0xbe, 0xfd, 0x41, 0x71, 0x5e, 0x1a,
		0xc8, 0x0b, 0xe4, 0x4d, 0x25, 0xf2, 0xe2, 0xbc, 0xf4, 0xfc, 0x79, 0xe9, 0x3e, 0x60, 0x6d, 0x16,
		0xa8, 0x5b, 0x7e, 0xef, 0x29, 0xa0, 0x5c, 0xe7, 0x69, 0x70, 0x0f, 0x07, 0x07, 0xc8, 0x03, 0xe4,
		0x01, 0xf2, 0x00, 0xf9, 0xac, 0x80, 0x7c, 0x08, 0x5c, 0xa8, 0x8d, 0xb1, 0x6e, 0x95, 0x51, 0x1b,
		0x03, 0x00, 0x0f, 0x80, 0x4f, 0x31, 0xc0, 0x93, 0xd7, 0xc6, 0xa0, 0x0c, 0x05, 0x30, 0x86, 0x04,
		0x98, 0x58, 0x23, 0x1b, 0x7b, 0xe4, 0x04, 0x19, 0x03, 0x60, 0xc3, 0x0d, 0x3a, 0xc6, 0xc0, 0xc7,
		0x18, 0x08, 0x99, 0x01, 0x23, 0x5a, 0x50, 0x22, 0x06, 0x27, 0x3e, 0x16, 0xba, 0x80, 0xa7, 0xc4,
		0x6c, 0x3b, 0xae, 0x4c, 0x5a, 0x4e, 0xb6, 0xa0, 0x24, 0x06, 0x47, 0xc4, 0xc0, 0x40, 0xe4, 0x00,
		0xb6, 0x00, 0xb6, 0x00, 0xb6, 0x00, 0xb6, 0x00, 0xb6, 0x80, 0xd0, 0x16, 0xf0, 0x1a, 0x01, 0xa0,
		0x3f, 0xd0, 0x1f, 0xe8, 0x0f, 0xf4, 0xa7, 0x97, 0x78, 0xc7, 0x0d, 0x0e, 0x4a, 0x8c, 0xe0, 0x7f,
		0xc0, 0x30, 0xf4, 0x9d, 0xed, 0xbe, 0x08, 0xb6, 0xd2, 0x41, 0x7c, 0xe7, 0x95, 0xf3, 0x57, 0x8e,
		0xcb, 0x06, 0x00, 0x11, 0xab, 0xfb, 0x81, 0xf7, 0x36, 0x83, 0x02, 0x4e, 0xf9, 0xb3, 0x5c, 0xa9,
		0x58, 0x3e, 0x2e, 0x9f, 0x1c, 0x1c, 0x95, 0x4f, 0x98, 0x6f, 0xf8, 0x93, 0x67, 0x37, 0x03, 0xa7,
		0xe3, 0x5e, 0x38, 0x2f, 0xce, 0xf0, 0x58, 0x65, 0x16, 0x4f, 0xc3, 0xe7, 0xaf, 0xec, 0x6f, 0xc6,
		0x64, 0xa0, 0x60, 0x5a, 0x06, 0x8e, 0x37, 0x48, 0x06, 0x76, 0xb2, 0x31, 0x6a, 0x7d, 0x0b, 0xc8,
		0xf5, 0xd7, 0x91, 0x9c, 0x31, 0xb1, 0xeb, 0xe1, 0xf0, 0xa0, 0xd7, 0xa0, 0xd7, 0xa0, 0xd7, 0xa0,
		0xd7, 0xa4, 0x12, 0xff, 0xe4, 0xb8, 0xb6, 0xf7, 0xc6, 0xc8, 0xaf, 0x4f, 0x51, 0xef, 0x25, 0x8e,
		0xac, 0x67, 0x30, 0x6d, 0x3e, 0x5d, 0x75, 0x5e, 0x08, 0x72, 0x6e, 0x78, 0x32, 0x2b, 0x91, 0x52,
		0x99, 0x56, 0xdb, 0x8c, 0x8c, 0x9b, 0x64, 0x6c, 0x2f, 0x52, 0x2a, 0xb5, 0x63, 0x27, 0xac, 0x29,
		0x95, 0xa9, 0xca, 0xa5, 0x4c, 0x43, 0xfd, 0xae, 0xfe, 0x84, 0xe4, 0x3a, 0x3d, 0x27, 0x47, 0xb7,
		0xd7, 0x8d, 0x7a, 0x5e, 0xa8, 0xe7, 0xa5, 0xce, 0xbd, 0xcc, 0xd5, 0xf1, 0x7a, 0x68, 0x7f, 0x45,
		0x01, 0xaf, 0x14, 0xac, 0x7a, 0x9a, 0xeb, 0xe9, 0x38, 0x2d, 0xfd, 0x32, 0x3a, 0x4e, 0x4b, 0xb3,
		0x7a, 0x4e, 0x01, 0x75, 0xbb, 0x72, 0xa8, 0x9e, 0x93, 0x11, 0xb0, 0xd1, 0xe6, 0x9c, 0x84, 0x1c,
		0x93, 0x82, 0x53, 0x46, 0x39, 0xa4, 0xd3, 0x4a, 0x33, 0x62, 0xe9, 0x9d, 0xae, 0x21, 0x39, 0x4d,
		0x83, 0xaa, 0x5f, 0xc0, 0xad, 0xed, 0xab, 0xfa, 0x65, 0xbf, 0x08, 0xba, 0xaa, 0x5f, 0xfd, 0xc1,
		0x68, 0xaa, 0x7e, 0x15, 0x50, 0xf5, 0x2b, 0x89, 0x80, 0x19, 0xaa, 0x7e, 0xa5, 0x21, 0xc8, 0x41,
		0x16, 0x00, 0x0b, 0x25, 0xae, 0xe7, 0xb8, 0xc1, 0x51, 0x99, 0x42, 0xe0, 0x46, 0xfa, 0x49, 0x90,
		0xba, 0x43, 0x9c, 0x94, 0x45, 0x18, 0x2e, 0xe4, 0x48, 0xba, 0xe2, 0xda, 0xdd, 0x1f, 0x27, 0xd4,
		0x50, 0x8f, 0xcb, 0x98, 0x37, 0x43, 0x99, 0xe7, 0xc1, 0x91, 0x1b, 0xc5, 0xbd, 0x54, 0x3c, 0xa1,
		0x3b, 0x63, 0xab, 0x97, 0x92, 0x38, 0x74, 0x3d, 0xa9, 0x20, 0x98, 0x06, 0xa5, 0x6e, 0x7e, 0xb1,
		0x7d, 0xdf, 0xf1, 0x2d, 0xa7, 0x45, 0xc7, 0xb9, 0xa6, 0xc6, 0x04, 0xf5, 0x02, 0xf5, 0x02, 0xf5,
		0x4a, 0x19, 0xf5, 0x22, 0x3b, 0x2c, 0x45, 0x74, 0x38, 0x2a, 0x69, 0xe4, 0xb3, 0x48, 0x92, 0x3a,
		0x16, 0xc0, 0x9f, 0x45, 0xb1, 0x09, 0x08, 0x0c, 0x04, 0x06, 0x02, 0x03, 0xa9, 0x31, 0x90, 0x56,
		0x49, 0x67, 0xc0, 0xb0, 0x4c, 0x30, 0x56, 0xd5, 0xed, 0xbd, 0xf6, 0x5f, 0xf8, 0x3d, 0x83, 0xc0,
		0x4a, 0x49, 0x25, 0x41, 0x21, 0x01, 0x9f, 0x80, 0x4f, 0x50, 0xc8, 0x74, 0x22, 0x5d, 0xdb, 0xf6,
		0x03, 0xab, 0xd7, 0x6d, 0x51, 0x94, 0xe1, 0x9b, 0xec, 0xd6, 0x4e, 0x0d, 0x0a, 0xec, 0x03, 0xf6,
		0x01, 0xfb, 0x52, 0x86, 0x7d, 0xd4, 0x1b, 0x17, 0x65, 0x6c, 0x5c, 0x28, 0xda, 0x0c, 0xa6, 0x68,
		0xf8, 0x69, 0xa9, 0x74, 0x70, 0x70, 0x5c, 0x2a, 0x1c, 0x1c, 0x9d, 0x1c, 0x96, 0x8f, 0x8f, 0x0f,
		0x4f, 0x0a, 0x27, 0xd8, 0xca, 0xa0, 0x5e, 0xbc, 0x82, 0xb1, 0xc5, 0x3b, 0xc6, 0x4e, 0x86, 0xec,
		0x57, 0x16, 0x77, 0x32, 0x5e, 0x6d, 0xd7, 0x7e, 0x19, 0x24, 0xa3, 0x5b, 0x76, 0xab, 0xe5, 0x09,
		0xdf, 0xa7, 0xe3, 0x64, 0x0b, 0xc6, 0x06, 0x35, 0x03, 0x35, 0x03, 0x35, 0x83, 0x5b, 0x9a, 0x09,
		0x24, 0x24, 0xde, 0xe1, 0x58, 0x76, 0x03, 0x60, 0x22, 0x30, 0x11, 0x98, 0x08, 0x4c, 0x4c, 0x21,
		0x26, 0x76, 0x3b, 0x5e, 0x60, 0xb5, 0x84, 0xdf, 0xf4, 0x9c, 0x2e, 0xc9, 0xf1, 0xbd, 0x70, 0x7e,
		0x23, 0x23, 0x03, 0x05, 0x81, 0x82, 0x40, 0x41, 0xa0, 0x60, 0x5a, 0x51, 0x90, 0x72, 0x7f, 0x76,
		0x3c, 0x20, 0x30, 0x0f, 0x98, 0x07, 0xcc, 0x03, 0xe6, 0xa5, 0x17, 0xf3, 0x88, 0x5d, 0xe0, 0x99,
		0x51, 0x81, 0x7e, 0x40, 0x3f, 0xa0, 0x5f, 0xca, 0xd0, 0x8f, 0x50, 0x43, 0x73, 0x48, 0xef, 0x9b,
		0x3c, 0xbb, 0xff, 0xe6, 0x07, 0xe2, 0x95, 0xc7, 0x97, 0x5e, 0x30, 0x36, 0xb0, 0x15, 0xd8, 0x0a,
		0x6c, 0xdd, 0x7c, 0x66, 0x49, 0x30, 0xd6, 0xa5, 0x70, 0x5f, 0x06, 0x25, 0x46, 0x70, 0x7c, 0x57,
		0x63, 0x58, 0x1c, 0xdf, 0xcd, 0xdc, 0x52, 0x95, 0x0e, 0x71, 0x5a, 0x57, 0xfa, 0xab, 0x9e, 0x5d,
		0xee, 0x35, 0x2a, 0xc8, 0x47, 0x4b, 0xba, 0x06, 0x83, 0x82, 0x6d, 0x81, 0x6d, 0x81, 0x6d, 0x81,
		0x6d, 0x81, 0x6d, 0x81, 0x6d, 0x81, 0x6d, 0x81, 0x6d, 0x6d, 0x35, 0xdb, 0x0a, 0x82, 0x36, 0x1d,
		0xcb, 0xea, 0x0f, 0x06, 0x76, 0x05, 0x76, 0x05, 0x76, 0x95, 0x32, 0x76, 0xd5, 0x73, 0xdc, 0xa0,
		0x78, 0x44, 0xc8, 0xae, 0x8e, 0x70, 0x9e, 0x0b, 0xdc, 0x0a, 0xdc, 0x4a, 0x69, 0xa9, 0x8e, 0x0e,
		0x0f, 0x0f, 0xc0, 0xae, 0xb2, 0xc3, 0xae, 0xb6, 0xbe, 0xfd, 0x82, 0x46, 0x83, 0x33, 0x85, 0x32,
		0xe6, 0x3b, 0x8c, 0xd3, 0x3c, 0x6e, 0x64, 0x23, 0x9d, 0xcd, 0xa7, 0xd7, 0xa6, 0x46, 0xbf, 0x2d,
		0x0d, 0x4b, 0x1b, 0x1a, 0xbd, 0xb6, 0x33, 0xb2, 0x53, 0xaf, 0x29, 0xd9, 0x94, 0x12, 0x9d, 0x57,
		0x2a, 0x95, 0x1f, 0xa3, 0x4d, 0x8c, 0x9c, 0x92, 0xc4, 0x17, 0xf5, 0x78, 0x9f, 0x8c, 0xb9, 0x22,
		0xaa, 0x2b, 0x41, 0xb0, 0x02, 0xf1, 0xe6, 0x67, 0xfd, 0xdb, 0xc6, 0x78, 0x53, 0xc9, 0xde, 0x06,
		0x4a, 0xbd, 0x0c, 0x24, 0x0f, 0xe9, 0x4b, 0xf7, 0x2a, 0x50, 0xf1, 0x3e, 0x35, 0xbc, 0x4c, 0x55,
		0x6f, 0x52, 0xdb, 0x6b, 0xd4, 0xf6, 0x0e, 0xf5, 0xbc, 0x40, 0x5a, 0xed, 0x92, 0xed, 0x0d, 0x90,
		0x6f, 0x76, 0x7a, 0x7d, 0x4d, 0x91, 0x3f, 0xca, 0x3d, 0x29, 0xf4, 0x36, 0x1e, 0x41, 0xd6, 0x1a,
		0x2a, 0xd5, 0x98, 0x50, 0x0e, 0xae, 0xe8, 0x04, 0x53, 0x08, 0x82, 0x27, 0xba, 0xc1, 0x12, 0xb2,
		0xe0, 0x08, 0x59, 0x30, 0x84, 0x26, 0xf8, 0xc1, 0xcb, 0xb8, 0x54, 0x5b, 0x65, 0xe4, 0x9f, 0x3d,
		0xfb, 0x55, 0x58, 0x2d, 0xc7, 0x6f, 0xda, 0x1e, 0x41, 0x63, 0xad, 0xd9, 0xe1, 0xd0, 0x63, 0x0b,
		0xbd, 0x6a, 0x12, 0x8b, 0x32, 0x66, 0xb5, 0xc7, 0xd6, 0xc8, 0xcc, 0x68, 0x15, 0x86, 0x22, 0xe8,
		0x64, 0x41, 0x14, 0x38, 0xa4, 0xe9, 0x36, 0x4a, 0x18, 0x7a, 0xa7, 0xed, 0x69, 0x4d, 0x1c, 0x18,
		0xe4, 0x88, 0x30, 0xbd, 0xd3, 0xb4, 0x67, 0x4d, 0xfd, 0x12, 0xf0, 0x75, 0x9e, 0x60, 0x59, 0x95,
		0x84, 0xe2, 0x6c, 0xf5, 0x14, 0xf7, 0xc9, 0x1b, 0x92, 0x07, 0xe1, 0x79, 0x1d, 0xcf, 0xd2, 0xd0,
		0xf9, 0x39, 0x32, 0x12, 0x8e, 0x07, 0x36, 0x02, 0x36, 0x02, 0x36, 0x02, 0x36, 0x02, 0x36, 0x02,
		0x36, 0x02, 0x36, 0x02, 0x36, 0x22, 0xc1, 0x46, 0x3a, 0xbd, 0x80, 0x96, 0x8e, 0xf4, 0x07, 0x04,
		0x1f, 0x01, 0x1f, 0x01, 0x1f, 0x01, 0x1f, 0x01, 0x1f, 0x01, 0x1f, 0x01, 0x1f, 0x01, 0x1f, 0x89,
		0xc5, 0x47, 0xe8, 0xe2, 0x22, 0x88, 0x88, 0x80, 0x81, 0x80, 0x81, 0x80, 0x81, 0x80, 0x81, 0x80,
		0x81, 0x80, 0x81, 0x80, 0x81, 0xc4, 0x65, 0x20, 0x84, 0xb1, 0x10, 0x44, 0x41, 0xc0, 0x41, 0xc0,
		0x41, 0xc0, 0x41, 0xc0, 0x41, 0xc0, 0x41, 0xc0, 0x41, 0xc0, 0x41, 0x62, 0x4c, 0xf3, 0xa0, 0xa7,
		0x69, 0xb3, 0x2d, 0x6c, 0x4f, 0x9f, 0x84, 0x4c, 0x8d, 0x05, 0x16, 0x02, 0x16, 0x02, 0x16, 0x22,
		0x29, 0x31, 0x2d, 0x3b, 0x10, 0x96, 0xed, 0xb6, 0xac, 0xc0, 0xd1, 0x2a, 0xf8, 0x45, 0x51, 0x4c,
		0x28, 0x7f, 0x6b, 0x07, 0x81, 0xf0, 0x5c, 0x6d, 0x32, 0x92, 0xff, 0xfc, 0xb9, 0xf5, 0xbd, 0xfc,
		0x6e, 0xf5, 0xff, 0x29, 0x8d, 0xff, 0x79, 0x18, 0xfe, 0x73, 0x36, 0xf3, 0xcf, 0xee, 0xe7, 0xcf,
		0x1f, 0x3f, 0x7f, 0x6e, 0xfd, 0xcf, 0xde, 0xbf, 0x76, 0xff, 0xff, 0x3f, 0x1e, 0x3f, 0x7f, 0xfe,
		0x9f, 0xcf, 0x9f, 0xad, 0xfa, 0xcc, 0x27, 0xf6, 0xf2, 0x1b, 0x89, 0xc1, 0x41, 0xfb, 0x2b, 0xdd,
		0x89, 0x81, 0xe9, 0xc1, 0x80, 0xc2, 0x40, 0x61, 0xa0, 0x30, 0x7c, 0x41, 0xf8, 0x82, 0xf0, 0x05,
		0xe1, 0x0b, 0xc2, 0x17, 0x8c, 0xc1, 0x43, 0x7a, 0xee, 0x5f, 0x6e, 0xe7, 0x6f, 0x97, 0x86, 0x87,
		0x8c, 0x07, 0x03, 0x0f, 0x01, 0x0f, 0x01, 0x0f, 0x01, 0x0f, 0x01, 0x0f, 0x01, 0x0f, 0x01, 0x0f,
		0xd9, 0x2e, 0x1e, 0xb2, 0x99, 0xd5, 0x99, 0x06, 0xf5, 0x76, 0xf6, 0x15, 0x2b, 0x98, 0xe4, 0xd6,
		0x56, 0x66, 0x3a, 0x1f, 0x0f, 0xcc, 0x55, 0x99, 0x49, 0xa2, 0xbc, 0x8e, 0x70, 0xed, 0xa7, 0xb6,
		0x68, 0xa9, 0xd7, 0x79, 0x19, 0x0f, 0x20, 0x5b, 0x82, 0x43, 0x3c, 0xdb, 0xbd, 0xf6, 0x80, 0x03,
		0xf4, 0x29, 0x85, 0x62, 0x95, 0x98, 0x02, 0xaa, 0xc4, 0x18, 0x25, 0x85, 0x5b, 0x55, 0x25, 0x46,
		0x99, 0xec, 0x85, 0x2b, 0xfe, 0xd4, 0xe9, 0xb4, 0x85, 0xad, 0xe2, 0x21, 0x85, 0x41, 0xfe, 0x62,
		0x0a, 0x30, 0x42, 0xa9, 0xed, 0x49, 0x38, 0x09, 0x0a, 0xfd, 0x4d, 0xa0, 0xde, 0x50, 0xef, 0x2c,
		0xa8, 0xb7, 0xed, 0x0b, 0x2b, 0x64, 0x0d, 0x96, 0x27, 0x9e, 0x75, 0x34, 0xfd, 0x58, 0xe1, 0xda,
		0xdb, 0x90, 0xdb, 0x34, 0x2d, 0xe7, 0xf9, 0x6c, 0x8a, 0xcc, 0xcc, 0xfd, 0x62, 0xf4, 0xf3, 0x40,
		0x17, 0x51, 0x0f, 0x72, 0x29, 0xe7, 0x23, 0xab, 0x05, 0xb9, 0xa3, 0x31, 0x07, 0xe3, 0x82, 0xb0,
		0x31, 0x80, 0x53, 0xae, 0x04, 0xac, 0x7c, 0xc9, 0x57, 0x92, 0x12, 0xaf, 0x72, 0x25, 0x5d, 0xd7,
		0x4d, 0x8e, 0xa4, 0x60, 0x28, 0x0b, 0x44, 0x3e, 0x56, 0x39, 0xcf, 0xe5, 0x2c, 0x7f, 0xb5, 0x28,
		0x2d, 0x17, 0x90, 0xc5, 0x7f, 0x59, 0x32, 0x2b, 0x71, 0x67, 0x43, 0x72, 0x16, 0x16, 0x3f, 0x7b,
		0xf4, 0xc9, 0x16, 0x3c, 0xd5, 0x9a, 0x12, 0xa7, 0xb1, 0x4a, 0x9a, 0xae, 0xa9, 0x01, 0xb9, 0xb6,
		0x64, 0x69, 0x1c, 0x73, 0x2e, 0x61, 0xb6, 0xe3, 0x9a, 0x67, 0x69, 0x33, 0x2c, 0x6d, 0x6e, 0xe5,
		0xcc, 0xaa, 0x9c, 0x24, 0xad, 0xab, 0x89, 0x98, 0x6f, 0x7e, 0xb1, 0x7d, 0xdf, 0xf1, 0x2d, 0x67,
		0xbd, 0xb3, 0x38, 0x89, 0x72, 0x4e, 0xae, 0x59, 0x87, 0x79, 0xb1, 0x18, 0x5f, 0x6c, 0x86, 0x27,
		0xc3, 0xe8, 0x14, 0x18, 0x9c, 0x2c, 0x63, 0x53, 0x66, 0x68, 0xca, 0x8c, 0x4c, 0x8d, 0x81, 0xe9,
		0xd9, 0xad, 0xd8, 0x8c, 0x4a, 0xbe, 0xc3, 0xda, 0x24, 0xe9, 0x49, 0x15, 0x56, 0x3f, 0xc4, 0x91,
		0xec, 0x61, 0xd3, 0x72, 0x05, 0xf1, 0x8e, 0xd3, 0xed, 0x1c, 0x32, 0xbe, 0x95, 0x32, 0x2e, 0x27,
		0x24, 0x39, 0xc9, 0x96, 0xf7, 0x31, 0x5b, 0xda, 0x2b, 0x2a, 0x46, 0xdc, 0x2a, 0xd0, 0xb2, 0x55,
		0x9f, 0x63, 0x56, 0x79, 0x86, 0x2a, 0xa4, 0x59, 0x15, 0xe2, 0x56, 0x51, 0xce, 0x0b, 0x37, 0xf0,
		0x1c, 0xe1, 0x5b, 0xf6, 0x8b, 0x68, 0x49, 0x1d, 0x88, 0x9b, 0x0a, 0x32, 0xcf, 0x8d, 0x20, 0x57,
		0x0b, 0xbf, 0x20, 0x5b, 0x0b, 0xbf, 0x80, 0x5a, 0xf8, 0xa4, 0x71, 0xa1, 0x34, 0xd5, 0xc2, 0x97,
		0x8e, 0xfb, 0x68, 0xed, 0xd9, 0x2b, 0xec, 0xd1, 0x2b, 0xee, 0xc9, 0xab, 0xb5, 0x80, 0xd1, 0x08,
		0x3a, 0xea, 0xe5, 0xef, 0x68, 0xee, 0xa9, 0x53, 0xec, 0xd6, 0xbe, 0xab, 0xf5, 0xbc, 0x49, 0x7c,
		0xca, 0xe8, 0xf6, 0xc0, 0x49, 0x66, 0x91, 0x29, 0x9e, 0x58, 0x37, 0xd8, 0x97, 0x45, 0xad, 0xae,
		0xbf, 0x56, 0x1d, 0x7f, 0xd8, 0x26, 0xd8, 0x26, 0xd8, 0x26, 0xd8, 0x26, 0xd8, 0x26, 0xd8, 0xa6,
		0x18, 0xb6, 0x49, 0xba, 0xce, 0xbb, 0x5e, 0x5d, 0x77, 0x58, 0x27, 0x58, 0x27, 0x58, 0x27, 0x58,
		0x27, 0x58, 0x27, 0x58, 0xa7, 0x18, 0xd6, 0x49, 0xdd, 0x2e, 0xc1, 0x22, 0xc1, 0x22, 0xc1, 0x22,
		0xc1, 0x22, 0xc1, 0x22, 0xc1, 0x22, 0x51, 0x5a, 0x24, 0xa5, 0x6d, 0x26, 0xd9, 0x3a, 0x8b, 0xb0,
		0x49, 0xb0, 0x49, 0xb0, 0x49, 0xb0, 0x49, 0xb0, 0x49, 0xb0, 0x49, 0x2b, 0xa7, 0x41, 0xa1, 0x0e,
		0x9f, 0x7a, 0xdd, 0x3d, 0x58, 0x25, 0x58, 0x25, 0x42, 0xab, 0xa4, 0x5a, 0xb7, 0x4e, 0xa5, 0x4e,
		0x9d, 0x72, 0x5d, 0xba, 0x84, 0xea, 0xd0, 0x99, 0xc4, 0x90, 0xa0, 0xfd, 0xd5, 0xb2, 0x9b, 0x4d,
		0xd1, 0x0d, 0x84, 0xc2, 0x16, 0xf5, 0xcc, 0xd5, 0xc0, 0x11, 0xe0, 0x08, 0xd8, 0x2d, 0xd8, 0x2d,
		0xd8, 0x2d, 0xd8, 0x2d, 0x91, 0x65, 0x52, 0xce, 0x9d, 0x92, 0xaf, 0x68, 0x0a, 0xbb, 0x04, 0xbb,
		0x04, 0xbb, 0x04, 0xbb, 0x04, 0xbb, 0x04, 0xbb, 0xb4, 0xd6, 0x2e, 0xc9, 0x56, 0xbc, 0xd4, 0xa8,
		0x70, 0x09, 0xbb, 0x04, 0xbb, 0x04, 0xbb, 0x04, 0xbb, 0x04, 0xbb, 0xb4, 0xcd, 0x76, 0x29, 0x75,
		0xc5, 0x4d, 0xa4, 0x8b, 0x19, 0x2e, 0x2a, 0x6b, 0x12, 0xaf, 0x64, 0xa1, 0xda, 0x29, 0xe3, 0xb8,
		0x25, 0x08, 0x25, 0x4b, 0x0e, 0x4a, 0x96, 0x18, 0xc4, 0xe9, 0x7c, 0x62, 0x6b, 0x9c, 0x8d, 0xd3,
		0xf9, 0xf1, 0x4b, 0xf4, 0xc5, 0x2c, 0xc9, 0xa7, 0xa6, 0x03, 0x5f, 0x44, 0xbb, 0xdd, 0x19, 0xec,
		0xb0, 0x78, 0xf1, 0xf5, 0x60, 0xfa, 0x22, 0x08, 0x37, 0x84, 0x3b, 0x32, 0xe3, 0x3d, 0xc7, 0x0d,
		0x62, 0xf1, 0x47, 0x09, 0xde, 0x28, 0xc9, 0x17, 0x25, 0x88, 0xaf, 0x0a, 0x3f, 0x54, 0xad, 0x14,
		0xa9, 0xc8, 0x07, 0x75, 0x18, 0x8c, 0x4c, 0xc5, 0x4d, 0x15, 0xde, 0xa7, 0x3b, 0x15, 0xfa, 0x3c,
		0x4f, 0x6b, 0x76, 0x88, 0xf8, 0x57, 0x9d, 0x01, 0x9c, 0xfd, 0x5e, 0xb7, 0xeb, 0x09, 0xdf, 0xb7,
		0x06, 0x9b, 0xa8, 0xad, 0xaf, 0xc2, 0x0b, 0x1c, 0x5f, 0x8c, 0xb4, 0x3f, 0x26, 0x56, 0xaf, 0x18,
		0x03, 0xd0, 0x0d, 0xe8, 0x8e, 0xcc, 0xb8, 0xd3, 0x12, 0x6e, 0xe0, 0x04, 0x6f, 0xf1, 0x8a, 0x8a,
		0x86, 0xdc, 0x24, 0x4e, 0x39, 0xc6, 0xda, 0x68, 0xe8, 0x4f, 0xb6, 0x2f, 0xe4, 0xe3, 0x62, 0x97,
		0x97, 0x17, 0xb7, 0x8d, 0x87, 0xcb, 0xdf, 0xe2, 0x2e, 0xd3, 0x00, 0x5e, 0x7c, 0xa9, 0xf8, 0x82,
		0x62, 0xa1, 0xe1, 0xfb, 0x3f, 0xee, 0x1f, 0xaa, 0x57, 0x8d, 0x8b, 0xea, 0xfd, 0xf9, 0x5d, 0xed,
		0xf6, 0xa1, 0x76, 0x73, 0x9d, 0xe7, 0x00, 0x67, 0xc5, 0xa7, 0x3b, 0xff, 0xa5, 0x72, 0x7f, 0x5f,
		0xbb, 0x6f, 0xd4, 0x2e, 0xd2, 0xf4, 0x54, 0xb7, 0x37, 0x77, 0x0f, 0x69, 0x9d, 0xb1, 0xd1, 0x7a,
		0x5e, 0x57, 0xae, 0xaa, 0x69, 0x7a, 0xac, 0xab, 0xca, 0x75, 0xe5, 0xe7, 0xea, 0x55, 0xf5, 0xfa,
		0xa1, 0x51, 0xb9, 0xb8, 0xb8, 0xab, 0xde, 0xdf, 0xa7, 0x6e, 0x41, 0xd3, 0x25, 0x63, 0xa3, 0x75,
		0x3c, 0xaf, 0xdc, 0x56, 0x3e, 0xd5, 0x2e, 0x6b, 0x0f, 0xb5, 0xea, 0x3d, 0x75, 0x34, 0xb6, 0xce,
		0x8c, 0xdf, 0x1b, 0x58, 0x66, 0x57, 0x8d, 0x09, 0xbd, 0xf9, 0x81, 0x78, 0xb5, 0x5a, 0xc2, 0x6f,
		0x7a, 0x4e, 0x37, 0x56, 0x9c, 0x6a, 0xc2, 0x80, 0xa2, 0xd7, 0x82, 0xf9, 0x80, 0xf9, 0x44, 0xe5,
		0x44, 0xbe, 0x26, 0x68, 0x8c, 0xcf, 0x5e, 0x0a, 0xf7, 0x65, 0x10, 0x25, 0x85, 0xdb, 0xba, 0x59,
		0x6e, 0x6b, 0xe9, 0x10, 0x5e, 0xea, 0x34, 0x36, 0xc7, 0x6a, 0xd6, 0x31, 0x0f, 0xca, 0x71, 0x4a,
		0xcd, 0x03, 0x8d, 0x81, 0xc6, 0x40, 0x63, 0xa0, 0x31, 0xd0, 0x78, 0xf5, 0x5f, 0x4c, 0xb4, 0x6a,
		0x58, 0xd1, 0xac, 0x64, 0x41, 0x97, 0x86, 0x9d, 0x15, 0x8f, 0xb7, 0xee, 0xb1, 0xe2, 0x3c, 0x4e,
		0x7e, 0x61, 0x1b, 0x88, 0xf9, 0x3d, 0xe4, 0xd9, 0xc7, 0x9d, 0x3c, 0xd4, 0xd4, 0x03, 0xe5, 0xdb,
		0x9d, 0xa6, 0xdd, 0xb6, 0xbc, 0x4e, 0x2f, 0x10, 0xd1, 0xa2, 0xd3, 0x93, 0x13, 0x71, 0xd3, 0x9f,
		0x9a, 0x7b, 0x9d, 0xc5, 0x85, 0xa5, 0x97, 0x5a, 0xa5, 0x55, 0x56, 0x68, 0xc6, 0xea, 0x74, 0x9a,
		0x96, 0xb7, 0x28, 0x54, 0xbb, 0xce, 0xce, 0xc4, 0xb6, 0x2b, 0xb1, 0xed, 0x48, 0xc4, 0x6e, 0x0c,
		0x1f, 0x4d, 0x72, 0xd9, 0x97, 0x15, 0x6f, 0xce, 0x37, 0xc7, 0x33, 0xb5, 0xa6, 0x81, 0xc7, 0xe8,
		0x73, 0x9a, 0x1d, 0x3c, 0x0a, 0x44, 0x1d, 0x3c, 0x96, 0x2d, 0x8f, 0x2c, 0x1d, 0x48, 0xa0, 0x87,
		0xc7, 0x92, 0xe5, 0x4b, 0x0c, 0x64, 0x42, 0xe5, 0x72, 0xdc, 0x97, 0xfd, 0x69, 0x55, 0xdb, 0x1f,
		0x2d, 0xb9, 0x46, 0x73, 0x98, 0xe1, 0x70, 0xf6, 0xcb, 0x8b, 0x27, 0x5e, 0xec, 0x45, 0x3a, 0xbe,
		0x44, 0xd7, 0xa7, 0xae, 0x80, 0xc0, 0xa5, 0x4a, 0xe0, 0xd6, 0xb6, 0x8d, 0x09, 0x97, 0x2e, 0xbe,
		0x53, 0x32, 0xb9, 0x24, 0x23, 0x5d, 0x04, 0xd6, 0x09, 0x43, 0x86, 0x9d, 0x92, 0x35, 0xc2, 0x42,
		0xe3, 0x96, 0xc4, 0xee, 0x24, 0xb0, 0xc6, 0x38, 0xa9, 0x19, 0x2b, 0x45, 0xb1, 0x92, 0x16, 0x2f,
		0x15, 0x31, 0xd3, 0x12, 0x37, 0x55, 0xb1, 0xd3, 0x16, 0x3f, 0x6d, 0x31, 0xd4, 0x15, 0x47, 0x49,
		0x0f, 0x21, 0xe6, 0xba, 0xc5, 0x15, 0xd3, 0xf0, 0x02, 0x99, 0x38, 0xf9, 0xd2, 0x15, 0x8f, 0x1f,
		0x30, 0xa7, 0x72, 0xe6, 0x12, 0x6f, 0xa3, 0x2a, 0x2b, 0xe0, 0xba, 0x82, 0x4e, 0x26, 0xf0, 0x64,
		0x82, 0x4f, 0xa5, 0x00, 0x72, 0x8a, 0xa0, 0x10, 0x65, 0xc8, 0xd1, 0xb4, 0x52, 0x8d, 0x1d, 0x66,
		0x5a, 0x1e, 0x76, 0x4a, 0x41, 0xa3, 0x64, 0xd9, 0x43, 0xb0, 0x51, 0x5d, 0x97, 0x3a, 0x08, 0x3b,
		0x01, 0xa6, 0x49, 0xa6, 0xf3, 0xb3, 0xdd, 0xf6, 0x05, 0x70, 0x02, 0x38, 0xb1, 0x99, 0x38, 0xb1,
		0x21, 0x1d, 0xd5, 0xbb, 0x6a, 0x0a, 0x10, 0x4e, 0x83, 0x1a, 0x1b, 0x83, 0x9a, 0x43, 0xcd, 0xb3,
		0xa1, 0xe6, 0x4e, 0xd7, 0x52, 0x9e, 0xf0, 0x50, 0xd1, 0x4f, 0x15, 0xae, 0x1d, 0x3d, 0xfa, 0xa3,
		0xd2, 0xea, 0xa8, 0x49, 0xd9, 0xdc, 0x8b, 0x7f, 0x2d, 0x5b, 0x5a, 0xb2, 0x96, 0x53, 0x2c, 0xbd,
		0x15, 0xd5, 0x5e, 0xc5, 0x52, 0x5c, 0x91, 0x81, 0xfe, 0xdc, 0xdd, 0x7d, 0x2c, 0x58, 0xa7, 0xf5,
		0x1f, 0x8f, 0x45, 0xeb, 0xb4, 0x3e, 0xfc, 0xb6, 0x38, 0xf8, 0x67, 0xf8, 0x7d, 0xe9, 0xb1, 0x60,
		0x95, 0xc7, 0xdf, 0x1f, 0x3e, 0x16, 0xac, 0xc3, 0xfa, 0xde, 0xe7, 0xcf, 0x1f, 0xf7, 0xbe, 0x1f,
		0xbc, 0xcb, 0x5f, 0xb8, 0x3f, 0xba, 0xd9, 0xde, 0x8f, 0xdd, 0xc7, 0xa2, 0x55, 0xaa, 0x8f, 0x7f,
		0x38, 0x78, 0x2c, 0x58, 0xa5, 0xfa, 0xde, 0xde, 0x3f, 0xf2, 0xca, 0x2f, 0x53, 0xd7, 0x99, 0xcc,
		0x9b, 0xfb, 0xda, 0xef, 0x98, 0xd1, 0xf9, 0x19, 0x55, 0xba, 0xf2, 0xfd, 0x43, 0x82, 0xda, 0x79,
		0xb4, 0xa1, 0xda, 0x69, 0x5b, 0xcf, 0x15, 0xeb, 0xa7, 0xfa, 0xf7, 0xe2, 0x87, 0xf2, 0xfb, 0xd9,
		0xde, 0xf7, 0xe3, 0xf7, 0xf9, 0x5f, 0xfe, 0x58, 0xf4, 0xb1, 0xe2, 0x87, 0xe3, 0xf7, 0xb3, 0x25,
		0x7f, 0x39, 0x7a, 0x3f, 0x8b, 0x39, 0xc6, 0xe1, 0xfb, 0x6e, 0xe4, 0xa3, 0xfd, 0xdf, 0x97, 0x96,
		0x5d, 0x50, 0x5e, 0x72, 0xc1, 0xc1, 0xb2, 0x0b, 0x0e, 0x96, 0x5c, 0xb0, 0xf4, 0x91, 0x4a, 0x4b,
		0x2e, 0x38, 0x7c, 0xff, 0x11, 0xf9, 0xfc, 0xee, 0xe2, 0x8f, 0x1e, 0xbd, 0xef, 0xfd, 0x58, 0xf6,
		0xb7, 0xe3, 0xf7, 0x1f, 0x67, 0x7b, 0x7b, 0xfb, 0xbb, 0xc5, 0xbe, 0xc2, 0x9d, 0x0c, 0x75, 0xb0,
		0x58, 0x8f, 0xa8, 0xe6, 0x50, 0xd5, 0x36, 0x09, 0xb2, 0x20, 0x66, 0x1b, 0x29, 0x66, 0x6a, 0x38,
		0xbe, 0xc3, 0x7b, 0x1f, 0x1e, 0xd7, 0xcd, 0x17, 0x81, 0x15, 0xd8, 0x2f, 0xea, 0xbe, 0xdb, 0x78,
		0x00, 0x38, 0x6f, 0x70, 0xde, 0x36, 0xd2, 0x79, 0x0b, 0xec, 0x97, 0xb8, 0x9d, 0xee, 0x37, 0xca,
		0x77, 0xeb, 0x39, 0x6e, 0x70, 0x50, 0x22, 0x20, 0x86, 0xc7, 0x1a, 0x43, 0xa8, 0x55, 0xf3, 0xa1,
		0x9b, 0x8d, 0xf0, 0x41, 0x74, 0xaa, 0xfd, 0x10, 0x81, 0xdf, 0xd2, 0xe1, 0x34, 0xab, 0x01, 0x45,
		0xc6, 0x23, 0xa8, 0x6b, 0x43, 0xe4, 0xe4, 0xcc, 0x2e, 0x81, 0x46, 0xf5, 0x20, 0x53, 0x4b, 0x50,
		0x2e, 0x9d, 0x96, 0x4f, 0x8f, 0x8e, 0x4b, 0xa7, 0x87, 0x29, 0x5e, 0x8b, 0x9d, 0x64, 0xae, 0xce,
		0x9a, 0x7b, 0xfc, 0x45, 0x7c, 0xb3, 0x94, 0x37, 0xf2, 0xd2, 0xe9, 0x1d, 0xcf, 0xd0, 0xf6, 0x79,
		0xb6, 0x5e, 0x7a, 0xdf, 0xfb, 0xe7, 0xde, 0xbf, 0xb6, 0x98, 0x36, 0x93, 0x66, 0x57, 0x48, 0xd6,
		0xbe, 0x9a, 0x10, 0x72, 0x95, 0x54, 0xc6, 0xf9, 0xb4, 0xc2, 0xfd, 0xf0, 0xdb, 0x95, 0x59, 0x8e,
		0xf2, 0x33, 0x10, 0xa7, 0x4e, 0xa5, 0xe4, 0x6e, 0x90, 0xda, 0x2e, 0x50, 0xea, 0xab, 0x53, 0x22,
		0xab, 0x29, 0x19, 0xbd, 0x53, 0xaf, 0x50, 0xd9, 0x16, 0xf6, 0x73, 0xbc, 0xfa, 0x14, 0x11, 0x70,
		0x3f, 0x96, 0xeb, 0x09, 0x32, 0x50, 0xed, 0x8f, 0x1f, 0x47, 0xb5, 0xec, 0x46, 0xab, 0x66, 0x50,
		0x43, 0x87, 0xe7, 0x2d, 0xa4, 0x15, 0x74, 0x78, 0x19, 0x73, 0xd6, 0x61, 0x09, 0xfa, 0xb9, 0xd1,
		0xfa, 0x89, 0xac, 0x43, 0x44, 0xaa, 0x10, 0xa9, 0x62, 0x89, 0x54, 0x21, 0xeb, 0x10, 0x59, 0x87,
		0xc0, 0x09, 0xe0, 0xc4, 0xba, 0x55, 0x47, 0xd6, 0x21, 0xb2, 0x0e, 0xa1, 0xe6, 0xc8, 0x3a, 0x8c,
		0xa3, 0xe8, 0xc8, 0x3a, 0x44, 0xd6, 0x21, 0xb2, 0x0e, 0x91, 0x75, 0x48, 0xaa, 0x9d, 0xc8, 0x3a,
		0x44, 0x3a, 0x18, 0xb2, 0x0e, 0x21, 0x66, 0x10, 0x33, 0x7d, 0x1c, 0x47, 0xd6, 0x21, 0x9c, 0x37,
		0x38, 0x6f, 0xc8, 0x3a, 0xdc, 0x10, 0xdf, 0x0d, 0x59, 0x87, 0xd3, 0x0f, 0x82, 0xac, 0x43, 0xad,
		0x2f, 0x64, 0x1d, 0xa6, 0x68, 0x2d, 0x90, 0x75, 0x18, 0x0b, 0x00, 0x91, 0x75, 0xb8, 0x65, 0xb4,
		0x79, 0x23, 0xb3, 0x0e, 0x57, 0x54, 0x74, 0x95, 0x9f, 0x00, 0xbd, 0x6a, 0x6c, 0xff, 0x16, 0x6f,
		0xf1, 0xab, 0x11, 0x6e, 0x60, 0x67, 0x0c, 0x73, 0x3d, 0x5a, 0x55, 0x24, 0x45, 0xa1, 0x81, 0x6b,
		0x7f, 0xac, 0xbb, 0xc1, 0xb8, 0x8d, 0x4a, 0x38, 0x4c, 0x56, 0x6a, 0x1e, 0xc7, 0x9f, 0x23, 0x9d,
		0xc2, 0xa4, 0xab, 0x13, 0xfc, 0x62, 0x25, 0xf4, 0xc5, 0x2e, 0x41, 0x5a, 0x42, 0x09, 0xd2, 0xec,
		0xd4, 0xbc, 0x95, 0xab, 0xb4, 0xbd, 0x44, 0xb2, 0x9c, 0xe6, 0xb2, 0x9a, 0xd6, 0x0b, 0x25, 0x6c,
		0xf2, 0x71, 0x14, 0xbb, 0xcd, 0x56, 0xb1, 0xdb, 0xe1, 0xea, 0x49, 0xb4, 0xdf, 0x18, 0x7e, 0x1e,
		0x65, 0x6e, 0x51, 0xe6, 0x76, 0xfa, 0x83, 0x28, 0x73, 0x8b, 0x84, 0x73, 0x24, 0x9c, 0x33, 0x07,
		0x89, 0xb0, 0x49, 0x81, 0x4d, 0x0a, 0x24, 0x9c, 0x2b, 0xcc, 0x05, 0xf2, 0x48, 0xa1, 0xe5, 0xd0,
		0xf2, 0x15, 0xab, 0x8e, 0x3c, 0x52, 0xe4, 0x91, 0x22, 0x8f, 0x74, 0xf3, 0x67, 0x14, 0x79, 0xa4,
		0x69, 0xd1, 0x4e, 0x24, 0xf8, 0x21, 0x8f, 0xd4, 0x00, 0x64, 0x41, 0xcc, 0x90, 0x47, 0xaa, 0x46,
		0x42, 0x73, 0xc8, 0x23, 0x85, 0xf3, 0x06, 0xe7, 0x0d, 0x79, 0xa4, 0xa9, 0xf5, 0xdd, 0x90, 0x47,
		0x3a, 0xfd, 0x20, 0xc8, 0x23, 0xd5, 0xfa, 0x42, 0x1e, 0x69, 0x8a, 0xd6, 0x02, 0x79, 0xa4, 0xb1,
		0x00, 0x10, 0x79, 0xa4, 0x5b, 0x46, 0x9b, 0xb3, 0x9b, 0x47, 0x3a, 0x93, 0x24, 0x34, 0xfa, 0x29,
		0x81, 0xba, 0x95, 0xae, 0xf8, 0x16, 0x58, 0x5f, 0x3a, 0x5d, 0x5f, 0x3e, 0x53, 0x61, 0x72, 0x29,
		0x92, 0x15, 0x90, 0xac, 0xa0, 0xa1, 0x77, 0xd2, 0xc9, 0x0a, 0x63, 0xc9, 0x53, 0x77, 0x81, 0xc3,
		0x11, 0xd4, 0x7c, 0xe0, 0x22, 0x7c, 0x60, 0xf8, 0xc0, 0x9c, 0x3e, 0xb0, 0xac, 0x4a, 0x84, 0x17,
		0x4a, 0xa6, 0x9d, 0x2d, 0x15, 0x1a, 0xa9, 0x34, 0x34, 0x22, 0x35, 0xd1, 0x56, 0x17, 0x0a, 0xb5,
		0x21, 0x55, 0x1f, 0x2a, 0x35, 0x22, 0x57, 0x27, 0x72, 0xb5, 0xa2, 0x56, 0x2f, 0x3d, 0xdf, 0x45,
		0xd1, 0x03, 0x51, 0x56, 0xbb, 0x70, 0x00, 0xc7, 0x6d, 0x09, 0x7d, 0x97, 0x77, 0xb2, 0xdd, 0x37,
		0x18, 0x4e, 0x73, 0x45, 0x68, 0xfc, 0x66, 0x6d, 0xa5, 0xa4, 0x54, 0x4e, 0x16, 0x25, 0xa5, 0x56,
		0x56, 0x36, 0xa5, 0x65, 0x53, 0x5e, 0x2e, 0x25, 0x26, 0x0a, 0x63, 0x68, 0xca, 0x9d, 0x72, 0x5c,
		0x79, 0xa9, 0xd4, 0x69, 0x87, 0x1a, 0xa2, 0x21, 0x87, 0x84, 0x02, 0x3d, 0x1a, 0x73, 0x9b, 0x7f,
		0x15, 0x81, 0x17, 0xe3, 0xc0, 0x44, 0xec, 0x59, 0x1d, 0x8d, 0x07, 0xd4, 0x03, 0xea, 0x01, 0xf5,
		0x52, 0x88, 0x7a, 0xda, 0xbb, 0x4c, 0xf3, 0x3a, 0x7a, 0x4c, 0x30, 0x14, 0xcd, 0xae, 0xd3, 0xf8,
		0x8b, 0x46, 0x05, 0x72, 0xd4, 0xbb, 0x50, 0xc4, 0xe0, 0x16, 0x19, 0x96, 0x78, 0x57, 0x2a, 0x1c,
		0x97, 0x61, 0x47, 0x84, 0x48, 0x3d, 0x66, 0x97, 0x8a, 0x70, 0xb7, 0xca, 0xd4, 0x52, 0x51, 0xef,
		0x5e, 0x19, 0x59, 0xb3, 0x9d, 0x74, 0x8c, 0x52, 0xcf, 0x20, 0xd9, 0x52, 0x0e, 0x7d, 0x2e, 0x85,
		0x73, 0xc5, 0x50, 0x28, 0x08, 0x17, 0x08, 0x17, 0x08, 0x97, 0x19, 0xc2, 0xe5, 0xca, 0x1f, 0xa8,
		0x5c, 0xe9, 0x65, 0x9e, 0x12, 0x8c, 0xa5, 0x95, 0xeb, 0xc4, 0xc8, 0xb7, 0xa6, 0x0e, 0xf0, 0xd8,
		0xad, 0x96, 0x27, 0x7c, 0x3f, 0x4f, 0x48, 0x11, 0x08, 0x67, 0x90, 0x67, 0x26, 0xe9, 0x67, 0x74,
		0xc1, 0xcc, 0x7e, 0x2d, 0x33, 0xcc, 0x6d, 0x34, 0x16, 0xc2, 0x30, 0x36, 0x55, 0x5a, 0xc6, 0xd2,
		0x1b, 0x18, 0x3d, 0x18, 0xf3, 0x8f, 0x3c, 0xf9, 0x4b, 0xd4, 0x39, 0x26, 0x9d, 0x32, 0x8f, 0x7f,
		0x73, 0x67, 0x9e, 0x74, 0xc4, 0xf7, 0x0f, 0x19, 0x82, 0x93, 0x23, 0xc0, 0xc9, 0x6a, 0xa1, 0xc6,
		0xa1, 0x15, 0xf3, 0x87, 0x56, 0x00, 0xae, 0x90, 0xc3, 0x4d, 0x95, 0x43, 0x5a, 0x53, 0xb3, 0x93,
		0xae, 0xe7, 0x22, 0x32, 0x7d, 0x0c, 0x3e, 0xc9, 0x30, 0x01, 0xb4, 0x25, 0x9e, 0x1d, 0x57, 0xb4,
		0x2c, 0xa2, 0xc0, 0xcb, 0x42, 0x63, 0x47, 0x18, 0x0d, 0xcc, 0xd7, 0x5a, 0xc2, 0x0d, 0x9c, 0xe0,
		0xed, 0x93, 0xed, 0x0b, 0xfa, 0xf8, 0xe8, 0x78, 0x6e, 0x2e, 0x6f, 0xce, 0x2b, 0x97, 0x8d, 0x8b,
		0xea, 0x4f, 0xb5, 0xeb, 0xea, 0x45, 0xe3, 0xba, 0xfa, 0xfb, 0x43, 0xe3, 0x97, 0x9b, 0xdb, 0x3c,
		0x47, 0xd8, 0xd4, 0x67, 0xc1, 0xc9, 0xef, 0x3c, 0xc8, 0x3b, 0x9e, 0x9f, 0x8b, 0xbb, 0x9b, 0x5b,
		0x7a, 0x24, 0x78, 0xff, 0x90, 0xb5, 0x79, 0x18, 0xca, 0xc9, 0x65, 0xed, 0xfa, 0xdf, 0x0c, 0xb3,
		0xb1, 0x93, 0x4e, 0x94, 0x45, 0xc0, 0x5c, 0x3d, 0x60, 0xee, 0x89, 0x66, 0xcf, 0x23, 0x00, 0xae,
		0x50, 0x00, 0xc7, 0x03, 0x6a, 0x86, 0x09, 0x35, 0x3b, 0xef, 0x2e, 0x43, 0x7e, 0x84, 0xdf, 0xe3,
		0x0e, 0x8a, 0xf0, 0x3b, 0xc2, 0xef, 0xb1, 0xa4, 0x4e, 0xbd, 0x73, 0xf0, 0x52, 0x7a, 0x56, 0x4c,
		0x0a, 0x48, 0x8d, 0x66, 0xd3, 0x2a, 0x9e, 0xa7, 0x8a, 0x8c, 0x43, 0x77, 0xbe, 0x2a, 0x3c, 0xb2,
		0x14, 0x7e, 0x27, 0x75, 0xe4, 0x4a, 0x7f, 0x3a, 0x15, 0xa6, 0x52, 0x33, 0xa7, 0x98, 0x24, 0x97,
		0x58, 0xd3, 0xba, 0x20, 0xa1, 0xdf, 0x98, 0xd5, 0x40, 0x42, 0x3f, 0xad, 0x35, 0x98, 0xf8, 0xee,
		0xc2, 0x7e, 0xf6, 0xc4, 0x33, 0xc5, 0xb9, 0xe2, 0x63, 0xbd, 0x73, 0xc5, 0x03, 0x14, 0xfc, 0xf8,
		0x71, 0x58, 0xd6, 0x7e, 0x7f, 0xa8, 0xd6, 0xa9, 0x86, 0xaf, 0x40, 0x78, 0xcf, 0x76, 0x53, 0x58,
		0xfd, 0xe9, 0x23, 0x80, 0xb1, 0xe9, 0xe1, 0x70, 0x3e, 0xa9, 0xaf, 0x93, 0xce, 0x33, 0xa0, 0x4c,
		0x01, 0xca, 0x9c, 0xe7, 0xad, 0x39, 0x97, 0xa4, 0x79, 0x2c, 0x30, 0x22, 0x74, 0x5a, 0xc7, 0x03,
		0x89, 0xd4, 0x30, 0x33, 0x3e, 0xab, 0x96, 0x7a, 0xc2, 0x5f, 0xe5, 0x50, 0xdf, 0x74, 0xf8, 0xaa,
		0xba, 0x6a, 0x1d, 0xb5, 0xb1, 0x74, 0xe2, 0x11, 0xb1, 0xb7, 0x54, 0xe2, 0x41, 0x5c, 0xc6, 0x87,
		0x4a, 0xf9, 0x39, 0x40, 0x80, 0x0d, 0x0c, 0xb8, 0x40, 0x81, 0x1d, 0x1c, 0xd8, 0x41, 0x82, 0x13,
		0x2c, 0x68, 0x40, 0x83, 0x08, 0x3c, 0xe8, 0x03, 0x5e, 0x0c, 0x2e, 0x0f, 0x87, 0x0b, 0xb4, 0xd4,
		0x25, 0xda, 0x1f, 0x2c, 0xf3, 0x59, 0x08, 0x58, 0xfe, 0xfc, 0x2f, 0x46, 0x3f, 0x0f, 0x7a, 0xea,
		0xa5, 0x64, 0x47, 0x85, 0xa2, 0xc8, 0x9a, 0xdf, 0x7b, 0x62, 0xc4, 0xff, 0x99, 0xd1, 0x61, 0x02,
		0x60, 0x02, 0x60, 0x02, 0x60, 0x02, 0x32, 0x6b, 0x02, 0x1e, 0x27, 0x26, 0xe0, 0x7f, 0x9b, 0x3d,
		0xcf, 0x13, 0x6e, 0xb0, 0xbb, 0xb7, 0xff, 0xf1, 0xe3, 0x7e, 0xf8, 0x89, 0xfa, 0xe8, 0x92, 0x69,
		0xdc, 0xf3, 0x17, 0xfc, 0x2e, 0x1c, 0x59, 0x39, 0xfc, 0xc6, 0x60, 0x4d, 0x12, 0xf5, 0x66, 0xaa,
		0xdf, 0x02, 0x9a, 0xcc, 0x1a, 0x7a, 0x07, 0xb7, 0xd3, 0xb4, 0xc4, 0xb7, 0xe0, 0x2c, 0x10, 0x6d,
		0xf1, 0x2a, 0x02, 0xef, 0xcd, 0xea, 0xb8, 0x56, 0xf3, 0xcb, 0xe0, 0xc8, 0x30, 0x8b, 0xd3, 0x3b,
		0xd8, 0xd1, 0x67, 0xf0, 0x7a, 0x93, 0x76, 0x78, 0xeb, 0xba, 0x01, 0x38, 0x9a, 0x1d, 0xc1, 0x09,
		0xf5, 0xe1, 0xdc, 0x19, 0x9c, 0x89, 0x34, 0x6b, 0xed, 0x13, 0xea, 0x4f, 0xbe, 0x4e, 0x06, 0xcc,
		0xea, 0xbe, 0xc8, 0xf2, 0x84, 0x30, 0x88, 0xd7, 0xc1, 0xda, 0x68, 0xe4, 0xaf, 0x84, 0xc8, 0x1f,
		0x22, 0x7f, 0x88, 0xfc, 0x21, 0xf2, 0x07, 0xb7, 0x0f, 0x6e, 0x1f, 0xdc, 0x3e, 0xb8, 0x7d, 0x88,
		0xfc, 0x21, 0xf2, 0x07, 0x13, 0x00, 0x13, 0x00, 0x13, 0x00, 0x13, 0x80, 0xc8, 0x1f, 0xb3, 0x37,
		0x93, 0xe1, 0xb0, 0xce, 0x30, 0x9a, 0x81, 0x74, 0xfc, 0x54, 0xae, 0x4e, 0x5e, 0x2b, 0xea, 0xe5,
		0xf5, 0x9a, 0x81, 0x3b, 0x3e, 0x35, 0xd8, 0x7f, 0x96, 0xbb, 0xc1, 0xcd, 0x1b, 0xf7, 0x83, 0x9b,
		0x37, 0xae, 0xc5, 0xb7, 0xe0, 0x97, 0x4e, 0xb7, 0x51, 0x1b, 0xdf, 0xf1, 0x4e, 0x3c, 0xa7, 0x39,
		0x8f, 0x56, 0x2f, 0x8c, 0x47, 0x12, 0xbe, 0x23, 0xcb, 0x9b, 0x2d, 0xe1, 0x18, 0x00, 0x2f, 0xe5,
		0xc2, 0x31, 0x00, 0xd2, 0x70, 0x1b, 0xea, 0xfa, 0x9b, 0xf5, 0x9d, 0x70, 0xe2, 0x13, 0x27, 0x3e,
		0xcd, 0xfb, 0x40, 0xa8, 0xeb, 0x3f, 0xf3, 0xec, 0xa8, 0xeb, 0x0f, 0xd4, 0x03, 0xea, 0x6d, 0x0f,
		0xea, 0xa1, 0xae, 0xbf, 0xcc, 0x83, 0xa1, 0xae, 0x3f, 0xea, 0xfa, 0xa3, 0xae, 0x3f, 0x71, 0x18,
		0x33, 0x87, 0xba, 0xfe, 0xa8, 0xeb, 0x0f, 0xc2, 0x05, 0xc2, 0xb5, 0x1d, 0x84, 0x0b, 0x75, 0xfd,
		0x15, 0x42, 0x67, 0xa8, 0xeb, 0x4f, 0xfb, 0x85, 0xba, 0xfe, 0x71, 0x6e, 0x80, 0xba, 0xfe, 0x0b,
		0x26, 0x1d, 0x75, 0xfd, 0xd9, 0xd9, 0x28, 0xa3, 0x5f, 0x94, 0x43, 0x5d, 0xff, 0xa4, 0xe1, 0x04,
		0xf5, 0xd4, 0x51, 0xd7, 0x3f, 0x0d, 0xe0, 0x0a, 0x39, 0x44, 0x5d, 0x7f, 0xa6, 0x70, 0x4e, 0x0e,
		0x75, 0xfd, 0x09, 0x8d, 0x1d, 0xea, 0xfa, 0xaf, 0x08, 0x9b, 0xa2, 0xae, 0x3f, 0x17, 0x4d, 0xcc,
		0xa1, 0xae, 0x3f, 0x07, 0xca, 0x22, 0x60, 0x8e, 0xba, 0xfe, 0x31, 0x91, 0x1f, 0xe1, 0xf7, 0xb8,
		0x83, 0x22, 0xfc, 0x8e, 0xf0, 0x7b, 0x2c, 0xa9, 0x43, 0x5d, 0xff, 0x4d, 0x3e, 0x48, 0xa0, 0x71,
		0xb0, 0x43, 0x21, 0x9f, 0x7f, 0x87, 0x71, 0xde, 0xfb, 0x08, 0xa4, 0x9a, 0x34, 0x9c, 0xbf, 0x74,
		0xfc, 0xa0, 0x12, 0x04, 0x6a, 0xe9, 0xcf, 0xf9, 0x2b, 0xc7, 0xad, 0xb6, 0x45, 0x1f, 0x4b, 0x7c,
		0x35, 0xd3, 0x91, 0xbf, 0xb2, 0xbf, 0x4d, 0x8d, 0x50, 0x3c, 0x29, 0x97, 0x8f, 0x8e, 0xcb, 0xe5,
		0xc2, 0xf1, 0xc1, 0x71, 0xe1, 0xf4, 0xf0, 0xb0, 0x78, 0xa4, 0xe2, 0xd1, 0xe4, 0x6f, 0xbc, 0x96,
		0xf0, 0x44, 0xeb, 0x53, 0x7f, 0x5a, 0xdc, 0x5e, 0xbb, 0xcd, 0x3a, 0xfb, 0x9a, 0xd2, 0xce, 0x2a,
		0xe5, 0x79, 0xa5, 0x73, 0x24, 0xf1, 0x0e, 0xc6, 0xc8, 0xe9, 0x4e, 0x7c, 0x0d, 0x88, 0xf7, 0xc9,
		0x98, 0xab, 0xa4, 0xba, 0x3a, 0x1c, 0xab, 0x12, 0x6f, 0xc2, 0xd6, 0xbf, 0x7e, 0x8c, 0x57, 0x1f,
		0x33, 0x91, 0xb8, 0xaf, 0x1c, 0xda, 0x3c, 0x29, 0x06, 0x23, 0xc9, 0x3d, 0xa5, 0x39, 0xa6, 0x0a,
		0x97, 0xd4, 0xe2, 0x8c, 0xaa, 0xdc, 0x50, 0x9b, 0x03, 0x6a, 0x73, 0x3d, 0x5d, 0x4e, 0x47, 0xab,
		0x74, 0xd2, 0x5c, 0x4c, 0xe3, 0x54, 0xb1, 0xca, 0xa9, 0xe1, 0x68, 0x97, 0x8c, 0xd1, 0xaa, 0x19,
		0xd4, 0x50, 0xb9, 0xe3, 0x7a, 0x4a, 0xc7, 0xf3, 0x24, 0x8f, 0xe3, 0x49, 0x1f, 0xbf, 0x83, 0x7e,
		0x66, 0x54, 0x3f, 0x65, 0x8f, 0xbb, 0xe5, 0x5b, 0xc2, 0x6f, 0x7a, 0x4e, 0x57, 0x89, 0xe4, 0x84,
		0x2b, 0x3e, 0x3d, 0x88, 0x2c, 0xc3, 0x55, 0x0a, 0x72, 0x28, 0x07, 0x35, 0x74, 0x82, 0x18, 0x24,
		0x41, 0x0b, 0xdd, 0x20, 0x05, 0x59, 0x50, 0x82, 0x2c, 0x08, 0x41, 0x15, 0x74, 0xe0, 0xf5, 0xa4,
		0x94, 0x83, 0x08, 0xfa, 0x47, 0xc3, 0x14, 0x8f, 0x82, 0x49, 0xf0, 0x6a, 0x09, 0x9c, 0xed, 0xaa,
		0xc9, 0xbf, 0x1a, 0x8d, 0x84, 0x96, 0x43, 0xcb, 0x33, 0xa6, 0xe5, 0x4e, 0xd7, 0x52, 0x9e, 0x70,
		0x9d, 0x5c, 0x52, 0xbd, 0x9c, 0x51, 0x82, 0xa2, 0x08, 0x83, 0x1c, 0x50, 0xed, 0x30, 0x37, 0x45,
		0x6e, 0x16, 0x59, 0x0e, 0x96, 0xd9, 0x04, 0xc2, 0xfd, 0xd1, 0xcd, 0xf6, 0x7e, 0xec, 0x3e, 0x16,
		0xad, 0x52, 0x7d, 0xfc, 0xc3, 0xc1, 0x63, 0xc1, 0x2a, 0xd5, 0xb5, 0xb2, 0x3e, 0xea, 0x3a, 0x93,
		0x49, 0x99, 0x4d, 0xb4, 0x39, 0x33, 0x6a, 0x32, 0x6c, 0x4e, 0xa3, 0x9d, 0x47, 0x1b, 0xaa, 0x9d,
		0xc8, 0x40, 0x33, 0x9f, 0x81, 0xb6, 0xbf, 0x5b, 0xec, 0x2b, 0xdc, 0xc9, 0x50, 0x07, 0x8b, 0xf5,
		0x88, 0x6a, 0x0e, 0x55, 0x6d, 0x93, 0x20, 0x0b, 0x62, 0xb6, 0x91, 0x62, 0x66, 0x68, 0x9b, 0xaf,
		0x9e, 0x02, 0xd7, 0xcd, 0x17, 0x81, 0x15, 0xd8, 0x2f, 0xea, 0xbe, 0xdb, 0x78, 0x00, 0x38, 0x6f,
		0x70, 0xde, 0x36, 0xd2, 0x79, 0x0b, 0xec, 0x17, 0x2b, 0xe8, 0x8f, 0xb2, 0x65, 0xbe, 0x9b, 0x76,
		0xfd, 0x0e, 0x82, 0xba, 0x1d, 0x44, 0xf5, 0x3a, 0x08, 0xb2, 0x7c, 0x28, 0xeb, 0x73, 0x50, 0x97,
		0xad, 0x26, 0xae, 0xc7, 0xc1, 0x51, 0xd3, 0x81, 0xa2, 0x3c, 0x39, 0x65, 0xdd, 0x0d, 0xae, 0x25,
		0xa0, 0xae, 0xb3, 0xc1, 0xb2, 0x16, 0x09, 0x65, 0x95, 0x65, 0xcd, 0x3d, 0xfe, 0x22, 0xbe, 0x59,
		0xda, 0xa5, 0xdb, 0xd2, 0xe5, 0x1d, 0xcf, 0xd0, 0xf6, 0x79, 0xb6, 0x5e, 0x7a, 0xdf, 0xfb, 0xe7,
		0xde, 0xbf, 0xb6, 0x98, 0x36, 0x6f, 0x58, 0x26, 0x91, 0x44, 0xca, 0x62, 0x8c, 0x1c, 0x85, 0x1d,
		0x8d, 0x49, 0x19, 0xa7, 0x1c, 0xc6, 0x22, 0xae, 0x72, 0x39, 0x86, 0xf2, 0x39, 0x85, 0x24, 0x39,
		0x84, 0x72, 0x39, 0x83, 0xeb, 0xa6, 0x47, 0x52, 0x56, 0xe8, 0x64, 0x24, 0x1f, 0x2b, 0xf3, 0x64,
		0x75, 0x82, 0xdf, 0x6a, 0x09, 0x5b, 0x2e, 0x37, 0x8b, 0xff, 0xb2, 0x64, 0xaa, 0xe2, 0x4e, 0x11,
		0xc1, 0xd4, 0x2c, 0x7e, 0x9f, 0xe8, 0xd3, 0xce, 0xfe, 0x66, 0xee, 0xb9, 0xd7, 0x3d, 0xaf, 0xd2,
		0x73, 0x2e, 0x58, 0xad, 0xe5, 0xab, 0x33, 0xfb, 0x1a, 0x93, 0x87, 0x9d, 0x7a, 0xd0, 0xfc, 0xab,
		0xf0, 0x7d, 0xfb, 0x65, 0x70, 0xd0, 0x6d, 0xf6, 0x11, 0xa7, 0x8a, 0x6c, 0x8e, 0x3e, 0x31, 0xf7,
		0x7a, 0x8b, 0x53, 0x85, 0x96, 0xba, 0xe7, 0xab, 0xdc, 0xef, 0x69, 0xf7, 0x7a, 0xc9, 0xed, 0xe2,
		0x38, 0xd0, 0xb1, 0x1d, 0xe4, 0xd8, 0x0e, 0xf0, 0xbc, 0x83, 0x1b, 0x3e, 0x9c, 0xa4, 0x28, 0x2c,
		0x4b, 0x9f, 0xc9, 0x37, 0xc7, 0xb3, 0xb5, 0xe4, 0x8d, 0xc6, 0x13, 0x33, 0xfa, 0xdc, 0x92, 0xa7,
		0x5c, 0x9d, 0xb5, 0xb5, 0x36, 0x62, 0x12, 0x27, 0x32, 0x12, 0x73, 0x89, 0x64, 0x63, 0x1d, 0xd2,
		0x31, 0x0d, 0xe9, 0xd8, 0x45, 0xfc, 0x25, 0x54, 0x43, 0xa5, 0x75, 0x99, 0x51, 0x79, 0x5f, 0x7c,
		0x15, 0x9e, 0x13, 0xbc, 0xad, 0x9f, 0x8b, 0x49, 0x3c, 0x6d, 0x74, 0xc5, 0x3a, 0x93, 0x1a, 0xcb,
		0x81, 0x89, 0x1d, 0x30, 0x93, 0x09, 0x90, 0x49, 0x8a, 0x83, 0x6a, 0x08, 0x4c, 0x39, 0xe4, 0xa5,
		0x1c, 0xe2, 0x92, 0x17, 0x17, 0x1a, 0x7a, 0x14, 0x3b, 0x48, 0x35, 0x91, 0x92, 0x37, 0xbf, 0xdd,
		0x79, 0xb1, 0x62, 0x0a, 0xcb, 0x0c, 0x4e, 0x94, 0x63, 0x7c, 0xb6, 0xea, 0xf6, 0x5e, 0xfb, 0x0f,
		0xf4, 0x9e, 0x11, 0xdb, 0x3e, 0x5e, 0xa8, 0xfd, 0xf0, 0x9b, 0x55, 0xfd, 0x75, 0x17, 0xd8, 0xf2,
		0x05, 0xf6, 0xa6, 0x25, 0x9e, 0x7a, 0x2f, 0x96, 0x70, 0x03, 0xcf, 0x59, 0x60, 0x21, 0x23, 0x2b,
		0x32, 0xfb, 0x71, 0x60, 0x75, 0xf6, 0xb0, 0x7a, 0xb8, 0x82, 0xbe, 0xf0, 0xbe, 0x3a, 0x71, 0x26,
		0x64, 0x76, 0xe1, 0xc7, 0x97, 0xc5, 0x43, 0xed, 0x22, 0x50, 0x3b, 0xfb, 0xa8, 0x1d, 0x37, 0x2d,
		0x7a, 0x1d, 0xcf, 0x53, 0xe3, 0x7d, 0x8a, 0xa2, 0x25, 0x2d, 0x62, 0x2a, 0xa2, 0xa6, 0x29, 0x72,
		0xaa, 0xa2, 0xa7, 0x2d, 0x82, 0xda, 0xa2, 0xa8, 0x2f, 0x92, 0x3c, 0xc1, 0x28, 0xe9, 0x0c, 0x7e,
		0xe1, 0xda, 0x4f, 0x6d, 0xd1, 0x52, 0xdf, 0x16, 0x1e, 0x0f, 0x20, 0x39, 0x6f, 0x9a, 0xe5, 0x0e,
		0xb2, 0xba, 0xad, 0xac, 0xa0, 0x1c, 0xba, 0x4a, 0x42, 0xa6, 0x2c, 0x64, 0x4a, 0x43, 0xa7, 0x3c,
		0x6a, 0xb1, 0x65, 0xf3, 0x5b, 0xcb, 0xea, 0x25, 0x03, 0x14, 0x4b, 0x04, 0x70, 0xe5, 0x90, 0xc4,
		0xa3, 0x4c, 0x2b, 0x7c, 0xde, 0x38, 0xe4, 0x09, 0xca, 0x0e, 0x65, 0xcf, 0xb0, 0xb2, 0x3b, 0xa3,
		0xfa, 0x68, 0x6a, 0x8d, 0x28, 0x75, 0x4a, 0xb6, 0xd1, 0x94, 0x66, 0x9b, 0x94, 0x18, 0xab, 0x7e,
		0xfa, 0xf5, 0xe7, 0xc6, 0x7d, 0xf5, 0xee, 0xb7, 0xda, 0x79, 0x95, 0x7d, 0x9d, 0x36, 0x66, 0xfb,
		0x2e, 0x1a, 0xa3, 0x98, 0x09, 0x19, 0xec, 0xcf, 0xf8, 0x91, 0x2b, 0xe3, 0x17, 0xf2, 0x6f, 0x1e,
		0xeb, 0x84, 0xb1, 0x24, 0x8a, 0x2b, 0xa2, 0x77, 0xda, 0xab, 0x00, 0xc0, 0x4f, 0x49, 0xd0, 0x4f,
		0xc9, 0x5e, 0x25, 0x80, 0xb1, 0xf0, 0xa3, 0x14, 0x80, 0xc9, 0x52, 0x00, 0x50, 0x52, 0x04, 0x13,
		0x10, 0x4c, 0x80, 0x7f, 0x01, 0xff, 0x02, 0xc1, 0x04, 0x04, 0x13, 0xa0, 0xec, 0x08, 0x26, 0x20,
		0x98, 0x80, 0x60, 0xc2, 0xd2, 0x60, 0x42, 0xfa, 0x32, 0x81, 0x63, 0x6e, 0x97, 0x23, 0x15, 0xd8,
		0x90, 0x88, 0xc8, 0x27, 0x02, 0x5f, 0x8d, 0x46, 0x6d, 0x5c, 0xf4, 0xc7, 0xb9, 0x8f, 0xe3, 0x06,
		0xa7, 0x39, 0x5f, 0x68, 0x36, 0x7d, 0x47, 0x23, 0x6d, 0x68, 0xb5, 0x77, 0x1e, 0xcb, 0x1b, 0x8f,
		0x9d, 0x26, 0x54, 0x42, 0x9a, 0x90, 0xf9, 0x34, 0xa1, 0xd1, 0x0d, 0xe3, 0x27, 0x08, 0x8d, 0x2f,
		0x20, 0x4e, 0x0d, 0x2a, 0x21, 0x35, 0x88, 0x91, 0x10, 0x1a, 0x4a, 0x0d, 0xb2, 0xbb, 0x5d, 0x6b,
		0x84, 0xa8, 0x92, 0xe1, 0xbc, 0xf0, 0x4a, 0x84, 0xdd, 0x11, 0xd1, 0x4b, 0x2c, 0xec, 0x2e, 0x7d,
		0x3e, 0x52, 0xb2, 0x6e, 0x21, 0x4d, 0xc4, 0xfc, 0xd5, 0x57, 0xc8, 0xbe, 0xeb, 0x5f, 0x04, 0xdd,
		0x82, 0x6e, 0x41, 0xb7, 0xd6, 0xe9, 0x96, 0xd3, 0x52, 0xd2, 0x2e, 0xa7, 0x05, 0xfd, 0x82, 0x7e,
		0x41, 0xbf, 0x56, 0xdf, 0xb3, 0xeb, 0x39, 0x9d, 0x58, 0x27, 0xc8, 0x22, 0xef, 0x17, 0x5e, 0x09,
		0x2d, 0x83, 0x96, 0x25, 0xa6, 0x65, 0x3d, 0xc7, 0x0d, 0x4e, 0x14, 0x94, 0x4c, 0x22, 0x34, 0xad,
		0x58, 0x25, 0x48, 0xad, 0x81, 0x91, 0xc6, 0x76, 0x89, 0x56, 0xc9, 0x19, 0xdd, 0x2a, 0x3f, 0x14,
		0x95, 0x64, 0xde, 0xd5, 0x3a, 0x36, 0x25, 0x3e, 0x65, 0xa5, 0xc3, 0xc3, 0x04, 0x27, 0x8d, 0x69,
		0x8b, 0xa2, 0x6e, 0xd4, 0x08, 0x75, 0x9a, 0x2a, 0x2c, 0x6f, 0x74, 0x1d, 0x0c, 0x10, 0x0c, 0xd0,
		0x36, 0xd3, 0x3c, 0xad, 0x58, 0x62, 0xf5, 0x5b, 0x10, 0xaf, 0x13, 0xb5, 0x7c, 0x10, 0xb6, 0xd3,
		0xb4, 0xc4, 0xb7, 0xe0, 0x2c, 0x10, 0x6d, 0xf1, 0x2a, 0x02, 0xef, 0xcd, 0xb2, 0x83, 0xce, 0x6b,
		0xac, 0xaa, 0x30, 0x0b, 0x64, 0x6c, 0x90, 0x62, 0xa5, 0x10, 0x96, 0xd5, 0x8d, 0xc5, 0xd6, 0x13,
		0xdc, 0x51, 0x1b, 0xe6, 0x80, 0xc6, 0x0b, 0xf0, 0xe7, 0x56, 0xec, 0xa1, 0x8d, 0xbe, 0x51, 0xde,
		0x3e, 0xfb, 0x80, 0x0a, 0x14, 0xd8, 0xb0, 0xd0, 0x01, 0x19, 0x54, 0xa0, 0x20, 0xdf, 0x51, 0x5e,
		0x91, 0x74, 0x61, 0xae, 0x98, 0x54, 0xe4, 0xb1, 0xd6, 0xd7, 0x90, 0xba, 0x5a, 0x28, 0x72, 0x8b,
		0x0b, 0x48, 0xb9, 0x22, 0xf8, 0xbb, 0xe3, 0xfd, 0x65, 0x39, 0xae, 0x1f, 0xd8, 0x6e, 0x73, 0x55,
		0x25, 0xa9, 0xe8, 0x47, 0xcd, 0x94, 0x94, 0x72, 0x45, 0xd0, 0xbf, 0x65, 0x2a, 0x2b, 0x4a, 0x8d,
		0x9f, 0x8d, 0xaa, 0xa0, 0xd4, 0xfc, 0x1c, 0xaf, 0x4f, 0x43, 0x88, 0x5c, 0x91, 0x8e, 0xc2, 0x25,
		0xcb, 0x17, 0x4d, 0x16, 0xca, 0xcd, 0x27, 0x24, 0x2c, 0x5d, 0x54, 0x35, 0x68, 0x5a, 0x9b, 0x8f,
		0x60, 0x3f, 0x07, 0x7e, 0x7c, 0xe3, 0x3e, 0xf8, 0x74, 0x36, 0x32, 0x11, 0xec, 0xe7, 0x60, 0x23,
		0x6d, 0x7a, 0xff, 0xbd, 0xd2, 0x92, 0x7f, 0x20, 0x82, 0x2f, 0xc2, 0x73, 0x45, 0x20, 0xef, 0xda,
		0x87, 0x57, 0x6e, 0x46, 0x79, 0x92, 0x78, 0xc2, 0xb6, 0x79, 0x7e, 0x7d, 0x2c, 0x61, 0xe4, 0x71,
		0xe9, 0xa5, 0xcf, 0x11, 0xbd, 0xda, 0xcd, 0x41, 0x86, 0xde, 0x9b, 0xfa, 0xe1, 0x80, 0xc9, 0x10,
		0x6a, 0xc7, 0x03, 0x8a, 0x19, 0x3b, 0x1e, 0x20, 0x27, 0xd6, 0xba, 0xe2, 0x4d, 0x26, 0xe6, 0x64,
		0xe2, 0x4e, 0x22, 0xf6, 0x8a, 0x91, 0x5c, 0xd9, 0xd3, 0x6a, 0x92, 0xea, 0x30, 0xa3, 0x16, 0x76,
		0xab, 0xe5, 0x09, 0xdf, 0xd7, 0xcf, 0xc7, 0x9f, 0x1e, 0xec, 0x43, 0x22, 0x41, 0x7b, 0x55, 0x95,
		0xa1, 0x50, 0x1d, 0x3a, 0x15, 0xa2, 0x52, 0x25, 0x72, 0x95, 0x22, 0x57, 0x2d, 0x52, 0x15, 0x53,
		0x53, 0x35, 0x45, 0x95, 0x53, 0x0f, 0x2e, 0x2f, 0x95, 0x17, 0xf9, 0x63, 0xe8, 0x4b, 0x2d, 0xcd,
		0xb1, 0x5e, 0xc3, 0x80, 0xd9, 0x63, 0xea, 0xd3, 0x6a, 0x6d, 0xa8, 0x4c, 0xbf, 0xca, 0x66, 0xa1,
		0xdc, 0xd1, 0xf6, 0x15, 0x21, 0xff, 0xf8, 0x47, 0xdd, 0x89, 0x2c, 0xbd, 0xb4, 0x57, 0x04, 0xf8,
		0x02, 0x7c, 0x11, 0xc1, 0x97, 0x2a, 0x73, 0x20, 0x65, 0x10, 0x0c, 0x4c, 0x82, 0x88, 0x51, 0x90,
		0x31, 0x0b, 0x4a, 0x15, 0xa5, 0x57, 0x55, 0x6a, 0x95, 0x65, 0x53, 0x5d, 0x36, 0x15, 0x66, 0x51,
		0x65, 0x3d, 0x95, 0xd6, 0x54, 0x6d, 0x3a, 0x86, 0xc2, 0xa8, 0x9e, 0x39, 0xa2, 0x36, 0x47, 0xd3,
		0xec, 0x85, 0xa4, 0xdd, 0x51, 0x38, 0xe0, 0x9f, 0x6b, 0xda, 0x1e, 0x7d, 0x3f, 0x7c, 0xff, 0x87,
		0xbe, 0x84, 0xd4, 0x29, 0x5e, 0x9d, 0xb2, 0x4b, 0xad, 0xe9, 0xf7, 0x4f, 0xa8, 0xaf, 0x98, 0x86,
		0x6e, 0xe5, 0x5d, 0xf1, 0x2d, 0xb0, 0xbe, 0x74, 0xba, 0xd6, 0x8b, 0xd7, 0xe9, 0x75, 0xe9, 0x8c,
		0xdf, 0xdc, 0xb8, 0xb0, 0x7f, 0xb0, 0x7f, 0xb0, 0x7f, 0xa9, 0xb2, 0x7f, 0xfa, 0x9e, 0x3a, 0xa5,
		0xc7, 0xbe, 0xc8, 0x73, 0x0f, 0xff, 0x9b, 0x05, 0x13, 0x7f, 0xee, 0xe7, 0x91, 0x87, 0xef, 0xb4,
		0xf2, 0x19, 0xc4, 0xdf, 0x4e, 0x33, 0x10, 0x81, 0x6f, 0x3d, 0x77, 0xbc, 0xbf, 0x6d, 0xaf, 0xa5,
		0x50, 0x23, 0x6c, 0x05, 0x9e, 0xcc, 0x8d, 0x0c, 0x0c, 0x06, 0x06, 0x03, 0x83, 0x53, 0x85, 0xc1,
		0xcd, 0x4e, 0xcf, 0x0d, 0x84, 0x77, 0x54, 0x26, 0x44, 0x61, 0x0a, 0x07, 0x84, 0xa6, 0xeb, 0xf4,
		0xf8, 0x8b, 0x46, 0x05, 0x72, 0xd4, 0x5d, 0xa8, 0x89, 0x91, 0x2d, 0x32, 0x2c, 0x71, 0x57, 0xea,
		0x70, 0x5c, 0x86, 0x8e, 0xc8, 0x44, 0x1a, 0x32, 0xbb, 0x54, 0x84, 0xdd, 0xaa, 0x4d, 0x2d, 0x95,
		0x5a, 0x01, 0xa4, 0xd4, 0xac, 0xde, 0x4e, 0x3a, 0x46, 0xc9, 0xa2, 0x1f, 0xdc, 0xb5, 0x9b, 0x7f,
		0x31, 0x11, 0xb1, 0xe8, 0xd0, 0x60, 0x62, 0x60, 0x62, 0x60, 0x62, 0x60, 0x62, 0x60, 0x62, 0x60,
		0x62, 0x60, 0x62, 0x60, 0x62, 0x9b, 0xc7, 0xc4, 0x8c, 0x6e, 0xff, 0x2b, 0x56, 0x97, 0x8d, 0x8c,
		0xb3, 0xfc, 0x14, 0xd1, 0xfc, 0x29, 0x91, 0xfd, 0xc8, 0x61, 0x9e, 0xc8, 0x6f, 0xf6, 0xed, 0xe7,
		0xc0, 0xdf, 0x1f, 0x27, 0x89, 0xef, 0x87, 0x79, 0xb7, 0x32, 0xb5, 0x68, 0xf5, 0xa7, 0x95, 0x37,
		0x63, 0x73, 0x54, 0xcb, 0x56, 0x7d, 0x27, 0x55, 0xae, 0xbe, 0xed, 0x22, 0x1b, 0x24, 0x57, 0xef,
		0x76, 0x11, 0x34, 0x6a, 0xd7, 0xbf, 0x8d, 0x0c, 0x2a, 0x55, 0x0f, 0x57, 0x77, 0x0d, 0x34, 0x85,
		0xdf, 0x8c, 0xd0, 0xe7, 0x95, 0x52, 0xe1, 0xa6, 0x0f, 0xe5, 0x5d, 0x0f, 0xef, 0x54, 0x1b, 0xdd,
		0xa8, 0x51, 0x79, 0x0e, 0xfc, 0xc6, 0x95, 0xdd, 0xac, 0x0e, 0x86, 0xdf, 0xd2, 0x22, 0xd8, 0xda,
		0x2b, 0x64, 0xb2, 0x6b, 0x8f, 0xd3, 0xfd, 0x5a, 0xb6, 0x7a, 0xae, 0xd3, 0xb4, 0x7d, 0x85, 0xd3,
		0x36, 0x33, 0x57, 0xe3, 0xc4, 0x8d, 0x41, 0x7f, 0x75, 0xab, 0x4f, 0xdc, 0x0c, 0xc4, 0x4e, 0xf3,
		0xc8, 0xcd, 0xd4, 0x18, 0x38, 0x73, 0xc3, 0x17, 0xa8, 0xc1, 0x99, 0x1b, 0x93, 0x67, 0x6e, 0xba,
		0x7a, 0x31, 0xbf, 0xa9, 0x02, 0x49, 0x3a, 0x2b, 0x85, 0x93, 0x36, 0x0c, 0x91, 0x4e, 0xa4, 0xaa,
		0x33, 0xfa, 0xaa, 0x9b, 0x7f, 0xd2, 0x66, 0x24, 0x32, 0x38, 0x64, 0xc3, 0x60, 0xda, 0xa3, 0xc8,
		0x85, 0x43, 0x36, 0x40, 0x2e, 0x33, 0xc8, 0xa5, 0x7d, 0xc8, 0xa6, 0x25, 0x9a, 0x76, 0xd7, 0xef,
		0xb5, 0xed, 0x40, 0x58, 0x5f, 0x84, 0xdd, 0x12, 0x1e, 0xdd, 0x1e, 0xeb, 0x82, 0xb1, 0xb1, 0xc9,
		0xca, 0xaf, 0xb8, 0xd4, 0x0a, 0xcc, 0xa6, 0xc8, 0x6c, 0x0a, 0xcd, 0xa2, 0xd8, 0x7a, 0x0a, 0xae,
		0xa9, 0xe8, 0x74, 0x54, 0x25, 0x22, 0x6f, 0xc2, 0x1d, 0x6b, 0xa9, 0xd3, 0x71, 0x47, 0x7a, 0x6a,
		0x05, 0xfd, 0xdb, 0x10, 0x26, 0x21, 0x97, 0x09, 0xc6, 0x8a, 0x57, 0x7c, 0x8d, 0x6f, 0xf9, 0x70,
		0xa2, 0x03, 0xf0, 0x0a, 0x78, 0x05, 0xbc, 0x9a, 0xf6, 0x08, 0x29, 0x3d, 0xc3, 0x45, 0x1e, 0x22,
		0x4e, 0x74, 0xe8, 0xe1, 0x09, 0x4e, 0x74, 0x00, 0x83, 0x81, 0xc1, 0x69, 0xc6, 0x60, 0xe4, 0x11,
		0x4a, 0x3e, 0x18, 0xf2, 0x08, 0x91, 0x47, 0x88, 0x3c, 0x42, 0x16, 0x74, 0xa4, 0x1b, 0x25, 0x8b,
		0x27, 0x3a, 0x3a, 0x9e, 0xf3, 0xe2, 0xb8, 0x56, 0xd7, 0xeb, 0x04, 0x9d, 0x66, 0xa7, 0x4d, 0x48,
		0xc3, 0xe6, 0x06, 0x06, 0x0b, 0x03, 0x0b, 0x03, 0x0b, 0x4b, 0x15, 0x0b, 0x73, 0x5a, 0xc2, 0x0d,
		0x9c, 0xe0, 0x8d, 0xd8, 0x1b, 0x26, 0xb0, 0x1c, 0xf9, 0xda, 0xe8, 0xd1, 0x3e, 0xd9, 0x3e, 0xa1,
		0x18, 0x8f, 0x5f, 0xbc, 0x76, 0x7d, 0xff, 0x50, 0xb9, 0xbc, 0x6c, 0xdc, 0xde, 0xdd, 0x3c, 0xdc,
		0x9c, 0xdf, 0x5c, 0x36, 0x1e, 0xfe, 0xb8, 0xad, 0x52, 0x89, 0xf4, 0xc0, 0xa6, 0xfa, 0x64, 0x24,
		0x92, 0x96, 0x48, 0xce, 0x4c, 0xc3, 0x6d, 0xed, 0x2a, 0x9f, 0x46, 0x0a, 0xc5, 0xf4, 0xba, 0xb5,
		0x9f, 0xaf, 0x6e, 0xb7, 0xe9, 0x7d, 0x2f, 0x6a, 0x77, 0xd5, 0xf3, 0x87, 0xcb, 0x3f, 0x1a, 0xe7,
		0x37, 0xd7, 0xd7, 0xd5, 0xf3, 0x87, 0xea, 0xc5, 0x36, 0xbd, 0xfd, 0xcd, 0xfd, 0xed, 0x4f, 0x07,
		0xdb, 0xf4, 0xc2, 0xf7, 0x0f, 0x95, 0x87, 0xda, 0xf9, 0x56, 0x29, 0xf4, 0x7d, 0xed, 0x7e, 0x9b,
		0xde, 0xf7, 0xd3, 0xcf, 0xb7, 0xdb, 0xa6, 0xc1, 0xdb, 0xf4, 0xbe, 0x97, 0x37, 0xe7, 0x95, 0xcb,
		0x46, 0xe5, 0xe7, 0x9f, 0xef, 0xaa, 0x3f, 0x57, 0x1e, 0xaa, 0xf9, 0x94, 0xf9, 0xc7, 0xf5, 0xa4,
		0xf9, 0x33, 0x2a, 0x1e, 0xc0, 0x47, 0x86, 0x8f, 0x0c, 0x1f, 0xd9, 0xa8, 0x8f, 0x8c, 0x9d, 0x0a,
		0xc9, 0x07, 0xc3, 0x4e, 0x05, 0x76, 0x2a, 0xb0, 0x53, 0xc1, 0xca, 0xc4, 0xb6, 0xb4, 0xf6, 0x14,
		0x0d, 0x9b, 0xa0, 0x39, 0x53, 0x05, 0xce, 0x05, 0xce, 0x05, 0xce, 0xc5, 0xc4, 0xb9, 0x06, 0x47,
		0x81, 0xc9, 0xd6, 0x33, 0xe5, 0x3d, 0x07, 0x76, 0x77, 0x1f, 0x0b, 0xd6, 0x69, 0xfd, 0xc7, 0x63,
		0xd1, 0x3a, 0xad, 0x0f, 0xbf, 0x2d, 0x0e, 0xfe, 0x19, 0x7e, 0x5f, 0x7a, 0x2c, 0x58, 0xe5, 0xf1,
		0xf7, 0x87, 0x8f, 0x05, 0xeb, 0xb0, 0xbe, 0xf7, 0xf9, 0xf3, 0xc7, 0xbd, 0xef, 0x07, 0xef, 0xf2,
		0x17, 0xee, 0x8f, 0x6e, 0xb6, 0xf7, 0x63, 0xf7, 0xb1, 0x68, 0x95, 0xea, 0xe3, 0x1f, 0x0e, 0x1e,
		0x0b, 0x56, 0xa9, 0xbe, 0xb7, 0xb7, 0xd9, 0xdd, 0x0d, 0x36, 0x6d, 0xa6, 0x51, 0xb5, 0x48, 0x62,
		0x1c, 0x86, 0xf2, 0x20, 0xd3, 0xc5, 0x36, 0xf6, 0x27, 0xe5, 0x0b, 0x36, 0xb0, 0x74, 0x91, 0x5a,
		0x45, 0x0c, 0x54, 0x2d, 0xd2, 0x9d, 0xfe, 0x14, 0x56, 0x2d, 0x5a, 0x22, 0xf4, 0x4c, 0xa5, 0x8b,
		0x6a, 0xdd, 0xaf, 0x65, 0xd4, 0x2e, 0xd2, 0x5d, 0x27, 0xc3, 0xf5, 0x8b, 0x8e, 0xb4, 0xea, 0x17,
		0x1d, 0xa1, 0x7e, 0x11, 0xea, 0x17, 0xe9, 0xa9, 0xa1, 0x4a, 0xfd, 0xa2, 0x23, 0x82, 0xfa, 0x45,
		0x47, 0xa8, 0x5f, 0xc4, 0x1e, 0x02, 0x40, 0xfd, 0x22, 0xd4, 0x2f, 0x32, 0x1c, 0x5b, 0x43, 0x15,
		0x90, 0x64, 0x62, 0x66, 0xa8, 0x5f, 0x84, 0xfa, 0x45, 0xea, 0xeb, 0x80, 0xfa, 0x45, 0x40, 0x2e,
		0x20, 0x97, 0xf4, 0x93, 0xa3, 0x7e, 0x51, 0x12, 0x14, 0x83, 0x52, 0x61, 0xe9, 0x15, 0x97, 0x5a,
		0x81, 0xd9, 0x14, 0x99, 0x4d, 0xa1, 0x59, 0x14, 0x5b, 0x4f, 0xc1, 0x35, 0x15, 0x9d, 0x8e, 0xaa,
		0x44, 0xe4, 0x0d, 0xf5, 0x8b, 0xf8, 0x97, 0x0e, 0xf5, 0x8b, 0x00, 0xaf, 0x80, 0xd7, 0xad, 0x84,
		0x57, 0xd4, 0x2f, 0x4a, 0x03, 0xfe, 0xa2, 0x7e, 0x11, 0x30, 0x18, 0x18, 0xbc, 0xad, 0x18, 0x8c,
		0x53, 0x01, 0x92, 0x0f, 0x86, 0x53, 0x01, 0x38, 0x15, 0x80, 0x53, 0x01, 0x2c, 0xe8, 0x48, 0x37,
		0x0a, 0xea, 0x17, 0xa1, 0x7e, 0x11, 0x58, 0x18, 0x58, 0x58, 0x56, 0x58, 0x18, 0xea, 0x17, 0xa1,
		0x7e, 0x11, 0xea, 0x17, 0x6d, 0xec, 0xfb, 0xa2, 0x7e, 0x11, 0xea, 0x17, 0x6d, 0xb6, 0x42, 0xa3,
		0x7e, 0xd1, 0xa6, 0x6b, 0x30, 0xea, 0x17, 0xa5, 0xc6, 0x3f, 0x46, 0xfd, 0x22, 0xd4, 0x2f, 0x82,
		0x8f, 0x0c, 0x1f, 0x79, 0xbb, 0x7c, 0x64, 0xec, 0x54, 0x48, 0x3e, 0x18, 0x76, 0x2a, 0xb0, 0x53,
		0x81, 0x9d, 0x0a, 0x56, 0x26, 0x86, 0xfa, 0x45, 0x24, 0xf4, 0x0b, 0xf5, 0x8b, 0xc0, 0xb9, 0xc0,
		0xb9, 0xd2, 0x59, 0xbf, 0xe8, 0x68, 0xcb, 0xea, 0x17, 0xd9, 0xd6, 0x73, 0xc5, 0xfa, 0xa9, 0xfe,
		0xbd, 0xf8, 0xa1, 0xfc, 0x7e, 0xb6, 0xf7, 0xfd, 0xf8, 0x7d, 0xfe, 0x97, 0x3f, 0x16, 0x7d, 0xac,
		0xf8, 0xe1, 0xf8, 0xfd, 0x6c, 0xc9, 0x5f, 0x8e, 0xde, 0xcf, 0x62, 0x8e, 0x71, 0xf8, 0xbe, 0x1b,
		0xf9, 0x68, 0xff, 0xf7, 0xa5, 0x65, 0x17, 0x94, 0x97, 0x5c, 0x70, 0xb0, 0xec, 0x82, 0x83, 0x25,
		0x17, 0x2c, 0x7d, 0xa4, 0xd2, 0x92, 0x0b, 0x0e, 0xdf, 0x7f, 0x44, 0x3e, 0xbf, 0xbb, 0xf8, 0xa3,
		0x47, 0xef, 0x7b, 0x3f, 0x96, 0xfd, 0xed, 0xf8, 0xfd, 0xc7, 0xd9, 0xde, 0xde, 0xfe, 0x6e, 0xb1,
		0xf4, 0x58, 0xb0, 0x4e, 0x86, 0xd5, 0x88, 0x8a, 0xf5, 0x48, 0x91, 0xa2, 0x61, 0xd1, 0xa1, 0x6d,
		0x28, 0xea, 0x04, 0xf1, 0xdb, 0x68, 0xf1, 0x43, 0xa5, 0x2b, 0x89, 0x71, 0x78, 0x8a, 0xc9, 0x1c,
		0x4d, 0x17, 0xfd, 0x39, 0x42, 0xa5, 0xab, 0x99, 0x8b, 0x51, 0xe9, 0x4a, 0x77, 0xfa, 0xd3, 0x59,
		0xe9, 0x6a, 0x91, 0xd0, 0xf3, 0x55, 0xba, 0x3a, 0x42, 0xa5, 0x2b, 0xdd, 0x75, 0x32, 0x59, 0xe9,
		0xea, 0xb5, 0xdb, 0xf6, 0xe5, 0x2b, 0x5c, 0x0d, 0xae, 0x42, 0x65, 0x2b, 0x83, 0x3e, 0xf2, 0x56,
		0x57, 0xb6, 0x6a, 0xdb, 0x4f, 0xa2, 0xad, 0x5b, 0xda, 0x6a, 0x7a, 0x10, 0xd4, 0xb6, 0xe2, 0x0b,
		0x0f, 0xa1, 0xb6, 0x95, 0xc9, 0xda, 0x56, 0x03, 0xa9, 0xd6, 0xaf, 0x0f, 0x33, 0x1c, 0x06, 0x95,
		0xad, 0x50, 0x1f, 0x26, 0xa1, 0x28, 0x2a, 0x2a, 0x5b, 0xd1, 0x56, 0xb6, 0x1a, 0x2a, 0x34, 0x0a,
		0x5b, 0x31, 0xd8, 0xf5, 0x28, 0x70, 0xa1, 0xb0, 0x15, 0x80, 0xcb, 0x0c, 0x70, 0x69, 0x17, 0xb6,
		0xd2, 0xe3, 0x0b, 0xa4, 0xbc, 0x81, 0x88, 0x3f, 0x90, 0xf1, 0x08, 0x4a, 0xb5, 0xa4, 0x57, 0x4f,
		0x6a, 0x35, 0x65, 0x53, 0x57, 0x36, 0xb5, 0x65, 0x51, 0x5f, 0x3d, 0x35, 0xd6, 0x54, 0x67, 0x3a,
		0x3e, 0xb2, 0x30, 0x42, 0x63, 0x51, 0x68, 0xe7, 0x8c, 0xa1, 0x3c, 0x25, 0x18, 0x6b, 0xf4, 0xae,
		0xa9, 0x4b, 0x99, 0x1b, 0xcf, 0x5c, 0xcf, 0x71, 0x83, 0x83, 0x52, 0x9e, 0x30, 0xc3, 0x6b, 0x34,
		0x7b, 0xc7, 0x84, 0x43, 0xd2, 0x26, 0x1e, 0xd2, 0xcf, 0x66, 0xf8, 0xa0, 0x1c, 0x89, 0x88, 0xc4,
		0x86, 0x63, 0xe9, 0xf0, 0x61, 0xb6, 0xdb, 0x11, 0xd3, 0x0d, 0x18, 0x73, 0xdc, 0x88, 0x90, 0x69,
		0xf1, 0x9a, 0x32, 0x64, 0x2c, 0x1a, 0x5f, 0xd3, 0x42, 0xf9, 0xe4, 0xf0, 0xf8, 0x30, 0xc3, 0x0b,
		0xbb, 0x93, 0xce, 0xd1, 0xea, 0x3b, 0x29, 0x12, 0x5b, 0x06, 0xf3, 0x20, 0xdc, 0xde, 0xab, 0xf0,
		0x86, 0x9b, 0x46, 0xf4, 0x36, 0x82, 0xa2, 0x22, 0x64, 0x38, 0x26, 0x4d, 0x65, 0x48, 0x3a, 0x11,
		0xa9, 0xa3, 0x42, 0x25, 0x2a, 0x54, 0xc2, 0x83, 0x82, 0x07, 0x95, 0x09, 0x0f, 0x0a, 0x15, 0x2a,
		0xd3, 0x80, 0xbf, 0xa8, 0x50, 0x09, 0x0c, 0x06, 0x06, 0x6f, 0x2b, 0x06, 0xe3, 0xdc, 0x67, 0x0a,
		0xc2, 0x2d, 0x38, 0xf7, 0xc9, 0x11, 0x4d, 0xc1, 0xb9, 0x4f, 0xf3, 0xab, 0x07, 0x3f, 0x58, 0x79,
		0x59, 0x50, 0x81, 0x03, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c,
		0x4c, 0x0c, 0x4c, 0x2c, 0x31, 0x26, 0xd6, 0xe9, 0x76, 0x45, 0xcb, 0x9a, 0x24, 0x78, 0x58, 0x7e,
		0x60, 0x37, 0xff, 0x22, 0xe4, 0x63, 0x4b, 0x6e, 0x00, 0x56, 0x06, 0x56, 0x06, 0x56, 0x96, 0x2a,
		0x56, 0x86, 0x2c, 0x2f, 0xd5, 0x99, 0x43, 0x96, 0x17, 0x25, 0x55, 0x40, 0x96, 0x57, 0x32, 0x3c,
		0x8a, 0x81, 0x0d, 0xb3, 0xb2, 0x62, 0xe3, 0x6b, 0x8a, 0x2c, 0x2f, 0x9e, 0xd1, 0x90, 0xe5, 0xa5,
		0x65, 0x61, 0x91, 0xe5, 0xc5, 0xc5, 0xb1, 0xb4, 0x8a, 0x98, 0x2c, 0xb2, 0x6b, 0x7a, 0x45, 0x4d,
		0x16, 0xa1, 0x2a, 0x79, 0x91, 0x93, 0xc8, 0x4d, 0xb4, 0x8a, 0x9e, 0x10, 0x7a, 0xb9, 0xa8, 0x3c,
		0x34, 0x2c, 0xee, 0xd1, 0xa7, 0xe9, 0xfb, 0x53, 0xf5, 0x07, 0x36, 0xb0, 0xe4, 0x90, 0x8a, 0x13,
		0x82, 0x8a, 0x43, 0xda, 0xb3, 0x9f, 0xc2, 0x8a, 0x43, 0xf3, 0xc2, 0xce, 0x54, 0x6a, 0xe8, 0xb2,
		0x7f, 0x07, 0xd4, 0x1a, 0x52, 0x5d, 0x21, 0x93, 0x35, 0x86, 0xe6, 0xd2, 0x13, 0xe5, 0xcb, 0x0d,
		0xcd, 0x0f, 0x80, 0xca, 0x43, 0x06, 0x23, 0x7f, 0x5b, 0x5d, 0x79, 0x48, 0x33, 0xfd, 0x9f, 0x26,
		0xdd, 0x1f, 0xf5, 0x87, 0x8c, 0x0a, 0x3c, 0x99, 0xe0, 0x93, 0x28, 0x80, 0x19, 0x16, 0xa7, 0x5c,
		0x7f, 0xa8, 0xd9, 0x71, 0x5b, 0x4e, 0xdf, 0xaa, 0xd9, 0x04, 0x55, 0x88, 0xa6, 0x07, 0x4b, 0xb8,
		0xa4, 0x07, 0x6a, 0x11, 0x71, 0xa8, 0x14, 0xb9, 0x6a, 0x91, 0xaa, 0x58, 0x32, 0x7e, 0xab, 0x76,
		0x49, 0x8f, 0x50, 0x6b, 0xe8, 0xb6, 0x80, 0x27, 0x43, 0xd2, 0x6c, 0xfa, 0x16, 0xb1, 0xe9, 0x6b,
		0x50, 0x5d, 0xd9, 0xd4, 0x96, 0x4d, 0x7d, 0x59, 0xd4, 0x98, 0x26, 0xa4, 0xa9, 0x1b, 0x90, 0xd4,
		0x55, 0xef, 0x70, 0x20, 0xa7, 0x45, 0xdf, 0x82, 0xd9, 0x69, 0x51, 0x49, 0x04, 0xed, 0x86, 0x0e,
		0x99, 0xc2, 0x73, 0x28, 0x3e, 0x1f, 0x00, 0x70, 0x01, 0x01, 0x3b, 0x20, 0xb0, 0x03, 0x03, 0x2b,
		0x40, 0xd0, 0x00, 0x05, 0x11, 0x60, 0x84, 0x6f, 0x4a, 0x96, 0x2d, 0x12, 0x91, 0x57, 0xba, 0x93,
		0xad, 0x11, 0x3b, 0x4f, 0x99, 0xfd, 0x10, 0xa9, 0x69, 0xa8, 0x7b, 0x82, 0x95, 0x6e, 0x9d, 0x09,
		0xd6, 0x38, 0xef, 0xb8, 0xdd, 0x5e, 0x60, 0x39, 0x6e, 0x20, 0xbc, 0x67, 0xbb, 0x29, 0x7c, 0x06,
		0x74, 0x9f, 0xbf, 0x03, 0x2d, 0xd6, 0x17, 0x81, 0xf5, 0xc0, 0x7a, 0x60, 0x3d, 0xc5, 0x9b, 0x52,
		0x91, 0xc4, 0x65, 0xe0, 0x42, 0x2f, 0x5d, 0x4b, 0x30, 0x86, 0x5a, 0xc6, 0x68, 0xa1, 0x86, 0x0d,
		0x72, 0x38, 0xa1, 0x87, 0x1f, 0x82, 0xb8, 0xa1, 0xc8, 0x18, 0x24, 0x19, 0x83, 0x26, 0x23, 0x10,
		0x45, 0x0b, 0x55, 0xc4, 0x90, 0xc5, 0x06, 0x5d, 0x1c, 0xfe, 0x2e, 0xbf, 0xff, 0xcb, 0xec, 0x0f,
		0x1b, 0x03, 0x30, 0x13, 0x40, 0x66, 0x0e, 0xd0, 0x4c, 0x01, 0x9b, 0x71, 0x80, 0x33, 0x0e, 0x74,
		0x46, 0x01, 0x8f, 0x07, 0xf8, 0x98, 0x00, 0x90, 0xcf, 0x5f, 0x37, 0xe8, 0xbf, 0x9b, 0xf0, 0xe7,
		0xcd, 0xf9, 0xf7, 0xfc, 0x72, 0xc4, 0x91, 0x6f, 0xaf, 0xd7, 0x10, 0x21, 0xb6, 0xf0, 0xe8, 0x34,
		0x4c, 0x48, 0x88, 0xae, 0x47, 0xad, 0x5e, 0x09, 0x56, 0x0f, 0x56, 0x0f, 0x56, 0x2f, 0x05, 0x56,
		0x8f, 0x8b, 0xfe, 0x9b, 0x70, 0x03, 0xcc, 0xb9, 0x03, 0x86, 0xdc, 0x02, 0x63, 0xee, 0x81, 0x49,
		0xc0, 0x34, 0x0f, 0x9c, 0xa6, 0x01, 0x34, 0x31, 0x20, 0x4d, 0x0c, 0x50, 0x13, 0x01, 0x56, 0x5e,
		0x80, 0x65, 0x06, 0x5a, 0x73, 0x6e, 0xc6, 0x02, 0xc6, 0xe8, 0x39, 0xee, 0x8b, 0x09, 0x7d, 0x1b,
		0xd3, 0xc7, 0x93, 0x9d, 0x6c, 0xae, 0x3f, 0xe3, 0xda, 0xe7, 0xf9, 0x62, 0xf9, 0xcb, 0xcd, 0x21,
		0x53, 0x54, 0x1f, 0x56, 0x91, 0xc7, 0x2a, 0x3a, 0xcf, 0x30, 0x8a, 0x1b, 0x68, 0x14, 0x9d, 0x67,
		0xd8, 0xc4, 0xb4, 0xd9, 0x44, 0xfe, 0x10, 0x5c, 0xc4, 0x28, 0x1e, 0x1b, 0xb8, 0xd7, 0x6d, 0x78,
		0xcc, 0xac, 0x2f, 0x76, 0x67, 0x93, 0xd4, 0x91, 0xf9, 0x5f, 0x8c, 0x7e, 0x1e, 0x9c, 0xd0, 0x83,
		0xb1, 0x8e, 0xcc, 0xa3, 0xdf, 0x7b, 0x4a, 0xc0, 0x5e, 0xcf, 0xdc, 0x15, 0x26, 0x1b, 0x26, 0x1b,
		0x26, 0x1b, 0x26, 0x1b, 0x26, 0x1b, 0x26, 0x7b, 0xf0, 0x8b, 0xc7, 0x89, 0xc9, 0xfe, 0xdf, 0x66,
		0xcf, 0xf3, 0x84, 0x1b, 0xec, 0xee, 0xed, 0x7f, 0xfc, 0xb8, 0x1f, 0x7e, 0xa2, 0x3e, 0xba, 0x64,
		0xda, 0x8e, 0xf8, 0x0b, 0x7e, 0x17, 0x8e, 0xdc, 0x12, 0xdf, 0x32, 0x6b, 0xfd, 0x33, 0x15, 0x65,
		0x27, 0xaa, 0x6d, 0xb2, 0x9e, 0xb7, 0xd0, 0x17, 0x1b, 0x58, 0xd3, 0x9b, 0x68, 0xea, 0xc8, 0xe7,
		0xe4, 0xfb, 0xfd, 0xf9, 0xcc, 0xe5, 0xf9, 0x5f, 0xe8, 0x14, 0x50, 0x31, 0x2f, 0x19, 0xe9, 0x4e,
		0xe0, 0x1a, 0x15, 0x70, 0x21, 0xdf, 0xfb, 0xa0, 0x2d, 0xc5, 0x14, 0x19, 0x9d, 0xbc, 0x34, 0x53,
		0xf4, 0x0e, 0x06, 0x4a, 0x35, 0x45, 0x6e, 0x4a, 0x5a, 0xba, 0x89, 0x5b, 0x74, 0x98, 0x61, 0x29,
		0x33, 0x70, 0x94, 0x67, 0x49, 0x07, 0x59, 0x5b, 0x02, 0xe7, 0x5a, 0x7c, 0x0b, 0x7e, 0xe9, 0x74,
		0x7f, 0xee, 0x3f, 0x79, 0xe3, 0x7c, 0xfc, 0xb4, 0x8d, 0x5a, 0xff, 0xe1, 0x6a, 0xe1, 0xb3, 0xa5,
		0xb4, 0x82, 0x60, 0xba, 0x12, 0xf0, 0x99, 0x24, 0x39, 0xb5, 0x12, 0xbc, 0x49, 0x07, 0xa9, 0x68,
		0x13, 0xa7, 0x58, 0x12, 0xa5, 0xd8, 0x8e, 0x4c, 0x95, 0x70, 0x64, 0x2a, 0x43, 0x71, 0x0b, 0x1c,
		0x99, 0x4a, 0xf1, 0x91, 0xa9, 0x96, 0xdf, 0xec, 0xf2, 0x9d, 0x93, 0x1a, 0x8c, 0xfe, 0x21, 0x13,
		0x2d, 0x46, 0x70, 0x38, 0x2a, 0x89, 0x20, 0x2a, 0x0e, 0x47, 0x6d, 0xa0, 0x6f, 0xcd, 0x16, 0xe5,
		0xe4, 0xc4, 0x95, 0x69, 0x6c, 0xe1, 0x70, 0x71, 0x79, 0xba, 0x1a, 0x8c, 0xbf, 0x18, 0xa3, 0x63,
		0x9c, 0x5d, 0x0e, 0x98, 0x41, 0x3d, 0x72, 0x1b, 0xa6, 0x96, 0x5f, 0x91, 0xfb, 0x18, 0xa8, 0x91,
		0xcf, 0xa4, 0xbc, 0xf3, 0xb1, 0xa0, 0x8d, 0x5b, 0xfa, 0xa3, 0x83, 0x0d, 0x5a, 0xfb, 0x8c, 0x84,
		0x82, 0xeb, 0xa9, 0x36, 0x57, 0x88, 0xd8, 0x2a, 0xdc, 0x94, 0x37, 0x62, 0x9b, 0xca, 0x86, 0x89,
		0x0c, 0x67, 0x32, 0xf8, 0xce, 0x60, 0xc0, 0x4d, 0x82, 0x9b, 0x04, 0x37, 0x69, 0xcb, 0xdd, 0xa4,
		0x9e, 0xe3, 0x06, 0x24, 0xbd, 0x8b, 0x97, 0xa1, 0xcb, 0x09, 0x1c, 0x25, 0x38, 0x4a, 0x70, 0x94,
		0x36, 0xd2, 0x51, 0x32, 0x43, 0x24, 0xe1, 0x3a, 0x19, 0x75, 0x9d, 0x52, 0x49, 0xac, 0x35, 0xdb,
		0x4d, 0xc4, 0x36, 0x87, 0x5a, 0xed, 0x28, 0x40, 0xb8, 0x41, 0xb8, 0x41, 0xb8, 0x41, 0xb8, 0x57,
		0xca, 0x3b, 0x5f, 0xb6, 0x35, 0x67, 0x76, 0xf5, 0x74, 0x4d, 0xa2, 0xe9, 0xff, 0xe6, 0x72, 0x6c,
		0x78, 0xca, 0x15, 0x21, 0xb7, 0x4a, 0x6e, 0xdc, 0xb4, 0xe4, 0x56, 0x11, 0xe6, 0x22, 0xbf, 0x67,
		0xbc, 0xd9, 0x01, 0x55, 0x2e, 0x31, 0xda, 0xb8, 0xd2, 0xb7, 0x71, 0xd5, 0x6d, 0xb0, 0x43, 0xab,
		0xc5, 0x69, 0xd1, 0xde, 0x3c, 0x49, 0x02, 0xa2, 0x62, 0xaa, 0x6e, 0x1e, 0x8d, 0x79, 0xb3, 0x22,
		0x31, 0xc6, 0x9a, 0xf5, 0x2a, 0x34, 0xcc, 0xd3, 0xd8, 0x8e, 0xd1, 0xdf, 0x76, 0xd1, 0xf4, 0xf6,
		0xd0, 0x71, 0xcd, 0x8c, 0xd7, 0x85, 0x8e, 0x6b, 0x84, 0xde, 0x0f, 0xa1, 0x97, 0x43, 0xe1, 0xcd,
		0xd0, 0x55, 0x52, 0x35, 0x83, 0x57, 0x63, 0x94, 0xf5, 0xf5, 0x61, 0x6b, 0x32, 0x14, 0xfa, 0x45,
		0x02, 0xbd, 0xb6, 0x02, 0xbd, 0xb4, 0xfb, 0x45, 0x8e, 0x75, 0x86, 0xae, 0x5d, 0x64, 0x38, 0x22,
		0xba, 0x45, 0xf2, 0x2b, 0x29, 0xb5, 0xb2, 0xb2, 0x07, 0x7a, 0xd1, 0x2d, 0xd2, 0x9c, 0x72, 0x4f,
		0x7c, 0x82, 0x41, 0x71, 0x06, 0x86, 0x96, 0x62, 0xfd, 0x61, 0xd1, 0x33, 0x32, 0x3d, 0x30, 0xc0,
		0x05, 0x07, 0xec, 0xb0, 0xc0, 0x0e, 0x0f, 0xac, 0x30, 0x41, 0x03, 0x17, 0x44, 0xb0, 0x41, 0xe7,
		0xd9, 0x30, 0x7a, 0x3a, 0x1c, 0x9e, 0x4f, 0x0c, 0x4f, 0x88, 0xae, 0x48, 0x0d, 0x4e, 0x3b, 0x9b,
		0xe5, 0x71, 0x51, 0x60, 0xc7, 0x69, 0x67, 0x00, 0xfb, 0x76, 0x02, 0x3b, 0x43, 0x83, 0x48, 0x4a,
		0x7e, 0xc8, 0xca, 0x13, 0x99, 0xf8, 0x22, 0x1b, 0x6f, 0xe4, 0x84, 0x19, 0x7e, 0xb8, 0xe1, 0x86,
		0x1d, 0x63, 0xf0, 0x63, 0x0c, 0x86, 0x8c, 0xc0, 0x11, 0x2d, 0x2c, 0x11, 0xc3, 0x13, 0x1f, 0xff,
		0x34, 0xc0, 0x43, 0x39, 0xf9, 0xe8, 0x22, 0x5e, 0xba, 0x24, 0xb5, 0x68, 0xb2, 0xf9, 0x48, 0xcf,
		0x5c, 0xe9, 0x85, 0x87, 0x32, 0xe9, 0xf5, 0x6f, 0xe1, 0xbc, 0x7c, 0x09, 0xf8, 0x6c, 0xd1, 0x68,
		0x7c, 0x18, 0x23, 0x18, 0x23, 0x18, 0x23, 0x18, 0x23, 0x42, 0x79, 0xc7, 0xa9, 0xb2, 0xc8, 0x17,
		0x4e, 0x95, 0xc5, 0xba, 0x0d, 0x4e, 0x95, 0xc9, 0x2d, 0x3d, 0x4e, 0x95, 0x65, 0x4d, 0x1a, 0x70,
		0xaa, 0x6c, 0x83, 0xc2, 0x4f, 0x9b, 0x93, 0xc2, 0xbf, 0xcc, 0xdd, 0x42, 0xfe, 0xfe, 0x74, 0xfe,
		0x3e, 0x41, 0xf4, 0x0e, 0x29, 0xfc, 0x48, 0xe1, 0x37, 0xa0, 0xbd, 0x49, 0xe4, 0xef, 0x8f, 0x7e,
		0x40, 0xf6, 0x7e, 0x46, 0x84, 0x25, 0xcd, 0xb9, 0xb0, 0x7a, 0xdb, 0xb9, 0x24, 0xdb, 0xb7, 0x64,
		0x39, 0xb0, 0x25, 0xe4, 0xc0, 0x32, 0x86, 0x94, 0x90, 0x03, 0x3b, 0x79, 0x72, 0xed, 0x1c, 0xd8,
		0x27, 0xbb, 0xf9, 0x57, 0xaf, 0x6b, 0x11, 0xd7, 0x5b, 0x08, 0xa5, 0x70, 0xf1, 0xf0, 0x34, 0xd9,
		0xb1, 0x05, 0x64, 0xc7, 0x1a, 0x54, 0x63, 0x36, 0x75, 0x66, 0x53, 0x6b, 0x16, 0xf5, 0x4e, 0x87,
		0x7b, 0x42, 0x16, 0xd1, 0x65, 0xd8, 0x4e, 0xa4, 0xdc, 0x3e, 0x8c, 0x6e, 0x17, 0xb2, 0x14, 0x20,
		0xd0, 0xa0, 0xa0, 0x1a, 0xf6, 0xb5, 0xd9, 0x69, 0x77, 0x3c, 0x3a, 0xa8, 0x1d, 0x0e, 0x07, 0x68,
		0x05, 0xb4, 0x02, 0x5a, 0x53, 0x05, 0xad, 0x64, 0x9b, 0x63, 0x84, 0x9b, 0x61, 0xc4, 0x9b, 0x5f,
		0x84, 0x91, 0x50, 0x8e, 0xcd, 0x2d, 0xae, 0x1c, 0x05, 0xa6, 0xcd, 0x2b, 0xce, 0xed, 0x09, 0xca,
		0x7c, 0x15, 0x8e, 0xcd, 0x28, 0xee, 0xa5, 0xe2, 0xdf, 0x6c, 0x62, 0x5d, 0xbd, 0x94, 0x04, 0xe7,
		0xeb, 0x19, 0xa4, 0x5b, 0x04, 0xb5, 0xba, 0xe9, 0x6a, 0x73, 0x83, 0x68, 0x81, 0x68, 0x81, 0x68,
		0x81, 0x68, 0x81, 0x68, 0x81, 0x68, 0x81, 0x68, 0x81, 0x68, 0xa5, 0x8e, 0x68, 0x61, 0x6b, 0x35,
		0xd6, 0xd6, 0xaa, 0x46, 0xca, 0x8c, 0xc2, 0xb6, 0xea, 0x0e, 0xe3, 0x62, 0x28, 0x97, 0xac, 0xd4,
		0xcb, 0x6f, 0xd1, 0xcf, 0x67, 0x61, 0xc9, 0x5f, 0xd1, 0xcb, 0x57, 0x91, 0x9d, 0x7a, 0x4d, 0xf9,
		0x37, 0x2f, 0xf7, 0x79, 0xa5, 0x0d, 0x7e, 0xa9, 0xe4, 0x12, 0x39, 0xa5, 0x8a, 0xaf, 0x1a, 0xf1,
		0x3e, 0x19, 0x73, 0x05, 0x55, 0x57, 0xce, 0xc0, 0x8a, 0xc5, 0x9b, 0xbf, 0xf5, 0xb3, 0x11, 0x63,
		0x26, 0x14, 0xea, 0x98, 0x29, 0xd7, 0x2d, 0x93, 0xcc, 0xd1, 0x90, 0x76, 0x90, 0x55, 0x1c, 0x61,
		0x75, 0x87, 0x57, 0xd5, 0xb1, 0xd5, 0x76, 0x60, 0xb5, 0x1d, 0x55, 0x2d, 0x87, 0x94, 0x56, 0x07,
		0x65, 0x73, 0x20, 0xd4, 0xeb, 0x7e, 0xe9, 0xd6, 0xf9, 0x52, 0x4c, 0x30, 0x52, 0x8e, 0xf2, 0xe8,
		0x44, 0x75, 0xf4, 0xa3, 0x38, 0xba, 0x51, 0x1b, 0xb2, 0x28, 0x0d, 0x59, 0x54, 0x86, 0x24, 0x0a,
		0xc3, 0xcb, 0xe2, 0x54, 0x13, 0x82, 0x34, 0xeb, 0x20, 0x90, 0xd4, 0x3b, 0x40, 0x05, 0x5d, 0x8e,
		0xa0, 0x27, 0xf2, 0xef, 0x18, 0x3d, 0xd7, 0x2d, 0xa8, 0xa0, 0xab, 0x7e, 0xfa, 0xde, 0x50, 0xd1,
		0x6f, 0x37, 0x10, 0xde, 0xb3, 0xdd, 0x14, 0x56, 0x7f, 0xfa, 0x08, 0x00, 0x6c, 0x7a, 0x38, 0x14,
		0xd3, 0xed, 0x2b, 0xa4, 0xf3, 0x0c, 0x1c, 0x53, 0xc0, 0x31, 0xe7, 0x79, 0x6b, 0xd2, 0x88, 0x69,
		0x8a, 0xb1, 0x91, 0x16, 0x61, 0x23, 0x2f, 0xa2, 0x5b, 0x4a, 0xe7, 0x16, 0xab, 0xf3, 0x8c, 0x1d,
		0x56, 0x8a, 0x81, 0x09, 0x95, 0x57, 0x4f, 0x89, 0x35, 0x95, 0x99, 0x4c, 0xa9, 0xa3, 0x16, 0x96,
		0xa3, 0x8c, 0xee, 0x78, 0x68, 0x94, 0xd2, 0x4d, 0x0d, 0x18, 0x70, 0x81, 0x02, 0x3b, 0x38, 0xb0,
		0x83, 0x04, 0x27, 0x58, 0xd0, 0x80, 0x06, 0x11, 0x78, 0xd0, 0x39, 0x38, 0x8c, 0x0e, 0x0f, 0x87,
		0x03, 0xb4, 0xd4, 0x21, 0xda, 0x1f, 0x2c, 0xf3, 0x59, 0x08, 0x58, 0xfe, 0xfc, 0x2f, 0x46, 0x3f,
		0x0f, 0x36, 0x38, 0x36, 0xa9, 0xcc, 0x6e, 0xef, 0x89, 0x11, 0xff, 0x67, 0x46, 0x87, 0x09, 0x80,
		0x09, 0x80, 0x09, 0x80, 0x09, 0xc8, 0xac, 0x09, 0x78, 0x9c, 0x98, 0x80, 0xff, 0x6d, 0xf6, 0x3c,
		0x4f, 0xb8, 0xc1, 0xee, 0xde, 0xfe, 0xc7, 0x8f, 0xfb, 0xe1, 0x27, 0xea, 0xa3, 0x4b, 0xa6, 0x71,
		0xcf, 0x5f, 0xf0, 0xbb, 0x70, 0xe4, 0x34, 0x15, 0x6d, 0x47, 0xcd, 0x8e, 0x78, 0x3b, 0xf0, 0x53,
		0x25, 0x75, 0x66, 0xa2, 0x89, 0x14, 0x05, 0x76, 0x90, 0xd2, 0xc5, 0xbe, 0x4c, 0x3a, 0xb1, 0xce,
		0xf8, 0x49, 0x2e, 0x8d, 0xda, 0xf8, 0x9e, 0x77, 0xe2, 0x19, 0x85, 0x39, 0x38, 0x43, 0x79, 0x28,
		0xcc, 0x61, 0x86, 0x83, 0x61, 0x63, 0x90, 0x2e, 0xf8, 0x96, 0x17, 0x6e, 0xd3, 0xee, 0xfa, 0xbd,
		0xb6, 0x1d, 0x08, 0xeb, 0x8b, 0xb0, 0x5b, 0x82, 0xf0, 0xa8, 0xf8, 0x82, 0xb1, 0x71, 0x9c, 0x89,
		0x5f, 0x71, 0xb9, 0x9c, 0x2a, 0x1c, 0x67, 0x4a, 0x01, 0x3f, 0xa5, 0x3f, 0xce, 0x34, 0xd1, 0x52,
		0xa7, 0xe3, 0x8e, 0xf4, 0xd4, 0x0a, 0xfa, 0xb7, 0x21, 0x2c, 0xd2, 0x51, 0x26, 0x18, 0xab, 0xea,
		0xf6, 0x5e, 0xfb, 0xaf, 0xfe, 0x9e, 0xc5, 0x53, 0xa1, 0x24, 0xed, 0x5f, 0x48, 0xdb, 0xbd, 0x00,
		0x4c, 0x01, 0xa6, 0x00, 0x53, 0x9c, 0x0d, 0x95, 0xfd, 0xc2, 0xd9, 0x50, 0xd2, 0x71, 0x71, 0x36,
		0x14, 0x67, 0x43, 0x19, 0xa0, 0x91, 0x6e, 0x94, 0x4c, 0x16, 0xe1, 0xe8, 0x5a, 0x76, 0xab, 0xe5,
		0x09, 0xdf, 0x27, 0xe4, 0x5c, 0x93, 0x31, 0x41, 0xbc, 0x40, 0xbc, 0x40, 0xbc, 0x52, 0x45, 0xbc,
		0xc8, 0xb4, 0x73, 0xc6, 0x6d, 0x3d, 0x25, 0x18, 0x6b, 0xf4, 0xae, 0xa9, 0x23, 0x5f, 0x93, 0x99,
		0xfb, 0x5a, 0x26, 0x9c, 0xbb, 0xc8, 0x1c, 0x9e, 0xd0, 0x6e, 0x91, 0x06, 0xc2, 0x73, 0xc9, 0xbb,
		0x29, 0xe5, 0xff, 0xdc, 0xdd, 0x7d, 0x2c, 0x58, 0xa7, 0xf5, 0x1f, 0x8f, 0x45, 0xeb, 0xb4, 0x3e,
		0xfc, 0xb6, 0x38, 0xf8, 0x67, 0xf8, 0x7d, 0xe9, 0xb1, 0x60, 0x95, 0xc7, 0xdf, 0x1f, 0x3e, 0x16,
		0xac, 0xc3, 0xfa, 0xde, 0xe7, 0xcf, 0x1f, 0xf7, 0xbe, 0x1f, 0xbc, 0xcb, 0x5f, 0xf8, 0x0f, 0xba,
		0x2d, 0xfc, 0x3a, 0xe5, 0xe4, 0xde, 0xdc, 0xd7, 0x7e, 0xc7, 0x0c, 0x93, 0xd2, 0x1f, 0x62, 0x2a,
		0xce, 0xa3, 0xfe, 0x47, 0x50, 0xff, 0xa1, 0x70, 0xda, 0xd6, 0x73, 0xc5, 0xfa, 0xa9, 0xfe, 0xbd,
		0xf8, 0xa1, 0xfc, 0x7e, 0xb6, 0xf7, 0xfd, 0xf8, 0x7d, 0xfe, 0x97, 0x3f, 0x16, 0x7d, 0xac, 0xf8,
		0xe1, 0xf8, 0xfd, 0x6c, 0xc9, 0x5f, 0x8e, 0xde, 0xcf, 0x62, 0x8e, 0x71, 0xf8, 0xbe, 0x1b, 0xf9,
		0x68, 0xff, 0xf7, 0xa5, 0x65, 0x17, 0x94, 0x97, 0x5c, 0x70, 0xb0, 0xec, 0x82, 0x83, 0x25, 0x17,
		0x2c, 0x7d, 0xa4, 0xd2, 0x92, 0x0b, 0x0e, 0xdf, 0x7f, 0x44, 0x3e, 0xbf, 0xbb, 0xf8, 0xa3, 0x47,
		0xef, 0x7b, 0x3f, 0x96, 0xfd, 0xed, 0xf8, 0xfd, 0xc7, 0xd9, 0xde, 0x56, 0x83, 0x21, 0xe4, 0x2d,
		0xdb, 0xf2, 0x06, 0x0f, 0x5d, 0x59, 0x03, 0xda, 0x7e, 0xd7, 0x1a, 0xe5, 0xaf, 0x10, 0xf9, 0xe7,
		0xe1, 0x88, 0xf0, 0xce, 0xe1, 0x9d, 0xc3, 0x3b, 0x4f, 0x95, 0x77, 0xee, 0x07, 0x9e, 0xe3, 0xbe,
		0x50, 0x7a, 0xe6, 0x27, 0x19, 0xc4, 0xbc, 0x57, 0xbb, 0x49, 0x1f, 0x96, 0x9c, 0x1e, 0x14, 0xc8,
		0x07, 0xe4, 0x03, 0xf2, 0xa5, 0x0a, 0xf9, 0xe8, 0xd4, 0x93, 0xda, 0xab, 0x26, 0xf7, 0xa6, 0xf3,
		0x7f, 0x4e, 0xb3, 0xee, 0x79, 0x32, 0x5f, 0x7a, 0xdf, 0xfb, 0x7e, 0xf8, 0x4e, 0xc0, 0xbe, 0xeb,
		0x14, 0xaf, 0xce, 0xe1, 0xdd, 0x99, 0x7a, 0xff, 0x0c, 0x5a, 0xbe, 0x8e, 0xe7, 0xbc, 0x38, 0xae,
		0xd5, 0xf5, 0x3a, 0x41, 0xa7, 0xd9, 0x69, 0xd3, 0x59, 0xbf, 0xf9, 0x81, 0x61, 0x01, 0x61, 0x01,
		0x61, 0x01, 0x53, 0x65, 0x01, 0x9d, 0x96, 0x70, 0x03, 0x27, 0x78, 0x23, 0x6e, 0xfb, 0x46, 0xd1,
		0x2d, 0xba, 0x36, 0x7a, 0xb4, 0x4f, 0xb6, 0xcf, 0x70, 0xe8, 0xb8, 0x76, 0x7d, 0xff, 0x50, 0xb9,
		0xbc, 0x6c, 0xdc, 0xde, 0xdd, 0x3c, 0xdc, 0x9c, 0xdf, 0x5c, 0x36, 0x1e, 0xfe, 0xb8, 0xad, 0x52,
		0x89, 0xf4, 0x20, 0xc7, 0xc5, 0x27, 0x8d, 0x4c, 0x12, 0x27, 0xf7, 0x8c, 0xa7, 0xe1, 0xb6, 0x76,
		0x95, 0x4f, 0x63, 0x4a, 0x13, 0xd3, 0xeb, 0xd6, 0x7e, 0xbe, 0xba, 0xdd, 0xa6, 0xf7, 0xbd, 0xa8,
		0xdd, 0x55, 0xcf, 0x1f, 0x2e, 0xff, 0x68, 0x9c, 0xdf, 0x5c, 0x5f, 0x57, 0xcf, 0x1f, 0xaa, 0x17,
		0xdb, 0xf4, 0xf6, 0x37, 0xf7, 0xb7, 0x3f, 0x1d, 0x6c, 0xd3, 0x0b, 0xdf, 0x3f, 0x54, 0x1e, 0x6a,
		0xe7, 0x5b, 0xa5, 0xd0, 0xf7, 0xb5, 0xfb, 0x6d, 0x7a, 0xdf, 0x4f, 0x3f, 0xdf, 0x6e, 0x9b, 0x06,
		0x6f, 0xd3, 0xfb, 0x5e, 0xde, 0x9c, 0x57, 0x2e, 0x1b, 0x95, 0x9f, 0x7f, 0xbe, 0xab, 0xfe, 0x5c,
		0x79, 0xa8, 0xa6, 0xad, 0x9a, 0x44, 0x3d, 0x69, 0xfe, 0x9c, 0x88, 0x7f, 0xdc, 0xed, 0xf9, 0x5f,
		0x44, 0xcb, 0x7a, 0xed, 0xb6, 0x7d, 0xab, 0x6d, 0x3f, 0x89, 0xb6, 0xe5, 0x07, 0x76, 0xf3, 0x2f,
		0x3a, 0x3f, 0x79, 0xd9, 0x0d, 0xe0, 0x2f, 0xc3, 0x5f, 0x86, 0xbf, 0x9c, 0x2a, 0x7f, 0x79, 0xa2,
		0xa3, 0xc8, 0x64, 0x95, 0x9b, 0xb9, 0x9e, 0xe3, 0x06, 0x07, 0x25, 0x86, 0x24, 0x36, 0xca, 0x2a,
		0x3f, 0xb4, 0x87, 0xb1, 0x78, 0xc8, 0x42, 0x8e, 0xeb, 0x70, 0x16, 0xb1, 0xe1, 0x58, 0x1d, 0x1d,
		0xe9, 0x8b, 0xfd, 0x11, 0xd3, 0x0d, 0x18, 0xcf, 0xfd, 0x30, 0x50, 0xc9, 0xc9, 0x9a, 0x32, 0x9c,
		0xe2, 0x32, 0xbe, 0xa6, 0x85, 0xf2, 0xc9, 0xe1, 0xf1, 0x61, 0x86, 0x17, 0x76, 0x27, 0x9d, 0xa3,
		0x6d, 0x7a, 0xa6, 0xb3, 0x70, 0x7b, 0xaf, 0xc2, 0x1b, 0x16, 0x8b, 0x62, 0x48, 0x74, 0x2e, 0x13,
		0x8e, 0x49, 0x53, 0xea, 0x80, 0x4e, 0x44, 0xea, 0x89, 0x72, 0x2c, 0xad, 0xce, 0x7f, 0x8b, 0xec,
		0x9a, 0x5e, 0x27, 0xc0, 0x45, 0xa8, 0x4a, 0xde, 0x19, 0x30, 0x72, 0x93, 0xe9, 0x4e, 0x81, 0xc4,
		0x1b, 0x15, 0x3d, 0x5f, 0xbb, 0x32, 0x0f, 0x97, 0x8f, 0x33, 0xef, 0xe7, 0x74, 0x86, 0xb3, 0x60,
		0x3d, 0xbd, 0x51, 0xaa, 0x30, 0x67, 0x11, 0xcf, 0x19, 0x9f, 0x67, 0x30, 0xd3, 0x9b, 0x51, 0x67,
		0x11, 0x05, 0x02, 0x19, 0x0a, 0x04, 0x6e, 0x60, 0x9f, 0x57, 0x85, 0x4a, 0x35, 0x68, 0xf5, 0xaa,
		0x3d, 0xfb, 0x29, 0x6e, 0xf5, 0x3a, 0xf9, 0x8e, 0xb7, 0xbd, 0x2b, 0x3a, 0xbb, 0xaa, 0x2e, 0x90,
		0xc9, 0x9e, 0xae, 0xdd, 0x4e, 0xdb, 0x69, 0xbe, 0x59, 0xcf, 0x1d, 0xef, 0x6f, 0xdb, 0x6b, 0x39,
		0xee, 0x8b, 0x7c, 0x6f, 0xd7, 0xe8, 0x10, 0xe8, 0xf1, 0xaa, 0xc6, 0xae, 0xd0, 0xe3, 0x55, 0xb6,
		0xc7, 0x6b, 0x44, 0xf6, 0x2c, 0xe1, 0x06, 0xde, 0x9b, 0x7a, 0xcb, 0xd7, 0x65, 0x03, 0xa2, 0x03,
		0x2c, 0x9f, 0xd3, 0x81, 0x0e, 0xb0, 0xe8, 0x00, 0x6b, 0x44, 0x4d, 0x28, 0xd4, 0x85, 0x4e, 0x6d,
		0xa8, 0x7d, 0x76, 0x14, 0x7a, 0x66, 0xf4, 0x63, 0xd1, 0x01, 0x96, 0xd6, 0xf7, 0x45, 0x85, 0x7a,
		0x00, 0x17, 0x80, 0xcb, 0x00, 0x70, 0x69, 0x57, 0xa8, 0x47, 0xe9, 0x64, 0x23, 0x6a, 0x49, 0xaf,
		0x9e, 0xd4, 0x6a, 0xca, 0xa6, 0xae, 0x6c, 0x6a, 0xcb, 0xa2, 0xbe, 0x7a, 0x6a, 0xac, 0xa9, 0xce,
		0x74, 0x7c, 0x24, 0x22, 0x6f, 0x28, 0x9d, 0x2c, 0xf3, 0x60, 0x28, 0x9d, 0x8c, 0xd2, 0xc9, 0x28,
		0x9d, 0xcc, 0x02, 0x8d, 0x74, 0xa3, 0x64, 0xb4, 0x74, 0x72, 0xcb, 0x6f, 0x76, 0x49, 0xeb, 0x26,
		0x0f, 0x06, 0x04, 0xe5, 0x02, 0xe5, 0x02, 0xe5, 0x4a, 0x15, 0xe5, 0x22, 0xd0, 0xcb, 0x69, 0xdd,
		0x3c, 0x04, 0xe1, 0x02, 0xe1, 0x02, 0xe1, 0x52, 0x5a, 0xaa, 0xa3, 0x03, 0xd0, 0xab, 0x2d, 0xa1,
		0x57, 0x5d, 0x1a, 0xe6, 0x30, 0x4d, 0xb0, 0x68, 0xa2, 0x96, 0xa0, 0x58, 0xa0, 0x58, 0xa0, 0x58,
		0xe4, 0x7d, 0x29, 0xc8, 0x56, 0x73, 0xfb, 0xda, 0x52, 0x90, 0x2a, 0x42, 0x0e, 0x5d, 0x29, 0x56,
		0x5d, 0xb8, 0x3f, 0xba, 0xd9, 0xde, 0x8f, 0xdd, 0xc7, 0xa2, 0x55, 0xaa, 0x8f, 0x7f, 0x38, 0x78,
		0x2c, 0x58, 0xa5, 0xfa, 0x1e, 0xba, 0x56, 0x6c, 0xd4, 0x0a, 0x6c, 0x43, 0x57, 0x0b, 0xa0, 0x07,
		0x9a, 0x0c, 0x24, 0xd3, 0x64, 0x60, 0x7f, 0xb7, 0xd8, 0x57, 0xf0, 0x93, 0xa1, 0xce, 0x17, 0xeb,
		0x11, 0x28, 0x18, 0xaa, 0x36, 0x7a, 0x5f, 0x40, 0x2c, 0x37, 0x5c, 0x2c, 0x11, 0x2a, 0xd0, 0x0b,
		0x15, 0x50, 0x17, 0xcc, 0x9d, 0x1e, 0x14, 0xe1, 0x02, 0x84, 0x0b, 0x10, 0x2e, 0x48, 0x5f, 0xb8,
		0x60, 0xa8, 0x9e, 0x56, 0xd0, 0x1f, 0x1d, 0x51, 0x03, 0xa9, 0xf9, 0xeb, 0x39, 0x6e, 0x70, 0xc2,
		0xc0, 0xf8, 0x0f, 0x51, 0x01, 0x88, 0x78, 0x70, 0x43, 0xd5, 0x62, 0x0a, 0x28, 0x00, 0x34, 0xb3,
		0xa4, 0x1b, 0x50, 0x00, 0xa8, 0x74, 0x58, 0x46, 0xf1, 0x1f, 0xea, 0xd1, 0x36, 0x3e, 0x20, 0x44,
		0x5a, 0x85, 0x3e, 0x62, 0x5b, 0x29, 0xed, 0x03, 0x4b, 0x55, 0xfa, 0xc8, 0x84, 0xd4, 0x6e, 0xc3,
		0xc2, 0xf4, 0x79, 0x8e, 0x3d, 0x6d, 0x9f, 0xdc, 0xc2, 0xf1, 0x58, 0xb9, 0xf9, 0x49, 0xf9, 0xf5,
		0x82, 0xb0, 0xfc, 0x31, 0x23, 0x94, 0xf3, 0xcf, 0xc4, 0x65, 0xe9, 0x01, 0x53, 0x31, 0x9c, 0x8a,
		0xca, 0xaf, 0x0f, 0xbf, 0x60, 0x2a, 0x06, 0x53, 0x71, 0x77, 0xff, 0x1b, 0xa4, 0x62, 0x38, 0x15,
		0xb4, 0xad, 0x1e, 0xb2, 0x3d, 0x15, 0xe7, 0x98, 0x8a, 0xb1, 0x55, 0xa5, 0xec, 0x77, 0x92, 0xe9,
		0x99, 0xf8, 0xf9, 0xae, 0x8a, 0x99, 0x18, 0xcc, 0xc4, 0xc3, 0x39, 0x87, 0x76, 0x90, 0x8e, 0x58,
		0x47, 0x7a, 0x20, 0xd1, 0xfd, 0xb5, 0xda, 0x62, 0x97, 0xad, 0x96, 0x1f, 0x58, 0xdd, 0x8e, 0x17,
		0x10, 0x76, 0xc6, 0x9e, 0x1a, 0x14, 0x31, 0xff, 0xb5, 0xd3, 0x85, 0x98, 0x3f, 0x62, 0xfe, 0xcb,
		0xdf, 0x88, 0x3e, 0xe6, 0xdf, 0xd7, 0x4b, 0xcb, 0xed, 0xbd, 0x3e, 0x91, 0x54, 0x61, 0x1d, 0xab,
		0xe8, 0x11, 0x0e, 0x63, 0x24, 0x82, 0x6d, 0x8b, 0xa3, 0x21, 0x38, 0x8c, 0x91, 0xa5, 0xa5, 0x3a,
		0x3a, 0x3c, 0x3c, 0xc0, 0x71, 0xd7, 0x6d, 0x21, 0x5c, 0xbe, 0xd7, 0xa4, 0x27, 0x5c, 0xe1, 0xa0,
		0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c, 0x20, 0x5c,
		0xdb, 0x4e, 0xb8, 0x5e, 0xed, 0xa6, 0x65, 0xb7, 0x5a, 0x9e, 0xf0, 0x7d, 0x3a, 0xc2, 0x35, 0x3d,
		0x28, 0x08, 0x17, 0x08, 0x17, 0x08, 0x57, 0xaa, 0x08, 0x17, 0x9d, 0x7a, 0xe6, 0x88, 0x4f, 0x61,
		0x91, 0x9f, 0xbe, 0xca, 0xff, 0x39, 0x7d, 0xfc, 0x62, 0xfe, 0x54, 0x47, 0xe9, 0x7d, 0xef, 0xfb,
		0xe1, 0x3b, 0xc1, 0xf9, 0x8a, 0x3a, 0xc5, 0xab, 0x73, 0x1c, 0xf3, 0x31, 0xf5, 0xfe, 0x59, 0xb4,
		0x7c, 0x93, 0xc6, 0xae, 0x74, 0x86, 0x8f, 0xaa, 0x59, 0x2c, 0xec, 0x1e, 0xec, 0x1e, 0xec, 0x1e,
		0x5a, 0x39, 0x27, 0x1c, 0x67, 0x40, 0x2b, 0x67, 0x1c, 0xe4, 0x58, 0x1c, 0x22, 0x40, 0x2b, 0x67,
		0xfe, 0x30, 0x8f, 0xf1, 0x35, 0x45, 0x2b, 0x67, 0x9e, 0xd1, 0xd0, 0xca, 0x59, 0xcb, 0xc2, 0xa2,
		0x95, 0x73, 0x0a, 0x3d, 0xa7, 0xa0, 0x49, 0xec, 0x36, 0x05, 0x4d, 0xf8, 0x4c, 0xf0, 0x99, 0xe0,
		0x33, 0xa5, 0xd0, 0x67, 0xd2, 0x56, 0xcd, 0x1c, 0xca, 0x12, 0xa7, 0x8e, 0xfe, 0x61, 0x63, 0x36,
		0x7b, 0x1b, 0xb3, 0xc7, 0xd8, 0x94, 0xdd, 0x06, 0x82, 0x35, 0x6e, 0xfd, 0x6c, 0xbd, 0x78, 0x9d,
		0x1e, 0x61, 0xef, 0x87, 0xb9, 0x71, 0x41, 0xb7, 0x40, 0xb7, 0x40, 0xb7, 0x52, 0x45, 0xb7, 0xf4,
		0xbb, 0x81, 0x46, 0xbc, 0xe7, 0x63, 0x9a, 0x6d, 0xd9, 0x71, 0x77, 0xd0, 0xf0, 0xbf, 0x59, 0x30,
		0xf1, 0xe7, 0x7e, 0x1e, 0x77, 0x11, 0x6d, 0xe5, 0x33, 0x88, 0xbf, 0x9d, 0x66, 0x20, 0x02, 0x7f,
		0xdc, 0xf5, 0x5b, 0xb4, 0xe8, 0x10, 0x38, 0x32, 0x32, 0x30, 0x18, 0x18, 0x0c, 0x0c, 0x4e, 0x15,
		0x06, 0x37, 0x3b, 0x3d, 0x37, 0x10, 0x1e, 0x9a, 0x1f, 0xc2, 0xe9, 0x85, 0xd3, 0x9b, 0x82, 0xa5,
		0x42, 0xf3, 0xc3, 0x6d, 0xf5, 0x83, 0xbb, 0x76, 0xf3, 0x2f, 0x26, 0x22, 0x16, 0x1d, 0x1a, 0x4c,
		0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x0c, 0x4c, 0x6c, 0xf3,
		0x98, 0xd8, 0x8e, 0x41, 0x99, 0xcf, 0x57, 0x5c, 0xb7, 0x13, 0x0c, 0x53, 0x82, 0x74, 0xc4, 0x3c,
		0xef, 0x37, 0xbf, 0x88, 0x57, 0xbb, 0x3b, 0x0a, 0x40, 0xee, 0x77, 0xba, 0xc2, 0x6d, 0x0e, 0x38,
		0x92, 0xe5, 0x8a, 0xe0, 0xef, 0x8e, 0xf7, 0x97, 0xe5, 0xb8, 0x7e, 0x60, 0xbb, 0x4d, 0xb1, 0x3f,
		0xff, 0x0b, 0x3f, 0xf2, 0x9b, 0x7d, 0xfb, 0x39, 0xf0, 0xf7, 0xbb, 0x9d, 0xb6, 0xd3, 0x7c, 0x1b,
		0x53, 0x3f, 0xc7, 0x7d, 0x89, 0xfe, 0xc6, 0x12, 0x6e, 0xe0, 0xbd, 0x0d, 0x83, 0x98, 0x6a, 0x76,
		0x59, 0x7e, 0xb6, 0xe5, 0xae, 0x90, 0x5c, 0x97, 0x3e, 0x43, 0x1a, 0x14, 0xde, 0x75, 0x5b, 0x42,
		0x96, 0x1c, 0xe5, 0x2f, 0x1d, 0x3f, 0xa8, 0x04, 0x81, 0xa7, 0xb4, 0x92, 0x7d, 0xa3, 0x54, 0x6d,
		0x8b, 0x3e, 0xd7, 0xf1, 0xd5, 0xb0, 0xa9, 0x8f, 0x95, 0x53, 0x23, 0xd0, 0xa0, 0x50, 0xfe, 0xc6,
		0x6b, 0x09, 0x4f, 0xb4, 0x3e, 0xf5, 0xa7, 0xc5, 0xed, 0xb5, 0xdb, 0xac, 0xb3, 0xaf, 0xa9, 0x0d,
		0x89, 0x6a, 0x81, 0x02, 0xf9, 0xca, 0xfb, 0x81, 0xd7, 0x6b, 0x06, 0xee, 0x88, 0xc7, 0x5d, 0x0f,
		0x1f, 0xa0, 0x36, 0xba, 0x7f, 0xa3, 0xf2, 0x1c, 0xf8, 0x8d, 0xdb, 0xc1, 0xdd, 0x7e, 0x0a, 0x6f,
		0x56, 0x1d, 0xdc, 0x6b, 0x87, 0x47, 0x63, 0xe2, 0x7d, 0x32, 0xe6, 0xaa, 0xaa, 0xae, 0xa6, 0x91,
		0x55, 0x8c, 0x37, 0x83, 0xeb, 0xe7, 0x63, 0xf5, 0x27, 0xd6, 0xcc, 0x94, 0xec, 0x0c, 0x31, 0xcc,
		0x4c, 0x0c, 0xa9, 0x8d, 0x21, 0xa5, 0xab, 0x67, 0x73, 0xf9, 0x1c, 0xad, 0x98, 0x9f, 0x7c, 0x73,
		0xec, 0xe2, 0xaf, 0x9e, 0x97, 0x29, 0x2f, 0x68, 0xf0, 0xf9, 0x35, 0x33, 0x3e, 0xde, 0xee, 0x5b,
		0xf3, 0xb1, 0xb8, 0xf1, 0x05, 0x99, 0xf8, 0xc1, 0x74, 0x7c, 0xc0, 0x15, 0x41, 0x7f, 0x19, 0xe2,
		0xcc, 0xbe, 0x64, 0x0c, 0x40, 0xd9, 0xc7, 0x57, 0xf6, 0xe1, 0xe7, 0x7d, 0xf4, 0xf1, 0xbb, 0x31,
		0xeb, 0xce, 0x85, 0x13, 0xcf, 0xd0, 0xe6, 0x5b, 0xc2, 0x6f, 0x7a, 0x4e, 0x57, 0x0a, 0x87, 0xc2,
		0xb5, 0x9a, 0xbe, 0x38, 0xe6, 0x74, 0xc8, 0x79, 0x17, 0xd2, 0xa1, 0x2c, 0x95, 0x90, 0x95, 0x9a,
		0xe8, 0xe9, 0x86, 0xa1, 0xb4, 0xc3, 0x4d, 0xda, 0x61, 0x25, 0x65, 0xd1, 0xe4, 0x31, 0x88, 0xd2,
		0xa1, 0x9f, 0x70, 0xdd, 0xfc, 0xc0, 0xeb, 0x1b, 0x2d, 0x89, 0x35, 0x0b, 0x8f, 0x9b, 0x53, 0x19,
		0xba, 0x18, 0x50, 0x25, 0x5c, 0xfb, 0xa9, 0x2d, 0x11, 0x7e, 0x9e, 0x3a, 0x19, 0x31, 0xbc, 0x10,
		0x1a, 0x06, 0x0d, 0x4b, 0x48, 0xc3, 0x9e, 0x3a, 0x9d, 0xb6, 0xb0, 0x5d, 0x15, 0x15, 0x2b, 0x9a,
		0x57, 0xb1, 0x71, 0x61, 0x0a, 0xeb, 0xd9, 0x7e, 0x75, 0xda, 0x8e, 0xf0, 0x95, 0x75, 0x2e, 0x3a,
		0xd2, 0x86, 0x28, 0xa1, 0x63, 0xb5, 0x0f, 0xb6, 0x53, 0x05, 0x07, 0x6f, 0x9e, 0x39, 0x05, 0x54,
		0xeb, 0x75, 0xa4, 0xd2, 0xcb, 0x48, 0xaf, 0x57, 0x51, 0xf8, 0xc0, 0x95, 0x8b, 0x8b, 0xbb, 0xea,
		0xfd, 0x7d, 0xe3, 0xa7, 0xca, 0x55, 0xed, 0xf2, 0x0f, 0xd9, 0x55, 0xd7, 0x68, 0x37, 0xa4, 0x16,
		0x26, 0x0c, 0x9f, 0xfb, 0xb2, 0xd4, 0xa8, 0x3e, 0xfc, 0x52, 0xbd, 0xbb, 0xae, 0x3e, 0xc8, 0xc7,
		0xec, 0x14, 0xe2, 0x9c, 0x9a, 0x8f, 0x7b, 0x75, 0x7b, 0x79, 0x9f, 0x85, 0xe7, 0xac, 0xdd, 0xfe,
		0x76, 0x94, 0x91, 0xe7, 0x2c, 0xe7, 0x99, 0xa3, 0xae, 0xf5, 0x84, 0xd0, 0x47, 0x29, 0x02, 0xab,
		0x1e, 0x79, 0x25, 0x8d, 0xb8, 0xaa, 0x45, 0x5a, 0x69, 0x58, 0xc5, 0x6b, 0xd0, 0x93, 0x27, 0x10,
		0xfd, 0x8b, 0x40, 0xd8, 0x41, 0xd8, 0x13, 0xe2, 0x0b, 0x3d, 0xc7, 0x0d, 0x8a, 0x47, 0x0a, 0x54,
		0x41, 0xa2, 0x24, 0x87, 0x62, 0x0a, 0x83, 0xda, 0xee, 0x8f, 0xf2, 0x06, 0xa0, 0xe6, 0x7e, 0xb6,
		0x6e, 0x8a, 0x01, 0xc5, 0x66, 0xf4, 0xbb, 0xda, 0x76, 0x57, 0xe2, 0x53, 0xa6, 0x51, 0x02, 0x96,
		0x64, 0xda, 0x98, 0xf6, 0x81, 0xea, 0x06, 0x6d, 0xcf, 0x68, 0x5f, 0x41, 0xd2, 0xf8, 0x0c, 0xae,
		0x82, 0xf5, 0x81, 0xf5, 0x41, 0x40, 0x76, 0xc5, 0x3d, 0xbd, 0x4e, 0x2f, 0x10, 0x56, 0xcb, 0xf1,
		0x03, 0xc7, 0x7d, 0xe9, 0x39, 0xfe, 0x17, 0xe1, 0xc9, 0xab, 0xda, 0xa2, 0x41, 0xa0, 0x79, 0xd0,
		0xbc, 0x84, 0x34, 0x4f, 0x5d, 0x1c, 0x73, 0x8a, 0xf5, 0x08, 0xd5, 0xea, 0x0e, 0x2a, 0x90, 0x40,
		0x65, 0x70, 0x89, 0x82, 0x8c, 0xc2, 0xb5, 0xba, 0x45, 0x75, 0xf3, 0x7f, 0xee, 0x1e, 0x1d, 0x3e,
		0x16, 0xac, 0xc3, 0xfa, 0x63, 0xc1, 0x3a, 0xa8, 0x0f, 0xbe, 0xfb, 0xf1, 0x58, 0xec, 0xff, 0x5c,
		0x1c, 0xfe, 0xf2, 0x74, 0xea, 0x7f, 0xfd, 0xbf, 0x9c, 0xd6, 0xff, 0x35, 0xfa, 0xff, 0xdc, 0xaf,
		0xf7, 0xce, 0x76, 0xcb, 0x8f, 0x05, 0xab, 0x14, 0x7e, 0xbe, 0x1c, 0x7e, 0x77, 0xd4, 0xff, 0xdf,
		0x71, 0x7d, 0xe6, 0xaf, 0xfd, 0xfb, 0x8c, 0x6e, 0x79, 0x5a, 0xff, 0x7e, 0xfa, 0x3e, 0x1c, 0x64,
		0xf8, 0x53, 0xf1, 0xc3, 0xc9, 0xe8, 0xe7, 0x3d, 0x85, 0x0a, 0xbe, 0x75, 0x95, 0x79, 0xa4, 0xa8,
		0x50, 0xbc, 0x91, 0x93, 0xc9, 0x99, 0x3b, 0xb6, 0x8d, 0xea, 0xb6, 0x3b, 0xb5, 0xca, 0xc3, 0x6f,
		0x8b, 0x53, 0x8b, 0x5f, 0x9a, 0x2c, 0xf5, 0x8f, 0xd2, 0x50, 0x96, 0xf6, 0x3e, 0x7f, 0xfe, 0xb8,
		0xf7, 0xfd, 0xe0, 0x5d, 0xfe, 0xc2, 0x33, 0x3a, 0x71, 0xcc, 0x98, 0x1a, 0x6e, 0xcf, 0x24, 0x43,
		0x3d, 0x69, 0xd5, 0x93, 0x01, 0x75, 0x97, 0x4a, 0xc8, 0xf7, 0xd2, 0xfb, 0xf0, 0xc3, 0x07, 0xa3,
		0x8f, 0x7e, 0x2f, 0x7c, 0x18, 0xfd, 0x2a, 0xc3, 0xba, 0xb7, 0x21, 0x33, 0xb8, 0x01, 0x51, 0x9a,
		0x01, 0xeb, 0xf6, 0x2c, 0xa7, 0xa5, 0xe8, 0x3f, 0x0e, 0x2e, 0x85, 0xd7, 0x08, 0xaf, 0x31, 0x21,
		0xaf, 0xb1, 0xd5, 0x09, 0x02, 0xd1, 0xb2, 0xfe, 0xdb, 0xb3, 0x5b, 0x4a, 0x41, 0x1b, 0x89, 0x6b,
		0x54, 0x71, 0x2f, 0x6f, 0x92, 0x6a, 0xe4, 0x53, 0x89, 0x32, 0x81, 0xcc, 0xfa, 0x86, 0x6b, 0x3b,
		0xb8, 0x0a, 0xd8, 0x02, 0x6c, 0x49, 0x08, 0x5b, 0x32, 0x97, 0xb9, 0x74, 0x5d, 0x7d, 0xf8, 0xcf,
		0xcd, 0xdd, 0xbf, 0x1b, 0xb5, 0xeb, 0xfb, 0x87, 0xca, 0xf5, 0x79, 0xb5, 0xf1, 0xf0, 0xc7, 0x6d,
		0x35, 0x4b, 0x09, 0x4c, 0x97, 0x07, 0x59, 0xc8, 0xb4, 0xb9, 0xa8, 0xfe, 0x54, 0xf9, 0xf5, 0xf2,
		0x21, 0x9c, 0xe6, 0x2c, 0x3c, 0xf3, 0x65, 0xe9, 0xb6, 0x74, 0x9b, 0x8d, 0x07, 0xfd, 0xed, 0xbe,
		0x96, 0x89, 0x07, 0x3d, 0xf8, 0xed, 0xee, 0xa7, 0xcc, 0x25, 0x5c, 0x6d, 0xf4, 0xc1, 0xb7, 0xd1,
		0x51, 0x31, 0x9e, 0x43, 0x6b, 0xae, 0x18, 0xec, 0xea, 0x5b, 0xdd, 0x8e, 0x33, 0x4c, 0x0b, 0x8b,
		0x7f, 0x7e, 0x6d, 0xee, 0x52, 0x1c, 0x65, 0xc3, 0x51, 0xb6, 0xd5, 0xe2, 0x25, 0xcf, 0x95, 0x23,
		0x23, 0xc8, 0xf1, 0xe6, 0x22, 0x78, 0x33, 0x78, 0xb3, 0x9a, 0xf0, 0x4e, 0x0b, 0x71, 0x9c, 0x83,
		0xbd, 0xab, 0x44, 0x78, 0xfd, 0x41, 0x5f, 0x4d, 0x01, 0x56, 0x16, 0x64, 0x1d, 0x81, 0xa6, 0x11,
		0x6c, 0x5d, 0x01, 0x27, 0x13, 0x74, 0x32, 0x81, 0x27, 0x13, 0x7c, 0x35, 0x6e, 0x25, 0x5b, 0xc4,
		0x42, 0x56, 0x21, 0x96, 0xa2, 0xbb, 0x4c, 0xb4, 0x35, 0x36, 0xe0, 0xc7, 0x8f, 0xc3, 0x6a, 0xc6,
		0x4e, 0xc8, 0x54, 0x89, 0x42, 0xa5, 0x68, 0x55, 0x8b, 0x4a, 0xc5, 0xc8, 0x55, 0x8d, 0x5c, 0xe5,
		0xc8, 0x55, 0x4f, 0x4d, 0x05, 0x35, 0xbc, 0xb7, 0x1c, 0x49, 0xcd, 0x3d, 0xfd, 0xcd, 0xc8, 0x68,
		0x48, 0x79, 0x23, 0xea, 0x25, 0xa5, 0xab, 0x62, 0x4f, 0xc4, 0x87, 0x8a, 0xfc, 0x26, 0x96, 0xef,
		0xa7, 0x3e, 0x85, 0x12, 0xd3, 0x47, 0x02, 0xf7, 0x84, 0x30, 0xaf, 0x08, 0xef, 0x60, 0x48, 0x60,
		0x48, 0xb2, 0xa0, 0xa1, 0x0c, 0xc7, 0x04, 0x0d, 0x40, 0x74, 0x1a, 0x7e, 0x4c, 0x37, 0xf8, 0x18,
		0x36, 0xee, 0x58, 0xa4, 0x76, 0x29, 0x80, 0x16, 0xe1, 0xb6, 0x62, 0x86, 0x9f, 0x96, 0xce, 0xf0,
		0x64, 0x08, 0x38, 0x5a, 0x80, 0x91, 0xcd, 0x72, 0xb4, 0xc6, 0xb2, 0xad, 0xef, 0x5d, 0x85, 0x23,
		0xe9, 0xb9, 0x54, 0x45, 0xb8, 0x54, 0x70, 0xa9, 0xb2, 0xe5, 0x52, 0xa9, 0x2a, 0x9f, 0x6e, 0x18,
		0x90, 0x36, 0x2c, 0x48, 0xac, 0x90, 0x64, 0x8a, 0x49, 0xa9, 0xa0, 0x3c, 0x8a, 0x4a, 0xad, 0xb0,
		0x6c, 0x8a, 0xcb, 0xa6, 0xc0, 0x6c, 0x8a, 0xac, 0xa7, 0xd0, 0x9a, 0x8a, 0x4d, 0xa6, 0xe0, 0x11,
		0x6b, 0xab, 0x13, 0xce, 0x5c, 0x6b, 0x80, 0xd5, 0xc3, 0x9a, 0xc4, 0x61, 0x4e, 0x36, 0x28, 0xe0,
		0x80, 0x04, 0x5e, 0x68, 0xe0, 0x82, 0x08, 0x76, 0xa8, 0x60, 0x87, 0x0c, 0x76, 0xe8, 0xa0, 0x81,
		0x10, 0x22, 0x28, 0xa1, 0x0b, 0xc3, 0xf2, 0x85, 0x65, 0x97, 0x12, 0x81, 0x93, 0x94, 0xb4, 0x43,
		0x20, 0x58, 0x83, 0xbe, 0x92, 0x34, 0x45, 0x4b, 0xb8, 0x94, 0xe6, 0x3a, 0xec, 0x14, 0x35, 0x19,
		0x1b, 0x38, 0x0c, 0x1c, 0x06, 0x0e, 0x6f, 0x25, 0x0e, 0x4b, 0x17, 0x65, 0x8a, 0x8b, 0x02, 0x47,
		0x84, 0x43, 0xd2, 0xf6, 0xa5, 0x1a, 0x7f, 0xd1, 0xea, 0x54, 0x8e, 0xab, 0x4f, 0x15, 0x13, 0xbc,
		0x46, 0x86, 0x67, 0xea, 0x5b, 0x15, 0x8e, 0xcf, 0xd8, 0x01, 0x89, 0x58, 0xdd, 0x66, 0x97, 0x94,
		0xa1, 0x9f, 0x95, 0xe9, 0x25, 0xd5, 0x28, 0x7a, 0x95, 0x8a, 0x65, 0xdd, 0x49, 0xe7, 0x68, 0xf5,
		0x0d, 0x62, 0x9a, 0x01, 0xa5, 0x85, 0x51, 0x39, 0xe8, 0x05, 0x76, 0x09, 0x76, 0x09, 0x76, 0xb9,
		0x61, 0xec, 0x52, 0xed, 0xa0, 0x5d, 0x6c, 0x57, 0x9f, 0xd0, 0xa6, 0xe9, 0x1d, 0xd4, 0x8b, 0x3d,
		0x21, 0xd5, 0xeb, 0x8b, 0xdb, 0x9b, 0xda, 0xf5, 0x83, 0xca, 0x01, 0xbe, 0x78, 0xe6, 0xde, 0x27,
		0xe7, 0xc9, 0x3c, 0x5c, 0x79, 0x66, 0x5a, 0xee, 0xaa, 0x57, 0x37, 0x0f, 0xd5, 0x7c, 0x16, 0x08,
		0x21, 0xf3, 0x4c, 0x5c, 0xde, 0x9c, 0x57, 0x2e, 0xf3, 0x29, 0xa7, 0x50, 0xf5, 0x8d, 0xeb, 0x5d,
		0x9a, 0xec, 0xce, 0x0d, 0x51, 0x4f, 0xd1, 0x70, 0x3c, 0xe3, 0x39, 0x9a, 0x61, 0xee, 0x51, 0xf8,
		0x9d, 0x52, 0xda, 0x26, 0xdd, 0xaa, 0xe8, 0x74, 0xe7, 0xa7, 0xdc, 0xfe, 0x62, 0xd8, 0xf6, 0xda,
		0x96, 0x8e, 0xfc, 0xd8, 0xf1, 0xc6, 0x8e, 0xb7, 0x29, 0xe2, 0x4a, 0x90, 0xa6, 0xba, 0x94, 0xa4,
		0x1e, 0x13, 0x8c, 0x15, 0x49, 0x63, 0x9d, 0x86, 0x93, 0x0c, 0x42, 0x6c, 0xbb, 0xd3, 0xb4, 0xdb,
		0x74, 0xe0, 0x3a, 0x1c, 0x0e, 0x89, 0x44, 0x80, 0x55, 0xc0, 0x6a, 0x9a, 0x12, 0x89, 0x88, 0x32,
		0x06, 0x23, 0x62, 0x4c, 0x92, 0x39, 0x48, 0xac, 0xf8, 0x08, 0x2c, 0x22, 0xb0, 0x88, 0xc0, 0x22,
		0x0f, 0x90, 0x84, 0x03, 0x3a, 0x6e, 0x20, 0xbc, 0x67, 0xbb, 0xc9, 0x18, 0xa1, 0x9b, 0xdc, 0x82,
		0x78, 0xe9, 0x79, 0xf6, 0xfa, 0xc8, 0xe1, 0x86, 0x13, 0x76, 0x16, 0xc1, 0x8f, 0xf3, 0x9c, 0x67,
		0xd8, 0xb5, 0x65, 0x42, 0x20, 0x63, 0x48, 0x64, 0x0c, 0x91, 0x96, 0x21, 0x93, 0xf3, 0x9c, 0xf6,
		0x20, 0x24, 0x71, 0x6c, 0x97, 0x7e, 0x17, 0x84, 0xd1, 0xb9, 0xe4, 0x74, 0x36, 0x97, 0x3a, 0x9f,
		0xfb, 0x03, 0xb1, 0x38, 0x0b, 0x01, 0xd2, 0x9f, 0xff, 0xc5, 0xe8, 0xe7, 0x41, 0xa7, 0xa7, 0x94,
		0x6e, 0xd9, 0x13, 0x0a, 0x4d, 0xde, 0x77, 0x02, 0x41, 0x99, 0x22, 0x1f, 0x91, 0x97, 0xf1, 0x0d,
		0x60, 0x88, 0x4c, 0x18, 0x22, 0x7a, 0x1e, 0x0c, 0x6b, 0x94, 0x5a, 0x9e, 0x0c, 0x93, 0xc4, 0x94,
		0xfe, 0x39, 0x8f, 0x32, 0x47, 0x0c, 0x43, 0xf3, 0xa4, 0x83, 0x8e, 0xbf, 0x78, 0x74, 0x34, 0xc7,
		0x9d, 0x1e, 0xca, 0x0c, 0xef, 0x91, 0xdb, 0x30, 0xa7, 0x8b, 0x86, 0xf7, 0x31, 0x90, 0x5f, 0xc8,
		0xa4, 0xbe, 0xb3, 0x4b, 0xcf, 0x98, 0x46, 0x9a, 0xd4, 0xd2, 0x33, 0xa6, 0x95, 0x26, 0xb2, 0xfc,
		0x3b, 0xd9, 0x18, 0xb5, 0xbe, 0x2d, 0xdc, 0xba, 0x6d, 0x3f, 0x89, 0xb6, 0xf5, 0xd4, 0xee, 0x34,
		0xff, 0xb2, 0x3a, 0xcf, 0xcf, 0xbe, 0x08, 0x98, 0xb9, 0xf6, 0x82, 0x1b, 0x82, 0x7b, 0x83, 0x7b,
		0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b,
		0x6f, 0x1b, 0xf7, 0xf6, 0x9d, 0xff, 0x27, 0x0c, 0x32, 0xef, 0xc1, 0xed, 0xc0, 0xbb, 0xc1, 0xbb,
		0xc1, 0xbb, 0xc1, 0xbb, 0xc1, 0xbb, 0xc1, 0xbb, 0xc1, 0xbb, 0xc1, 0xbb, 0xc1, 0xbb, 0xc1, 0xbb,
		0x37, 0x9d, 0x77, 0xf7, 0x9e, 0x0c, 0xe4, 0x37, 0xce, 0xdc, 0x05, 0x2c, 0x1b, 0x29, 0x8e, 0x5b,
		0x4b, 0xb0, 0x91, 0xe2, 0x48, 0x2f, 0xed, 0x9b, 0x9e, 0xe2, 0xf8, 0x38, 0x49, 0x71, 0xfc, 0xdf,
		0x66, 0xcf, 0xf3, 0x84, 0x1b, 0xec, 0xee, 0xed, 0x7f, 0xfc, 0xb8, 0x1f, 0x7e, 0xa2, 0x3e, 0xba,
		0x64, 0x1a, 0x67, 0xfd, 0x05, 0xbf, 0x0b, 0x47, 0x6e, 0x89, 0x6f, 0xa9, 0xcd, 0x96, 0x4c, 0xd5,
		0x69, 0x02, 0xe2, 0x53, 0xf2, 0x13, 0xbb, 0x9b, 0x82, 0xd3, 0xf2, 0x83, 0x13, 0x8c, 0x24, 0x67,
		0xe6, 0xe9, 0xd6, 0x8e, 0xa2, 0xac, 0xd4, 0xe0, 0xb4, 0x2a, 0xfd, 0x01, 0xb0, 0xe1, 0xb0, 0x29,
		0x3f, 0xff, 0x55, 0xc2, 0xf9, 0x2f, 0x9c, 0xff, 0x32, 0x1c, 0xe3, 0xc3, 0xf9, 0x2f, 0x5d, 0x8d,
		0x80, 0x73, 0x04, 0xe7, 0x08, 0xce, 0x11, 0x9c, 0x23, 0x38, 0x47, 0xd2, 0xce, 0x11, 0xce, 0x7f,
		0x11, 0x87, 0xea, 0x70, 0xfe, 0x0b, 0x7b, 0xe1, 0xb0, 0x46, 0xd8, 0x0b, 0xc7, 0x5e, 0xf8, 0xcc,
		0xd0, 0xd8, 0x0b, 0x37, 0x0f, 0xef, 0x91, 0xdb, 0x60, 0x2f, 0x5c, 0x6e, 0xe9, 0xb1, 0x17, 0x9e,
		0xfa, 0xe5, 0xc7, 0x5e, 0x78, 0xba, 0xb8, 0x35, 0xce, 0x7f, 0x81, 0x7b, 0x83, 0x7b, 0x83, 0x7b,
		0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x9b, 0xe7,
		0xde, 0x38, 0xff, 0x05, 0xde, 0x0d, 0xde, 0x0d, 0xde, 0x0d, 0xde, 0x0d, 0xde, 0x0d, 0xde, 0x0d,
		0xde, 0x0d, 0xde, 0x0d, 0xde, 0x0d, 0xde, 0x4d, 0xcf, 0xbb, 0x71, 0xfe, 0x6b, 0x33, 0x59, 0x36,
		0x52, 0x1c, 0x53, 0x49, 0xb0, 0x91, 0xe2, 0x48, 0x2f, 0xed, 0x38, 0xff, 0x85, 0xf3, 0x5f, 0x4c,
		0x52, 0xbc, 0x05, 0xe7, 0xbf, 0x86, 0xc7, 0x9a, 0xd0, 0x12, 0x77, 0x43, 0x5b, 0xe2, 0x52, 0xb4,
		0x29, 0x1c, 0xbe, 0x4c, 0xe0, 0xf5, 0x9a, 0x81, 0x3b, 0xc2, 0xdc, 0xeb, 0xe1, 0xd3, 0xd5, 0x46,
		0x0f, 0xd7, 0x38, 0x0f, 0x1f, 0xe5, 0xb6, 0x7f, 0xdb, 0x46, 0x75, 0x74, 0xff, 0xc6, 0xe5, 0xe0,
		0xfe, 0x19, 0x6c, 0x17, 0xe9, 0x89, 0xd7, 0x0e, 0xc1, 0x31, 0xc2, 0xd0, 0x4a, 0x8d, 0xc6, 0x43,
		0xc3, 0xc8, 0x38, 0xec, 0x15, 0x0d, 0x23, 0xd1, 0x30, 0x72, 0xcd, 0x5b, 0xa1, 0x61, 0x64, 0x9a,
		0xdc, 0x5b, 0x1c, 0x18, 0x36, 0xe6, 0xc3, 0xe2, 0xc0, 0x30, 0x2d, 0xc5, 0x27, 0x3f, 0x30, 0x3c,
		0xb4, 0xf4, 0x96, 0xff, 0xe6, 0x07, 0xe2, 0x95, 0x2f, 0xa8, 0x36, 0x7b, 0x1b, 0x44, 0xd5, 0xb0,
		0x77, 0xbd, 0xdd, 0xa1, 0x35, 0xec, 0x5d, 0x33, 0xc9, 0xbd, 0xd3, 0xb5, 0xec, 0x56, 0xcb, 0x13,
		0xbe, 0xcf, 0x19, 0x62, 0x3b, 0x65, 0x18, 0x7b, 0x34, 0x37, 0x99, 0xdb, 0xbf, 0x9e, 0xcc, 0xfc,
		0xd7, 0x32, 0xe3, 0xdc, 0x47, 0xd6, 0xe0, 0x84, 0xf1, 0x1e, 0xb7, 0x76, 0x10, 0x08, 0xcf, 0x65,
		0x5b, 0x8e, 0xf0, 0x46, 0xbb, 0xbb, 0x8f, 0x05, 0xeb, 0xb4, 0xfe, 0xe3, 0xb1, 0x68, 0x9d, 0xd6,
		0x87, 0xdf, 0x16, 0x07, 0xff, 0x0c, 0xbf, 0x2f, 0x3d, 0x16, 0xac, 0xf2, 0xf8, 0xfb, 0xc3, 0xc7,
		0x82, 0x75, 0x58, 0xdf, 0xfb, 0xfc, 0xf9, 0xe3, 0xde, 0xf7, 0x83, 0x77, 0xf9, 0x0b, 0x77, 0xff,
		0xcf, 0xe3, 0xe7, 0xcf, 0xdd, 0xef, 0xd7, 0xef, 0xfd, 0xff, 0x5f, 0xbe, 0xd7, 0xff, 0x67, 0xef,
		0x5f, 0x79, 0xb6, 0xb7, 0xab, 0xf3, 0xec, 0x9b, 0x7e, 0xc8, 0xb0, 0x76, 0x1c, 0x41, 0x3b, 0xa4,
		0xb5, 0xe3, 0xec, 0x47, 0x5f, 0x86, 0x6d, 0xeb, 0xb9, 0x62, 0xfd, 0x54, 0xff, 0x5e, 0xf8, 0x50,
		0x7e, 0xdf, 0x3b, 0xdb, 0xdb, 0x9d, 0xff, 0xdd, 0xd9, 0xde, 0xf7, 0xc2, 0x87, 0xc3, 0xf7, 0xdd,
		0xdd, 0x05, 0x7f, 0xf9, 0xd7, 0xa2, 0x31, 0xf6, 0x7e, 0xec, 0xee, 0xee, 0x8e, 0xf4, 0x62, 0x46,
		0x57, 0x1e, 0x0b, 0xc5, 0xfa, 0xbf, 0x06, 0xdf, 0x0e, 0xff, 0x1f, 0x6a, 0x5b, 0xac, 0x0f, 0xef,
		0x2d, 0xd4, 0xb1, 0x0f, 0xec, 0x10, 0xf2, 0xe7, 0x59, 0xfd, 0x7f, 0xce, 0xf6, 0xbe, 0x1f, 0xbd,
		0x8f, 0xbf, 0x1f, 0xfc, 0x7f, 0xef, 0xc7, 0xee, 0xc7, 0x7f, 0x7e, 0xfe, 0xfc, 0xf1, 0xe3, 0x3f,
		0xf7, 0x86, 0x2f, 0x3c, 0xfa, 0xdc, 0x3f, 0x87, 0x7f, 0xfd, 0xd7, 0xd9, 0x59, 0xe4, 0x57, 0x7b,
		0xbb, 0xff, 0xe7, 0x63, 0x16, 0x61, 0x01, 0xe9, 0x14, 0x0a, 0x82, 0x83, 0xf2, 0x1c, 0x70, 0xf7,
		0xe0, 0xee, 0xc1, 0xdd, 0xcb, 0xb2, 0xbb, 0x87, 0x54, 0x65, 0x93, 0x64, 0x16, 0xa9, 0xca, 0xf2,
		0xf7, 0x41, 0xaa, 0x72, 0x6a, 0x97, 0x1e, 0xa9, 0xca, 0xe0, 0xd6, 0x4c, 0xdc, 0xfa, 0xab, 0xe3,
		0x05, 0x3d, 0xbb, 0x6d, 0x35, 0x1d, 0xaf, 0xd9, 0x73, 0x02, 0xcb, 0x69, 0x09, 0x37, 0x70, 0x9e,
		0x1d, 0xe1, 0xf1, 0xd1, 0xed, 0x15, 0xf7, 0x04, 0x03, 0x07, 0x03, 0x07, 0x03, 0x07, 0x03, 0x67,
		0x62, 0xe0, 0x07, 0x25, 0x46, 0x06, 0x7e, 0x0c, 0x06, 0x0e, 0x06, 0x0e, 0x06, 0xbe, 0x91, 0x0c,
		0xbc, 0x5c, 0x3a, 0x2d, 0x9f, 0x1e, 0x1d, 0x97, 0x4e, 0x41, 0xc3, 0x41, 0xc3, 0x49, 0x47, 0xc2,
		0x99, 0x8a, 0xf5, 0xe9, 0xf6, 0xc3, 0xa4, 0x2c, 0x34, 0xd5, 0x89, 0x4b, 0x75, 0xd0, 0x54, 0x27,
		0xcd, 0xbe, 0x12, 0x72, 0x64, 0x13, 0xf3, 0x85, 0x90, 0x23, 0x4b, 0xa1, 0x15, 0xc8, 0x91, 0x45,
		0xc8, 0x06, 0x21, 0x1b, 0x84, 0x6c, 0x90, 0x23, 0xbb, 0x6e, 0x6e, 0x90, 0x23, 0x1b, 0x73, 0x0d,
		0x90, 0x23, 0x8b, 0x1c, 0xd9, 0x4c, 0x69, 0x07, 0x72, 0x64, 0xe5, 0xb5, 0x03, 0x39, 0xb2, 0x71,
		0x20, 0x04, 0x39, 0xb2, 0x5b, 0x13, 0x40, 0x44, 0x8e, 0x2c, 0xdc, 0x3d, 0xb8, 0x7b, 0x70, 0xf7,
		0xe0, 0xee, 0x21, 0x47, 0xd6, 0x38, 0x99, 0xc5, 0x0e, 0xbd, 0xfc, 0x7d, 0xb0, 0x43, 0x9f, 0xda,
		0xa5, 0x47, 0x8e, 0x2c, 0xb8, 0x35, 0x13, 0xb7, 0x46, 0x8e, 0x2c, 0x18, 0x38, 0x18, 0x38, 0x18,
		0xf8, 0x76, 0x30, 0x70, 0xe4, 0xc8, 0x82, 0x81, 0x83, 0x81, 0x83, 0x81, 0x4b, 0x2f, 0x3d, 0x72,
		0x64, 0x41, 0xc3, 0x79, 0x46, 0x42, 0x8e, 0x6c, 0xec, 0x1c, 0x59, 0x14, 0x1e, 0xe7, 0x5a, 0xed,
		0x14, 0xad, 0x72, 0x82, 0x95, 0xc7, 0xef, 0x86, 0x0f, 0x90, 0xc1, 0xd2, 0xe3, 0x34, 0xb9, 0xd6,
		0xa4, 0x39, 0xd6, 0xe4, 0x85, 0xc7, 0x4b, 0x28, 0x3c, 0x9e, 0x12, 0x5f, 0x19, 0x85, 0xc7, 0xe5,
		0xde, 0x8a, 0xac, 0xf0, 0x78, 0x9f, 0x1a, 0x7e, 0x65, 0x38, 0x53, 0x31, 0x1a, 0x97, 0xf6, 0x50,
		0x45, 0x01, 0x85, 0xc7, 0x53, 0x1e, 0x54, 0xc3, 0xa1, 0x8a, 0x8c, 0x71, 0x7c, 0xf2, 0x20, 0x59,
		0x28, 0xb7, 0x4f, 0x9d, 0x4e, 0x5b, 0xd8, 0x2e, 0xa5, 0xd0, 0x8e, 0xed, 0x7f, 0x71, 0x83, 0xce,
		0xb4, 0x8d, 0xb9, 0x2a, 0x65, 0x36, 0x52, 0xb8, 0x06, 0xd3, 0x83, 0x03, 0x8a, 0x01, 0xc5, 0x80,
		0xe2, 0xad, 0x84, 0x62, 0x3f, 0xf0, 0x1c, 0xf7, 0x85, 0x03, 0x89, 0x4f, 0x36, 0x08, 0x89, 0xbb,
		0x9e, 0x68, 0x8a, 0x96, 0x70, 0x9b, 0x0c, 0x74, 0x78, 0x6a, 0x6c, 0xe0, 0x30, 0x70, 0x18, 0x38,
		0xbc, 0x95, 0x38, 0x4c, 0x9e, 0xb1, 0xc9, 0x90, 0xa9, 0xc9, 0xb4, 0x3f, 0xcc, 0xb0, 0x0b, 0xcf,
		0xb9, 0x1f, 0xcc, 0xbc, 0x19, 0xc8, 0xbd, 0xff, 0x6b, 0x62, 0xcf, 0x8f, 0x61, 0xbf, 0x97, 0x75,
		0x9f, 0xd7, 0xd4, 0x92, 0x32, 0x66, 0x56, 0x1a, 0x59, 0xd6, 0x94, 0x6e, 0x8d, 0xd6, 0x37, 0x88,
		0x69, 0x06, 0x94, 0x16, 0x26, 0xb4, 0x2e, 0x83, 0x51, 0xc1, 0x2e, 0xc1, 0x2e, 0xc1, 0x2e, 0xb7,
		0x92, 0x5d, 0x0e, 0x73, 0x9e, 0x83, 0x37, 0x4f, 0x3c, 0x73, 0xb8, 0xfa, 0x84, 0x36, 0x2d, 0x5f,
		0x1b, 0x3d, 0xea, 0x27, 0xdb, 0x17, 0x7c, 0x49, 0xe1, 0xd5, 0xeb, 0x8b, 0xdb, 0x9b, 0xda, 0xf5,
		0x43, 0xe3, 0xe1, 0x8f, 0xdb, 0x2a, 0xb5, 0x5a, 0x0c, 0xcc, 0xbd, 0xcf, 0x92, 0x47, 0xc9, 0xc4,
		0x7f, 0xc6, 0xd3, 0x72, 0x57, 0xbd, 0xba, 0x79, 0xa8, 0xe6, 0xb3, 0x40, 0x08, 0x99, 0x67, 0xe2,
		0xf2, 0xe6, 0xbc, 0x72, 0x99, 0xf6, 0xb4, 0xe8, 0x7a, 0xda, 0x80, 0x10, 0x79, 0x4e, 0x33, 0xe3,
		0xa5, 0x21, 0xcf, 0x89, 0x20, 0x8d, 0x4d, 0x23, 0xcb, 0x68, 0xc7, 0xe0, 0x32, 0xf6, 0xf9, 0x0e,
		0xcd, 0xce, 0x56, 0xfe, 0xd2, 0xf1, 0x83, 0x4a, 0x10, 0xe8, 0x25, 0x52, 0xe4, 0xaf, 0x1c, 0xb7,
		0xda, 0x16, 0x7d, 0xfe, 0xe2, 0xeb, 0xf1, 0xdb, 0xbe, 0xf3, 0x3b, 0x35, 0x52, 0xf1, 0xa4, 0x5c,
		0x3e, 0x3a, 0x2e, 0x97, 0x0b, 0xc7, 0x07, 0xc7, 0x85, 0xd3, 0xc3, 0xc3, 0xe2, 0x91, 0x8e, 0x05,
		0xce, 0xdf, 0x78, 0x2d, 0xe1, 0x89, 0xd6, 0xa7, 0xfe, 0xe4, 0xb9, 0xbd, 0x76, 0xdb, 0xe8, 0x9a,
		0x11, 0xa9, 0x5c, 0x1a, 0x54, 0x2d, 0xaf, 0x95, 0x52, 0xa7, 0x92, 0x43, 0xa8, 0xa6, 0xd6, 0xf2,
		0x4a, 0x29, 0x77, 0x85, 0xa4, 0x28, 0xe8, 0x8a, 0x40, 0x82, 0x4b, 0x2f, 0x37, 0xff, 0xf1, 0x67,
		0x51, 0x62, 0x06, 0x15, 0x93, 0x31, 0xb5, 0x92, 0x2f, 0x15, 0x93, 0x2d, 0x95, 0x93, 0x2b, 0x75,
		0x5c, 0x7a, 0x1a, 0xd7, 0x5d, 0xd7, 0x45, 0x27, 0x73, 0xc5, 0xc9, 0x5c, 0x6e, 0x32, 0xd7, 0x9a,
		0x17, 0x1b, 0x54, 0x93, 0x19, 0xf3, 0xf3, 0x4a, 0xab, 0x93, 0x43, 0x13, 0xca, 0xd0, 0xa2, 0x41,
		0x55, 0xb9, 0x8a, 0x56, 0x14, 0x4d, 0x3b, 0x6a, 0x46, 0x11, 0x25, 0xa3, 0x8d, 0x8a, 0x51, 0x45,
		0xc1, 0xc8, 0xa3, 0x5e, 0xe4, 0x51, 0x2e, 0xf2, 0xa8, 0x96, 0x59, 0x96, 0xad, 0x1d, 0xa5, 0xa2,
		0xcb, 0x3d, 0xd1, 0xcc, 0x35, 0x01, 0x11, 0xd2, 0x24, 0x42, 0x0a, 0xbe, 0xa5, 0x04, 0x09, 0xda,
		0x21, 0x9c, 0xe3, 0xb1, 0x6f, 0xa8, 0x8e, 0xe0, 0x6a, 0x3e, 0xa1, 0xba, 0x0f, 0x48, 0xea, 0xf3,
		0xa9, 0xf9, 0x78, 0x71, 0xe7, 0x56, 0x51, 0x6e, 0x8d, 0xcb, 0x6b, 0x5e, 0x8a, 0x56, 0x4b, 0x38,
		0x64, 0xf1, 0x54, 0x60, 0xbd, 0x40, 0xaf, 0xfe, 0xc4, 0x9a, 0xe5, 0x90, 0x5d, 0x06, 0xee, 0xe9,
		0x5f, 0x3d, 0x29, 0xcb, 0x5f, 0x75, 0xc5, 0x6b, 0xe6, 0x85, 0xdb, 0xb4, 0xbb, 0x7e, 0xaf, 0x1d,
		0xef, 0x2d, 0xa7, 0x72, 0x9d, 0xa7, 0x2f, 0x5b, 0x33, 0x8d, 0xf1, 0x9c, 0x9b, 0xd8, 0x0c, 0x4c,
		0x86, 0x69, 0xa9, 0x31, 0x2a, 0x59, 0xe6, 0xa4, 0xcc, 0x90, 0x94, 0x99, 0x90, 0x32, 0xe3, 0xd1,
		0x53, 0x88, 0xb8, 0xce, 0x43, 0xbe, 0x39, 0x5e, 0xcb, 0x98, 0x13, 0x38, 0xe5, 0x0f, 0xf4, 0xaf,
		0x8b, 0x6b, 0x82, 0xa4, 0xbc, 0x66, 0x69, 0x8a, 0xaf, 0x42, 0xe9, 0xf5, 0x28, 0xbc, 0x2a, 0x65,
		0xd7, 0xa6, 0xe8, 0xda, 0x94, 0x5c, 0x9b, 0x82, 0xd3, 0x92, 0x13, 0x59, 0x2f, 0xb7, 0x2f, 0x78,
		0x81, 0xd7, 0x69, 0x5b, 0xa3, 0x59, 0x54, 0x8c, 0xfd, 0xcc, 0x8c, 0xa2, 0x16, 0x02, 0x2a, 0xa8,
		0x86, 0x80, 0x0a, 0x08, 0x01, 0x21, 0x04, 0xc4, 0xeb, 0x6f, 0x12, 0x1c, 0x37, 0x53, 0x3c, 0x56,
		0xc6, 0x13, 0xe9, 0x9d, 0x61, 0x31, 0x96, 0x52, 0xa2, 0xd8, 0x62, 0x46, 0x64, 0x29, 0xa4, 0x87,
		0x01, 0x00, 0x00, 0x00, 0x99, 0x01, 0x00, 0xbd, 0xf4, 0x27, 0x9d, 0x34, 0x27, 0x9a, 0x74, 0xa6,
		0xa9, 0xb4, 0xa5, 0xf3, 0xca, 0xed, 0xfd, 0xaf, 0x97, 0x95, 0x87, 0xda, 0xcd, 0xb5, 0xaa, 0xf8,
		0x10, 0xa4, 0x27, 0x11, 0x55, 0xfe, 0xb8, 0xba, 0xbd, 0xbc, 0xcf, 0x27, 0x51, 0xc2, 0x84, 0xe8,
		0xf9, 0x7f, 0xfb, 0xfd, 0xb2, 0x72, 0x6d, 0x3a, 0x6e, 0x5b, 0xe7, 0x56, 0x4f, 0x16, 0xe3, 0xd5,
		0xb6, 0x9f, 0x44, 0xdb, 0xb2, 0xdb, 0xed, 0x4e, 0x73, 0x68, 0x73, 0x5e, 0x3b, 0x2d, 0x0d, 0xfb,
		0xb5, 0x78, 0x38, 0x98, 0x30, 0x98, 0x30, 0x98, 0xb0, 0x74, 0x9b, 0xb0, 0xcb, 0xca, 0xa7, 0xea,
		0x65, 0xa3, 0x72, 0x79, 0x79, 0x73, 0x3e, 0xb0, 0x62, 0x8d, 0xab, 0x9b, 0x8b, 0x6a, 0xf6, 0x4d,
		0xd9, 0x6d, 0xf5, 0xae, 0x71, 0x5d, 0xfd, 0xfd, 0xe1, 0x97, 0x9b, 0xdb, 0x2c, 0x5b, 0xb4, 0xfe,
		0x6b, 0xdc, 0xde, 0x55, 0x7f, 0xaa, 0xfd, 0x9e, 0xe5, 0xb7, 0xa8, 0x5d, 0xdf, 0x3f, 0x54, 0xae,
		0xcf, 0xab, 0x8d, 0x81, 0xb0, 0x6d, 0xb1, 0x81, 0xde, 0xc0, 0x6d, 0x9e, 0x19, 0xcf, 0x55, 0xaa,
		0x91, 0x79, 0x8c, 0xfd, 0x97, 0x18, 0xc1, 0x76, 0xb9, 0x7c, 0x2b, 0xa5, 0x3c, 0x2b, 0xe5, 0x48,
		0x71, 0x09, 0x91, 0x62, 0x6a, 0xa2, 0x81, 0x48, 0x31, 0x22, 0xc5, 0x60, 0xd9, 0x88, 0x14, 0xc7,
		0xc6, 0x6c, 0x44, 0x8a, 0x01, 0x00, 0x00, 0x00, 0xb8, 0xd9, 0x09, 0xbb, 0xd9, 0x88, 0x14, 0xa7,
		0xca, 0x23, 0x45, 0xa4, 0x38, 0xf6, 0x94, 0x21, 0x52, 0x0c, 0x13, 0x06, 0x13, 0x06, 0x13, 0x86,
		0x48, 0x71, 0xaa, 0x2d, 0x1a, 0x22, 0xc5, 0x1b, 0x65, 0xa0, 0x37, 0x3e, 0x52, 0x2c, 0x71, 0x56,
		0x65, 0xb3, 0x13, 0xf5, 0x65, 0x92, 0xe1, 0x73, 0xeb, 0x8f, 0x42, 0x54, 0x67, 0x86, 0x63, 0xc8,
		0xf9, 0x7f, 0x6e, 0x3d, 0xc5, 0xcf, 0xf4, 0xef, 0x7f, 0x18, 0xf9, 0xfd, 0xc8, 0xef, 0x9f, 0xfd,
		0x20, 0xf2, 0xfb, 0xb1, 0x6b, 0x93, 0xa9, 0x5d, 0x9b, 0x57, 0xbb, 0x69, 0xd9, 0x2f, 0x8e, 0xfb,
		0x62, 0x05, 0xce, 0xab, 0x86, 0xf3, 0x3b, 0x37, 0x0e, 0xbc, 0x5e, 0x78, 0xbd, 0x1b, 0xea, 0xf5,
		0x2a, 0xd7, 0xcf, 0xd6, 0xa8, 0x93, 0xad, 0x59, 0x0f, 0x5b, 0xaf, 0xb2, 0x14, 0x41, 0xa1, 0x04,
		0x92, 0x42, 0xae, 0x54, 0xf5, 0xaa, 0x29, 0x0b, 0x18, 0xbf, 0xeb, 0x95, 0xda, 0x4a, 0xdd, 0xd4,
		0x12, 0xd4, 0x8d, 0x26, 0x9d, 0x5e, 0x43, 0xd5, 0x16, 0xea, 0x29, 0x88, 0x46, 0xf7, 0x2d, 0x68,
		0x5b, 0xd8, 0x9e, 0xeb, 0xb8, 0x2f, 0x7a, 0x76, 0x38, 0x1c, 0x05, 0x56, 0x18, 0x56, 0x18, 0xf9,
		0x13, 0xcb, 0xbc, 0xa7, 0x62, 0x2a, 0x94, 0xfe, 0x9b, 0xf3, 0xda, 0x7b, 0xb5, 0x84, 0x1b, 0x78,
		0xce, 0x20, 0x6a, 0xac, 0xac, 0xf7, 0xb3, 0x03, 0x41, 0xf5, 0xa1, 0xfa, 0x20, 0xe0, 0x20, 0xe0,
		0x20, 0xe0, 0x20, 0xe0, 0xdb, 0x4c, 0xc0, 0x37, 0x70, 0xb7, 0xe9, 0xb9, 0xf5, 0x94, 0xc0, 0x69,
		0x84, 0xbe, 0x63, 0x11, 0xd8, 0x4f, 0x6d, 0x85, 0x13, 0x09, 0x93, 0x4b, 0x11, 0xdf, 0x46, 0x7c,
		0x5b, 0x4b, 0x03, 0xa5, 0xe3, 0xdb, 0xda, 0xc4, 0x5a, 0x8f, 0x50, 0x17, 0x41, 0xa8, 0x41, 0xa8,
		0x53, 0x5a, 0xb8, 0xb8, 0x2f, 0xd9, 0x6f, 0xfa, 0xc9, 0x53, 0xc3, 0x61, 0xf4, 0x8a, 0x13, 0x17,
		0x51, 0x9c, 0x98, 0x48, 0x8d, 0xc8, 0xd5, 0x89, 0x5c, 0xad, 0xc8, 0xd5, 0x4b, 0x93, 0xab, 0x2a,
		0x4a, 0x8e, 0xaa, 0xda, 0x85, 0x03, 0x48, 0xa6, 0x0a, 0xac, 0x15, 0x3f, 0xa9, 0x14, 0x02, 0x26,
		0x85, 0x24, 0x53, 0x4c, 0x4a, 0x05, 0xe5, 0x51, 0x54, 0x6a, 0x85, 0x65, 0x53, 0x5c, 0x36, 0x05,
		0x66, 0x53, 0x64, 0x3d, 0x85, 0x26, 0x88, 0x0c, 0x90, 0x28, 0xf8, 0x8c, 0xe7, 0x64, 0xb7, 0x5a,
		0x9e, 0xf0, 0x7d, 0xfa, 0x7e, 0x9b, 0xd3, 0x83, 0xa3, 0xed, 0x66, 0xba, 0xa0, 0x81, 0x0b, 0x22,
		0xd8, 0xa1, 0x82, 0x1d, 0x32, 0xd8, 0xa1, 0x83, 0x06, 0x42, 0x88, 0xa0, 0x24, 0x7c, 0x5b, 0xbe,
		0xb6, 0x9b, 0xf4, 0x30, 0x30, 0xc3, 0x06, 0x4e, 0x08, 0xc7, 0xbc, 0xb5, 0x83, 0x40, 0x78, 0x2e,
		0x79, 0xd3, 0xca, 0xfc, 0x63, 0xc1, 0x3a, 0xb5, 0xad, 0xe7, 0x8a, 0xf5, 0x53, 0xfd, 0x7b, 0xe9,
		0x7d, 0xf7, 0x6c, 0xf6, 0xe7, 0xbd, 0xef, 0x87, 0xef, 0x79, 0x34, 0x82, 0x5e, 0x30, 0x6f, 0x5f,
		0xdb, 0xb6, 0x4b, 0x6f, 0x98, 0x06, 0xa3, 0xc2, 0x22, 0xc1, 0x22, 0xc1, 0x22, 0x6d, 0xa5, 0x45,
		0x6a, 0x0b, 0xfb, 0x99, 0xa9, 0x09, 0xf4, 0x31, 0xad, 0x35, 0x1a, 0x6c, 0xca, 0x7c, 0xfc, 0xb8,
		0x3f, 0xf7, 0x5f, 0x1f, 0xc0, 0xfc, 0xc1, 0xff, 0x87, 0x27, 0x7a, 0x06, 0xdf, 0x5a, 0x4e, 0x2b,
		0x8f, 0x06, 0xb6, 0xa9, 0x6f, 0x60, 0xfb, 0xdc, 0x7a, 0xda, 0x0f, 0x77, 0x9d, 0xf6, 0x47, 0x21,
		0xfc, 0xc1, 0xbf, 0x6f, 0x52, 0x5b, 0x67, 0xf4, 0x73, 0xaf, 0xb3, 0x5f, 0xed, 0xb8, 0x81, 0xf0,
		0x9e, 0x6d, 0x8a, 0xe8, 0x60, 0x78, 0x84, 0x37, 0x1c, 0x12, 0x71, 0x23, 0xc4, 0x8d, 0x10, 0x37,
		0x4a, 0x53, 0xdc, 0x28, 0xd4, 0x4d, 0xab, 0x6f, 0x47, 0xc9, 0x09, 0xfa, 0xec, 0xf0, 0xb4, 0x4c,
		0xbd, 0xb8, 0xa5, 0x4c, 0xdd, 0x79, 0x06, 0x49, 0x4f, 0x80, 0xa4, 0x3b, 0xcf, 0x9b, 0xca, 0xcf,
		0xa9, 0xc0, 0x24, 0x1c, 0x90, 0x68, 0xd7, 0x69, 0xa9, 0x12, 0x90, 0xec, 0x42, 0x31, 0xc3, 0x0a,
		0x1b, 0xbc, 0x70, 0xc2, 0x0c, 0x3b, 0xdc, 0x70, 0xc3, 0x8e, 0x31, 0xf8, 0x31, 0x06, 0x43, 0x26,
		0xe0, 0x88, 0x16, 0x96, 0x88, 0xe1, 0x89, 0x0d, 0xa6, 0x18, 0x5c, 0x1e, 0x63, 0xae, 0xd0, 0x3a,
		0x10, 0x2b, 0x30, 0x0d, 0xcf, 0x05, 0x66, 0x26, 0x40, 0xcd, 0x18, 0xb8, 0x99, 0x02, 0x39, 0xe3,
		0x60, 0x67, 0x1c, 0xf4, 0x4c, 0x82, 0x1f, 0x0f, 0x08, 0x32, 0x81, 0x61, 0x38, 0x31, 0xe4, 0xb1,
		0xd5, 0xa5, 0xda, 0x42, 0x1f, 0x6b, 0x5d, 0xca, 0xc0, 0x8e, 0x19, 0xef, 0x71, 0x1b, 0x46, 0xff,
		0xfa, 0x62, 0x74, 0x16, 0x02, 0xb2, 0x3f, 0xff, 0x8b, 0xd1, 0xcf, 0x83, 0x42, 0x41, 0x3b, 0xd9,
		0x10, 0x34, 0x06, 0x21, 0xcb, 0xfb, 0xbd, 0x27, 0x83, 0xf6, 0x71, 0xe6, 0x6e, 0x30, 0x91, 0x30,
		0x91, 0x30, 0x91, 0x30, 0x91, 0x30, 0x91, 0x29, 0x35, 0x91, 0x8f, 0x13, 0x13, 0xf9, 0xbf, 0xcd,
		0x9e, 0xe7, 0x09, 0x37, 0xd8, 0xdd, 0xdb, 0xff, 0xf8, 0x71, 0x3f, 0xfc, 0x44, 0x7d, 0x74, 0xc9,
		0x34, 0xae, 0xfb, 0x0b, 0x7e, 0x17, 0x8e, 0xdc, 0x12, 0xdf, 0x32, 0x63, 0x6d, 0x53, 0xed, 0x2d,
		0x57, 0xbf, 0x05, 0x3e, 0x79, 0xfa, 0x53, 0x4e, 0xbb, 0x54, 0x69, 0x1c, 0x80, 0xee, 0x34, 0x2d,
		0xf1, 0x2d, 0x38, 0x0b, 0x44, 0x5b, 0xbc, 0x8a, 0xc0, 0x7b, 0xb3, 0x3a, 0xae, 0xd5, 0xfc, 0x32,
		0x38, 0x1b, 0x6d, 0x24, 0x88, 0xf3, 0x6c, 0xb7, 0x7d, 0x13, 0x51, 0x9c, 0xb4, 0x07, 0x70, 0xea,
		0xd4, 0x01, 0x75, 0xda, 0xed, 0xfc, 0x28, 0x55, 0x35, 0xb6, 0xbd, 0x3f, 0xc1, 0xad, 0x99, 0x0d,
		0x2e, 0x92, 0x6d, 0x7f, 0xbe, 0x35, 0x25, 0x84, 0x18, 0xc9, 0xbe, 0x61, 0xf2, 0x7e, 0x80, 0x44,
		0x7f, 0x31, 0x69, 0xdb, 0xc9, 0x15, 0xe0, 0x2f, 0x21, 0xc0, 0x6f, 0x8c, 0xd8, 0x23, 0xc0, 0xbf,
		0x79, 0x94, 0x05, 0x01, 0x7e, 0x44, 0x2f, 0x10, 0xbd, 0x40, 0xf4, 0x02, 0xd1, 0x0b, 0x44, 0x2f,
		0x0c, 0x44, 0x2f, 0x10, 0xe0, 0xcf, 0x21, 0xc0, 0x0f, 0x13, 0x09, 0x13, 0x09, 0x13, 0x09, 0x13,
		0x09, 0x13, 0x89, 0x00, 0x7f, 0xb6, 0xbc, 0xe5, 0xcd, 0x8f, 0xa6, 0x4a, 0xf4, 0xb8, 0x32, 0xbf,
		0xa4, 0xe9, 0x4a, 0xe1, 0x66, 0x12, 0x86, 0xe4, 0x85, 0x20, 0x4f, 0x1a, 0xb3, 0x5e, 0xd5, 0xf9,
		0xeb, 0xa7, 0xd6, 0x53, 0xe3, 0xca, 0x6e, 0x3e, 0xf4, 0x9f, 0xad, 0x51, 0xed, 0x3f, 0x53, 0xa3,
		0x36, 0x7e, 0x92, 0xc9, 0x77, 0x77, 0xe2, 0x19, 0x67, 0x33, 0xb3, 0x7d, 0x36, 0x93, 0xd2, 0xff,
		0xd0, 0x90, 0xa9, 0x2c, 0x1e, 0x0e, 0xa5, 0xac, 0x32, 0xc4, 0x50, 0x56, 0x84, 0xaa, 0x4e, 0x32,
		0x0e, 0x88, 0xa6, 0xce, 0x0d, 0xc3, 0x01, 0xd1, 0x84, 0x7c, 0x22, 0x06, 0xdf, 0x87, 0xd2, 0xc7,
		0x99, 0xae, 0xad, 0x30, 0xac, 0xa0, 0x30, 0x0d, 0x27, 0x19, 0x84, 0x58, 0x9a, 0x8d, 0x75, 0xd2,
		0x8d, 0x74, 0xf2, 0x73, 0xf7, 0x25, 0xc0, 0x2a, 0x60, 0x35, 0x93, 0xb0, 0x4a, 0x76, 0xee, 0xde,
		0x7e, 0x11, 0xf4, 0xa7, 0xed, 0x6d, 0xb2, 0x0c, 0x39, 0x54, 0xc3, 0x42, 0x35, 0x2c, 0x6e, 0x88,
		0x60, 0x87, 0x8a, 0x74, 0x86, 0x6a, 0xf8, 0xaa, 0x61, 0xf5, 0x1c, 0x37, 0x38, 0x2a, 0x33, 0x14,
		0xc3, 0xa2, 0xac, 0xcc, 0xa8, 0xd7, 0xe3, 0x68, 0xd9, 0x17, 0x43, 0xfc, 0x93, 0xa2, 0x27, 0x92,
		0x21, 0x78, 0x8d, 0x0c, 0x4f, 0xd4, 0x43, 0x69, 0xe9, 0xf8, 0x84, 0xcd, 0x7f, 0x98, 0xd5, 0x6d,
		0x76, 0x49, 0xed, 0x6f, 0x99, 0x5f, 0xd2, 0xe2, 0x49, 0xb9, 0x7c, 0x74, 0x5c, 0x2e, 0x17, 0x8e,
		0x0f, 0x8e, 0x0b, 0xa7, 0x87, 0x87, 0xc5, 0xa3, 0xe2, 0x61, 0x86, 0x57, 0x39, 0xa5, 0xd1, 0xfd,
		0x4d, 0x2a, 0xbd, 0x3a, 0x88, 0x7a, 0x5a, 0x01, 0xa5, 0xd9, 0x99, 0xed, 0xcb, 0x31, 0x1c, 0x1b,
		0xc4, 0x13, 0xc4, 0x13, 0xc4, 0x73, 0x2b, 0x89, 0xa7, 0x70, 0x7b, 0xaf, 0xc2, 0x1b, 0x6e, 0x06,
		0x31, 0x94, 0x62, 0x2d, 0x13, 0x8e, 0x59, 0x75, 0x7b, 0xaf, 0xfd, 0x49, 0x78, 0xdf, 0x20, 0x80,
		0x47, 0xef, 0x07, 0x40, 0x3c, 0x20, 0x1e, 0x10, 0x8f, 0xde, 0x0f, 0x39, 0xf4, 0x7e, 0x48, 0xa1,
		0x7d, 0x42, 0xef, 0x07, 0x58, 0x24, 0x58, 0x24, 0x58, 0x24, 0x5a, 0xb9, 0x45, 0xef, 0x07, 0x6e,
		0xe8, 0x47, 0x7e, 0xa1, 0x52, 0x7e, 0x21, 0x41, 0xda, 0x72, 0x32, 0xa9, 0x27, 0x24, 0x76, 0x9a,
		0xd2, 0x3e, 0x23, 0x9f, 0x2f, 0x69, 0xbb, 0x8b, 0xc4, 0x93, 0x94, 0xc0, 0xe1, 0xf6, 0xe6, 0xf3,
		0x0d, 0x70, 0x24, 0x29, 0x34, 0x35, 0xda, 0xed, 0xf9, 0xdf, 0xe2, 0x6d, 0xce, 0xd5, 0xce, 0x69,
		0x80, 0x68, 0xfe, 0xd2, 0xf1, 0x83, 0x4a, 0x10, 0x68, 0x76, 0x90, 0xbe, 0x72, 0xdc, 0x6a, 0x5b,
		0xf4, 0x15, 0xca, 0xd7, 0x03, 0xd0, 0xfc, 0x95, 0xfd, 0x6d, 0x6a, 0x24, 0xda, 0x7d, 0xcc, 0xfc,
		0x8d, 0xd7, 0x12, 0x9e, 0x68, 0x7d, 0xea, 0xcf, 0xa0, 0xdb, 0x6b, 0xb7, 0x8d, 0x2e, 0x1c, 0x11,
		0x57, 0x31, 0xc7, 0x51, 0xf2, 0x5a, 0x09, 0xaa, 0x72, 0x27, 0x1e, 0xd4, 0x74, 0x57, 0x5e, 0xf3,
		0xe4, 0xae, 0x90, 0x5c, 0x6a, 0xdd, 0x25, 0x36, 0xb1, 0xb4, 0x72, 0x13, 0x1d, 0x7f, 0xba, 0xe2,
		0x7d, 0x32, 0xe6, 0x84, 0xaa, 0x4e, 0x24, 0xe7, 0x04, 0x4a, 0x68, 0x83, 0x84, 0xf4, 0xc7, 0x5b,
		0x8e, 0xf5, 0x93, 0x1b, 0x63, 0x62, 0x25, 0x93, 0xc6, 0x95, 0x92, 0xc3, 0x25, 0x93, 0xc0, 0xa5,
		0x93, 0xbd, 0x55, 0xb8, 0xb5, 0x1e, 0x87, 0x56, 0xe5, 0xca, 0xda, 0x9c, 0x58, 0x9b, 0xfb, 0x6a,
		0x73, 0x5c, 0x5a, 0x95, 0x96, 0x4d, 0x8a, 0x1e, 0x32, 0x9c, 0x17, 0xc7, 0x7d, 0xb1, 0x02, 0xe7,
		0x55, 0x61, 0x01, 0x66, 0x36, 0x25, 0x26, 0xe3, 0x48, 0x4e, 0xa2, 0x9a, 0x73, 0xa9, 0xec, 0x4c,
		0xea, 0x38, 0x8f, 0x34, 0xce, 0xa2, 0xae, 0x73, 0x48, 0xe6, 0x0c, 0x92, 0x39, 0x7f, 0x64, 0xce,
		0x1e, 0x2f, 0x79, 0x50, 0x76, 0xde, 0x66, 0x52, 0x7b, 0x8b, 0x47, 0x2a, 0x6b, 0x3e, 0x92, 0xf2,
		0x23, 0x85, 0x4b, 0xf5, 0x52, 0x75, 0xf5, 0x7c, 0x0e, 0xfd, 0x38, 0x14, 0x51, 0xec, 0x88, 0x28,
		0x95, 0x96, 0x32, 0x99, 0xf2, 0x5d, 0xcf, 0x09, 0x4b, 0xdd, 0xd4, 0x1e, 0x1d, 0x1e, 0x1e, 0x1c,
		0xa6, 0x68, 0x7a, 0x0d, 0x39, 0x2c, 0x75, 0x2e, 0xbe, 0xfe, 0x41, 0xce, 0x12, 0xb7, 0x85, 0xed,
		0xb9, 0x8e, 0xfb, 0xa2, 0x67, 0x87, 0xc3, 0x51, 0x60, 0x85, 0x61, 0x85, 0x37, 0xd4, 0x0a, 0x3f,
		0x75, 0x3a, 0x6d, 0xa1, 0x14, 0x90, 0x0b, 0xbd, 0xa7, 0x62, 0x2a, 0x94, 0xfe, 0x9b, 0xf3, 0xda,
		0x7b, 0xb5, 0xc6, 0x71, 0x03, 0x0d, 0xbd, 0x9f, 0x1d, 0x08, 0xaa, 0x0f, 0xd5, 0x07, 0x01, 0x07,
		0x01, 0x07, 0x01, 0x07, 0x01, 0xdf, 0x66, 0x02, 0xbe, 0xa1, 0x01, 0x73, 0x89, 0xc4, 0x96, 0x18,
		0x61, 0xed, 0x1d, 0x8d, 0xc9, 0x91, 0x9d, 0x14, 0xfa, 0xc9, 0xc8, 0xc7, 0x8a, 0xca, 0xaf, 0xd9,
		0x2b, 0x58, 0x3d, 0x97, 0xcb, 0x67, 0x68, 0xc5, 0xec, 0x0c, 0x1b, 0x10, 0x84, 0x8f, 0x6a, 0x75,
		0x3b, 0x6d, 0xa7, 0x19, 0x87, 0xe4, 0xcd, 0x76, 0x30, 0x58, 0x30, 0xc0, 0x9a, 0x15, 0x89, 0xb7,
		0x3d, 0x10, 0x9b, 0xbc, 0xc9, 0x90, 0x35, 0x35, 0x72, 0x26, 0x4b, 0xc6, 0x94, 0xc9, 0x97, 0x32,
		0xd9, 0x52, 0x26, 0x57, 0x7a, 0xba, 0x15, 0x37, 0x9c, 0x9f, 0xb7, 0xbb, 0xdd, 0xf6, 0xdb, 0x50,
		0x40, 0xde, 0xe4, 0x37, 0x9f, 0x66, 0xae, 0x66, 0xde, 0x83, 0x2a, 0x98, 0xd9, 0x83, 0xf2, 0xba,
		0x9d, 0xf6, 0x56, 0x6e, 0x40, 0x0d, 0x5e, 0x3c, 0x2b, 0xbb, 0x4f, 0xcd, 0xb1, 0x54, 0x28, 0x7a,
		0xbd, 0xa3, 0xeb, 0xd5, 0x9c, 0xdd, 0x62, 0xc6, 0x9c, 0x5d, 0x49, 0x91, 0xde, 0x1e, 0x4f, 0x57,
		0x4e, 0xe4, 0xcd, 0xb8, 0xb9, 0xaa, 0xd5, 0xa9, 0xf2, 0x2d, 0xf1, 0x6c, 0xf7, 0xda, 0x81, 0x25,
		0xbe, 0x75, 0x3b, 0x5e, 0x20, 0x0b, 0xe9, 0x4b, 0xe5, 0x67, 0xf1, 0xb0, 0x8a, 0xf3, 0x7f, 0x31,
		0x1c, 0xac, 0x3f, 0xee, 0x5d, 0xf5, 0xff, 0x57, 0x3d, 0x7f, 0x68, 0xdc, 0xdd, 0xfc, 0xfa, 0x50,
		0x55, 0x1d, 0x4e, 0xcf, 0x85, 0xd2, 0x4e, 0x29, 0xa6, 0x48, 0x25, 0x26, 0xd0, 0x53, 0x2a, 0x7d,
		0x25, 0xd7, 0x5b, 0x72, 0xfd, 0xa5, 0xd5, 0x63, 0x4d, 0x57, 0x55, 0x51, 0x66, 0xb4, 0x93, 0x80,
		0x23, 0x9a, 0x39, 0x54, 0x49, 0xdd, 0x02, 0x1e, 0x14, 0x27, 0xf5, 0x35, 0x4f, 0xe6, 0x2b, 0xe4,
		0x0b, 0x7e, 0x50, 0xc7, 0x49, 0xe7, 0x95, 0x05, 0x27, 0x67, 0x87, 0x05, 0x4e, 0x02, 0x27, 0x81,
		0x93, 0xc0, 0xc9, 0x0c, 0xe2, 0x24, 0x31, 0x8f, 0x24, 0xe1, 0x8f, 0x00, 0x32, 0x00, 0xd9, 0xf6,
		0x02, 0x99, 0xfe, 0x69, 0x2f, 0x8a, 0x53, 0x5e, 0x33, 0x9d, 0xa7, 0xfa, 0x0b, 0x71, 0xe6, 0x75,
		0x7a, 0x81, 0xe3, 0xbe, 0x8c, 0x74, 0x3b, 0xfc, 0xf5, 0x08, 0x6f, 0x5b, 0xe2, 0xd9, 0x71, 0x9d,
		0xc0, 0xe9, 0xb8, 0xfe, 0xf2, 0x3f, 0x85, 0x7f, 0x51, 0xef, 0xe4, 0xf8, 0x8e, 0x23, 0x56, 0xeb,
		0x07, 0x9f, 0x3e, 0x62, 0x45, 0x74, 0x46, 0xb8, 0xe7, 0x0b, 0x4f, 0x17, 0x2f, 0x08, 0x4f, 0xbc,
		0x4e, 0x83, 0x59, 0x67, 0xf8, 0xb6, 0xd6, 0xd3, 0x1b, 0xc5, 0x09, 0x49, 0x8e, 0xd3, 0xae, 0x33,
		0xc0, 0x36, 0x98, 0xc9, 0x6c, 0x9d, 0x92, 0x34, 0xc2, 0x44, 0x88, 0x3d, 0x35, 0x12, 0x0f, 0x0d,
		0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x04, 0x4c, 0x24, 0x93, 0x4c,
		0x64, 0x8b, 0xce, 0x9a, 0x2f, 0xc9, 0x07, 0xda, 0x9f, 0xce, 0xdf, 0xd8, 0x1f, 0xed, 0x89, 0xa7,
		0x20, 0xb9, 0x5d, 0xad, 0x7f, 0x96, 0x56, 0xbf, 0x2c, 0xed, 0xbd, 0xfd, 0x12, 0xf6, 0xf6, 0x13,
		0xc5, 0x32, 0xec, 0xed, 0xcb, 0xcb, 0x0f, 0xf6, 0xf6, 0xe1, 0x60, 0xc1, 0xc1, 0x4a, 0xa3, 0x83,
		0x85, 0x3d, 0x2b, 0xec, 0xed, 0x03, 0x27, 0x81, 0x93, 0xc0, 0x49, 0xe0, 0x24, 0x03, 0x4e, 0x62,
		0x6f, 0x1f, 0x40, 0x06, 0x20, 0x4b, 0x13, 0x90, 0x21, 0xa2, 0xce, 0xb1, 0x3e, 0x88, 0xa8, 0xeb,
		0x49, 0x25, 0x22, 0xea, 0x54, 0xc0, 0x86, 0xbd, 0xfd, 0xc5, 0x73, 0x84, 0xbd, 0x7d, 0x30, 0x11,
		0x30, 0x11, 0x30, 0x11, 0x30, 0x11, 0x30, 0x11, 0x30, 0x11, 0x30, 0x11, 0x22, 0x26, 0x82, 0xbd,
		0xfd, 0xd9, 0xbd, 0x7d, 0x85, 0x7e, 0x46, 0xdb, 0x5d, 0x2b, 0x27, 0xce, 0xac, 0xd2, 0xd5, 0x9c,
		0xaf, 0xf5, 0xef, 0x36, 0xfe, 0xe9, 0x76, 0x74, 0xaf, 0x46, 0xa5, 0x7f, 0xaf, 0xdb, 0xe1, 0xad,
		0x50, 0xb1, 0x67, 0x5f, 0xad, 0xa8, 0x8d, 0xea, 0xec, 0xb3, 0xd5, 0xf5, 0x79, 0xb6, 0x9b, 0xd2,
		0xa5, 0x7c, 0x86, 0xd7, 0xa0, 0x7a, 0x0f, 0xaa, 0xf7, 0x2c, 0x11, 0x28, 0xf9, 0xd2, 0x3d, 0x93,
		0x4b, 0x37, 0xa3, 0x6e, 0x0f, 0x7a, 0x47, 0x04, 0xa8, 0xde, 0x43, 0x28, 0xc0, 0xda, 0xe1, 0x1c,
		0x94, 0xaa, 0xa5, 0x77, 0x6a, 0x32, 0x52, 0xaa, 0x56, 0x39, 0xcf, 0xcf, 0xf6, 0xfd, 0x4e, 0xd3,
		0xb1, 0x03, 0xd1, 0x1a, 0x77, 0x8f, 0xb3, 0x9e, 0xed, 0x57, 0xa7, 0xad, 0x52, 0xe1, 0x39, 0x22,
		0x4b, 0xab, 0x06, 0x47, 0xa4, 0x94, 0xa6, 0x87, 0xe7, 0xf6, 0x06, 0x4b, 0xb5, 0x7b, 0x74, 0x66,
		0x35, 0x5e, 0xea, 0xb4, 0x84, 0x1b, 0x38, 0xc1, 0x1b, 0x51, 0xcc, 0x54, 0x27, 0xee, 0x56, 0x1b,
		0x3d, 0xca, 0x27, 0xdb, 0x17, 0x74, 0xa1, 0xb7, 0xca, 0xc5, 0xc5, 0x5d, 0xf5, 0xfe, 0xbe, 0xf1,
		0x53, 0xe5, 0xaa, 0x76, 0xf9, 0x47, 0x9e, 0xa2, 0x5e, 0xb1, 0xaf, 0x5c, 0x10, 0x7b, 0xfa, 0x8b,
		0xa8, 0x3d, 0xee, 0xf8, 0x3d, 0x2f, 0x4b, 0x8d, 0xea, 0xc3, 0x2f, 0xd5, 0xbb, 0xeb, 0xea, 0x03,
		0x41, 0xa7, 0xd9, 0x0f, 0x69, 0x7b, 0xbd, 0xab, 0xdb, 0xcb, 0xfb, 0x4d, 0x7c, 0xaf, 0xda, 0xed,
		0x6f, 0x47, 0x1b, 0xfa, 0x5e, 0xe5, 0xa4, 0x3b, 0x1e, 0xd7, 0x33, 0x82, 0xe6, 0x68, 0x93, 0x6b,
		0x20, 0xa6, 0xae, 0xb2, 0xbb, 0xdf, 0x22, 0xd8, 0xd2, 0x6f, 0x81, 0x9d, 0x82, 0x9d, 0x82, 0x9d,
		0xaa, 0xc9, 0x8d, 0x1f, 0x78, 0xf2, 0x0d, 0xbd, 0x16, 0x12, 0xd3, 0x93, 0x34, 0xe3, 0x8c, 0x74,
		0x1c, 0x94, 0x2c, 0x2e, 0xba, 0xe9, 0xa8, 0xe3, 0x3c, 0x03, 0x70, 0x14, 0x00, 0xc7, 0x79, 0x46,
		0xe6, 0x90, 0x06, 0xd8, 0x50, 0x65, 0x0e, 0x39, 0xcf, 0x67, 0x93, 0x0d, 0xb4, 0xf9, 0x5f, 0x8c,
		0x7e, 0xd6, 0x48, 0x06, 0x32, 0x02, 0x6e, 0x7e, 0xef, 0x89, 0x10, 0xdf, 0x66, 0x46, 0x03, 0xc4,
		0x01, 0xe2, 0x00, 0x71, 0x1b, 0x0c, 0x71, 0x8f, 0x13, 0x88, 0xfb, 0xdf, 0x66, 0xcf, 0xf3, 0x84,
		0x1b, 0xec, 0xee, 0xed, 0x7f, 0xfc, 0xb8, 0x1f, 0x7e, 0xa2, 0x3e, 0xba, 0x64, 0x1a, 0x17, 0xfc,
		0x05, 0xbf, 0x0b, 0x47, 0x6e, 0x89, 0x6f, 0x79, 0xa4, 0x71, 0xf1, 0x64, 0xb7, 0x0c, 0x27, 0x7f,
		0x32, 0xe7, 0xe9, 0x29, 0xc9, 0xa2, 0xe0, 0xc9, 0xab, 0x7b, 0xf0, 0xe8, 0x2a, 0x9a, 0x98, 0xf5,
		0x40, 0x57, 0x51, 0x73, 0x26, 0x41, 0xc7, 0x14, 0x84, 0x26, 0xe0, 0xe3, 0xc7, 0x61, 0x72, 0xe7,
		0xbe, 0xd3, 0x42, 0xe9, 0x26, 0x35, 0xb4, 0x28, 0x01, 0x2d, 0x80, 0x16, 0xb1, 0x9e, 0x12, 0x89,
		0x1d, 0xd9, 0xf4, 0xf0, 0x10, 0x3a, 0x4f, 0x40, 0x15, 0xb3, 0xee, 0xeb, 0x21, 0xb1, 0x43, 0x6a,
		0x54, 0x24, 0x76, 0x24, 0xf4, 0x7a, 0x48, 0xec, 0xc8, 0xdc, 0x7b, 0x21, 0xb1, 0x23, 0xe6, 0x9c,
		0x21, 0xb1, 0xc3, 0x40, 0x94, 0x0d, 0x89, 0x1d, 0x60, 0xa7, 0x60, 0xa7, 0x19, 0x63, 0xa7, 0x48,
		0xec, 0x90, 0x85, 0x1b, 0xec, 0x7a, 0x62, 0xd7, 0x53, 0x1f, 0x70, 0xb0, 0xeb, 0xa9, 0x05, 0x36,
		0x48, 0xec, 0x98, 0xbc, 0x0f, 0x12, 0x3b, 0x00, 0x71, 0x80, 0x38, 0x40, 0x9c, 0x0a, 0xc4, 0x21,
		0xb1, 0x63, 0x85, 0x38, 0xa7, 0x3f, 0xb1, 0x23, 0x43, 0xf5, 0x78, 0xfe, 0x2d, 0xde, 0xa4, 0xbc,
		0x75, 0xb5, 0x98, 0x8d, 0x7a, 0x8c, 0x86, 0x34, 0x26, 0xa3, 0x16, 0x83, 0xc9, 0x60, 0x69, 0xa3,
		0x39, 0x81, 0x24, 0x2e, 0x65, 0x34, 0x18, 0x12, 0x25, 0x8b, 0xa6, 0xa6, 0x9a, 0xa3, 0x9c, 0xd0,
		0x6b, 0xb7, 0x2d, 0x51, 0x48, 0x68, 0xf0, 0xe9, 0x6c, 0x94, 0x10, 0x8a, 0xf1, 0xa8, 0xb9, 0x4c,
		0xd6, 0x0f, 0x1a, 0xbc, 0x58, 0x5a, 0x8a, 0x07, 0xbd, 0xb4, 0x3b, 0x4f, 0x76, 0x5b, 0xbe, 0x72,
		0xd0, 0xe8, 0xba, 0xcd, 0x28, 0x1b, 0x14, 0x53, 0xd4, 0x74, 0x9d, 0x82, 0xf4, 0xd5, 0x0c, 0x8a,
		0x27, 0x8a, 0x3c, 0x94, 0x02, 0x05, 0x83, 0xa8, 0xbd, 0x5f, 0x0d, 0x91, 0xa6, 0xf2, 0x77, 0xd3,
		0x9f, 0x54, 0x26, 0x27, 0xf2, 0x66, 0x7c, 0x15, 0xe5, 0x8c, 0xb2, 0x3e, 0x39, 0xb5, 0xda, 0xf6,
		0x93, 0x68, 0xeb, 0x87, 0x8e, 0xa6, 0xc6, 0xd2, 0x6f, 0x6a, 0x35, 0x9a, 0xe8, 0xe0, 0xac, 0x76,
		0x75, 0x7b, 0x59, 0x3b, 0xaf, 0x3d, 0x20, 0x18, 0xa5, 0xa3, 0x96, 0x08, 0x47, 0xa9, 0xa9, 0x6d,
		0xd6, 0x03, 0x52, 0x1b, 0x9f, 0x7d, 0x76, 0xfd, 0xeb, 0xe5, 0x65, 0xe3, 0xb2, 0xf2, 0xa9, 0x7a,
		0xd9, 0x78, 0xf8, 0xe3, 0xb6, 0xba, 0xb9, 0xe9, 0x67, 0xd5, 0xdf, 0x47, 0x38, 0xb8, 0x89, 0xb9,
		0x4c, 0x57, 0x64, 0xef, 0x96, 0xad, 0x7c, 0x26, 0x23, 0x1b, 0x44, 0xdd, 0xbf, 0x2d, 0xe1, 0x36,
		0xed, 0xae, 0xdf, 0x6b, 0xab, 0x87, 0x33, 0x67, 0xd6, 0x2b, 0x32, 0x22, 0x6c, 0x33, 0x6c, 0x33,
		0x6c, 0x33, 0x6c, 0xf3, 0xec, 0x0b, 0xde, 0xde, 0x57, 0x7f, 0xbd, 0xb8, 0xf9, 0x4f, 0xed, 0xae,
		0xda, 0xa8, 0x5e, 0x9f, 0x57, 0x6e, 0xef, 0x7f, 0xbd, 0xac, 0x3c, 0xd4, 0x6e, 0xae, 0x37, 0xd7,
		0x48, 0xdf, 0xfe, 0xa7, 0x1a, 0x26, 0x89, 0x37, 0xee, 0x2a, 0xff, 0x69, 0x5c, 0xdd, 0x5c, 0x54,
		0x37, 0xd1, 0x62, 0xcf, 0xbc, 0xe8, 0x43, 0xe5, 0xe7, 0x9f, 0xab, 0x17, 0x54, 0xef, 0x0a, 0x0b,
		0x1e, 0x99, 0xf5, 0x20, 0x68, 0x5b, 0x5d, 0xaf, 0xd3, 0xb5, 0x5f, 0x88, 0x0c, 0xf8, 0xfc, 0x80,
		0xfa, 0xfe, 0x7a, 0xdf, 0x28, 0x80, 0x06, 0x80, 0x06, 0x80, 0x06, 0xc8, 0x4a, 0xcc, 0x53, 0xa7,
		0xd3, 0x16, 0xb6, 0x4b, 0x41, 0x01, 0x8a, 0x48, 0xbc, 0x20, 0xdf, 0x7c, 0xed, 0x0b, 0xe5, 0xfe,
		0x70, 0xb3, 0x2a, 0x4d, 0x85, 0x34, 0xc6, 0x5b, 0xc2, 0x96, 0x1d, 0x04, 0x9e, 0xf3, 0xd4, 0x0b,
		0x14, 0x8e, 0x00, 0x47, 0x93, 0x9a, 0xa7, 0x47, 0xc3, 0x36, 0x07, 0x23, 0x48, 0x63, 0x9b, 0x23,
		0x67, 0x72, 0x9b, 0x23, 0x85, 0x07, 0x00, 0x8a, 0x60, 0x3b, 0x60, 0x3b, 0x59, 0x61, 0x3b, 0xaa,
		0x8a, 0x17, 0x0e, 0xa0, 0xb8, 0xf5, 0xbe, 0x54, 0xf0, 0x94, 0xb6, 0xe2, 0x89, 0x55, 0x91, 0x4c,
		0x25, 0x29, 0x55, 0x93, 0x41, 0x45, 0xa9, 0x55, 0x95, 0x4d, 0x65, 0xd9, 0x54, 0x97, 0x47, 0x85,
		0x69, 0x22, 0x1e, 0x9a, 0xb1, 0x21, 0x6d, 0xd5, 0x5e, 0x40, 0x49, 0x35, 0x8e, 0xf5, 0xc6, 0xa0,
		0xa8, 0xca, 0x07, 0x7e, 0x89, 0xe3, 0x0e, 0x6c, 0x30, 0xc0, 0x01, 0x07, 0x8c, 0xb0, 0xc0, 0x05,
		0x0f, 0xec, 0x30, 0xc1, 0x0e, 0x17, 0xbc, 0xb0, 0x41, 0x03, 0x1f, 0x44, 0x30, 0x42, 0x17, 0x17,
		0x31, 0x89, 0x00, 0x39, 0xfd, 0x03, 0xcc, 0xf4, 0xab, 0x41, 0xb0, 0x12, 0x83, 0x2c, 0x6d, 0x4b,
		0xb8, 0xf6, 0x53, 0x5b, 0x30, 0x60, 0xf1, 0xcc, 0xe8, 0x44, 0x72, 0x33, 0x15, 0x4a, 0x7e, 0xb6,
		0xdb, 0xbe, 0x00, 0xc6, 0x03, 0xe3, 0x81, 0xf1, 0xdb, 0x86, 0xf1, 0xfa, 0xb1, 0xf0, 0xa5, 0xf0,
		0x5e, 0x4c, 0x0b, 0xbc, 0x27, 0xca, 0xf6, 0x35, 0x63, 0xeb, 0x91, 0xf1, 0xf8, 0x62, 0xed, 0x8b,
		0x62, 0xd2, 0x9a, 0x35, 0xad, 0xe9, 0x96, 0x42, 0x63, 0x19, 0x68, 0xfd, 0x24, 0x0e, 0x76, 0x44,
		0x64, 0x33, 0x11, 0x16, 0x41, 0x58, 0x24, 0xbb, 0x40, 0x49, 0x66, 0xe3, 0x08, 0x6b, 0x03, 0x44,
		0x6c, 0xda, 0x31, 0xc1, 0x58, 0xd1, 0x0a, 0xe0, 0xd3, 0x48, 0x92, 0x69, 0x7c, 0xed, 0xcf, 0x36,
		0x03, 0xc0, 0xea, 0x2f, 0xe2, 0xb6, 0x04, 0x9e, 0x9d, 0x67, 0xe0, 0x2b, 0x03, 0xbe, 0xea, 0x54,
		0x56, 0x49, 0x07, 0xba, 0x92, 0x05, 0x9d, 0x89, 0xf6, 0x95, 0x22, 0xc2, 0x4b, 0xb2, 0xbf, 0x44,
		0xac, 0xee, 0x99, 0x0d, 0x42, 0x90, 0xc0, 0x00, 0x42, 0x10, 0x49, 0xc0, 0x44, 0x3a, 0x03, 0x10,
		0x54, 0xf0, 0x11, 0xe5, 0x0c, 0xf4, 0x62, 0x45, 0x95, 0x37, 0xc2, 0xec, 0xad, 0xb1, 0x83, 0x0c,
		0x27, 0xd8, 0xb0, 0x83, 0x0e, 0x37, 0xf8, 0x18, 0x03, 0x21, 0x63, 0x60, 0x64, 0x02, 0x94, 0x68,
		0xc1, 0x89, 0x18, 0xa4, 0xe8, 0x3d, 0x49, 0x03, 0x9e, 0x25, 0xa7, 0xa7, 0xb9, 0xd4, 0xf3, 0xe4,
		0x2f, 0xc4, 0xc9, 0x2f, 0x38, 0x84, 0x42, 0x43, 0x53, 0xd0, 0x73, 0xad, 0xd0, 0x10, 0x14, 0xfa,
		0x84, 0x49, 0x82, 0x49, 0x82, 0x49, 0x82, 0x49, 0xda, 0x42, 0x93, 0x94, 0xa6, 0xc2, 0xa9, 0x06,
		0xac, 0x5b, 0xaa, 0xbc, 0xbf, 0xea, 0xb7, 0x80, 0xe6, 0xf0, 0xef, 0xf8, 0x8b, 0x2f, 0x90, 0xd0,
		0x69, 0x5a, 0xe2, 0x5b, 0x70, 0x16, 0x88, 0xb6, 0x78, 0x15, 0x81, 0xf7, 0x66, 0x75, 0x5c, 0xab,
		0xf9, 0xc5, 0x76, 0x5f, 0x04, 0x6f, 0x70, 0x61, 0x90, 0x42, 0xc3, 0x18, 0x5d, 0x48, 0x5b, 0x60,
		0xa1, 0x4e, 0x15, 0x68, 0xa5, 0xdd, 0x1e, 0x9f, 0x50, 0xba, 0xa4, 0xb6, 0xc9, 0x67, 0x76, 0x2d,
		0x48, 0x36, 0xcd, 0xe9, 0x16, 0x8e, 0x22, 0xd1, 0x4d, 0xad, 0x51, 0xec, 0x7a, 0x72, 0xac, 0xd0,
		0x40, 0x76, 0xad, 0xc1, 0xa2, 0x8e, 0xfe, 0x96, 0x10, 0xfd, 0xcd, 0x0e, 0xcb, 0x45, 0xf4, 0x17,
		0xd1, 0x5f, 0xb8, 0xda, 0x70, 0xb5, 0xe1, 0x6a, 0xc3, 0xd5, 0x86, 0xab, 0x8d, 0xe8, 0xef, 0x72,
		0x46, 0x8b, 0xe8, 0x2f, 0x4c, 0x12, 0x4c, 0x12, 0x4c, 0x12, 0x4c, 0x52, 0x6a, 0x4d, 0x12, 0xa2,
		0xbf, 0xc9, 0x79, 0x7f, 0x1b, 0x1e, 0xa2, 0x53, 0x68, 0xe9, 0xc5, 0x18, 0xa1, 0xc3, 0x59, 0x25,
		0xf2, 0x15, 0xce, 0x93, 0x44, 0x3d, 0x57, 0xf5, 0xce, 0xba, 0xea, 0xb6, 0xfd, 0xc6, 0xcf, 0x83,
		0x27, 0x9b, 0xf4, 0xd1, 0x9a, 0x7c, 0x77, 0x27, 0x9e, 0xb3, 0x98, 0xd6, 0x4f, 0x13, 0xe9, 0x25,
		0x8d, 0xf0, 0x92, 0xa7, 0xf1, 0x97, 0x70, 0x50, 0x2a, 0x0d, 0xdc, 0x14, 0x07, 0xa5, 0x24, 0x5e,
		0x09, 0xf5, 0x63, 0x50, 0x5b, 0x20, 0xd5, 0xae, 0x2c, 0x6a, 0x0b, 0x64, 0x89, 0xde, 0xa3, 0x7e,
		0x4c, 0x0a, 0x56, 0x02, 0xf5, 0x63, 0x80, 0xf1, 0xc0, 0x78, 0x60, 0x7c, 0xe6, 0x30, 0x1e, 0xf5,
		0x63, 0x10, 0x93, 0x89, 0x17, 0x93, 0x21, 0x88, 0xb3, 0xbd, 0x67, 0xa4, 0x78, 0xef, 0xb8, 0xf5,
		0xbe, 0x3e, 0xff, 0x51, 0x6b, 0xca, 0x1f, 0x19, 0x45, 0xb9, 0x49, 0x7f, 0x74, 0x24, 0xc2, 0xa6,
		0xfd, 0x91, 0xc1, 0x95, 0x9a, 0xf8, 0x53, 0x2d, 0x1a, 0x91, 0xa2, 0x25, 0xa6, 0x60, 0x79, 0xad,
		0x50, 0x9f, 0x74, 0x78, 0x33, 0x8f, 0xce, 0x17, 0xc6, 0x17, 0x3b, 0x0d, 0x7d, 0x30, 0x3c, 0xe1,
		0x0b, 0xef, 0xab, 0x68, 0x0d, 0xfb, 0x0e, 0x5b, 0x4f, 0xed, 0x4e, 0xf3, 0x2f, 0x8d, 0x46, 0x18,
		0x8b, 0x87, 0x43, 0x27, 0x0c, 0x46, 0x4a, 0x8f, 0x4e, 0x18, 0x39, 0x93, 0x9d, 0x30, 0x16, 0x49,
		0xb8, 0x7e, 0x53, 0x8c, 0x85, 0xa3, 0xa2, 0x3f, 0x06, 0xfa, 0x63, 0x24, 0xe6, 0x01, 0xa3, 0x3f,
		0x06, 0xfa, 0x63, 0x18, 0x0e, 0x72, 0x61, 0x7f, 0x13, 0xfb, 0x9b, 0x2b, 0x06, 0x6a, 0x77, 0x9a,
		0x76, 0x9b, 0x65, 0x6f, 0x33, 0x1c, 0x19, 0x31, 0xef, 0x14, 0xc1, 0x01, 0x17, 0x2c, 0xb0, 0xc3,
		0x03, 0x3b, 0x4c, 0xf0, 0xc2, 0x05, 0x5d, 0xa8, 0x35, 0x97, 0x89, 0x98, 0xb7, 0x1f, 0x78, 0x8e,
		0xfb, 0x82, 0x1d, 0xcd, 0x75, 0xe8, 0xfb, 0xb7, 0xf0, 0xac, 0xa7, 0x4e, 0xcf, 0x65, 0x01, 0xe0,
		0xc9, 0xe0, 0xc0, 0x60, 0x60, 0x30, 0x30, 0x78, 0xcb, 0x30, 0x78, 0x90, 0xd1, 0x30, 0x88, 0x7d,
		0x70, 0xe0, 0xf0, 0x29, 0xe1, 0x98, 0xa3, 0x39, 0x78, 0x24, 0x15, 0x22, 0xc6, 0xa3, 0x24, 0x3d,
		0xc7, 0x0d, 0x0e, 0x4a, 0x8c, 0x27, 0x49, 0x38, 0x0e, 0x92, 0xdc, 0x0d, 0x2a, 0xbc, 0x50, 0xcf,
		0x32, 0xdf, 0x6c, 0x87, 0x0f, 0x7e, 0xe5, 0xb8, 0x6c, 0x47, 0xc9, 0x98, 0x4c, 0xdb, 0xd2, 0xdb,
		0xfc, 0x66, 0xb7, 0x7b, 0xfd, 0x45, 0x28, 0x1e, 0x31, 0xdf, 0xe8, 0x27, 0xcf, 0x6e, 0x06, 0x4e,
		0xc7, 0xbd, 0x70, 0x5e, 0x9c, 0xe1, 0x8e, 0x26, 0xdb, 0xfd, 0xde, 0x3f, 0x30, 0xae, 0xbd, 0xfd,
		0x6d, 0xf3, 0xd6, 0xbe, 0x50, 0x3e, 0x39, 0x3c, 0x3e, 0xdc, 0x20, 0x01, 0xd8, 0xc9, 0xc6, 0xa8,
		0xf5, 0x34, 0x9f, 0x80, 0x64, 0x34, 0x57, 0xc2, 0xed, 0xbd, 0x0a, 0x6f, 0xb8, 0x85, 0xcb, 0x78,
		0xfa, 0xb1, 0xcc, 0x30, 0x76, 0xd5, 0xed, 0xbd, 0xf6, 0x01, 0xe0, 0x3d, 0xa5, 0xc7, 0x10, 0xeb,
		0x1b, 0xe4, 0x8d, 0xf6, 0xba, 0x5d, 0x3e, 0x6f, 0x74, 0x7a, 0x70, 0x78, 0xa3, 0xf0, 0x46, 0xe1,
		0x8d, 0xc2, 0x1b, 0x85, 0x37, 0x0a, 0x6f, 0x14, 0xde, 0x28, 0xbc, 0x51, 0x78, 0xa3, 0xf0, 0x46,
		0xe1, 0x8d, 0xc2, 0x1b, 0x85, 0x37, 0xba, 0x29, 0xde, 0x28, 0x8e, 0x03, 0xc5, 0x4a, 0x60, 0x5f,
		0x98, 0xd9, 0xbd, 0xf0, 0xb7, 0x19, 0x6e, 0x2d, 0x4d, 0x96, 0x62, 0x44, 0x9d, 0x5a, 0x84, 0x96,
		0xd2, 0x89, 0x06, 0x08, 0x90, 0x49, 0x98, 0x06, 0xb0, 0xdc, 0xde, 0x96, 0xd2, 0x21, 0x8a, 0xa0,
		0xee, 0x14, 0xea, 0x4e, 0x01, 0x4d, 0x81, 0xa6, 0xc8, 0xcb, 0x4e, 0x3e, 0x5c, 0x81, 0x5d, 0x18,
		0xec, 0xc2, 0x98, 0x84, 0x0b, 0x5a, 0x1f, 0x1c, 0x79, 0xd9, 0x29, 0x88, 0x3d, 0x20, 0x2f, 0x1b,
		0x18, 0x0c, 0x0c, 0x06, 0x06, 0xa7, 0x16, 0x83, 0xb1, 0x13, 0x4e, 0xfc, 0x85, 0x9d, 0x70, 0x93,
		0xb3, 0x1d, 0x3e, 0x38, 0x76, 0xc2, 0x15, 0x6e, 0x84, 0x9d, 0xf0, 0xf4, 0xae, 0x3d, 0x76, 0xc2,
		0x93, 0x19, 0x15, 0x3b, 0xe1, 0xd8, 0x09, 0x27, 0x16, 0x2d, 0xe4, 0x65, 0xc7, 0xa5, 0x4c, 0xc8,
		0xcb, 0x86, 0x37, 0x0a, 0x6f, 0x14, 0xde, 0x28, 0xbc, 0x51, 0x78, 0xa3, 0xf0, 0x46, 0xe1, 0x8d,
		0xc2, 0x1b, 0x85, 0x37, 0x0a, 0x6f, 0x14, 0xde, 0x28, 0xbc, 0x51, 0xe4, 0x65, 0x93, 0x8a, 0xf2,
		0x66, 0xe6, 0x65, 0x6f, 0x5f, 0xcb, 0x06, 0xcd, 0x04, 0x22, 0xb4, 0x6b, 0x30, 0xb6, 0x60, 0xe9,
		0x6f, 0xd7, 0x10, 0x5f, 0xd1, 0xcc, 0xb4, 0x6e, 0xb8, 0x1b, 0xdd, 0xf9, 0xb2, 0x7f, 0xe3, 0x4f,
		0x83, 0xfb, 0xa2, 0x87, 0x83, 0x79, 0x09, 0x48, 0x43, 0x13, 0x07, 0xb5, 0x14, 0x6b, 0xad, 0x94,
		0x6a, 0xed, 0x26, 0x0d, 0x25, 0x34, 0x69, 0x48, 0x34, 0x52, 0xb9, 0xd1, 0x4d, 0x1a, 0xfa, 0xe6,
		0x6b, 0x14, 0x28, 0xd4, 0x6e, 0xcd, 0x30, 0x35, 0x96, 0x6a, 0x71, 0xfb, 0x49, 0x6b, 0xc5, 0xd1,
		0x44, 0x07, 0x67, 0xb5, 0xab, 0xdb, 0xcb, 0xda, 0x79, 0xed, 0x41, 0xb3, 0xc9, 0x43, 0x01, 0x4d,
		0x1e, 0x72, 0x68, 0xf2, 0x90, 0x11, 0x52, 0xae, 0xbd, 0x31, 0x30, 0x69, 0x45, 0xdb, 0x12, 0x6e,
		0xe0, 0x04, 0x6f, 0x7a, 0x67, 0xb7, 0x42, 0x1b, 0xa6, 0xc3, 0x9a, 0x6b, 0xa3, 0x47, 0xf9, 0x64,
		0xfb, 0x84, 0xa7, 0x9c, 0xae, 0x7f, 0xbd, 0xbc, 0x6c, 0x5c, 0x56, 0x3e, 0x55, 0x2f, 0x1b, 0x0f,
		0x7f, 0xdc, 0x56, 0x75, 0xa5, 0x70, 0x10, 0xa8, 0xf3, 0x49, 0x42, 0xe5, 0xc4, 0x7b, 0xba, 0xd5,
		0xdf, 0x47, 0x38, 0x98, 0x86, 0xed, 0x6b, 0xe2, 0x77, 0x0b, 0x31, 0x3e, 0xe1, 0x60, 0x48, 0xdd,
		0x34, 0x3e, 0xec, 0x18, 0x58, 0xbb, 0x7c, 0xf7, 0x6f, 0x4b, 0xb8, 0x4d, 0xbb, 0xeb, 0xf7, 0xda,
		0x7a, 0x7e, 0x63, 0xb8, 0x5e, 0x91, 0x11, 0x61, 0x9b, 0x61, 0x9b, 0x61, 0x9b, 0x61, 0x9b, 0x67,
		0x5f, 0xf0, 0xf6, 0xbe, 0xfa, 0xeb, 0xc5, 0xcd, 0x7f, 0x6a, 0x77, 0xd5, 0x46, 0xf5, 0xfa, 0xbc,
		0x72, 0x7b, 0xff, 0xeb, 0x65, 0xe5, 0xa1, 0x76, 0x73, 0xbd, 0xb9, 0x46, 0xfa, 0xf6, 0x3f, 0xd5,
		0x46, 0xf5, 0xe1, 0x97, 0xea, 0xdd, 0x75, 0xf5, 0xa1, 0x71, 0x57, 0xf9, 0x4f, 0xe3, 0xea, 0xe6,
		0xa2, 0xba, 0x89, 0x16, 0x7b, 0xe6, 0x45, 0x1f, 0x2a, 0x3f, 0xff, 0x5c, 0xbd, 0xa0, 0x7a, 0x57,
		0x58, 0xf0, 0xc8, 0xac, 0x07, 0x41, 0xdb, 0xea, 0x7a, 0x9d, 0xae, 0xfd, 0x42, 0x64, 0xc0, 0xe7,
		0x07, 0xd4, 0xf7, 0xd7, 0xfb, 0x46, 0x01, 0x34, 0x00, 0x34, 0x00, 0x34, 0x40, 0x56, 0x62, 0x9e,
		0x3a, 0x9d, 0xb6, 0xb0, 0x5d, 0x0a, 0x0a, 0x50, 0xc4, 0xbe, 0x06, 0xeb, 0xbe, 0x86, 0xc2, 0xbe,
		0xb0, 0xc4, 0x3e, 0xc6, 0x0e, 0xe1, 0x64, 0xaa, 0x4e, 0x22, 0xdf, 0xe4, 0xe5, 0xa5, 0xb6, 0x69,
		0x62, 0xee, 0xed, 0xc5, 0x5b, 0x8b, 0xf5, 0x33, 0x1b, 0x63, 0x56, 0xf3, 0x6d, 0xbf, 0x1b, 0xbf,
		0xdf, 0xf7, 0xe4, 0x60, 0x78, 0xff, 0xaa, 0x98, 0x6b, 0x26, 0xb7, 0x53, 0x24, 0x6d, 0xf7, 0x54,
		0xec, 0x9c, 0x86, 0x5d, 0x53, 0xb5, 0x63, 0xda, 0x76, 0x4b, 0xdb, 0x4e, 0xe9, 0xd9, 0x25, 0x5a,
		0x3d, 0x96, 0xdd, 0xd9, 0xc9, 0x37, 0x3b, 0xae, 0x1f, 0x78, 0xb6, 0xe3, 0x8a, 0x96, 0x35, 0x52,
		0x63, 0xc5, 0xdd, 0xce, 0xc8, 0x48, 0xe8, 0x4e, 0xcf, 0x48, 0xdb, 0xb0, 0xf1, 0x99, 0x33, 0xba,
		0xf1, 0x69, 0xbf, 0x8a, 0x96, 0x25, 0xbe, 0x75, 0xdb, 0x4e, 0xd3, 0x09, 0x06, 0xf2, 0xed, 0x13,
		0x6c, 0x81, 0x2e, 0x1a, 0x15, 0xdd, 0xe9, 0xe1, 0x15, 0x6d, 0x89, 0x57, 0xa4, 0xdd, 0x9d, 0x7e,
		0x81, 0x02, 0xd1, 0xc5, 0x23, 0x17, 0x0d, 0x8e, 0xbe, 0xf5, 0x06, 0x94, 0x97, 0x5a, 0x89, 0xd9,
		0x94, 0x99, 0x4d, 0xa9, 0x79, 0x94, 0x9b, 0x26, 0x66, 0x9a, 0x9a, 0xfa, 0x88, 0xcd, 0xb1, 0x16,
		0x10, 0x07, 0xab, 0x47, 0xe3, 0xd2, 0x9e, 0x84, 0x2e, 0xe2, 0x24, 0x34, 0xc9, 0xd0, 0x38, 0x09,
		0x6d, 0x14, 0x2a, 0x68, 0x20, 0x83, 0x08, 0x3a, 0xc8, 0x21, 0x64, 0x86, 0x47, 0xd0, 0xcb, 0xd4,
		0x34, 0x91, 0xa0, 0x16, 0x27, 0x9e, 0x93, 0x88, 0xe4, 0xf0, 0xc2, 0x09, 0x33, 0x06, 0xe0, 0x86,
		0x1b, 0x76, 0x8c, 0xc1, 0x8f, 0x31, 0x18, 0x32, 0x03, 0x47, 0xb4, 0xb0, 0x44, 0x0c, 0x4f, 0xe1,
		0x14, 0x90, 0x17, 0x6c, 0x88, 0x48, 0x3c, 0x79, 0x29, 0xd7, 0x08, 0x6d, 0x39, 0x49, 0xe9, 0x71,
		0x4a, 0xc2, 0xb5, 0xca, 0xfb, 0x4e, 0xcb, 0xea, 0x7a, 0x9d, 0x40, 0x0c, 0x8e, 0x41, 0x5b, 0x9e,
		0xf8, 0x6f, 0xcf, 0xf1, 0x44, 0x8b, 0xcf, 0x20, 0x2c, 0xbb, 0x21, 0xb1, 0xfc, 0x4d, 0xed, 0xb7,
		0x3f, 0xdb, 0x6d, 0x1f, 0x36, 0xc8, 0x9c, 0x0d, 0xb2, 0x7c, 0x0f, 0x66, 0x28, 0xa5, 0x66, 0xa8,
		0xbf, 0x36, 0xb0, 0x44, 0xc4, 0x72, 0xaf, 0x9f, 0x96, 0xb0, 0xd6, 0x14, 0x15, 0xb7, 0xc4, 0x14,
		0xf9, 0xa2, 0x3d, 0x32, 0x0c, 0xaf, 0x9d, 0x96, 0xe0, 0xb5, 0x42, 0x73, 0xf7, 0xe2, 0x33, 0x40,
		0x57, 0xb5, 0xdf, 0xc7, 0x39, 0x7f, 0xb0, 0x42, 0xb0, 0x42, 0xb0, 0x42, 0xb0, 0x42, 0x0c, 0x72,
		0x8f, 0xfa, 0x35, 0x7c, 0x56, 0x2e, 0x55, 0x11, 0x40, 0xe2, 0x3a, 0x32, 0x13, 0xfb, 0x4b, 0x9f,
		0xcf, 0xd6, 0xf6, 0xbb, 0xfe, 0xfe, 0x7c, 0x72, 0xcc, 0xfe, 0xa2, 0xad, 0xff, 0x45, 0xbf, 0x24,
		0x69, 0xfa, 0x49, 0xb7, 0x86, 0x14, 0xb5, 0x6c, 0xc3, 0xf7, 0xf3, 0x3a, 0xbd, 0x40, 0x58, 0x9d,
		0xa7, 0xff, 0x2b, 0x9a, 0x81, 0x4f, 0xbf, 0x8f, 0xb3, 0xe4, 0x3e, 0xd8, 0xd7, 0xa1, 0xa2, 0x17,
		0xd8, 0xd7, 0xc1, 0xbe, 0x0e, 0x29, 0xaa, 0x93, 0xef, 0xeb, 0x2c, 0x84, 0x00, 0x3e, 0x8f, 0x6a,
		0xf1, 0xed, 0x78, 0xfc, 0x9d, 0x22, 0xfc, 0x1d, 0xec, 0xfc, 0x64, 0xc5, 0xd9, 0xd9, 0x36, 0x4f,
		0x87, 0x1a, 0xc8, 0xc2, 0x81, 0x89, 0x73, 0x5e, 0x96, 0x2a, 0x14, 0x69, 0x0e, 0x8c, 0x21, 0x08,
		0x63, 0x87, 0x32, 0x13, 0x90, 0x66, 0x10, 0xda, 0x4c, 0x41, 0x9c, 0x71, 0xa8, 0x33, 0x0e, 0x79,
		0x66, 0xa1, 0x8f, 0x07, 0x02, 0x99, 0xa0, 0x90, 0x1d, 0x12, 0xc3, 0x1b, 0xd8, 0xad, 0x96, 0x27,
		0x7c, 0x9f, 0x5f, 0x8c, 0xc7, 0x9a, 0x39, 0xbe, 0xe1, 0x87, 0x8d, 0xa8, 0x39, 0xce, 0x0d, 0x9a,
		0x26, 0xc1, 0x33, 0x01, 0x10, 0x35, 0x0d, 0xa6, 0x89, 0x81, 0x6a, 0x62, 0xe0, 0x9a, 0x0c, 0xc8,
		0xf2, 0x82, 0x2d, 0x33, 0xe8, 0x86, 0x53, 0xc6, 0x16, 0x79, 0x5f, 0xaa, 0x71, 0x4e, 0xd7, 0x32,
		0x83, 0x8f, 0x39, 0xa6, 0x56, 0x33, 0xeb, 0xe6, 0xf2, 0xd1, 0x88, 0xb0, 0x9b, 0x01, 0x91, 0xb9,
		0x95, 0xfb, 0x5a, 0x36, 0xb8, 0x76, 0x91, 0x35, 0x3c, 0x31, 0x78, 0xcf, 0x5b, 0x3b, 0x08, 0x84,
		0xe7, 0x1a, 0x5b, 0xce, 0xf0, 0xc6, 0x7f, 0xee, 0xee, 0x3e, 0x16, 0xac, 0xd3, 0xfa, 0x8f, 0xc7,
		0xa2, 0x75, 0x5a, 0x1f, 0x7e, 0x5b, 0x1c, 0xfc, 0x33, 0xfc, 0xbe, 0xf4, 0x58, 0xb0, 0xca, 0xe3,
		0xef, 0x0f, 0x1f, 0x0b, 0xd6, 0x61, 0x7d, 0xef, 0xf3, 0xe7, 0x8f, 0x7b, 0xdf, 0x0f, 0xde, 0xe5,
		0x2f, 0xfc, 0x47, 0xde, 0xd8, 0xcb, 0xd5, 0x4d, 0x2e, 0xde, 0xcd, 0x7d, 0xed, 0x77, 0xac, 0x20,
		0xf5, 0x0a, 0x1a, 0xb9, 0xd3, 0xfb, 0x87, 0x0d, 0x86, 0xcf, 0x23, 0xc0, 0xa7, 0x19, 0xe5, 0xb3,
		0xad, 0xe7, 0x8a, 0xf5, 0x53, 0xfd, 0x7b, 0xf1, 0x43, 0xf9, 0xfd, 0x6c, 0xef, 0xfb, 0xf1, 0xfb,
		0xfc, 0x2f, 0x7f, 0x2c, 0xfa, 0x58, 0xf1, 0xc3, 0xf1, 0xfb, 0xd9, 0x92, 0xbf, 0x1c, 0xbd, 0x9f,
		0xc5, 0x1c, 0xe3, 0xf0, 0x7d, 0x37, 0xf2, 0xd1, 0xfe, 0xef, 0x4b, 0xcb, 0x2e, 0x28, 0x2f, 0xb9,
		0xe0, 0x60, 0xd9, 0x05, 0x07, 0x4b, 0x2e, 0x58, 0xfa, 0x48, 0xa5, 0x25, 0x17, 0x1c, 0xbe, 0xff,
		0x88, 0x7c, 0x7e, 0x77, 0xf1, 0x47, 0x8f, 0xde, 0xf7, 0x7e, 0x2c, 0xfb, 0xdb, 0xf1, 0xfb, 0x8f,
		0xb3, 0x3d, 0x18, 0x13, 0xc8, 0x33, 0xe4, 0x39, 0xd5, 0xa6, 0x75, 0x27, 0xdb, 0xef, 0xf1, 0x9e,
		0xc9, 0xf6, 0x83, 0x5f, 0x3a, 0x5d, 0x2b, 0x30, 0xe1, 0x65, 0x87, 0x44, 0x23, 0xbc, 0x23, 0xe2,
		0x8f, 0x88, 0x3f, 0x22, 0xfe, 0x88, 0xf8, 0x23, 0xe2, 0x8f, 0xf3, 0x2d, 0xad, 0x0d, 0x41, 0x64,
		0x8e, 0x39, 0x37, 0x38, 0x72, 0x2f, 0x9e, 0x5c, 0xe1, 0xcd, 0x30, 0xc4, 0x8e, 0xdb, 0x12, 0xdf,
		0xcc, 0x59, 0xe1, 0xe1, 0xed, 0x60, 0x82, 0x61, 0x82, 0x61, 0x82, 0x61, 0x82, 0x61, 0x82, 0xa7,
		0x34, 0xae, 0xe7, 0xb8, 0xc1, 0x89, 0x41, 0xd3, 0x7b, 0x68, 0xe0, 0x56, 0x77, 0xb6, 0xfb, 0xb2,
		0x91, 0xbb, 0x7f, 0x57, 0x8e, 0x6b, 0x0c, 0xb0, 0x0c, 0xdb, 0xb5, 0xc8, 0x6d, 0xc7, 0xed, 0xf5,
		0x4d, 0xdf, 0xd7, 0x60, 0xa3, 0x7d, 0xc3, 0xe8, 0x32, 0x2b, 0x4a, 0xf6, 0xb7, 0xad, 0x13, 0xa5,
		0xd2, 0xe1, 0xe1, 0x16, 0x09, 0x13, 0xe2, 0x98, 0xc9, 0xba, 0x4f, 0x99, 0x4a, 0xfc, 0x64, 0x3a,
		0xaa, 0x19, 0xb9, 0x4f, 0xfa, 0x8e, 0x6e, 0x2e, 0x3e, 0x80, 0xb8, 0xf8, 0xd7, 0xa4, 0xe7, 0x3c,
		0xf9, 0x05, 0x86, 0x41, 0x58, 0x98, 0x3d, 0x77, 0x23, 0x1e, 0x3b, 0xb3, 0x19, 0xc2, 0xc9, 0x86,
		0x74, 0x7a, 0xe2, 0x38, 0xd9, 0xb0, 0xcd, 0x06, 0x8e, 0xdd, 0xb3, 0x9e, 0x74, 0x87, 0x11, 0xf6,
		0xb3, 0x5e, 0xfb, 0xc7, 0xb8, 0x00, 0x56, 0x3c, 0x66, 0xbc, 0xc7, 0xed, 0xc8, 0x46, 0x7f, 0xfc,
		0x38, 0x6c, 0x91, 0xb4, 0x3f, 0x84, 0xe4, 0x2d, 0x36, 0x7d, 0xc3, 0x4e, 0x51, 0xec, 0xa6, 0x6f,
		0x78, 0x9b, 0x8c, 0x1f, 0xea, 0x2b, 0xc1, 0xf4, 0xc1, 0xf4, 0xc1, 0xf4, 0xa5, 0xc2, 0xf4, 0xe1,
		0x50, 0x5f, 0xaa, 0xc3, 0x55, 0xd8, 0xd1, 0xcb, 0x16, 0x98, 0x26, 0x06, 0xaa, 0x89, 0x81, 0x6b,
		0x32, 0x20, 0xcb, 0x1f, 0xa2, 0xcb, 0xe1, 0x50, 0x1f, 0x19, 0xa1, 0xc4, 0xa1, 0x3e, 0x8a, 0x95,
		0xc3, 0xa1, 0x3e, 0xf6, 0x1b, 0xe3, 0x50, 0x1f, 0xc1, 0xe2, 0xe1, 0x50, 0x1f, 0xc7, 0x0a, 0xe2,
		0x50, 0x9f, 0x2e, 0x7c, 0xe2, 0x50, 0x9f, 0x21, 0xe5, 0xc3, 0x21, 0x28, 0x1c, 0xea, 0xdb, 0x24,
		0x63, 0x02, 0x79, 0xc6, 0xa1, 0xbe, 0x94, 0x7b, 0xaa, 0x39, 0x1c, 0xea, 0x5b, 0xa8, 0xc1, 0x38,
		0xd4, 0x87, 0xf8, 0x23, 0xe2, 0x8f, 0x88, 0x3f, 0x22, 0xfe, 0x98, 0x8e, 0xf8, 0x23, 0x0e, 0xf5,
		0x6d, 0xa9, 0x21, 0xc6, 0xa1, 0x3e, 0x98, 0x60, 0x98, 0x60, 0x98, 0x60, 0x98, 0xe0, 0xa4, 0x4d,
		0x30, 0x0e, 0xf5, 0xe9, 0x7e, 0xe1, 0x50, 0x1f, 0xcb, 0x6d, 0x71, 0xa8, 0x8f, 0x57, 0x94, 0x70,
		0xa8, 0x6f, 0xc3, 0x85, 0x09, 0x71, 0xcc, 0x64, 0xdd, 0x27, 0x1c, 0xea, 0x5b, 0x70, 0x9f, 0x8c,
		0x1f, 0xea, 0x1b, 0x26, 0xdc, 0x67, 0xe5, 0x60, 0x43, 0xaa, 0x5b, 0x2a, 0xfd, 0x5b, 0xbc, 0x71,
		0xb9, 0xe6, 0xf9, 0x4b, 0xc7, 0x0f, 0x2a, 0x41, 0xc0, 0xd4, 0xb3, 0xe9, 0xca, 0x71, 0xab, 0x6d,
		0xd1, 0xf7, 0x6c, 0x7c, 0x1e, 0x63, 0xd6, 0x37, 0xce, 0x53, 0x77, 0x28, 0x9e, 0x94, 0xcb, 0x47,
		0xc7, 0xe5, 0x72, 0xe1, 0xf8, 0xe0, 0xb8, 0x70, 0x7a, 0x78, 0x58, 0x3c, 0x2a, 0x32, 0xd8, 0xb1,
		0xfc, 0x8d, 0xd7, 0x12, 0x9e, 0x68, 0x7d, 0xea, 0x2f, 0x8b, 0xdb, 0x6b, 0xb7, 0x53, 0x2d, 0x3d,
		0xcc, 0x78, 0x95, 0x71, 0x9c, 0xca, 0xb3, 0x1c, 0x69, 0xf2, 0x7a, 0xcd, 0xc0, 0x1d, 0xb9, 0x8d,
		0xd7, 0xc3, 0x57, 0xac, 0x8d, 0xde, 0xb0, 0x71, 0xd5, 0x6d, 0xfb, 0x8d, 0x4b, 0xbf, 0xeb, 0x37,
		0xce, 0x27, 0x6f, 0x78, 0x6b, 0x07, 0x5f, 0x1a, 0x7d, 0x47, 0xb3, 0x55, 0x1d, 0x3d, 0xe5, 0xe0,
		0x37, 0xe3, 0x1f, 0xee, 0xfa, 0x4f, 0x7c, 0x33, 0x7c, 0x60, 0x34, 0x49, 0x4e, 0x4e, 0xe8, 0x33,
		0x23, 0xec, 0x9b, 0xd4, 0x34, 0x79, 0xa4, 0x48, 0xc4, 0x2d, 0x92, 0x07, 0xa3, 0xd2, 0x36, 0x44,
		0x2e, 0xa0, 0x21, 0x32, 0xc9, 0xd0, 0x68, 0x88, 0xbc, 0x14, 0xd6, 0xb6, 0xa7, 0x21, 0x32, 0x79,
		0x7c, 0x97, 0xf1, 0x28, 0x39, 0xc7, 0xd1, 0xf1, 0xe8, 0x51, 0xf1, 0x01, 0x62, 0x6d, 0x10, 0xae,
		0xd3, 0x9e, 0xfc, 0x66, 0x39, 0xe9, 0xcd, 0xd6, 0xea, 0xbe, 0x04, 0x64, 0x07, 0xb2, 0x6f, 0x29,
		0xb2, 0x93, 0xb7, 0xba, 0x27, 0x25, 0x88, 0x9c, 0x44, 0x91, 0x89, 0x30, 0xb2, 0x11, 0x47, 0x4e,
		0x98, 0x31, 0x00, 0x37, 0xdc, 0xb0, 0x63, 0x0c, 0x7e, 0x8c, 0xc1, 0x90, 0x19, 0x38, 0xa2, 0x0f,
		0x3e, 0x70, 0xc4, 0xcd, 0xd8, 0x12, 0x0c, 0xa6, 0x98, 0x8a, 0xe7, 0xb8, 0x1c, 0x9d, 0xe6, 0x27,
		0x87, 0xa7, 0xd2, 0x1a, 0x2c, 0x22, 0xe4, 0x14, 0xbe, 0xd3, 0xb2, 0xba, 0x5e, 0x27, 0x10, 0x83,
		0xed, 0x43, 0xcb, 0x13, 0xff, 0xed, 0x39, 0x9e, 0x68, 0xf1, 0x19, 0x84, 0x65, 0x37, 0x24, 0x96,
		0xbf, 0x0b, 0xf1, 0x6c, 0xf7, 0xda, 0x03, 0x0d, 0x7c, 0xb6, 0xdb, 0x3e, 0x6c, 0x90, 0x39, 0x1b,
		0x64, 0xf9, 0x1e, 0xcc, 0x50, 0x4a, 0xcd, 0x50, 0x7f, 0x6d, 0x60, 0x89, 0x88, 0xe5, 0xfe, 0xa9,
		0xd3, 0x69, 0x0b, 0xdb, 0xe5, 0x34, 0x45, 0xc5, 0x2d, 0x31, 0x45, 0xbe, 0x68, 0x8f, 0x0c, 0xc3,
		0x6b, 0xa7, 0x25, 0x78, 0xad, 0xd0, 0xdc, 0xbd, 0xf8, 0x0c, 0xd0, 0x55, 0xed, 0xf7, 0xea, 0x45,
		0xe3, 0xea, 0xe6, 0xa2, 0x0a, 0x2b, 0x04, 0x2b, 0x04, 0x2b, 0x04, 0x2b, 0xc4, 0x21, 0xf7, 0xc2,
		0xed, 0xbd, 0x0a, 0x6f, 0xb8, 0x6b, 0xcb, 0x68, 0x89, 0x18, 0x4e, 0x34, 0x31, 0x9d, 0x60, 0xc2,
		0xee, 0xbc, 0xa4, 0xfd, 0x4d, 0xdd, 0xee, 0x3c, 0x61, 0x16, 0x1c, 0xc1, 0xa6, 0xcd, 0x4e, 0x82,
		0x8b, 0x3f, 0xce, 0x62, 0x23, 0x08, 0xa7, 0xd2, 0x26, 0xad, 0xd1, 0x27, 0xa9, 0x19, 0x49, 0x4a,
		0xa3, 0x4d, 0x42, 0xd3, 0x5d, 0x5c, 0x62, 0x8d, 0x4e, 0x9f, 0x26, 0xe7, 0x49, 0x36, 0x3c, 0x89,
		0xf2, 0xc2, 0xf4, 0x00, 0x45, 0x1d, 0x06, 0xd4, 0xae, 0x54, 0x94, 0x2d, 0x2a, 0x99, 0x4a, 0x56,
		0x96, 0xd4, 0x96, 0x4a, 0x7e, 0xa2, 0x15, 0x26, 0x39, 0x1f, 0xf4, 0x5c, 0x57, 0xb4, 0xd5, 0x2b,
		0x0c, 0x87, 0xc4, 0x6d, 0x3c, 0x90, 0xe2, 0x42, 0xeb, 0x6d, 0xb2, 0x6b, 0xfb, 0x7a, 0x14, 0x3e,
		0x1d, 0xe1, 0x2e, 0x16, 0x95, 0x83, 0x46, 0xee, 0x88, 0x91, 0x3b, 0x5c, 0xb4, 0xbb, 0x4c, 0x66,
		0xc1, 0x49, 0x77, 0x13, 0x7b, 0xa4, 0x33, 0xfa, 0xab, 0x3c, 0xab, 0x83, 0xba, 0x4b, 0x4c, 0x93,
		0xef, 0x42, 0x16, 0x7e, 0xa1, 0x0c, 0xb7, 0x30, 0x6c, 0x34, 0x53, 0xc7, 0x52, 0xd8, 0x62, 0x27,
		0x6c, 0xb1, 0x12, 0x9e, 0x8d, 0xe2, 0x64, 0x1d, 0x15, 0xaa, 0xfc, 0x94, 0xfc, 0x93, 0xed, 0xb6,
		0xfe, 0x76, 0x5a, 0x03, 0xde, 0x41, 0x9c, 0xe4, 0x36, 0x19, 0x3a, 0xe5, 0x89, 0x6e, 0x48, 0x61,
		0xce, 0x54, 0x70, 0x15, 0x89, 0x6e, 0x69, 0x4e, 0x74, 0xb3, 0x7b, 0x41, 0xc7, 0xa2, 0x47, 0x95,
		0x88, 0x42, 0xcc, 0xdd, 0x87, 0x67, 0xcb, 0xa7, 0x88, 0x2d, 0x1f, 0x24, 0xbf, 0xa5, 0x09, 0x9a,
		0xcc, 0x40, 0x14, 0x2d, 0x54, 0x11, 0x43, 0x16, 0x1b, 0x74, 0x85, 0x03, 0x37, 0xc7, 0x5a, 0xca,
		0xdc, 0xef, 0x6d, 0x74, 0x9f, 0x8c, 0x37, 0x7c, 0x43, 0xaf, 0xd3, 0x34, 0x40, 0x9c, 0x71, 0xa8,
		0x33, 0x0e, 0x79, 0x66, 0xa1, 0x8f, 0x07, 0x02, 0x99, 0xa0, 0x90, 0x1d, 0x12, 0x27, 0xec, 0xae,
		0xf5, 0x7f, 0x7b, 0x7e, 0x60, 0x39, 0x6e, 0x20, 0xbc, 0xaf, 0x76, 0xdb, 0x64, 0xe3, 0xb7, 0xd9,
		0x1b, 0xa3, 0xfa, 0x63, 0xda, 0xc0, 0x34, 0x01, 0x50, 0x35, 0x0d, 0xae, 0x89, 0x81, 0x6c, 0x62,
		0x60, 0x9b, 0x0c, 0xe8, 0xf2, 0x82, 0x2f, 0x33, 0x08, 0x87, 0x53, 0x96, 0x4c, 0xf5, 0xc7, 0x83,
		0x92, 0xc1, 0xf2, 0x8f, 0xc7, 0x28, 0xff, 0xa8, 0xfe, 0x62, 0x28, 0xff, 0xc8, 0x7f, 0x5f, 0x94,
		0x7f, 0xdc, 0x58, 0x51, 0x2a, 0x97, 0x4e, 0xcb, 0xa7, 0x47, 0xc7, 0xa5, 0x53, 0x54, 0x81, 0xcc,
		0xdc, 0x5d, 0xd0, 0xcd, 0x66, 0xa9, 0x6b, 0x15, 0x7c, 0xf1, 0x84, 0xff, 0xa5, 0xd3, 0x6e, 0x19,
		0xf7, 0xad, 0x26, 0x77, 0x86, 0x73, 0x05, 0xe7, 0x0a, 0xce, 0x15, 0x9c, 0x2b, 0x38, 0x57, 0x53,
		0x1a, 0xd7, 0x15, 0x5e, 0x53, 0xb8, 0x81, 0xfd, 0x22, 0x50, 0x5f, 0x1f, 0x0e, 0x16, 0x1c, 0x2c,
		0x38, 0x58, 0x1b, 0x2e, 0x4a, 0xc5, 0x42, 0x01, 0x9e, 0x15, 0x3c, 0xab, 0xec, 0x7b, 0x56, 0xc2,
		0xb5, 0x9f, 0xda, 0xc2, 0xa0, 0x43, 0x35, 0xbe, 0x21, 0x33, 0x07, 0x62, 0xae, 0xbe, 0x02, 0xbf,
		0x0d, 0x7e, 0x1b, 0xfc, 0x36, 0xf8, 0x6d, 0x19, 0xf7, 0xdb, 0xf8, 0xea, 0xc6, 0x2c, 0x03, 0x48,
		0xe2, 0x3a, 0x32, 0x9b, 0x61, 0x84, 0x5f, 0xed, 0x6f, 0xd6, 0xd3, 0xdf, 0xe6, 0x6c, 0xf0, 0xe8,
		0x7e, 0x30, 0x89, 0x30, 0x89, 0x30, 0x89, 0x30, 0x89, 0x30, 0x89, 0x8b, 0x4e, 0x66, 0x59, 0x7f,
		0x3d, 0x75, 0x7d, 0x83, 0x96, 0xf1, 0xc4, 0xc0, 0xad, 0x7e, 0x75, 0x87, 0xb1, 0x83, 0xfc, 0xbf,
		0x0d, 0xbd, 0x1b, 0xe2, 0xa7, 0xd9, 0xb3, 0xa8, 0x91, 0xdb, 0x22, 0x7e, 0xca, 0x2b, 0x4a, 0xdb,
		0x18, 0x3f, 0x35, 0xd2, 0xe8, 0x2d, 0xb5, 0xd2, 0x85, 0x80, 0xea, 0xe6, 0xfa, 0x72, 0x8e, 0x6b,
		0xd6, 0x97, 0x1b, 0xde, 0x0f, 0xbe, 0x1c, 0x7c, 0x39, 0xf8, 0x72, 0xf0, 0xe5, 0xe0, 0xcb, 0xc1,
		0x97, 0x83, 0x2f, 0x07, 0x5f, 0x0e, 0xbe, 0x1c, 0x7c, 0x39, 0xf8, 0x72, 0xf0, 0xe5, 0x36, 0xdf,
		0x97, 0xcb, 0xd4, 0x21, 0x74, 0xe6, 0x66, 0xee, 0xe1, 0x7d, 0x8c, 0xd5, 0x4c, 0x1d, 0x95, 0x0e,
		0x1d, 0xfd, 0xbb, 0x1f, 0x32, 0xae, 0xfd, 0xd9, 0x1a, 0x44, 0xfb, 0xa3, 0x7a, 0x1e, 0x3b, 0xd9,
		0x10, 0x01, 0x86, 0xe5, 0xcf, 0x77, 0xbe, 0x0a, 0xef, 0xb9, 0xdd, 0xf9, 0x9b, 0xbf, 0x76, 0x4a,
		0x78, 0x27, 0x54, 0x4f, 0x49, 0xca, 0xf9, 0x47, 0xf5, 0x94, 0x0c, 0x3a, 0xf7, 0xa8, 0x9e, 0xb2,
		0x7c, 0x6a, 0xd8, 0xab, 0xa7, 0x30, 0x17, 0x96, 0x8a, 0x28, 0x26, 0x6b, 0x81, 0x29, 0x43, 0x50,
		0x69, 0x0c, 0x32, 0x4d, 0x42, 0x67, 0x02, 0x10, 0x6a, 0x1a, 0x4a, 0x13, 0x83, 0xd4, 0xc4, 0xa0,
		0x35, 0x19, 0x88, 0x35, 0xe3, 0x3d, 0x71, 0xc7, 0x4d, 0xb9, 0xa1, 0x37, 0xbc, 0x91, 0xa9, 0xb3,
		0x00, 0x11, 0x0d, 0x37, 0x73, 0x26, 0x60, 0x32, 0xa1, 0x66, 0xcf, 0x06, 0x24, 0x14, 0xa7, 0x31,
		0x66, 0x14, 0x92, 0x30, 0x0e, 0x09, 0x1a, 0x89, 0xa4, 0x8c, 0x45, 0xe2, 0x46, 0x23, 0x71, 0xe3,
		0x91, 0xac, 0x11, 0x31, 0x63, 0x4c, 0x0c, 0x19, 0x95, 0x70, 0x2a, 0x8d, 0x6d, 0xca, 0x45, 0x34,
		0xd6, 0xdc, 0xd9, 0x83, 0x08, 0x1b, 0x2f, 0x6e, 0x48, 0xcc, 0xd6, 0x80, 0x90, 0x84, 0xc1, 0x24,
		0x83, 0xc5, 0x57, 0x96, 0x06, 0xb4, 0x8c, 0x95, 0x61, 0x81, 0xc9, 0x86, 0xc9, 0x86, 0xc9, 0x86,
		0xc9, 0x86, 0xc9, 0xce, 0x25, 0x56, 0xe6, 0x65, 0x1e, 0x83, 0x0d, 0xee, 0x29, 0x1b, 0x4e, 0x75,
		0x19, 0x7f, 0x99, 0x05, 0xa5, 0x5c, 0x52, 0xa9, 0x2f, 0x09, 0x19, 0xd7, 0xc8, 0xed, 0x13, 0x4a,
		0x85, 0x09, 0xef, 0x9f, 0x60, 0xd2, 0x82, 0x61, 0xc8, 0x9a, 0x15, 0xb9, 0x04, 0x52, 0x64, 0xd2,
		0x26, 0x72, 0xc6, 0xcb, 0xc7, 0xa4, 0x4a, 0xe8, 0x76, 0x36, 0xf3, 0x6e, 0x75, 0x78, 0x95, 0xb1,
		0xc5, 0x30, 0xf0, 0x9c, 0x97, 0x17, 0xe1, 0x59, 0xe2, 0xab, 0x70, 0x03, 0xab, 0xd9, 0xe9, 0x0d,
		0x98, 0xa1, 0x61, 0xb7, 0x72, 0xd1, 0x43, 0xc0, 0xaf, 0x84, 0x5f, 0x09, 0xbf, 0x12, 0x7e, 0x25,
		0xfc, 0x4a, 0x83, 0x1a, 0xdb, 0x73, 0xdc, 0xa0, 0x78, 0x94, 0x80, 0x4f, 0x79, 0x04, 0x9f, 0x12,
		0x3e, 0x25, 0x7c, 0x4a, 0xf8, 0x94, 0x1b, 0x20, 0x72, 0x47, 0x87, 0x87, 0x07, 0x87, 0xf0, 0x2a,
		0xe1, 0x55, 0xa6, 0xd4, 0xab, 0xcc, 0x74, 0x0e, 0x96, 0xa1, 0x73, 0x1b, 0xe1, 0xfd, 0x52, 0x77,
		0x7e, 0x63, 0xbc, 0x05, 0xcb, 0x7a, 0x90, 0x83, 0x5f, 0x56, 0x38, 0x2b, 0x3f, 0xf8, 0x81, 0x1d,
		0x08, 0x73, 0x09, 0xcc, 0xc3, 0xdb, 0x6d, 0x58, 0xfe, 0x72, 0x09, 0xf9, 0xcb, 0x19, 0x8a, 0x43,
		0x20, 0x7f, 0x19, 0xf9, 0xcb, 0xeb, 0xa7, 0x0c, 0xf9, 0xcb, 0xd4, 0x13, 0x8a, 0xfc, 0xe5, 0xac,
		0x1b, 0x87, 0x04, 0x8d, 0x44, 0x52, 0xc6, 0x22, 0x71, 0xa3, 0x91, 0xb8, 0xf1, 0x48, 0xd6, 0x88,
		0x98, 0x75, 0x5d, 0x91, 0xbf, 0xcc, 0xc8, 0xc6, 0x91, 0xbf, 0x1c, 0x7f, 0xce, 0x90, 0xbf, 0x0c,
		0x93, 0x0d, 0x93, 0x0d, 0x93, 0x0d, 0x93, 0x0d, 0x93, 0x8d, 0xfc, 0x65, 0xd6, 0x2f, 0xec, 0x35,
		0x1b, 0xbd, 0x3d, 0xf6, 0x9a, 0xb1, 0xd7, 0x9c, 0x90, 0xc8, 0x21, 0x7f, 0x79, 0x03, 0xef, 0x86,
		0xfc, 0xe5, 0xf8, 0x62, 0x88, 0xfc, 0x65, 0xf8, 0x95, 0xf0, 0x2b, 0xe1, 0x57, 0xc2, 0xaf, 0x84,
		0x5f, 0x89, 0xfc, 0x65, 0xf8, 0x94, 0xf0, 0x29, 0xe1, 0x53, 0xc2, 0xa7, 0xd4, 0x12, 0x39, 0xe4,
		0x2f, 0xc3, 0xab, 0x4c, 0xb3, 0x57, 0x89, 0xfc, 0x65, 0x89, 0xfb, 0xa5, 0x37, 0x7f, 0x79, 0x98,
		0x36, 0x8b, 0x66, 0x07, 0xfc, 0xc2, 0xb7, 0xbd, 0xcd, 0x0e, 0x98, 0x0b, 0xf0, 0x0f, 0x5f, 0x3a,
		0xf0, 0x7a, 0xcd, 0xc0, 0x1d, 0x79, 0x20, 0xd7, 0xc3, 0xb7, 0xa8, 0x8d, 0x5e, 0xa2, 0x71, 0xd5,
		0x6d, 0xfb, 0x8d, 0x4b, 0xbf, 0xeb, 0x37, 0xce, 0x27, 0x2f, 0x71, 0x6b, 0x07, 0x5f, 0x1a, 0x0f,
		0x83, 0x67, 0x6f, 0x7c, 0x1a, 0x3f, 0x6c, 0xa3, 0xd2, 0x0b, 0x3a, 0x93, 0x9f, 0x6e, 0xc6, 0x8f,
		0xbe, 0xc5, 0x9d, 0x1a, 0x78, 0x13, 0xf9, 0x8d, 0x24, 0xf0, 0x1b, 0xeb, 0xd1, 0x50, 0x42, 0x8f,
		0x86, 0x14, 0x05, 0xd8, 0xd0, 0xa3, 0x61, 0x9b, 0xed, 0x2d, 0x7b, 0x8f, 0x06, 0xbb, 0xf5, 0x7f,
		0x7b, 0x7e, 0x60, 0x39, 0x6e, 0x20, 0xbc, 0xaf, 0x76, 0xdb, 0xdc, 0x59, 0xa7, 0xf9, 0x1b, 0xa3,
		0xdb, 0x6d, 0xda, 0xc0, 0x34, 0x01, 0x50, 0x35, 0x0d, 0xae, 0x89, 0x81, 0x6c, 0x62, 0x60, 0x9b,
		0x0c, 0xe8, 0x6e, 0x86, 0xc7, 0x6d, 0xbe, 0xdb, 0x6d, 0xcf, 0x71, 0x83, 0x83, 0x92, 0xc1, 0x2e,
		0xb7, 0xc7, 0x68, 0x3a, 0xab, 0xfe, 0x62, 0x68, 0x3a, 0xcb, 0x7f, 0x5f, 0x34, 0x9d, 0xdd, 0x58,
		0x51, 0x2a, 0x97, 0x4e, 0xcb, 0xa7, 0x47, 0xc7, 0xa5, 0x53, 0xb4, 0x9a, 0xcd, 0xdc, 0x5d, 0xea,
		0x28, 0x1e, 0xb1, 0xcc, 0xb5, 0x32, 0x77, 0x48, 0x69, 0xde, 0xb7, 0x32, 0x75, 0x34, 0x09, 0xce,
		0x15, 0x9c, 0x2b, 0x38, 0x57, 0x70, 0xae, 0x32, 0xe6, 0x5c, 0x19, 0x3d, 0x3a, 0x64, 0xf0, 0xc8,
		0x10, 0x1c, 0x2c, 0x38, 0x58, 0x70, 0xb0, 0xe0, 0x60, 0x45, 0x44, 0xc9, 0xf8, 0x11, 0x1f, 0x78,
		0x56, 0xf0, 0xac, 0x38, 0xc4, 0xca, 0x54, 0x55, 0x28, 0xc3, 0xd5, 0xa0, 0x4c, 0x57, 0x81, 0x82,
		0xdf, 0x06, 0xbf, 0x0d, 0x7e, 0x1b, 0xfc, 0xb6, 0x8c, 0xf9, 0x6d, 0xe6, 0xaa, 0x34, 0x19, 0xaa,
		0xce, 0x94, 0x4d, 0x23, 0x3c, 0xce, 0xdc, 0xb0, 0xbe, 0x38, 0x2f, 0x5f, 0xac, 0xa7, 0xbf, 0xcd,
		0x59, 0xe3, 0xc8, 0x9d, 0x61, 0x26, 0x61, 0x26, 0x61, 0x26, 0x61, 0x26, 0x61, 0x26, 0xa7, 0xcd,
		0xe4, 0x38, 0x01, 0xdc, 0xfa, 0xeb, 0xa9, 0xeb, 0x1b, 0xb4, 0x96, 0x27, 0x06, 0x6e, 0xf5, 0xab,
		0x3b, 0x8c, 0x27, 0xe4, 0xff, 0x6d, 0xe8, 0xdd, 0x10, 0x53, 0xcd, 0x9e, 0x45, 0x8d, 0xdc, 0x16,
		0x31, 0x55, 0x5e, 0x51, 0xda, 0xc6, 0x98, 0xea, 0x49, 0xb9, 0x7c, 0x74, 0x5c, 0x2e, 0x17, 0x8e,
		0x0f, 0x8e, 0x0b, 0xa7, 0x87, 0x87, 0xc5, 0xa3, 0x22, 0xd2, 0x57, 0x32, 0x77, 0x17, 0x04, 0x59,
		0xa3, 0x62, 0xf5, 0x6a, 0x7f, 0x33, 0xea, 0xd5, 0x8d, 0xee, 0x07, 0x5f, 0x0e, 0xbe, 0x1c, 0x7c,
		0x39, 0xf8, 0x72, 0xf0, 0xe5, 0xe0, 0xcb, 0xc1, 0x97, 0x83, 0x2f, 0x07, 0x5f, 0x0e, 0xbe, 0x1c,
		0x7c, 0x39, 0xf8, 0x72, 0xf0, 0xe5, 0x74, 0x7c, 0x39, 0xc7, 0x35, 0xeb, 0xcb, 0x0d, 0xef, 0x07,
		0x5f, 0x0e, 0xbe, 0x1c, 0x7c, 0x39, 0xf8, 0x72, 0xf0, 0xe5, 0xe0, 0xcb, 0xc1, 0x97, 0x83, 0x2f,
		0x07, 0x5f, 0x0e, 0xbe, 0x1c, 0x7c, 0x39, 0xf8, 0x72, 0x9b, 0xef, 0xcb, 0xa1, 0xa8, 0xe7, 0x82,
		0xfb, 0xa4, 0xae, 0xa8, 0x27, 0x63, 0xe1, 0xd8, 0x6c, 0x94, 0xc5, 0xec, 0xb9, 0xad, 0x51, 0x6d,
		0x50, 0xf6, 0xd2, 0x98, 0x93, 0x5b, 0x65, 0xbc, 0x3c, 0x66, 0x01, 0xe5, 0x31, 0x53, 0xe4, 0xed,
		0xa3, 0x3c, 0xe6, 0x36, 0x5b, 0x2e, 0xf6, 0xf2, 0x98, 0xcd, 0xb1, 0xd6, 0x1b, 0x0a, 0x9c, 0x8e,
		0xee, 0x67, 0x26, 0x70, 0x5a, 0x44, 0xe0, 0x34, 0xcd, 0x10, 0x6a, 0x1a, 0x4a, 0x13, 0x83, 0xd4,
		0xc4, 0xa0, 0x35, 0x19, 0x88, 0x35, 0xe3, 0x3e, 0x71, 0x07, 0x4e, 0xb9, 0xa1, 0x37, 0xbc, 0x91,
		0xa9, 0xc3, 0xde, 0x11, 0x0d, 0x37, 0x73, 0xe8, 0x7b, 0x32, 0xa1, 0x66, 0x0f, 0x7f, 0x27, 0x14,
		0xa8, 0x41, 0xdf, 0xc7, 0xcd, 0x32, 0x16, 0x89, 0x1b, 0x8d, 0xc4, 0x8d, 0x47, 0xb2, 0x46, 0xc4,
		0x8c, 0x31, 0x31, 0x64, 0x54, 0xc2, 0xa9, 0x4c, 0xae, 0xef, 0xa3, 0xb9, 0xc3, 0xe5, 0x11, 0x36,
		0x5e, 0x44, 0xb3, 0xe6, 0xd8, 0x73, 0x86, 0x66, 0xcd, 0x30, 0xda, 0x30, 0xda, 0x30, 0xda, 0x30,
		0xda, 0x30, 0xda, 0x68, 0xd6, 0xcc, 0xf8, 0x85, 0x66, 0xcd, 0x46, 0x6f, 0x8f, 0x66, 0xcd, 0x68,
		0xd6, 0x9c, 0x90, 0xc8, 0xa1, 0x59, 0xf3, 0x46, 0xde, 0xad, 0x0e, 0xaf, 0x32, 0xb6, 0x18, 0x86,
		0x39, 0x0a, 0x06, 0x9b, 0x36, 0x44, 0xc9, 0xcc, 0x82, 0x87, 0x80, 0x57, 0x09, 0xaf, 0x12, 0x5e,
		0x25, 0xbc, 0x4a, 0x78, 0x95, 0x06, 0x35, 0xd6, 0x68, 0x7f, 0x88, 0x79, 0x0c, 0x3e, 0x84, 0x67,
		0x09, 0xcf, 0x12, 0x9e, 0x25, 0x3c, 0xcb, 0x0d, 0x10, 0x39, 0xe3, 0x7d, 0x27, 0xe0, 0x57, 0xc2,
		0xaf, 0x4c, 0xc7, 0x1d, 0xb8, 0xb3, 0xb0, 0x0c, 0x1d, 0xdd, 0x08, 0xef, 0x97, 0xba, 0x23, 0x1c,
		0xa1, 0xb7, 0xbc, 0x3f, 0x4a, 0x9d, 0x45, 0xf5, 0x87, 0xe8, 0xa2, 0x0d, 0x8e, 0xb9, 0x18, 0xcb,
		0x61, 0x1e, 0xde, 0x6e, 0xc3, 0x52, 0x98, 0x4b, 0x48, 0x61, 0xce, 0x50, 0x28, 0x02, 0x29, 0xcc,
		0x48, 0x61, 0x5e, 0x3f, 0x65, 0x48, 0x61, 0xa6, 0x9e, 0x50, 0xa4, 0x30, 0x67, 0xdd, 0x38, 0x24,
		0x68, 0x24, 0x92, 0x32, 0x16, 0x89, 0x1b, 0x8d, 0xc4, 0x8d, 0x47, 0xb2, 0x46, 0xc4, 0xac, 0xef,
		0x8a, 0x14, 0x66, 0x46, 0x36, 0x8e, 0x14, 0xe6, 0xf8, 0x73, 0x86, 0x14, 0x66, 0x18, 0x6d, 0x18,
		0x6d, 0x18, 0x6d, 0x18, 0x6d, 0x18, 0x6d, 0xa4, 0x30, 0x33, 0x7e, 0x61, 0xa3, 0xd9, 0xe8, 0xed,
		0xb1, 0xd1, 0x8c, 0x8d, 0xe6, 0x84, 0x44, 0x0e, 0x29, 0xcc, 0x1b, 0x79, 0x37, 0xa4, 0x30, 0xc7,
		0x17, 0x43, 0xa4, 0x30, 0xc3, 0xab, 0x84, 0x57, 0x09, 0xaf, 0x12, 0x5e, 0x25, 0xbc, 0x4a, 0xa4,
		0x30, 0xc3, 0xb3, 0x84, 0x67, 0x09, 0xcf, 0x12, 0x9e, 0xa5, 0xb6, 0xc8, 0x21, 0x85, 0x19, 0x7e,
		0x65, 0x7a, 0xfd, 0x4a, 0xa4, 0x30, 0x4b, 0xdc, 0x2f, 0xc5, 0x29, 0xcc, 0x8c, 0xf5, 0xe8, 0xf9,
		0x65, 0x05, 0x3d, 0x0f, 0xb2, 0x25, 0x6d, 0x79, 0xd6, 0x8c, 0x73, 0xaf, 0xd7, 0x0c, 0xdc, 0x91,
		0x17, 0x72, 0x3d, 0x7c, 0x8d, 0xda, 0xe8, 0x2d, 0x1a, 0x57, 0xdd, 0xb6, 0xdf, 0xb8, 0xf4, 0xbb,
		0x7e, 0xe3, 0x7c, 0xf2, 0x16, 0xb7, 0x76, 0xf0, 0xa5, 0xf1, 0x30, 0x78, 0xf8, 0xc6, 0xa7, 0xf1,
		0xd3, 0x36, 0x2a, 0xbd, 0xa0, 0x33, 0xf9, 0xe9, 0xd7, 0xf0, 0xd9, 0xb3, 0xd2, 0xb3, 0x61, 0x27,
		0xc5, 0xba, 0xc0, 0xad, 0x03, 0xa9, 0x93, 0x7d, 0x06, 0x89, 0x67, 0x92, 0x74, 0x5a, 0xf9, 0xa6,
		0x93, 0x42, 0x42, 0x09, 0xe4, 0x2a, 0xad, 0xcf, 0x5b, 0x4a, 0x9f, 0xe9, 0xdc, 0x09, 0x5b, 0x1c,
		0x99, 0x33, 0x5e, 0x6c, 0x20, 0x2e, 0xcc, 0x1d, 0xff, 0x35, 0x16, 0xe7, 0x35, 0x16, 0xcf, 0x35,
		0x13, 0xb7, 0x4d, 0xb7, 0x5d, 0xe3, 0x3a, 0xd7, 0x91, 0xf7, 0x45, 0x30, 0x65, 0x4d, 0xd8, 0x5b,
		0x26, 0xcd, 0xde, 0x8e, 0xb7, 0x6d, 0x52, 0x01, 0x6d, 0x93, 0x92, 0x04, 0x3a, 0x53, 0x80, 0x67,
		0x1c, 0xf8, 0x8c, 0x03, 0xa0, 0x59, 0x20, 0xcc, 0xa6, 0xf3, 0xcb, 0xbe, 0x21, 0x65, 0xbe, 0xd9,
		0xb1, 0x81, 0x26, 0xc7, 0xc6, 0x9a, 0x1b, 0x1b, 0xda, 0xcd, 0x32, 0x10, 0x6b, 0xfb, 0xff, 0xd8,
		0x7b, 0xd7, 0xde, 0xb6, 0x91, 0xa4, 0x7b, 0xfc, 0x7d, 0x3e, 0x85, 0x21, 0xec, 0x8b, 0x18, 0x08,
		0xa3, 0x8b, 0x75, 0xb1, 0x0d, 0xfc, 0x5e, 0x38, 0xb1, 0x66, 0xc7, 0x58, 0xdf, 0xd6, 0x76, 0xf6,
		0x99, 0x81, 0x47, 0x2b, 0xd0, 0x54, 0xcb, 0xe6, 0x3f, 0x14, 0xc9, 0x87, 0xdd, 0xca, 0xc4, 0x4f,
		0xac, 0xef, 0xfe, 0x87, 0x24, 0x4a, 0xd6, 0x35, 0x91, 0xa5, 0xae, 0x6a, 0x5e, 0x4e, 0xb0, 0xd8,
		0x68, 0x14, 0x89, 0x4d, 0xb1, 0xab, 0x4f, 0x9d, 0x53, 0x55, 0xdd, 0xc5, 0x99, 0xad, 0xe2, 0x2e,
		0xfd, 0x60, 0xce, 0x46, 0x99, 0x48, 0x04, 0x70, 0x14, 0x2c, 0x71, 0x66, 0x97, 0x4c, 0x99, 0x88,
		0xb9, 0x66, 0xc4, 0x46, 0xac, 0x26, 0xa5, 0x01, 0xec, 0x56, 0x8e, 0x1b, 0xc1, 0xca, 0x50, 0x38,
		0x6e, 0xd7, 0x75, 0x46, 0xd1, 0x40, 0x4b, 0x51, 0xf2, 0x83, 0x57, 0x79, 0xb3, 0x3c, 0x26, 0x55,
		0x9b, 0xc8, 0xd7, 0x7d, 0xe9, 0xb7, 0xd7, 0xcd, 0xcf, 0x67, 0xbf, 0x9d, 0x35, 0x4f, 0xa1, 0xa7,
		0xa0, 0xa7, 0xa0, 0xa7, 0xa0, 0xa7, 0xd2, 0xa5, 0xa7, 0x94, 0x78, 0x8d, 0x08, 0x51, 0x42, 0xe6,
		0x2c, 0x94, 0x95, 0xab, 0x84, 0x63, 0x34, 0xfd, 0x7e, 0x6f, 0xf8, 0xe8, 0x06, 0xc8, 0xe8, 0xe9,
		0x58, 0xa3, 0x99, 0xcf, 0xe8, 0x51, 0x9c, 0xf2, 0x96, 0xcc, 0xfc, 0x18, 0xcd, 0xa9, 0x6d, 0xa4,
		0xa7, 0xb4, 0x91, 0x67, 0xc7, 0x2a, 0xc8, 0x8e, 0x31, 0x92, 0x1b, 0x64, 0xc7, 0xb2, 0xe8, 0x23,
		0x90, 0x1d, 0x83, 0x9a, 0x83, 0x9a, 0x83, 0x9a, 0x83, 0x9a, 0x33, 0xae, 0xe6, 0x90, 0x1d, 0xdb,
		0x66, 0x20, 0x64, 0xc7, 0x92, 0xe7, 0xc9, 0x96, 0x86, 0x43, 0x76, 0x4c, 0x8f, 0x89, 0x20, 0x3b,
		0x96, 0x35, 0xab, 0x41, 0x76, 0x8c, 0xf4, 0x7e, 0x49, 0xb2, 0x63, 0xee, 0xa3, 0x6f, 0x7b, 0xa2,
		0xc3, 0x2a, 0x6f, 0x96, 0xc7, 0x84, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81,
		0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0x81, 0xc6, 0xd1, 0xa3, 0x71,
		0x50, 0x01, 0x08, 0x3d, 0x05, 0x3d, 0x05, 0x3d, 0x05, 0x3d, 0x95, 0x68, 0x3d, 0x85, 0x0a, 0x40,
		0xd3, 0xce, 0x17, 0x15, 0x80, 0x46, 0x2b, 0x00, 0x09, 0x0e, 0x49, 0xd2, 0x58, 0x00, 0xf8, 0x2e,
		0x41, 0x46, 0x41, 0x65, 0x0c, 0xe6, 0x8d, 0xa0, 0xa0, 0xb5, 0xce, 0x52, 0xcf, 0x09, 0x2e, 0x7a,
		0x4c, 0x72, 0x77, 0x03, 0xd2, 0x60, 0x3c, 0xba, 0xcf, 0x66, 0xa1, 0x39, 0x93, 0x45, 0x73, 0xb5,
		0xa9, 0x76, 0x62, 0x4d, 0x41, 0xa4, 0x09, 0x89, 0x33, 0x15, 0x51, 0x26, 0x27, 0xc6, 0xe4, 0x44,
		0x98, 0x96, 0xf8, 0x26, 0xcb, 0x65, 0xe8, 0xae, 0x0e, 0x2d, 0xd8, 0x9d, 0x9e, 0xeb, 0x5b, 0x43,
		0xa7, 0xdd, 0x97, 0x74, 0xd5, 0xec, 0x73, 0xa3, 0xe8, 0x2e, 0x98, 0x7d, 0x8d, 0x1d, 0xc4, 0x93,
		0xaf, 0x8e, 0x4f, 0x4e, 0x2f, 0xce, 0x2e, 0xdb, 0x5f, 0xae, 0x89, 0x0a, 0xe8, 0x4b, 0x38, 0x5e,
		0x0a, 0x05, 0xf4, 0x49, 0x8c, 0x05, 0xa0, 0x80, 0x9e, 0x50, 0xeb, 0x4f, 0x2d, 0xde, 0xed, 0x08,
		0x5f, 0xb9, 0xea, 0x39, 0x12, 0x5d, 0x0a, 0xab, 0x9f, 0xf0, 0x26, 0x82, 0x0c, 0x44, 0xe1, 0x2c,
		0xbe, 0xf5, 0x4f, 0xb6, 0x64, 0x08, 0x20, 0xdf, 0x7d, 0xb9, 0xbc, 0x6c, 0x9e, 0xb7, 0xc7, 0x68,
		0x7c, 0x7b, 0x77, 0x72, 0xf7, 0xe5, 0x96, 0x6a, 0x85, 0x8d, 0x32, 0x39, 0x92, 0x34, 0x25, 0x4b,
		0x1c, 0xa0, 0x9c, 0x3c, 0xb4, 0xa9, 0xef, 0xa2, 0x8b, 0xdd, 0x7d, 0xc8, 0xc6, 0x33, 0x3a, 0xbd,
		0xfa, 0x9f, 0xcb, 0xb4, 0x45, 0x38, 0x5b, 0x49, 0x47, 0xe3, 0x44, 0x6e, 0xb6, 0xec, 0x08, 0xe9,
		0x44, 0x6e, 0x48, 0x12, 0x37, 0x9b, 0x1a, 0xd5, 0xec, 0x20, 0xe0, 0x8d, 0xe0, 0x8d, 0xe0, 0x8d,
		0xe0, 0x8d, 0x5a, 0x2d, 0x5e, 0xaa, 0xc8, 0xf5, 0x1f, 0x29, 0x29, 0xe3, 0x61, 0x0e, 0x7c, 0xc1,
		0x53, 0xe0, 0x75, 0xac, 0x30, 0x72, 0x83, 0xc8, 0x55, 0xcf, 0x74, 0xde, 0x60, 0x7e, 0x18, 0xba,
		0x98, 0x45, 0x09, 0xbe, 0x86, 0xc5, 0xd7, 0x44, 0xf2, 0x5b, 0x08, 0x5f, 0x93, 0x40, 0x5f, 0x33,
		0x9a, 0x18, 0xf8, 0x1a, 0xcd, 0x16, 0xdf, 0x77, 0x7d, 0x75, 0x48, 0xe8, 0x6a, 0x28, 0x82, 0x13,
		0xb4, 0x55, 0xd5, 0x84, 0xc5, 0x1f, 0x1c, 0x55, 0xd4, 0x4c, 0xa5, 0xb1, 0x5c, 0x55, 0xd3, 0x9c,
		0x75, 0xaf, 0x84, 0xf1, 0x0e, 0x96, 0xea, 0x68, 0xee, 0xa9, 0x6f, 0x64, 0x68, 0xea, 0x53, 0x52,
		0xb5, 0xd4, 0xca, 0x01, 0x71, 0xef, 0x09, 0x15, 0xb9, 0x0e, 0x1d, 0x63, 0x8f, 0xaf, 0x0f, 0x3a,
		0x8d, 0xd0, 0x0d, 0x42, 0x37, 0xa0, 0xd3, 0x5a, 0x2d, 0xde, 0xf5, 0xd5, 0x41, 0x85, 0x90, 0x4e,
		0x1f, 0x80, 0x4e, 0x9b, 0xa1, 0xd3, 0x65, 0x26, 0x4e, 0x55, 0x29, 0x57, 0x1b, 0xd5, 0xc3, 0x83,
		0x7a, 0xf5, 0x10, 0xbc, 0x3a, 0xaf, 0xbc, 0x7a, 0x6a, 0x03, 0x20, 0xd8, 0x20, 0xd8, 0x64, 0x04,
		0x9b, 0x66, 0x73, 0xe0, 0x02, 0xcb, 0xa6, 0xd8, 0xda, 0xb2, 0xb2, 0x92, 0xef, 0xfc, 0xf6, 0xba,
		0x7d, 0xd1, 0xbc, 0xbb, 0x39, 0xfb, 0xdc, 0x3e, 0xbb, 0xfc, 0xbd, 0x79, 0x73, 0x76, 0xa7, 0x7d,
		0x67, 0x20, 0x28, 0x3e, 0x28, 0x3e, 0x28, 0x3e, 0x28, 0x3e, 0xaa, 0xfa, 0x36, 0x7b, 0x50, 0x33,
		0x90, 0x7c, 0xf7, 0xe7, 0x75, 0x13, 0x15, 0x7d, 0x6f, 0x78, 0x60, 0xaf, 0x3e, 0x0c, 0xd5, 0x7d,
		0x9b, 0x3c, 0xaf, 0x93, 0x4f, 0xb7, 0x57, 0xe7, 0x5f, 0xee, 0x9a, 0x78, 0x5c, 0x1b, 0x3d, 0xae,
		0x9b, 0xe6, 0xf9, 0xc9, 0xdd, 0xd9, 0x7f, 0x9a, 0xa8, 0x8a, 0xcc, 0x43, 0x55, 0x64, 0xbc, 0x29,
		0x92, 0x88, 0xe8, 0x8f, 0xae, 0x0e, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0x0d, 0xa6, 0xad, 0xd5, 0xe2,
		0x51, 0x07, 0xa9, 0xe3, 0xb7, 0x0e, 0x57, 0x9c, 0x88, 0x84, 0xef, 0x10, 0xfa, 0x80, 0x99, 0x31,
		0xe0, 0x09, 0xe0, 0x09, 0xe0, 0x09, 0xe0, 0x09, 0xb4, 0x5a, 0x3c, 0xaa, 0x14, 0xf9, 0x34, 0x63,
		0x26, 0xab, 0x14, 0xcb, 0xc8, 0xa6, 0x6e, 0x34, 0xf5, 0x59, 0xcc, 0xa6, 0xd6, 0x6a, 0x48, 0xa3,
		0x72, 0x5f, 0xb5, 0x95, 0x0b, 0x62, 0x1d, 0x28, 0x31, 0x9a, 0x78, 0x4b, 0xaa, 0x67, 0x4f, 0x58,
		0x91, 0xf8, 0xdf, 0xbe, 0x90, 0x4a, 0x74, 0x28, 0x89, 0xf6, 0xda, 0x31, 0x19, 0x92, 0xac, 0x5f,
		0x2e, 0xaf, 0x6f, 0xae, 0xee, 0x9a, 0x9f, 0x91, 0x5b, 0x05, 0xcf, 0x07, 0xcf, 0x07, 0xcf, 0xd7,
		0x6e, 0xf1, 0xc8, 0xad, 0x6e, 0xf8, 0xa0, 0x62, 0x1c, 0x3e, 0xbb, 0xba, 0x44, 0x6e, 0x75, 0xa3,
		0x07, 0x76, 0x7e, 0x76, 0xf9, 0xaf, 0xf6, 0xcc, 0x53, 0xbb, 0x69, 0xfe, 0xfb, 0xcb, 0xd9, 0x0d,
		0xf2, 0xab, 0xbf, 0x7c, 0x66, 0x97, 0x57, 0xa7, 0xcd, 0xc5, 0x07, 0xd7, 0xbc, 0x45, 0x66, 0xfa,
		0xa7, 0x4f, 0x6e, 0x96, 0x28, 0x21, 0xc5, 0x9a, 0x03, 0x2d, 0x10, 0x89, 0x20, 0x54, 0x6e, 0xcf,
		0xfd, 0x3f, 0x61, 0x29, 0xb7, 0x27, 0x22, 0x3a, 0x05, 0xb0, 0x34, 0x12, 0x88, 0x38, 0x88, 0x38,
		0x88, 0x38, 0x88, 0xb8, 0x56, 0x8b, 0xef, 0xbb, 0xbe, 0x2a, 0xd7, 0x09, 0x39, 0x78, 0x1d, 0x11,
		0xf7, 0xd7, 0x1b, 0xc7, 0xb9, 0x00, 0x6f, 0x1f, 0x07, 0x11, 0xf7, 0xc4, 0x4e, 0x7d, 0xbd, 0x56,
		0x3b, 0x40, 0xcc, 0x9d, 0xfd, 0xaa, 0x79, 0x88, 0xb9, 0x4b, 0xa1, 0xfa, 0x21, 0xc3, 0xa9, 0x5e,
		0x0b, 0xe3, 0xd0, 0xc5, 0xd6, 0x1b, 0xe0, 0xef, 0x38, 0xd6, 0x2b, 0xcf, 0xfc, 0x1d, 0xc7, 0x7a,
		0x51, 0xf1, 0x77, 0x14, 0xcc, 0x80, 0xbe, 0x83, 0xbe, 0x83, 0xbe, 0xbf, 0x75, 0xea, 0x71, 0xea,
		0x00, 0xa8, 0x3b, 0x05, 0x75, 0x7f, 0x0a, 0x22, 0xe5, 0xf4, 0x95, 0x25, 0x3c, 0xf7, 0xd1, 0x7d,
		0xf0, 0x08, 0xcb, 0xd1, 0x97, 0x87, 0xa2, 0x23, 0xf0, 0x43, 0xa6, 0x04, 0x0e, 0x8f, 0x18, 0x7c,
		0x9e, 0x39, 0x3c, 0x62, 0xf0, 0x14, 0x16, 0xff, 0x10, 0x04, 0x9e, 0xb0, 0x7d, 0xca, 0x42, 0x98,
		0x72, 0x1e, 0xfc, 0x8e, 0xfb, 0xe8, 0xdb, 0x9e, 0xeb, 0x3f, 0x5a, 0x61, 0x14, 0xa8, 0xc0, 0x09,
		0x3c, 0x42, 0xc7, 0xb3, 0x3c, 0x16, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x83, 0x56, 0x8b,
		0x47, 0x9d, 0xe4, 0x86, 0x0f, 0xea, 0xfa, 0xe4, 0xee, 0xf7, 0xf6, 0x6d, 0xf3, 0xee, 0xcb, 0xf5,
		0xa8, 0x86, 0xed, 0xea, 0xf3, 0xd5, 0x39, 0x6a, 0x25, 0xdf, 0xf0, 0xd0, 0xce, 0x4f, 0xd1, 0x5f,
		0x6e, 0xb3, 0x27, 0x75, 0x73, 0xfb, 0x1f, 0x3c, 0xaa, 0xcd, 0x1e, 0xd5, 0xed, 0x0d, 0x8a, 0x22,
		0xf3, 0x50, 0x14, 0x29, 0x83, 0xae, 0xb2, 0xc2, 0x48, 0x88, 0x1e, 0x71, 0x47, 0xbe, 0xc5, 0x81,
		0xe8, 0xa2, 0x3d, 0x5d, 0xdb, 0x93, 0x08, 0xf7, 0x20, 0x65, 0x9b, 0x6b, 0x4e, 0x8f, 0x94, 0x2d,
		0xc2, 0x3d, 0x09, 0x76, 0x3a, 0x24, 0xab, 0x7b, 0xc6, 0xd7, 0x8c, 0xae, 0x0f, 0x17, 0x00, 0x17,
		0x00, 0x17, 0x00, 0x17, 0xa0, 0x37, 0xac, 0x13, 0x5a, 0x76, 0xa7, 0x13, 0x09, 0x29, 0x29, 0xbd,
		0xc0, 0x11, 0xc1, 0xb5, 0xe3, 0x67, 0x93, 0xba, 0xd2, 0x9d, 0xd7, 0x27, 0xff, 0xad, 0x4a, 0xf8,
		0xec, 0x97, 0xe6, 0x80, 0xb0, 0xbb, 0x47, 0xe1, 0xda, 0x56, 0x4a, 0x44, 0x3e, 0x69, 0x24, 0x6a,
		0x34, 0xd0, 0x7f, 0xdf, 0xbf, 0xbf, 0x2f, 0x59, 0x47, 0xad, 0x97, 0xfb, 0xb2, 0x75, 0xd4, 0x1a,
		0xbf, 0x2c, 0x8f, 0xfe, 0x1a, 0xbf, 0xae, 0xdc, 0x97, 0xac, 0xea, 0xe4, 0x75, 0xed, 0xbe, 0x64,
		0xd5, 0x5a, 0xfb, 0x7f, 0xfd, 0xf5, 0x71, 0xff, 0xc7, 0xc1, 0xe0, 0xed, 0x5f, 0xfc, 0x07, 0x5d,
		0xcc, 0xa0, 0x45, 0x39, 0x19, 0x57, 0xb7, 0x67, 0x7f, 0x60, 0x46, 0x8c, 0xc7, 0x5b, 0x08, 0x83,
		0x68, 0x3c, 0xf0, 0x54, 0x07, 0x3c, 0x6d, 0xb7, 0x18, 0x6c, 0xab, 0x7b, 0x62, 0xfd, 0xd6, 0xfa,
		0x51, 0xfe, 0x50, 0x1d, 0x1c, 0xef, 0xff, 0x68, 0x0c, 0x16, 0xdf, 0x7c, 0x59, 0xf5, 0xb1, 0xf2,
		0x87, 0xc6, 0xe0, 0x78, 0xcd, 0xbf, 0xd4, 0x07, 0xc7, 0x1b, 0x5e, 0xa3, 0x36, 0x78, 0xbf, 0xf4,
		0xd1, 0xe1, 0xfb, 0x95, 0x75, 0x5f, 0xa8, 0xae, 0xf9, 0xc2, 0xc1, 0xba, 0x2f, 0x1c, 0xac, 0xf9,
		0xc2, 0xda, 0x5b, 0xaa, 0xac, 0xf9, 0x42, 0x6d, 0xf0, 0xb2, 0xf4, 0xf9, 0xf7, 0xab, 0x3f, 0x5a,
		0x1f, 0xec, 0xbf, 0xac, 0xfb, 0xb7, 0xc6, 0xe0, 0xe5, 0x78, 0x1f, 0x60, 0x0d, 0xfb, 0xcc, 0xad,
		0x7d, 0xa2, 0xe4, 0x34, 0x31, 0xb1, 0x20, 0xda, 0x0e, 0x57, 0x14, 0xad, 0xad, 0x10, 0x07, 0x5a,
		0x19, 0x07, 0x42, 0x79, 0x4f, 0x42, 0xe3, 0x40, 0x28, 0xef, 0x21, 0xa1, 0xfb, 0x28, 0xef, 0xd9,
		0xec, 0x41, 0xdd, 0x7d, 0xb9, 0xbc, 0x6c, 0x9e, 0xe3, 0x08, 0xb4, 0x8d, 0x1e, 0xd6, 0x75, 0x05,
		0x05, 0x2a, 0x3f, 0x7d, 0x3c, 0x17, 0xd7, 0xa8, 0x4b, 0x49, 0x6c, 0x5d, 0xca, 0xbb, 0x04, 0x59,
		0x69, 0xe1, 0xc4, 0xf7, 0x03, 0x65, 0x6b, 0x2f, 0x6a, 0x29, 0x48, 0xe7, 0x49, 0xf4, 0xec, 0xd0,
		0x56, 0x4f, 0x43, 0x8b, 0x2c, 0x06, 0xa1, 0xf0, 0x9d, 0x11, 0x75, 0xb3, 0x7c, 0xa1, 0xfe, 0x0e,
		0xa2, 0xaf, 0x96, 0xeb, 0x4b, 0x65, 0xfb, 0x8e, 0x28, 0x2e, 0xbe, 0x21, 0x97, 0xde, 0x29, 0x0e,
		0x9d, 0x73, 0xd1, 0x93, 0xa1, 0x2c, 0x3a, 0x81, 0x2f, 0x55, 0x64, 0xbb, 0xbe, 0xe8, 0x58, 0xc3,
		0xab, 0x17, 0x55, 0xdf, 0xf7, 0x85, 0x27, 0xe3, 0xbf, 0x8b, 0xe3, 0x41, 0xf4, 0x58, 0xff, 0xee,
		0x33, 0xa5, 0x61, 0x96, 0xf4, 0xf6, 0xbc, 0xa2, 0xe8, 0x75, 0xa5, 0x99, 0xea, 0x6b, 0xa7, 0xf8,
		0x14, 0xd4, 0x9e, 0x90, 0xd2, 0x53, 0x51, 0x79, 0x72, 0x0a, 0x4f, 0x4e, 0xdd, 0x69, 0x29, 0x7b,
		0xb2, 0x70, 0x59, 0x3b, 0x35, 0x9f, 0x5a, 0xac, 0x27, 0xec, 0xae, 0x5e, 0x3a, 0x3e, 0xa5, 0xe1,
		0x1a, 0xf7, 0x5b, 0x17, 0xae, 0x63, 0xd7, 0xf1, 0xf1, 0x63, 0x51, 0x2a, 0x5b, 0x89, 0xe2, 0x08,
		0xb1, 0x32, 0x84, 0xeb, 0x61, 0x25, 0xb4, 0xc6, 0x4e, 0xcb, 0xb2, 0x95, 0x8a, 0xdc, 0x87, 0xbe,
		0x1a, 0xb1, 0x73, 0xcd, 0x40, 0xbf, 0x7a, 0x18, 0xbd, 0xc8, 0x5f, 0x06, 0xf2, 0x03, 0xf9, 0x81,
		0xfc, 0x7a, 0x6c, 0xf6, 0xd4, 0xd5, 0x7b, 0xe6, 0x6e, 0xc1, 0x99, 0xac, 0x2a, 0xa2, 0xe8, 0x71,
		0x7c, 0x7d, 0x9a, 0xf8, 0x71, 0x19, 0xf1, 0x63, 0xc4, 0x8f, 0x93, 0x04, 0x45, 0x3c, 0x90, 0x44,
		0x14, 0xc4, 0xd0, 0xbd, 0x9d, 0xc4, 0x8d, 0x68, 0x0c, 0xbe, 0x23, 0xa4, 0x72, 0x7d, 0x9b, 0x64,
		0xaf, 0xcd, 0xd2, 0xaa, 0x9a, 0x1d, 0x8c, 0xc8, 0x56, 0x68, 0xcf, 0x3d, 0x22, 0x03, 0x35, 0x0e,
		0x70, 0x63, 0x04, 0x39, 0x2e, 0xb0, 0x63, 0x07, 0x3d, 0x76, 0xf0, 0xe3, 0x05, 0x41, 0x1a, 0x30,
		0x24, 0x02, 0x45, 0x3a, 0x05, 0xbf, 0x76, 0xc5, 0x90, 0x16, 0x5b, 0x2f, 0x11, 0xb2, 0x23, 0xc2,
		0x31, 0x48, 0x8b, 0xaf, 0x27, 0x7f, 0x68, 0x17, 0xfd, 0x9e, 0x81, 0x62, 0xec, 0xa5, 0x39, 0x3a,
		0x64, 0x18, 0x8b, 0xab, 0xba, 0x6c, 0x3a, 0x60, 0x56, 0x4a, 0x82, 0x27, 0x7f, 0x5a, 0x1c, 0x93,
		0xc4, 0x59, 0x07, 0x98, 0xdd, 0x99, 0x22, 0x1d, 0x61, 0xf0, 0x21, 0x43, 0x70, 0x57, 0x07, 0xdc,
		0xe9, 0x5d, 0x44, 0x28, 0xaa, 0xcd, 0x54, 0x51, 0x6d, 0x6e, 0xc0, 0x1f, 0x76, 0x9b, 0x4d, 0xbb,
		0xa5, 0x75, 0x85, 0xb9, 0x2f, 0x66, 0x4f, 0x76, 0xc0, 0x8f, 0xa8, 0x5a, 0x68, 0x7a, 0x7d, 0x53,
		0x55, 0x43, 0x2b, 0x93, 0xa4, 0x5a, 0x6b, 0x89, 0xf4, 0xcf, 0xaf, 0xd6, 0x06, 0xf0, 0x95, 0x51,
		0x8b, 0x98, 0x9e, 0x1d, 0x3d, 0x5b, 0xf1, 0xd3, 0xa7, 0x6a, 0xfb, 0xbe, 0x38, 0x12, 0xd2, 0x46,
		0x48, 0x1b, 0x99, 0x8f, 0xa0, 0x22, 0x6d, 0xc4, 0xe8, 0x45, 0xc8, 0xd2, 0x46, 0xe4, 0x30, 0xc6,
		0x0d, 0x67, 0xc4, 0xb0, 0x46, 0x0e, 0x6f, 0x1c, 0x30, 0xc7, 0x08, 0x77, 0x5c, 0xb0, 0xc7, 0x0e,
		0x7f, 0xec, 0x30, 0xc8, 0x0b, 0x87, 0xb4, 0xf2, 0x82, 0x2a, 0x81, 0x44, 0x05, 0x93, 0xd3, 0x01,
		0xec, 0x4e, 0xcf, 0xf5, 0xad, 0xc7, 0x28, 0xe8, 0x87, 0x92, 0xde, 0x96, 0x27, 0xcb, 0x73, 0x6e,
		0xd4, 0x0f, 0x2c, 0xfd, 0x86, 0xca, 0xc4, 0xc3, 0x50, 0xc3, 0x27, 0x27, 0x8c, 0x1a, 0x80, 0x53,
		0x6e, 0x58, 0x35, 0x06, 0xaf, 0xc6, 0x60, 0xd6, 0x0c, 0xdc, 0xd2, 0x47, 0x75, 0xf6, 0xe8, 0xd3,
		0x27, 0xe4, 0x30, 0x3c, 0x1d, 0x88, 0xa8, 0x4e, 0xf3, 0x97, 0x0b, 0x9c, 0xa4, 0x7e, 0xd3, 0x30,
		0x24, 0xb3, 0x43, 0xb3, 0x09, 0x88, 0x36, 0x08, 0xd5, 0xa6, 0x20, 0xdb, 0x38, 0x74, 0x1b, 0x87,
		0x70, 0xb3, 0x50, 0xce, 0x03, 0xe9, 0x4c, 0xd0, 0xce, 0x0e, 0xf1, 0xd3, 0x01, 0xc5, 0x77, 0xc7,
		0xeb, 0x77, 0xc4, 0x98, 0x05, 0xf3, 0x2f, 0x9e, 0x09, 0x5e, 0xcc, 0xdf, 0x06, 0xb3, 0xfd, 0xf2,
		0xf4, 0x02, 0x35, 0xee, 0x10, 0x4c, 0x3a, 0x86, 0x04, 0x38, 0x08, 0xd3, 0x8e, 0x22, 0x31, 0x0e,
		0x23, 0x31, 0x8e, 0x23, 0x19, 0x0e, 0x84, 0xd7, 0x91, 0x30, 0x3b, 0x94, 0xe9, 0x23, 0x26, 0xaf,
		0x01, 0xfe, 0xe5, 0x8a, 0xd7, 0xbf, 0xdb, 0xf7, 0xcd, 0x4c, 0xbf, 0x61, 0x60, 0xec, 0x99, 0xdd,
		0xc3, 0x3f, 0xf9, 0x9f, 0x12, 0xd6, 0xa3, 0x17, 0x3c, 0xd8, 0x73, 0x59, 0xdf, 0xe1, 0x3a, 0xb0,
		0x66, 0x83, 0x54, 0xc5, 0x99, 0xff, 0x98, 0x7d, 0x6d, 0xe9, 0xdb, 0x91, 0x9c, 0x54, 0xfb, 0x3d,
		0x77, 0xa5, 0x3a, 0x51, 0x2a, 0x32, 0x63, 0xc3, 0x17, 0xae, 0xdf, 0xf4, 0xc4, 0x10, 0xa2, 0x24,
		0xbf, 0xbf, 0xde, 0x8b, 0x9b, 0xa2, 0xcf, 0xdc, 0x41, 0xf9, 0xb0, 0x5a, 0xad, 0x37, 0xaa, 0xd5,
		0x52, 0xe3, 0xa0, 0x51, 0x3a, 0xaa, 0xd5, 0xca, 0x75, 0x8a, 0x83, 0xa7, 0x7e, 0x79, 0x53, 0x57,
		0x51, 0x47, 0x44, 0xa2, 0xf3, 0xe9, 0xb9, 0x70, 0xbc, 0xe7, 0xf7, 0x3d, 0xef, 0x5d, 0x36, 0xf1,
		0x9a, 0xd1, 0xd6, 0x0b, 0xae, 0x3f, 0x26, 0xc2, 0xb6, 0xe7, 0x99, 0xe6, 0xe4, 0xcb, 0xb7, 0x02,
		0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e,
		0x5e, 0x0e, 0x5e, 0x9e, 0x37, 0x5e, 0xee, 0x3f, 0x27, 0x86, 0x97, 0x4f, 0x6f, 0x05, 0xbc, 0x1c,
		0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c,
		0xbc, 0xdc, 0x24, 0x2f, 0xcf, 0x54, 0x49, 0x0e, 0xf1, 0x4e, 0xd3, 0xb5, 0xe3, 0x26, 0x6b, 0x07,
		0xea, 0xe2, 0xf6, 0xa2, 0xe5, 0x37, 0xe6, 0x80, 0x97, 0x62, 0xc3, 0xaa, 0x39, 0x73, 0x63, 0x30,
		0xb5, 0xc2, 0xe8, 0x68, 0x69, 0xfe, 0x92, 0xdb, 0xf1, 0xb0, 0x19, 0xaf, 0xb8, 0xad, 0xa0, 0xe2,
		0x36, 0x43, 0xc2, 0x10, 0x15, 0xb7, 0xa8, 0xb8, 0xd5, 0xf7, 0x28, 0x51, 0x71, 0x8b, 0x08, 0x62,
		0x16, 0x1d, 0x43, 0x02, 0x1c, 0x84, 0x69, 0x47, 0x91, 0x18, 0x87, 0x91, 0x18, 0xc7, 0x91, 0x0c,
		0x07, 0xc2, 0xaf, 0x48, 0xf7, 0x10, 0x41, 0xdc, 0x33, 0x01, 0xf0, 0x88, 0x20, 0xa6, 0xd7, 0x7e,
		0x11, 0x41, 0x44, 0x04, 0xd1, 0x14, 0x5e, 0xa3, 0xe2, 0x16, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c,
		0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x3c, 0xa7, 0xbc,
		0x1c, 0x15, 0xb7, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0,
		0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0x06, 0x46, 0x42, 0xc5, 0x6d, 0x82, 0x2b, 0x6e, 0xc7,
		0x85, 0x9c, 0x59, 0x29, 0xb8, 0x4d, 0xf5, 0x39, 0xbd, 0xcc, 0xf6, 0x9b, 0x6a, 0xbb, 0x2d, 0xb0,
		0x94, 0x56, 0x47, 0x7d, 0x47, 0xf9, 0x31, 0xcb, 0xbb, 0x1c, 0xff, 0xe0, 0xb3, 0xf8, 0xf7, 0xb6,
		0x2f, 0x42, 0x4f, 0xb6, 0xcf, 0x65, 0x28, 0xdb, 0x9f, 0x5f, 0x7f, 0xef, 0x90, 0x13, 0xb5, 0xef,
		0x46, 0xbf, 0xad, 0x7d, 0x5d, 0xb9, 0x1e, 0xbf, 0x3a, 0x99, 0xfe, 0xc8, 0xe1, 0x7b, 0xd7, 0xe3,
		0x9f, 0x34, 0xfa, 0xe4, 0xc9, 0xf0, 0x17, 0xfd, 0x73, 0xfc, 0x83, 0x52, 0xda, 0x96, 0x8c, 0x70,
		0x51, 0x14, 0x1c, 0xdb, 0xef, 0xb8, 0x1d, 0x5b, 0x09, 0x4b, 0x0a, 0x27, 0xf0, 0x3b, 0x13, 0x4b,
		0x60, 0x3c, 0xeb, 0x7f, 0xfd, 0x2d, 0xe0, 0xe0, 0xff, 0xa4, 0x86, 0x66, 0x70, 0xf0, 0x7f, 0x06,
		0x43, 0x2b, 0x38, 0xf8, 0xff, 0xed, 0x8f, 0x8c, 0xef, 0xe0, 0xff, 0x35, 0x28, 0x69, 0xa0, 0x15,
		0xc0, 0xba, 0x3b, 0x41, 0x73, 0x80, 0xb4, 0xc1, 0xb8, 0x41, 0x38, 0x37, 0x05, 0xeb, 0xc6, 0xe1,
		0xdd, 0x38, 0xcc, 0x9b, 0x85, 0xfb, 0x6c, 0xc6, 0x45, 0xd8, 0xb7, 0x2a, 0x31, 0xf7, 0x81, 0x59,
		0x76, 0x02, 0x9c, 0xfd, 0x60, 0x0c, 0x41, 0xbf, 0x31, 0x17, 0x60, 0xd2, 0x15, 0x24, 0xc0, 0x25,
		0x98, 0x76, 0x0d, 0x89, 0x71, 0x11, 0x89, 0x71, 0x15, 0xc9, 0x70, 0x19, 0xbc, 0xae, 0x83, 0xd9,
		0x85, 0x18, 0x73, 0x25, 0xd3, 0x81, 0xc3, 0xc8, 0x0d, 0x22, 0x57, 0x3d, 0x9b, 0x5b, 0x6f, 0xd3,
		0x86, 0xb9, 0x93, 0x3b, 0x31, 0x64, 0xe5, 0x66, 0x6a, 0x7a, 0x8c, 0xbb, 0x9b, 0x24, 0xb8, 0x9d,
		0x04, 0xb9, 0x9f, 0xa4, 0xb8, 0xa1, 0xc4, 0xb9, 0xa3, 0xc4, 0xb9, 0xa5, 0x64, 0xb9, 0x27, 0x33,
		0x6e, 0xca, 0x90, 0xbb, 0x9a, 0x3e, 0x7a, 0x63, 0x35, 0x42, 0x4b, 0x88, 0xd1, 0x77, 0x7d, 0x55,
		0xae, 0x9b, 0x04, 0x8c, 0xd8, 0x7f, 0xd4, 0x0d, 0xde, 0xc2, 0x8d, 0xed, 0x3f, 0x0e, 0x9f, 0xc6,
		0xbd, 0xd1, 0x05, 0x69, 0x16, 0x30, 0xf7, 0xe2, 0xea, 0x1b, 0xe3, 0xc8, 0x9d, 0x10, 0x62, 0xb1,
		0x74, 0x3b, 0xff, 0xb1, 0xbd, 0xbe, 0x48, 0xd0, 0xfd, 0xfc, 0x16, 0xd9, 0x8e, 0x72, 0x03, 0xff,
		0xd4, 0x7d, 0x74, 0xc7, 0xc5, 0x52, 0xc6, 0xef, 0x6b, 0xf0, 0x21, 0x01, 0x26, 0x6c, 0x7f, 0x87,
		0x09, 0xff, 0xc2, 0x84, 0xeb, 0xb5, 0xda, 0x41, 0x0d, 0x66, 0x9c, 0x2c, 0x2e, 0x62, 0x7e, 0xf4,
		0xd6, 0xbb, 0x7c, 0xfc, 0x5e, 0x03, 0x30, 0x55, 0x30, 0x94, 0x87, 0x5c, 0xcb, 0xfb, 0x8c, 0x64,
		0x23, 0x11, 0x3b, 0x40, 0xec, 0x00, 0xb1, 0x03, 0xc4, 0x0e, 0x10, 0x3b, 0xc8, 0x44, 0xec, 0xc0,
		0xdc, 0x3e, 0xa3, 0x45, 0x07, 0x62, 0x62, 0xbf, 0xd1, 0x2b, 0x88, 0xaf, 0xdd, 0x77, 0x14, 0x56,
		0xc2, 0xc5, 0x32, 0xcd, 0x15, 0xef, 0x8d, 0x4b, 0xde, 0x8b, 0xfc, 0x3b, 0x8b, 0x0c, 0x32, 0xb0,
		0x4c, 0x27, 0xa5, 0x0c, 0xed, 0xfb, 0x78, 0xe5, 0x9a, 0x29, 0xab, 0xa3, 0x5f, 0x5b, 0xd3, 0xbc,
		0xf6, 0x5f, 0x58, 0xcf, 0x65, 0xe7, 0x37, 0x5a, 0xce, 0xe3, 0x09, 0x0c, 0x0b, 0x93, 0x64, 0x08,
		0x12, 0x1c, 0x4c, 0x90, 0x2b, 0xc1, 0x81, 0x5a, 0x99, 0xa4, 0x09, 0x0b, 0xd4, 0xca, 0x64, 0x58,
		0x38, 0xe0, 0x60, 0x82, 0xa9, 0x40, 0x18, 0x53, 0xfd, 0x05, 0x5f, 0x07, 0x16, 0xb3, 0x3b, 0x8b,
		0x61, 0xed, 0x3a, 0xb3, 0x4c, 0x5e, 0x18, 0xbb, 0xcf, 0x2c, 0x99, 0xb4, 0x29, 0xce, 0x52, 0x01,
		0x67, 0x01, 0x67, 0x01, 0x67, 0x01, 0x67, 0x21, 0x7c, 0xc4, 0xc6, 0xea, 0x7b, 0x6d, 0x47, 0xb9,
		0xdf, 0x84, 0xf9, 0x3c, 0x5d, 0x7c, 0x1f, 0xc8, 0xcf, 0x19, 0xb9, 0x01, 0xe4, 0xe7, 0x92, 0xe4,
		0x82, 0x12, 0xe7, 0x8a, 0x12, 0xe7, 0x92, 0x92, 0xe5, 0x9a, 0xcc, 0xb8, 0x28, 0x43, 0xae, 0xca,
		0xbc, 0xcc, 0x5e, 0x42, 0x8c, 0x87, 0x20, 0xf0, 0x84, 0xed, 0x27, 0x21, 0x3f, 0x57, 0x46, 0x69,
		0x11, 0xd9, 0x33, 0xc6, 0x56, 0x24, 0xd0, 0x15, 0xd0, 0x15, 0xd0, 0x15, 0xd0, 0x15, 0xd0, 0x95,
		0x34, 0xd3, 0x15, 0x6c, 0x45, 0xc2, 0x56, 0xa4, 0xd7, 0x07, 0x81, 0xad, 0x48, 0xeb, 0x6f, 0x07,
		0x5b, 0x91, 0x92, 0x0a, 0xa7, 0xf3, 0x26, 0x8c, 0xad, 0x48, 0xbf, 0x34, 0x61, 0x6c, 0x45, 0x4a,
		0x20, 0x17, 0x31, 0x3f, 0x3a, 0xb6, 0x22, 0xd1, 0x99, 0x39, 0xb6, 0x22, 0x21, 0x76, 0x80, 0xd8,
		0x01, 0x62, 0x07, 0x88, 0x1d, 0x20, 0x76, 0x90, 0x95, 0xd8, 0x01, 0xb6, 0x22, 0xed, 0x61, 0x2b,
		0x52, 0x0a, 0x46, 0xc4, 0x56, 0xa4, 0xcc, 0x6d, 0x45, 0x62, 0x6c, 0x58, 0xc3, 0x6f, 0xb3, 0xd9,
		0x3a, 0x78, 0xf8, 0x5f, 0xe2, 0xd9, 0x98, 0xe0, 0x30, 0xd3, 0x57, 0xcd, 0x5c, 0x3f, 0xb5, 0x44,
		0xf5, 0x51, 0x33, 0xd3, 0x3f, 0x0d, 0x7d, 0xc6, 0xd2, 0x0e, 0xee, 0x05, 0xd6, 0x2d, 0x0c, 0xd4,
		0xdd, 0x9d, 0x3e, 0x4f, 0x7e, 0xe5, 0xed, 0xe4, 0x47, 0x5e, 0xb3, 0x6d, 0x3f, 0x41, 0xaf, 0xb5,
		0x44, 0xad, 0xe1, 0xec, 0xac, 0x5d, 0xf4, 0x29, 0x5b, 0x9e, 0x5c, 0xa6, 0x7e, 0x07, 0xbc, 0xfd,
		0x0d, 0xd0, 0x81, 0x2c, 0x55, 0x91, 0x55, 0x74, 0x20, 0xcb, 0x66, 0xe4, 0x13, 0x1d, 0xc8, 0x36,
		0x83, 0x60, 0x19, 0x76, 0x2d, 0xe5, 0x8a, 0x87, 0x48, 0xd8, 0x5f, 0x45, 0x64, 0xa0, 0xf1, 0xd8,
		0xc2, 0x0d, 0xf0, 0xf6, 0x1b, 0x2b, 0xa1, 0xdf, 0x58, 0x9a, 0xc1, 0xdb, 0x14, 0x88, 0x1b, 0x07,
		0x73, 0xe3, 0xa0, 0x6e, 0x16, 0xdc, 0xb3, 0x19, 0xf6, 0x63, 0x4f, 0x53, 0x2d, 0x81, 0xb0, 0x35,
		0x42, 0x61, 0xd7, 0xe7, 0xec, 0x01, 0x36, 0xe5, 0xcb, 0x55, 0xc6, 0x31, 0x9b, 0x7e, 0xbf, 0x37,
		0x7c, 0xd4, 0x9c, 0x67, 0x3f, 0x9c, 0x8a, 0xae, 0xdd, 0xf7, 0x46, 0x0b, 0xe5, 0xe6, 0xe4, 0xf2,
		0xf4, 0xea, 0x22, 0x33, 0x11, 0x0d, 0x06, 0x96, 0x2e, 0xbe, 0x87, 0x9e, 0xeb, 0xb8, 0x6a, 0x24,
		0xa6, 0xad, 0x38, 0xfa, 0xc4, 0x4c, 0x55, 0x56, 0xdc, 0x03, 0xd8, 0x0a, 0xd8, 0x0a, 0xd8, 0x0a,
		0xd8, 0x0a, 0xd8, 0x0a, 0xe3, 0x8a, 0xe5, 0x2f, 0xa2, 0x31, 0x51, 0x34, 0xf3, 0x93, 0x22, 0x99,
		0x8f, 0x1f, 0x47, 0xa5, 0x2f, 0x1d, 0x6b, 0xce, 0x23, 0xc9, 0x55, 0x6f, 0xb2, 0x57, 0xca, 0x64,
		0x83, 0x6e, 0x3c, 0x05, 0x5e, 0xc7, 0x62, 0xdf, 0xb0, 0x3c, 0xb5, 0xf0, 0xf9, 0xe1, 0xb9, 0xda,
		0x1d, 0xbf, 0xf2, 0xd3, 0x12, 0x88, 0x4d, 0x26, 0x88, 0x4d, 0x24, 0xbf, 0x85, 0x20, 0x36, 0x39,
		0x24, 0x36, 0xa3, 0x89, 0x07, 0xb1, 0x49, 0x19, 0xb1, 0xe9, 0xbb, 0xbe, 0x3a, 0x34, 0x40, 0x6b,
		0x38, 0x2b, 0x9c, 0xcc, 0x6c, 0x1c, 0x36, 0x50, 0x52, 0x6a, 0x72, 0x63, 0xb0, 0xe9, 0x5d, 0x42,
		0x86, 0x37, 0xfe, 0x26, 0x61, 0x87, 0xa4, 0x89, 0x1d, 0x73, 0x26, 0x37, 0xf2, 0x26, 0xc5, 0xe4,
		0x1a, 0x39, 0x36, 0xb9, 0x8c, 0x16, 0x77, 0xb7, 0x20, 0x5c, 0x37, 0x36, 0x43, 0x33, 0x91, 0x71,
		0xc4, 0xc2, 0x33, 0x23, 0x19, 0x11, 0x0b, 0xcf, 0xa9, 0x64, 0x44, 0x2c, 0x3c, 0x8d, 0x92, 0x51,
		0xaa, 0xc8, 0x50, 0xba, 0xfe, 0x10, 0x5e, 0x79, 0xe3, 0x67, 0x36, 0x4a, 0x18, 0x3b, 0x41, 0x2f,
		0xec, 0x8f, 0x6b, 0xe7, 0xad, 0x9e, 0x50, 0x4f, 0x41, 0x87, 0xdf, 0x51, 0xaf, 0xbb, 0x11, 0xfe,
		0x10, 0x73, 0x8c, 0x38, 0xea, 0xf8, 0xfc, 0xea, 0xf3, 0xc9, 0xf9, 0xf9, 0x9f, 0xed, 0xcf, 0x57,
		0x17, 0xd7, 0x5f, 0xee, 0x9a, 0xa7, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11,
		0x9c, 0x2b, 0xd6, 0xed, 0x08, 0x5f, 0xb9, 0xea, 0xd9, 0x50, 0x5e, 0x9d, 0x33, 0x02, 0x7d, 0x16,
		0xff, 0xd4, 0x4f, 0xb6, 0x34, 0xd8, 0x8a, 0xe9, 0xfa, 0xe4, 0xee, 0xf7, 0xd8, 0xe7, 0x9d, 0xdc,
		0x9d, 0x5d, 0x5d, 0xb6, 0x2f, 0x9a, 0x77, 0xbf, 0x5f, 0x9d, 0x72, 0xa3, 0xc7, 0x28, 0x6c, 0x26,
		0x8d, 0x1c, 0xe4, 0x69, 0xf8, 0x38, 0xaf, 0xe6, 0x1f, 0x77, 0xcd, 0x9b, 0xcb, 0x11, 0xf5, 0xf8,
		0xf7, 0x97, 0xe6, 0xcd, 0x59, 0xf3, 0xb4, 0x90, 0x87, 0x20, 0xb1, 0xf1, 0xa7, 0x7e, 0x7d, 0x7e,
		0xf6, 0xf9, 0xec, 0xee, 0xfc, 0xcf, 0xf6, 0x69, 0xf3, 0xb7, 0xb3, 0x4b, 0x3c, 0x75, 0x8e, 0xa7,
		0xbe, 0xc4, 0xb1, 0x33, 0x1e, 0x9b, 0x6e, 0x65, 0x8d, 0x7f, 0x64, 0x53, 0x05, 0x4b, 0x11, 0x7d,
		0x33, 0xb1, 0xe7, 0x6c, 0xdd, 0x8d, 0x40, 0x79, 0x42, 0x79, 0x42, 0x79, 0x42, 0x79, 0x42, 0x79,
		0x72, 0x2a, 0xcf, 0xd0, 0xb2, 0x3b, 0x9d, 0x48, 0x48, 0x69, 0x42, 0x78, 0x1e, 0x31, 0x8e, 0x19,
		0x3f, 0xe3, 0xcc, 0x57, 0x3e, 0xbd, 0xce, 0xec, 0xb7, 0xaa, 0x81, 0xb9, 0x5d, 0x9a, 0xe3, 0x43,
		0x33, 0xbd, 0xb4, 0x95, 0x88, 0x7c, 0x63, 0x1d, 0x32, 0x0a, 0xff, 0x7d, 0xff, 0xfe, 0xbe, 0x64,
		0x1d, 0xb5, 0x5e, 0xee, 0xcb, 0xd6, 0x51, 0x6b, 0xfc, 0xb2, 0x3c, 0xfa, 0x6b, 0xfc, 0xba, 0x72,
		0x5f, 0xb2, 0xaa, 0x93, 0xd7, 0xb5, 0xfb, 0x92, 0x55, 0x6b, 0xed, 0xff, 0xf5, 0xd7, 0xc7, 0xfd,
		0x1f, 0x07, 0x83, 0xb7, 0x7f, 0xf1, 0x1f, 0xfc, 0x82, 0xa2, 0x65, 0x62, 0x52, 0xaf, 0x6e, 0xcf,
		0xfe, 0xc0, 0xcc, 0x66, 0x46, 0xbc, 0x19, 0x08, 0x06, 0x98, 0x85, 0xe3, 0x3a, 0xe0, 0xd8, 0xec,
		0xa2, 0xb5, 0xad, 0xee, 0x89, 0xf5, 0x5b, 0xeb, 0x47, 0xf9, 0x43, 0x75, 0x70, 0xbc, 0xff, 0xa3,
		0x31, 0x58, 0x7c, 0xf3, 0x65, 0xd5, 0xc7, 0xca, 0x1f, 0x1a, 0x83, 0xe3, 0x35, 0xff, 0x52, 0x1f,
		0x1c, 0x6f, 0x78, 0x8d, 0xda, 0xe0, 0xfd, 0xd2, 0x47, 0x87, 0xef, 0x57, 0xd6, 0x7d, 0xa1, 0xba,
		0xe6, 0x0b, 0x07, 0xeb, 0xbe, 0x70, 0xb0, 0xe6, 0x0b, 0x6b, 0x6f, 0xa9, 0xb2, 0xe6, 0x0b, 0xb5,
		0xc1, 0xcb, 0xd2, 0xe7, 0xdf, 0xaf, 0xfe, 0x68, 0x7d, 0xb0, 0xff, 0xb2, 0xee, 0xdf, 0x1a, 0x83,
		0x97, 0xe3, 0x7d, 0x38, 0x27, 0xd8, 0x39, 0xec, 0x3c, 0x13, 0xae, 0x1a, 0x15, 0xc7, 0x49, 0x8c,
		0xea, 0x46, 0xa2, 0x2b, 0x22, 0xe1, 0x3b, 0x06, 0xea, 0x8e, 0x67, 0xc6, 0x46, 0xec, 0x16, 0xb1,
		0x5b, 0xc4, 0x6e, 0x11, 0xbb, 0x45, 0xec, 0x96, 0x71, 0xc5, 0x62, 0xc3, 0x6a, 0x86, 0xe2, 0x04,
		0xd8, 0xb0, 0x4a, 0x7e, 0x68, 0xf3, 0xda, 0xf1, 0xb1, 0x61, 0x35, 0xb7, 0x26, 0x57, 0xa9, 0xd5,
		0xb0, 0x65, 0x15, 0x02, 0x32, 0xbf, 0x02, 0x32, 0x12, 0x2a, 0x7a, 0xb6, 0x94, 0xdb, 0x33, 0x51,
		0x0a, 0x34, 0x3b, 0x38, 0x24, 0x64, 0x16, 0x24, 0x24, 0xce, 0x3c, 0xca, 0xa9, 0x84, 0xc4, 0x99,
		0x47, 0x69, 0x95, 0x90, 0xe5, 0xba, 0x01, 0x0d, 0x59, 0x87, 0x86, 0x84, 0x86, 0x84, 0x86, 0x84,
		0x86, 0xcc, 0x80, 0xc9, 0xd5, 0x4b, 0x25, 0x68, 0x48, 0x68, 0xc8, 0xfc, 0x6a, 0x48, 0x29, 0x54,
		0x3f, 0x34, 0x78, 0x60, 0xef, 0xc2, 0xf8, 0xfc, 0xc7, 0x29, 0x34, 0xa0, 0x5e, 0xa1, 0x5e, 0xa1,
		0x5e, 0xa1, 0x5e, 0xa1, 0x5e, 0xb9, 0xd5, 0x2b, 0x12, 0xa0, 0x10, 0xaf, 0x99, 0x51, 0x12, 0x38,
		0xb1, 0x17, 0xe2, 0x95, 0xd9, 0xe4, 0x70, 0x62, 0x2f, 0xa4, 0x6b, 0x8e, 0xa5, 0x6b, 0x5f, 0x0a,
		0xcb, 0x91, 0x61, 0x97, 0x5f, 0xb4, 0x4e, 0x47, 0x86, 0x74, 0xcc, 0x82, 0x74, 0x44, 0xed, 0x6c,
		0x4e, 0xa5, 0x23, 0x6a, 0x67, 0xd3, 0x28, 0x1d, 0x1f, 0x82, 0xc0, 0x13, 0xb6, 0x6f, 0xe2, 0xd0,
		0x83, 0x72, 0x56, 0xdc, 0x73, 0xaa, 0x7b, 0xfc, 0x9f, 0xf8, 0x7e, 0x30, 0x3e, 0x7f, 0x88, 0xa7,
		0xd5, 0xbf, 0x74, 0x9e, 0x44, 0xcf, 0x0e, 0xe3, 0xae, 0x82, 0xc5, 0x20, 0x14, 0xbe, 0x33, 0x72,
		0x91, 0x96, 0x2f, 0xd4, 0xdf, 0x41, 0xf4, 0xd5, 0x72, 0x7d, 0xa9, 0x6c, 0xdf, 0x11, 0xc5, 0xc5,
		0x37, 0xe4, 0xd2, 0x3b, 0xc5, 0x21, 0xe8, 0x14, 0x3d, 0x19, 0xca, 0xa2, 0x13, 0xf8, 0x52, 0x45,
		0xb6, 0xeb, 0x8b, 0xce, 0xb8, 0xe5, 0xa0, 0xea, 0xfb, 0xbe, 0xf0, 0x64, 0xfc, 0x77, 0x31, 0xac,
		0x84, 0xd6, 0xf8, 0xa5, 0x65, 0x2b, 0x15, 0xb9, 0x0f, 0x7d, 0x25, 0xe4, 0xe8, 0xdd, 0x30, 0x72,
		0x7b, 0x76, 0xf4, 0x3c, 0xfe, 0xd6, 0xd2, 0x1b, 0xe3, 0x9b, 0xa3, 0x05, 0x36, 0x3a, 0x0b, 0x22,
		0xb4, 0x1e, 0x9e, 0x26, 0x0f, 0x9c, 0xcd, 0x1d, 0x98, 0xa8, 0x21, 0x1b, 0x25, 0xe4, 0xa4, 0x82,
		0x06, 0x28, 0x20, 0x37, 0xf5, 0x33, 0x46, 0xf9, 0x8c, 0x51, 0x3d, 0x33, 0x14, 0x2f, 0xdd, 0xfe,
		0x94, 0x8d, 0xca, 0x19, 0x68, 0x44, 0xcc, 0xd9, 0x80, 0x78, 0xb6, 0xf1, 0x30, 0x57, 0xf7, 0xe0,
		0x74, 0xfa, 0xe1, 0xd1, 0xd3, 0xe1, 0x73, 0xc4, 0xe3, 0xe1, 0x78, 0x3c, 0x71, 0x99, 0xcb, 0x13,
		0x57, 0xe0, 0x89, 0xe1, 0x89, 0xe1, 0x89, 0x33, 0xe5, 0x89, 0x4f, 0x5d, 0x9e, 0x9d, 0x3c, 0x05,
		0x5b, 0xca, 0xc0, 0x71, 0x6d, 0x25, 0x3a, 0xa3, 0xfa, 0x09, 0x4b, 0x0a, 0x29, 0xdd, 0xc0, 0x97,
		0xfc, 0xb1, 0xf4, 0xb5, 0x77, 0x82, 0xd8, 0x7a, 0xda, 0x60, 0xdc, 0x20, 0x9c, 0x9b, 0x82, 0x75,
		0xe3, 0xf0, 0x6e, 0x1c, 0xe6, 0xcd, 0xc2, 0x3d, 0x0f, 0xec, 0x33, 0xc1, 0x3f, 0xbf, 0x20, 0x33,
		0x28, 0xcc, 0x4c, 0x08, 0xb4, 0x55, 0x42, 0x6d, 0xdd, 0xff, 0xa4, 0xfb, 0xe8, 0xdb, 0x9e, 0xeb,
		0x3f, 0x5a, 0x61, 0x14, 0xa8, 0xc0, 0x09, 0x3c, 0x59, 0x1c, 0x39, 0x28, 0x25, 0x8a, 0x13, 0x1f,
		0x35, 0x79, 0x51, 0xf4, 0x02, 0xc7, 0xf6, 0x2c, 0xd7, 0xef, 0x88, 0xef, 0x85, 0x4c, 0x59, 0xe2,
		0xb9, 0x2b, 0xd5, 0x89, 0x52, 0x11, 0xaf, 0x35, 0x5e, 0xb8, 0x7e, 0xd3, 0x13, 0x43, 0x30, 0x91,
		0xbc, 0x65, 0x36, 0x85, 0x0b, 0xfb, 0xfb, 0xcc, 0xc8, 0xe5, 0xc3, 0x6a, 0xb5, 0xde, 0xa8, 0x56,
		0x4b, 0x8d, 0x83, 0x46, 0xe9, 0xa8, 0x56, 0x2b, 0xd7, 0x59, 0xfb, 0x2d, 0x5d, 0x45, 0x1d, 0x11,
		0x89, 0xce, 0xa7, 0xe7, 0xc2, 0xf1, 0x9e, 0xdf, 0xf7, 0x3c, 0xd4, 0x86, 0x6c, 0xfc, 0xe8, 0x1c,
		0x19, 0x76, 0xad, 0x9e, 0x50, 0x91, 0xeb, 0xf0, 0x53, 0xda, 0xd9, 0xc1, 0xc1, 0x62, 0xc1, 0x62,
		0xc1, 0x62, 0xc1, 0x62, 0xc1, 0x62, 0x19, 0x57, 0x6c, 0xdf, 0xf5, 0x55, 0xbd, 0x6a, 0x80, 0xc4,
		0x1e, 0x62, 0x77, 0x01, 0x09, 0x1b, 0xc4, 0xee, 0x02, 0xec, 0x2e, 0x60, 0x35, 0x39, 0xec, 0x2e,
		0x30, 0x2c, 0x7e, 0x12, 0x67, 0x85, 0xd8, 0x70, 0x00, 0x51, 0x39, 0xd4, 0x75, 0xca, 0x15, 0x0f,
		0x91, 0xb0, 0xbf, 0x9a, 0x38, 0x73, 0x6d, 0xf1, 0x06, 0x20, 0x2e, 0x21, 0x2e, 0x21, 0x2e, 0x21,
		0x2e, 0x21, 0x2e, 0x0d, 0x80, 0xb0, 0x35, 0x42, 0x61, 0xd7, 0x7f, 0x34, 0x91, 0x2c, 0xa9, 0x32,
		0x8e, 0xd9, 0xf4, 0xfb, 0xbd, 0xe1, 0xa3, 0x66, 0x24, 0xe2, 0xb3, 0x07, 0xb4, 0xdc, 0x9c, 0x5c,
		0x9e, 0x5e, 0x5d, 0x14, 0xc0, 0x53, 0x36, 0x7e, 0x78, 0xe2, 0x7b, 0xe8, 0xb9, 0x8e, 0xab, 0x46,
		0xbb, 0x01, 0x2c, 0x96, 0x9a, 0xf7, 0xa5, 0x55, 0xb2, 0xe2, 0x1e, 0xc0, 0x56, 0xc0, 0x56, 0xc0,
		0x56, 0xc0, 0x56, 0xc0, 0x56, 0x18, 0x57, 0x2c, 0x0a, 0x3a, 0x3e, 0x8e, 0xaa, 0xf0, 0x3b, 0xd6,
		0x9c, 0x47, 0x92, 0xab, 0xde, 0x64, 0x2b, 0xda, 0xcf, 0x16, 0xdd, 0x78, 0x0a, 0xbc, 0x8e, 0xc1,
		0x13, 0x04, 0xe7, 0x87, 0xe7, 0x3f, 0x40, 0xb0, 0x04, 0x62, 0x93, 0x09, 0x62, 0x83, 0x03, 0x04,
		0x73, 0x4a, 0x6c, 0x70, 0x80, 0x60, 0x1a, 0x89, 0x0d, 0x0e, 0x10, 0xa4, 0xfa, 0x83, 0x14, 0x3f,
		0xeb, 0xf0, 0x48, 0xf1, 0x23, 0xc5, 0x6f, 0xc8, 0xe4, 0x70, 0x80, 0x60, 0xe6, 0x46, 0x43, 0x3e,
		0x7f, 0x73, 0x33, 0x34, 0x13, 0x19, 0x47, 0x2c, 0x3c, 0x33, 0x92, 0x11, 0xb1, 0xf0, 0x9c, 0x4a,
		0x46, 0xc4, 0xc2, 0xd3, 0x28, 0x19, 0xa5, 0x8a, 0x0c, 0xa5, 0xeb, 0x0f, 0xe1, 0x95, 0x37, 0x7e,
		0x66, 0xa3, 0x84, 0xb1, 0x13, 0xf4, 0xc2, 0xfe, 0xf8, 0x8c, 0x3f, 0xab, 0x27, 0xd4, 0x53, 0xd0,
		0xe1, 0x77, 0xd4, 0xeb, 0x6e, 0x84, 0x3f, 0xc4, 0x1c, 0x23, 0x8e, 0x3a, 0x3e, 0xbf, 0xfa, 0x7c,
		0x72, 0x7e, 0xfe, 0x67, 0xfb, 0xf3, 0xd5, 0xc5, 0xf5, 0x97, 0xbb, 0xe6, 0x29, 0x78, 0x04, 0x78,
		0x04, 0x78, 0x04, 0x78, 0x04, 0x78, 0x04, 0xe7, 0x8a, 0x75, 0x3b, 0xc2, 0x57, 0xae, 0x7a, 0x36,
		0x94, 0x57, 0xe7, 0x8c, 0x40, 0x9f, 0xc5, 0x3f, 0xf5, 0x93, 0x2d, 0x0d, 0xe0, 0xc5, 0xe4, 0x81,
		0x5f, 0x9f, 0xdc, 0xfd, 0x1e, 0xfb, 0xbc, 0x93, 0xbb, 0xb3, 0xab, 0xcb, 0xf6, 0x45, 0xf3, 0xee,
		0xf7, 0xab, 0x53, 0x6e, 0xf4, 0x18, 0x85, 0xcd, 0x24, 0x7b, 0x3c, 0x7e, 0xcf, 0x48, 0x4c, 0x7e,
		0x6e, 0x02, 0x9a, 0x7f, 0xdc, 0x35, 0x6f, 0x2e, 0x47, 0xd4, 0xe3, 0xdf, 0x5f, 0x9a, 0x37, 0x67,
		0xcd, 0xd3, 0x42, 0x1e, 0x82, 0xc4, 0xc6, 0x9f, 0xfa, 0xf5, 0xf9, 0xd9, 0xe7, 0xb3, 0xbb, 0xf3,
		0x3f, 0xdb, 0xa7, 0xcd, 0xdf, 0xce, 0x2e, 0xf1, 0xd4, 0x39, 0x9e, 0xfa, 0x12, 0xc7, 0xce, 0x78,
		0x6c, 0xba, 0x95, 0x35, 0xfe, 0x91, 0x4d, 0x15, 0x2c, 0x45, 0xf4, 0xcd, 0xc4, 0x9e, 0xb3, 0x75,
		0x37, 0x02, 0xe5, 0x09, 0xe5, 0x09, 0xe5, 0x09, 0xe5, 0x09, 0xe5, 0xc9, 0xa9, 0x3c, 0x43, 0xcb,
		0xee, 0x74, 0x22, 0x21, 0xa5, 0x09, 0xe1, 0x79, 0xc4, 0x38, 0x66, 0xfc, 0x8c, 0x33, 0x5f, 0xf9,
		0xf4, 0x3a, 0xb3, 0xdf, 0xaa, 0x06, 0xe6, 0x76, 0x69, 0x8e, 0x0f, 0x0d, 0x8c, 0x7d, 0x6d, 0x2b,
		0x25, 0x22, 0xdf, 0x88, 0xb0, 0x1e, 0xdd, 0xc0, 0x7f, 0xdf, 0xbf, 0xbf, 0x2f, 0x59, 0x47, 0xad,
		0x97, 0xfb, 0xb2, 0x75, 0xd4, 0x1a, 0xbf, 0x2c, 0x8f, 0xfe, 0x1a, 0xbf, 0xae, 0xdc, 0x97, 0xac,
		0xea, 0xe4, 0x75, 0xed, 0xbe, 0x64, 0xd5, 0x5a, 0xfb, 0x7f, 0xfd, 0xf5, 0x71, 0xff, 0xc7, 0xc1,
		0xe0, 0xed, 0x5f, 0xfc, 0x07, 0xbf, 0xa0, 0x68, 0x99, 0x98, 0xd4, 0xab, 0xdb, 0xb3, 0x3f, 0x30,
		0xb3, 0x99, 0x11, 0x6f, 0x06, 0x82, 0x01, 0x66, 0xe1, 0xb8, 0x0e, 0x38, 0x36, 0xbb, 0x68, 0x6d,
		0xab, 0x7b, 0x62, 0xfd, 0xd6, 0xfa, 0x51, 0xfe, 0x50, 0x1d, 0x1c, 0xef, 0xff, 0x68, 0x0c, 0x16,
		0xdf, 0x7c, 0x59, 0xf5, 0xb1, 0xf2, 0x87, 0xc6, 0xe0, 0x78, 0xcd, 0xbf, 0xd4, 0x07, 0xc7, 0x1b,
		0x5e, 0xa3, 0x36, 0x78, 0xbf, 0xf4, 0xd1, 0xe1, 0xfb, 0x95, 0x75, 0x5f, 0xa8, 0xae, 0xf9, 0xc2,
		0xc1, 0xba, 0x2f, 0x1c, 0xac, 0xf9, 0xc2, 0xda, 0x5b, 0xaa, 0xac, 0xf9, 0x42, 0x6d, 0xf0, 0xb2,
		0xf4, 0xf9, 0xf7, 0xab, 0x3f, 0x5a, 0x1f, 0xec, 0xbf, 0xac, 0xfb, 0xb7, 0xc6, 0xe0, 0xe5, 0x78,
		0x1f, 0xce, 0x09, 0x76, 0x0e, 0x3b, 0xcf, 0x84, 0xab, 0x46, 0xc5, 0x71, 0x12, 0xa3, 0xba, 0x91,
		0xe8, 0x8a, 0x48, 0xf8, 0x8e, 0x81, 0xba, 0xe3, 0x99, 0xb1, 0x11, 0xbb, 0x45, 0xec, 0x16, 0xb1,
		0x5b, 0xc4, 0x6e, 0x11, 0xbb, 0x65, 0x5c, 0xb1, 0xd8, 0xb0, 0x9a, 0xa1, 0x38, 0x01, 0x36, 0xac,
		0x92, 0x77, 0xba, 0x5c, 0x3b, 0x3e, 0x36, 0xac, 0xe6, 0xd6, 0xe4, 0x2a, 0x35, 0x1c, 0x41, 0x0d,
		0x01, 0x99, 0x63, 0x01, 0x19, 0x09, 0x15, 0x3d, 0x5b, 0xca, 0xed, 0x99, 0x28, 0x05, 0x9a, 0x1d,
		0x1c, 0x12, 0x32, 0x0b, 0x12, 0x12, 0x67, 0x1e, 0xe5, 0x54, 0x42, 0xe2, 0xcc, 0xa3, 0xb4, 0x4a,
		0xc8, 0x72, 0xdd, 0x80, 0x86, 0xac, 0x43, 0x43, 0x42, 0x43, 0x42, 0x43, 0x42, 0x43, 0x66, 0xc0,
		0xe4, 0xea, 0xa5, 0x12, 0x34, 0x24, 0x34, 0x64, 0x7e, 0x35, 0xa4, 0x14, 0xaa, 0x1f, 0x1a, 0x3c,
		0xb0, 0x77, 0x61, 0x7c, 0xfe, 0xe3, 0x14, 0x1a, 0x50, 0xaf, 0x50, 0xaf, 0x50, 0xaf, 0x50, 0xaf,
		0x50, 0xaf, 0xdc, 0xea, 0x15, 0x09, 0x50, 0x88, 0xd7, 0xcc, 0x28, 0x09, 0x9c, 0xd8, 0x0b, 0xf1,
		0xca, 0x6c, 0x72, 0x38, 0xb1, 0x17, 0xd2, 0x35, 0xcf, 0xd2, 0x35, 0xec, 0x5a, 0x3d, 0xa1, 0x22,
		0xd7, 0x31, 0x20, 0x5b, 0x5f, 0xc7, 0x86, 0x7c, 0xcc, 0x82, 0x7c, 0x44, 0xfd, 0x6c, 0x4e, 0xe5,
		0x23, 0xea, 0x67, 0xd3, 0x2a, 0x1f, 0xeb, 0x55, 0x03, 0xfa, 0xf1, 0x10, 0xfa, 0x11, 0xfa, 0x11,
		0xfa, 0x11, 0xfa, 0x31, 0x03, 0x26, 0x57, 0x3e, 0xac, 0x56, 0xeb, 0x8d, 0x6a, 0xb5, 0xd4, 0x38,
		0x68, 0x94, 0x8e, 0x6a, 0xb5, 0x72, 0xbd, 0x8c, 0x8a, 0x5a, 0x48, 0xca, 0x1c, 0x4b, 0xca, 0xbe,
		0x14, 0x96, 0x23, 0xc3, 0x2e, 0xbf, 0xa0, 0x9c, 0x8e, 0x0c, 0x39, 0x09, 0x39, 0x09, 0x39, 0x09,
		0x39, 0x09, 0x39, 0xc9, 0xb8, 0x62, 0x1f, 0x82, 0xc0, 0x13, 0xb6, 0x6f, 0xe2, 0x1c, 0xbd, 0x72,
		0x56, 0xdc, 0xf3, 0xbb, 0x14, 0x9b, 0x60, 0xe1, 0xc4, 0xf7, 0x83, 0xf1, 0x91, 0xb6, 0x2c, 0x06,
		0x58, 0x90, 0xce, 0x93, 0xe8, 0xd9, 0x61, 0xdc, 0xa8, 0xbe, 0x18, 0x84, 0xc2, 0x77, 0x46, 0x2e,
		0xd2, 0xf2, 0x85, 0xfa, 0x3b, 0x88, 0xbe, 0x5a, 0xae, 0x2f, 0x95, 0xed, 0x3b, 0xa2, 0xb8, 0xf8,
		0x86, 0x5c, 0x7a, 0xa7, 0x38, 0x04, 0x9d, 0xa2, 0x27, 0x43, 0x59, 0x74, 0x02, 0x5f, 0xaa, 0xc8,
		0x76, 0x7d, 0xd1, 0x19, 0x77, 0xb1, 0x57, 0x7d, 0xdf, 0x17, 0x9e, 0x8c, 0xff, 0x2e, 0x86, 0x95,
		0xd0, 0x1a, 0xbf, 0xb4, 0x6c, 0xa5, 0x22, 0xf7, 0xa1, 0xaf, 0x84, 0x1c, 0xbd, 0x1b, 0x46, 0x6e,
		0xcf, 0x8e, 0x9e, 0xc7, 0xdf, 0x5a, 0x7a, 0x63, 0xd4, 0x0c, 0x9f, 0x16, 0xd7, 0xe8, 0x0c, 0x88,
		0xe6, 0xca, 0x44, 0x26, 0x39, 0x74, 0xa9, 0xc4, 0x9d, 0x01, 0x0b, 0xe7, 0xae, 0x54, 0x27, 0x4a,
		0xd1, 0xee, 0x1a, 0x2b, 0x5c, 0xb8, 0x7e, 0xd3, 0x13, 0x43, 0xdf, 0x28, 0x69, 0x89, 0xdf, 0x50,
		0xcc, 0xcf, 0x8c, 0xc4, 0x2b, 0x6b, 0x0b, 0x57, 0x51, 0x47, 0x44, 0xa2, 0xf3, 0x69, 0x38, 0x6b,
		0x7e, 0xdf, 0xf3, 0x52, 0x65, 0x6c, 0x4c, 0xb8, 0x97, 0x36, 0xbc, 0x23, 0x24, 0x02, 0x05, 0xa9,
		0xa2, 0xbe, 0xa3, 0xe2, 0x76, 0xa3, 0x85, 0xcb, 0xf1, 0x6f, 0x3b, 0x8b, 0x7f, 0x5a, 0xfb, 0x22,
		0xf4, 0x64, 0xfb, 0x5c, 0x86, 0xb2, 0xfd, 0xf9, 0xf5, 0xa7, 0x5d, 0xdb, 0xea, 0xa9, 0x7d, 0x37,
		0xfa, 0x19, 0xed, 0xeb, 0xca, 0xf5, 0xf8, 0xd5, 0xc9, 0xf4, 0xf7, 0x0c, 0xdf, 0xbb, 0x1e, 0xdf,
		0xfd, 0xf0, 0x93, 0x34, 0x30, 0xad, 0x1f, 0x44, 0xf5, 0x5e, 0x51, 0xf3, 0x0a, 0xa1, 0x5e, 0x19,
		0x09, 0x5f, 0x11, 0x7a, 0x6d, 0x48, 0xdf, 0x4c, 0x6b, 0x9c, 0xe5, 0xc2, 0xf0, 0x37, 0x4b, 0xe1,
		0x04, 0x7e, 0x67, 0xf2, 0xab, 0xa5, 0xf6, 0xa9, 0x7e, 0x3d, 0x70, 0x6b, 0xc5, 0x60, 0x9a, 0x2d,
		0x76, 0xa2, 0x28, 0x34, 0x5f, 0x96, 0x2a, 0x74, 0x43, 0x19, 0xa2, 0x61, 0x08, 0xc5, 0x50, 0x87,
		0x5c, 0xd8, 0x42, 0x2b, 0x6c, 0x21, 0x14, 0x9e, 0x50, 0x49, 0xb2, 0xbd, 0xca, 0xa9, 0x4b, 0x43,
		0xba, 0x57, 0xe0, 0x0b, 0x9d, 0x65, 0xae, 0xc7, 0x34, 0x2a, 0x13, 0xa5, 0x81, 0x36, 0x72, 0x88,
		0xe3, 0x80, 0x3a, 0x46, 0xc8, 0xe3, 0x82, 0x3e, 0x76, 0x08, 0x64, 0x87, 0x42, 0x5e, 0x48, 0x4c,
		0x67, 0x1c, 0x84, 0x0a, 0x2a, 0xa7, 0x03, 0xd8, 0x9d, 0x9e, 0xeb, 0x5b, 0x8f, 0x51, 0xd0, 0x0f,
		0x25, 0xbd, 0x2d, 0x4f, 0x96, 0xe7, 0xdc, 0xa8, 0xc4, 0xd6, 0x45, 0x0b, 0x9b, 0x6c, 0xf0, 0xc9,
		0x09, 0xa3, 0x06, 0xe0, 0x94, 0x1b, 0x56, 0x8d, 0xc1, 0xab, 0x31, 0x98, 0x35, 0x03, 0xb7, 0xb4,
		0xb0, 0x4b, 0x0c, 0xbf, 0x6c, 0x30, 0x3c, 0x1d, 0xc8, 0x99, 0xa0, 0x08, 0x73, 0xe5, 0x45, 0x3c,
		0x2e, 0x6f, 0xdd, 0x45, 0x19, 0x75, 0x17, 0x69, 0x86, 0x6a, 0x53, 0x90, 0x6d, 0x1c, 0xba, 0x8d,
		0x43, 0xb8, 0x59, 0x28, 0xe7, 0x81, 0x74, 0x26, 0x68, 0x67, 0x87, 0xf8, 0xe9, 0x80, 0xe2, 0xbb,
		0xe3, 0xf5, 0x3b, 0x62, 0xcc, 0x82, 0xcd, 0x75, 0x92, 0x9f, 0xbf, 0x0d, 0x66, 0xfb, 0x35, 0x53,
		0x03, 0xcc, 0xee, 0x10, 0x4c, 0x3a, 0x86, 0x04, 0x38, 0x08, 0xd3, 0x8e, 0x22, 0x31, 0x0e, 0x23,
		0x31, 0x8e, 0x23, 0x19, 0x0e, 0x84, 0xd7, 0x91, 0x30, 0x3b, 0x94, 0xe9, 0x23, 0x66, 0x2f, 0xe8,
		0x5b, 0x5a, 0xf1, 0x9e, 0xb0, 0xbb, 0x91, 0xe8, 0x9a, 0xec, 0xda, 0xd7, 0x30, 0xd3, 0xb5, 0x6f,
		0x94, 0x56, 0xfe, 0xf8, 0xb1, 0xf8, 0x93, 0xff, 0x29, 0x61, 0x3d, 0x7a, 0xc1, 0x83, 0x3d, 0x97,
		0x09, 0x1e, 0xae, 0x03, 0x6b, 0x36, 0x48, 0x55, 0x9c, 0xf9, 0x8f, 0xd9, 0xd7, 0xd6, 0xa8, 0x84,
		0x21, 0xd3, 0xf6, 0xcb, 0x52, 0x27, 0xb5, 0x76, 0x74, 0xb6, 0xfa, 0xa9, 0xf5, 0x77, 0x60, 0xb0,
		0xae, 0x6a, 0xed, 0x4d, 0xb1, 0xd4, 0x5b, 0x99, 0xc7, 0x6b, 0x46, 0x5b, 0x2f, 0xb8, 0xfe, 0x98,
		0x08, 0xdb, 0x9e, 0x67, 0x9a, 0x93, 0x2f, 0xdf, 0x0a, 0x78, 0x39, 0x78, 0x39, 0x78, 0x39, 0x78,
		0x39, 0x78, 0x39, 0x78, 0x39, 0x78, 0x39, 0x78, 0x39, 0x78, 0x39, 0x78, 0x79, 0xde, 0x78, 0xb9,
		0xff, 0x9c, 0x18, 0x5e, 0x3e, 0xbd, 0x15, 0xf0, 0x72, 0xf0, 0x72, 0xf0, 0x72, 0xf0, 0x72, 0xf0,
		0x72, 0xf0, 0x72, 0xf0, 0x72, 0xf0, 0x72, 0xf0, 0x72, 0xf0, 0x72, 0x93, 0xbc, 0x3c, 0x53, 0x25,
		0x39, 0xcc, 0xe7, 0x51, 0x4c, 0xc7, 0x4d, 0xde, 0xae, 0xd4, 0x85, 0x4d, 0x93, 0x2b, 0xde, 0x2b,
		0xce, 0xa1, 0x6f, 0x5c, 0xce, 0x89, 0x43, 0xcf, 0x36, 0x9f, 0xf3, 0xd1, 0xd9, 0x1e, 0xfc, 0x47,
		0x68, 0x8f, 0x86, 0xcd, 0x78, 0xd9, 0x6d, 0x05, 0x65, 0xb7, 0x19, 0x52, 0x87, 0x28, 0xbb, 0x45,
		0xd9, 0xad, 0xbe, 0x47, 0x89, 0xb2, 0x5b, 0x84, 0x11, 0xb3, 0xe8, 0x18, 0x12, 0xe0, 0x20, 0x4c,
		0x3b, 0x8a, 0xc4, 0x38, 0x8c, 0xc4, 0x38, 0x8e, 0x64, 0x38, 0x10, 0x7e, 0x59, 0xba, 0x87, 0x30,
		0xe2, 0x9e, 0x09, 0x80, 0x47, 0x18, 0x31, 0xbd, 0xf6, 0x8b, 0x30, 0x22, 0xc2, 0x88, 0xa6, 0xf0,
		0x1a, 0x65, 0xb7, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0,
		0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0x39, 0xe5, 0xe5, 0x28, 0xbb, 0x05, 0x2f, 0x07, 0x2f,
		0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f,
		0x37, 0x30, 0x12, 0xca, 0x6e, 0x93, 0x5e, 0x76, 0xcb, 0xd0, 0x20, 0x8e, 0xcf, 0xe4, 0xd0, 0xcb,
		0x30, 0x57, 0xc6, 0x5b, 0x60, 0x29, 0xb2, 0xa6, 0xe8, 0xfa, 0x75, 0x3b, 0xf9, 0x51, 0xa3, 0xcf,
		0x9e, 0x0c, 0x7f, 0xd3, 0x3f, 0xc7, 0x3f, 0x29, 0xad, 0xad, 0x1a, 0x09, 0xbb, 0x56, 0x30, 0x1d,
		0x30, 0xcd, 0x7b, 0xb0, 0x34, 0xce, 0xf8, 0x4f, 0x55, 0xc0, 0x05, 0x67, 0xfc, 0x67, 0x33, 0x60,
		0x82, 0x33, 0xfe, 0x37, 0x83, 0x60, 0x19, 0x76, 0x2d, 0xe5, 0x8a, 0x87, 0x48, 0xd8, 0x5f, 0x45,
		0x64, 0xe0, 0xb0, 0xff, 0x85, 0x1b, 0xe0, 0xdd, 0x7e, 0x54, 0xc2, 0xa9, 0xff, 0x69, 0x06, 0x6f,
		0x53, 0x20, 0x6e, 0x1c, 0xcc, 0x8d, 0x83, 0xba, 0x59, 0x70, 0xcf, 0x66, 0xac, 0x83, 0x3d, 0xea,
		0xbd, 0x04, 0xc2, 0xd6, 0x08, 0x85, 0x5d, 0xff, 0x91, 0x73, 0xed, 0x4e, 0xf8, 0x72, 0x95, 0x71,
		0xcc, 0xa6, 0xdf, 0xef, 0x0d, 0x1f, 0x35, 0x67, 0x12, 0xfb, 0x54, 0x74, 0xed, 0xbe, 0x37, 0x5a,
		0x28, 0x37, 0x27, 0x97, 0xa7, 0x57, 0x17, 0xd8, 0x12, 0xbd, 0xf9, 0xc3, 0x13, 0xdf, 0x43, 0xcf,
		0x75, 0x5c, 0x35, 0x8a, 0x15, 0x58, 0xb1, 0x6a, 0x67, 0xa6, 0x2a, 0x2b, 0xee, 0x01, 0x6c, 0x05,
		0x6c, 0x05, 0x6c, 0x05, 0x6c, 0x05, 0x6c, 0x85, 0x71, 0xc5, 0xf2, 0xe7, 0xe6, 0x4d, 0xe4, 0xe4,
		0x7f, 0x9e, 0x8b, 0x1f, 0x7a, 0x9f, 0x8e, 0x35, 0xe7, 0x91, 0xe4, 0xaa, 0x37, 0xc7, 0x69, 0xa0,
		0x22, 0x5f, 0xca, 0x3d, 0x1b, 0x74, 0xe3, 0x29, 0xf0, 0x3a, 0x56, 0x18, 0xb9, 0x41, 0xe4, 0xaa,
		0x67, 0x7e, 0xa6, 0x31, 0x3f, 0x3c, 0xd7, 0xe9, 0x07, 0xaf, 0xfc, 0xb4, 0x04, 0x62, 0x93, 0x09,
		0x62, 0x13, 0xc9, 0x6f, 0x21, 0x88, 0x4d, 0x0e, 0x89, 0xcd, 0x68, 0xe2, 0x41, 0x6c, 0x52, 0x46,
		0x6c, 0xfa, 0xae, 0xaf, 0x0e, 0x0d, 0xd0, 0x1a, 0xc6, 0x6a, 0xac, 0xc2, 0x8d, 0xed, 0x3f, 0x0e,
		0x7f, 0xec, 0x3d, 0xeb, 0xfa, 0x30, 0x53, 0x85, 0x67, 0xb0, 0x6a, 0xdb, 0xc8, 0x26, 0x81, 0xe9,
		0xf0, 0xff, 0xb1, 0xbd, 0xbe, 0x30, 0x38, 0xfe, 0x6f, 0x91, 0xed, 0x28, 0x37, 0xf0, 0x4f, 0xdd,
		0x47, 0x77, 0x5c, 0x04, 0xc9, 0x5f, 0xa0, 0x6d, 0xa6, 0xec, 0x32, 0xf7, 0x26, 0xd7, 0xc8, 0xb1,
		0xc9, 0x65, 0xb4, 0xa2, 0xb5, 0x05, 0xe1, 0xba, 0xb1, 0x19, 0x9a, 0x89, 0x8c, 0x23, 0x16, 0x9e,
		0x19, 0xc9, 0x88, 0x58, 0x78, 0x4e, 0x25, 0x23, 0x62, 0xe1, 0x69, 0x94, 0x8c, 0x52, 0x45, 0x86,
		0xd2, 0xf5, 0x87, 0xf0, 0xca, 0x1b, 0x3f, 0xb3, 0x51, 0xc2, 0xd8, 0x09, 0x7a, 0x61, 0x7f, 0xbc,
		0x0d, 0xc0, 0xea, 0x09, 0xf5, 0x14, 0x74, 0xf8, 0x1d, 0xf5, 0xba, 0x1b, 0xe1, 0x0f, 0x31, 0xc7,
		0x88, 0xa3, 0x8e, 0xcf, 0xaf, 0x3e, 0x9f, 0x9c, 0x9f, 0xff, 0xd9, 0xfe, 0x7c, 0x75, 0x71, 0xfd,
		0xe5, 0xae, 0x79, 0x0a, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0xc1, 0xb9, 0x62,
		0xdd, 0x8e, 0xf0, 0x95, 0xab, 0x9e, 0x0d, 0xe5, 0xd5, 0x39, 0x23, 0xd0, 0x67, 0xf1, 0x4f, 0xfd,
		0x64, 0x4b, 0x61, 0xee, 0x1c, 0x99, 0xeb, 0x93, 0xbb, 0xdf, 0x63, 0x9f, 0x77, 0x72, 0x77, 0x76,
		0x75, 0xd9, 0xbe, 0x68, 0xde, 0xfd, 0x7e, 0x75, 0xca, 0x8d, 0x1e, 0xa3, 0xb0, 0x99, 0x64, 0x8f,
		0xc7, 0xef, 0x19, 0x89, 0xc9, 0xcf, 0x4d, 0x40, 0xf3, 0x8f, 0xbb, 0xe6, 0xcd, 0xe5, 0x88, 0x7a,
		0xfc, 0xfb, 0x4b, 0xf3, 0xe6, 0xac, 0x79, 0x5a, 0xc8, 0x43, 0x90, 0xd8, 0xf8, 0x53, 0xbf, 0x3e,
		0x3f, 0xfb, 0x7c, 0x76, 0x77, 0xfe, 0x67, 0xfb, 0xb4, 0xf9, 0xdb, 0xd9, 0x25, 0x9e, 0x3a, 0xc7,
		0x53, 0x5f, 0xe2, 0xd8, 0x19, 0x8f, 0x4d, 0xb7, 0xb2, 0xc6, 0x3f, 0xb2, 0xa9, 0x82, 0xa5, 0x88,
		0xbe, 0x99, 0xd8, 0x73, 0xb6, 0xee, 0x46, 0xa0, 0x3c, 0xa1, 0x3c, 0xa1, 0x3c, 0xa1, 0x3c, 0xa1,
		0x3c, 0x39, 0x95, 0x67, 0x68, 0xd9, 0x9d, 0x4e, 0x24, 0xa4, 0x34, 0x21, 0x3c, 0x8f, 0x18, 0xc7,
		0x8c, 0x9f, 0x71, 0xe6, 0x2b, 0x9f, 0x5e, 0x67, 0xf6, 0x5b, 0xd5, 0xc0, 0xdc, 0x2e, 0xcd, 0xf1,
		0xa1, 0x99, 0x83, 0xf4, 0x94, 0x88, 0x7c, 0x23, 0xc2, 0x7a, 0x74, 0x03, 0xff, 0x7d, 0xff, 0xfe,
		0xbe, 0x64, 0x1d, 0xb5, 0x5e, 0xee, 0xcb, 0xd6, 0x51, 0x6b, 0xfc, 0xb2, 0x3c, 0xfa, 0x6b, 0xfc,
		0xba, 0x72, 0x5f, 0xb2, 0xaa, 0x93, 0xd7, 0xb5, 0xfb, 0x92, 0x55, 0x6b, 0xed, 0xff, 0xf5, 0xd7,
		0xc7, 0xfd, 0x1f, 0x07, 0x83, 0xb7, 0x7f, 0xf1, 0x1f, 0xfc, 0x82, 0xa2, 0x65, 0x62, 0x52, 0xaf,
		0x6e, 0xcf, 0xfe, 0xc0, 0xcc, 0x66, 0x46, 0xbc, 0x19, 0x08, 0x06, 0x98, 0x85, 0xe3, 0x3a, 0xe0,
		0xd8, 0xec, 0xa2, 0xb5, 0xad, 0xee, 0x89, 0xf5, 0x5b, 0xeb, 0x47, 0xf9, 0x43, 0x75, 0x70, 0xbc,
		0xff, 0xa3, 0x31, 0x58, 0x7c, 0xf3, 0x65, 0xd5, 0xc7, 0xca, 0x1f, 0x1a, 0x83, 0xe3, 0x35, 0xff,
		0x52, 0x1f, 0x1c, 0x6f, 0x78, 0x8d, 0xda, 0xe0, 0xfd, 0xd2, 0x47, 0x87, 0xef, 0x57, 0xd6, 0x7d,
		0xa1, 0xba, 0xe6, 0x0b, 0x07, 0xeb, 0xbe, 0x70, 0xb0, 0xe6, 0x0b, 0x6b, 0x6f, 0xa9, 0xb2, 0xe6,
		0x0b, 0xb5, 0xc1, 0xcb, 0xd2, 0xe7, 0xdf, 0xaf, 0xfe, 0x68, 0x7d, 0xb0, 0xff, 0xb2, 0xee, 0xdf,
		0x1a, 0x83, 0x97, 0xe3, 0x7d, 0x38, 0x27, 0xd8, 0x39, 0xec, 0x3c, 0x13, 0xae, 0x1a, 0x15, 0xc7,
		0x49, 0x8c, 0xea, 0x46, 0xa2, 0x2b, 0x22, 0xe1, 0x3b, 0x06, 0xea, 0x8e, 0x67, 0xc6, 0x46, 0xec,
		0x16, 0xb1, 0x5b, 0xc4, 0x6e, 0x11, 0xbb, 0x45, 0xec, 0x96, 0x71, 0xc5, 0x62, 0xc3, 0x6a, 0x86,
		0xe2, 0x04, 0xd8, 0xb0, 0x4a, 0x7e, 0x68, 0xf3, 0xda, 0xf1, 0xb1, 0x61, 0x35, 0xb7, 0x26, 0x57,
		0xa9, 0xd5, 0xb0, 0x65, 0x15, 0x02, 0x32, 0xbf, 0x02, 0x32, 0x12, 0x2a, 0x7a, 0xb6, 0x94, 0xdb,
		0x33, 0x51, 0x0a, 0x34, 0x3b, 0x38, 0x24, 0x64, 0x16, 0x24, 0x24, 0xce, 0x3c, 0xca, 0xa9, 0x84,
		0xc4, 0x99, 0x47, 0x69, 0x95, 0x90, 0xe5, 0xba, 0x01, 0x0d, 0x59, 0x87, 0x86, 0x84, 0x86, 0x84,
		0x86, 0x84, 0x86, 0xcc, 0x80, 0xc9, 0xd5, 0x4b, 0x25, 0x68, 0x48, 0x68, 0xc8, 0xfc, 0x6a, 0x48,
		0x29, 0x54, 0x3f, 0x34, 0x78, 0x60, 0xef, 0xc2, 0xf8, 0xfc, 0xc7, 0x29, 0x34, 0xa0, 0x5e, 0xa1,
		0x5e, 0xa1, 0x5e, 0xa1, 0x5e, 0xa1, 0x5e, 0xb9, 0xd5, 0x2b, 0x12, 0xa0, 0x10, 0xaf, 0x99, 0x51,
		0x12, 0x38, 0xb1, 0x17, 0xe2, 0x95, 0xd9, 0xe4, 0x70, 0x62, 0x2f, 0xa4, 0x6b, 0x8e, 0xa5, 0x6b,
		0x5f, 0x0a, 0xcb, 0x91, 0x61, 0x97, 0x5f, 0xb4, 0x4e, 0x47, 0x86, 0x74, 0xcc, 0x82, 0x74, 0x44,
		0xed, 0x6c, 0x4e, 0xa5, 0x23, 0x6a, 0x67, 0xd3, 0x28, 0x1d, 0x1f, 0x82, 0xc0, 0x13, 0xb6, 0x6f,
		0xe2, 0xd0, 0x83, 0x72, 0x56, 0xdc, 0x73, 0xaa, 0x7b, 0xfc, 0x9f, 0xf8, 0x7e, 0x30, 0x3e, 0x7f,
		0x88, 0xa7, 0xd5, 0xbf, 0x74, 0x9e, 0x44, 0xcf, 0x0e, 0xe3, 0xae, 0x82, 0xc5, 0x20, 0x14, 0xbe,
		0x33, 0x72, 0x91, 0x96, 0x2f, 0xd4, 0xdf, 0x41, 0xf4, 0xd5, 0x72, 0x7d, 0xa9, 0x6c, 0xdf, 0x11,
		0xc5, 0xc5, 0x37, 0xe4, 0xd2, 0x3b, 0xc5, 0x21, 0xe8, 0x14, 0x3d, 0x19, 0xca, 0xa2, 0x13, 0xf8,
		0x52, 0x45, 0xb6, 0xeb, 0x8b, 0xce, 0xb8, 0xe5, 0xa0, 0xea, 0xfb, 0xbe, 0xf0, 0x64, 0xfc, 0x77,
		0x31, 0xac, 0x84, 0xd6, 0xf8, 0xa5, 0x65, 0x2b, 0x15, 0xb9, 0x0f, 0x7d, 0x25, 0xe4, 0xe8, 0x5d,
		0x29, 0x9c, 0xc0, 0xef, 0xd8, 0xd1, 0x73, 0xdc, 0xbf, 0x70, 0xf9, 0xbd, 0xe2, 0xf8, 0x0e, 0x69,
		0xd1, 0x8d, 0xce, 0x8c, 0x08, 0x4d, 0x88, 0xa7, 0xd3, 0x03, 0x67, 0x87, 0x07, 0x26, 0x7e, 0xc8,
		0xc6, 0x0b, 0x39, 0xf9, 0xa0, 0x01, 0x1e, 0xc8, 0xcd, 0xff, 0x8c, 0xf1, 0x3e, 0x63, 0x7c, 0xcf,
		0x0c, 0xcf, 0x4b, 0xb7, 0x53, 0x65, 0xe3, 0x73, 0x06, 0xba, 0x11, 0x73, 0x76, 0x21, 0x9e, 0xed,
		0x3e, 0xcc, 0xd5, 0x42, 0x38, 0x9d, 0x7e, 0x78, 0xf4, 0x74, 0xf8, 0x1c, 0xf1, 0x78, 0x38, 0x1e,
		0x4f, 0x5c, 0xe6, 0xf2, 0xc4, 0x15, 0x78, 0x62, 0x78, 0x62, 0x78, 0xe2, 0x4c, 0x79, 0xe2, 0x53,
		0x97, 0x67, 0x3b, 0x4f, 0xc1, 0x96, 0x32, 0x70, 0x5c, 0x5b, 0x89, 0xce, 0xa8, 0x88, 0xc2, 0x92,
		0x42, 0x4a, 0x37, 0xf0, 0x25, 0x7f, 0x40, 0x7d, 0xed, 0x9d, 0x20, 0xc0, 0x9e, 0x36, 0x18, 0x37,
		0x08, 0xe7, 0xa6, 0x60, 0xdd, 0x38, 0xbc, 0x1b, 0x87, 0x79, 0xb3, 0x70, 0xcf, 0x03, 0xfb, 0x4c,
		0xf0, 0xcf, 0x2f, 0xc8, 0x0c, 0x0a, 0x33, 0x13, 0x02, 0x6d, 0x95, 0x50, 0x5b, 0xf7, 0x3f, 0xe9,
		0x3e, 0xfa, 0xb6, 0xe7, 0xfa, 0x8f, 0x56, 0x18, 0x05, 0x2a, 0x70, 0x02, 0x4f, 0x16, 0x47, 0x0e,
		0x4a, 0x89, 0xe2, 0xc4, 0x47, 0x4d, 0x5e, 0x14, 0xbd, 0xc0, 0xb1, 0x3d, 0xcb, 0xf5, 0x3b, 0xe2,
		0x7b, 0x21, 0x53, 0x96, 0x78, 0xee, 0x4a, 0x75, 0xa2, 0x54, 0xc4, 0x6b, 0x8d, 0x17, 0xae, 0xdf,
		0xf4, 0xc4, 0x10, 0x4c, 0x24, 0x6f, 0xad, 0x4d, 0xe1, 0xc2, 0xfe, 0x3e, 0x33, 0x72, 0xf9, 0xb0,
		0x5a, 0xad, 0x37, 0xaa, 0xd5, 0x52, 0xe3, 0xa0, 0x51, 0x3a, 0xaa, 0xd5, 0xca, 0x75, 0xd6, 0xa6,
		0x4b, 0x57, 0x51, 0x47, 0x44, 0xa2, 0xf3, 0xe9, 0xb9, 0x70, 0xbc, 0xe7, 0xf7, 0x3d, 0x0f, 0x05,
		0x22, 0x1b, 0x3f, 0x3a, 0x47, 0x86, 0x5d, 0xab, 0x27, 0x54, 0xe4, 0x3a, 0xfc, 0x94, 0x76, 0x76,
		0x70, 0xb0, 0x58, 0xb0, 0x58, 0xb0, 0x58, 0xb0, 0x58, 0xb0, 0x58, 0xc6, 0x15, 0xdb, 0x77, 0x7d,
		0x55, 0xaf, 0x1a, 0x20, 0xb1, 0x87, 0xd8, 0x62, 0x40, 0xc2, 0x06, 0xb1, 0xc5, 0x00, 0x5b, 0x0c,
		0x58, 0x4d, 0x0e, 0x5b, 0x0c, 0x0c, 0x8b, 0x9f, 0xc4, 0x59, 0x21, 0x76, 0x1d, 0x40, 0x54, 0x0e,
		0x75, 0x9d, 0x72, 0xc5, 0x43, 0x24, 0xec, 0xaf, 0x26, 0x0e, 0x5e, 0x5b, 0xbc, 0x01, 0x88, 0x4b,
		0x88, 0x4b, 0x88, 0x4b, 0x88, 0x4b, 0x88, 0x4b, 0x03, 0x20, 0x6c, 0x8d, 0x50, 0xd8, 0xf5, 0x1f,
		0x4d, 0x24, 0x4b, 0xaa, 0x8c, 0x63, 0x36, 0xfd, 0x7e, 0x6f, 0xf8, 0xa8, 0x19, 0x89, 0xf8, 0xec,
		0x29, 0x2d, 0x37, 0x27, 0x97, 0xa7, 0x57, 0x17, 0x05, 0xf0, 0x94, 0x8d, 0x1f, 0x9e, 0xf8, 0x1e,
		0x7a, 0xae, 0xe3, 0xaa, 0xd1, 0x6e, 0x00, 0x8b, 0xa5, 0xe6, 0x7d, 0x69, 0x95, 0xac, 0xb8, 0x07,
		0xb0, 0x15, 0xb0, 0x15, 0xb0, 0x15, 0xb0, 0x15, 0xb0, 0x15, 0xc6, 0x15, 0x8b, 0x82, 0x8e, 0x8f,
		0xa3, 0x2a, 0xfc, 0x8e, 0x35, 0xe7, 0x91, 0xe4, 0xaa, 0x37, 0xd9, 0x8a, 0xf6, 0xb3, 0x45, 0x37,
		0x9e, 0x02, 0xaf, 0x63, 0xf0, 0x18, 0xc1, 0xf9, 0xe1, 0xf9, 0x4f, 0x11, 0x2c, 0x81, 0xd8, 0x64,
		0x82, 0xd8, 0xe0, 0x14, 0xc1, 0x9c, 0x12, 0x1b, 0x9c, 0x22, 0x98, 0x46, 0x62, 0x83, 0x53, 0x04,
		0xa9, 0xfe, 0x20, 0xc5, 0xcf, 0x3a, 0x3c, 0x52, 0xfc, 0x48, 0xf1, 0x1b, 0x32, 0x39, 0x9c, 0x22,
		0x98, 0xb9, 0xd1, 0x90, 0xcf, 0xdf, 0xdc, 0x0c, 0xcd, 0x44, 0xc6, 0x11, 0x0b, 0xcf, 0x8c, 0x64,
		0x44, 0x2c, 0x3c, 0xa7, 0x92, 0x11, 0xb1, 0xf0, 0x34, 0x4a, 0x46, 0xa9, 0x22, 0x43, 0xe9, 0xfa,
		0x43, 0x78, 0xe5, 0x8d, 0x9f, 0xd9, 0x28, 0x61, 0xec, 0x04, 0xbd, 0xb0, 0x3f, 0x3e, 0xe8, 0xcf,
		0xea, 0x09, 0xf5, 0x14, 0x74, 0xf8, 0x1d, 0xf5, 0xba, 0x1b, 0xe1, 0x0f, 0x31, 0xc7, 0x88, 0xa3,
		0x8e, 0xcf, 0xaf, 0x3e, 0x9f, 0x9c, 0x9f, 0xff, 0xd9, 0xfe, 0x7c, 0x75, 0x71, 0xfd, 0xe5, 0xae,
		0x79, 0x0a, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0xc1, 0xb9, 0x62, 0xdd, 0x8e,
		0xf0, 0x95, 0xab, 0x9e, 0x0d, 0xe5, 0xd5, 0x39, 0x23, 0xd0, 0x67, 0xf1, 0x4f, 0xfd, 0x64, 0x4b,
		0x03, 0x78, 0x31, 0x79, 0xe0, 0xd7, 0x27, 0x77, 0xbf, 0xc7, 0x3e, 0xef, 0xe4, 0xee, 0xec, 0xea,
		0xb2, 0x7d, 0xd1, 0xbc, 0xfb, 0xfd, 0xea, 0x94, 0x1b, 0x3d, 0x46, 0x61, 0x33, 0xc9, 0x1e, 0x8f,
		0xdf, 0x33, 0x12, 0x93, 0x9f, 0x9b, 0x80, 0xe6, 0x1f, 0x77, 0xcd, 0x9b, 0xcb, 0x11, 0xf5, 0xf8,
		0xf7, 0x97, 0xe6, 0xcd, 0x59, 0xf3, 0xb4, 0x90, 0x87, 0x20, 0xb1, 0xf1, 0xa7, 0x7e, 0x7d, 0x7e,
		0xf6, 0xf9, 0xec, 0xee, 0xfc, 0xcf, 0xf6, 0x69, 0xf3, 0xb7, 0xb3, 0x4b, 0x3c, 0x75, 0x8e, 0xa7,
		0xbe, 0xc4, 0xb1, 0x33, 0x1e, 0x9b, 0x6e, 0x65, 0x8d, 0x7f, 0x64, 0x53, 0x05, 0x4b, 0x11, 0x7d,
		0x33, 0xb1, 0xe7, 0x6c, 0xdd, 0x8d, 0x40, 0x79, 0x42, 0x79, 0x42, 0x79, 0x42, 0x79, 0x42, 0x79,
		0x72, 0x2a, 0xcf, 0xd0, 0xb2, 0x3b, 0x9d, 0x48, 0x48, 0x69, 0x42, 0x78, 0x1e, 0x31, 0x8e, 0x19,
		0x3f, 0xe3, 0xcc, 0x57, 0x3e, 0xbd, 0xce, 0xec, 0xb7, 0xaa, 0x81, 0xb9, 0x5d, 0x9a, 0xe3, 0x43,
		0x03, 0x63, 0x5f, 0xdb, 0x4a, 0x89, 0xc8, 0x37, 0x22, 0xac, 0x47, 0x37, 0xf0, 0xdf, 0xf7, 0xef,
		0xef, 0x4b, 0xd6, 0x51, 0xeb, 0xe5, 0xbe, 0x6c, 0x1d, 0xb5, 0xc6, 0x2f, 0xcb, 0xa3, 0xbf, 0xc6,
		0xaf, 0x2b, 0xf7, 0x25, 0xab, 0x3a, 0x79, 0x5d, 0xbb, 0x2f, 0x59, 0xb5, 0xd6, 0xfe, 0x5f, 0x7f,
		0x7d, 0xdc, 0xff, 0x71, 0x30, 0x78, 0xfb, 0x17, 0xff, 0xc1, 0x2f, 0x28, 0x5a, 0x26, 0x26, 0xf5,
		0xea, 0xf6, 0xec, 0x0f, 0xcc, 0x6c, 0x66, 0xc4, 0x9b, 0x81, 0x60, 0x80, 0x59, 0x38, 0xae, 0x03,
		0x8e, 0xcd, 0x2e, 0x5a, 0xdb, 0xea, 0x9e, 0x58, 0xbf, 0xb5, 0x7e, 0x94, 0x3f, 0x54, 0x07, 0xc7,
		0xfb, 0x3f, 0x1a, 0x83, 0xc5, 0x37, 0x5f, 0x56, 0x7d, 0xac, 0xfc, 0xa1, 0x31, 0x38, 0x5e, 0xf3,
		0x2f, 0xf5, 0xc1, 0xf1, 0x86, 0xd7, 0xa8, 0x0d, 0xde, 0x2f, 0x7d, 0x74, 0xf8, 0x7e, 0x65, 0xdd,
		0x17, 0xaa, 0x6b, 0xbe, 0x70, 0xb0, 0xee, 0x0b, 0x07, 0x6b, 0xbe, 0xb0, 0xf6, 0x96, 0x2a, 0x6b,
		0xbe, 0x50, 0x1b, 0xbc, 0x2c, 0x7d, 0xfe, 0xfd, 0xea, 0x8f, 0xd6, 0x07, 0xfb, 0x2f, 0xeb, 0xfe,
		0xad, 0x31, 0x78, 0x39, 0xde, 0x87, 0x73, 0x82, 0x9d, 0xc3, 0xce, 0x33, 0xe1, 0xaa, 0x51, 0x71,
		0x9c, 0xc4, 0xa8, 0x6e, 0x24, 0xba, 0x22, 0x12, 0xbe, 0x63, 0xa0, 0xee, 0x78, 0x66, 0x6c, 0xc4,
		0x6e, 0x11, 0xbb, 0x45, 0xec, 0x16, 0xb1, 0x5b, 0xc4, 0x6e, 0x19, 0x57, 0x2c, 0x36, 0xac, 0x66,
		0x28, 0x4e, 0x80, 0x0d, 0xab, 0xe4, 0x9d, 0x2e, 0xd7, 0x8e, 0x8f, 0x0d, 0xab, 0xb9, 0x35, 0xb9,
		0x4a, 0x0d, 0x47, 0x50, 0x43, 0x40, 0xe6, 0x58, 0x40, 0x46, 0x42, 0x45, 0xcf, 0x96, 0x72, 0x7b,
		0x26, 0x4a, 0x81, 0x66, 0x07, 0x87, 0x84, 0xcc, 0x82, 0x84, 0xc4, 0x99, 0x47, 0x39, 0x95, 0x90,
		0x38, 0xf3, 0x28, 0xad, 0x12, 0xb2, 0x5c, 0x37, 0xa0, 0x21, 0xeb, 0xd0, 0x90, 0xd0, 0x90, 0xd0,
		0x90, 0xd0, 0x90, 0x19, 0x30, 0xb9, 0x7a, 0xa9, 0x04, 0x0d, 0x09, 0x0d, 0x99, 0x5f, 0x0d, 0x29,
		0x85, 0xea, 0x87, 0x06, 0x0f, 0xec, 0x5d, 0x18, 0x9f, 0xff, 0x38, 0x85, 0x06, 0xd4, 0x2b, 0xd4,
		0x2b, 0xd4, 0x2b, 0xd4, 0x2b, 0xd4, 0x2b, 0xb7, 0x7a, 0x45, 0x02, 0x14, 0xe2, 0x35, 0x33, 0x4a,
		0x02, 0x27, 0xf6, 0x42, 0xbc, 0x32, 0x9b, 0x1c, 0x4e, 0xec, 0x85, 0x74, 0xcd, 0xb3, 0x74, 0x0d,
		0xbb, 0x56, 0x4f, 0xa8, 0xc8, 0x75, 0x0c, 0xc8, 0xd6, 0xd7, 0xb1, 0x21, 0x1f, 0xb3, 0x20, 0x1f,
		0x51, 0x3f, 0x9b, 0x53, 0xf9, 0x88, 0xfa, 0xd9, 0xb4, 0xca, 0xc7, 0x7a, 0xd5, 0x80, 0x7e, 0x3c,
		0x84, 0x7e, 0x84, 0x7e, 0x84, 0x7e, 0x84, 0x7e, 0xcc, 0x80, 0xc9, 0x95, 0x0f, 0xab, 0xd5, 0x7a,
		0xa3, 0x5a, 0x2d, 0x35, 0x0e, 0x1a, 0xa5, 0xa3, 0x5a, 0xad, 0x5c, 0x2f, 0xa3, 0xa2, 0x16, 0x92,
		0x32, 0xc7, 0x92, 0xb2, 0x2f, 0x85, 0xe5, 0xc8, 0xb0, 0xcb, 0x2f, 0x28, 0xa7, 0x23, 0x43, 0x4e,
		0x42, 0x4e, 0x42, 0x4e, 0x42, 0x4e, 0x42, 0x4e, 0x32, 0xae, 0xd8, 0x87, 0x20, 0xf0, 0x84, 0xed,
		0x9b, 0x38, 0x47, 0xaf, 0x9c, 0x15, 0xf7, 0xfc, 0x2e, 0xc5, 0x26, 0x58, 0x38, 0xf1, 0xfd, 0x60,
		0x7c, 0xa4, 0x2d, 0x8b, 0x01, 0x16, 0xa4, 0xf3, 0x24, 0x7a, 0x76, 0x18, 0x37, 0xaa, 0x2f, 0x06,
		0xa1, 0xf0, 0x9d, 0x91, 0x8b, 0xb4, 0x7c, 0xa1, 0xfe, 0x0e, 0xa2, 0xaf, 0x96, 0xeb, 0x4b, 0x65,
		0xfb, 0x8e, 0x28, 0x2e, 0xbe, 0x21, 0x97, 0xde, 0x29, 0x0e, 0x41, 0xa7, 0xe8, 0xc9, 0x50, 0x16,
		0x9d, 0xc0, 0x97, 0x2a, 0xb2, 0x5d, 0x5f, 0x74, 0xc6, 0x5d, 0xec, 0x55, 0xdf, 0xf7, 0x85, 0x27,
		0xe3, 0xbf, 0x8b, 0x61, 0x25, 0xb4, 0xc6, 0x2f, 0x2d, 0x5b, 0xa9, 0xc8, 0x7d, 0xe8, 0x2b, 0x21,
		0x47, 0xef, 0x4a, 0xe1, 0x04, 0x7e, 0xc7, 0x8e, 0x9e, 0xe3, 0x96, 0xf8, 0xcb, 0xef, 0x8d, 0x3b,
		0xe2, 0xd3, 0x82, 0x1b, 0x9d, 0x15, 0xd1, 0x5c, 0x99, 0xc8, 0x2e, 0x87, 0x7e, 0x95, 0xb8, 0x3d,
		0x60, 0xe1, 0xdc, 0x95, 0xea, 0x44, 0x29, 0xda, 0xad, 0x63, 0x85, 0x0b, 0xd7, 0x6f, 0x7a, 0x62,
		0xe8, 0x20, 0x25, 0x2d, 0xfb, 0x1b, 0x2a, 0xfa, 0x99, 0x91, 0x78, 0xb5, 0x6d, 0xe1, 0x2a, 0xea,
		0x88, 0x48, 0x74, 0x3e, 0x0d, 0x67, 0xcd, 0xef, 0x7b, 0x5e, 0xaa, 0x8c, 0x8d, 0x09, 0xfc, 0x52,
		0x09, 0x7a, 0x84, 0x94, 0xa0, 0x20, 0x55, 0xd4, 0x77, 0x54, 0xdc, 0x78, 0xb4, 0x70, 0x39, 0xfe,
		0x81, 0x67, 0xf1, 0xef, 0x6b, 0x5f, 0x84, 0x9e, 0x6c, 0x9f, 0xcb, 0x50, 0xb6, 0x3f, 0xbf, 0xfe,
		0xbe, 0x6b, 0x5b, 0x3d, 0xb5, 0xef, 0x46, 0xbf, 0xa5, 0x7d, 0x5d, 0xb9, 0x1e, 0xbf, 0x3a, 0x99,
		0xfe, 0xa8, 0xe1, 0x7b, 0xb7, 0x93, 0xfb, 0x1f, 0x7e, 0x96, 0x06, 0xad, 0xf5, 0x63, 0xa9, 0xde,
		0x2b, 0x6a, 0x5e, 0x28, 0xd4, 0x0b, 0x24, 0xf9, 0x0b, 0x43, 0xaf, 0x19, 0xe9, 0x9b, 0x6c, 0x8d,
		0x13, 0x5d, 0x18, 0xb3, 0x1b, 0xdd, 0xf3, 0x3b, 0xd3, 0x6f, 0x72, 0x78, 0x79, 0xcd, 0x86, 0x39,
		0x11, 0x11, 0x9a, 0x2f, 0x3b, 0x8d, 0xd6, 0x54, 0x34, 0x5f, 0x98, 0x30, 0x2a, 0xc3, 0x10, 0x7d,
		0xa1, 0x8e, 0xb2, 0xb0, 0x45, 0x53, 0xd8, 0xa2, 0x26, 0x3c, 0xd1, 0x91, 0x64, 0x3b, 0x8f, 0x53,
		0x97, 0x86, 0x62, 0x17, 0x3a, 0x42, 0x2a, 0xd7, 0xa7, 0xe5, 0x6d, 0xd3, 0x55, 0x35, 0x3b, 0x18,
		0x95, 0xe6, 0x21, 0x0d, 0x49, 0x93, 0x87, 0xa0, 0x39, 0x42, 0xce, 0x8c, 0x21, 0x66, 0xae, 0x90,
		0x32, 0x7b, 0x08, 0x99, 0x3d, 0x64, 0xcc, 0x1b, 0x22, 0x4e, 0x57, 0x9c, 0x83, 0x3c, 0xe4, 0xcb,
		0xdb, 0x2d, 0x85, 0xa3, 0x3b, 0x0a, 0x4f, 0x37, 0x14, 0x86, 0x18, 0xa8, 0xa1, 0x6e, 0x27, 0x9c,
		0xc7, 0xe9, 0xb3, 0x1f, 0x9f, 0x9f, 0xb9, 0x1e, 0x17, 0x2d, 0x8e, 0x49, 0x32, 0x71, 0x00, 0x7c,
		0xf6, 0x66, 0x2a, 0xcd, 0x09, 0x20, 0x5e, 0xb8, 0xab, 0x03, 0xee, 0xf4, 0x2e, 0x22, 0x74, 0x4d,
		0xc8, 0x64, 0xd7, 0x84, 0xcc, 0x83, 0x3f, 0xec, 0x36, 0x9b, 0x76, 0x9b, 0xd2, 0x1c, 0x79, 0x0b,
		0xd9, 0x22, 0x1d, 0x72, 0x3f, 0x57, 0xd9, 0x22, 0x82, 0xa2, 0x10, 0x8d, 0xf9, 0xa1, 0x77, 0x09,
		0x32, 0x10, 0x2a, 0xc3, 0x48, 0x96, 0x41, 0x14, 0xb4, 0xa6, 0xe4, 0x74, 0x27, 0xc8, 0xf5, 0x18,
		0xea, 0xee, 0x66, 0xa5, 0xc1, 0xa4, 0x34, 0x27, 0x2c, 0x49, 0x12, 0x95, 0x9a, 0x13, 0x94, 0xda,
		0x13, 0x93, 0x14, 0x31, 0x7b, 0xc2, 0x18, 0x3d, 0x55, 0x4c, 0x9e, 0x3c, 0x06, 0x4f, 0x1e, 0x73,
		0xa7, 0x8d, 0xb1, 0x27, 0xcb, 0x8d, 0xe8, 0x4e, 0x28, 0x16, 0xec, 0x4e, 0xcf, 0xf5, 0xad, 0xe1,
		0xba, 0xef, 0x4b, 0xba, 0x02, 0x88, 0xb9, 0x51, 0x74, 0xe7, 0x58, 0x5f, 0xcf, 0xf3, 0x8b, 0x27,
		0x5f, 0x1d, 0x9f, 0x9c, 0x5e, 0x9c, 0x5d, 0xb6, 0xbf, 0x5c, 0x13, 0xd5, 0x5c, 0x94, 0xa8, 0x6a,
		0x2e, 0x4a, 0xa8, 0xb9, 0x60, 0x80, 0x3c, 0x36, 0xe8, 0x63, 0x83, 0x40, 0x1e, 0x28, 0x4c, 0x87,
		0x04, 0x23, 0x4b, 0x2b, 0xbe, 0x46, 0x71, 0x3b, 0xc2, 0x57, 0xae, 0x7a, 0x8e, 0x04, 0xc5, 0x96,
		0xbd, 0x29, 0x6f, 0x22, 0xa8, 0x59, 0x2e, 0x9c, 0xc5, 0xb7, 0xfe, 0xc9, 0x96, 0x82, 0xbe, 0x70,
		0xe4, 0xee, 0xcb, 0xe5, 0x65, 0xf3, 0xbc, 0x3d, 0x46, 0xe3, 0xdb, 0xbb, 0x93, 0xbb, 0x2f, 0xb7,
		0x54, 0x2b, 0x6c, 0xb4, 0xaf, 0x59, 0x92, 0x06, 0xf1, 0x88, 0x6b, 0x21, 0x26, 0x0f, 0x6d, 0xea,
		0xbb, 0xe8, 0xca, 0x04, 0x3e, 0x64, 0xe3, 0x19, 0x9d, 0x5e, 0xfd, 0xcf, 0x65, 0xda, 0x8a, 0x29,
		0x5a, 0x49, 0x47, 0xe3, 0x44, 0xd6, 0xe7, 0xda, 0x7d, 0x15, 0x58, 0x8f, 0xc2, 0x17, 0x91, 0xad,
		0x44, 0x87, 0x90, 0xa7, 0xce, 0x8f, 0x03, 0xf6, 0x08, 0xf6, 0x08, 0xf6, 0x08, 0xf6, 0xa8, 0xd5,
		0xe2, 0xe9, 0xf6, 0x1b, 0x13, 0xed, 0x2b, 0x4e, 0xa6, 0x4b, 0x70, 0x82, 0xbe, 0xaf, 0x44, 0x44,
		0x18, 0xb4, 0x98, 0x8e, 0x90, 0xb2, 0x8d, 0x1b, 0x70, 0x03, 0x70, 0x03, 0x70, 0x03, 0xbb, 0x3d,
		0x02, 0xb2, 0x8d, 0x1b, 0x0f, 0xcf, 0x4a, 0x48, 0x7a, 0xe5, 0x3d, 0x1e, 0x06, 0x9b, 0x35, 0xb8,
		0x01, 0x8d, 0x11, 0xd8, 0xb8, 0x00, 0x8e, 0x1d, 0xe8, 0xd8, 0x01, 0x8f, 0x17, 0xf8, 0x68, 0xe3,
		0x0b, 0xe9, 0xdf, 0xac, 0x11, 0xd3, 0x2e, 0xd2, 0x13, 0x5e, 0x19, 0x4e, 0x74, 0x65, 0x3a, 0xc1,
		0x95, 0xa1, 0x78, 0x99, 0xf3, 0x84, 0x56, 0xee, 0xb3, 0xe9, 0x98, 0x4f, 0x60, 0x35, 0x71, 0xd6,
		0x25, 0xc7, 0xd9, 0x89, 0x9c, 0x27, 0xaa, 0x9a, 0x32, 0x11, 0x73, 0x27, 0xa6, 0x1a, 0xb1, 0x1a,
		0x94, 0xb1, 0x92, 0xde, 0x2f, 0xc1, 0xaa, 0x2c, 0x38, 0xfd, 0x28, 0x12, 0xbe, 0x1a, 0xd5, 0xeb,
		0x8d, 0xba, 0xf3, 0xd3, 0xeb, 0x8c, 0xe5, 0x21, 0xa1, 0x39, 0xa0, 0x39, 0xa0, 0x39, 0xa0, 0x39,
		0x52, 0xa5, 0x39, 0x86, 0xc8, 0xa5, 0x5c, 0xe7, 0xab, 0x4c, 0xbd, 0xea, 0xf8, 0xe2, 0x8f, 0x19,
		0x42, 0xc1, 0xb7, 0xfd, 0x60, 0x7c, 0x92, 0x13, 0x29, 0x10, 0x40, 0xe5, 0x40, 0xe5, 0x40, 0xe5,
		0x40, 0xe5, 0x40, 0xe5, 0x40, 0xe5, 0xf0, 0xa8, 0x1c, 0x5f, 0x7c, 0x57, 0x56, 0x24, 0x82, 0x50,
		0xb9, 0x3d, 0xf7, 0xff, 0x46, 0x5b, 0xaa, 0x98, 0xc4, 0xce, 0xda, 0x91, 0xa1, 0x79, 0xa0, 0x79,
		0xa0, 0x79, 0xa0, 0x79, 0xa0, 0x79, 0xa0, 0x79, 0xa0, 0x79, 0xa0, 0x79, 0xa0, 0x79, 0xa0, 0x79,
		0xa0, 0x79, 0xa0, 0x79, 0xb4, 0x99, 0x49, 0xe0, 0x7b, 0xae, 0x2f, 0x98, 0x64, 0xce, 0xec, 0x60,
		0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0x50, 0x36,
		0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0x50, 0x36, 0xda, 0xcc, 0x24, 0xb4, 0x9d, 0xaf, 0x42, 0x31,
		0xec, 0x88, 0x99, 0x0c, 0x04, 0x45, 0x03, 0x45, 0x03, 0x45, 0x03, 0x45, 0x93, 0x2a, 0x45, 0x83,
		0x3d, 0x31, 0xd0, 0x17, 0xd0, 0x17, 0xd0, 0x17, 0xd0, 0x17, 0xd0, 0x17, 0xd0, 0x17, 0x6f, 0xd3,
		0x17, 0xea, 0xc9, 0x72, 0x9e, 0x86, 0x7e, 0x87, 0x45, 0x64, 0xcc, 0x8c, 0x06, 0xa5, 0x01, 0xa5,
		0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5, 0x01, 0xa5,
		0x01, 0xa5, 0x91, 0x59, 0xa5, 0x31, 0xea, 0x9d, 0xc2, 0x27, 0x35, 0xe6, 0x87, 0x83, 0xd6, 0x80,
		0xd6, 0x80, 0xd6, 0x80, 0xd6, 0x80, 0xd6, 0x80, 0xd6, 0x80, 0xd6, 0x80, 0xd6, 0x80, 0xd6, 0x80,
		0xd6, 0x80, 0xd6, 0x48, 0x86, 0xd6, 0x40, 0xc3, 0x5a, 0x03, 0xfd, 0x49, 0x47, 0xf2, 0xa8, 0x48,
		0x74, 0x84, 0xfb, 0x9e, 0x86, 0x06, 0xa5, 0x9f, 0x27, 0xb7, 0x96, 0x83, 0xb3, 0xfa, 0x3b, 0x42,
		0x3a, 0x91, 0x1b, 0x92, 0x58, 0xd9, 0x94, 0x4d, 0xce, 0x0e, 0x82, 0xc6, 0x2d, 0x38, 0xb1, 0xdf,
		0xbc, 0xbc, 0xc5, 0x89, 0xfd, 0x8c, 0x8e, 0x8c, 0xbe, 0x71, 0x8b, 0x54, 0x91, 0xeb, 0x3f, 0x52,
		0xf6, 0x6d, 0x39, 0xcc, 0x81, 0x2f, 0x78, 0x0a, 0xbc, 0x8e, 0x15, 0x46, 0x6e, 0x10, 0xb9, 0xea,
		0x99, 0xce, 0x1b, 0xcc, 0x0f, 0x43, 0xd7, 0x72, 0xb6, 0x04, 0x5f, 0xc3, 0xe2, 0x6b, 0x22, 0xf9,
		0x2d, 0x84, 0xaf, 0x49, 0xa0, 0xaf, 0x19, 0x4d, 0x0c, 0x7c, 0x8d, 0x66, 0x8b, 0xef, 0xbb, 0xbe,
		0x3a, 0x24, 0x74, 0x35, 0x14, 0xbd, 0x65, 0x69, 0xc3, 0xa0, 0x84, 0xf1, 0x68, 0x8e, 0xb0, 0x27,
		0x53, 0x2c, 0x8b, 0x2b, 0xcc, 0xc9, 0x19, 0xa8, 0x22, 0x0c, 0x6b, 0xb2, 0x84, 0x33, 0xb9, 0xa7,
		0xbe, 0x91, 0xa1, 0xa9, 0x4f, 0x49, 0x8c, 0xaf, 0x95, 0x03, 0xe2, 0xde, 0x13, 0x2a, 0x72, 0x1d,
		0x3a, 0xc6, 0x1e, 0x5f, 0x1f, 0x74, 0x1a, 0xa1, 0x1b, 0x84, 0x6e, 0x40, 0xa7, 0xb5, 0x5a, 0xbc,
		0xeb, 0xab, 0x83, 0x0a, 0x21, 0x9d, 0x3e, 0x00, 0x9d, 0x36, 0x43, 0xa7, 0xcb, 0x4c, 0x9c, 0xaa,
		0x52, 0xae, 0x36, 0xaa, 0x87, 0x07, 0xf5, 0xea, 0x21, 0x78, 0x75, 0x5e, 0x79, 0xf5, 0xd4, 0x06,
		0x40, 0xb0, 0x41, 0xb0, 0xc9, 0x08, 0xb6, 0xa5, 0x28, 0xbc, 0xe1, 0x02, 0xcb, 0x1e, 0x0f, 0x42,
		0x17, 0x15, 0x8f, 0x89, 0x8c, 0x3a, 0x3e, 0xbf, 0xbd, 0x6e, 0x5f, 0x34, 0xef, 0x6e, 0xce, 0x3e,
		0xb7, 0xcf, 0x2e, 0x7f, 0x6f, 0xde, 0x9c, 0xdd, 0x35, 0x4f, 0x41, 0xf1, 0x41, 0xf1, 0x41, 0xf1,
		0x41, 0xf1, 0x35, 0x53, 0xfc, 0x8e, 0xf0, 0x95, 0xab, 0x9e, 0x23, 0xd1, 0xa5, 0x4c, 0xd1, 0x52,
		0x04, 0xce, 0xcf, 0xe2, 0x5b, 0xff, 0x64, 0x4b, 0x86, 0xe3, 0x7d, 0x67, 0x20, 0xf9, 0xee, 0xcf,
		0xeb, 0x26, 0xd5, 0xea, 0x1a, 0xb1, 0x26, 0x49, 0x5a, 0x15, 0x4d, 0x4c, 0x2f, 0x57, 0x3c, 0xb0,
		0x57, 0x1f, 0x96, 0x46, 0x56, 0xce, 0xff, 0xbc, 0x4e, 0x3e, 0xdd, 0x5e, 0x9d, 0x7f, 0xb9, 0x6b,
		0xe2, 0x71, 0x6d, 0xf4, 0xb8, 0x6e, 0x9a, 0xe7, 0x27, 0x77, 0x67, 0xff, 0x69, 0xa6, 0x6d, 0x2b,
		0x4a, 0x2b, 0xe9, 0xde, 0x2c, 0x91, 0x7c, 0x3f, 0x2e, 0x1d, 0x25, 0x22, 0xfa, 0xa3, 0xab, 0x83,
		0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x6b, 0xb5, 0x78, 0xd4, 0x41, 0xea, 0xf8, 0xad, 0x41,
		0x28, 0x22, 0x4b, 0x2a, 0x5b, 0xf5, 0x25, 0x9d, 0x13, 0x98, 0x1d, 0x04, 0xbe, 0x00, 0xbe, 0x00,
		0xbe, 0x00, 0xbe, 0x00, 0x51, 0x17, 0x53, 0x51, 0x97, 0xab, 0xeb, 0xe6, 0x4d, 0xfb, 0xf6, 0xee,
		0xe4, 0xee, 0xcb, 0x2d, 0xa2, 0x2e, 0xbf, 0x7a, 0x60, 0x5f, 0xae, 0x11, 0x34, 0x58, 0xff, 0x74,
		0x4e, 0xaf, 0xfe, 0xe7, 0x12, 0x51, 0x82, 0x3c, 0x44, 0x09, 0x86, 0xde, 0x58, 0x44, 0xc2, 0x77,
		0x08, 0x63, 0x05, 0x33, 0x63, 0x80, 0x25, 0x82, 0x25, 0x82, 0x25, 0x82, 0x25, 0x6a, 0xb5, 0x78,
		0xec, 0x66, 0xe1, 0xa3, 0x09, 0x99, 0xdc, 0xcd, 0x52, 0x46, 0xd5, 0xdd, 0x46, 0x53, 0x9f, 0xc5,
		0xaa, 0xbb, 0x5a, 0x0d, 0xe5, 0x76, 0xdc, 0x57, 0x6d, 0xe5, 0x82, 0x58, 0x07, 0x4a, 0x8c, 0x26,
		0xde, 0x92, 0xea, 0xd9, 0x13, 0x56, 0x24, 0xfe, 0xb7, 0x2f, 0xa4, 0x12, 0x1d, 0x4a, 0xa2, 0xbd,
		0x76, 0x4c, 0x86, 0x62, 0xbc, 0x2f, 0x97, 0xd7, 0x37, 0x57, 0x77, 0xcd, 0xcf, 0xa8, 0xc1, 0x03,
		0xcf, 0x07, 0xcf, 0x07, 0xcf, 0xd7, 0x6e, 0xf1, 0x88, 0x06, 0x6f, 0xf8, 0xa0, 0x62, 0x1c, 0x3e,
		0xbb, 0xba, 0x44, 0x0d, 0xde, 0x46, 0x0f, 0xec, 0xfc, 0xec, 0xf2, 0x5f, 0xed, 0x99, 0xa7, 0x76,
		0xd3, 0xfc, 0xf7, 0x97, 0xb3, 0x1b, 0xd4, 0xe1, 0xfd, 0xf2, 0x99, 0x5d, 0x5e, 0x9d, 0x36, 0x17,
		0x1f, 0x5c, 0xf3, 0x16, 0x15, 0x8c, 0x3f, 0x7d, 0x72, 0xb3, 0x44, 0x09, 0x41, 0xf6, 0x1c, 0x68,
		0x81, 0x48, 0x04, 0xa1, 0x72, 0x7b, 0xee, 0xff, 0x09, 0x4b, 0xb9, 0x3d, 0x11, 0xd1, 0x29, 0x80,
		0xa5, 0x91, 0x40, 0xc4, 0x41, 0xc4, 0x41, 0xc4, 0x41, 0xc4, 0xb5, 0x5a, 0x7c, 0xdf, 0xf5, 0x55,
		0xb9, 0x4e, 0xc8, 0xc1, 0xeb, 0x88, 0xb8, 0xbf, 0xde, 0x38, 0xce, 0x8f, 0x7a, 0xfb, 0x38, 0x88,
		0xb8, 0x27, 0x76, 0xea, 0xeb, 0xb5, 0xda, 0x01, 0x62, 0xee, 0xec, 0x57, 0xcd, 0x43, 0xcc, 0x3d,
		0x0a, 0x3c, 0xc2, 0x32, 0x96, 0xd1, 0xd5, 0xc1, 0xa7, 0xc1, 0xa7, 0xc1, 0xa7, 0xc1, 0xa7, 0xb5,
		0x5a, 0x3c, 0x02, 0xdb, 0x1b, 0x3e, 0xa8, 0xf3, 0xdb, 0xeb, 0xf6, 0xcd, 0xd5, 0x39, 0x22, 0xda,
		0xbf, 0x7c, 0x52, 0x77, 0x37, 0x27, 0x97, 0xb7, 0x67, 0x77, 0x08, 0xc3, 0xae, 0x7f, 0x44, 0xcd,
		0x7f, 0xde, 0x34, 0x6f, 0x6f, 0xf1, 0x84, 0xd6, 0x3f, 0xa1, 0xb3, 0x4b, 0xea, 0x47, 0x84, 0x20,
		0x75, 0x62, 0xc8, 0xb3, 0x14, 0xaa, 0x1f, 0x32, 0xb4, 0x4e, 0x58, 0x18, 0x87, 0xae, 0x30, 0xa5,
		0x01, 0xb2, 0x8e, 0xde, 0x09, 0x79, 0x26, 0xeb, 0xe8, 0x9d, 0x40, 0x61, 0xf1, 0xa8, 0x36, 0xe7,
		0x63, 0x23, 0x88, 0x7d, 0x6f, 0x31, 0x0e, 0x62, 0xdf, 0x89, 0x9d, 0x7a, 0x1c, 0xed, 0xca, 0x7e,
		0xd5, 0x3c, 0xc4, 0xbd, 0xe5, 0x53, 0x10, 0x29, 0xa7, 0xaf, 0x2c, 0xe1, 0xb9, 0x8f, 0xee, 0x03,
		0x65, 0x10, 0x7c, 0x79, 0x28, 0x3a, 0x02, 0x3f, 0x64, 0x4a, 0xe0, 0xf0, 0x08, 0xb8, 0xe7, 0x99,
		0xc3, 0x23, 0xe0, 0x4e, 0x61, 0xf1, 0x0f, 0x41, 0xe0, 0x09, 0xdb, 0xa7, 0x0c, 0xb6, 0x97, 0xf3,
		0xe0, 0x77, 0xdc, 0x47, 0xdf, 0xf6, 0x5c, 0xff, 0xd1, 0x0a, 0xa3, 0x40, 0x05, 0x4e, 0xe0, 0x11,
		0x3a, 0x9e, 0xe5, 0xb1, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xb4, 0x5a, 0x3c, 0x72,
		0xb1, 0x1b, 0x3e, 0xa8, 0xeb, 0x93, 0xbb, 0xdf, 0xdb, 0xb7, 0xcd, 0xbb, 0x2f, 0xd7, 0xa3, 0x0d,
		0x20, 0x57, 0x9f, 0xaf, 0xce, 0x91, 0x96, 0x7d, 0xc3, 0x43, 0x3b, 0x3f, 0xc5, 0x11, 0x54, 0x9b,
		0x3d, 0xa9, 0x9b, 0xdb, 0xff, 0xe0, 0x51, 0x6d, 0xf6, 0xa8, 0x6e, 0x6f, 0x90, 0xac, 0xcd, 0x45,
		0xb2, 0x36, 0xe8, 0x2a, 0x2b, 0x8c, 0x84, 0xe8, 0x85, 0xca, 0x0d, 0x7c, 0x42, 0xda, 0xbd, 0x30,
		0x10, 0x5d, 0xb4, 0xa7, 0x6b, 0x7b, 0x12, 0xe1, 0x1e, 0xa4, 0x6c, 0x73, 0xcd, 0xe9, 0x91, 0xb2,
		0x45, 0xb8, 0x27, 0xc1, 0x4e, 0x87, 0x64, 0x75, 0xcf, 0xf8, 0x9a, 0xd1, 0xf5, 0xe1, 0x02, 0xe0,
		0x02, 0xe0, 0x02, 0xe0, 0x02, 0xf4, 0x86, 0x75, 0x42, 0xcb, 0xee, 0x74, 0x22, 0x21, 0x25, 0xa5,
		0x17, 0x38, 0x22, 0xb8, 0x76, 0xfc, 0x6c, 0x52, 0x57, 0xba, 0xf3, 0xfa, 0xe4, 0xbf, 0x55, 0x09,
		0x9f, 0xfd, 0xd2, 0x1c, 0x10, 0xb6, 0x50, 0x2e, 0x5c, 0xdb, 0x4a, 0x89, 0xc8, 0x27, 0x8d, 0x44,
		0x8d, 0x06, 0xfa, 0xef, 0xfb, 0xf7, 0xf7, 0x25, 0xeb, 0xa8, 0xf5, 0x72, 0x5f, 0xb6, 0x8e, 0x5a,
		0xe3, 0x97, 0xe5, 0xd1, 0x5f, 0xe3, 0xd7, 0x95, 0xfb, 0x92, 0x55, 0x9d, 0xbc, 0xae, 0xdd, 0x97,
		0xac, 0x5a, 0x6b, 0xff, 0xaf, 0xbf, 0x3e, 0xee, 0xff, 0x38, 0x18, 0xbc, 0xfd, 0x8b, 0xff, 0xa0,
		0x8b, 0x19, 0xb4, 0x28, 0x27, 0xe3, 0xea, 0xf6, 0xec, 0x0f, 0xcc, 0x88, 0xf1, 0x78, 0x0b, 0x61,
		0x10, 0x8d, 0x07, 0x9e, 0xea, 0x80, 0xa7, 0xed, 0x16, 0x83, 0x6d, 0x75, 0x4f, 0xac, 0xdf, 0x5a,
		0x3f, 0xca, 0x1f, 0xaa, 0x83, 0xe3, 0xfd, 0x1f, 0x8d, 0xc1, 0xe2, 0x9b, 0x2f, 0xab, 0x3e, 0x56,
		0xfe, 0xd0, 0x18, 0x1c, 0xaf, 0xf9, 0x97, 0xfa, 0xe0, 0x78, 0xc3, 0x6b, 0xd4, 0x06, 0xef, 0x97,
		0x3e, 0x3a, 0x7c, 0xbf, 0xb2, 0xee, 0x0b, 0xd5, 0x35, 0x5f, 0x38, 0x58, 0xf7, 0x85, 0x83, 0x35,
		0x5f, 0x58, 0x7b, 0x4b, 0x95, 0x35, 0x5f, 0xa8, 0x0d, 0x5e, 0x96, 0x3e, 0xff, 0x7e, 0xf5, 0x47,
		0xeb, 0x83, 0xfd, 0x97, 0x75, 0xff, 0xd6, 0x18, 0xbc, 0x1c, 0xef, 0x03, 0xac, 0x61, 0x9f, 0xb9,
		0xb5, 0x4f, 0x94, 0x9c, 0x26, 0x26, 0x16, 0xa4, 0x28, 0x14, 0xdb, 0xd4, 0x29, 0x8f, 0xae, 0x8e,
		0x38, 0x10, 0xca, 0x7b, 0x72, 0x1c, 0x07, 0x42, 0x79, 0x0f, 0x09, 0xdd, 0x47, 0x79, 0xcf, 0x66,
		0x0f, 0xea, 0xee, 0xcb, 0xe5, 0x65, 0xf3, 0x1c, 0xe7, 0x07, 0x6f, 0xf4, 0xb0, 0xae, 0x2b, 0x28,
		0x50, 0xf9, 0xe9, 0xe3, 0xb9, 0xb8, 0x46, 0x5d, 0x4a, 0x62, 0xeb, 0x52, 0xde, 0x25, 0xc8, 0x4a,
		0x0b, 0x27, 0xbe, 0x1f, 0x28, 0x5b, 0x7b, 0x51, 0x4b, 0x41, 0x3a, 0x4f, 0xa2, 0x67, 0x87, 0xb6,
		0x7a, 0x1a, 0x5a, 0x64, 0x31, 0x08, 0x85, 0xef, 0x8c, 0xa8, 0x9b, 0xe5, 0x0b, 0xf5, 0x77, 0x10,
		0x7d, 0xb5, 0x5c, 0x5f, 0x2a, 0xdb, 0x77, 0x44, 0x71, 0xf1, 0x0d, 0xb9, 0xf4, 0x4e, 0x71, 0xe8,
		0x9c, 0x8b, 0x9e, 0x0c, 0x65, 0xd1, 0x09, 0x7c, 0xa9, 0x22, 0xdb, 0xf5, 0x45, 0xc7, 0x1a, 0x5e,
		0xbd, 0xa8, 0xfa, 0xbe, 0x2f, 0x3c, 0x19, 0xff, 0x5d, 0x94, 0xca, 0x56, 0x42, 0x8f, 0xf1, 0xef,
		0x3e, 0x51, 0xbb, 0x5d, 0x61, 0xc7, 0x29, 0x1e, 0x52, 0xb6, 0xe1, 0xb3, 0xf7, 0x87, 0xa8, 0xb0,
		0xe3, 0xa5, 0xce, 0x5d, 0xa9, 0x4e, 0x94, 0xd2, 0x73, 0x92, 0x72, 0xe1, 0xc2, 0xf5, 0x9b, 0x9e,
		0x18, 0x72, 0x2f, 0xa9, 0x87, 0xc8, 0x17, 0x2e, 0xec, 0xef, 0x33, 0x57, 0x2c, 0x1f, 0x56, 0xab,
		0xf5, 0x46, 0xb5, 0x5a, 0x6a, 0x1c, 0x34, 0x4a, 0x47, 0xb5, 0x5a, 0xb9, 0xae, 0x83, 0x20, 0x14,
		0xae, 0xa2, 0x8e, 0x88, 0x44, 0xe7, 0xd3, 0xf0, 0xa9, 0xfa, 0x7d, 0xcf, 0x33, 0x3a, 0xb9, 0x9a,
		0xd7, 0xad, 0xa9, 0xf5, 0xaa, 0x81, 0xeb, 0x14, 0xa4, 0x8a, 0xfa, 0x8e, 0xf2, 0x63, 0xe7, 0x77,
		0x39, 0xbe, 0x97, 0xb3, 0xf8, 0x56, 0xda, 0x17, 0xa1, 0x27, 0xdb, 0xe7, 0x32, 0x94, 0xed, 0xcf,
		0xaf, 0xb7, 0x72, 0x6d, 0xab, 0xa7, 0xf6, 0xdd, 0xf8, 0x0e, 0xde, 0x99, 0x59, 0xe1, 0xdb, 0x7d,
		0x73, 0x4b, 0xb3, 0xd1, 0x65, 0x2e, 0xec, 0x66, 0xb2, 0xdd, 0xec, 0xbc, 0xfd, 0xd9, 0xbe, 0xed,
		0x1b, 0x6f, 0x9c, 0x85, 0x5d, 0x9f, 0x3e, 0xdb, 0x53, 0xdf, 0x62, 0x35, 0x6e, 0xbb, 0xfa, 0xde,
		0x36, 0xb1, 0x9b, 0x4f, 0xcf, 0x1b, 0xa6, 0xa6, 0x30, 0xe4, 0x0a, 0xae, 0x63, 0x0d, 0x1f, 0xc5,
		0x9b, 0xe7, 0xe5, 0xb5, 0x8a, 0x6a, 0xe6, 0x22, 0x6f, 0x34, 0x8b, 0x89, 0x7a, 0x7d, 0xe3, 0xd7,
		0xb6, 0x0d, 0x81, 0xed, 0x12, 0xe2, 0xd2, 0x10, 0xc2, 0xda, 0x35, 0x44, 0xa5, 0x2d, 0x04, 0xa5,
		0x2d, 0xc4, 0xa4, 0x27, 0x84, 0x44, 0x0b, 0x3d, 0xa7, 0x6e, 0xb4, 0x25, 0xe6, 0x4c, 0xed, 0x7a,
		0xfb, 0x19, 0x5b, 0x5e, 0x23, 0xdb, 0x4e, 0xd9, 0x76, 0x4b, 0x65, 0xe7, 0x25, 0xa3, 0x63, 0xe9,
		0x2c, 0x3d, 0x8d, 0x1d, 0x43, 0xc0, 0xba, 0x42, 0xbd, 0xda, 0x43, 0xba, 0xda, 0x43, 0xb7, 0x73,
		0xeb, 0x6b, 0xb7, 0xf8, 0x2c, 0x2f, 0xdb, 0xda, 0x76, 0xd1, 0x4d, 0x2f, 0xe0, 0x4c, 0xec, 0x75,
		0xc7, 0x29, 0x9e, 0x98, 0x5c, 0x7c, 0xbd, 0x5d, 0x05, 0xe5, 0x4e, 0x8b, 0x50, 0xdb, 0x62, 0xd4,
		0xb9, 0x28, 0x75, 0x2f, 0x4e, 0xdd, 0x8b, 0x94, 0x6c, 0xb1, 0x92, 0x2d, 0x5a, 0x82, 0xc5, 0x9b,
		0x8c, 0x70, 0xca, 0xae, 0x8b, 0x7a, 0x7a, 0xa1, 0x98, 0x2b, 0x6b, 0x32, 0x8c, 0x89, 0xe1, 0x6a,
		0x08, 0xf3, 0x2c, 0x2e, 0x74, 0x4d, 0x29, 0x56, 0xed, 0x39, 0x5b, 0x8a, 0x5c, 0xad, 0x6e, 0x00,
		0xa0, 0x02, 0x02, 0x72, 0x40, 0x20, 0x07, 0x06, 0x42, 0x80, 0xd0, 0x17, 0xb9, 0xdd, 0xd3, 0x18,
		0x62, 0xd7, 0x9e, 0x65, 0x9d, 0xe1, 0xd5, 0x91, 0xeb, 0x3f, 0xea, 0xb4, 0xd6, 0x69, 0xd9, 0x24,
		0x22, 0xe8, 0x29, 0x0a, 0xb2, 0xce, 0xc4, 0x20, 0x66, 0x5e, 0x17, 0x63, 0xd6, 0x67, 0x2a, 0xc0,
		0xb9, 0x83, 0xc4, 0x11, 0x8f, 0xa3, 0xfa, 0x60, 0x6d, 0xfc, 0x37, 0xbe, 0x1e, 0xf8, 0x2f, 0xf8,
		0x2f, 0xf8, 0xaf, 0x69, 0xfe, 0xab, 0x49, 0xdc, 0xd2, 0x88, 0x5c, 0xcd, 0x8b, 0x1d, 0x1c, 0x18,
		0x1c, 0x18, 0x1c, 0x58, 0x1f, 0x78, 0x4c, 0x2f, 0xe8, 0xfa, 0x4e, 0xd0, 0x73, 0xfd, 0x47, 0xcb,
		0xb3, 0x1f, 0x04, 0xe1, 0x39, 0x88, 0x0b, 0xe3, 0xa0, 0x48, 0x9a, 0xbc, 0x48, 0x1a, 0x15, 0xd2,
		0x86, 0x41, 0x89, 0x01, 0x9c, 0xf4, 0x82, 0x94, 0x66, 0xb0, 0xa2, 0x13, 0xee, 0x2b, 0x6d, 0x9d,
		0x04, 0x59, 0xf6, 0xb0, 0x4d, 0xfe, 0xe7, 0x4f, 0xbe, 0xef, 0xfa, 0xea, 0xa0, 0xc2, 0xb0, 0x03,
		0x95, 0xb0, 0x07, 0x01, 0x71, 0x9f, 0x11, 0xfa, 0xd9, 0x98, 0xfe, 0x10, 0x8e, 0xbe, 0x23, 0xc4,
		0x4e, 0x77, 0xed, 0x70, 0x93, 0x66, 0x14, 0xe5, 0x3a, 0xd3, 0x80, 0x8c, 0x5d, 0x29, 0x88, 0x90,
		0x77, 0xb5, 0x8d, 0x30, 0x34, 0x28, 0x31, 0x6e, 0x23, 0xa5, 0xea, 0x61, 0xad, 0x51, 0xcb, 0xb0,
		0xa1, 0xbc, 0x4b, 0xe7, 0xd5, 0x71, 0x8c, 0xc3, 0xbc, 0xfb, 0x14, 0x7e, 0xbf, 0x27, 0x22, 0x9b,
		0xe0, 0x8c, 0xca, 0x95, 0x0c, 0xa6, 0x4a, 0x38, 0x46, 0xd3, 0xef, 0xf7, 0x86, 0xc0, 0x82, 0x0e,
		0x3b, 0x89, 0x31, 0xe6, 0x82, 0x2f, 0xbe, 0x2b, 0xeb, 0x29, 0x08, 0xe9, 0x74, 0xfd, 0x74, 0x04,
		0x28, 0x7a, 0x28, 0x7a, 0x28, 0x7a, 0x28, 0x7a, 0x4d, 0xb6, 0x8e, 0x83, 0xef, 0x4c, 0x51, 0x12,
		0x1c, 0x7c, 0xb7, 0xc5, 0x40, 0x38, 0xf8, 0x6e, 0x83, 0xc9, 0xc0, 0xc1, 0x77, 0x50, 0x4c, 0x3a,
		0xe0, 0x09, 0x07, 0xdf, 0x6d, 0xb9, 0x18, 0x70, 0xb0, 0x18, 0x0e, 0xbe, 0x4b, 0x32, 0x58, 0xc3,
		0x3e, 0x71, 0xf0, 0x1d, 0x22, 0x41, 0x24, 0x91, 0xa0, 0xb0, 0x2f, 0x9f, 0xa8, 0x6b, 0x3c, 0x66,
		0xc6, 0x40, 0x34, 0x08, 0xd1, 0x20, 0x44, 0x83, 0x10, 0x0d, 0xd2, 0x68, 0xeb, 0xa8, 0xef, 0x30,
		0x21, 0xb7, 0x50, 0xdf, 0x91, 0x80, 0xd9, 0x98, 0xfe, 0x10, 0xd4, 0x77, 0x68, 0x1c, 0x10, 0xf5,
		0x1d, 0xe9, 0xb5, 0x11, 0xd4, 0x77, 0x24, 0xf3, 0xea, 0x88, 0x56, 0xce, 0xbb, 0x4f, 0xd4, 0x77,
		0x40, 0xd5, 0x93, 0x5c, 0x29, 0xaf, 0xe7, 0x96, 0xae, 0xd9, 0xa2, 0x3b, 0xde, 0x98, 0xaa, 0x65,
		0xa7, 0xae, 0xbe, 0x79, 0x1a, 0x68, 0x39, 0x94, 0xd1, 0x56, 0x04, 0xa7, 0x5c, 0x8c, 0x2f, 0x9b,
		0xf0, 0x2d, 0x7e, 0x15, 0x6c, 0xf1, 0x4b, 0x4d, 0xd4, 0x05, 0x5b, 0xfc, 0xb0, 0xc5, 0x0f, 0x5b,
		0xfc, 0x68, 0x41, 0x87, 0x1a, 0x7c, 0xa8, 0x41, 0x88, 0x0d, 0x8c, 0xd8, 0x40, 0x89, 0x01, 0x9c,
		0x68, 0x08, 0x32, 0x42, 0xc0, 0xab, 0x29, 0x0c, 0x42, 0xc0, 0xcb, 0x4f, 0x1e, 0x21, 0xe0, 0x04,
		0xcc, 0xc6, 0xf4, 0x87, 0x20, 0x04, 0xac, 0x71, 0x40, 0x84, 0x80, 0xd3, 0x6b, 0x23, 0x08, 0x01,
		0x27, 0xf3, 0xea, 0x08, 0x01, 0xcf, 0xbb, 0x4f, 0x84, 0x80, 0x8d, 0x99, 0x24, 0xb6, 0xf8, 0xe9,
		0x30, 0x60, 0x6c, 0xf1, 0x83, 0xa2, 0x87, 0xa2, 0x87, 0xa2, 0xd7, 0x6d, 0xeb, 0xd8, 0xe2, 0x67,
		0x8a, 0x92, 0x60, 0x8b, 0xdf, 0x16, 0x03, 0x61, 0x8b, 0xdf, 0x06, 0x93, 0x81, 0x2d, 0x7e, 0x50,
		0x4c, 0x3a, 0xe0, 0x09, 0x5b, 0xfc, 0xb6, 0x5c, 0x0c, 0xd8, 0x42, 0x85, 0x2d, 0x7e, 0x49, 0x06,
		0x6b, 0xd8, 0x27, 0xb6, 0xf8, 0x21, 0x12, 0x44, 0x12, 0x09, 0xc2, 0x16, 0x3f, 0x44, 0x83, 0x10,
		0x0d, 0x42, 0x34, 0x68, 0x0f, 0xf5, 0x1d, 0x88, 0x06, 0xbd, 0xe1, 0xc9, 0xa3, 0xbe, 0x23, 0x01,
		0xb3, 0x31, 0xfd, 0x21, 0xa8, 0xef, 0xd0, 0x38, 0x20, 0xea, 0x3b, 0xd2, 0x6b, 0x23, 0xa8, 0xef,
		0x48, 0xe6, 0xd5, 0x11, 0xad, 0x9c, 0x77, 0x9f, 0xa8, 0xef, 0x80, 0xaa, 0x27, 0xb9, 0x12, 0xb6,
		0xf8, 0xad, 0xda, 0xe2, 0x37, 0xde, 0xb9, 0x86, 0xb6, 0xaa, 0xe9, 0x6f, 0xab, 0xaa, 0xa5, 0x99,
		0xe8, 0xf8, 0xc6, 0x55, 0xd4, 0x77, 0x54, 0xdc, 0x0f, 0xbc, 0x70, 0x39, 0xbe, 0x93, 0xb3, 0xf8,
		0x46, 0xda, 0x17, 0xa1, 0x27, 0xdb, 0xe7, 0x32, 0x94, 0xed, 0xdb, 0xd1, 0xe0, 0xe7, 0x32, 0x6c,
		0x37, 0xc7, 0x63, 0xa7, 0xb0, 0xa5, 0xab, 0xeb, 0x6b, 0xee, 0xe9, 0x3a, 0xb9, 0x20, 0x9a, 0xba,
		0x72, 0xc5, 0xe3, 0xd0, 0xd4, 0x15, 0x4d, 0x5d, 0xd7, 0x5d, 0x08, 0x4d, 0x5d, 0x75, 0x5c, 0x10,
		0x3b, 0xbe, 0xb1, 0xe3, 0x3b, 0x3d, 0x04, 0x1d, 0x3b, 0xbe, 0x19, 0x03, 0x4f, 0xc8, 0x08, 0x32,
		0x82, 0x10, 0x1b, 0x18, 0xb1, 0x81, 0x12, 0x03, 0x38, 0xd1, 0xc4, 0x4b, 0x90, 0x11, 0x5c, 0x4d,
		0x61, 0x90, 0x11, 0x5c, 0x7e, 0xf2, 0xc8, 0x08, 0x26, 0x60, 0x36, 0xa6, 0x3f, 0x04, 0x19, 0x41,
		0x8d, 0x03, 0x22, 0x23, 0x98, 0x5e, 0x1b, 0x41, 0x46, 0x30, 0x99, 0x57, 0x47, 0x46, 0x70, 0xde,
		0x7d, 0x22, 0x23, 0x68, 0xcc, 0x24, 0xb1, 0xe3, 0x5b, 0x87, 0x01, 0x63, 0xc7, 0x37, 0x14, 0x3d,
		0x14, 0x3d, 0x14, 0xbd, 0x6e, 0x5b, 0xc7, 0x8e, 0x6f, 0x53, 0x94, 0x04, 0x3b, 0xbe, 0xb7, 0x18,
		0x08, 0x3b, 0xbe, 0x37, 0x98, 0x0c, 0xec, 0xf8, 0x86, 0x62, 0xd2, 0x01, 0x4f, 0xd8, 0xf1, 0xbd,
		0xe5, 0x62, 0xc0, 0x8e, 0x5a, 0xec, 0xf8, 0x4e, 0x32, 0x58, 0xc3, 0x3e, 0xb1, 0xe3, 0x1b, 0x91,
		0x20, 0x92, 0x48, 0x10, 0x76, 0x7c, 0x23, 0x1a, 0x84, 0x68, 0x10, 0xa2, 0x41, 0x7b, 0xa8, 0xef,
		0x40, 0x34, 0xe8, 0x0d, 0x4f, 0x1e, 0xf5, 0x1d, 0x09, 0x98, 0x8d, 0xe9, 0x0f, 0x41, 0x7d, 0x87,
		0xc6, 0x01, 0x51, 0xdf, 0x91, 0x5e, 0x1b, 0x41, 0x7d, 0x47, 0x32, 0xaf, 0x8e, 0x68, 0xe5, 0xbc,
		0xfb, 0x44, 0x7d, 0x07, 0x54, 0x3d, 0xc9, 0x95, 0xb0, 0xe3, 0x7b, 0x6e, 0x83, 0x70, 0xbc, 0x33,
		0x15, 0x5d, 0x5d, 0x37, 0x05, 0x26, 0x74, 0x75, 0x4d, 0x66, 0x18, 0x06, 0x7b, 0xfc, 0x0c, 0x84,
		0x59, 0xb0, 0xc7, 0x4f, 0xcb, 0x52, 0xc0, 0x1e, 0x3f, 0x62, 0xd0, 0xa1, 0x06, 0x1f, 0x6a, 0x10,
		0x62, 0x03, 0x23, 0x36, 0x50, 0x62, 0x00, 0x27, 0x1a, 0x86, 0x8c, 0x18, 0xf0, 0x6a, 0x0a, 0x83,
		0x18, 0xf0, 0xf2, 0x93, 0x47, 0x0c, 0x38, 0x01, 0xb3, 0x31, 0xfd, 0x21, 0x88, 0x01, 0x6b, 0x1c,
		0x10, 0x31, 0xe0, 0xf4, 0xda, 0x08, 0x62, 0xc0, 0xc9, 0xbc, 0x3a, 0x62, 0xc0, 0xf3, 0xee, 0x13,
		0x31, 0x60, 0x63, 0x26, 0x89, 0x3d, 0x7e, 0x3a, 0x0c, 0x18, 0x7b, 0xfc, 0xa0, 0xe8, 0xa1, 0xe8,
		0xa1, 0xe8, 0x75, 0xdb, 0x3a, 0xf6, 0xf8, 0x99, 0xa2, 0x24, 0xd8, 0xe3, 0xb7, 0xc5, 0x40, 0xd8,
		0xe3, 0xb7, 0xc1, 0x64, 0x60, 0x8f, 0x1f, 0x14, 0x93, 0x0e, 0x78, 0xc2, 0x1e, 0xbf, 0x2d, 0x17,
		0x03, 0xf6, 0x50, 0x61, 0x8f, 0x5f, 0x92, 0xc1, 0x1a, 0xf6, 0x89, 0x3d, 0x7e, 0x88, 0x04, 0x91,
		0x44, 0x82, 0xb0, 0xc7, 0x0f, 0xd1, 0x20, 0x44, 0x83, 0x10, 0x0d, 0xda, 0x43, 0x7d, 0x07, 0xa2,
		0x41, 0x6f, 0x78, 0xf2, 0xa8, 0xef, 0x48, 0xc0, 0x6c, 0x4c, 0x7f, 0x08, 0xea, 0x3b, 0x34, 0x0e,
		0x88, 0xfa, 0x8e, 0xf4, 0xda, 0x08, 0xea, 0x3b, 0x92, 0x79, 0x75, 0x44, 0x2b, 0xe7, 0xdd, 0x27,
		0xea, 0x3b, 0xa0, 0xea, 0x49, 0xae, 0x84, 0x3d, 0x7e, 0x2b, 0xf7, 0xf8, 0xa1, 0xad, 0x2b, 0xd5,
		0xcc, 0x1a, 0x9a, 0x51, 0x33, 0x7d, 0x5d, 0xcf, 0xfc, 0xd4, 0x36, 0x76, 0x8d, 0x7f, 0xa6, 0xa6,
		0xae, 0xae, 0xa3, 0xab, 0xe9, 0x69, 0xe9, 0x5a, 0x42, 0x4b, 0x57, 0xf6, 0xe0, 0x1b, 0x5a, 0xba,
		0x1a, 0x87, 0x61, 0x6d, 0xc1, 0xb1, 0xa9, 0xad, 0x79, 0xc2, 0xee, 0x46, 0xa2, 0xab, 0xc3, 0xdc,
		0x26, 0xbc, 0x51, 0x43, 0xf0, 0xa5, 0x70, 0x1d, 0x7b, 0x86, 0x8f, 0x1f, 0xc7, 0x5e, 0xb8, 0x38,
		0xc2, 0x8e, 0x14, 0x22, 0xa8, 0x9e, 0x5d, 0xf5, 0x5a, 0x77, 0xd3, 0x6b, 0x6f, 0x8b, 0x5d, 0x01,
		0x86, 0x02, 0x43, 0x53, 0x83, 0xa1, 0xda, 0xda, 0x62, 0x6b, 0x21, 0x47, 0x14, 0x24, 0x89, 0x28,
		0xa0, 0x86, 0x96, 0xd8, 0x38, 0x2e, 0x83, 0x07, 0x20, 0x92, 0x19, 0xdd, 0xd0, 0x9e, 0x99, 0x9c,
		0xf1, 0xea, 0x91, 0xeb, 0x3f, 0xea, 0xb4, 0xd6, 0x69, 0xc1, 0x21, 0xa2, 0x17, 0xe9, 0x8f, 0x5e,
		0x68, 0x88, 0x43, 0x99, 0x21, 0xbf, 0x2a, 0xb2, 0x7d, 0xe9, 0x2a, 0x7d, 0xf4, 0x77, 0x72, 0xc1,
		0x84, 0x11, 0x60, 0x04, 0x11, 0x40, 0x80, 0x73, 0x48, 0x80, 0x9d, 0x89, 0xfd, 0x6b, 0xa6, 0xc0,
		0xf1, 0x75, 0x13, 0x7e, 0x66, 0x1c, 0x48, 0x30, 0x48, 0x70, 0xfe, 0x48, 0x30, 0xce, 0x8c, 0x63,
		0x50, 0xda, 0x64, 0x60, 0x43, 0x09, 0x3a, 0xd4, 0xe0, 0x43, 0x0d, 0x42, 0x6c, 0x60, 0xc4, 0x06,
		0x4a, 0x0c, 0xe0, 0xa4, 0x17, 0xa4, 0x34, 0x83, 0x15, 0x9d, 0x72, 0x5f, 0x69, 0xeb, 0xa8, 0x29,
		0x5e, 0xfa, 0x83, 0x9a, 0xe2, 0xcd, 0x86, 0x40, 0x4d, 0x71, 0x72, 0x9c, 0xee, 0xda, 0xe1, 0x50,
		0x53, 0xac, 0xc9, 0x46, 0x50, 0x53, 0x9c, 0x01, 0x43, 0x41, 0x4d, 0x31, 0xfd, 0xb2, 0x41, 0x4d,
		0xf1, 0x5b, 0xc6, 0x40, 0x4d, 0x71, 0xe2, 0x8c, 0x19, 0x67, 0xc6, 0x41, 0xd1, 0x43, 0xd1, 0x43,
		0xd1, 0xe3, 0xcc, 0x38, 0x28, 0xfa, 0x37, 0x3c, 0x79, 0x9c, 0x19, 0xf7, 0xe6, 0x81, 0x70, 0x66,
		0xdc, 0x06, 0x93, 0x81, 0x33, 0xe3, 0xa0, 0x98, 0x74, 0xc0, 0x13, 0xce, 0x8c, 0xdb, 0x72, 0x31,
		0xe0, 0x4c, 0x2e, 0x9c, 0x19, 0x97, 0x64, 0xb0, 0x86, 0x7d, 0xe2, 0xcc, 0x38, 0x44, 0x82, 0x48,
		0x22, 0x41, 0x38, 0x33, 0x0e, 0xd1, 0x20, 0x44, 0x83, 0x10, 0x0d, 0xda, 0x43, 0x7d, 0x07, 0xa2,
		0x41, 0x6f, 0x78, 0xf2, 0xa8, 0xef, 0x48, 0xc0, 0x6c, 0x4c, 0x7f, 0x08, 0xea, 0x3b, 0x34, 0x0e,
		0x88, 0xfa, 0x8e, 0xf4, 0xda, 0x08, 0xea, 0x3b, 0x92, 0x79, 0x75, 0x44, 0x2b, 0xe7, 0xdd, 0x27,
		0xea, 0x3b, 0xa0, 0xea, 0x49, 0xae, 0x84, 0x33, 0xe3, 0xe6, 0xf6, 0xe8, 0xc6, 0x3b, 0x53, 0x8b,
		0xf1, 0xde, 0xb5, 0xa4, 0x6c, 0xbb, 0xd6, 0x72, 0xe0, 0x99, 0x8e, 0x13, 0x6c, 0x96, 0x80, 0x49,
		0xc7, 0x49, 0x36, 0x4b, 0xf0, 0xa3, 0x7b, 0x8f, 0x5f, 0x05, 0x7b, 0xfc, 0x52, 0x13, 0x76, 0xc1,
		0x1e, 0x3f, 0xec, 0xf1, 0xc3, 0x1e, 0x3f, 0x5a, 0xd0, 0xa1, 0x06, 0x1f, 0x6a, 0x10, 0x62, 0x03,
		0x23, 0x36, 0x50, 0x62, 0x00, 0x27, 0x1a, 0x86, 0x8c, 0x18, 0xf0, 0x6a, 0x0a, 0x83, 0x18, 0xf0,
		0xf2, 0x93, 0x47, 0x0c, 0x38, 0x01, 0xb3, 0x31, 0xfd, 0x21, 0x88, 0x01, 0x6b, 0x1c, 0x10, 0x31,
		0xe0, 0xf4, 0xda, 0x08, 0x62, 0xc0, 0xc9, 0xbc, 0x3a, 0x62, 0xc0, 0xf3, 0xee, 0x13, 0x31, 0x60,
		0x63, 0x26, 0x89, 0x3d, 0x7e, 0x3a, 0x0c, 0x18, 0x7b, 0xfc, 0xa0, 0xe8, 0xa1, 0xe8, 0xa1, 0xe8,
		0x75, 0xdb, 0x3a, 0xf6, 0xf8, 0x99, 0xa2, 0x24, 0xd8, 0xe3, 0xb7, 0xc5, 0x40, 0xd8, 0xe3, 0xb7,
		0xc1, 0x64, 0x60, 0x8f, 0x1f, 0x14, 0x93, 0x0e, 0x78, 0xc2, 0x1e, 0xbf, 0x2d, 0x17, 0x03, 0xf6,
		0x50, 0x61, 0x8f, 0x5f, 0x92, 0xc1, 0x1a, 0xf6, 0x89, 0x3d, 0x7e, 0x88, 0x04, 0x91, 0x44, 0x82,
		0xb0, 0xc7, 0x0f, 0xd1, 0x20, 0x44, 0x83, 0x10, 0x0d, 0xda, 0x43, 0x7d, 0x07, 0xa2, 0x41, 0x6f,
		0x78, 0xf2, 0xa8, 0xef, 0x48, 0xc0, 0x6c, 0x4c, 0x7f, 0x08, 0xea, 0x3b, 0x34, 0x0e, 0x88, 0xfa,
		0x8e, 0xf4, 0xda, 0x08, 0xea, 0x3b, 0x92, 0x79, 0x75, 0x44, 0x2b, 0xe7, 0xdd, 0x27, 0xea, 0x3b,
		0xa0, 0xea, 0x49, 0xae, 0x84, 0x3d, 0x7e, 0x2b, 0xf7, 0xf8, 0x69, 0xe8, 0xc7, 0xa9, 0x6f, 0x9e,
		0xd0, 0x59, 0x75, 0xf7, 0x19, 0x2d, 0x68, 0xd9, 0x26, 0x19, 0xf5, 0x1d, 0x15, 0xf7, 0x04, 0x2f,
		0x5c, 0x8e, 0x6f, 0xe5, 0x2c, 0xbe, 0x93, 0xf6, 0x45, 0xe8, 0xc9, 0xf6, 0xb9, 0x0c, 0x65, 0xfb,
		0x76, 0x34, 0xfa, 0xb9, 0x0c, 0xdb, 0x77, 0xf1, 0xe0, 0xa6, 0x1a, 0xbb, 0xbe, 0x63, 0x34, 0x98,
		0xc2, 0xbf, 0xc4, 0xf3, 0x8e, 0xdd, 0xcd, 0x0b, 0xe7, 0xae, 0x54, 0x27, 0x4a, 0xed, 0xb6, 0x37,
		0x6d, 0xa8, 0x6e, 0x9a, 0x9e, 0xe8, 0x09, 0x7f, 0x4c, 0xb2, 0x76, 0xe8, 0x6e, 0x7b, 0x61, 0x7f,
		0x9f, 0xb9, 0x52, 0xf9, 0xb0, 0x5a, 0xad, 0x37, 0xaa, 0xd5, 0x52, 0xe3, 0xa0, 0x51, 0x3a, 0xaa,
		0xd5, 0xca, 0xf5, 0xf2, 0x0e, 0xd4, 0xb1, 0x70, 0x15, 0x75, 0x44, 0x24, 0x3a, 0x9f, 0x86, 0x4f,
		0xcd, 0xef, 0x7b, 0x1e, 0xeb, 0x64, 0x69, 0x5a, 0xd5, 0xcc, 0xab, 0x79, 0x87, 0x55, 0xfc, 0xf6,
		0xd5, 0xbb, 0xdd, 0xaa, 0x7d, 0xfb, 0x9a, 0x7b, 0xdb, 0x37, 0xde, 0x38, 0xe1, 0xbb, 0x4e, 0x34,
		0xc7, 0x04, 0xbf, 0xed, 0x41, 0x6f, 0xfe, 0xb8, 0xde, 0xf0, 0xa8, 0x0a, 0xfd, 0xe1, 0xaf, 0x92,
		0x2a, 0xb2, 0x5d, 0x5f, 0x74, 0xac, 0xf8, 0xe7, 0xbe, 0xed, 0x71, 0xbd, 0xc6, 0xba, 0x96, 0xaf,
		0xf5, 0xc6, 0x49, 0xdb, 0x6e, 0xb3, 0xfb, 0xd6, 0x79, 0x88, 0x5d, 0xf2, 0x0c, 0xd3, 0x5f, 0x1d,
		0x38, 0xd6, 0x96, 0xa9, 0x84, 0x5d, 0x53, 0x05, 0xda, 0x52, 0x01, 0xda, 0x42, 0xfd, 0x73, 0xa1,
		0xfc, 0xc9, 0x83, 0x49, 0x18, 0x30, 0x6c, 0xbb, 0x05, 0xbc, 0x30, 0x34, 0x68, 0x4b, 0x0a, 0xd5,
		0x0f, 0xad, 0x30, 0x0a, 0x54, 0xe0, 0x04, 0xdb, 0xe7, 0x02, 0x5f, 0x73, 0x7e, 0x2b, 0x2e, 0xba,
		0x2d, 0x0f, 0xd9, 0xe9, 0xa4, 0x88, 0x9d, 0x93, 0x79, 0x3a, 0x92, 0x76, 0x1a, 0x16, 0x95, 0xae,
		0xc5, 0xa5, 0x7d, 0x91, 0x69, 0x5f, 0x6c, 0x7a, 0x17, 0x9d, 0x19, 0xee, 0xbc, 0xeb, 0x79, 0x0c,
		0x05, 0xaf, 0xb3, 0xfb, 0xe6, 0x8c, 0xa9, 0xd5, 0x0d, 0x2f, 0xb6, 0xe3, 0x5c, 0xe8, 0x39, 0xae,
		0x45, 0x5b, 0x66, 0x5d, 0x67, 0x26, 0x7d, 0x76, 0x71, 0xee, 0xfe, 0xa4, 0xf6, 0x08, 0x72, 0xe5,
		0x64, 0xb9, 0x71, 0xb2, 0x5c, 0xf8, 0xe2, 0xda, 0x1d, 0x3e, 0x57, 0xc4, 0x4d, 0x58, 0x88, 0xf8,
		0x32, 0x5b, 0x2d, 0xae, 0x70, 0xc6, 0x45, 0x4d, 0x96, 0xbe, 0xa9, 0x0a, 0xfb, 0x32, 0x7b, 0x57,
		0xd7, 0xb6, 0x7a, 0x6a, 0x0f, 0xff, 0xef, 0x76, 0x78, 0x4f, 0xd7, 0xf1, 0x2d, 0xb5, 0xcf, 0x77,
		0x35, 0x92, 0xb4, 0x44, 0x56, 0x92, 0x2e, 0xd6, 0x37, 0x33, 0x21, 0x0e, 0xf1, 0xbe, 0x81, 0xd9,
		0x40, 0xd6, 0xf3, 0x9a, 0xc2, 0x36, 0x82, 0x70, 0xeb, 0xe9, 0x26, 0x0b, 0x25, 0xbc, 0xd3, 0x38,
		0x89, 0xdb, 0x4e, 0x1e, 0xd5, 0xa4, 0xbd, 0x61, 0x86, 0x36, 0x9d, 0x99, 0xcd, 0xe6, 0xe1, 0xd7,
		0x4f, 0x75, 0x83, 0x27, 0x5a, 0x90, 0xee, 0xa3, 0x6f, 0x7b, 0xae, 0xff, 0x38, 0x45, 0x1a, 0xb9,
		0xf1, 0x63, 0x7d, 0x3d, 0xab, 0x70, 0xc5, 0x45, 0x36, 0x9c, 0xcd, 0xb7, 0x51, 0xdd, 0x37, 0x53,
		0xda, 0x6d, 0xa8, 0xeb, 0x0e, 0xfa, 0x71, 0x5b, 0x2e, 0xba, 0x33, 0xe7, 0xdc, 0x99, 0x5b, 0xee,
		0xa6, 0xff, 0xf4, 0xae, 0xf0, 0xb7, 0xea, 0xb9, 0xad, 0xf4, 0xdb, 0x0e, 0x7a, 0x2d, 0xad, 0x11,
		0xc6, 0xed, 0x58, 0x68, 0xf6, 0x03, 0x8c, 0x5b, 0xe9, 0xa5, 0x84, 0xc6, 0x17, 0x1f, 0xbd, 0xe0,
		0xc1, 0xd6, 0x10, 0x52, 0x8c, 0xaf, 0x83, 0x28, 0xe2, 0xee, 0x81, 0x8a, 0xfc, 0x06, 0x11, 0x77,
		0x0a, 0x44, 0xa4, 0x2c, 0x86, 0x68, 0xf7, 0xd5, 0x93, 0xf0, 0x95, 0xeb, 0xe8, 0x89, 0x5a, 0x4c,
		0xcd, 0x6f, 0xe1, 0xba, 0x88, 0x2c, 0x22, 0xb2, 0x88, 0xc8, 0xe2, 0x0e, 0xbf, 0x48, 0xd7, 0xe1,
		0xcd, 0x05, 0x67, 0xb2, 0x06, 0x34, 0x1f, 0xfc, 0x1e, 0x5f, 0x37, 0xe1, 0x27, 0xbf, 0x97, 0x52,
		0x70, 0xf2, 0xbb, 0x36, 0x20, 0xa0, 0x02, 0x04, 0x72, 0x60, 0x20, 0x07, 0x08, 0x52, 0xa0, 0xd0,
		0x03, 0x18, 0x9a, 0x80, 0x43, 0x3b, 0x80, 0xac, 0x61, 0x0e, 0xd6, 0xd7, 0x51, 0x25, 0x20, 0xd1,
		0xee, 0xe0, 0x15, 0x63, 0x61, 0x97, 0x30, 0xf9, 0x2e, 0x61, 0xed, 0x40, 0x44, 0x0d, 0x48, 0x6c,
		0xc0, 0xc4, 0x06, 0x50, 0x2c, 0x40, 0xa5, 0x17, 0xb0, 0x34, 0x03, 0xd7, 0xf4, 0x09, 0xd0, 0xef,
		0x14, 0x8e, 0x82, 0xbe, 0x1a, 0x45, 0x83, 0x6d, 0x29, 0x47, 0xe6, 0x43, 0xb8, 0x5f, 0xf8, 0x30,
		0x07, 0xe7, 0x46, 0x08, 0xdf, 0x7e, 0xf0, 0x04, 0x9d, 0x57, 0x88, 0xaf, 0xaf, 0xd9, 0xce, 0x4e,
		0x45, 0xd7, 0xee, 0x7b, 0xa3, 0x85, 0xd6, 0xb5, 0x3d, 0x29, 0xe0, 0x69, 0xe0, 0x69, 0xe0, 0x69,
		0xe0, 0x69, 0x74, 0xda, 0xfb, 0x43, 0x10, 0x78, 0xc2, 0xf6, 0x29, 0x1d, 0x4c, 0x19, 0x5b, 0x18,
		0x37, 0x31, 0xf6, 0xf4, 0x6c, 0x61, 0x5c, 0x91, 0xad, 0x2e, 0x7a, 0x9d, 0xb0, 0x38, 0x4e, 0x79,
		0x14, 0xe7, 0x25, 0x12, 0x1a, 0x16, 0x6e, 0xba, 0x14, 0xd1, 0xb0, 0x10, 0x61, 0x2b, 0x84, 0xad,
		0x10, 0xb6, 0x42, 0xd8, 0x0a, 0x62, 0x02, 0x62, 0x02, 0x62, 0x02, 0x61, 0x2b, 0x84, 0xad, 0x10,
		0xb6, 0x82, 0xa7, 0x81, 0xa7, 0x81, 0xa7, 0x81, 0xa7, 0x41, 0xd8, 0x0a, 0x61, 0x2b, 0xce, 0xb0,
		0x15, 0xce, 0xe0, 0xa2, 0x9a, 0x63, 0xe3, 0x73, 0xcb, 0xb4, 0x93, 0xf4, 0x76, 0x72, 0x4f, 0x93,
		0xbd, 0x7f, 0xb2, 0x7d, 0xde, 0x09, 0xdb, 0xff, 0x1c, 0xdd, 0x52, 0xfb, 0x64, 0xfe, 0x96, 0x4c,
		0xed, 0x24, 0xdd, 0xa1, 0x2a, 0x5b, 0x53, 0xfd, 0x9e, 0xde, 0xba, 0x3d, 0x14, 0xe8, 0x9a, 0x64,
		0x77, 0x28, 0xd0, 0x4d, 0x00, 0x5c, 0x6b, 0x2b, 0xd0, 0xf5, 0x64, 0x64, 0xb9, 0x1d, 0xfd, 0x89,
		0x8e, 0xf8, 0xba, 0x7a, 0x33, 0x1d, 0x25, 0x14, 0xe8, 0x26, 0x58, 0xee, 0x21, 0xd3, 0x91, 0x22,
		0x4e, 0xaf, 0x5d, 0xbe, 0xd1, 0xf6, 0x43, 0xa5, 0xe8, 0x7c, 0x41, 0xd3, 0xf1, 0x82, 0xb4, 0xd3,
		0x2c, 0x69, 0xbf, 0x53, 0xca, 0x46, 0x82, 0xe4, 0x0d, 0x04, 0x53, 0xdf, 0x45, 0xb3, 0x45, 0xf1,
		0xd0, 0x39, 0x5a, 0xe3, 0xa5, 0xff, 0xc9, 0x27, 0x39, 0xce, 0x46, 0x0b, 0x27, 0x75, 0xc0, 0xc9,
		0xcf, 0x8d, 0x1a, 0x7d, 0x1e, 0x33, 0xd1, 0xe7, 0x31, 0xf5, 0xe0, 0x0a, 0x3b, 0xcc, 0x86, 0x1d,
		0x26, 0x34, 0xdf, 0xd0, 0x42, 0x0c, 0x3c, 0x13, 0x31, 0x70, 0x1d, 0x75, 0xb8, 0x66, 0x02, 0xcd,
		0x8f, 0x91, 0xed, 0x88, 0x6e, 0xdf, 0xb3, 0x22, 0x21, 0x95, 0x1d, 0x29, 0x7d, 0x21, 0xe7, 0xa5,
		0x2b, 0x23, 0xf8, 0x8c, 0xe0, 0x33, 0x82, 0xcf, 0x49, 0x08, 0x3e, 0xe3, 0x74, 0x08, 0x04, 0x9f,
		0x11, 0x7c, 0xce, 0x5f, 0xf0, 0x59, 0x7b, 0x99, 0xfd, 0xb8, 0xc8, 0xb1, 0x43, 0x5d, 0x45, 0xd9,
		0x41, 0x19, 0xe5, 0x1e, 0xca, 0x28, 0xb9, 0xa1, 0x8d, 0x0d, 0xe2, 0xd8, 0xa0, 0x8e, 0x05, 0xf2,
		0xf4, 0xab, 0xe4, 0x3d, 0x94, 0x51, 0xae, 0x66, 0x46, 0xe5, 0x1c, 0xd4, 0xe9, 0x77, 0x83, 0xe8,
		0x6f, 0x3b, 0xea, 0x0c, 0xa5, 0xf7, 0x53, 0xe0, 0x75, 0x94, 0xdb, 0x23, 0x2c, 0xda, 0x5f, 0x35,
		0x18, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x83, 0x46, 0x7b, 0xef, 0xbb, 0xbe, 0x2a, 0xd7,
		0x09, 0x3d, 0x43, 0x9d, 0xe0, 0xd2, 0x37, 0xb6, 0xff, 0x28, 0xc8, 0x12, 0x2e, 0x84, 0x9d, 0xd6,
		0x2f, 0x5c, 0x9f, 0x0c, 0x00, 0x88, 0x61, 0x7d, 0x69, 0x98, 0xff, 0xd8, 0x5e, 0x5f, 0x30, 0x8c,
		0xf3, 0x5b, 0x64, 0x3b, 0xca, 0x0d, 0xfc, 0x53, 0xf7, 0xd1, 0x1d, 0xf7, 0xda, 0x25, 0x1b, 0x6f,
		0x40, 0xd8, 0x91, 0xfe, 0xc2, 0xfe, 0x9e, 0xb9, 0xa9, 0xaf, 0xd7, 0x6a, 0x07, 0xb5, 0x0c, 0x4d,
		0xff, 0xbb, 0x74, 0x5c, 0xb5, 0x95, 0x03, 0xae, 0xfd, 0x24, 0xbc, 0x50, 0x44, 0x16, 0xf5, 0xd6,
		0xd8, 0xf9, 0x61, 0xc0, 0xaf, 0xc1, 0xaf, 0xc1, 0xaf, 0xc1, 0xaf, 0x11, 0x7a, 0x49, 0x9a, 0x3b,
		0x88, 0x84, 0x13, 0xf8, 0xbe, 0x70, 0x94, 0x45, 0x1b, 0x75, 0x59, 0x18, 0x07, 0x0e, 0x01, 0x0e,
		0x01, 0x0e, 0x01, 0x0e, 0x01, 0x01, 0x17, 0x04, 0x5c, 0x10, 0x70, 0x41, 0xc0, 0x05, 0x01, 0x17,
		0x04, 0x5c, 0x32, 0xcc, 0xb0, 0xbf, 0x89, 0xe8, 0x99, 0x81, 0x60, 0xbf, 0x0e, 0x03, 0x7e, 0x0d,
		0x7e, 0x0d, 0x7e, 0x0d, 0x7e, 0x0d, 0x7e, 0x0d, 0x7e, 0x0d, 0x7e, 0x0d, 0x7e, 0x0d, 0x7e, 0x0d,
		0x7e, 0x9d, 0x24, 0x7e, 0x8d, 0x33, 0x18, 0x49, 0xf6, 0x28, 0x2e, 0xee, 0xc7, 0x43, 0xf3, 0x90,
		0x4d, 0xd9, 0x0d, 0x9a, 0x87, 0x24, 0x55, 0x16, 0x61, 0x57, 0x93, 0x11, 0xd9, 0x83, 0x5d, 0x4d,
		0xbb, 0xad, 0x03, 0xec, 0x6a, 0x42, 0xa4, 0x07, 0x91, 0x1e, 0x44, 0x7a, 0x50, 0x5a, 0xb3, 0x8a,
		0x19, 0x61, 0x57, 0x93, 0xe6, 0x39, 0xc3, 0xae, 0x26, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0x24,
		0x01, 0x96, 0x2f, 0x8d, 0x24, 0x00, 0x3f, 0xac, 0x2f, 0x0d, 0x83, 0x24, 0xc0, 0xdb, 0xa6, 0x1e,
		0x49, 0x80, 0xc4, 0x4f, 0x3f, 0x92, 0x00, 0x89, 0xe1, 0xda, 0xd8, 0xd5, 0x04, 0x7e, 0x0d, 0x7e,
		0x0d, 0x7e, 0x8d, 0xd0, 0x0b, 0x42, 0x2f, 0xd8, 0xd5, 0x04, 0x87, 0x00, 0x87, 0x00, 0x87, 0x80,
		0x80, 0x0b, 0x02, 0x2e, 0x08, 0xb8, 0x20, 0xe0, 0x82, 0x80, 0x0b, 0x02, 0x2e, 0x08, 0xb8, 0x60,
		0x57, 0x13, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35,
		0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0x76, 0x35, 0xbd, 0xf9, 0xba, 0x09, 0xd8, 0xd5, 0x34, 0xde,
		0xac, 0x83, 0xbe, 0x7a, 0x99, 0xe8, 0xab, 0xa7, 0xb9, 0x87, 0xdc, 0xf8, 0x57, 0xa8, 0xa8, 0xef,
		0x28, 0x3f, 0xe6, 0x78, 0x97, 0xe3, 0xdb, 0x3a, 0x8b, 0xef, 0xaa, 0x7d, 0x11, 0x7a, 0xb2, 0x7d,
		0x3b, 0xb9, 0xab, 0xeb, 0xc9, 0x4d, 0xb5, 0xcf, 0x3b, 0x61, 0xfb, 0x9f, 0xa3, 0x9b, 0x6a, 0xff,
		0x33, 0xbe, 0xa9, 0x9b, 0xf8, 0x9e, 0x52, 0xd8, 0xf5, 0x4f, 0xcf, 0x46, 0x39, 0xad, 0x1b, 0xe4,
		0xb4, 0xf7, 0xf7, 0xab, 0xa0, 0xbf, 0x5f, 0x02, 0x14, 0x32, 0xfa, 0xfb, 0x6d, 0xfe, 0x8b, 0xb4,
		0xf5, 0xf7, 0xf3, 0x64, 0x64, 0xb9, 0x1d, 0xfd, 0x1b, 0x61, 0xe3, 0xeb, 0xea, 0xdd, 0x09, 0x5b,
		0x42, 0x7f, 0xbf, 0x04, 0x87, 0xd0, 0xb0, 0x13, 0x36, 0x45, 0xb4, 0x5e, 0x7b, 0x48, 0x6c, 0x6a,
		0xaf, 0x6e, 0x68, 0xd9, 0x9d, 0x4e, 0x24, 0xa4, 0xd4, 0x69, 0xb3, 0x13, 0x97, 0x7f, 0xa4, 0xf1,
		0x9a, 0xf1, 0x33, 0xd0, 0x1b, 0xfe, 0x22, 0x0c, 0x32, 0xba, 0xe1, 0xb7, 0x2a, 0xc1, 0xb3, 0x5d,
		0x7a, 0xc6, 0x87, 0x14, 0xad, 0xf8, 0x99, 0xba, 0xf0, 0xb7, 0x5e, 0xee, 0xcb, 0xd6, 0x51, 0x6b,
		0xfc, 0xb2, 0x3c, 0xfa, 0x6b, 0xfc, 0xba, 0x72, 0x5f, 0xb2, 0xaa, 0x93, 0xd7, 0xb5, 0xfb, 0x92,
		0x55, 0x6b, 0xed, 0xff, 0xf5, 0xd7, 0xc7, 0xfd, 0x1f, 0x07, 0x83, 0xb7, 0x7f, 0x91, 0xa2, 0xef,
		0x3c, 0xc5, 0x43, 0xbf, 0xba, 0x3d, 0xfb, 0x03, 0x4f, 0x9e, 0x37, 0x0e, 0xf4, 0x21, 0x45, 0x70,
		0x52, 0x07, 0x9c, 0xfc, 0xdc, 0xa8, 0x6d, 0xab, 0x7b, 0x62, 0xfd, 0xd6, 0xfa, 0x51, 0xfe, 0x50,
		0x1d, 0x1c, 0xef, 0xff, 0x68, 0x0c, 0x16, 0xdf, 0x7c, 0x59, 0xf5, 0xb1, 0xf2, 0x87, 0xc6, 0xe0,
		0x78, 0xcd, 0xbf, 0xd4, 0x07, 0xc7, 0x1b, 0x5e, 0xa3, 0x36, 0x78, 0xbf, 0xf4, 0xd1, 0xe1, 0xfb,
		0x95, 0x75, 0x5f, 0xa8, 0xae, 0xf9, 0xc2, 0xc1, 0xba, 0x2f, 0x1c, 0xac, 0xf9, 0xc2, 0xda, 0x5b,
		0xaa, 0xac, 0xf9, 0x42, 0x6d, 0xf0, 0xb2, 0xf4, 0xf9, 0xf7, 0xab, 0x3f, 0x5a, 0x1f, 0xec, 0xbf,
		0xac, 0xfb, 0xb7, 0xc6, 0xe0, 0xe5, 0x78, 0x1f, 0xe0, 0x0a, 0x3b, 0xcc, 0xac, 0x1d, 0x26, 0x34,
		0xe5, 0xd0, 0x42, 0x10, 0x3c, 0x13, 0x41, 0x70, 0x0d, 0x19, 0x8d, 0x1d, 0xa2, 0xcc, 0xef, 0x18,
		0x27, 0x4d, 0xd7, 0x64, 0xf1, 0x4f, 0x52, 0x61, 0xa7, 0x60, 0xfc, 0x6e, 0x09, 0x89, 0xed, 0x4c,
		0xe3, 0xed, 0x13, 0xbb, 0xc5, 0xa4, 0x16, 0x5c, 0x5f, 0x89, 0xa8, 0x6b, 0x3b, 0xc2, 0xb2, 0x95,
		0x8a, 0xdc, 0x87, 0xbe, 0x12, 0x72, 0xeb, 0xa9, 0x7d, 0x25, 0xb9, 0xab, 0xae, 0xba, 0xa5, 0xc9,
		0xed, 0x96, 0x76, 0xd8, 0x39, 0xea, 0xa8, 0x23, 0xca, 0xa8, 0x2f, 0xaa, 0xa8, 0x2b, 0x8a, 0xa8,
		0x3d, 0x6a, 0xa8, 0x3d, 0x4a, 0xa8, 0x35, 0x2a, 0xc8, 0x0b, 0x92, 0xbb, 0xa6, 0x09, 0x0a, 0xce,
		0xc4, 0x66, 0x35, 0xa5, 0xff, 0xe2, 0xeb, 0x25, 0x2c, 0xff, 0x57, 0x42, 0xfe, 0x2f, 0x01, 0x61,
		0x7e, 0xe4, 0xff, 0xf8, 0x16, 0xf6, 0xf4, 0x42, 0x4f, 0xc2, 0xf3, 0x02, 0xfd, 0x07, 0x8b, 0xcd,
		0x1e, 0x75, 0x30, 0x7b, 0x7d, 0xe4, 0x03, 0x93, 0x03, 0x0c, 0x54, 0x00, 0x41, 0x0e, 0x14, 0xe4,
		0x80, 0x41, 0x0a, 0x1c, 0x7a, 0xd5, 0x7b, 0xf2, 0xf3, 0x81, 0xda, 0x4b, 0xe3, 0x09, 0x4a, 0xe2,
		0x89, 0x4a, 0xe1, 0x09, 0x82, 0xf7, 0x94, 0xa5, 0xef, 0xc4, 0x75, 0xcf, 0xd4, 0xa5, 0xee, 0x1c,
		0x35, 0xce, 0x04, 0xa5, 0xed, 0xa4, 0x25, 0xed, 0x5c, 0x53, 0x4a, 0x58, 0xc2, 0xce, 0x32, 0xad,
		0x88, 0xcb, 0x52, 0x9b, 0x7d, 0xcc, 0x04, 0x47, 0xf1, 0x98, 0x6f, 0xb6, 0x47, 0xc5, 0x34, 0xa7,
		0xd7, 0x07, 0xd3, 0x04, 0xd3, 0x04, 0xd3, 0x04, 0xd3, 0x04, 0xd3, 0x04, 0xd3, 0x04, 0xd3, 0x04,
		0xd3, 0x04, 0xd3, 0x4c, 0x07, 0xd3, 0x44, 0x05, 0xc0, 0x76, 0xc9, 0xe5, 0x55, 0x89, 0x4e, 0x2d,
		0x7d, 0xdb, 0xcc, 0x6c, 0x3b, 0x9b, 0xfe, 0x1c, 0xa9, 0x2f, 0xf9, 0x34, 0x73, 0x4d, 0x24, 0xa0,
		0xf8, 0xd8, 0x3f, 0x12, 0x50, 0x48, 0x40, 0x6d, 0xb0, 0xd0, 0xf5, 0x47, 0x04, 0x5e, 0x2f, 0x9d,
		0xf0, 0x86, 0x8c, 0x08, 0x06, 0x20, 0x18, 0x90, 0xcf, 0x60, 0x80, 0xf6, 0x86, 0x8c, 0xf1, 0x7e,
		0x06, 0xab, 0x6b, 0xf7, 0x5c, 0xcf, 0xd5, 0xc0, 0x1e, 0xd6, 0x2e, 0x88, 0xa5, 0x91, 0x68, 0x8e,
		0x95, 0x2b, 0xe3, 0x58, 0x39, 0x1c, 0x2b, 0x97, 0x20, 0x70, 0x62, 0x01, 0x29, 0x22, 0xb5, 0xac,
		0xbb, 0x89, 0xaa, 0x66, 0xf0, 0x5a, 0x0d, 0x62, 0xcf, 0x74, 0x46, 0xb9, 0x12, 0xca, 0x9e, 0xa9,
		0x2c, 0x93, 0x06, 0xd0, 0xc8, 0x81, 0x8d, 0x03, 0xe0, 0xf8, 0x80, 0x8e, 0x0b, 0xf0, 0xd8, 0x81,
		0x8f, 0x1d, 0x00, 0x59, 0x81, 0x90, 0x06, 0x10, 0x89, 0x80, 0x91, 0x1c, 0x20, 0x5f, 0x81, 0xb2,
		0xeb, 0x5a, 0xf1, 0x6e, 0x08, 0x62, 0x33, 0x9e, 0x42, 0xe5, 0x64, 0xc4, 0x0f, 0x99, 0x38, 0x82,
		0x90, 0x1a, 0x34, 0x39, 0xc1, 0x93, 0x1f, 0x44, 0xb9, 0xc1, 0xd4, 0x18, 0xa8, 0x1a, 0x03, 0x57,
		0x23, 0x20, 0x4b, 0x0b, 0xb6, 0xc4, 0xa0, 0x3b, 0x7d, 0x62, 0x64, 0x87, 0x1e, 0xaf, 0x5d, 0x6f,
		0x9e, 0xb0, 0xbb, 0x91, 0xe8, 0x72, 0x2c, 0xb8, 0x09, 0x97, 0x6c, 0x30, 0x8c, 0x75, 0x1d, 0xa7,
		0x6f, 0x3e, 0x7e, 0x1c, 0xef, 0xaf, 0x2c, 0x4e, 0x7d, 0xc0, 0xbb, 0x74, 0x5a, 0x1f, 0xe5, 0xf9,
		0xbc, 0x9a, 0x36, 0x0c, 0x6d, 0x6c, 0x73, 0x5a, 0x36, 0x14, 0x19, 0x96, 0x2e, 0xf0, 0xc6, 0xf0,
		0xc6, 0xf0, 0xc6, 0xd9, 0xf6, 0xc6, 0xd4, 0x52, 0x88, 0x5f, 0x12, 0x99, 0x92, 0x46, 0xcc, 0x12,
		0x89, 0x1d, 0x9c, 0x4d, 0x80, 0xb4, 0x39, 0xb0, 0x36, 0x05, 0xda, 0xc6, 0xc1, 0xdb, 0x38, 0x88,
		0x1b, 0x05, 0x73, 0x1e, 0x50, 0x67, 0x02, 0x77, 0x7e, 0xc9, 0xb5, 0xb4, 0x5e, 0x7b, 0xa1, 0x27,
		0x87, 0x33, 0x67, 0xd9, 0x5d, 0x97, 0x73, 0xd5, 0x4e, 0x88, 0x71, 0x95, 0x71, 0xcc, 0xa6, 0xdf,
		0xef, 0x0d, 0x9f, 0x32, 0x93, 0xed, 0xbc, 0xcb, 0x80, 0x75, 0x16, 0xc6, 0xad, 0xe6, 0x3b, 0xfc,
		0xa4, 0x60, 0x32, 0x30, 0xd3, 0x0a, 0x3c, 0x15, 0x5d, 0xbb, 0xef, 0x8d, 0xa0, 0xac, 0x6b, 0x7b,
		0x12, 0x5c, 0x04, 0x5c, 0x04, 0x5c, 0x04, 0x5c, 0x04, 0x5c, 0x84, 0x71, 0xbd, 0x3e, 0x04, 0x81,
		0x27, 0x6c, 0xdf, 0x04, 0x0d, 0x29, 0x67, 0x85, 0x12, 0xa4, 0x3a, 0xd6, 0x41, 0xd4, 0x32, 0x6a,
		0xed, 0x78, 0xa6, 0x77, 0x59, 0xbc, 0xee, 0x2b, 0x78, 0x7d, 0x59, 0x5c, 0x2c, 0x0f, 0x9c, 0x7f,
		0xe3, 0x59, 0xcb, 0xd6, 0x0c, 0x73, 0x66, 0x44, 0x99, 0x42, 0xd0, 0xd3, 0x71, 0x68, 0x63, 0xb8,
		0xd2, 0xd1, 0x91, 0x68, 0x63, 0x80, 0xe2, 0x4a, 0x20, 0x54, 0x90, 0x40, 0x48, 0x0f, 0xff, 0x43,
		0x02, 0x01, 0x09, 0x84, 0x5f, 0x2b, 0x5b, 0x24, 0x10, 0x20, 0xda, 0x21, 0xda, 0x21, 0xda, 0x21,
		0xda, 0x21, 0xda, 0xf5, 0xaf, 0x57, 0x24, 0x10, 0x52, 0x1c, 0x2d, 0x40, 0x02, 0x41, 0x1f, 0xcd,
		0x42, 0x02, 0x01, 0x5c, 0x04, 0x5c, 0x04, 0x5c, 0x04, 0x5c, 0x04, 0x09, 0x84, 0x14, 0x53, 0x02,
		0x24, 0x10, 0xde, 0x30, 0x5e, 0x2a, 0x13, 0x08, 0x1a, 0x7a, 0x3d, 0x99, 0xb3, 0xa2, 0x74, 0xed,
		0x63, 0xfc, 0x97, 0x78, 0x66, 0x88, 0x4f, 0x15, 0xce, 0x5d, 0xa9, 0x4e, 0x94, 0x22, 0xde, 0x33,
		0x79, 0xe1, 0xfa, 0x4d, 0x4f, 0x0c, 0x7d, 0xa4, 0xa4, 0xe5, 0x7f, 0x85, 0x0b, 0xfb, 0xfb, 0xcc,
		0x48, 0xe5, 0xc3, 0x6a, 0xb5, 0xde, 0xa8, 0x56, 0x4b, 0x8d, 0x83, 0x46, 0xe9, 0xa8, 0x56, 0x2b,
		0xd7, 0xcb, 0x35, 0xc2, 0xc1, 0xaf, 0xa2, 0x8e, 0x88, 0x44, 0xe7, 0xd3, 0x70, 0xe6, 0xfc, 0xbe,
		0xe7, 0xa5, 0xca, 0xe0, 0x98, 0x00, 0x30, 0x95, 0xc0, 0x57, 0x20, 0x4d, 0x3d, 0x6e, 0xdb, 0x5f,
		0xed, 0x6c, 0x72, 0xfb, 0x27, 0xd3, 0x5f, 0xf7, 0xfa, 0x5e, 0xfb, 0x64, 0xfc, 0x0b, 0x7e, 0x1b,
		0xff, 0x80, 0x77, 0xe9, 0x40, 0xd4, 0x64, 0x1f, 0xbe, 0x41, 0xbc, 0x44, 0xd2, 0xb1, 0x34, 0x0a,
		0x09, 0x3d, 0x4d, 0x54, 0xe3, 0x64, 0x53, 0xed, 0x28, 0xa4, 0xdd, 0x41, 0x88, 0xd3, 0x9b, 0x38,
		0xe3, 0x30, 0x38, 0xbd, 0x29, 0x91, 0x71, 0x92, 0x9c, 0x9e, 0xde, 0x44, 0xd4, 0x52, 0x6d, 0xed,
		0xb2, 0x22, 0x69, 0xb1, 0xb6, 0x0e, 0xd0, 0x4a, 0x38, 0xbd, 0xc9, 0x20, 0xd0, 0x71, 0x01, 0x1e,
		0x3b, 0xf0, 0xb1, 0x03, 0x20, 0x2b, 0x10, 0xa6, 0x33, 0xea, 0x41, 0x1e, 0x00, 0xa6, 0x6b, 0xdc,
		0xb1, 0x0e, 0xbd, 0xea, 0x84, 0x43, 0xd0, 0x34, 0xf6, 0x58, 0xfc, 0xc3, 0x10, 0x0d, 0xa5, 0x6c,
		0xfc, 0xc1, 0xec, 0x56, 0x96, 0x86, 0x23, 0x6e, 0x0c, 0xb2, 0x34, 0x1e, 0x43, 0x47, 0x09, 0x26,
		0x38, 0x58, 0x8c, 0xec, 0x65, 0xde, 0x44, 0x08, 0x1b, 0x8d, 0x24, 0xc2, 0x4c, 0x52, 0x9a, 0x39,
		0x68, 0xa5, 0x25, 0x7a, 0xf6, 0x81, 0x4a, 0x59, 0x68, 0x6f, 0xa1, 0xf7, 0x0b, 0x65, 0xa1, 0xb9,
		0xa5, 0x1e, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05,
		0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x85, 0x61, 0x65, 0xf1, 0x9a, 0x82, 0x76, 0x3b, 0xf4,
		0xba, 0x62, 0x6e, 0x34, 0xa8, 0x0a, 0xa8, 0x0a, 0xa8, 0x0a, 0xa8, 0x8a, 0x14, 0xa9, 0x0a, 0x06,
		0xfc, 0x9a, 0xc5, 0xb0, 0xf2, 0x21, 0x2a, 0xc6, 0x74, 0xac, 0x9c, 0x3c, 0x56, 0x8c, 0x51, 0x1c,
		0x33, 0x93, 0xcc, 0x3a, 0x31, 0x52, 0x0a, 0xc3, 0xb1, 0xf4, 0x89, 0x28, 0x0b, 0x6a, 0xc6, 0x8c,
		0x50, 0x12, 0xd4, 0x8c, 0x65, 0xd0, 0x85, 0x90, 0x51, 0x0c, 0x86, 0x1e, 0x2a, 0x94, 0x3d, 0x53,
		0x96, 0x7b, 0xa4, 0xcc, 0xe1, 0x64, 0xae, 0xbc, 0xcf, 0x70, 0xf6, 0x18, 0xdc, 0x8f, 0x7e, 0x23,
		0x41, 0xcd, 0xf2, 0x6a, 0xff, 0xe3, 0x76, 0xe1, 0x7e, 0x12, 0xe8, 0x7e, 0xdc, 0x2e, 0x2a, 0x96,
		0x35, 0x5d, 0x98, 0xb8, 0x69, 0x13, 0x4f, 0xb3, 0x26, 0xf4, 0x97, 0x4d, 0x00, 0xac, 0x71, 0xc1,
		0x1b, 0x3b, 0xcc, 0xb1, 0xc3, 0x1d, 0x27, 0xec, 0xd1, 0x45, 0x84, 0xf6, 0xd2, 0xdc, 0x5d, 0x76,
		0x4a, 0xb6, 0xf8, 0x0e, 0xa3, 0x7d, 0x1d, 0x12, 0xfd, 0x65, 0x93, 0x06, 0x9e, 0xec, 0x20, 0xca,
		0x0d, 0xa6, 0xc6, 0x40, 0xd5, 0x18, 0xb8, 0x9a, 0x00, 0x59, 0x5a, 0xb0, 0x25, 0x06, 0x5d, 0xfa,
		0x48, 0x88, 0x81, 0xc8, 0x08, 0x67, 0xa4, 0x64, 0x6d, 0xe4, 0xa4, 0x38, 0x32, 0xbb, 0xe3, 0x99,
		0x20, 0xfe, 0xc2, 0x1b, 0xf1, 0x7f, 0xa3, 0xf1, 0xec, 0xea, 0xe7, 0x28, 0xfb, 0x0f, 0x06, 0xfc,
		0xf5, 0xdc, 0xa8, 0x70, 0xd9, 0x70, 0xd9, 0x70, 0xd9, 0x70, 0xd9, 0x70, 0xd9, 0x70, 0xd9, 0xa3,
		0x37, 0xee, 0x5f, 0x5d, 0xf6, 0xff, 0x73, 0xfa, 0x51, 0x24, 0x7c, 0xf5, 0x7e, 0xbf, 0xf8, 0xf1,
		0xe3, 0x6b, 0x76, 0xa4, 0x15, 0x7f, 0x65, 0xd6, 0x8f, 0xc8, 0x15, 0xef, 0x4d, 0xaf, 0xdc, 0x11,
		0xdf, 0x71, 0xe6, 0x1b, 0x47, 0x74, 0xa1, 0xf9, 0x7d, 0x54, 0x2e, 0x4b, 0x57, 0x73, 0xcf, 0x17,
		0x18, 0x0b, 0x1c, 0x4b, 0x7c, 0x57, 0xc7, 0x4a, 0x78, 0xa2, 0x27, 0x54, 0xf4, 0x6c, 0x05, 0xbe,
		0xe5, 0x3c, 0x8d, 0x36, 0x15, 0xb0, 0x06, 0xcb, 0x46, 0x07, 0x2a, 0x33, 0x46, 0xcb, 0xd2, 0x16,
		0x28, 0x6b, 0xe1, 0x34, 0x39, 0xfd, 0x05, 0x50, 0x73, 0x19, 0x53, 0xd2, 0xae, 0x5b, 0xe9, 0xa8,
		0xf4, 0xa6, 0xed, 0xae, 0xc5, 0xd2, 0x55, 0x8b, 0x2d, 0xd3, 0x53, 0x41, 0xa6, 0x27, 0x31, 0x4a,
		0x07, 0x99, 0x9e, 0xfc, 0x72, 0x31, 0x64, 0x7a, 0x10, 0x36, 0x42, 0xd8, 0x08, 0x61, 0x23, 0x84,
		0x8d, 0x10, 0x36, 0xca, 0x41, 0xd8, 0x08, 0x99, 0x9e, 0x9f, 0x2b, 0x18, 0x64, 0x7a, 0xe0, 0xb2,
		0xe1, 0xb2, 0xe1, 0xb2, 0xe1, 0xb2, 0xe1, 0xb2, 0x13, 0xe2, 0xb2, 0x91, 0xe9, 0x49, 0x6f, 0x74,
		0x01, 0xe1, 0xf1, 0x69, 0x78, 0x9c, 0xb0, 0xa7, 0x14, 0x76, 0x9b, 0xe7, 0xcd, 0x9a, 0x0a, 0x24,
		0xd9, 0x0b, 0x9a, 0x06, 0x3d, 0xd3, 0x57, 0x37, 0xa2, 0x9b, 0x87, 0xed, 0x8a, 0x34, 0x59, 0x20,
		0xd2, 0xec, 0x0f, 0xf9, 0xf6, 0xc4, 0x0a, 0xb6, 0xc7, 0xf3, 0xc9, 0x1a, 0x6c, 0x8f, 0xcf, 0xa0,
		0xcf, 0x23, 0xdc, 0xa0, 0xd8, 0x1f, 0x02, 0xb4, 0xe4, 0xd8, 0xa2, 0x18, 0x8f, 0x84, 0xd4, 0xb5,
		0xa9, 0x50, 0x0e, 0x8e, 0x25, 0x4b, 0x5f, 0xac, 0x06, 0xc7, 0x92, 0x41, 0x5e, 0xae, 0x12, 0x04,
		0xe3, 0xc3, 0x40, 0x88, 0x41, 0x95, 0x54, 0x19, 0x7c, 0x9e, 0xdc, 0x7b, 0xee, 0xfb, 0x0e, 0xa0,
		0xa3, 0xd9, 0x76, 0xae, 0x18, 0x27, 0x84, 0xc2, 0x15, 0xc3, 0x15, 0x27, 0xc1, 0x15, 0xa3, 0xef,
		0xc0, 0x9b, 0x86, 0x40, 0xdf, 0x81, 0xe4, 0xb9, 0x95, 0xa5, 0xe1, 0xd0, 0x77, 0x40, 0x8f, 0x89,
		0xa0, 0xef, 0x40, 0xea, 0xcd, 0x04, 0x7d, 0x07, 0x52, 0xaa, 0x2c, 0xd0, 0xd1, 0x0c, 0xca, 0x02,
		0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02,
		0xca, 0x02, 0xca, 0x62, 0x17, 0x33, 0x41, 0x47, 0x33, 0xa8, 0x0a, 0xa8, 0x0a, 0xa8, 0x0a, 0xa8,
		0x8a, 0x84, 0xe0, 0xd7, 0x1e, 0x3a, 0x9a, 0xa1, 0xc6, 0x5c, 0x57, 0x49, 0x49, 0x62, 0x6b, 0xb4,
		0xdf, 0x25, 0xc8, 0x4e, 0x86, 0xbe, 0x83, 0x68, 0x71, 0x17, 0xce, 0x5d, 0xa9, 0x4e, 0x94, 0xd2,
		0x5b, 0xef, 0x39, 0x94, 0xd3, 0x4d, 0x4f, 0x0c, 0x9d, 0x81, 0xd4, 0x4b, 0x44, 0x86, 0x2a, 0x6c,
		0xe6, 0xca, 0xe5, 0xc3, 0x6a, 0xb5, 0xde, 0xa8, 0x56, 0x4b, 0x8d, 0x83, 0x46, 0xe9, 0xa8, 0x56,
		0x2b, 0xd7, 0xcb, 0x1a, 0xe5, 0x4b, 0xe1, 0x2a, 0xea, 0x88, 0x48, 0x74, 0x3e, 0x0d, 0x9f, 0xbe,
		0xdf, 0xf7, 0xbc, 0x44, 0x19, 0x05, 0x11, 0x68, 0x24, 0x12, 0x2c, 0x0a, 0x5a, 0xb7, 0x4c, 0x90,
		0x14, 0x98, 0xe9, 0x41, 0xb2, 0xdd, 0x71, 0x67, 0xb7, 0x2b, 0xec, 0x68, 0x9c, 0xba, 0x8d, 0x32,
		0x41, 0xc6, 0xb8, 0xdb, 0xfc, 0x6e, 0x3f, 0x2b, 0x3b, 0xcc, 0x88, 0xa6, 0xdd, 0x41, 0x5a, 0x77,
		0x03, 0x69, 0x2a, 0x9c, 0xd7, 0x56, 0x20, 0xaf, 0x53, 0xcd, 0xea, 0x57, 0xad, 0xba, 0xd5, 0x29,
		0x99, 0x0a, 0x25, 0x53, 0x9b, 0x24, 0xaa, 0xd2, 0x2c, 0x46, 0xea, 0xda, 0x5d, 0x43, 0x55, 0xce,
		0x4b, 0x5b, 0xbe, 0xab, 0x39, 0xfc, 0xa5, 0x3d, 0xdc, 0x45, 0x11, 0xde, 0xa2, 0x0b, 0x67, 0x51,
		0x85, 0xaf, 0xc8, 0xc3, 0x55, 0xe4, 0xe1, 0x29, 0xd2, 0x70, 0x54, 0xb2, 0xe4, 0xa1, 0xf6, 0xf0,
		0x12, 0x5d, 0x92, 0x9a, 0x20, 0x29, 0x4d, 0x94, 0x84, 0x26, 0x08, 0xc3, 0x50, 0x26, 0x99, 0xa9,
		0xb3, 0x0a, 0xc4, 0x49, 0x64, 0x8e, 0x6c, 0x20, 0x45, 0x76, 0x8a, 0x32, 0x29, 0xcc, 0x35, 0xa5,
		0x84, 0x49, 0x5f, 0x96, 0x69, 0x4d, 0x68, 0x08, 0xb1, 0x95, 0x94, 0x80, 0xc0, 0x07, 0x5d, 0x4c,
		0x53, 0x7b, 0x79, 0x27, 0x6d, 0x39, 0x27, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98,
		0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x35, 0xd3, 0x44, 0xea, 0x49, 0x63, 0xea,
		0x49, 0x43, 0x7d, 0xc4, 0x0e, 0x59, 0xa7, 0x77, 0x8c, 0x53, 0xa8, 0x6b, 0xea, 0x4c, 0x4f, 0x59,
		0x61, 0xa7, 0x54, 0x9d, 0xc6, 0xac, 0xf4, 0x76, 0x56, 0xf3, 0xf6, 0x39, 0xdf, 0x62, 0xbe, 0x0b,
		0xbe, 0x70, 0x1f, 0x9f, 0x1e, 0x82, 0x1d, 0xce, 0x00, 0x9b, 0x72, 0xc6, 0xd7, 0x4b, 0x6d, 0x69,
		0x77, 0xbb, 0xe5, 0x22, 0x77, 0x16, 0x84, 0x3a, 0x04, 0xa0, 0x3e, 0xc1, 0xa7, 0x4b, 0xe0, 0x69,
		0x17, 0x74, 0xda, 0x05, 0x9c, 0x56, 0xc1, 0xc6, 0x8b, 0x94, 0xbb, 0xe6, 0x0e, 0xa7, 0x6b, 0x46,
		0x5f, 0x55, 0xc0, 0xf4, 0x8a, 0x09, 0x2b, 0x0c, 0x28, 0xa1, 0x30, 0x20, 0x01, 0x51, 0x18, 0x14,
		0x06, 0xf0, 0x2d, 0xee, 0xe9, 0x85, 0xec, 0xbe, 0x7a, 0x12, 0xbe, 0x72, 0x1d, 0xbd, 0xe5, 0x81,
		0x53, 0x33, 0x5e, 0xb8, 0xbe, 0xde, 0x70, 0x6d, 0x19, 0xe1, 0x5a, 0x1d, 0x57, 0x46, 0xb8, 0x96,
		0x13, 0x38, 0xf4, 0x8a, 0x7a, 0x5d, 0xe1, 0x5a, 0xdd, 0xe7, 0xf8, 0x16, 0x9c, 0xc9, 0x9a, 0x22,
		0x3a, 0x6f, 0x3c, 0xbe, 0x7e, 0xca, 0x0e, 0x1c, 0x2f, 0xe1, 0xc0, 0x71, 0x7a, 0xe0, 0x61, 0x03,
		0x20, 0x36, 0x20, 0x62, 0x01, 0x24, 0xa2, 0xd8, 0x65, 0x5a, 0x0e, 0x1c, 0x9f, 0x67, 0x2a, 0xd6,
		0xd7, 0xd1, 0x46, 0x1a, 0xe2, 0x3d, 0xc4, 0x2b, 0xc6, 0xc4, 0x4e, 0x62, 0x6e, 0xa0, 0xe3, 0x03,
		0x3c, 0x2e, 0xe0, 0x63, 0x07, 0x40, 0x76, 0x20, 0x64, 0x05, 0x44, 0x1a, 0x60, 0x24, 0x02, 0xc8,
		0xe9, 0x93, 0xe1, 0xdb, 0x49, 0x1c, 0x05, 0x7d, 0x35, 0x0a, 0x7b, 0xdb, 0x52, 0x8e, 0xcc, 0x0d,
		0xbb, 0x89, 0x29, 0x67, 0xb7, 0x20, 0x7c, 0xfb, 0xc1, 0x63, 0x38, 0x93, 0x3b, 0x1e, 0x87, 0xaa,
		0xc3, 0xbb, 0xe8, 0xda, 0x7d, 0x6f, 0xb4, 0x70, 0xbb, 0xb6, 0x27, 0x71, 0xe6, 0x37, 0x3c, 0x1f,
		0x3c, 0x1f, 0x3c, 0x5f, 0xaa, 0x3c, 0xdf, 0x43, 0x10, 0x78, 0xc2, 0xf6, 0x39, 0x1c, 0x5e, 0x19,
		0xc7, 0x67, 0xe8, 0x58, 0x34, 0xd9, 0x39, 0x3e, 0x63, 0x9a, 0xd2, 0x9e, 0xbe, 0x2a, 0xce, 0xcb,
		0xc9, 0x62, 0x1c, 0x22, 0x43, 0x6f, 0xc3, 0x5d, 0x97, 0x39, 0x7a, 0x1b, 0x22, 0xd4, 0x98, 0x10,
		0xbe, 0x81, 0x50, 0x23, 0x9f, 0xb3, 0x40, 0xa8, 0x11, 0x82, 0x0b, 0x82, 0x0b, 0x82, 0x0b, 0x82,
		0x2b, 0x31, 0x82, 0x0b, 0xa1, 0x46, 0xd6, 0xd9, 0x45, 0xa8, 0x11, 0x9e, 0x0f, 0x9e, 0x0f, 0x9e,
		0x0f, 0x9e, 0xcf, 0xb8, 0xe7, 0x43, 0xa8, 0x31, 0x65, 0xea, 0x31, 0x57, 0xa1, 0x46, 0x9c, 0xd0,
		0x6b, 0xda, 0x2e, 0x12, 0x65, 0x0f, 0xc9, 0x38, 0x84, 0xf5, 0x32, 0xbe, 0xb9, 0xf6, 0xc9, 0xfc,
		0xcd, 0x65, 0xe8, 0xb4, 0x15, 0xcd, 0x55, 0xb6, 0x34, 0xd5, 0xb5, 0x28, 0xd7, 0x47, 0xb9, 0x3e,
		0xca, 0xf5, 0xb5, 0x3a, 0x11, 0xed, 0xe5, 0xfa, 0x9e, 0xfd, 0x20, 0x3c, 0x4b, 0x86, 0x44, 0xdd,
		0x73, 0xa6, 0xcb, 0x61, 0x61, 0x1c, 0x9a, 0x9c, 0x5a, 0x09, 0xe5, 0xfb, 0xc8, 0xa9, 0x25, 0x50,
		0x50, 0x23, 0xa7, 0x46, 0x27, 0x98, 0xe9, 0xbb, 0x65, 0x12, 0x76, 0xc9, 0x24, 0xee, 0x8e, 0x49,
		0x18, 0x9e, 0xe0, 0xe8, 0x86, 0xc9, 0xd4, 0xe2, 0x90, 0xab, 0xfb, 0x25, 0x67, 0x3b, 0x43, 0xc2,
		0x6e, 0x97, 0x2c, 0x5d, 0x2e, 0xb9, 0xa7, 0x9e, 0xa1, 0xab, 0x25, 0xeb, 0xf4, 0xa7, 0x24, 0x92,
		0xd7, 0xca, 0x41, 0x8d, 0x9a, 0x27, 0x23, 0x5a, 0x66, 0x3d, 0xbe, 0x3e, 0x18, 0x35, 0x18, 0x35,
		0x18, 0x35, 0x18, 0xb5, 0x46, 0x7b, 0x77, 0x43, 0xcb, 0xee, 0x74, 0x22, 0x21, 0x25, 0x21, 0xab,
		0x2e, 0x1f, 0x11, 0x5c, 0x3b, 0x7e, 0x36, 0xa9, 0x63, 0xd5, 0xaf, 0x4f, 0xfe, 0x5b, 0x95, 0xf0,
		0xd9, 0x2f, 0xcd, 0xc1, 0x21, 0xe1, 0x18, 0xd7, 0xb6, 0x52, 0x22, 0xf2, 0xc9, 0xa6, 0x63, 0x3a,
		0xd0, 0x7f, 0xdf, 0xbf, 0xbf, 0x2f, 0x59, 0x47, 0xad, 0x97, 0xfb, 0xb2, 0x75, 0xd4, 0x1a, 0xbf,
		0x2c, 0x8f, 0xfe, 0x1a, 0xbf, 0xae, 0xdc, 0x97, 0xac, 0xea, 0xe4, 0x75, 0xed, 0xbe, 0x64, 0xd5,
		0x5a, 0xfb, 0x7f, 0xfd, 0xf5, 0x71, 0xff, 0xc7, 0xc1, 0xe0, 0xed, 0x5f, 0xfc, 0x07, 0x5d, 0x26,
		0xbc, 0x45, 0x39, 0x19, 0x57, 0xb7, 0x67, 0x7f, 0x60, 0x46, 0x8c, 0xd2, 0x54, 0x62, 0x8d, 0xc6,
		0x03, 0x4f, 0x75, 0xc0, 0xd3, 0x76, 0x8b, 0xc1, 0xb6, 0xba, 0x27, 0xd6, 0x6f, 0xad, 0x1f, 0xe5,
		0x0f, 0xd5, 0xc1, 0xf1, 0xfe, 0x8f, 0xc6, 0x60, 0xf1, 0xcd, 0x97, 0x55, 0x1f, 0x2b, 0x7f, 0x68,
		0x0c, 0x8e, 0xd7, 0xfc, 0x4b, 0x7d, 0x70, 0xbc, 0xe1, 0x35, 0x6a, 0x83, 0xf7, 0x4b, 0x1f, 0x1d,
		0xbe, 0x5f, 0x59, 0xf7, 0x85, 0xea, 0x9a, 0x2f, 0x1c, 0xac, 0xfb, 0xc2, 0xc1, 0x9a, 0x2f, 0xac,
		0xbd, 0xa5, 0xca, 0x9a, 0x2f, 0xd4, 0x06, 0x2f, 0x4b, 0x9f, 0x7f, 0xbf, 0xfa, 0xa3, 0xf5, 0xc1,
		0xfe, 0xcb, 0xba, 0x7f, 0x6b, 0x0c, 0x5e, 0x8e, 0xf7, 0x01, 0xd6, 0xb0, 0xcf, 0xdc, 0xda, 0x27,
		0x22, 0x41, 0x09, 0xb8, 0x12, 0x6a, 0x88, 0x7e, 0x56, 0x43, 0xa4, 0x73, 0xbf, 0x6a, 0x92, 0x9a,
		0x21, 0xd9, 0x9d, 0xff, 0xcf, 0x76, 0x84, 0xef, 0xb8, 0x42, 0x52, 0xf5, 0x43, 0x9a, 0x1d, 0x22,
		0xe1, 0x45, 0x3b, 0x15, 0x14, 0xed, 0xa4, 0x28, 0xa2, 0x87, 0xa2, 0x9d, 0x04, 0x17, 0xed, 0xcc,
		0xaf, 0xfd, 0x67, 0xba, 0xdc, 0xc2, 0xe2, 0x40, 0xd8, 0x0a, 0x8f, 0x24, 0x83, 0x31, 0x48, 0x62,
		0x83, 0x26, 0x16, 0x88, 0xa2, 0xa1, 0xd2, 0xa9, 0xd9, 0x0a, 0x4f, 0xd4, 0x98, 0xfc, 0x17, 0x48,
		0xa6, 0xb9, 0x51, 0x39, 0x13, 0xa0, 0x2d, 0x03, 0x1b, 0x36, 0x02, 0x26, 0x00, 0xf0, 0xd8, 0x81,
		0x8f, 0x1d, 0x00, 0x59, 0x81, 0x90, 0x2e, 0xb6, 0xb0, 0x47, 0xb8, 0x11, 0x90, 0x0a, 0x20, 0x5f,
		0xa5, 0x39, 0xc9, 0x11, 0x47, 0x6b, 0x57, 0x25, 0xc5, 0x91, 0x47, 0xcc, 0x30, 0x49, 0xce, 0x03,
		0x4d, 0xc0, 0x26, 0x3f, 0x7c, 0x72, 0xc3, 0xa8, 0x31, 0x38, 0x35, 0x06, 0xab, 0x46, 0xe0, 0x95,
		0x16, 0x66, 0x89, 0xe1, 0x96, 0x0d, 0x76, 0xa7, 0x03, 0xc5, 0xda, 0x57, 0xf1, 0x99, 0xff, 0xf4,
		0xe0, 0xa6, 0xc9, 0xc8, 0x4c, 0x46, 0xc8, 0x53, 0x71, 0xcb, 0xc6, 0x65, 0x4d, 0x82, 0xb4, 0x39,
		0xb0, 0x36, 0x05, 0xda, 0xc6, 0xc1, 0xdb, 0x38, 0x88, 0x1b, 0x05, 0x73, 0x1e, 0x50, 0x67, 0x02,
		0xf7, 0xe9, 0x93, 0x24, 0x3f, 0x64, 0x63, 0xed, 0x7a, 0x25, 0xdb, 0x4b, 0xf4, 0x2b, 0xf4, 0xad,
		0x33, 0x0e, 0x49, 0xbb, 0xf7, 0x68, 0xdd, 0x1f, 0x5e, 0x3c, 0xda, 0xe3, 0xda, 0xab, 0x94, 0x10,
		0xb7, 0xba, 0x34, 0x3c, 0xd3, 0xde, 0xa6, 0xb5, 0xe3, 0x33, 0x6e, 0x7a, 0x31, 0x0c, 0x57, 0xf3,
		0x26, 0x67, 0x7f, 0xcf, 0xbd, 0xc9, 0x31, 0xec, 0xa9, 0x4a, 0xb4, 0xd9, 0xbd, 0xcb, 0xe6, 0x68,
		0xad, 0x77, 0xd9, 0xf8, 0x3d, 0x0c, 0xb0, 0x10, 0x67, 0x1d, 0xc4, 0xf7, 0xd0, 0x8d, 0xe8, 0x4e,
		0x84, 0xfa, 0x29, 0x93, 0x59, 0xba, 0x03, 0xa8, 0x49, 0xa8, 0x49, 0xa8, 0x49, 0xa8, 0x49, 0xa8,
		0x49, 0xb6, 0xf5, 0xaa, 0xdc, 0x9e, 0x50, 0xae, 0xf3, 0x55, 0xd6, 0xab, 0x06, 0x24, 0xe5, 0x21,
		0xe3, 0x90, 0x5f, 0xfc, 0x31, 0xdb, 0x2a, 0xf8, 0xb6, 0x1f, 0x48, 0xe1, 0x04, 0x7e, 0x47, 0x16,
		0x20, 0x69, 0x21, 0x69, 0x21, 0x69, 0x21, 0x69, 0x33, 0x60, 0x72, 0xe5, 0xc3, 0x6a, 0xb5, 0xde,
		0xa8, 0x56, 0x4b, 0x8d, 0x83, 0x46, 0xe9, 0xa8, 0x56, 0x2b, 0xd7, 0xcb, 0x50, 0xb8, 0x50, 0xb8,
		0x39, 0x56, 0xb8, 0xbe, 0x78, 0x0c, 0x94, 0x6b, 0x2b, 0xd1, 0xe1, 0xd7, 0xb6, 0x33, 0x63, 0x43,
		0xd5, 0x42, 0xd5, 0x42, 0xd5, 0x42, 0xd5, 0x42, 0xd5, 0xb2, 0xad, 0x57, 0xe4, 0x48, 0x21, 0x28,
		0x21, 0x28, 0x21, 0x28, 0x21, 0x28, 0x77, 0x30, 0x39, 0xe4, 0x48, 0xa1, 0x20, 0x73, 0xaf, 0x20,
		0xbf, 0x2b, 0x6b, 0x94, 0xa6, 0x34, 0xa1, 0x20, 0xa7, 0x63, 0x43, 0x41, 0x42, 0x41, 0x42, 0x41,
		0x42, 0x41, 0x42, 0x41, 0xb2, 0xad, 0x57, 0xe4, 0x45, 0x21, 0x63, 0x21, 0x63, 0x21, 0x63, 0x21,
		0x63, 0xd3, 0x6e, 0x72, 0xc8, 0x8b, 0x42, 0xd5, 0xa6, 0x48, 0xd5, 0xa6, 0x7a, 0xeb, 0x2b, 0x71,
		0x7f, 0xd9, 0xa5, 0xf1, 0xcc, 0x9e, 0x0d, 0xb8, 0x74, 0xcc, 0xdd, 0xc2, 0x3b, 0xcf, 0xc5, 0xf9,
		0x93, 0x5d, 0x28, 0x3a, 0xd2, 0xf2, 0xd9, 0x4f, 0xba, 0xce, 0xbe, 0x60, 0xb2, 0xc4, 0x94, 0x59,
		0x20, 0xe5, 0x89, 0x36, 0x1a, 0x7a, 0xe2, 0xfe, 0x3e, 0xbc, 0xd9, 0x93, 0xc9, 0xbd, 0x8f, 0xff,
		0xf3, 0xf7, 0xc9, 0xad, 0xa7, 0xa5, 0x01, 0x38, 0xc1, 0xe9, 0x68, 0xae, 0xaf, 0x44, 0xd4, 0xb5,
		0x1d, 0x61, 0x45, 0xa2, 0x4b, 0x7f, 0x1e, 0xd5, 0xfc, 0x70, 0x38, 0x8e, 0x6a, 0xe5, 0x00, 0xcc,
		0xc7, 0x51, 0xb9, 0x5d, 0x9c, 0x46, 0xb5, 0xc5, 0x80, 0xa6, 0x4f, 0xa3, 0x72, 0xbb, 0x38, 0x8c,
		0x6a, 0xfc, 0x60, 0x70, 0x18, 0x55, 0xe2, 0x40, 0x72, 0x19, 0x2c, 0x33, 0x7a, 0x18, 0x15, 0x29,
		0x78, 0x72, 0x83, 0xa8, 0x31, 0x30, 0x35, 0x06, 0xaa, 0x26, 0xc0, 0x35, 0x1b, 0x7a, 0x9c, 0xed,
		0x28, 0xaa, 0x29, 0x65, 0xe4, 0xcf, 0x93, 0xbf, 0x0e, 0x8d, 0x34, 0x79, 0xda, 0x40, 0xda, 0x18,
		0x58, 0x9b, 0x02, 0x6d, 0xe3, 0xe0, 0x6d, 0x1c, 0xc4, 0x4d, 0x82, 0x39, 0x0f, 0xa8, 0x33, 0x81,
		0xfb, 0xf4, 0x41, 0x9a, 0x4b, 0x92, 0x7b, 0xc2, 0xee, 0xd2, 0x85, 0x08, 0x7e, 0xca, 0x88, 0x1b,
		0x8c, 0x63, 0x5e, 0x4f, 0xa3, 0x7b, 0x43, 0x33, 0x3d, 0x9e, 0x3a, 0x1c, 0xb9, 0xf8, 0x46, 0xfc,
		0xdf, 0xa3, 0x18, 0x18, 0xaa, 0xec, 0x36, 0x57, 0x6e, 0xfd, 0x07, 0x83, 0xfc, 0x61, 0x6e, 0x74,
		0x50, 0x08, 0x50, 0x08, 0x50, 0x08, 0x50, 0x08, 0x50, 0x08, 0x50, 0x08, 0x23, 0x14, 0xe2, 0xfe,
		0x95, 0x42, 0xfc, 0x3f, 0xa7, 0x1f, 0x45, 0xc2, 0x57, 0xef, 0xf7, 0x8b, 0x1f, 0x3f, 0x16, 0xa7,
		0x9f, 0x68, 0xc5, 0x5f, 0x99, 0xf5, 0x5b, 0x72, 0xc5, 0x7b, 0xd3, 0x2b, 0x77, 0xc4, 0xf7, 0x02,
		0xaa, 0x23, 0x12, 0x10, 0x8d, 0x41, 0x75, 0xc4, 0x7c, 0x6e, 0x7a, 0x2e, 0xcf, 0x88, 0xe2, 0x08,
		0x36, 0x83, 0x44, 0x71, 0xc4, 0x2a, 0x03, 0x4c, 0x57, 0x6d, 0xc4, 0xd9, 0xe4, 0xd6, 0x6f, 0x44,
		0x37, 0xcf, 0xa5, 0x11, 0x5e, 0xe0, 0xd8, 0xde, 0xb4, 0xdf, 0x3b, 0x79, 0x69, 0xc4, 0xfc, 0x70,
		0xb4, 0xa5, 0x11, 0x25, 0xea, 0xd2, 0x88, 0x0a, 0x3a, 0x75, 0x25, 0x47, 0xde, 0xa1, 0x53, 0x57,
		0x8e, 0x1d, 0x32, 0xb9, 0xfe, 0x62, 0xd4, 0x5b, 0x1c, 0xfa, 0x6a, 0xaa, 0xa7, 0x3e, 0x7e, 0x1c,
		0xf3, 0xc6, 0xe2, 0x3c, 0x30, 0xe7, 0xd8, 0x21, 0x46, 0xa2, 0x17, 0x28, 0xc1, 0xe7, 0x11, 0x17,
		0xc6, 0x83, 0x4b, 0x84, 0x4b, 0x84, 0x4b, 0x84, 0x4b, 0x84, 0x4b, 0x34, 0xee, 0x12, 0x17, 0x90,
		0x39, 0xc7, 0x3e, 0x91, 0xb6, 0x34, 0x94, 0xa5, 0x24, 0x14, 0xf5, 0xf2, 0xf0, 0x80, 0xf0, 0x80,
		0xb9, 0xf2, 0x80, 0xe4, 0x15, 0xf3, 0xd3, 0x40, 0xa8, 0xa5, 0x38, 0xf2, 0x7f, 0x8b, 0xdd, 0x43,
		0x27, 0xe3, 0xf2, 0xd4, 0xd0, 0x97, 0xb8, 0x6a, 0xe8, 0x4b, 0x68, 0xe8, 0x9c, 0x7c, 0x60, 0x35,
		0x06, 0xb0, 0xc6, 0x80, 0xd6, 0x08, 0xe0, 0xd2, 0x02, 0x2f, 0x31, 0x00, 0xf3, 0x49, 0x91, 0xa5,
		0xf5, 0xd6, 0x0b, 0x3d, 0x39, 0x9c, 0x19, 0x8b, 0x15, 0x2a, 0xe7, 0x78, 0x66, 0x95, 0x61, 0xac,
		0xa6, 0xdf, 0xef, 0x0d, 0x1f, 0xec, 0x20, 0xad, 0x59, 0x5f, 0x42, 0x86, 0x39, 0xce, 0x55, 0x76,
		0xa2, 0x20, 0x0c, 0x19, 0xce, 0xaf, 0x5f, 0xe8, 0xc9, 0x36, 0x19, 0x16, 0xae, 0x19, 0xae, 0x19,
		0xae, 0x19, 0xae, 0x19, 0xae, 0x79, 0xba, 0xde, 0x9c, 0xa0, 0xef, 0x2b, 0x11, 0xb1, 0x1c, 0x0b,
		0xc8, 0x78, 0x1c, 0x20, 0xf3, 0x31, 0x7c, 0x8c, 0x95, 0xa6, 0x26, 0x8e, 0xdd, 0x33, 0x74, 0xf6,
		0x99, 0xa9, 0x63, 0xf6, 0x4c, 0x1e, 0x6c, 0xc6, 0x78, 0xac, 0x9e, 0x91, 0xe3, 0xf4, 0x4c, 0x9b,
		0x92, 0xf9, 0xe3, 0xf3, 0x8c, 0x5a, 0x57, 0x46, 0x0a, 0xa7, 0x5b, 0x50, 0x58, 0x6b, 0x14, 0x56,
		0x24, 0x1c, 0xe1, 0x7e, 0xe3, 0x97, 0x58, 0xd3, 0x71, 0xa1, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0,
		0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0, 0xb1, 0xa0,
		0xb1, 0x32, 0xa1, 0xb1, 0x3c, 0x5b, 0x2a, 0xcb, 0xf1, 0x84, 0x1d, 0xf1, 0xe9, 0xab, 0x99, 0x31,
		0xa1, 0xad, 0xa0, 0xad, 0xa0, 0xad, 0xa0, 0xad, 0xa0, 0xad, 0x0c, 0x35, 0xb6, 0xe2, 0x54, 0x57,
		0x86, 0x1a, 0x59, 0x41, 0xd5, 0x41, 0xd5, 0x41, 0xd5, 0x41, 0xd5, 0x41, 0xd5, 0x41, 0xd5, 0xe5,
		0x45, 0xd5, 0xb1, 0x1c, 0xba, 0xb1, 0x2c, 0xec, 0x18, 0x0e, 0xdf, 0x80, 0xb6, 0x83, 0xb6, 0x83,
		0xb6, 0x83, 0xb6, 0x4b, 0xa5, 0xb6, 0x73, 0x43, 0x26, 0x74, 0x9c, 0x45, 0xc8, 0xf2, 0x11, 0xc3,
		0x58, 0xf1, 0xb3, 0xcc, 0x9c, 0xc4, 0x7a, 0x9d, 0xb9, 0x6f, 0x55, 0xc6, 0xb9, 0x5b, 0x9a, 0xc3,
		0x43, 0xde, 0xb3, 0x30, 0x95, 0x88, 0x7c, 0xf6, 0x96, 0xcf, 0x85, 0xff, 0xbe, 0x7f, 0x7f, 0x5f,
		0xb2, 0x8e, 0x5a, 0x2f, 0xf7, 0x65, 0xeb, 0xa8, 0x35, 0x7e, 0x59, 0x1e, 0xfd, 0x35, 0x7e, 0x5d,
		0xb9, 0x2f, 0x59, 0xd5, 0xc9, 0xeb, 0xda, 0x7d, 0xc9, 0xaa, 0xb5, 0xf6, 0xff, 0xfa, 0xeb, 0xe3,
		0xfe, 0x8f, 0x83, 0xc1, 0xdb, 0xbf, 0xf8, 0x0f, 0xbe, 0xb3, 0x68, 0x5b, 0x9c, 0x93, 0x77, 0x75,
		0x7b, 0xf6, 0x07, 0x66, 0x30, 0x55, 0x22, 0x83, 0x59, 0xf0, 0x9b, 0x81, 0xcf, 0x3a, 0xe0, 0x93,
		0x67, 0xf1, 0xd9, 0x56, 0xf7, 0xc4, 0xfa, 0xad, 0xf5, 0xa3, 0xfc, 0xa1, 0x3a, 0x38, 0xde, 0xff,
		0xd1, 0x18, 0x2c, 0xbe, 0xf9, 0xb2, 0xea, 0x63, 0xe5, 0x0f, 0x8d, 0xc1, 0xf1, 0x9a, 0x7f, 0xa9,
		0x0f, 0x8e, 0x37, 0xbc, 0x46, 0x6d, 0xf0, 0x7e, 0xe9, 0xa3, 0xc3, 0xf7, 0x2b, 0xeb, 0xbe, 0x50,
		0x5d, 0xf3, 0x85, 0x83, 0x75, 0x5f, 0x38, 0x58, 0xf3, 0x85, 0xb5, 0xb7, 0x54, 0x59, 0xf3, 0x85,
		0xda, 0xe0, 0x65, 0xe9, 0xf3, 0xef, 0x57, 0x7f, 0xb4, 0x3e, 0xd8, 0x7f, 0x59, 0xf7, 0x6f, 0x8d,
		0xc1, 0xcb, 0xf1, 0x3e, 0x9c, 0x09, 0xec, 0x19, 0xf6, 0x9c, 0x68, 0xd7, 0x8a, 0x38, 0xa4, 0x81,
		0x38, 0x24, 0xd3, 0x59, 0x87, 0x4b, 0x74, 0x83, 0xe5, 0xcc, 0x43, 0x44, 0x22, 0x11, 0x89, 0x44,
		0x24, 0x12, 0x91, 0x48, 0x44, 0x22, 0x11, 0x89, 0x44, 0x24, 0x12, 0x91, 0x48, 0x44, 0x22, 0x11,
		0x89, 0x44, 0x24, 0x12, 0x91, 0x48, 0xc0, 0x27, 0x22, 0x37, 0x88, 0x44, 0x22, 0x12, 0x09, 0x7b,
		0x46, 0x24, 0x12, 0x91, 0x48, 0xe3, 0x57, 0x46, 0x8f, 0x3e, 0xda, 0x1e, 0x7d, 0x84, 0x6d, 0x21,
		0x09, 0x9a, 0x17, 0xbc, 0x4b, 0xb0, 0x69, 0x15, 0xfe, 0x25, 0x9e, 0x97, 0xa3, 0xd7, 0x7b, 0x94,
		0x55, 0xb5, 0x85, 0x73, 0x57, 0xaa, 0x13, 0xa5, 0x68, 0x76, 0x7f, 0x16, 0x2e, 0x5c, 0xbf, 0xe9,
		0x89, 0x9e, 0xf0, 0xc7, 0xb5, 0xed, 0x04, 0x9d, 0x23, 0x2e, 0xec, 0xef, 0x33, 0x23, 0xf0, 0x54,
		0xf4, 0x17, 0xae, 0xa2, 0x8e, 0x88, 0x44, 0xe7, 0xd3, 0x70, 0xb6, 0xfc, 0xbe, 0xe7, 0x25, 0xda,
		0xa8, 0x88, 0x71, 0x2a, 0xe9, 0xf8, 0x54, 0x20, 0x69, 0x57, 0xa2, 0xb9, 0x5b, 0xa8, 0x5e, 0xf8,
		0xd4, 0x07, 0x72, 0x7a, 0xae, 0xa4, 0xc9, 0xa2, 0xa9, 0x2c, 0x39, 0x69, 0x16, 0xac, 0xc7, 0x18,
		0x76, 0x9f, 0x3a, 0x0d, 0xd3, 0x56, 0xf0, 0xec, 0x07, 0xe1, 0x59, 0x32, 0xb4, 0x1d, 0x61, 0xb9,
		0xfa, 0x8e, 0x70, 0x9b, 0x39, 0x4a, 0x60, 0xee, 0xfa, 0x9a, 0x0c, 0x4d, 0x6f, 0x42, 0x57, 0x7b,
		0xe2, 0x96, 0x22, 0x41, 0x4b, 0x97, 0x88, 0xa5, 0x4a, 0xb8, 0x92, 0x27, 0x56, 0xc9, 0x13, 0xa8,
		0xa4, 0x89, 0xd2, 0x64, 0x41, 0xb7, 0xf6, 0x04, 0x27, 0x61, 0x73, 0x38, 0x8a, 0x66, 0x70, 0x2b,
		0xfa, 0xa1, 0xce, 0x23, 0x57, 0x96, 0x30, 0x5f, 0x46, 0x34, 0x58, 0x3f, 0xbe, 0x2e, 0x30, 0x1e,
		0x18, 0x0f, 0x8c, 0x07, 0xc6, 0xa7, 0x01, 0xe3, 0xc7, 0x88, 0x95, 0x21, 0x6c, 0xd7, 0xdb, 0xa8,
		0x93, 0xa4, 0x31, 0xa7, 0xe6, 0x46, 0x9c, 0xda, 0x5b, 0x4f, 0x03, 0xd9, 0x81, 0xec, 0x29, 0x43,
		0x76, 0xdd, 0x8d, 0x2e, 0xa9, 0xc2, 0x02, 0x3c, 0xe1, 0x01, 0x22, 0x0a, 0x49, 0x46, 0x25, 0x29,
		0x81, 0x87, 0x1e, 0x80, 0xa8, 0x81, 0x88, 0x0d, 0x90, 0xd8, 0x80, 0x89, 0x05, 0xa0, 0xf4, 0x02,
		0x95, 0x66, 0xc0, 0xa2, 0xa3, 0xa4, 0x4b, 0xf6, 0xde, 0x77, 0x7d, 0x55, 0xae, 0x53, 0xd8, 0x7b,
		0x8c, 0x2e, 0x75, 0x82, 0x4b, 0xd3, 0x1e, 0x88, 0x47, 0x98, 0x0b, 0xe7, 0x38, 0xf0, 0x8e, 0x6b,
		0x3b, 0x0f, 0xd3, 0x81, 0x76, 0x9c, 0x47, 0x8c, 0x51, 0x6e, 0x25, 0xe3, 0x38, 0xa0, 0x8e, 0x7b,
		0xea, 0xeb, 0xb5, 0xda, 0x41, 0x2d, 0x43, 0xd3, 0x9f, 0x92, 0x22, 0x90, 0x56, 0x52, 0xb3, 0xad,
		0x1a, 0x65, 0x9b, 0xe6, 0x20, 0xec, 0x32, 0xb3, 0xd6, 0x19, 0x8c, 0x05, 0xa3, 0x06, 0xa3, 0x06,
		0xa3, 0x06, 0xa3, 0xa6, 0xdf, 0x99, 0x48, 0xb9, 0x13, 0x91, 0x76, 0xe7, 0x21, 0x21, 0xab, 0x66,
		0xde, 0x59, 0xc8, 0xb1, 0x15, 0x86, 0x6d, 0xeb, 0x4b, 0x66, 0xf6, 0x99, 0xb5, 0x28, 0x27, 0x83,
		0x73, 0xf3, 0x46, 0x76, 0x66, 0x24, 0x4d, 0xe5, 0xf0, 0x3c, 0xf0, 0x54, 0x07, 0x3c, 0x6d, 0xb7,
		0x18, 0xb0, 0x73, 0x29, 0x53, 0x3b, 0x97, 0x32, 0x07, 0xd6, 0xb0, 0xcf, 0x6c, 0xd9, 0x27, 0x22,
		0x41, 0x09, 0xb8, 0x12, 0xea, 0xee, 0x7f, 0x56, 0x77, 0xaf, 0x71, 0xdf, 0x9a, 0x86, 0xda, 0x9c,
		0x77, 0x06, 0x27, 0x7a, 0xb2, 0xef, 0x6c, 0x1c, 0xd3, 0xdb, 0xd3, 0x9a, 0x34, 0xd7, 0xbb, 0xc1,
		0x4c, 0xff, 0x86, 0x32, 0x96, 0x0d, 0x64, 0x7a, 0x37, 0x8c, 0xed, 0x3a, 0xdb, 0x9a, 0x97, 0xb3,
		0xd9, 0x65, 0x5c, 0xd0, 0x52, 0xd4, 0xb6, 0xeb, 0x76, 0xae, 0xdd, 0x60, 0x64, 0xfb, 0xc5, 0xbf,
		0xdd, 0x37, 0xb7, 0x34, 0x20, 0x5d, 0x86, 0x63, 0xc4, 0x60, 0xb6, 0x9b, 0xa1, 0xb7, 0x3f, 0xdf,
		0x2d, 0x9e, 0x6d, 0x41, 0xd9, 0xd1, 0xa3, 0x50, 0x62, 0xfb, 0x6c, 0xcd, 0x6b, 0xef, 0xc0, 0xc9,
		0x95, 0xb6, 0x9c, 0xe1, 0xdd, 0x4a, 0x27, 0x77, 0xce, 0xb3, 0xe8, 0xc8, 0xa7, 0xe8, 0xcb, 0x9b,
		0xe8, 0xca, 0x8f, 0x68, 0xcf, 0x83, 0x68, 0xcf, 0x77, 0x68, 0xcd, 0x6b, 0xf0, 0x62, 0xd2, 0xae,
		0xa5, 0x89, 0x85, 0x38, 0xa0, 0x64, 0x75, 0xed, 0x9e, 0xeb, 0xb9, 0x62, 0xf7, 0x43, 0x6a, 0xa7,
		0x06, 0xb8, 0x74, 0xe5, 0x5d, 0x59, 0x9a, 0x96, 0xba, 0x66, 0x6d, 0xc9, 0x50, 0x9d, 0xc9, 0x4f,
		0xfd, 0xc9, 0x4e, 0xdd, 0xc9, 0x4d, 0xb2, 0x64, 0x26, 0x59, 0xf2, 0x92, 0x24, 0x59, 0x69, 0x56,
		0xa7, 0xe8, 0xaa, 0x43, 0x9e, 0x5f, 0x9a, 0xcf, 0xfa, 0xf7, 0x33, 0x2c, 0x5c, 0x3f, 0xe1, 0x1b,
		0x1b, 0xb0, 0x65, 0x4d, 0x6b, 0xfa, 0x00, 0x1b, 0x1b, 0x52, 0x13, 0xd9, 0xd2, 0xbe, 0xb1, 0xc1,
		0xee, 0xba, 0x56, 0x2c, 0x24, 0x89, 0x0a, 0xaf, 0xa6, 0x23, 0xa0, 0xf4, 0x0a, 0xa5, 0x57, 0xc6,
		0x40, 0x88, 0x0d, 0x8c, 0x58, 0x40, 0x49, 0x2f, 0x38, 0x69, 0x06, 0xa9, 0xe9, 0x13, 0xa0, 0x2f,
		0xbd, 0xd2, 0xbf, 0xcf, 0x76, 0x89, 0xbb, 0x34, 0x08, 0xae, 0xbd, 0xb4, 0xef, 0x76, 0x8a, 0x91,
		0x39, 0x28, 0xf4, 0x75, 0x26, 0x00, 0x4b, 0xe4, 0x6f, 0xe2, 0xeb, 0xd3, 0x78, 0x9b, 0x32, 0xbc,
		0x0d, 0xbc, 0x0d, 0xbc, 0x4d, 0x12, 0xbd, 0x8d, 0x6e, 0x6a, 0x4c, 0x4f, 0x91, 0xb9, 0xa8, 0x32,
		0x31, 0x65, 0x26, 0x07, 0x33, 0x0e, 0x50, 0xe3, 0x03, 0x37, 0x2e, 0x90, 0x63, 0x07, 0x3b, 0x76,
		0xd0, 0x63, 0x05, 0x3f, 0x1a, 0x10, 0x24, 0x02, 0x43, 0x7a, 0x0a, 0xbe, 0xb4, 0x5e, 0x7a, 0xa1,
		0x27, 0x87, 0x4f, 0xde, 0xb2, 0xbb, 0x2e, 0x47, 0xb1, 0x6b, 0x95, 0x70, 0x8c, 0xa6, 0xdf, 0xef,
		0x0d, 0x9f, 0xda, 0x00, 0x87, 0x44, 0xeb, 0x58, 0x9d, 0xd9, 0x39, 0xcf, 0x77, 0x92, 0xae, 0x2e,
		0x2e, 0xa6, 0xca, 0xe6, 0xdf, 0x78, 0x2e, 0xc6, 0x22, 0x24, 0x07, 0x72, 0x4e, 0xef, 0x01, 0x4b,
		0x4b, 0xb0, 0xa2, 0xf3, 0xa0, 0x25, 0x36, 0x31, 0x57, 0x81, 0x98, 0x83, 0x98, 0x83, 0x98, 0x83,
		0x98, 0x83, 0x98, 0x83, 0x98, 0x83, 0x98, 0x83, 0x98, 0x83, 0x98, 0x83, 0x98, 0x83, 0x98, 0x4b,
		0xab, 0x98, 0x23, 0x68, 0x18, 0x95, 0x4c, 0x2d, 0x37, 0x7e, 0x22, 0x92, 0x4e, 0xcd, 0x4d, 0x06,
		0x40, 0x72, 0x0e, 0x7a, 0x0e, 0x7a, 0x0e, 0x7a, 0x4e, 0x17, 0x64, 0xd1, 0xab, 0xb9, 0x78, 0x1c,
		0x5a, 0x2d, 0x57, 0x86, 0x96, 0x83, 0x96, 0x83, 0x96, 0xcb, 0x83, 0x96, 0xa3, 0x02, 0xc4, 0xe9,
		0x00, 0x44, 0x65, 0x56, 0x6b, 0x97, 0x25, 0x49, 0xd9, 0x15, 0x33, 0x50, 0xb2, 0x01, 0x26, 0x27,
		0x70, 0xf2, 0x03, 0x28, 0x37, 0x90, 0x1a, 0x03, 0x54, 0x63, 0xc0, 0x6a, 0x04, 0x60, 0x69, 0x81,
		0x96, 0x18, 0x70, 0xd9, 0x80, 0x77, 0x3a, 0x90, 0xf0, 0xed, 0x07, 0x4f, 0x74, 0xf8, 0xac, 0x7f,
		0xb2, 0xbe, 0x27, 0x03, 0x33, 0x99, 0xe0, 0xa9, 0xe8, 0xda, 0x7d, 0x6f, 0x64, 0x81, 0x5d, 0xdb,
		0x93, 0x82, 0x6b, 0x5c, 0x9e, 0xa3, 0xaf, 0xd9, 0x5d, 0x82, 0x09, 0xd7, 0x60, 0xce, 0x45, 0x98,
		0x72, 0x15, 0xc6, 0x5d, 0x86, 0x71, 0xd7, 0x61, 0xd4, 0x85, 0xf0, 0xb8, 0x12, 0x26, 0x97, 0x32,
		0x7d, 0x92, 0xe4, 0xf9, 0x99, 0xb5, 0xeb, 0xf5, 0x21, 0x08, 0x3c, 0x61, 0xfb, 0x9c, 0x0b, 0x76,
		0xc2, 0xc4, 0xcb, 0xef, 0xb2, 0x61, 0x28, 0x0c, 0x46, 0x52, 0x18, 0x77, 0xce, 0x7e, 0x0a, 0xbc,
		0x8e, 0x72, 0x7b, 0x82, 0x9f, 0x19, 0x2c, 0x8c, 0x0f, 0x47, 0x0d, 0x47, 0x0d, 0x47, 0x0d, 0x47,
		0x0d, 0x47, 0xcd, 0xb6, 0x5e, 0xc9, 0xba, 0x6f, 0xfd, 0x0a, 0x7d, 0xeb, 0x8c, 0x43, 0xd2, 0x76,
		0xeb, 0x5a, 0xf7, 0x87, 0x17, 0x8f, 0xf6, 0xb8, 0xba, 0x7b, 0x25, 0xc4, 0xad, 0x2e, 0x0d, 0xcf,
		0xd4, 0x0d, 0x6c, 0xed, 0xf8, 0x8c, 0x6d, 0xa2, 0x0c, 0xc3, 0xd5, 0xbc, 0xc9, 0xd9, 0xdf, 0x73,
		0x6f, 0x72, 0x0c, 0x5d, 0xc8, 0x12, 0x6d, 0x76, 0xef, 0xb2, 0x39, 0x5a, 0x0b, 0x4a, 0xf2, 0x8d,
		0x4a, 0xd2, 0xf5, 0x95, 0x88, 0xbe, 0xd9, 0x9e, 0x29, 0x25, 0x39, 0x1d, 0x1f, 0x4a, 0x12, 0x4a,
		0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a,
		0x12, 0x4a, 0x12, 0x4a, 0x12, 0x4a, 0x32, 0xf1, 0x4a, 0xd2, 0x0b, 0x1c, 0xdb, 0x9b, 0x76, 0x29,
		0x64, 0x17, 0x92, 0xf3, 0xc3, 0x43, 0x47, 0x42, 0x47, 0x42, 0x47, 0x42, 0x47, 0x42, 0x47, 0xb2,
		0xad, 0x57, 0xd2, 0xee, 0xe5, 0xbf, 0x42, 0x60, 0x8a, 0xae, 0xe6, 0xbf, 0x7a, 0xc6, 0x99, 0xd7,
		0x92, 0xcc, 0xdd, 0xd1, 0x7f, 0x39, 0xc7, 0x87, 0x06, 0xc6, 0xe6, 0x6a, 0x07, 0xbb, 0xf6, 0x06,
		0xb2, 0xd2, 0xd3, 0x7b, 0x2d, 0xc5, 0x36, 0x31, 0xa9, 0x9c, 0x8d, 0x7e, 0xf3, 0x3b, 0xb3, 0xef,
		0x32, 0x1c, 0xf9, 0x30, 0x0b, 0xc7, 0x75, 0xc0, 0xb1, 0xd9, 0x45, 0x8b, 0xae, 0xdd, 0x99, 0xea,
		0xda, 0x0d, 0xe7, 0x04, 0x3b, 0xcf, 0xb5, 0x9d, 0x23, 0x7e, 0x9b, 0xfb, 0xf8, 0x6d, 0x24, 0x7a,
		0x81, 0x12, 0xe6, 0x02, 0xb8, 0x0b, 0xe3, 0x23, 0x82, 0x8b, 0x08, 0x2e, 0x22, 0xb8, 0x88, 0xe0,
		0x22, 0x82, 0x8b, 0x08, 0x2e, 0x22, 0xb8, 0x88, 0xe0, 0x22, 0x82, 0x8b, 0x08, 0x2e, 0x22, 0xb8,
		0x88, 0xe0, 0x22, 0x82, 0x0b, 0x38, 0x46, 0x64, 0x0b, 0x91, 0x2d, 0x38, 0x27, 0xd8, 0x39, 0xec,
		0x1c, 0x11, 0xdc, 0xb4, 0x44, 0x70, 0x53, 0x7d, 0xd6, 0x21, 0x71, 0xb3, 0x86, 0xa5, 0xf1, 0x92,
		0xd8, 0xbc, 0x21, 0x6e, 0x39, 0x10, 0xff, 0x4d, 0xd2, 0x98, 0x8f, 0xcf, 0x68, 0x08, 0x0d, 0x86,
		0x3b, 0x91, 0x60, 0x26, 0x81, 0xc0, 0x94, 0x38, 0xc0, 0x01, 0xc2, 0x7a, 0x46, 0xc4, 0x01, 0xc2,
		0xd4, 0x03, 0xe3, 0x00, 0xe1, 0xb7, 0x3e, 0x31, 0xb6, 0x40, 0xff, 0xeb, 0x1e, 0x19, 0x61, 0x77,
		0x23, 0xd1, 0xe5, 0x58, 0x70, 0x93, 0x10, 0x43, 0x83, 0x61, 0xac, 0xeb, 0x98, 0x27, 0x7c, 0xfc,
		0x38, 0xee, 0xb0, 0x54, 0x5c, 0xf0, 0x04, 0xf0, 0xd1, 0xcb, 0x04, 0x8b, 0xa4, 0xd9, 0xee, 0x5a,
		0xc3, 0xa3, 0x68, 0xbe, 0xbb, 0xd6, 0xe4, 0xb8, 0x3c, 0x72, 0x05, 0x1e, 0x19, 0x1e, 0x19, 0x1e,
		0x39, 0x43, 0x1e, 0x19, 0x47, 0xfa, 0xeb, 0x7e, 0xa0, 0x38, 0xd2, 0x3f, 0xed, 0xae, 0xc1, 0x9c,
		0x8b, 0x30, 0xe5, 0x2a, 0x8c, 0xbb, 0x0c, 0xe3, 0xae, 0xc3, 0xa8, 0x0b, 0xe1, 0x71, 0x25, 0x4c,
		0x2e, 0x85, 0x5f, 0xec, 0x2d, 0xad, 0x57, 0x1c, 0xe9, 0x9f, 0x06, 0x23, 0xc1, 0x91, 0xfe, 0x70,
		0xd4, 0x70, 0xd4, 0x70, 0xd4, 0x70, 0xd4, 0xb9, 0x75, 0xd4, 0x38, 0x88, 0x91, 0xec, 0x0f, 0x0e,
		0x62, 0x64, 0x1d, 0x1e, 0x07, 0x31, 0xe2, 0x20, 0x46, 0x43, 0x26, 0x87, 0x83, 0x18, 0x33, 0x39,
		0x1a, 0x36, 0xf2, 0xbe, 0x55, 0x49, 0xe2, 0x48, 0x7f, 0x28, 0x49, 0x28, 0x49, 0x28, 0x49, 0x28,
		0x49, 0x28, 0x49, 0x28, 0x49, 0x28, 0x49, 0x28, 0x49, 0x28, 0x49, 0x28, 0x49, 0x28, 0x49, 0x28,
		0x49, 0x28, 0xc9, 0x4d, 0xcd, 0x10, 0x47, 0xfa, 0xf3, 0xe9, 0xc8, 0x0a, 0x74, 0x24, 0x74, 0x24,
		0x74, 0x24, 0x74, 0x64, 0x82, 0x74, 0x24, 0x0e, 0x84, 0xca, 0x9a, 0x96, 0xc4, 0x81, 0x50, 0x38,
		0x10, 0x8a, 0x9e, 0x62, 0xe3, 0x40, 0x28, 0x1c, 0x08, 0x95, 0xbe, 0xc8, 0x07, 0x0e, 0x84, 0xc2,
		0x81, 0x50, 0x38, 0x28, 0x07, 0x07, 0x42, 0x65, 0xdc, 0x39, 0xc1, 0xce, 0x71, 0x20, 0x14, 0xe2,
		0xb7, 0xb9, 0x88, 0xdf, 0xe2, 0x48, 0x7f, 0x44, 0x70, 0x11, 0xc1, 0x45, 0x04, 0x17, 0x11, 0x5c,
		0x44, 0x70, 0x11, 0xc1, 0x45, 0x04, 0x17, 0x21, 0x03, 0xc4, 0xf9, 0x20, 0x92, 0x11, 0xc1, 0x45,
		0x04, 0x17, 0x11, 0x5c, 0x44, 0x70, 0x11, 0xd9, 0x42, 0x04, 0x17, 0x11, 0x5c, 0xd8, 0x39, 0x22,
		0xb8, 0x88, 0xe0, 0x26, 0x6f, 0x04, 0x1c, 0xe9, 0xcf, 0x7e, 0xa4, 0xff, 0xf8, 0x94, 0xda, 0xb4,
		0x9e, 0x16, 0xfc, 0x2e, 0x45, 0x56, 0x58, 0xf8, 0x97, 0x78, 0x66, 0x4b, 0x10, 0x14, 0xce, 0x5d,
		0xa9, 0x4e, 0x94, 0xa2, 0x3d, 0xdb, 0xb3, 0x70, 0xe1, 0xfa, 0x4d, 0x4f, 0xf4, 0x84, 0x3f, 0xde,
		0xb0, 0x41, 0x78, 0x78, 0xf3, 0x85, 0xfd, 0x7d, 0x66, 0xa4, 0xf2, 0x61, 0xb5, 0x5a, 0x6f, 0x54,
		0xab, 0xa5, 0xc6, 0x41, 0xa3, 0x74, 0x54, 0xab, 0x95, 0xeb, 0x65, 0xc2, 0x6d, 0x2b, 0x85, 0xab,
		0xa8, 0x23, 0x22, 0xd1, 0xf9, 0x34, 0x9c, 0x3f, 0xbf, 0xef, 0x79, 0xa9, 0x32, 0x3b, 0x26, 0xd0,
		0x4b, 0x01, 0xd8, 0x15, 0x48, 0x0f, 0x17, 0x8f, 0xfa, 0x8e, 0xf2, 0x63, 0x65, 0x7c, 0x39, 0xfe,
		0x39, 0x67, 0xf1, 0xaf, 0x69, 0x5f, 0x84, 0x9e, 0x6c, 0xdf, 0x4e, 0x7e, 0xcd, 0xf5, 0xe4, 0xc7,
		0xb4, 0xcf, 0x3b, 0x61, 0xfb, 0x2e, 0xfe, 0x31, 0xed, 0x93, 0xf1, 0xbd, 0xff, 0x36, 0xba, 0xf5,
		0xf8, 0x6d, 0x1a, 0x64, 0xd6, 0x8f, 0x9b, 0x7a, 0xaf, 0xa8, 0x79, 0x29, 0x50, 0x2f, 0x81, 0x24,
		0x9b, 0xbe, 0x5e, 0x03, 0xd2, 0x37, 0xcd, 0x7a, 0xae, 0xa4, 0xc9, 0x50, 0x26, 0xae, 0xd9, 0xee,
		0xba, 0xd6, 0x68, 0x09, 0x6b, 0xba, 0x2c, 0x89, 0x13, 0xa6, 0x73, 0xba, 0xac, 0x4e, 0x96, 0xc6,
		0xa9, 0xea, 0x32, 0x08, 0x22, 0xc4, 0x48, 0x22, 0x52, 0x68, 0xf4, 0x8a, 0xda, 0xbd, 0xa0, 0x1e,
		0xf4, 0xda, 0x1d, 0x6b, 0x76, 0xbb, 0xc2, 0x8e, 0x46, 0xa9, 0xdb, 0x18, 0x13, 0x61, 0x84, 0xbb,
		0xcd, 0xec, 0xf6, 0xf3, 0xb1, 0xc3, 0x5c, 0x14, 0x9c, 0x49, 0xd5, 0xd3, 0x6e, 0x73, 0x30, 0xcd,
		0x9f, 0xc4, 0xd7, 0xdb, 0xd1, 0x3a, 0xf4, 0xb4, 0x80, 0xd1, 0x76, 0xb8, 0x93, 0xce, 0x52, 0x2d,
		0xfd, 0x25, 0x58, 0xba, 0x4b, 0xab, 0xc8, 0x4a, 0xa6, 0xc8, 0x4a, 0xa1, 0x48, 0x4a, 0x9c, 0xcc,
		0xe2, 0xa3, 0xae, 0x16, 0x26, 0xf1, 0x29, 0x6e, 0xb6, 0xe3, 0x88, 0x50, 0xe9, 0x33, 0x91, 0xf9,
		0x33, 0xe2, 0xe2, 0xab, 0xeb, 0x22, 0xae, 0x5a, 0xeb, 0x3e, 0xb5, 0x9f, 0xf0, 0x46, 0x51, 0xb7,
		0x49, 0x57, 0x97, 0x49, 0x55, 0x77, 0x49, 0x5e, 0x57, 0x49, 0x5e, 0x37, 0x49, 0x5a, 0x17, 0x99,
		0x2c, 0x29, 0xa8, 0xbd, 0x6e, 0x91, 0xb0, 0x29, 0x85, 0xe6, 0xa6, 0x13, 0x1a, 0x78, 0xf2, 0x07,
		0x5d, 0x20, 0xac, 0xbd, 0x29, 0x04, 0x6d, 0xd3, 0x07, 0x00, 0x31, 0x80, 0x18, 0x40, 0x9c, 0x12,
		0x20, 0xd6, 0x7e, 0x54, 0x24, 0xc1, 0x51, 0x90, 0x44, 0x47, 0x3d, 0x12, 0x04, 0xbf, 0x29, 0x8f,
		0x6a, 0x24, 0xde, 0xd7, 0x44, 0x7d, 0xd4, 0x22, 0xc7, 0x99, 0x76, 0x04, 0x69, 0x43, 0xd2, 0xa3,
		0x10, 0xb9, 0xa6, 0x94, 0xf0, 0x28, 0x43, 0x96, 0x69, 0x4d, 0x68, 0xde, 0xa6, 0x95, 0x39, 0xa6,
		0xa9, 0xfd, 0xd0, 0x78, 0xda, 0x43, 0xe1, 0xc1, 0x34, 0xc1, 0x34, 0xc1, 0x34, 0xc1, 0x34, 0xc1,
		0x34, 0xc1, 0x34, 0xc1, 0x34, 0xc1, 0x34, 0xc1, 0x34, 0xa9, 0x99, 0x26, 0x72, 0xff, 0x3b, 0xe6,
		0xfe, 0xe3, 0x3c, 0x77, 0x0a, 0x33, 0xfe, 0xe3, 0xea, 0x78, 0x6d, 0x09, 0xff, 0xf1, 0xe5, 0x12,
		0x96, 0xef, 0xaf, 0x20, 0xdf, 0x9f, 0x00, 0x5e, 0x8f, 0x7c, 0xff, 0xe6, 0xbf, 0x08, 0xf9, 0x7e,
		0x88, 0x7f, 0x88, 0x7f, 0x88, 0xff, 0x84, 0x8b, 0x7f, 0xe4, 0xfb, 0xdf, 0x00, 0xc2, 0xc8, 0xf7,
		0x03, 0x88, 0x01, 0xc4, 0x00, 0x62, 0x44, 0x61, 0x11, 0x85, 0x45, 0x14, 0x96, 0x7e, 0xb9, 0xcd,
		0x4f, 0x29, 0xa2, 0xb0, 0xc6, 0xa7, 0x15, 0x51, 0x58, 0x26, 0xa6, 0x89, 0x7c, 0x3f, 0x98, 0x26,
		0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0x26, 0x98, 0xa6,
		0xbe, 0x2b, 0x20, 0xdf, 0xdf, 0xd1, 0x71, 0xa6, 0xdc, 0x0e, 0xe9, 0xfe, 0x77, 0x8c, 0xd3, 0xa6,
		0x6b, 0xba, 0x4c, 0x4c, 0x53, 0x61, 0xa7, 0xba, 0x88, 0x5d, 0xcf, 0xf9, 0xd8, 0xce, 0x3c, 0xde,
		0x3e, 0xb9, 0x6f, 0xfb, 0xc6, 0x1b, 0xcd, 0x60, 0xd7, 0xe9, 0x67, 0x9c, 0xf6, 0x2d, 0x66, 0x7b,
		0xfb, 0x59, 0x7e, 0xdb, 0xe4, 0x6e, 0x3e, 0x45, 0x6f, 0x98, 0x9e, 0x42, 0x24, 0xbf, 0x85, 0xd6,
		0x16, 0xc5, 0x3b, 0xaf, 0x8d, 0x9c, 0xe2, 0x0b, 0xbc, 0xd1, 0x24, 0xb6, 0x2b, 0xcf, 0xd9, 0x5a,
		0x96, 0xef, 0x22, 0xbf, 0x67, 0x65, 0xf6, 0xf0, 0xd7, 0x6e, 0x63, 0x23, 0x3b, 0xea, 0x69, 0x6d,
		0xba, 0x59, 0x9b, 0x3e, 0x5e, 0xd4, 0xc1, 0xa3, 0x07, 0x93, 0x30, 0xd8, 0xd9, 0xb6, 0x00, 0xa6,
		0xf0, 0xe8, 0x05, 0x0f, 0x3b, 0x44, 0xbe, 0xa6, 0x06, 0x13, 0x5f, 0x67, 0xcb, 0x27, 0xbc, 0x5b,
		0x05, 0xdb, 0xce, 0x11, 0x2c, 0x1d, 0x11, 0x2b, 0x0d, 0x4b, 0x47, 0x77, 0x48, 0x4a, 0x7b, 0x08,
		0x4a, 0x7b, 0xc8, 0x49, 0xcf, 0xd2, 0x32, 0x43, 0xf4, 0x76, 0xad, 0x39, 0x2b, 0x3c, 0x46, 0xb6,
		0x23, 0xba, 0x7d, 0xcf, 0x8a, 0x84, 0x54, 0x76, 0xa4, 0xf4, 0x55, 0x95, 0x2e, 0x5d, 0x19, 0x07,
		0x4a, 0x31, 0x2c, 0x5b, 0xdd, 0xcb, 0x97, 0x6c, 0x19, 0x93, 0x2d, 0x67, 0x9a, 0x65, 0x9d, 0x0c,
		0x19, 0xae, 0xad, 0xc4, 0x54, 0xd3, 0x99, 0x71, 0x4b, 0x06, 0xac, 0xe5, 0xec, 0x38, 0xcd, 0x4b,
		0x5e, 0xfb, 0xd2, 0xa7, 0x80, 0x00, 0x42, 0x28, 0xa0, 0x82, 0x04, 0x72, 0x68, 0x20, 0x87, 0x08,
		0x5a, 0xa8, 0xd0, 0x1b, 0x8b, 0xd4, 0x95, 0x65, 0xd2, 0x05, 0x21, 0xd3, 0x0b, 0x0a, 0xdf, 0x7e,
		0xf0, 0x08, 0xac, 0x6a, 0xb2, 0x10, 0xe2, 0xeb, 0x6b, 0x9e, 0xf1, 0x53, 0xd1, 0xb5, 0xfb, 0xde,
		0x68, 0xc2, 0xbb, 0xb6, 0x27, 0xb5, 0x5f, 0x9f, 0x26, 0xe8, 0xaf, 0x1d, 0xc2, 0x28, 0xa1, 0x8c,
		0x01, 0xd2, 0xa8, 0xa1, 0x8d, 0x0d, 0xe2, 0xd8, 0xa0, 0x8e, 0x07, 0xf2, 0xf4, 0x42, 0x9f, 0x66,
		0x08, 0x9c, 0x3e, 0x02, 0xb2, 0x5e, 0xc0, 0x84, 0xb5, 0xf6, 0x4b, 0xdc, 0xa8, 0x9c, 0xd4, 0x93,
		0xf4, 0x35, 0x12, 0x97, 0x48, 0x38, 0xc1, 0x37, 0x11, 0x3d, 0x5b, 0x5a, 0x4b, 0xf1, 0x97, 0x66,
		0x6b, 0x7e, 0x18, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0xad, 0x16, 0xdf, 0x77, 0x7d,
		0x75, 0x50, 0x21, 0xf4, 0x07, 0x0d, 0x82, 0x4b, 0xd3, 0x54, 0x66, 0x4d, 0xfe, 0xd0, 0xf6, 0x01,
		0x23, 0xef, 0xa8, 0x47, 0x5c, 0xde, 0x33, 0x1d, 0x86, 0xb8, 0x72, 0x6b, 0x3a, 0x0e, 0x43, 0xa9,
		0x0f, 0xd1, 0xf2, 0x9d, 0x9f, 0x7a, 0xc2, 0x8a, 0x2e, 0x53, 0x53, 0x5f, 0xad, 0x1c, 0x55, 0x8f,
		0xea, 0x8d, 0xca, 0x51, 0x2d, 0x43, 0x36, 0x90, 0x92, 0x4e, 0x62, 0xad, 0x5c, 0xd0, 0xec, 0x51,
		0xa2, 0x86, 0x9c, 0x65, 0xcf, 0x8c, 0x02, 0x92, 0x0d, 0x92, 0x0d, 0x92, 0x0d, 0x92, 0x0d, 0x92,
		0x0d, 0x92, 0x0d, 0x92, 0x0d, 0x92, 0x0d, 0x92, 0x0d, 0x92, 0x9d, 0x40, 0x92, 0x8d, 0x26, 0xa0,
		0xfa, 0xaa, 0xbe, 0xe3, 0x02, 0xe6, 0xe2, 0xb8, 0x58, 0xb3, 0xb8, 0x58, 0x26, 0xa6, 0xe5, 0x58,
		0x46, 0x7d, 0x13, 0xa7, 0x63, 0x83, 0xb7, 0x9e, 0xe3, 0x1a, 0x97, 0x68, 0x8e, 0x8e, 0x63, 0x1b,
		0x17, 0x51, 0x56, 0x7b, 0xa9, 0x4d, 0x05, 0xa5, 0x36, 0x69, 0x52, 0x44, 0x28, 0xb5, 0x41, 0xa9,
		0x0d, 0x4a, 0x6d, 0x10, 0xf4, 0x41, 0xd0, 0x07, 0x41, 0x9f, 0x74, 0x05, 0x7d, 0x50, 0x6a, 0xa3,
		0xe5, 0xb7, 0xa2, 0xd4, 0x06, 0x0e, 0x01, 0x0e, 0x01, 0x0e, 0x21, 0xfd, 0x0e, 0x01, 0x59, 0x80,
		0xa5, 0x3f, 0xc8, 0x02, 0x6c, 0x34, 0x0c, 0xb2, 0x00, 0x6f, 0x9b, 0x7a, 0x64, 0x01, 0xd2, 0x61,
		0x03, 0xc8, 0x02, 0x24, 0x88, 0x66, 0xa3, 0xd4, 0x06, 0x24, 0x1b, 0x24, 0x1b, 0x24, 0x1b, 0x24,
		0x1b, 0x24, 0x1b, 0x24, 0x1b, 0x24, 0x1b, 0x24, 0x1b, 0x24, 0x1b, 0x24, 0x1b, 0xa5, 0x36, 0x9c,
		0xa5, 0x36, 0x1a, 0x4e, 0x44, 0xd5, 0x37, 0x6f, 0x38, 0xe0, 0x56, 0xff, 0x0c, 0x17, 0xb4, 0x54,
		0x2f, 0x6d, 0x73, 0xdc, 0xe6, 0x8d, 0xfc, 0x16, 0xde, 0x89, 0xf6, 0x3f, 0x47, 0xf7, 0xd5, 0xfe,
		0x67, 0x7c, 0x5f, 0x37, 0xf1, 0x6d, 0xa5, 0xb0, 0xe7, 0xee, 0xa8, 0x8b, 0x86, 0xd4, 0x77, 0x3c,
		0x5a, 0x7c, 0x3d, 0x1c, 0x8a, 0xc6, 0xa8, 0xaa, 0x71, 0x28, 0x1a, 0x0e, 0x45, 0xfb, 0xc9, 0x85,
		0x70, 0x28, 0x5a, 0x42, 0x03, 0x6d, 0xa8, 0xd4, 0x34, 0x10, 0x48, 0x43, 0xa5, 0xe6, 0x0e, 0x17,
		0x24, 0xea, 0xe9, 0xb5, 0x9a, 0x45, 0xe8, 0xee, 0xed, 0xf5, 0xfa, 0x58, 0x5e, 0x2b, 0x37, 0x8f,
		0x4a, 0xa5, 0x12, 0x52, 0x08, 0x48, 0x21, 0x18, 0x44, 0x3c, 0x36, 0xe4, 0xe3, 0x41, 0x40, 0x9a,
		0xd8, 0x4e, 0x3a, 0x53, 0x08, 0x5a, 0x9b, 0x93, 0x2d, 0xe2, 0x4b, 0x1d, 0x29, 0x84, 0xd7, 0x1b,
		0xcf, 0x62, 0x0a, 0xa1, 0x5c, 0x2a, 0x21, 0x8b, 0xb0, 0xd9, 0xec, 0x67, 0x30, 0x8b, 0x50, 0x2f,
		0x65, 0x6b, 0xfa, 0x91, 0x40, 0x48, 0xca, 0xf2, 0x29, 0x44, 0xa2, 0x1b, 0x09, 0xf9, 0x64, 0x45,
		0xa2, 0xd3, 0x77, 0xb4, 0x67, 0x01, 0xf6, 0xe6, 0x4b, 0x75, 0x16, 0x87, 0xa2, 0xe3, 0xf2, 0x43,
		0xc6, 0x04, 0x2e, 0x0f, 0x2e, 0x0f, 0x2e, 0x0f, 0x2e, 0xaf, 0xd7, 0xe2, 0xf3, 0xbc, 0x09, 0x0b,
		0x89, 0x6b, 0xb2, 0xb4, 0xe6, 0x38, 0x57, 0x86, 0x93, 0x21, 0x36, 0x5d, 0x86, 0x38, 0x19, 0x22,
		0xb1, 0x1e, 0x1c, 0xf9, 0x06, 0x33, 0x1e, 0x1a, 0xf9, 0x06, 0x2d, 0x0b, 0x02, 0xf9, 0x06, 0x68,
		0x14, 0x68, 0x14, 0x68, 0x94, 0x14, 0x6b, 0x14, 0xe4, 0x1b, 0x96, 0xfe, 0x20, 0xdf, 0xb0, 0xd1,
		0x30, 0xc8, 0x37, 0xbc, 0x79, 0xf6, 0x91, 0x6f, 0x48, 0xfc, 0xf4, 0x23, 0xdf, 0x90, 0x94, 0xe5,
		0x83, 0x7c, 0x03, 0xb8, 0x3c, 0xb8, 0x3c, 0xb8, 0x3c, 0xb8, 0xfc, 0xa6, 0x16, 0x8f, 0x7c, 0x43,
		0x42, 0x02, 0x5a, 0x99, 0xcc, 0x37, 0x60, 0x7b, 0x1c, 0xd5, 0xfc, 0x1a, 0x9d, 0xd7, 0xa4, 0x6c,
		0x8a, 0xfb, 0x7d, 0x7c, 0x37, 0x29, 0xdc, 0x0b, 0x27, 0x83, 0xae, 0xb2, 0xc2, 0x48, 0x88, 0x5e,
		0xa8, 0xc5, 0x24, 0x5e, 0x13, 0x57, 0x0b, 0x17, 0xc6, 0xee, 0x38, 0x46, 0xd2, 0x87, 0xdd, 0x71,
		0xd8, 0x1d, 0xf7, 0x93, 0x0b, 0x61, 0x77, 0x5c, 0x42, 0x75, 0x20, 0xb2, 0xd5, 0x06, 0x74, 0x1e,
		0xb2, 0xd5, 0x3b, 0x5c, 0x10, 0x7d, 0x0c, 0x10, 0xd2, 0x42, 0x48, 0x0b, 0x21, 0x2d, 0x84, 0xb4,
		0x10, 0xd2, 0xa2, 0x99, 0xac, 0x45, 0x25, 0x39, 0x3a, 0x02, 0x35, 0xe8, 0x2b, 0x3a, 0x9f, 0xb3,
		0x6e, 0x40, 0x3a, 0x27, 0x74, 0x80, 0x02, 0x29, 0x78, 0x20, 0x78, 0x20, 0x78, 0x20, 0xcd, 0x16,
		0x8f, 0x02, 0xa9, 0xa5, 0x3f, 0x28, 0x90, 0xda, 0x68, 0x18, 0x9c, 0xe9, 0xfa, 0xb6, 0xa9, 0x67,
		0xac, 0x8e, 0x3a, 0xc0, 0xd4, 0x9b, 0xf5, 0x03, 0x74, 0x57, 0xc5, 0x51, 0xae, 0x1b, 0x51, 0x87,
		0x4c, 0x65, 0xa8, 0x17, 0xd4, 0x06, 0xb6, 0xc6, 0x6d, 0x2c, 0xd3, 0xb0, 0x35, 0x2e, 0xa9, 0xba,
		0x08, 0xc9, 0x06, 0x33, 0xba, 0x07, 0xc9, 0x86, 0x9d, 0x16, 0x02, 0x92, 0x0d, 0x08, 0xf5, 0x20,
		0xd4, 0x83, 0x50, 0x0f, 0x92, 0x0d, 0x2b, 0xb9, 0x11, 0x92, 0x0d, 0x04, 0xf3, 0x86, 0x64, 0x03,
		0x3c, 0x10, 0x3c, 0x10, 0x3c, 0x50, 0xfa, 0x3d, 0x10, 0x92, 0x0d, 0x4b, 0x7f, 0x90, 0x6c, 0xd8,
		0x68, 0x18, 0x24, 0x1b, 0xde, 0x36, 0xf5, 0x48, 0x36, 0x24, 0x7a, 0xea, 0x91, 0x6c, 0xc8, 0x50,
		0x10, 0x2b, 0xdb, 0xc9, 0x06, 0xec, 0x8b, 0xa3, 0x9a, 0xe8, 0x64, 0x4c, 0x70, 0x52, 0x36, 0xc8,
		0xdd, 0x06, 0x5d, 0x75, 0xfd, 0x7a, 0x57, 0x69, 0xdc, 0x28, 0xa7, 0x25, 0x89, 0xa5, 0x35, 0x79,
		0xa5, 0x7d, 0x53, 0x5c, 0x05, 0x9b, 0xe2, 0x92, 0xa0, 0x93, 0xb1, 0x29, 0xee, 0x2d, 0x81, 0x2d,
		0x7d, 0x9b, 0xe2, 0xfa, 0xbe, 0x12, 0x91, 0xa4, 0xd8, 0x16, 0x17, 0x5f, 0x19, 0xb9, 0xea, 0x04,
		0x86, 0xd5, 0x90, 0xab, 0x36, 0x13, 0x36, 0xcb, 0x7a, 0xae, 0x3a, 0x8a, 0x02, 0x8d, 0x60, 0xb2,
		0xb4, 0x10, 0xe2, 0xeb, 0xd3, 0x44, 0xf2, 0xcb, 0x88, 0xe4, 0x23, 0x92, 0x9f, 0x24, 0x28, 0xe2,
		0x81, 0x24, 0x9a, 0x58, 0x8b, 0xee, 0x48, 0xbe, 0x6e, 0xa8, 0x9a, 0x5e, 0xd8, 0xee, 0xab, 0x27,
		0xe1, 0x2b, 0xd7, 0x19, 0xa9, 0x60, 0xab, 0x6b, 0xbb, 0x1e, 0x9d, 0x69, 0x4e, 0x56, 0xd7, 0xaa,
		0x41, 0x89, 0x6c, 0x87, 0x36, 0x9a, 0x4d, 0x06, 0x72, 0x1c, 0x60, 0xc7, 0x08, 0x7a, 0x5c, 0xe0,
		0xc7, 0x0e, 0x82, 0xec, 0x60, 0xc8, 0x0b, 0x8a, 0x34, 0xe0, 0x48, 0x04, 0x92, 0xd3, 0x47, 0x43,
		0x96, 0xf6, 0x5c, 0xa7, 0xf2, 0xea, 0x55, 0xca, 0x35, 0x13, 0x43, 0xd8, 0x21, 0xe1, 0x10, 0xb4,
		0x19, 0xd1, 0xc9, 0x1f, 0xda, 0x35, 0xbf, 0xc7, 0x95, 0x21, 0x65, 0xf2, 0x2d, 0x4b, 0xc3, 0x31,
		0xa5, 0xcd, 0xa6, 0xe3, 0x31, 0xa6, 0xcf, 0x88, 0x11, 0x61, 0xde, 0x44, 0x18, 0x32, 0xa9, 0xa6,
		0x4d, 0xa4, 0x7c, 0x58, 0xad, 0xd6, 0x1b, 0xd5, 0x6a, 0xa9, 0x71, 0xd0, 0x28, 0x1d, 0xd5, 0x6a,
		0xe5, 0x7a, 0xb9, 0x96, 0x61, 0xab, 0x79, 0x97, 0xce, 0xab, 0xb7, 0x52, 0x92, 0x34, 0x26, 0x58,
		0x95, 0x85, 0x07, 0xbb, 0x63, 0x39, 0x4f, 0xc2, 0xf9, 0x2a, 0xfb, 0x3d, 0x7a, 0xc1, 0x31, 0x37,
		0x1a, 0x94, 0x06, 0x94, 0x06, 0x94, 0x06, 0x94, 0x06, 0x94, 0x06, 0x94, 0x06, 0x94, 0x06, 0x94,
		0x06, 0x94, 0x06, 0x94, 0x06, 0x94, 0x46, 0xa6, 0x95, 0x46, 0x68, 0x3b, 0x5f, 0x85, 0xb2, 0xba,
		0x41, 0xd4, 0xb3, 0x15, 0x8f, 0xdc, 0x98, 0x1f, 0x12, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a,
		0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x23, 0x0f,
		0x9a, 0xc3, 0x13, 0xfe, 0xe3, 0x68, 0x3b, 0x10, 0x9f, 0xe6, 0x88, 0x87, 0x84, 0xe6, 0x80, 0xe6,
		0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6, 0x80, 0xe6,
		0x80, 0xe6, 0xc8, 0xac, 0xe6, 0x08, 0xfa, 0xca, 0x0a, 0xba, 0x56, 0x10, 0x75, 0x44, 0x44, 0x2f,
		0x37, 0xe6, 0x46, 0x83, 0xd2, 0x80, 0xd2, 0x80, 0xd2, 0x80, 0xd2, 0x80, 0xd2, 0x80, 0xd2, 0x80,
		0xd2, 0x80, 0xd2, 0x80, 0xd2, 0x80, 0xd2, 0x80, 0xd2, 0xc8, 0xac, 0xd2, 0x88, 0x84, 0x23, 0xdc,
		0x6f, 0xa2, 0x63, 0xf9, 0xb6, 0xf3, 0x95, 0x5e, 0x6a, 0xcc, 0x0f, 0x07, 0xad, 0x01, 0xad, 0x01,
		0xad, 0x01, 0xad, 0x01, 0xad, 0x01, 0xad, 0x01, 0xad, 0x01, 0xad, 0x01, 0xad, 0x01, 0xad, 0x01,
		0xad, 0x91, 0x59, 0xad, 0xa1, 0x22, 0xdb, 0x97, 0x3d, 0x57, 0x8d, 0x0e, 0x89, 0xea, 0x47, 0x82,
		0x5e, 0x6e, 0x2c, 0x8d, 0x08, 0xc5, 0x01, 0xc5, 0x01, 0xc5, 0x01, 0xc5, 0x01, 0xc5, 0x01, 0xc5,
		0x01, 0xc5, 0x01, 0xc5, 0x01, 0xc5, 0x01, 0xc5, 0x01, 0xc5, 0x91, 0x7d, 0xc5, 0xf1, 0xbf, 0x7d,
		0xd1, 0x17, 0x56, 0xb7, 0xef, 0x79, 0x8c, 0xa2, 0x63, 0x66, 0x50, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8,
		0x0e, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8, 0x0e, 0xe8,
		0x8e, 0xcc, 0xea, 0x8e, 0xbe, 0xff, 0xd5, 0x0f, 0xfe, 0xf6, 0x2d, 0x96, 0x9a, 0xaa, 0xd9, 0xc1,
		0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33,
		0xa0, 0x33, 0xa0, 0x33, 0xa0, 0x33, 0x32, 0xaf, 0x33, 0x7c, 0x56, 0xa1, 0x81, 0xbd, 0x1b, 0x50,
		0x1a, 0x50, 0x1a, 0x50, 0x1a, 0x50, 0x1a, 0x50, 0x1a, 0x50, 0x1a, 0x50, 0x1a, 0x50, 0x1a, 0x50,
		0x1a, 0x50, 0x1a, 0x09, 0x52, 0x1a, 0x89, 0x6e, 0x7f, 0x7e, 0xe2, 0xfb, 0x81, 0x1a, 0x35, 0x0b,
		0xa7, 0xe9, 0x82, 0x2e, 0x9d, 0x27, 0xd1, 0xb3, 0x43, 0x7b, 0x74, 0x50, 0x6f, 0xa1, 0x18, 0x84,
		0xc2, 0x77, 0x46, 0xac, 0xdf, 0xf2, 0x85, 0xfa, 0x3b, 0x88, 0xbe, 0x5a, 0xae, 0x2f, 0x95, 0xed,
		0x3b, 0xa2, 0xb8, 0xf8, 0x86, 0x5c, 0x7a, 0xa7, 0xd8, 0x0b, 0x3d, 0x59, 0x94, 0xee, 0xa3, 0x6f,
		0x7b, 0xae, 0xff, 0x68, 0x85, 0x51, 0xa0, 0x02, 0x27, 0xf0, 0x64, 0x71, 0x48, 0xe0, 0x2c, 0x25,
		0x8a, 0x8f, 0x5e, 0xf0, 0x60, 0x7b, 0x45, 0xa9, 0x6c, 0x25, 0x8a, 0x31, 0xbf, 0x90, 0x45, 0x11,
		0x45, 0x41, 0x24, 0x09, 0x58, 0x46, 0x41, 0xaa, 0xa8, 0xef, 0x28, 0x3f, 0x26, 0x34, 0x97, 0xe3,
		0xfb, 0x3d, 0x8b, 0x6f, 0xb7, 0x7d, 0x11, 0x7a, 0xb2, 0x7d, 0x3b, 0xb9, 0xdd, 0xeb, 0xc9, 0xdd,
		0xb6, 0x6f, 0xe4, 0xb7, 0xf0, 0x4e, 0xb4, 0xff, 0x39, 0xba, 0xd9, 0xf6, 0xe7, 0xf8, 0x36, 0xdb,
		0xcd, 0xf1, 0x6d, 0xbe, 0x4b, 0xa6, 0xf5, 0x69, 0xb4, 0xbc, 0x82, 0x3b, 0xca, 0x8f, 0x59, 0x3d,
		0x21, 0xa5, 0xfd, 0x28, 0xa4, 0x76, 0xd3, 0x9b, 0x52, 0xcc, 0xc5, 0x81, 0x34, 0xaf, 0x1e, 0x1a,
		0x07, 0x45, 0xa6, 0x8b, 0x29, 0xf5, 0x30, 0x83, 0x0e, 0xa6, 0xd6, 0xbf, 0x6c, 0xba, 0x97, 0x4d,
		0xef, 0xf2, 0xe8, 0xdc, 0x64, 0x7b, 0x38, 0x32, 0x3d, 0xcb, 0xa2, 0x63, 0x09, 0xf5, 0x2b, 0xb1,
		0x6e, 0x25, 0x0c, 0x20, 0x70, 0xe8, 0x54, 0x26, 0xf1, 0xc1, 0xa5, 0x4b, 0x39, 0x95, 0x05, 0xa1,
		0x0e, 0x65, 0xd1, 0x9f, 0xdc, 0x53, 0xcf, 0xaf, 0x37, 0x59, 0xad, 0x21, 0x25, 0x3a, 0xad, 0x95,
		0x0f, 0xde, 0xfd, 0x24, 0x3c, 0x2f, 0xe0, 0x61, 0xde, 0x0b, 0x43, 0x81, 0x7b, 0x83, 0x7b, 0x83,
		0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0xe7,
		0x8b, 0x7b, 0x87, 0xb6, 0x7a, 0xb2, 0x46, 0xc9, 0x08, 0x1e, 0x02, 0xbe, 0x6a, 0x3c, 0xb0, 0x70,
		0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70,
		0xb0, 0xf0, 0x1c, 0xb2, 0x70, 0x3e, 0xfe, 0x0d, 0xe6, 0x0d, 0xe6, 0x0d, 0xe6, 0x0d, 0xe6, 0x0d,
		0xe6, 0x0d, 0xe6, 0x0d, 0xe6, 0x0d, 0xe6, 0x0d, 0xe6, 0x0d, 0xe6, 0x9d, 0x67, 0xe6, 0xad, 0x84,
		0xcd, 0x19, 0xfe, 0x9e, 0x1f, 0x0e, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c,
		0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x1c, 0x3c, 0x5f, 0x1c, 0x3c, 0x12, 0x52, 0x44,
		0xdf, 0x46, 0x3b, 0x7e, 0x39, 0x4b, 0x51, 0x7e, 0x32, 0x2c, 0x38, 0x39, 0x38, 0x39, 0x38, 0x39,
		0x38, 0x39, 0x38, 0x39, 0x38, 0x39, 0x38, 0x39, 0x38, 0x39, 0x38, 0x39, 0x38, 0x79, 0x7e, 0x39,
		0x39, 0x3b, 0x1b, 0x07, 0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x07,
		0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x07, 0x0f, 0x67, 0x2c, 0x53, 0x59, 0x3f, 0x2a, 0x18,
		0x39, 0x18, 0x39, 0x18, 0x39, 0x18, 0x39, 0x18, 0x39, 0x18, 0x39, 0x18, 0x39, 0x18, 0x39, 0x18,
		0x39, 0x18, 0x79, 0xbe, 0x18, 0xb9, 0x8c, 0x44, 0x37, 0x12, 0x92, 0x69, 0xbf, 0xe6, 0xf2, 0x68,
		0x60, 0xe0, 0x60, 0xe0, 0x60, 0xe0, 0x60, 0xe0, 0x60, 0xe0, 0x60, 0xe0, 0x60, 0xe0, 0x60, 0xe0,
		0x60, 0xe0, 0x60, 0xe0, 0x39, 0x62, 0xe0, 0x41, 0x5f, 0x31, 0x35, 0xea, 0x59, 0x1a, 0x09, 0xcc,
		0x1b, 0xcc, 0x1b, 0xcc, 0x1b, 0xcc, 0x1b, 0xcc, 0x1b, 0xcc, 0x1b, 0xcc, 0x1b, 0xcc, 0x1b, 0xcc,
		0x1b, 0xcc, 0x3b, 0x67, 0xcc, 0x9b, 0xab, 0x55, 0xcf, 0x8a, 0xb1, 0xc0, 0xbe, 0xc1, 0xbe, 0xc1,
		0xbe, 0xc1, 0xbe, 0xc1, 0xbe, 0xc1, 0xbe, 0xc1, 0xbe, 0xc1, 0xbe, 0xc1, 0xbe, 0xc1, 0xbe, 0x73,
		0xc6, 0xbe, 0x59, 0x9b, 0xf5, 0xac, 0x1b, 0x10, 0x3c, 0x1c, 0x3c, 0x1c, 0x3c, 0x1c, 0x3c, 0x1c,
		0x3c, 0x1c, 0x3c, 0x1c, 0x3c, 0x1c, 0x3c, 0x1c, 0x3c, 0x1c, 0x3c, 0x3c, 0x8f, 0x3c, 0x9c, 0x91,
		0x81, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83,
		0x7b, 0x83, 0x7b, 0x83, 0x7b, 0xe7, 0x9a, 0x7b, 0x33, 0x9d, 0x84, 0xb2, 0x66, 0x3c, 0xb0, 0x70,
		0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70, 0xb0, 0x70,
		0xb0, 0xf0, 0x9c, 0xb1, 0x70, 0x13, 0x2d, 0x7b, 0x7e, 0x31, 0x2e, 0x58, 0x39, 0x58, 0x39, 0x58,
		0x39, 0x58, 0x39, 0x58, 0x39, 0x58, 0x39, 0x58, 0x39, 0x58, 0x39, 0x58, 0x39, 0x58, 0x79, 0x8e,
		0x59, 0x39, 0x3f, 0x1f, 0x07, 0x13, 0x07, 0x13, 0x07, 0x13, 0x07, 0x13, 0x07, 0x13, 0x07, 0x13,
		0x07, 0x13, 0x07, 0x13, 0x07, 0x13, 0x07, 0x13, 0x07, 0x13, 0xf7, 0x39, 0x8b, 0x55, 0xd0, 0xb7,
		0x07, 0x9c, 0x1c, 0x9c, 0x1c, 0x9c, 0x1c, 0x9c, 0x1c, 0x9c, 0x1c, 0x9c, 0x1c, 0x9c, 0x1c, 0x9c,
		0x1c, 0x9c, 0x1c, 0x9c, 0x3c, 0xe6, 0xe4, 0x8c, 0x8d, 0x7b, 0x56, 0x0f, 0x07, 0x0e, 0x0e, 0x0e,
		0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x0e,
		0x9e, 0x23, 0x0e, 0x3e, 0xde, 0x49, 0xe9, 0xf6, 0x44, 0xd0, 0x57, 0x84, 0xdc, 0x7b, 0x7e, 0x18,
		0x70, 0x6e, 0x70, 0x6e, 0x70, 0x6e, 0x70, 0x6e, 0x70, 0x6e, 0x70, 0x6e, 0x70, 0x6e, 0x70, 0x6e,
		0x70, 0x6e, 0x70, 0xee, 0x1c, 0x71, 0xee, 0xc8, 0x56, 0xc2, 0xf2, 0xdc, 0x9e, 0xab, 0x44, 0x87,
		0x21, 0xee, 0xbd, 0x7a, 0x38, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70,
		0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0xf0, 0x3c, 0x71, 0xf0, 0xd9, 0xa2, 0x6c, 0xf2,
		0xf0, 0xf7, 0xca, 0xd1, 0xc0, 0xc0, 0xc1, 0xc0, 0xc1, 0xc0, 0xc1, 0xc0, 0xc1, 0xc0, 0xc1, 0xc0,
		0xc1, 0xc0, 0xc1, 0xc0, 0xc1, 0xc0, 0xc1, 0xc0, 0x93, 0xce, 0xc0, 0xdf, 0x25, 0x68, 0x4d, 0x16,
		0x4e, 0x7c, 0x3f, 0x50, 0x23, 0x52, 0xad, 0x75, 0x19, 0x16, 0xa4, 0xf3, 0x24, 0x7a, 0x76, 0x68,
		0xab, 0xa7, 0xa1, 0x47, 0x2d, 0x06, 0xa1, 0xf0, 0x9d, 0x11, 0x0b, 0xb6, 0x7c, 0xa1, 0xfe, 0x0e,
		0xa2, 0xaf, 0x96, 0xeb, 0x4b, 0x65, 0xfb, 0x8e, 0x28, 0x2e, 0xbe, 0x21, 0x97, 0xde, 0x29, 0xf6,
		0x42, 0x4f, 0x16, 0xa5, 0xfb, 0xe8, 0xdb, 0x9e, 0xeb, 0x3f, 0x5a, 0x61, 0x14, 0xa8, 0xc0, 0x09,
		0x3c, 0x59, 0x1c, 0x12, 0x20, 0x4b, 0x89, 0xe2, 0xa3, 0x17, 0x3c, 0xd8, 0x5e, 0x51, 0x2a, 0x5b,
		0x89, 0x62, 0xec, 0xbf, 0x75, 0xaa, 0x83, 0x82, 0x54, 0x51, 0xdf, 0x51, 0x7e, 0xcc, 0x10, 0x2e,
		0xc7, 0x37, 0x78, 0x16, 0xdf, 0x5f, 0xfb, 0x22, 0xf4, 0x64, 0xfb, 0x76, 0x72, 0x7f, 0xd7, 0x93,
		0xdb, 0x6b, 0xdf, 0xc8, 0x6f, 0xe1, 0x9d, 0x68, 0xff, 0x73, 0x74, 0x77, 0xed, 0xcf, 0x93, 0xfb,
		0x7a, 0x97, 0x0c, 0x3b, 0xda, 0xed, 0x0a, 0x3b, 0x5a, 0xa0, 0x6e, 0xcb, 0x33, 0x69, 0x71, 0xbb,
		0x4d, 0xe8, 0xf6, 0xd3, 0xb0, 0xdd, 0x37, 0xb7, 0x9c, 0x38, 0x5d, 0x13, 0x66, 0x66, 0xa2, 0x76,
		0xc0, 0x02, 0x1d, 0x6b, 0x7f, 0x3b, 0x0b, 0x79, 0xfb, 0xfc, 0x6e, 0x31, 0xb7, 0x05, 0x77, 0x08,
		0x4a, 0x5d, 0xdb, 0x11, 0x96, 0xad, 0x54, 0xe4, 0x3e, 0xf4, 0xd5, 0x0e, 0x99, 0xd4, 0xa9, 0x88,
		0x5a, 0x79, 0xd5, 0x2d, 0x2d, 0x2f, 0xe6, 0x6f, 0xe5, 0x2d, 0xbf, 0xbe, 0x6b, 0xf8, 0x45, 0x47,
		0x98, 0x45, 0x63, 0x38, 0x45, 0x57, 0xd8, 0x44, 0x7b, 0x78, 0x44, 0x7b, 0x18, 0x44, 0x6f, 0xb8,
		0x83, 0x17, 0x2d, 0x4f, 0xdd, 0x68, 0x37, 0x83, 0x99, 0x2e, 0xa0, 0xdd, 0x27, 0x7a, 0x69, 0x4d,
		0xee, 0x3a, 0xd1, 0xbb, 0x2d, 0x48, 0xed, 0x71, 0x51, 0x9d, 0x71, 0x50, 0x82, 0xb8, 0xa7, 0xee,
		0x38, 0x27, 0x59, 0x5c, 0x93, 0x2c, 0x8e, 0x49, 0x13, 0xb7, 0x34, 0xcb, 0x5f, 0x77, 0x5d, 0xe0,
		0xd3, 0x0b, 0xd9, 0x7d, 0xf5, 0x24, 0x7c, 0xe5, 0x3a, 0x7a, 0x65, 0xd8, 0xd4, 0x90, 0x17, 0xae,
		0xaf, 0x69, 0x46, 0xf5, 0x40, 0x80, 0x76, 0x28, 0xa0, 0x80, 0x04, 0x42, 0x68, 0xa0, 0x82, 0x08,
		0x72, 0xa8, 0x20, 0x87, 0x0c, 0x5a, 0xe8, 0x48, 0x66, 0x30, 0x46, 0x17, 0xa4, 0x4c, 0x2f, 0xe8,
		0x4c, 0x56, 0x15, 0x51, 0x4e, 0x36, 0xbe, 0x3e, 0x4d, 0x16, 0xb6, 0x8c, 0x2c, 0x2c, 0xb2, 0xb0,
		0x49, 0x82, 0x22, 0x1e, 0x48, 0xd2, 0x0b, 0x4d, 0x9a, 0x21, 0x8a, 0x0c, 0xaa, 0xd6, 0xb0, 0x21,
		0xeb, 0xab, 0x78, 0xa6, 0xb3, 0xcc, 0xd5, 0x0c, 0x69, 0x34, 0x26, 0x91, 0xe5, 0xd0, 0x66, 0xa2,
		0xc8, 0x20, 0x8e, 0x03, 0xea, 0x18, 0x21, 0x8f, 0x0b, 0xfa, 0xd8, 0x21, 0x90, 0x1d, 0x0a, 0x79,
		0x21, 0x91, 0x06, 0x1a, 0x89, 0x20, 0x72, 0xfa, 0x68, 0xc8, 0x0a, 0x56, 0x96, 0x56, 0x8c, 0x54,
		0x91, 0xeb, 0x3f, 0x52, 0x2e, 0x98, 0x09, 0x35, 0x3b, 0x24, 0x1c, 0xe3, 0x5c, 0xf8, 0x8f, 0xa3,
		0xdc, 0xc0, 0x3d, 0xa9, 0xc9, 0xd2, 0x2e, 0xf9, 0x3d, 0xae, 0xba, 0x16, 0x26, 0xd7, 0xb2, 0x34,
		0xdc, 0xb4, 0xd8, 0x81, 0x69, 0x3c, 0xc6, 0x0a, 0x07, 0x62, 0x40, 0x98, 0x37, 0x11, 0x86, 0xfa,
		0x17, 0xd3, 0x26, 0x72, 0x50, 0xc9, 0xb0, 0x8d, 0xbc, 0x4b, 0xe7, 0xd5, 0x5b, 0x29, 0xa9, 0xe2,
		0x21, 0x58, 0x83, 0x05, 0xe1, 0xdb, 0x0f, 0x9e, 0xa0, 0x97, 0x15, 0xf1, 0x38, 0x44, 0xb4, 0xe2,
		0x54, 0x74, 0xed, 0xbe, 0x37, 0x22, 0x5c, 0x5d, 0xdb, 0x93, 0x02, 0x92, 0x05, 0x92, 0x05, 0x92,
		0x05, 0x92, 0x25, 0x5d, 0x92, 0xe5, 0x21, 0x08, 0x3c, 0x61, 0xfb, 0x1c, 0x9a, 0xa5, 0x9c, 0x16,
		0x97, 0x97, 0xe8, 0xc0, 0x1f, 0x51, 0xc1, 0xe8, 0xf4, 0xfa, 0xcc, 0xd5, 0x61, 0xab, 0xca, 0x94,
		0x5e, 0xdf, 0x2c, 0xce, 0x47, 0x06, 0x8b, 0x71, 0xbe, 0x23, 0x07, 0x7b, 0xfb, 0xc6, 0x75, 0x8d,
		0x64, 0x89, 0xa3, 0xf1, 0xe5, 0x53, 0x96, 0x37, 0xaa, 0x20, 0x6f, 0xc4, 0xc8, 0x44, 0x90, 0x37,
		0xca, 0xa2, 0xfb, 0x40, 0xde, 0x08, 0x22, 0x0c, 0x22, 0x0c, 0x22, 0x0c, 0x22, 0x2c, 0x41, 0x22,
		0x0c, 0x79, 0xa3, 0x37, 0xfc, 0x41, 0xde, 0x68, 0xa7, 0xe1, 0x90, 0x37, 0xd2, 0x63, 0x22, 0xc8,
		0x1b, 0xa5, 0xdb, 0x46, 0x90, 0x37, 0xa2, 0x0d, 0xa2, 0x21, 0x6f, 0xb4, 0x4e, 0x81, 0x21, 0x6f,
		0x04, 0xc9, 0x02, 0xc9, 0x02, 0xc9, 0x92, 0x6a, 0xc9, 0x82, 0xbc, 0x11, 0xf1, 0x15, 0x91, 0x37,
		0xd2, 0x98, 0x37, 0xd2, 0x70, 0x4a, 0x04, 0xdd, 0x6c, 0xe3, 0x40, 0x1a, 0xd3, 0xf6, 0x91, 0x98,
		0x83, 0x6a, 0xce, 0x26, 0x37, 0xd8, 0x3e, 0x99, 0xbf, 0xc1, 0xa4, 0x9c, 0x58, 0xa3, 0x61, 0x33,
		0xf6, 0x83, 0xed, 0x77, 0xfe, 0x76, 0x3b, 0xea, 0xc9, 0x9a, 0x39, 0x51, 0x54, 0xea, 0xdf, 0x76,
		0xbb, 0x66, 0x1c, 0x6c, 0xbf, 0x4d, 0x20, 0x5b, 0xc6, 0xf6, 0x5b, 0x33, 0x6c, 0x37, 0xe3, 0xdb,
		0x6f, 0x57, 0x42, 0x00, 0x5d, 0x51, 0xc5, 0xea, 0xe1, 0x50, 0x64, 0x81, 0x22, 0x0b, 0xf3, 0x72,
		0x1d, 0x45, 0x16, 0x8c, 0x5a, 0x8b, 0xac, 0xc8, 0x22, 0x8c, 0xdc, 0x20, 0x72, 0x15, 0x43, 0x69,
		0xc5, 0x74, 0x24, 0x44, 0x27, 0x11, 0x9d, 0x44, 0x74, 0x12, 0xd1, 0xc9, 0x54, 0x45, 0x27, 0x3d,
		0x61, 0x77, 0x23, 0xd1, 0xe5, 0x88, 0x4e, 0x36, 0x08, 0xc7, 0xb8, 0x8e, 0xa3, 0x25, 0x1f, 0x3f,
		0xc6, 0x27, 0xeb, 0x4e, 0x51, 0x39, 0xc7, 0x59, 0x40, 0x9a, 0xca, 0xe8, 0x25, 0x13, 0xa2, 0xa8,
		0x90, 0x26, 0x26, 0xf1, 0xf0, 0x7e, 0xf0, 0x7e, 0xf0, 0x7e, 0x49, 0xf5, 0x7e, 0x54, 0xa2, 0x60,
		0x3a, 0x80, 0xed, 0x28, 0xf7, 0x9b, 0x98, 0x8b, 0x76, 0x5a, 0xa3, 0xa3, 0xd8, 0xe9, 0x0d, 0x7b,
		0x5a, 0x90, 0xbd, 0xf6, 0x16, 0x3e, 0x64, 0xa2, 0xc3, 0x04, 0x35, 0xb0, 0x72, 0x02, 0xac, 0x01,
		0xa0, 0xe5, 0x06, 0x5c, 0x63, 0xc0, 0x6b, 0x0c, 0x80, 0xcd, 0x00, 0x31, 0x2d, 0x20, 0x13, 0x03,
		0x33, 0x9f, 0x3c, 0x59, 0x5a, 0x71, 0x8f, 0x76, 0xff, 0x51, 0x90, 0xb4, 0xb9, 0x5a, 0x07, 0x90,
		0x87, 0x0c, 0x43, 0xd1, 0xb6, 0xc1, 0x5a, 0xfc, 0xc3, 0x83, 0x20, 0x7b, 0xdc, 0x65, 0xe1, 0xcc,
		0x9e, 0x6d, 0x69, 0x58, 0xa6, 0x36, 0x5a, 0x4b, 0xe3, 0x1a, 0x28, 0x05, 0x66, 0xc2, 0x97, 0x79,
		0x53, 0x62, 0x2c, 0x1f, 0x4f, 0x8a, 0x29, 0xf1, 0xb7, 0xe5, 0x4a, 0x94, 0x75, 0xbd, 0xcb, 0xc6,
		0x28, 0xad, 0x94, 0x16, 0xce, 0x53, 0x36, 0xd1, 0xb3, 0xbf, 0xd9, 0xae, 0x67, 0x3f, 0x78, 0xc2,
		0x9a, 0xa6, 0x80, 0x19, 0x35, 0xd7, 0x8a, 0xc1, 0xa1, 0xb6, 0xa0, 0xb6, 0xa0, 0xb6, 0xa0, 0xb6,
		0xa0, 0xb6, 0x56, 0x96, 0xe7, 0xf4, 0x1e, 0x42, 0x99, 0x31, 0xd1, 0xf5, 0xc5, 0x1f, 0x13, 0x9a,
		0xc2, 0x05, 0xd3, 0x6f, 0x83, 0xca, 0x83, 0xca, 0x83, 0xca, 0x83, 0xca, 0x83, 0xca, 0x83, 0xca,
		0xcb, 0x87, 0xca, 0x7b, 0x72, 0x1f, 0x9f, 0xfe, 0xb6, 0x95, 0x88, 0xac, 0x9e, 0x1d, 0x7d, 0xe5,
		0x13, 0x78, 0x0b, 0xe3, 0x42, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb,
		0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0x41, 0xdb, 0xed, 0x60,
		0x56, 0xe4, 0x1b, 0xab, 0x96, 0x18, 0x0b, 0xf1, 0x06, 0x2b, 0xe8, 0x39, 0xe8, 0x39, 0xe8, 0x39,
		0xe8, 0xb9, 0x94, 0xea, 0xb9, 0xbe, 0xaf, 0x7f, 0xeb, 0xfc, 0xcf, 0xe0, 0xb1, 0x7c, 0xc4, 0x30,
		0x56, 0xfc, 0x18, 0x33, 0xa7, 0xaa, 0xa6, 0x93, 0xe6, 0xfa, 0xea, 0xb0, 0xc0, 0xc8, 0xc1, 0xe3,
		0xc9, 0x63, 0xe4, 0xa0, 0xcc, 0xd2, 0x98, 0x7f, 0x32, 0x8d, 0x4a, 0x65, 0xc3, 0x3a, 0xc7, 0xb4,
		0x74, 0x4e, 0x82, 0xc8, 0x31, 0x20, 0xa5, 0x8d, 0x4a, 0xea, 0xa4, 0x99, 0x5c, 0x23, 0xc7, 0x26,
		0xf7, 0x2e, 0x9b, 0xa3, 0xb5, 0xde, 0x65, 0x68, 0xc1, 0x1a, 0xa0, 0x15, 0xc2, 0xef, 0xf7, 0x44,
		0x44, 0x71, 0x98, 0xd2, 0x46, 0xcc, 0xb0, 0xca, 0x38, 0x66, 0xd3, 0xef, 0xf7, 0x86, 0x10, 0x88,
		0x50, 0x93, 0xd9, 0xfb, 0xa7, 0x0c, 0x35, 0x8d, 0x37, 0xc7, 0x8a, 0x8e, 0x89, 0x5a, 0xf1, 0x15,
		0x63, 0x23, 0xfc, 0xf4, 0xa6, 0x81, 0x10, 0x7e, 0xd2, 0x6b, 0x1e, 0x08, 0x3f, 0x21, 0xfc, 0xb4,
		0x61, 0xdc, 0x04, 0xe5, 0x04, 0x7a, 0x86, 0x42, 0x39, 0x41, 0x9a, 0x63, 0x24, 0x28, 0x27, 0x40,
		0x39, 0x41, 0x46, 0x4c, 0x09, 0xe5, 0x04, 0xd0, 0x78, 0x06, 0x35, 0x5e, 0xaa, 0x4e, 0x8f, 0x22,
		0x6e, 0xdf, 0x31, 0x1d, 0x27, 0x59, 0x6d, 0x1a, 0x56, 0x9f, 0xe1, 0xbf, 0xfa, 0x6d, 0x8a, 0x26,
		0x1f, 0x74, 0xb6, 0x92, 0xec, 0x03, 0x8c, 0xff, 0x35, 0xea, 0xde, 0x4c, 0x55, 0xa3, 0x52, 0x38,
		0x77, 0xa5, 0x3a, 0x51, 0x8a, 0xe8, 0x90, 0xe4, 0x0b, 0xd7, 0x6f, 0x7a, 0x62, 0xa8, 0xb1, 0x24,
		0x8d, 0x73, 0x1b, 0x3a, 0xeb, 0x99, 0x11, 0x78, 0xdc, 0x58, 0xe1, 0x2a, 0xea, 0x88, 0x48, 0x74,
		0x3e, 0x0d, 0x67, 0xc6, 0xef, 0x7b, 0x1e, 0xba, 0x0d, 0xa5, 0x12, 0xa6, 0x0a, 0x24, 0x47, 0xa2,
		0x6a, 0xe9, 0x39, 0xf3, 0x69, 0x72, 0xbf, 0x37, 0x33, 0xb7, 0x8b, 0xa6, 0x49, 0xe6, 0xcc, 0x3d,
		0x15, 0x66, 0x9e, 0xa5, 0xde, 0x44, 0xce, 0x24, 0x8c, 0xac, 0xb9, 0x17, 0x51, 0x7c, 0x5d, 0xf4,
		0x1e, 0xda, 0xf9, 0x49, 0xa2, 0xf7, 0xd0, 0xeb, 0x00, 0xe8, 0x3d, 0x94, 0xe0, 0xde, 0x43, 0xaf,
		0x58, 0xea, 0x76, 0xe8, 0x5a, 0x0e, 0xcd, 0x8d, 0x42, 0xd3, 0x69, 0xa8, 0x44, 0xd5, 0x69, 0xa8,
		0x84, 0x4e, 0x43, 0x0c, 0x30, 0xc4, 0x06, 0x47, 0x6c, 0xb0, 0xc4, 0x03, 0x4f, 0xe9, 0x10, 0xea,
		0x64, 0xa9, 0x31, 0x0e, 0x84, 0x99, 0x23, 0x33, 0x87, 0x10, 0x1a, 0x10, 0x1a, 0xb1, 0xd0, 0x88,
		0xe9, 0x72, 0x86, 0x84, 0xc5, 0x93, 0xf0, 0xbc, 0x80, 0xa0, 0xc9, 0x69, 0x7c, 0x5d, 0x08, 0x0b,
		0x08, 0x0b, 0x08, 0x8b, 0x7c, 0x08, 0x0b, 0xcd, 0x31, 0x0a, 0xda, 0x58, 0x05, 0x11, 0xb4, 0x40,
		0x4c, 0x40, 0x4c, 0x40, 0x4c, 0xa4, 0xa6, 0x6d, 0xe9, 0x88, 0xa5, 0x58, 0x23, 0x7e, 0xf7, 0xcd,
		0xf6, 0xe8, 0x7b, 0xb7, 0x2d, 0x8c, 0x47, 0xd5, 0xd0, 0x49, 0x74, 0xed, 0xbe, 0x37, 0x32, 0x98,
		0xa3, 0x52, 0xa9, 0x84, 0x4e, 0xa9, 0xec, 0x48, 0xca, 0x88, 0xa8, 0x5c, 0xc8, 0xca, 0x8e, 0xb0,
		0xec, 0x48, 0xcb, 0x8b, 0xb8, 0x34, 0xc8, 0x4b, 0x84, 0xc0, 0xf4, 0x61, 0x9d, 0xa5, 0x15, 0xd3,
		0x77, 0x7d, 0x55, 0xae, 0x33, 0x34, 0x4a, 0xad, 0x13, 0x0e, 0xc1, 0x53, 0x60, 0xcc, 0x50, 0x7f,
		0xce, 0x59, 0x50, 0xcc, 0x5c, 0xfd, 0xf9, 0x5a, 0xf5, 0x59, 0x2a, 0x71, 0x0d, 0x69, 0xa0, 0xba,
		0x93, 0xa1, 0x66, 0x98, 0xb5, 0x56, 0xd8, 0x94, 0x95, 0xd4, 0x4b, 0xd9, 0x36, 0x93, 0x94, 0x16,
		0xcd, 0xb6, 0x72, 0xdc, 0x78, 0x3a, 0x12, 0xdd, 0x48, 0xc8, 0x27, 0x2b, 0x12, 0x9d, 0xbe, 0x43,
		0x5a, 0x89, 0x3b, 0xb3, 0x5f, 0x73, 0x71, 0x48, 0x7a, 0x2d, 0x33, 0x64, 0x7e, 0xd0, 0x32, 0xd0,
		0x32, 0xd0, 0x32, 0xd0, 0x32, 0xe9, 0xd2, 0x32, 0x0f, 0x41, 0xe0, 0x09, 0xdb, 0x67, 0x10, 0x33,
		0xe5, 0x32, 0xb6, 0x19, 0xe8, 0x58, 0x35, 0xb9, 0xaa, 0x12, 0x1f, 0xe7, 0x6a, 0xb5, 0x26, 0xb7,
		0xf5, 0x4f, 0xb3, 0xc6, 0x29, 0x2e, 0x8c, 0x37, 0xe4, 0x90, 0x25, 0xaa, 0xc6, 0x97, 0x4f, 0x59,
		0x9e, 0xaa, 0x82, 0x3c, 0x15, 0x23, 0x03, 0x41, 0x9e, 0x2a, 0x8b, 0x6e, 0x03, 0x79, 0xaa, 0x6d,
		0xb5, 0x1d, 0xf2, 0x54, 0xd0, 0x76, 0xd0, 0x76, 0xd0, 0x76, 0xe9, 0xd3, 0x76, 0xc8, 0x53, 0x6d,
		0xfc, 0x07, 0x79, 0xaa, 0x9d, 0x86, 0x43, 0x9e, 0x4a, 0x9b, 0x95, 0x20, 0x4f, 0x95, 0x7a, 0x33,
		0x41, 0x9e, 0x8a, 0xf4, 0x7e, 0x91, 0xa7, 0xda, 0x5a, 0xcb, 0x20, 0x4f, 0x05, 0x2d, 0x03, 0x2d,
		0x03, 0x2d, 0x93, 0x3e, 0x2d, 0x83, 0x3c, 0x15, 0xf1, 0x15, 0x91, 0xa7, 0xd2, 0x90, 0xa7, 0x22,
		0x38, 0x4e, 0x0d, 0xbb, 0x72, 0xd3, 0x6f, 0x17, 0x05, 0xad, 0x09, 0x42, 0x2d, 0xe7, 0x56, 0xfd,
		0x3e, 0xbe, 0xb1, 0x0c, 0x6d, 0x17, 0x26, 0x39, 0x3c, 0x84, 0x72, 0x4b, 0xbf, 0x66, 0xc6, 0x8c,
		0xad, 0xc3, 0xd8, 0x3a, 0x6c, 0x82, 0xc1, 0x26, 0xcb, 0xad, 0x68, 0x67, 0xa4, 0x53, 0x8b, 0xf5,
		0x84, 0xdd, 0x8d, 0x44, 0x57, 0xa7, 0xc5, 0x4e, 0x18, 0xa7, 0xc6, 0x06, 0x56, 0x85, 0xeb, 0xd8,
		0xf3, 0x7d, 0xfc, 0x38, 0x66, 0x23, 0xc5, 0x39, 0xe4, 0xca, 0x24, 0xde, 0x0f, 0x67, 0x85, 0x10,
		0xf0, 0xf5, 0x4d, 0x7a, 0xde, 0x0f, 0x8b, 0x70, 0xbb, 0xc0, 0x7b, 0x03, 0x78, 0xef, 0x76, 0x71,
		0x50, 0xc4, 0x86, 0x17, 0xc4, 0x41, 0x11, 0x84, 0xf0, 0x42, 0x09, 0x33, 0xe4, 0x70, 0x43, 0x0d,
		0x3b, 0x6c, 0xf0, 0xc3, 0x06, 0x43, 0x1c, 0x70, 0x94, 0x8e, 0x58, 0x18, 0x59, 0xf1, 0xdd, 0x94,
		0xa4, 0xd0, 0xa7, 0xab, 0x5e, 0x87, 0x42, 0xfe, 0x88, 0x1b, 0xd4, 0xd8, 0xc0, 0x8d, 0x0b, 0xe4,
		0xd8, 0xc1, 0x8e, 0x1d, 0xf4, 0x38, 0xc1, 0x8f, 0x06, 0x04, 0x89, 0xc0, 0x90, 0x4e, 0xa9, 0x33,
		0x2a, 0x77, 0x0e, 0x25, 0xbf, 0x56, 0xd9, 0x17, 0x47, 0x66, 0x74, 0x3c, 0x05, 0x64, 0xb9, 0xf8,
		0x46, 0xfc, 0xdf, 0xa3, 0x18, 0x71, 0x8e, 0x6b, 0x3a, 0x64, 0xff, 0x81, 0xd1, 0x3f, 0xce, 0x8d,
		0x06, 0x17, 0x09, 0x17, 0x09, 0x17, 0x09, 0x17, 0x09, 0x17, 0x99, 0x50, 0x17, 0x79, 0xff, 0xea,
		0x22, 0xff, 0x9f, 0xd3, 0x8f, 0x22, 0xe1, 0xab, 0xf7, 0xfb, 0xc5, 0x8f, 0x1f, 0x5f, 0xa3, 0xe5,
		0xad, 0xf8, 0x2b, 0xb3, 0xb8, 0x2e, 0x57, 0xbc, 0x37, 0xbd, 0x72, 0x47, 0x7c, 0x47, 0x23, 0x35,
		0x1d, 0x93, 0xd8, 0xfc, 0x3e, 0x2a, 0xd4, 0xd5, 0x5f, 0xf0, 0x4f, 0x1f, 0xb0, 0x09, 0x1c, 0x4b,
		0x7c, 0x57, 0xc7, 0x4a, 0x78, 0xa2, 0x27, 0x54, 0xf4, 0x6c, 0x05, 0xbe, 0xe5, 0x3c, 0x8d, 0x76,
		0x30, 0xb0, 0x04, 0x71, 0xba, 0xb6, 0x27, 0x39, 0xa2, 0x38, 0x49, 0x0f, 0xe0, 0xb4, 0x50, 0xcc,
		0xb4, 0x43, 0xd1, 0xca, 0x5c, 0xea, 0x0b, 0x7b, 0xef, 0xb5, 0x29, 0x04, 0xec, 0xbd, 0x47, 0xe8,
		0x3f, 0x11, 0x54, 0x1f, 0xa1, 0x7f, 0x36, 0x32, 0x83, 0xd0, 0x3f, 0xe2, 0x1a, 0x88, 0x6b, 0x20,
		0xae, 0x81, 0xb8, 0x06, 0xe2, 0x1a, 0x0c, 0x71, 0x0d, 0x84, 0xfe, 0xf7, 0x10, 0xfa, 0x87, 0x8b,
		0x84, 0x8b, 0x84, 0x8b, 0x84, 0x8b, 0x84, 0x8b, 0x44, 0xe8, 0x3f, 0x5d, 0x6a, 0x39, 0xcf, 0x71,
		0x56, 0xec, 0x1d, 0x35, 0x6d, 0x26, 0x49, 0x36, 0x8f, 0x04, 0x6e, 0x21, 0x9d, 0xbe, 0xba, 0x11,
		0xdd, 0x2c, 0x6d, 0x2c, 0x1a, 0x4e, 0x94, 0xd0, 0x7b, 0x08, 0xcc, 0xd4, 0xd9, 0xce, 0x5c, 0x1b,
		0x5b, 0x8a, 0x74, 0x10, 0x7d, 0x6c, 0x22, 0x65, 0xa2, 0xee, 0xe8, 0x3f, 0xbb, 0xc3, 0x05, 0xb1,
		0xad, 0x88, 0x21, 0xd6, 0x80, 0x73, 0xbd, 0x93, 0x11, 0x4d, 0xc0, 0xb9, 0xde, 0x8c, 0x8a, 0x89,
		0x2c, 0xbf, 0xf8, 0xf0, 0x1c, 0xda, 0x52, 0x5a, 0x41, 0xa8, 0xdc, 0x9e, 0xfb, 0x7f, 0x82, 0xf1,
		0x84, 0xef, 0xb5, 0x23, 0x23, 0xb4, 0xca, 0x0d, 0x7b, 0x8c, 0xf0, 0xc7, 0x05, 0x83, 0xec, 0x70,
		0xc8, 0x0e, 0x8b, 0xbc, 0xf0, 0x48, 0x17, 0xaa, 0xda, 0xc3, 0x21, 0xdc, 0x6f, 0xc1, 0x2f, 0x1c,
		0xc2, 0xbd, 0xc1, 0x0f, 0xc9, 0xc3, 0x21, 0xdc, 0x38, 0x81, 0x7b, 0x37, 0x13, 0xc9, 0xc3, 0x09,
		0xdc, 0xb5, 0xda, 0x41, 0x0d, 0x27, 0x70, 0x27, 0xed, 0xea, 0x79, 0x3e, 0x81, 0xdb, 0x73, 0xfd,
		0xaf, 0xd6, 0x6b, 0x78, 0xd4, 0x92, 0xea, 0xd9, 0x13, 0x56, 0x24, 0xfe, 0xb7, 0x2f, 0xa4, 0x12,
		0x1d, 0x7a, 0xd9, 0xf1, 0xab, 0x1b, 0xa0, 0x3f, 0x9d, 0x3b, 0x70, 0xac, 0x5e, 0xe8, 0x49, 0x75,
		0x7c, 0x7e, 0x76, 0xf9, 0xaf, 0xf6, 0xe5, 0xd5, 0x69, 0xb3, 0x7d, 0x7d, 0x73, 0x75, 0xd7, 0xfc,
		0x7c, 0x77, 0x76, 0x75, 0xd9, 0xbe, 0x69, 0xfe, 0xfb, 0x4b, 0xf3, 0xf6, 0xae, 0x79, 0x0a, 0x1d,
		0x04, 0x1d, 0x04, 0x1d, 0x04, 0x1d, 0x94, 0x2e, 0x1d, 0xe4, 0x76, 0x84, 0xaf, 0x5c, 0xf5, 0xcc,
		0x54, 0x6a, 0x42, 0xc8, 0x6e, 0x0a, 0x67, 0xf1, 0x4f, 0xf9, 0x64, 0x4b, 0x86, 0xf5, 0x39, 0x79,
		0x80, 0x33, 0xae, 0xe0, 0xee, 0xcf, 0xeb, 0x26, 0xf5, 0x2a, 0x1d, 0x51, 0x45, 0x49, 0xae, 0xf9,
		0x78, 0x74, 0xdf, 0xdc, 0x83, 0x1c, 0x79, 0xd7, 0x05, 0xc7, 0x7a, 0x76, 0xd3, 0x3c, 0x2d, 0x64,
		0x41, 0xbe, 0x98, 0x78, 0x96, 0xeb, 0x99, 0x0a, 0x9e, 0xe8, 0x9b, 0x9f, 0xe8, 0x97, 0xcb, 0xf8,
		0x49, 0xb2, 0x3c, 0x3e, 0xd2, 0x11, 0x5a, 0x69, 0x73, 0xb2, 0xa8, 0xb6, 0xd3, 0x7a, 0xfd, 0x64,
		0x95, 0x53, 0xbd, 0x4a, 0x3b, 0x6c, 0x69, 0xd6, 0x05, 0x56, 0xd8, 0xd2, 0x8c, 0xb2, 0x83, 0xa4,
		0xe8, 0x4b, 0x94, 0x1d, 0x30, 0xba, 0x0e, 0x94, 0x1d, 0x20, 0xdc, 0x86, 0x70, 0x1b, 0xc2, 0x6d,
		0x08, 0xb7, 0x25, 0x34, 0xdc, 0x86, 0xb2, 0x83, 0x04, 0x09, 0x7c, 0x94, 0x1d, 0x68, 0x1c, 0x0f,
		0x65, 0x07, 0xa9, 0x35, 0x11, 0x94, 0x1d, 0x24, 0xf2, 0xea, 0x28, 0x3b, 0x40, 0xd9, 0x01, 0xca,
		0x0e, 0xa0, 0x83, 0xa0, 0x83, 0xa0, 0x83, 0xb2, 0xa6, 0x83, 0x50, 0x76, 0xb0, 0xe3, 0x03, 0x44,
		0xd9, 0x81, 0xa6, 0x07, 0x89, 0xb2, 0x03, 0xcd, 0xcf, 0x12, 0x65, 0x07, 0x1a, 0x9f, 0x28, 0xca,
		0x0e, 0xcc, 0x39, 0x59, 0x94, 0x1d, 0x68, 0xbd, 0x7e, 0x62, 0xcb, 0x0e, 0x70, 0xc2, 0x8f, 0x69,
		0x1b, 0x49, 0xac, 0x6d, 0x24, 0xf0, 0x78, 0x9f, 0xeb, 0xd7, 0x9b, 0xcb, 0xd0, 0xe1, 0x3e, 0x7a,
		0x0b, 0x62, 0x48, 0x0a, 0x61, 0xc8, 0x8e, 0xf4, 0xa9, 0xe0, 0x48, 0x9f, 0x34, 0x45, 0x30, 0x70,
		0xa4, 0x4f, 0xb2, 0x8f, 0xf4, 0xe9, 0x0f, 0xa1, 0x52, 0x52, 0x1e, 0xea, 0x13, 0x8f, 0x80, 0xfa,
		0x3a, 0xd4, 0xd7, 0x99, 0x83, 0x21, 0x36, 0x38, 0xe2, 0x81, 0xa5, 0x74, 0x68, 0x24, 0xb2, 0xfa,
		0x3a, 0x11, 0x45, 0x01, 0x01, 0x68, 0x2d, 0x2d, 0xa8, 0x78, 0x1c, 0xda, 0x9c, 0x51, 0x19, 0x39,
		0x23, 0x93, 0xd0, 0xc6, 0x05, 0x71, 0xec, 0x50, 0xc7, 0x0e, 0x79, 0xbc, 0xd0, 0x47, 0x1c, 0xce,
		0xa2, 0xca, 0x58, 0x13, 0x41, 0xe2, 0x74, 0x00, 0xbb, 0xaf, 0x9e, 0x84, 0xaf, 0x5c, 0x67, 0x14,
		0x77, 0xb0, 0xba, 0xb6, 0xeb, 0xf1, 0xa5, 0x59, 0x56, 0x0d, 0x4e, 0x6c, 0x6b, 0x3c, 0x45, 0x40,
		0xe4, 0x60, 0xca, 0x09, 0xaa, 0x06, 0xc0, 0x95, 0x1b, 0x64, 0x8d, 0x81, 0xad, 0x31, 0xd0, 0x35,
		0x03, 0xbe, 0xb4, 0x20, 0x4c, 0x0c, 0xc6, 0xd3, 0x47, 0x46, 0x9e, 0xc8, 0x5f, 0xa7, 0x8a, 0xeb,
		0x55, 0x8e, 0x35, 0x17, 0x43, 0xe4, 0x21, 0xc3, 0x50, 0x3c, 0xb5, 0xce, 0x93, 0x3f, 0x3c, 0x18,
		0xb2, 0xc7, 0x5d, 0xfb, 0xcc, 0xec, 0xdb, 0x96, 0x86, 0x65, 0xae, 0x85, 0x9e, 0x8e, 0x6b, 0xa0,
		0xd8, 0x95, 0x09, 0x61, 0xe6, 0x4d, 0x89, 0xb1, 0x46, 0x3a, 0x29, 0xa6, 0x54, 0x3e, 0xac, 0x56,
		0xeb, 0x8d, 0x6a, 0xb5, 0xd4, 0x38, 0x68, 0x94, 0x8e, 0x6a, 0xb5, 0x72, 0xbd, 0x5c, 0xcb, 0x91,
		0x75, 0xbd, 0xcb, 0xc6, 0x28, 0xad, 0x94, 0x96, 0x86, 0x13, 0xae, 0xee, 0xc2, 0x83, 0xdd, 0xb1,
		0x9c, 0x27, 0xe1, 0x7c, 0x95, 0xfd, 0x1e, 0x9f, 0xd0, 0x9a, 0x1b, 0x15, 0x0a, 0x0b, 0x0a, 0x0b,
		0x0a, 0x0b, 0x0a, 0x0b, 0x0a, 0x0b, 0x0a, 0x0b, 0x0a, 0x0b, 0x0a, 0x0b, 0x0a, 0x0b, 0x0a, 0x0b,
		0x0a, 0x0b, 0x0a, 0x2b, 0x43, 0x0a, 0x2b, 0xb4, 0x9d, 0xaf, 0x42, 0x59, 0xdd, 0x20, 0xea, 0xd9,
		0x8a, 0x57, 0x66, 0xcd, 0x0f, 0x0d, 0xad, 0x05, 0xad, 0x05, 0xad, 0x05, 0xad, 0x05, 0xad, 0x05,
		0xad, 0x05, 0xad, 0x05, 0xad, 0x05, 0xad, 0x05, 0xad, 0x05, 0xad, 0x05, 0xad, 0x95, 0x3d, 0xad,
		0xe5, 0x09, 0xff, 0x71, 0xb4, 0xc1, 0x90, 0x5f, 0x6b, 0xc5, 0x43, 0x43, 0x6b, 0x41, 0x6b, 0x41,
		0x6b, 0x41, 0x6b, 0x41, 0x6b, 0x41, 0x6b, 0x41, 0x6b, 0x41, 0x6b, 0x41, 0x6b, 0x41, 0x6b, 0x41,
		0x6b, 0x41, 0x6b, 0x65, 0x44, 0x6b, 0x05, 0x7d, 0x65, 0x05, 0x5d, 0x2b, 0x88, 0x3a, 0x22, 0xe2,
		0x93, 0x59, 0x73, 0xa3, 0x42, 0x61, 0x41, 0x61, 0x41, 0x61, 0x41, 0x61, 0x41, 0x61, 0x41, 0x61,
		0x41, 0x61, 0x41, 0x61, 0x41, 0x61, 0x41, 0x61, 0x41, 0x61, 0x41, 0x61, 0x65, 0x44, 0x61, 0x45,
		0xc2, 0x11, 0xee, 0x37, 0xd1, 0xb1, 0x7c, 0xdb, 0xf9, 0xca, 0x27, 0xb1, 0xe6, 0x87, 0x85, 0xc6,
		0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6,
		0x82, 0xc6, 0x82, 0xc6, 0x82, 0xc6, 0xca, 0x88, 0xc6, 0x52, 0x91, 0xed, 0xcb, 0x9e, 0xab, 0x46,
		0x87, 0xfd, 0xf5, 0x23, 0xc6, 0x9e, 0x4e, 0x4b, 0x23, 0x43, 0x69, 0x41, 0x69, 0x41, 0x69, 0x41,
		0x69, 0x41, 0x69, 0x41, 0x69, 0x41, 0x69, 0x41, 0x69, 0x41, 0x69, 0x41, 0x69, 0x41, 0x69, 0x41,
		0x69, 0x65, 0x4d, 0x69, 0xfd, 0x6f, 0x5f, 0xf4, 0x85, 0xd5, 0xed, 0x7b, 0x9e, 0x01, 0xb1, 0x35,
		0x33, 0x38, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16,
		0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x16, 0xf4, 0x56, 0x46, 0xf4, 0x56, 0xdf, 0xff, 0xea,
		0x07, 0x7f, 0xfb, 0x16, 0x6b, 0xed, 0xe0, 0xec, 0xa0, 0xd0, 0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0,
		0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0, 0x57, 0xd0,
		0x57, 0x19, 0xd3, 0x57, 0xbe, 0x11, 0x81, 0x85, 0xbd, 0x59, 0x50, 0x58, 0x50, 0x58, 0x50, 0x58,
		0x50, 0x58, 0x50, 0x58, 0x50, 0x58, 0x50, 0x58, 0x50, 0x58, 0x50, 0x58, 0x50, 0x58, 0x50, 0x58,
		0xec, 0x0a, 0xeb, 0x5d, 0x8a, 0x30, 0xa3, 0x70, 0xe2, 0xfb, 0x81, 0xb2, 0x87, 0xa6, 0x4a, 0x0a,
		0x13, 0x05, 0xe9, 0x3c, 0x89, 0x9e, 0x1d, 0xda, 0xa3, 0x03, 0xe8, 0x0b, 0xc5, 0x20, 0x14, 0xbe,
		0x33, 0x52, 0x39, 0x96, 0x2f, 0xd4, 0xdf, 0x41, 0xf4, 0xd5, 0x72, 0x7d, 0xa9, 0x6c, 0xdf, 0x11,
		0xc5, 0xc5, 0x37, 0xe4, 0xd2, 0x3b, 0xc5, 0x5e, 0xe8, 0xc9, 0xa2, 0x74, 0x1f, 0x7d, 0xdb, 0x73,
		0xfd, 0x47, 0x2b, 0x8c, 0x02, 0x15, 0x38, 0x81, 0x27, 0x8b, 0x43, 0x02, 0x6a, 0x29, 0x51, 0x74,
		0x87, 0x84, 0xa7, 0x6b, 0x3b, 0xc2, 0xb2, 0x95, 0x8a, 0xdc, 0x87, 0xbe, 0x12, 0xf2, 0xf5, 0xcd,
		0xa2, 0x54, 0xb6, 0x12, 0xc5, 0x98, 0x17, 0xc9, 0xa2, 0x88, 0xa2, 0x20, 0x92, 0x84, 0xec, 0xa8,
		0x20, 0x55, 0xd4, 0x77, 0x94, 0x1f, 0x13, 0xb2, 0xcb, 0xf1, 0xef, 0x39, 0x8b, 0x7f, 0x4e, 0xfb,
		0x22, 0xf4, 0x64, 0xfb, 0x76, 0xf2, 0x73, 0xae, 0x27, 0xbf, 0xa6, 0x7d, 0x23, 0xbf, 0x85, 0x77,
		0xa2, 0x7d, 0x36, 0xb9, 0xef, 0xf6, 0xe7, 0xf8, 0x8e, 0xdb, 0xcd, 0xf1, 0x1d, 0xbf, 0x4b, 0x87,
		0x01, 0x13, 0x18, 0x6f, 0xc1, 0x1d, 0xa5, 0x54, 0xad, 0x9e, 0x90, 0xd2, 0x7e, 0x14, 0x92, 0xcc,
		0x7a, 0xa7, 0x2c, 0x7a, 0x71, 0x40, 0xa2, 0x05, 0x49, 0xeb, 0x3b, 0xc9, 0x43, 0x0b, 0x1c, 0x21,
		0x05, 0xc6, 0x50, 0x02, 0x57, 0x08, 0x81, 0x3d, 0x74, 0xc0, 0x1e, 0x32, 0xe0, 0x0d, 0x15, 0xa4,
		0xcb, 0x09, 0x93, 0x87, 0x04, 0x58, 0x43, 0x01, 0x0c, 0x21, 0x00, 0x26, 0xe9, 0xcf, 0x10, 0xa3,
		0xe1, 0x94, 0xfa, 0xcc, 0xba, 0x8c, 0x5b, 0xda, 0x9b, 0x10, 0x5d, 0x0c, 0x52, 0x9e, 0x55, 0xc2,
		0x9b, 0x32, 0x11, 0x73, 0x92, 0xdd, 0x88, 0xd5, 0xa4, 0x54, 0xda, 0xb6, 0xf2, 0xad, 0x37, 0x9e,
		0x84, 0xe7, 0x05, 0xbc, 0x8a, 0x63, 0x61, 0x48, 0x68, 0x0e, 0x68, 0x0e, 0x68, 0x0e, 0x68, 0x0e,
		0x68, 0x0e, 0x68, 0x0e, 0x68, 0x0e, 0x68, 0x0e, 0x68, 0x0e, 0x68, 0x0e, 0x68, 0x8e, 0x2c, 0x6b,
		0x8e, 0xd0, 0x56, 0x4f, 0xd6, 0x28, 0x3f, 0xc5, 0x2b, 0x3c, 0x56, 0x8d, 0x0b, 0xf5, 0x01, 0xf5,
		0x01, 0xf5, 0x01, 0xf5, 0x01, 0xf5, 0x01, 0xf5, 0x01, 0xf5, 0x01, 0xf5, 0x01, 0xf5, 0x01, 0xf5,
		0x01, 0xf5, 0x91, 0x79, 0xf5, 0xc1, 0xaf, 0x3b, 0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38,
		0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38, 0xa0, 0x38, 0xf2, 0xa3,
		0x38, 0x94, 0xb0, 0x4d, 0xa4, 0x3b, 0xe6, 0x87, 0x85, 0xf6, 0x80, 0xf6, 0x80, 0xf6, 0x80, 0xf6,
		0x80, 0xf6, 0x80, 0xf6, 0x80, 0xf6, 0x80, 0xf6, 0x80, 0xf6, 0x80, 0xf6, 0x80, 0xf6, 0xc8, 0xb2,
		0xf6, 0x88, 0x84, 0x14, 0xd1, 0xb7, 0xd1, 0x61, 0x08, 0x26, 0x4a, 0xae, 0x7e, 0x32, 0x3c, 0xb4,
		0x08, 0xb4, 0x08, 0xb4, 0x08, 0xb4, 0x08, 0xb4, 0x08, 0xb4, 0x08, 0xb4, 0x08, 0xb4, 0x08, 0xb4,
		0x08, 0xb4, 0x08, 0xb4, 0x48, 0x5e, 0xb4, 0x88, 0x31, 0x15, 0x02, 0xfd, 0x01, 0xfd, 0x01, 0xfd,
		0x01, 0xfd, 0x01, 0xfd, 0x01, 0xfd, 0x01, 0xfd, 0x01, 0xfd, 0x01, 0xfd, 0x01, 0xfd, 0x01, 0xfd,
		0x91, 0x3b, 0xfd, 0xc1, 0x5f, 0x8e, 0xb5, 0x7e, 0x74, 0x28, 0x11, 0x28, 0x11, 0x28, 0x11, 0x28,
		0x11, 0x28, 0x11, 0x28, 0x11, 0x28, 0x11, 0x28, 0x11, 0x28, 0x11, 0x28, 0x11, 0x28, 0x91, 0x2c,
		0x2b, 0x11, 0x19, 0x89, 0x6e, 0x24, 0x24, 0xf3, 0x3e, 0xf4, 0xe5, 0x51, 0xa1, 0x3c, 0xa0, 0x3c,
		0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c,
		0xa0, 0x3c, 0x32, 0xab, 0x3c, 0x82, 0xbe, 0x62, 0x6e, 0x30, 0xb8, 0x34, 0x22, 0x14, 0x07, 0x14,
		0x07, 0x14, 0x07, 0x14, 0x07, 0x14, 0x07, 0x14, 0x07, 0x14, 0x07, 0x14, 0x07, 0x14, 0x07, 0x14,
		0x07, 0x14, 0x47, 0xa6, 0x15, 0x07, 0x77, 0x8b, 0xc1, 0x15, 0x63, 0x42, 0x75, 0x40, 0x75, 0x40,
		0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40, 0x75, 0x40,
		0x75, 0x64, 0x5a, 0x75, 0x18, 0x69, 0x32, 0xb8, 0x6e, 0x60, 0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x0f,
		0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x0f, 0xe8, 0x8f,
		0xec, 0xeb, 0x0f, 0x03, 0xca, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03,
		0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x03, 0x9a, 0x23, 0x47, 0x9a, 0x83, 0xf9,
		0x64, 0xab, 0x35, 0xe3, 0x42, 0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x40, 0x7d,
		0x40, 0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x64, 0x5a, 0x7d, 0x98, 0x6c, 0x35,
		0xf8, 0x8b, 0xf1, 0xa1, 0x46, 0xa0, 0x46, 0xa0, 0x46, 0xa0, 0x46, 0xa0, 0x46, 0xa0, 0x46, 0xa0,
		0x46, 0xa0, 0x46, 0xa0, 0x46, 0xa0, 0x46, 0xa0, 0x46, 0x72, 0xa3, 0x46, 0xcc, 0xe9, 0x10, 0x28,
		0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28, 0x10, 0x28,
		0x10, 0x28, 0x10, 0x28, 0x90, 0xfc, 0x29, 0x10, 0x03, 0x45, 0x59, 0xe8, 0x37, 0x08, 0x2d, 0x02,
		0x2d, 0x02, 0x2d, 0x02, 0x2d, 0x02, 0x2d, 0x02, 0x2d, 0x02, 0x2d, 0x02, 0x2d, 0x02, 0x2d, 0x02,
		0x2d, 0x92, 0x53, 0x2d, 0x62, 0xa0, 0xe1, 0xe0, 0xea, 0x61, 0xa1, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d,
		0xa0, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d, 0xa0, 0x3d,
		0x32, 0xab, 0x3d, 0x22, 0x5b, 0x09, 0xcb, 0x73, 0x7b, 0xae, 0x12, 0x1d, 0x46, 0xed, 0xb1, 0x7a,
		0x58, 0x68, 0x0f, 0x68, 0x0f, 0x68, 0x0f, 0x68, 0x0f, 0x68, 0x0f, 0x68, 0x0f, 0x68, 0x0f, 0x68,
		0x0f, 0x68, 0x0f, 0x68, 0x0f, 0x68, 0x8f, 0x64, 0x68, 0x8f, 0x77, 0x09, 0x5e, 0xe3, 0x85, 0x13,
		0xdf, 0x0f, 0xd4, 0xa8, 0x92, 0x8a, 0x64, 0x59, 0x17, 0xa4, 0xf3, 0x24, 0x7a, 0x76, 0x68, 0xab,
		0xa7, 0xa1, 0xc7, 0x2f, 0x06, 0xa1, 0xf0, 0x9d, 0x11, 0xeb, 0xb7, 0x7c, 0xa1, 0xfe, 0x0e, 0xa2,
		0xaf, 0x96, 0xeb, 0x4b, 0x65, 0xfb, 0x8e, 0x28, 0x2e, 0xbe, 0x21, 0x97, 0xde, 0x29, 0xf6, 0x42,
		0x4f, 0x16, 0xa5, 0xfb, 0xe8, 0xdb, 0x9e, 0xeb, 0x3f, 0x5a, 0x61, 0x14, 0xa8, 0xc0, 0x09, 0x3c,
		0x59, 0x1c, 0x12, 0x38, 0x4b, 0x89, 0xa2, 0x3b, 0x24, 0x14, 0x5d, 0xdb, 0x11, 0x96, 0xad, 0x54,
		0xe4, 0x3e, 0xf4, 0x95, 0x90, 0xaf, 0x6f, 0x16, 0xa5, 0xb2, 0x95, 0x28, 0xc6, 0xbc, 0x83, 0x42,
		0x35, 0x15, 0xa4, 0x8a, 0xfa, 0x8e, 0xf2, 0x63, 0x86, 0x73, 0x39, 0xfe, 0x01, 0x67, 0xf1, 0xfd,
		0xb7, 0x2f, 0x42, 0x4f, 0xb6, 0x6f, 0x27, 0xf7, 0x7f, 0x3d, 0xb9, 0xfd, 0xf6, 0x8d, 0xfc, 0x16,
		0xde, 0x89, 0xf6, 0xd9, 0xe4, 0x46, 0xdb, 0x9f, 0x27, 0xb7, 0xf8, 0x2e, 0x99, 0xa6, 0xa8, 0xd1,
		0x0c, 0x0b, 0xaf, 0x73, 0xe6, 0x76, 0xb4, 0x1b, 0xe1, 0x94, 0x6c, 0xce, 0x8d, 0xa2, 0x79, 0x11,
		0xd1, 0xf8, 0x29, 0x32, 0x79, 0x4c, 0x29, 0x8b, 0x19, 0xe4, 0x30, 0xb5, 0x0c, 0x66, 0x93, 0xbf,
		0x6c, 0xb2, 0x97, 0x47, 0xee, 0x26, 0xdb, 0xd1, 0x91, 0xc9, 0x5a, 0x0e, 0x84, 0x99, 0x45, 0x99,
		0xf2, 0x61, 0x0e, 0x7c, 0x42, 0xcf, 0xfe, 0x6e, 0x79, 0xae, 0xff, 0xd5, 0x7a, 0xb0, 0xfd, 0xce,
		0xdf, 0x6e, 0x67, 0x44, 0x1f, 0x88, 0x3c, 0xc3, 0x8a, 0xb1, 0xe0, 0x1f, 0xe0, 0x1f, 0xe0, 0x1f,
		0xe0, 0x1f, 0xb4, 0x5a, 0xfc, 0x14, 0x5e, 0xac, 0xaf, 0x0f, 0xa1, 0x24, 0xf4, 0x10, 0x04, 0xb1,
		0xce, 0xc2, 0x17, 0x7f, 0x1c, 0x8f, 0x28, 0xfc, 0x8b, 0xe8, 0xde, 0x69, 0x83, 0xa8, 0x84, 0xd1,
		0x6c, 0x8e, 0xa0, 0x29, 0x53, 0x24, 0x8c, 0x2b, 0x48, 0xca, 0x19, 0xe6, 0x22, 0x0c, 0x8a, 0xb2,
		0x04, 0x43, 0xb9, 0xa7, 0x9e, 0x3f, 0xf8, 0xc9, 0x6a, 0x0d, 0x29, 0x09, 0x1a, 0xb6, 0x92, 0xca,
		0xf1, 0xdf, 0x25, 0x68, 0x4d, 0x52, 0x05, 0x2f, 0x93, 0x18, 0xb4, 0xd4, 0x43, 0xc7, 0x76, 0x9f,
		0x3e, 0x0d, 0x53, 0x57, 0x90, 0xfd, 0x07, 0xe9, 0x44, 0x6e, 0xa8, 0x75, 0xe2, 0xa6, 0x34, 0x6b,
		0xee, 0xea, 0x9a, 0x0c, 0x6d, 0x22, 0xbd, 0x35, 0x5d, 0x4e, 0xb7, 0x70, 0xa3, 0x10, 0x6c, 0x84,
		0x42, 0x8d, 0x4a, 0xa0, 0x91, 0x0b, 0x33, 0x72, 0x41, 0x46, 0x2b, 0xc4, 0x92, 0x05, 0xde, 0xa7,
		0x6e, 0xa4, 0xd7, 0x60, 0x9d, 0xc9, 0xaa, 0x22, 0x8a, 0x13, 0xc5, 0xd7, 0xa7, 0x89, 0x0d, 0x95,
		0x11, 0x1b, 0x42, 0x6c, 0x08, 0xb1, 0xa1, 0x64, 0xc6, 0x86, 0x74, 0x43, 0x15, 0x2d, 0x13, 0xe2,
		0x64, 0x46, 0xcc, 0x6a, 0x15, 0x15, 0xc3, 0xc9, 0x82, 0x3b, 0x76, 0xd8, 0x63, 0x87, 0x3f, 0x5e,
		0x18, 0x24, 0x0e, 0x53, 0xa4, 0xbe, 0x62, 0x38, 0x14, 0x91, 0x23, 0x7c, 0x65, 0x3f, 0x0a, 0x86,
		0x92, 0xe1, 0x1a, 0x4a, 0x86, 0x7f, 0xfd, 0x43, 0x50, 0x32, 0xac, 0x6f, 0x3c, 0x94, 0x0c, 0xa7,
		0xd6, 0x44, 0xca, 0xa5, 0x12, 0x2a, 0x84, 0x93, 0x76, 0x75, 0x54, 0x08, 0x6b, 0x21, 0x3e, 0xf9,
		0xaa, 0x10, 0x9e, 0xd1, 0x48, 0xc5, 0x38, 0xe2, 0x93, 0x83, 0x7a, 0xab, 0x71, 0x8e, 0x81, 0x2c,
		0x74, 0x36, 0xbe, 0x7c, 0xca, 0x22, 0x67, 0x15, 0x44, 0xce, 0x10, 0x39, 0x43, 0xe4, 0x2c, 0x99,
		0x91, 0x33, 0xc7, 0xf6, 0x9c, 0xbe, 0x67, 0x2b, 0xd1, 0xb1, 0xec, 0x07, 0x19, 0x78, 0x7d, 0x25,
		0xac, 0x59, 0xec, 0xb6, 0x1e, 0xfe, 0xa6, 0x0f, 0xa8, 0x6d, 0x72, 0x13, 0x88, 0xb3, 0x21, 0xce,
		0x86, 0x38, 0x1b, 0xe2, 0x6c, 0xa9, 0x8a, 0xb3, 0xf5, 0x5d, 0x5f, 0x61, 0x5b, 0x3e, 0x62, 0x6c,
		0x88, 0xb1, 0x21, 0xc6, 0x96, 0x9c, 0x18, 0x1b, 0xb6, 0xe5, 0x23, 0xe8, 0x96, 0xe4, 0x55, 0x89,
		0x74, 0x3e, 0x64, 0x06, 0x64, 0x06, 0x64, 0x06, 0x64, 0xc6, 0x86, 0x2b, 0x06, 0xe9, 0x7c, 0x48,
		0x0d, 0x48, 0x0d, 0x48, 0x8d, 0xe4, 0x49, 0x0d, 0xa4, 0xf3, 0xa1, 0x2c, 0x92, 0x71, 0x45, 0xa4,
		0xf3, 0xb5, 0xa5, 0xf3, 0x35, 0x6e, 0xa4, 0xd3, 0x3f, 0xd7, 0xd8, 0x59, 0x69, 0xd6, 0x3a, 0x0a,
		0x5a, 0xab, 0x29, 0xb4, 0x1c, 0x02, 0x77, 0x3b, 0x7b, 0x7b, 0x49, 0xd9, 0xff, 0xf9, 0xce, 0xa0,
		0x79, 0x0e, 0x75, 0xa9, 0xe6, 0x93, 0x96, 0x0a, 0xe7, 0xae, 0x54, 0x27, 0x4a, 0xe9, 0x49, 0x53,
		0x0f, 0xf9, 0x73, 0xd3, 0x13, 0x43, 0x61, 0x29, 0xf5, 0xd0, 0x96, 0x21, 0xdd, 0x9a, 0xb9, 0x22,
		0x4d, 0x0c, 0xb4, 0x70, 0x15, 0x75, 0x44, 0x24, 0x3a, 0x9f, 0x86, 0x4f, 0xd7, 0xef, 0x7b, 0x9e,
		0xd1, 0x49, 0xd6, 0x8c, 0x3d, 0xc9, 0xc2, 0x9c, 0x82, 0x8e, 0xfd, 0xd3, 0x5a, 0xe0, 0x65, 0x37,
		0x44, 0xd9, 0x1e, 0x07, 0xb6, 0xfb, 0xe6, 0x96, 0x46, 0xa5, 0xcb, 0x98, 0x92, 0x60, 0x44, 0xdb,
		0x4d, 0xd8, 0xdb, 0x1f, 0xf7, 0x16, 0x8f, 0xba, 0xe0, 0x0b, 0xf7, 0xf1, 0xe9, 0x21, 0x88, 0xb6,
		0x6f, 0x80, 0x31, 0x0d, 0x0a, 0xbd, 0x5e, 0x6a, 0xcb, 0x29, 0xdf, 0xad, 0x2e, 0x70, 0xe7, 0x98,
		0xb4, 0x8e, 0x98, 0xb3, 0xc6, 0x98, 0xb2, 0xae, 0x98, 0xb1, 0xf6, 0x98, 0xb0, 0xf6, 0x98, 0xaf,
		0xde, 0x98, 0x2e, 0x2f, 0x4c, 0xed, 0x5a, 0x27, 0x37, 0x5d, 0x35, 0xbb, 0xcf, 0xf3, 0xe2, 0x3a,
		0xdc, 0x75, 0x9a, 0xf5, 0x94, 0xe9, 0x6a, 0x2b, 0xcb, 0xd5, 0x99, 0x12, 0x22, 0x48, 0xfd, 0xe8,
		0x4e, 0xf1, 0x90, 0xa5, 0x72, 0xc8, 0x52, 0x36, 0x34, 0xa9, 0x19, 0xb3, 0xba, 0x45, 0x57, 0x19,
		0x6c, 0xc1, 0xee, 0x74, 0x22, 0x21, 0xa5, 0xfe, 0x53, 0x73, 0x26, 0x17, 0xd6, 0x7b, 0x60, 0x4e,
		0x09, 0x07, 0xe6, 0x68, 0xb9, 0x34, 0x0e, 0xcc, 0x61, 0x05, 0x8b, 0x64, 0xc6, 0xe4, 0xb4, 0xe7,
		0x65, 0xa7, 0x16, 0xeb, 0x09, 0xbb, 0x1b, 0x89, 0xae, 0x4e, 0x8b, 0x9d, 0x78, 0xfd, 0x86, 0xc6,
		0x6b, 0x5e, 0xc7, 0xea, 0xeb, 0xe3, 0xc7, 0xb8, 0x91, 0xc3, 0x04, 0xb4, 0xb2, 0x74, 0x36, 0x9a,
		0xd6, 0x8d, 0x58, 0x24, 0x1b, 0xb0, 0xc8, 0x4e, 0x43, 0xab, 0x00, 0xdc, 0x01, 0xee, 0x39, 0x05,
		0x77, 0xed, 0xa7, 0xa1, 0xe9, 0x66, 0x8a, 0xc4, 0x8c, 0x91, 0x88, 0x39, 0x92, 0x31, 0x48, 0x4a,
		0xb0, 0x61, 0x00, 0x1d, 0x6a, 0xf0, 0x61, 0x03, 0x21, 0x36, 0x30, 0xe2, 0x01, 0x25, 0xbd, 0xe0,
		0xa4, 0x19, 0xa4, 0xe8, 0x98, 0xe8, 0x92, 0xc5, 0xbb, 0xa1, 0x45, 0x83, 0x2f, 0x73, 0x04, 0xe6,
		0x88, 0xe0, 0xda, 0xf1, 0xb3, 0x49, 0xdd, 0x31, 0xf6, 0xaf, 0x4f, 0xfe, 0x5b, 0x95, 0xf0, 0xd9,
		0x2f, 0xcd, 0x01, 0xe5, 0x0e, 0xb0, 0x6b, 0x5b, 0x29, 0x11, 0xf9, 0xe4, 0x85, 0x99, 0x85, 0xff,
		0xbe, 0x7f, 0x7f, 0x5f, 0xb2, 0x8e, 0x5a, 0x2f, 0xf7, 0x65, 0xeb, 0xa8, 0x35, 0x7e, 0x59, 0x1e,
		0xfd, 0x35, 0x7e, 0x5d, 0xb9, 0x2f, 0x59, 0xd5, 0xc9, 0xeb, 0xda, 0x7d, 0xc9, 0xaa, 0xb5, 0xf6,
		0xff, 0xfa, 0xeb, 0xe3, 0xfe, 0x8f, 0x83, 0xc1, 0xdb, 0xbf, 0xf8, 0x0f, 0xba, 0x42, 0xe5, 0x16,
		0xe5, 0x64, 0x5c, 0xdd, 0x9e, 0xfd, 0x81, 0x19, 0x79, 0xeb, 0x8c, 0xa4, 0xa9, 0x74, 0x9c, 0x07,
		0x9e, 0xea, 0x80, 0xa7, 0xed, 0x16, 0x83, 0x6d, 0x75, 0x4f, 0xac, 0xdf, 0x5a, 0x3f, 0xca, 0x1f,
		0xaa, 0x83, 0xe3, 0xfd, 0x1f, 0x8d, 0xc1, 0xe2, 0x9b, 0x2f, 0xab, 0x3e, 0x56, 0xfe, 0xd0, 0x18,
		0x1c, 0xaf, 0xf9, 0x97, 0xfa, 0xe0, 0x78, 0xc3, 0x6b, 0xd4, 0x06, 0xef, 0x97, 0x3e, 0x3a, 0x7c,
		0xbf, 0xb2, 0xee, 0x0b, 0xd5, 0x35, 0x5f, 0x38, 0x58, 0xf7, 0x85, 0x83, 0x35, 0x5f, 0x58, 0x7b,
		0x4b, 0x95, 0x35, 0x5f, 0xa8, 0x0d, 0x5e, 0x96, 0x3e, 0xff, 0x7e, 0xf5, 0x47, 0xeb, 0x83, 0xfd,
		0x97, 0x75, 0xff, 0xd6, 0x18, 0xbc, 0x1c, 0xef, 0x03, 0xac, 0x61, 0x9f, 0xb9, 0xb5, 0x4f, 0xf4,
		0x5a, 0x49, 0x8a, 0x93, 0x2e, 0x74, 0x84, 0x12, 0x8e, 0x12, 0x1d, 0xeb, 0xb5, 0x10, 0x8d, 0x2c,
		0x30, 0xb4, 0x62, 0x2c, 0xc4, 0x88, 0x10, 0x23, 0x42, 0x8c, 0x08, 0x31, 0x22, 0xad, 0x16, 0x2f,
		0x55, 0xe4, 0xfa, 0x8f, 0xe8, 0xb4, 0xbb, 0xdb, 0x6f, 0x9d, 0x94, 0x79, 0x59, 0x52, 0xd9, 0xaa,
		0x4f, 0x98, 0x2f, 0x58, 0x1c, 0x08, 0x3e, 0x01, 0x3e, 0x01, 0x3e, 0x01, 0x3e, 0x41, 0xab, 0xc5,
		0x0b, 0xbf, 0xdf, 0x13, 0x91, 0x4d, 0x74, 0x24, 0xca, 0xd4, 0x31, 0x54, 0x09, 0xae, 0xdd, 0xf4,
		0xfb, 0xbd, 0xe1, 0xc3, 0x19, 0xe4, 0xc0, 0xe9, 0x44, 0xa2, 0x1b, 0x09, 0xf9, 0x64, 0x45, 0xa2,
		0xd3, 0x77, 0x48, 0xf6, 0xa2, 0x4e, 0x2d, 0x62, 0x79, 0x28, 0x38, 0x1e, 0x38, 0x1e, 0x38, 0x1e,
		0x38, 0x1e, 0xad, 0x16, 0xff, 0x10, 0x04, 0x9e, 0xb0, 0x49, 0x9d, 0x4e, 0x19, 0x3b, 0xd7, 0x37,
		0xb1, 0xf6, 0x6c, 0xec, 0x5c, 0x9f, 0xee, 0x82, 0x9b, 0xbe, 0x4a, 0x58, 0x1f, 0xe0, 0x24, 0xec,
		0x03, 0xd7, 0x93, 0x07, 0xc4, 0x16, 0x70, 0x6c, 0x01, 0xa7, 0x5e, 0xbc, 0xc6, 0xb7, 0x7d, 0x5f,
		0x4e, 0x6e, 0x04, 0xbb, 0xbe, 0x53, 0x60, 0x37, 0x49, 0xde, 0xea, 0x2d, 0x85, 0x94, 0x6e, 0xe0,
		0x6b, 0xd8, 0xe9, 0x3d, 0xbd, 0x12, 0x36, 0x7a, 0x63, 0xa3, 0xb7, 0x31, 0x45, 0x93, 0xb2, 0x8d,
		0xde, 0xf1, 0xa2, 0xd1, 0xb7, 0xcf, 0x7b, 0x72, 0x41, 0x6c, 0xf3, 0x66, 0x0c, 0x6b, 0x60, 0x9b,
		0x37, 0xb6, 0x79, 0xff, 0xe4, 0x42, 0xe2, 0x7b, 0xe8, 0xb9, 0x8e, 0xab, 0xac, 0x28, 0xe8, 0x2b,
		0x61, 0x05, 0x0f, 0xff, 0x9f, 0x70, 0x14, 0xc1, 0xae, 0xef, 0x35, 0xe3, 0x24, 0x7c, 0x9f, 0x20,
		0x36, 0x81, 0xa7, 0x2a, 0xe2, 0x89, 0x7d, 0x82, 0x49, 0xde, 0x27, 0xb8, 0x12, 0x02, 0xe8, 0xd2,
		0x31, 0xab, 0x87, 0x43, 0x67, 0x48, 0xa4, 0x64, 0xcc, 0x01, 0x14, 0x1b, 0x50, 0xf1, 0x00, 0x96,
		0x5e, 0xe0, 0xd2, 0x0c, 0x60, 0x64, 0x40, 0x36, 0xbd, 0xb0, 0xeb, 0x77, 0xc4, 0x77, 0xfa, 0xee,
		0x2b, 0xe3, 0x61, 0xd0, 0x76, 0x85, 0x1b, 0xd0, 0x18, 0x81, 0x8d, 0x0b, 0xe0, 0xd8, 0x81, 0x8e,
		0x1d, 0xf0, 0x78, 0x81, 0x8f, 0x06, 0x00, 0x89, 0x80, 0x70, 0xfa, 0x68, 0xf8, 0xda, 0xae, 0xe8,
		0x3f, 0xee, 0x67, 0x2d, 0x03, 0x6b, 0xd0, 0x6e, 0x9f, 0x9b, 0x3f, 0x0e, 0x68, 0x0c, 0xc9, 0x79,
		0xee, 0x3f, 0x46, 0xd2, 0xc5, 0x7d, 0xc9, 0x7e, 0x28, 0xba, 0xb9, 0x13, 0x73, 0x77, 0x72, 0x0e,
		0x0f, 0xd7, 0x07, 0xd7, 0x07, 0xd7, 0x97, 0x30, 0x2d, 0x30, 0x1d, 0xc0, 0x96, 0xf4, 0x6d, 0xad,
		0x5e, 0x0f, 0x46, 0x92, 0x3e, 0xb5, 0xf1, 0xf2, 0xb4, 0x45, 0x22, 0xd7, 0x09, 0x9c, 0xa0, 0x69,
		0x00, 0x3c, 0xb9, 0x41, 0xd4, 0x18, 0x98, 0x1a, 0x03, 0x55, 0x33, 0xe0, 0x4a, 0x0b, 0xb2, 0xc4,
		0x60, 0xcb, 0xa7, 0x37, 0x56, 0x00, 0xa3, 0xe5, 0xf7, 0x7b, 0x0f, 0x22, 0xe2, 0x58, 0x73, 0x31,
		0x44, 0x36, 0x18, 0x86, 0xe2, 0xe9, 0xfe, 0x38, 0xf9, 0xc3, 0x83, 0x21, 0x7b, 0xdc, 0xdd, 0x20,
		0x99, 0x7d, 0xdb, 0xd2, 0xb0, 0xcc, 0xdd, 0x21, 0xa7, 0xe3, 0x1a, 0x68, 0x00, 0xc8, 0x84, 0x30,
		0xf3, 0xa6, 0xc4, 0xd8, 0x35, 0x32, 0x29, 0xa6, 0x54, 0xad, 0x1c, 0x55, 0x8f, 0xea, 0x8d, 0xca,
		0x51, 0x2d, 0x47, 0x36, 0xf5, 0x2e, 0x1b, 0xa3, 0xb4, 0x52, 0xda, 0x24, 0x93, 0x70, 0x4d, 0x13,
		0x67, 0x56, 0x96, 0xe8, 0x02, 0x65, 0x86, 0x05, 0x4a, 0x0a, 0x4a, 0x0a, 0x4a, 0x0a, 0x4a, 0x2a,
		0xa5, 0x4a, 0xaa, 0xef, 0xfa, 0xaa, 0x5e, 0x65, 0x94, 0x51, 0x87, 0x90, 0x51, 0x90, 0x51, 0x90,
		0x51, 0x90, 0x51, 0x06, 0x4c, 0x89, 0x66, 0xc3, 0x23, 0x04, 0x15, 0x04, 0x95, 0x79, 0x41, 0x35,
		0xd3, 0xc7, 0x9a, 0x51, 0x57, 0x69, 0xeb, 0x9e, 0x0d, 0x79, 0x05, 0x79, 0x05, 0x79, 0x05, 0x79,
		0x95, 0x41, 0x79, 0x75, 0x50, 0x41, 0x96, 0x0a, 0xf2, 0x0a, 0xf2, 0x0a, 0xf2, 0x2a, 0xe3, 0xa6,
		0x84, 0x2c, 0x15, 0x44, 0x55, 0xa6, 0x44, 0x55, 0x68, 0x85, 0x3c, 0x2c, 0x7d, 0xb6, 0x5b, 0x19,
		0x4f, 0xd1, 0x2a, 0xe4, 0x14, 0xe4, 0x14, 0xe4, 0x14, 0xe4, 0x54, 0xba, 0xe4, 0x14, 0x17, 0x3c,
		0xee, 0x11, 0xf7, 0x76, 0x5c, 0xf7, 0x28, 0x33, 0xa7, 0xa8, 0xe6, 0x7a, 0x41, 0xb2, 0x22, 0xc9,
		0x1e, 0x53, 0xef, 0xb5, 0x65, 0x4f, 0xc4, 0xd4, 0xeb, 0x6a, 0x69, 0x60, 0xd6, 0x46, 0x85, 0xc5,
		0x78, 0xb0, 0xfd, 0x97, 0xf7, 0xf7, 0x65, 0xab, 0xd2, 0x9a, 0xfc, 0xc7, 0xc1, 0x7d, 0xc9, 0xaa,
		0xb4, 0x48, 0xbb, 0x41, 0x2d, 0x51, 0x57, 0xce, 0xc9, 0xe5, 0xec, 0x66, 0x86, 0x19, 0x66, 0x11,
		0x27, 0xcc, 0xe1, 0x01, 0x33, 0xe8, 0x5b, 0x07, 0xfa, 0xb2, 0xac, 0x4d, 0x74, 0x1e, 0xe4, 0xef,
		0x3c, 0x58, 0x7c, 0x5f, 0x1e, 0x02, 0xd8, 0xe1, 0x18, 0xd3, 0xca, 0xad, 0x25, 0xa8, 0x1b, 0x43,
		0x17, 0x5c, 0x12, 0xcc, 0x1e, 0x66, 0x9f, 0x01, 0x3f, 0x8d, 0x60, 0xa8, 0x81, 0x60, 0xa8, 0x67,
		0x3f, 0x08, 0x8f, 0x2f, 0x10, 0x3a, 0x1e, 0x0e, 0x41, 0x50, 0x04, 0x41, 0x11, 0x04, 0x45, 0x10,
		0x14, 0x41, 0xd0, 0x99, 0x15, 0xd7, 0x0b, 0x3d, 0x69, 0x71, 0xe0, 0x23, 0xa2, 0xa0, 0x9a, 0x67,
		0x8e, 0xad, 0x1a, 0x68, 0x71, 0xf6, 0x1a, 0x8c, 0x43, 0xf2, 0x56, 0x07, 0xf1, 0xcf, 0xe6, 0xf4,
		0x87, 0x9a, 0xa8, 0x16, 0x62, 0xa6, 0x2e, 0x6b, 0x87, 0x9f, 0x56, 0xd4, 0xd7, 0x0d, 0xdd, 0x80,
		0xc1, 0x92, 0x0f, 0xe6, 0x78, 0xe1, 0xbc, 0xcd, 0x19, 0x28, 0x2b, 0x4a, 0x9c, 0xcd, 0x95, 0xaa,
		0x87, 0xb5, 0x46, 0x2d, 0xc7, 0x86, 0xf7, 0x2e, 0x9b, 0xa3, 0x21, 0xcc, 0xbf, 0x1b, 0xbd, 0xa0,
		0x6d, 0x59, 0xfc, 0x4b, 0x86, 0x58, 0x65, 0x1c, 0x93, 0xa6, 0xc5, 0xb1, 0xb9, 0x25, 0x80, 0x88,
		0xd3, 0xf2, 0x1c, 0x7b, 0x41, 0x20, 0x05, 0x63, 0xc4, 0x69, 0x34, 0x1c, 0x22, 0x4e, 0x6f, 0x1a,
		0x08, 0x11, 0x27, 0xbd, 0xe6, 0x81, 0x88, 0x13, 0x22, 0x4e, 0x1b, 0x46, 0x49, 0x18, 0x57, 0x1c,
		0x5d, 0x4b, 0xea, 0xb5, 0x64, 0xa2, 0x0c, 0x87, 0xb8, 0xf4, 0x6c, 0x14, 0xc7, 0xc4, 0x4f, 0x27,
		0x7d, 0x34, 0x1a, 0xdc, 0x21, 0xdc, 0x21, 0xdc, 0x21, 0xdc, 0x21, 0xdc, 0xa1, 0x31, 0x9d, 0xcd,
		0xa9, 0xaf, 0x99, 0x74, 0xf5, 0x00, 0xa7, 0xd5, 0xef, 0x11, 0x34, 0xa7, 0x5f, 0x3b, 0x0e, 0x73,
		0xf3, 0xf1, 0x49, 0x37, 0xee, 0xc9, 0x8b, 0xe2, 0xea, 0xe6, 0xa0, 0xab, 0xdf, 0x1e, 0x77, 0x60,
		0x49, 0x4d, 0xef, 0x95, 0x44, 0x77, 0x46, 0xfb, 0x97, 0x78, 0xa6, 0x3a, 0xfe, 0xb2, 0x70, 0xee,
		0x4a, 0x75, 0xa2, 0x14, 0x51, 0xeb, 0xb5, 0x0b, 0xd7, 0x6f, 0x7a, 0x62, 0xe8, 0x09, 0x25, 0x0d,
		0x6d, 0x2b, 0x5c, 0xd8, 0xdf, 0x67, 0x46, 0xe0, 0x39, 0x19, 0xaa, 0x70, 0x15, 0x75, 0x44, 0x24,
		0x3a, 0x9f, 0x86, 0xd3, 0xe2, 0xf7, 0x3d, 0x2f, 0xd1, 0xd6, 0x43, 0x8c, 0x4e, 0xa9, 0x42, 0xa5,
		0x02, 0x49, 0x8f, 0xa5, 0xa8, 0xef, 0x28, 0x3f, 0x26, 0x15, 0x97, 0xe3, 0x1f, 0x74, 0x16, 0xff,
		0x9e, 0xf6, 0x45, 0xe8, 0xc9, 0xf6, 0xed, 0xe4, 0xf7, 0x5c, 0x4f, 0x7e, 0x4e, 0xfb, 0x46, 0x7e,
		0x0b, 0xef, 0x44, 0xfb, 0x76, 0xfc, 0x23, 0xda, 0xcd, 0xf8, 0x6e, 0x6f, 0x86, 0x37, 0x7b, 0x35,
		0xbe, 0xd7, 0x77, 0xc9, 0x44, 0xb8, 0x64, 0xb5, 0xbf, 0x25, 0xb2, 0xee, 0x84, 0x5a, 0xb5, 0x1e,
		0x9b, 0xd8, 0x7d, 0x06, 0x35, 0xcc, 0x5e, 0xc1, 0x0b, 0x1c, 0xdb, 0xb3, 0xf4, 0x1e, 0x21, 0x3d,
		0x93, 0x05, 0x78, 0xbd, 0xb8, 0xde, 0xe6, 0xe5, 0x25, 0x34, 0x2f, 0x4f, 0x72, 0x10, 0x02, 0xcd,
		0xcb, 0xd3, 0x84, 0xde, 0xda, 0x45, 0x3f, 0x61, 0x4b, 0x4b, 0x8a, 0x16, 0x96, 0xcb, 0x2d, 0x2b,
		0x67, 0x81, 0x2b, 0x43, 0x60, 0x1f, 0x09, 0x27, 0x88, 0x3a, 0x0b, 0xce, 0x4c, 0x3b, 0xea, 0xaf,
		0x1c, 0x45, 0x2f, 0xfc, 0x97, 0x01, 0xff, 0x80, 0x7f, 0xc0, 0xbf, 0x1e, 0x9b, 0xd5, 0xdd, 0xe6,
		0x71, 0x15, 0x00, 0xe8, 0x37, 0xb1, 0x9f, 0xa0, 0x8d, 0x6e, 0x63, 0xa3, 0xe9, 0x7d, 0x4b, 0xd6,
		0xf3, 0x96, 0x32, 0x71, 0xc6, 0x90, 0x28, 0xa3, 0x4e, 0x8c, 0xb1, 0x25, 0xc2, 0xd8, 0x12, 0x5f,
		0x3c, 0x89, 0xae, 0x64, 0x47, 0x67, 0xa9, 0x7a, 0xd5, 0x12, 0x77, 0x57, 0x62, 0xe9, 0xaa, 0x44,
		0x5c, 0x19, 0x40, 0x5e, 0x11, 0x80, 0xe6, 0xdd, 0xc9, 0x06, 0x3a, 0x76, 0xc0, 0xe3, 0x05, 0x3e,
		0x1a, 0x00, 0x24, 0x02, 0x42, 0x3a, 0x51, 0xcf, 0x28, 0xf2, 0x39, 0x44, 0xff, 0xaf, 0x83, 0x00,
		0x1a, 0xe5, 0x3f, 0xbd, 0x29, 0x0d, 0x48, 0x72, 0x2a, 0xb6, 0x12, 0xf4, 0xae, 0x6f, 0x3c, 0x0c,
		0xad, 0xeb, 0x2b, 0x53, 0xbb, 0xbe, 0x0a, 0x5c, 0x1f, 0x5c, 0x1f, 0x5c, 0x5f, 0x22, 0x5c, 0x1f,
		0x95, 0x16, 0x98, 0x0e, 0x60, 0x77, 0x3a, 0x91, 0x90, 0x92, 0xaf, 0x7c, 0x78, 0x32, 0x20, 0x2a,
		0x88, 0x93, 0x06, 0x9e, 0x06, 0x40, 0x94, 0x1b, 0x4c, 0x8d, 0x81, 0xaa, 0x31, 0x70, 0x35, 0x03,
		0xb2, 0xb4, 0x60, 0x4b, 0x0c, 0xba, 0x7c, 0xba, 0x63, 0x39, 0x74, 0x12, 0x5a, 0x3c, 0xf8, 0xb8,
		0x87, 0x23, 0x5c, 0x74, 0xcf, 0xdc, 0xb7, 0x2a, 0xe3, 0xdc, 0x2d, 0xcd, 0x21, 0x4e, 0xb2, 0xd6,
		0x7d, 0xce, 0x31, 0x8e, 0x05, 0xc5, 0x0c, 0x6e, 0x3e, 0x83, 0x38, 0xa2, 0x62, 0x57, 0xf8, 0xac,
		0x03, 0x3e, 0x79, 0x16, 0x1f, 0xce, 0xe4, 0xe5, 0x3f, 0x93, 0x17, 0xce, 0x04, 0xf6, 0x0c, 0x7b,
		0x4e, 0xb2, 0x6b, 0xc5, 0x51, 0x3e, 0xfc, 0xa4, 0x83, 0xb8, 0x22, 0x61, 0x99, 0x65, 0x10, 0x56,
		0x26, 0x20, 0xf2, 0x88, 0xc8, 0x23, 0x22, 0x8f, 0x88, 0x3c, 0xa6, 0x34, 0xf2, 0xd8, 0x77, 0x7d,
		0x75, 0xc8, 0x18, 0x74, 0xac, 0xa1, 0x1f, 0xf9, 0xf6, 0x3f, 0x0c, 0xfd, 0xc8, 0xe9, 0xc7, 0x45,
		0x3f, 0xf2, 0xcc, 0x9a, 0x52, 0xa5, 0x86, 0x46, 0xe4, 0x90, 0x4f, 0x19, 0x90, 0x4f, 0x91, 0x08,
		0x83, 0x48, 0x89, 0x8e, 0xd5, 0xf5, 0xec, 0x47, 0xc6, 0x1a, 0x8e, 0x85, 0x71, 0x21, 0xa8, 0x20,
		0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x20,
		0xa8, 0x20, 0xa8, 0x20, 0xa8, 0x52, 0x2c, 0xa8, 0x98, 0xbb, 0x9a, 0x2e, 0x8c, 0x0b, 0x41, 0x05,
		0x41, 0x05, 0x41, 0x05, 0x41, 0x05, 0x41, 0x85, 0xf6, 0xa6, 0x29, 0x56, 0x55, 0x68, 0x6f, 0x9a,
		0xa1, 0xd9, 0x34, 0xaa, 0x95, 0x0d, 0x0b, 0x9d, 0x25, 0xc1, 0x83, 0xf6, 0xa6, 0xcc, 0x36, 0x87,
		0xf6, 0xa6, 0x68, 0x6f, 0x8a, 0xf6, 0xa6, 0x29, 0x58, 0xb6, 0x68, 0x6f, 0x4a, 0x39, 0x26, 0xda,
		0x9b, 0x26, 0xe3, 0xfe, 0xd1, 0x4e, 0x66, 0xd5, 0x38, 0xa6, 0x8f, 0xb8, 0x5f, 0x75, 0x5a, 0xef,
		0xaa, 0x37, 0xd1, 0x4a, 0x46, 0x6b, 0xb0, 0x08, 0xad, 0x64, 0xd6, 0xb3, 0x56, 0xb4, 0x92, 0x31,
		0x89, 0x4c, 0xa9, 0x41, 0xa4, 0xc4, 0xb6, 0x91, 0xb9, 0x19, 0xdd, 0x2b, 0x9a, 0xc8, 0x24, 0xc3,
		0xae, 0x13, 0x69, 0xcf, 0x59, 0xea, 0x2a, 0xa0, 0xf7, 0x98, 0x40, 0x92, 0x63, 0x01, 0xd1, 0x37,
		0x00, 0x7d, 0x03, 0xf6, 0xd0, 0x37, 0x40, 0x2f, 0x5e, 0x6b, 0xef, 0x1b, 0xd0, 0x11, 0x52, 0xb9,
		0xfe, 0xc8, 0x03, 0x58, 0x54, 0x47, 0xec, 0x4d, 0x57, 0xc5, 0xaa, 0xc1, 0x68, 0xfa, 0x06, 0x94,
		0xa8, 0xfa, 0x06, 0x94, 0xd0, 0x37, 0x80, 0x01, 0x94, 0xd8, 0xc0, 0x89, 0x0d, 0xa4, 0x78, 0xc0,
		0x2a, 0x1d, 0x52, 0x9c, 0x2c, 0x25, 0xcf, 0x73, 0x3c, 0x1d, 0x65, 0xca, 0x9d, 0x36, 0xc5, 0xce,
		0x70, 0x9e, 0x31, 0xd3, 0xf1, 0x72, 0x1c, 0xe7, 0x21, 0xb1, 0x9d, 0x7f, 0x94, 0x99, 0xc3, 0xc6,
		0x5a, 0x94, 0x93, 0xc1, 0x79, 0x82, 0x4f, 0x76, 0x66, 0x24, 0x4d, 0xf1, 0x7f, 0x1e, 0x78, 0xaa,
		0x03, 0x9e, 0xb6, 0x5b, 0x0c, 0x38, 0xbe, 0x2a, 0x53, 0xc7, 0x57, 0x65, 0x0e, 0xac, 0x61, 0x9f,
		0xd9, 0xb2, 0xcf, 0x94, 0xa4, 0x3d, 0x5b, 0x49, 0x4d, 0x34, 0x68, 0x8c, 0x3d, 0x8e, 0xaa, 0x99,
		0x2d, 0x82, 0x7a, 0xca, 0xd7, 0x86, 0x46, 0x93, 0x11, 0x10, 0x0f, 0x42, 0x3c, 0x08, 0xf1, 0x20,
		0xc4, 0x83, 0xb4, 0x5a, 0x3c, 0xe9, 0x96, 0x0c, 0xc4, 0x83, 0x7e, 0xf2, 0xe4, 0xc9, 0xb7, 0x54,
		0x30, 0x6c, 0xa1, 0x60, 0xda, 0x32, 0xc1, 0xb0, 0x45, 0x89, 0x73, 0x4b, 0x04, 0x73, 0x39, 0x3a,
		0xfb, 0x96, 0x07, 0x13, 0x95, 0xe6, 0x0c, 0xb5, 0xd1, 0xac, 0x5b, 0x18, 0x8c, 0xd9, 0x08, 0xe7,
		0x16, 0x05, 0x23, 0x86, 0x92, 0xd2, 0x7a, 0xe5, 0xff, 0x9f, 0xbd, 0xf7, 0x6d, 0x6a, 0x1b, 0x5b,
		0xd6, 0xbe, 0xdf, 0xf3, 0x29, 0x28, 0xd7, 0x79, 0x91, 0x54, 0x45, 0x01, 0x8c, 0x81, 0x90, 0xaa,
		0xfb, 0x05, 0x99, 0x21, 0x39, 0x3c, 0x9b, 0x10, 0x9e, 0x90, 0xc9, 0x39, 0xbb, 0x32, 0x6c, 0x97,
		0x62, 0xcb, 0x44, 0xb5, 0x8d, 0xec, 0x6d, 0xcb, 0x99, 0xe4, 0x9e, 0xf0, 0xdd, 0xef, 0xc2, 0x96,
		0x8d, 0xc1, 0x38, 0xb1, 0xad, 0xee, 0x5e, 0x4b, 0xf2, 0x8f, 0x3a, 0x75, 0xf6, 0x4c, 0x26, 0x68,
		0x49, 0x6b, 0xf5, 0xea, 0xee, 0xeb, 0xea, 0x7f, 0xf0, 0x95, 0xf7, 0xcd, 0xa7, 0x4d, 0xc9, 0x80,
		0x45, 0x89, 0x80, 0x72, 0x49, 0x00, 0xb8, 0x7e, 0x75, 0x5c, 0xdf, 0x19, 0xa4, 0xda, 0xc0, 0xfe,
		0x76, 0x09, 0x90, 0x3d, 0xc8, 0x1e, 0x64, 0x0f, 0xb2, 0x07, 0xd9, 0x83, 0xec, 0x41, 0xf6, 0x20,
		0x7b, 0x90, 0x3d, 0xc8, 0x1e, 0x64, 0x0f, 0xb2, 0x07, 0xd9, 0x83, 0xec, 0x41, 0xf6, 0xd2, 0xc8,
		0xbe, 0xd3, 0x08, 0xdb, 0x81, 0xce, 0xd8, 0xb2, 0x3b, 0x6c, 0x3f, 0xb5, 0x08, 0xe8, 0x1e, 0x74,
		0x0f, 0xba, 0x07, 0xdd, 0x8b, 0x63, 0xcc, 0xfd, 0x9a, 0x22, 0xb2, 0x57, 0xc8, 0xcf, 0x55, 0xc6,
		0x94, 0x8a, 0xae, 0x89, 0x05, 0x86, 0xb4, 0xea, 0xe9, 0x6b, 0xd4, 0x3c, 0xde, 0x12, 0x01, 0x68,
		0xf6, 0x93, 0xb6, 0x80, 0x86, 0xd6, 0x47, 0x6f, 0xd3, 0xc7, 0xc4, 0x99, 0x34, 0xe0, 0x6c, 0xfb,
		0xe3, 0x6c, 0xf7, 0xbb, 0x41, 0xdc, 0x54, 0xf4, 0xb3, 0x47, 0xcf, 0xc7, 0xc5, 0xc6, 0xc5, 0xc6,
		0xc5, 0xc6, 0xc5, 0x16, 0x77, 0xb1, 0x77, 0xf6, 0x15, 0x5d, 0xec, 0x7d, 0x5c, 0x6c, 0x5c, 0x6c,
		0x5c, 0xec, 0x52, 0xba, 0xd8, 0xfb, 0x7b, 0x7b, 0xbb, 0xf8, 0xd4, 0xf8, 0xd4, 0x0a, 0x3e, 0x75,
		0xb7, 0xd7, 0x49, 0xa3, 0xe1, 0xc1, 0x07, 0xbd, 0xe8, 0x3f, 0x83, 0xa8, 0x9f, 0x46, 0x8a, 0x1e,
		0xf6, 0xa3, 0xab, 0xe1, 0x6f, 0xe3, 0x6f, 0xe3, 0x6f, 0xe3, 0x6f, 0x8b, 0x4a, 0x7c, 0xdc, 0x8c,
		0x92, 0x34, 0x4e, 0xbf, 0xf7, 0xa2, 0x96, 0x66, 0xc6, 0x9a, 0x46, 0xc7, 0xde, 0x93, 0xec, 0xd5,
		0x5f, 0x85, 0x7d, 0xc5, 0x7b, 0x35, 0xde, 0xa8, 0xf3, 0xf7, 0xef, 0x3e, 0x1c, 0xff, 0xf6, 0xe1,
		0xe4, 0xdd, 0x59, 0xfd, 0xc3, 0x3f, 0xcf, 0x8f, 0xb5, 0x6e, 0xd7, 0xd0, 0x95, 0xe9, 0xab, 0xa6,
		0x80, 0x19, 0xcd, 0xe6, 0x3b, 0x3d, 0x39, 0xfb, 0x47, 0x7d, 0x6a, 0xd7, 0xde, 0x1f, 0xff, 0xff,
		0x7f, 0x9c, 0xbc, 0x3f, 0xfe, 0xbd, 0x52, 0x44, 0x77, 0xd9, 0x72, 0xcf, 0xce, 0xde, 0xfd, 0x7e,
		0xfc, 0x70, 0xe3, 0x8e, 0x2f, 0x3e, 0xb0, 0x73, 0x3f, 0xdb, 0xb9, 0x3f, 0xce, 0xb2, 0x1d, 0x53,
		0xdd, 0x26, 0x95, 0x27, 0x5f, 0xfa, 0x6e, 0xd4, 0xbc, 0x74, 0xc8, 0xfb, 0x51, 0xd2, 0x8c, 0x7a,
		0x41, 0xda, 0xef, 0x46, 0x0d, 0x3d, 0x47, 0xfc, 0xde, 0x2a, 0x3a, 0x0e, 0xf8, 0x0e, 0x0e, 0x38,
		0x0e, 0x38, 0x0e, 0xb8, 0x9f, 0x0e, 0xb8, 0x74, 0x83, 0xe3, 0x3b, 0x3e, 0x21, 0x0a, 0xff, 0x1d,
		0x34, 0xc3, 0x34, 0x0c, 0x7a, 0x92, 0xad, 0xd3, 0xe7, 0x33, 0x0a, 0xf7, 0xd7, 0x53, 0x92, 0x18,
		0x5d, 0xbe, 0x4f, 0x7d, 0x32, 0xb2, 0xc5, 0x44, 0x64, 0xc3, 0x49, 0xc8, 0x56, 0x13, 0x90, 0xcd,
		0x27, 0x1f, 0x9b, 0x4f, 0x3c, 0xb6, 0x9d, 0x74, 0x5c, 0xac, 0x29, 0x59, 0xea, 0x13, 0x8d, 0xef,
		0xb8, 0x8a, 0x28, 0x8a, 0x5a, 0xed, 0x4e, 0x68, 0x53, 0xe7, 0xa5, 0x38, 0xc1, 0xb8, 0x72, 0x1a,
		0x25, 0x57, 0xc3, 0x59, 0x24, 0x14, 0x7a, 0xf9, 0x63, 0x5e, 0x1e, 0xe7, 0x62, 0x2a, 0x2f, 0x37,
		0x6b, 0xd4, 0x79, 0xe5, 0x12, 0x91, 0x35, 0xa8, 0xf3, 0xaa, 0x51, 0xe1, 0xe5, 0xdb, 0xd3, 0x8b,
		0xd2, 0xb0, 0x53, 0xe1, 0x0a, 0x56, 0x6c, 0x30, 0x05, 0x48, 0x02, 0x24, 0x01, 0x92, 0x00, 0x49,
		0x80, 0x24, 0x40, 0x12, 0x20, 0x09, 0x90, 0x04, 0x48, 0x02, 0x11, 0x01, 0x49, 0x94, 0x0b, 0x49,
		0xf4, 0xe3, 0xff, 0x6b, 0x80, 0x24, 0x86, 0xab, 0x80, 0x24, 0x40, 0x12, 0x20, 0x09, 0x90, 0x04,
		0x48, 0x02, 0x24, 0x01, 0x92, 0x00, 0x49, 0x80, 0x24, 0x10, 0x11, 0x90, 0x84, 0x1b, 0x24, 0xe1,
		0x75, 0x52, 0xd6, 0x51, 0x92, 0x74, 0xd2, 0x51, 0xab, 0x3a, 0x95, 0xdc, 0xac, 0x7e, 0xe3, 0x4b,
		0x74, 0x1d, 0x76, 0xc3, 0xa1, 0x35, 0xac, 0x6c, 0x75, 0xba, 0x51, 0xd2, 0x18, 0x7a, 0xf9, 0x41,
		0x12, 0xa5, 0x7f, 0x75, 0x7a, 0xff, 0x0e, 0xe2, 0xa4, 0x9f, 0x86, 0x49, 0x23, 0xda, 0x7a, 0xf8,
		0x07, 0xfd, 0x99, 0x3f, 0xd9, 0xba, 0xee, 0xb6, 0xfb, 0x5b, 0xfd, 0xf8, 0x2a, 0x09, 0xdb, 0x71,
		0x72, 0x15, 0x74, 0x7b, 0x9d, 0xb4, 0xd3, 0xe8, 0xb4, 0xfb, 0x5b, 0xb7, 0x0e, 0x5b, 0x90, 0x46,
		0x5b, 0xfd, 0xa8, 0xdf, 0x8f, 0x3b, 0x49, 0x7f, 0xfc, 0x0f, 0x5b, 0xfd, 0x34, 0x1c, 0xfe, 0xb1,
		0x5a, 0xea, 0xe9, 0xe8, 0x2b, 0xd3, 0xde, 0xa0, 0x91, 0x26, 0x99, 0x1f, 0x73, 0x36, 0x7a, 0xed,
		0x93, 0xec, 0xad, 0xeb, 0x6f, 0xbb, 0xed, 0x7e, 0xfd, 0x62, 0xfc, 0xd6, 0xe7, 0xe3, 0x97, 0xae,
		0xbf, 0xef, 0x7f, 0xed, 0x7e, 0x88, 0xea, 0x17, 0xa3, 0x57, 0xad, 0x5f, 0x0c, 0x5f, 0xf2, 0xc3,
		0xf0, 0x1d, 0xd7, 0x22, 0xe9, 0x78, 0xf8, 0xd9, 0x41, 0xb6, 0x6b, 0x6a, 0x49, 0xc7, 0x53, 0xab,
		0x50, 0xf5, 0x47, 0xd2, 0xb1, 0x7b, 0x94, 0x4b, 0xd2, 0xb1, 0xa1, 0x7d, 0xd3, 0xaf, 0xfa, 0xeb,
		0xa7, 0xbd, 0x38, 0xb9, 0xd2, 0x2c, 0xf8, 0x7b, 0xb1, 0x0e, 0xd6, 0x60, 0x78, 0xb9, 0x27, 0xf3,
		0xbb, 0xf5, 0xec, 0xc1, 0xfd, 0x75, 0xb0, 0x08, 0x58, 0x04, 0x2c, 0x02, 0x16, 0x41, 0x54, 0xe2,
		0xe3, 0xae, 0x92, 0x7e, 0xd9, 0x64, 0x70, 0xc9, 0xaf, 0x76, 0xfe, 0x6b, 0x4d, 0x71, 0xef, 0x67,
		0x2d, 0xb3, 0xe6, 0xa0, 0x7d, 0xe3, 0x19, 0xfb, 0x97, 0x3f, 0x3e, 0xed, 0x04, 0x87, 0x97, 0xa3,
		0x7f, 0xdc, 0x19, 0xfe, 0xcf, 0xe8, 0x9f, 0xab, 0x9f, 0xb6, 0x83, 0xda, 0xf8, 0x9f, 0xf7, 0x3e,
		0x6d, 0x07, 0x7b, 0x97, 0x4f, 0xff, 0xfc, 0xf3, 0xf9, 0xd3, 0xbf, 0x77, 0x6f, 0x96, 0xff, 0x45,
		0xcd, 0xa9, 0xf2, 0x9a, 0x87, 0xf1, 0xee, 0xe2, 0xe4, 0x7f, 0x39, 0x11, 0x3f, 0x28, 0xba, 0x67,
		0x05, 0x56, 0x4f, 0xfb, 0xa8, 0xa7, 0xd5, 0x2e, 0x43, 0x18, 0xb4, 0x8e, 0x82, 0xd7, 0x97, 0x7f,
		0xef, 0x3c, 0xab, 0xdd, 0xbc, 0x7c, 0xfa, 0xf7, 0xc1, 0xcd, 0xc3, 0x3f, 0xfc, 0xf1, 0xd8, 0x5f,
		0xdb, 0x79, 0x76, 0x70, 0xf3, 0x72, 0xce, 0x7f, 0xd9, 0xbf, 0x79, 0xb9, 0xe0, 0x33, 0xf6, 0x6e,
		0x9e, 0xcc, 0xfc, 0xd5, 0xdb, 0x3f, 0xaf, 0xce, 0xfb, 0x85, 0xda, 0x9c, 0x5f, 0xd8, 0x9d, 0xf7,
		0x0b, 0xbb, 0x73, 0x7e, 0x61, 0xee, 0x2b, 0x55, 0xe7, 0xfc, 0xc2, 0xde, 0xcd, 0x8f, 0x99, 0xbf,
		0xff, 0xe4, 0xf1, 0xbf, 0xba, 0x7f, 0xf3, 0xf4, 0xc7, 0xbc, 0xff, 0x76, 0x70, 0xf3, 0xe3, 0xe5,
		0x53, 0x94, 0x35, 0xf2, 0xb9, 0xb6, 0xf2, 0x49, 0xbf, 0x40, 0x7f, 0xb8, 0xa1, 0x34, 0x4c, 0x07,
		0x9a, 0x9c, 0xd0, 0xe8, 0xf9, 0x70, 0x41, 0x70, 0x41, 0x70, 0x41, 0x70, 0x41, 0xa2, 0x12, 0xaf,
		0x3b, 0x0b, 0x4e, 0x73, 0x06, 0x9c, 0xd2, 0xec, 0x37, 0x3f, 0x4d, 0x4c, 0x3a, 0x48, 0x92, 0xa8,
		0xad, 0x3a, 0xe9, 0xe1, 0x6e, 0x09, 0x0c, 0x0d, 0x86, 0x06, 0x43, 0x83, 0xa1, 0x11, 0x95, 0x78,
		0x86, 0x3d, 0x58, 0x32, 0x7a, 0x0c, 0x7b, 0x58, 0x7e, 0x1d, 0x86, 0x3d, 0x78, 0x7b, 0xf4, 0x0c,
		0x7b, 0x80, 0xbc, 0xd1, 0xf2, 0xac, 0x35, 0x2c, 0xdf, 0x9d, 0x53, 0x7d, 0xfb, 0x74, 0xfc, 0x69,
		0xfc, 0x69, 0xfc, 0x69, 0xfc, 0x69, 0x51, 0x89, 0x67, 0x98, 0xc3, 0x82, 0x1b, 0x75, 0x7a, 0x71,
		0x5e, 0x7f, 0xff, 0xee, 0x94, 0x29, 0x0e, 0xbf, 0xdc, 0xa9, 0x0f, 0xef, 0x8f, 0xce, 0x2e, 0x4e,
		0x3e, 0x30, 0x7a, 0x60, 0xfe, 0x16, 0x1d, 0xbf, 0x79, 0x7f, 0x7c, 0x71, 0xc1, 0x0e, 0xcd, 0xdf,
		0xa1, 0x93, 0x33, 0xed, 0x2d, 0x62, 0x30, 0x83, 0x07, 0x4f, 0x12, 0x12, 0x54, 0xad, 0xfa, 0x3e,
		0x3f, 0xea, 0xfa, 0x64, 0x2e, 0x41, 0xfe, 0x03, 0xcb, 0xf7, 0x84, 0x9c, 0x47, 0x7d, 0xeb, 0xe0,
		0x0e, 0x27, 0x49, 0x77, 0x1a, 0x61, 0x3b, 0x88, 0x93, 0x66, 0x94, 0xd7, 0xc3, 0xad, 0x9c, 0xc6,
		0xfd, 0xf4, 0x28, 0x4d, 0x65, 0xda, 0xf5, 0x57, 0xde, 0xc6, 0xc9, 0x71, 0x3b, 0xba, 0x75, 0x58,
		0xfb, 0x32, 0xe8, 0xa7, 0xf2, 0x36, 0xfc, 0x36, 0xf5, 0x44, 0x9d, 0x61, 0xf0, 0x95, 0x77, 0xbd,
		0x66, 0xd4, 0x8b, 0x9a, 0xaf, 0x6e, 0x37, 0x37, 0x19, 0xb4, 0xdb, 0x4e, 0xcf, 0x58, 0xf8, 0x1a,
		0xbb, 0xbe, 0xbe, 0x02, 0xbe, 0xa2, 0x48, 0xcd, 0x6d, 0x3e, 0x05, 0xb2, 0xfa, 0xb5, 0x5f, 0xed,
		0x37, 0x57, 0x14, 0x22, 0x29, 0xe1, 0x71, 0x25, 0x34, 0xab, 0x1d, 0xd2, 0xf2, 0x5b, 0xbc, 0xdc,
		0x6f, 0x2c, 0x79, 0x18, 0x79, 0x0f, 0xc1, 0x78, 0xf3, 0x57, 0xb8, 0xa0, 0xb9, 0x2e, 0xe4, 0x72,
		0x67, 0xbc, 0xf8, 0x49, 0x2d, 0x71, 0x4a, 0x95, 0x7e, 0x74, 0x75, 0x6b, 0x52, 0x82, 0x5e, 0x67,
		0x90, 0xc6, 0xc9, 0xd5, 0xd2, 0xc7, 0x34, 0x55, 0x73, 0x7e, 0xff, 0x41, 0x4b, 0x4a, 0xca, 0x6a,
		0xb3, 0xac, 0x56, 0xe6, 0x17, 0xf3, 0xf0, 0x87, 0xd3, 0xfc, 0x60, 0xbf, 0xb7, 0x8a, 0xd0, 0xe4,
		0x64, 0xff, 0xc4, 0xd8, 0x3d, 0x31, 0xf6, 0xee, 0x21, 0x3b, 0xd7, 0xef, 0x55, 0x3c, 0xd3, 0x44,
		0xab, 0xce, 0x61, 0xaa, 0x84, 0x57, 0x57, 0xbd, 0xe8, 0x2a, 0x4c, 0xa3, 0xa0, 0x1f, 0x37, 0x83,
		0x46, 0x67, 0x90, 0xa4, 0x51, 0x6f, 0xf5, 0xbc, 0xcc, 0x89, 0xf0, 0xcc, 0x79, 0xee, 0x8a, 0xfb,
		0x9f, 0x6f, 0x14, 0x5c, 0x6e, 0x9a, 0x5e, 0x82, 0x8e, 0xcf, 0x7d, 0xad, 0xa4, 0xae, 0x97, 0xf8,
		0x35, 0x13, 0xbf, 0x6e, 0x92, 0xd7, 0xce, 0x8d, 0x77, 0x96, 0x77, 0x2c, 0xda, 0xe3, 0xd7, 0x27,
		0xff, 0x91, 0xff, 0xf4, 0x76, 0xe6, 0x3d, 0x7e, 0x99, 0x79, 0x8d, 0x77, 0x97, 0xb5, 0x9a, 0xf3,
		0x41, 0x82, 0x31, 0x34, 0xb1, 0xcb, 0x2b, 0x7d, 0x89, 0xd5, 0x2e, 0xb3, 0xda, 0xa5, 0xd6, 0xb8,
		0xdc, 0x7e, 0x70, 0x36, 0x52, 0xb3, 0x10, 0x2b, 0xb7, 0x8e, 0x7c, 0xd0, 0x0e, 0x3f, 0x47, 0x6d,
		0x39, 0xf9, 0x18, 0x0b, 0xf0, 0xd4, 0xb3, 0x85, 0xce, 0x51, 0x36, 0xb4, 0x2e, 0x1e, 0x52, 0xd7,
		0x08, 0xa5, 0x8b, 0xab, 0x03, 0x2d, 0xb5, 0xa0, 0xae, 0x1e, 0xd4, 0xd5, 0x84, 0xa6, 0xba, 0x90,
		0x23, 0x8b, 0x37, 0x05, 0xd9, 0x7d, 0xf1, 0x30, 0xf8, 0x44, 0x5a, 0xdb, 0x51, 0xd8, 0x92, 0x0d,
		0x7d, 0x4f, 0x6c, 0xfe, 0x81, 0xe0, 0x33, 0xcf, 0x33, 0x3e, 0xe4, 0xf9, 0xf3, 0xac, 0xd3, 0xdf,
		0x94, 0xce, 0xf2, 0x25, 0x38, 0x20, 0xc2, 0x75, 0x4a, 0x0e, 0xa1, 0xba, 0x57, 0xf8, 0x16, 0x09,
		0xeb, 0xf6, 0x1d, 0x69, 0xdd, 0x5e, 0x45, 0xb7, 0xa3, 0xdb, 0xd7, 0x50, 0xb7, 0x4b, 0x8f, 0xcb,
		0xae, 0xc4, 0x49, 0xd0, 0x69, 0xa4, 0x51, 0xaa, 0x58, 0x49, 0x7b, 0xb7, 0x04, 0x39, 0x99, 0x16,
		0x39, 0x99, 0xa2, 0x4a, 0x47, 0x5b, 0xf9, 0x98, 0x29, 0x21, 0x33, 0x65, 0x64, 0xa1, 0x94, 0x64,
		0x95, 0x93, 0xb0, 0x92, 0xd2, 0x73, 0x44, 0x67, 0xa4, 0x3d, 0x23, 0x9e, 0xf6, 0x6b, 0x8a, 0xd9,
		0x98, 0x2f, 0x28, 0x71, 0xba, 0x7b, 0x71, 0x4a, 0x9c, 0x96, 0x5f, 0x87, 0x12, 0x27, 0x6f, 0x8f,
		0x5e, 0x27, 0x4b, 0xc8, 0x1b, 0x69, 0xa0, 0xe2, 0xc9, 0x97, 0xdb, 0x74, 0xeb, 0x04, 0x77, 0xff,
		0xad, 0xec, 0x65, 0x0f, 0x17, 0xc0, 0xc7, 0xc6, 0xc7, 0xc6, 0xc7, 0xc6, 0xc7, 0xc6, 0xc7, 0xc6,
		0xc7, 0xc6, 0xc7, 0xc6, 0xc7, 0xc6, 0xc7, 0xc6, 0xc7, 0x5e, 0x13, 0x1f, 0x5b, 0x21, 0xed, 0x61,
		0xc6, 0x1a, 0x8a, 0xa7, 0x3f, 0xe0, 0x69, 0xe3, 0x69, 0xe3, 0x69, 0xe3, 0x69, 0x6b, 0xea, 0x96,
		0x4d, 0x46, 0x84, 0xfc, 0x7c, 0xe7, 0x07, 0x71, 0x62, 0x33, 0x5f, 0xfa, 0x40, 0x71, 0x09, 0x5d,
		0xc0, 0xa3, 0x7f, 0x1a, 0xa6, 0x00, 0xc8, 0xd8, 0x1b, 0x9e, 0xf5, 0x8a, 0xf7, 0x99, 0x2f, 0xed,
		0x3b, 0x52, 0x72, 0x2e, 0x23, 0xdb, 0xb5, 0x17, 0x7b, 0x07, 0x7b, 0x4c, 0x99, 0xf6, 0xed, 0xe9,
		0x8c, 0xb0, 0xb9, 0x6f, 0x3e, 0x75, 0xfb, 0x59, 0xcf, 0x78, 0x30, 0x8a, 0x73, 0xd7, 0x95, 0xfa,
		0x5b, 0x83, 0xeb, 0xf3, 0x9c, 0x49, 0x67, 0x90, 0xaa, 0x27, 0xa9, 0x4d, 0xad, 0x01, 0xae, 0x07,
		0xd7, 0x83, 0xeb, 0xc1, 0xf5, 0x62, 0xd2, 0x4e, 0x04, 0xcd, 0xd8, 0x2f, 0x21, 0x82, 0xe6, 0xb5,
		0xfb, 0x4f, 0x04, 0x6d, 0x49, 0x1c, 0x48, 0x04, 0x0d, 0x4f, 0xdb, 0xcc, 0xd3, 0xd6, 0x4d, 0x53,
		0x9b, 0xac, 0x80, 0x97, 0x8d, 0x97, 0x8d, 0x97, 0x8d, 0x97, 0x8d, 0x97, 0x8d, 0x97, 0x8d, 0x97,
		0x8d, 0x97, 0x8d, 0x97, 0x8d, 0x97, 0xed, 0xb3, 0x97, 0x4d, 0x03, 0x6f, 0xb9, 0x7e, 0xa2, 0x0f,
		0x7a, 0x61, 0x6e, 0x3d, 0xde, 0xeb, 0xef, 0xf1, 0x3f, 0xa6, 0xc9, 0xf7, 0x3d, 0x3f, 0x59, 0x34,
		0x6f, 0x88, 0x1e, 0xdf, 0xf4, 0xf8, 0x76, 0x7f, 0xc3, 0xdd, 0xf5, 0x01, 0xbf, 0x18, 0xbd, 0xf5,
		0xfb, 0xd1, 0x4b, 0xd7, 0x8f, 0xc6, 0x6f, 0x77, 0x11, 0x37, 0x7f, 0xcb, 0xde, 0x8d, 0xde, 0xe0,
		0x45, 0x15, 0x36, 0xb3, 0x8e, 0xe1, 0x2b, 0x34, 0x3c, 0x8e, 0x6f, 0xdf, 0xb0, 0x15, 0x36, 0x22,
		0x81, 0xc6, 0xb9, 0x53, 0xcf, 0xa2, 0x59, 0x2e, 0xcd, 0x72, 0x9d, 0x70, 0x54, 0x05, 0x6b, 0x96,
		0x3b, 0xb9, 0x32, 0x72, 0x0d, 0x72, 0xef, 0x1e, 0xe9, 0x59, 0x53, 0xdc, 0x6d, 0x9a, 0xe2, 0xba,
		0xbb, 0xb4, 0x6a, 0x97, 0x57, 0xe3, 0x12, 0xfb, 0x81, 0x71, 0xc4, 0x9a, 0xe2, 0x36, 0xc6, 0x37,
		0x40, 0xb8, 0x5f, 0x62, 0xf6, 0x5c, 0xcf, 0x1b, 0x26, 0xd2, 0x0c, 0x57, 0x92, 0x99, 0xa4, 0x61,
		0x62, 0x51, 0x98, 0x32, 0x85, 0x86, 0x89, 0x99, 0x61, 0x0f, 0xe2, 0xa6, 0x66, 0x37, 0x97, 0xa9,
		0x55, 0x08, 0x95, 0x13, 0x2a, 0x77, 0xa5, 0x8a, 0xcc, 0x54, 0x92, 0x85, 0x6a, 0x92, 0x55, 0x51,
		0xc2, 0xaa, 0x6a, 0xb2, 0x01, 0xfa, 0xa1, 0xf2, 0x7e, 0xda, 0x5b, 0x7e, 0x04, 0xd5, 0x52, 0xee,
		0xcb, 0x0b, 0xc2, 0x38, 0x76, 0x3c, 0x9b, 0x2f, 0xbc, 0xdb, 0x1d, 0xf3, 0x74, 0xf7, 0x8f, 0x5b,
		0x99, 0x7b, 0x5c, 0xa2, 0xbe, 0xeb, 0x2a, 0x1e, 0x80, 0xa6, 0xe5, 0x67, 0xc2, 0x06, 0xa0, 0x02,
		0x50, 0xc1, 0x84, 0x0d, 0xc5, 0x09, 0x1b, 0xf7, 0xb4, 0x56, 0x29, 0x75, 0xfd, 0xed, 0xa9, 0x28,
		0x2a, 0x7b, 0xb9, 0x43, 0x5f, 0x77, 0x0a, 0x29, 0x6e, 0xa1, 0xed, 0x1d, 0x68, 0xfb, 0xb8, 0x05,
		0x85, 0xb4, 0xe0, 0x03, 0x85, 0x99, 0xe8, 0x99, 0x4b, 0x20, 0xca, 0x48, 0x2b, 0xa9, 0x95, 0xd2,
		0xd0, 0x46, 0xa2, 0xea, 0x06, 0xda, 0xc8, 0x47, 0x75, 0x54, 0x0c, 0xda, 0x48, 0x5a, 0x4d, 0xcd,
		0xfa, 0x40, 0x7a, 0xe2, 0x28, 0x1d, 0x35, 0x37, 0x42, 0xc2, 0x66, 0xca, 0xcc, 0x42, 0xa9, 0x99,
		0x29, 0x37, 0x2b, 0x25, 0x67, 0xae, 0xec, 0xcc, 0x95, 0x9e, 0xa5, 0xf2, 0xd3, 0x51, 0x82, 0x4a,
		0xca, 0x50, 0x0f, 0xa9, 0x1b, 0x22, 0x77, 0x0b, 0x24, 0x3f, 0x17, 0xd9, 0x6f, 0x0d, 0xc5, 0xe8,
		0xe5, 0x14, 0xa5, 0xfb, 0xe0, 0x0f, 0xb2, 0x7f, 0x1f, 0xa6, 0xd8, 0x16, 0xa4, 0xb6, 0x44, 0x41,
		0xc8, 0x2a, 0xfd, 0xc1, 0x67, 0x43, 0xfb, 0x78, 0x6f, 0x35, 0x4c, 0x24, 0x26, 0x12, 0x13, 0x89,
		0x89, 0xc4, 0x44, 0x7a, 0x6a, 0x22, 0x3f, 0xdd, 0x99, 0xc8, 0xff, 0xd3, 0x18, 0xf4, 0x7a, 0x51,
		0x92, 0x3e, 0x79, 0xba, 0xf5, 0xfc, 0xf9, 0x1d, 0x5b, 0x7e, 0x99, 0xfd, 0xca, 0xb4, 0x5e, 0xef,
		0x3f, 0xf2, 0x67, 0x93, 0x27, 0x37, 0xa3, 0x6f, 0x85, 0xb1, 0xb6, 0x5e, 0xa3, 0xe5, 0xe3, 0x6f,
		0xc3, 0x12, 0x32, 0xf9, 0xa2, 0x7b, 0x7d, 0xc2, 0xa6, 0xd3, 0x08, 0xa2, 0x6f, 0xe9, 0xcb, 0x34,
		0x6a, 0x47, 0xd7, 0x51, 0xda, 0xfb, 0x1e, 0x74, 0x92, 0xa0, 0xf1, 0x65, 0xd8, 0x45, 0xc0, 0x84,
		0xc4, 0x69, 0x85, 0xed, 0xbe, 0x05, 0x8b, 0xe3, 0x3b, 0x81, 0x73, 0x29, 0x4d, 0xa8, 0xeb, 0x64,
		0x83, 0xdc, 0xb9, 0xaa, 0x1e, 0x65, 0x85, 0xdc, 0x0b, 0x7c, 0x89, 0xe6, 0x88, 0xc8, 0x9f, 0xb5,
		0x64, 0x83, 0x25, 0xd9, 0x99, 0xfd, 0xb3, 0xf8, 0x40, 0x70, 0x76, 0xff, 0x8c, 0x4d, 0xd5, 0x22,
		0xfe, 0xab, 0x10, 0xff, 0x66, 0x0e, 0x3f, 0xc4, 0x7f, 0xf9, 0x5c, 0x19, 0x88, 0x7f, 0x58, 0x0d,
		0x58, 0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x03, 0x56, 0x03, 0xe2, 0x7f, 0x13, 0xe2, 0x1f,
		0x13, 0x89, 0x89, 0xc4, 0x44, 0x62, 0x22, 0x31, 0x91, 0x10, 0xff, 0xc5, 0x42, 0xcb, 0xeb, 0xcb,
		0xb2, 0x0a, 0x36, 0x4e, 0x94, 0x3f, 0x6a, 0x0a, 0x33, 0x9d, 0x0a, 0x47, 0x45, 0x94, 0xe3, 0x16,
		0xe8, 0xbd, 0x77, 0x32, 0x7e, 0xbb, 0xbb, 0x7f, 0x7a, 0x1f, 0xb5, 0xca, 0x54, 0x5a, 0x74, 0xaf,
		0x37, 0x9d, 0x78, 0x65, 0xd1, 0xbd, 0xa7, 0x53, 0x58, 0x24, 0xe1, 0xf0, 0x53, 0x46, 0xba, 0x49,
		0x19, 0xe9, 0xa6, 0xcf, 0x85, 0x45, 0xd3, 0x4d, 0x54, 0xf5, 0x62, 0x8c, 0xa2, 0x9d, 0x5a, 0x15,
		0x15, 0xcc, 0xac, 0xa2, 0xa9, 0xd2, 0x99, 0xc6, 0x8c, 0x61, 0xa0, 0x33, 0x4d, 0xf9, 0xb0, 0x93,
		0x5a, 0xa4, 0xb1, 0xd5, 0xe9, 0xfd, 0x15, 0xf6, 0x9a, 0xb7, 0x5e, 0x6c, 0xa3, 0x1d, 0xf6, 0xfb,
		0x51, 0x5f, 0x9f, 0x52, 0x7d, 0x64, 0x4d, 0x5d, 0x62, 0x75, 0x07, 0x62, 0xd5, 0x9d, 0xba, 0xb3,
		0x52, 0x7b, 0xe6, 0xea, 0xcf, 0x5c, 0x0d, 0x5a, 0xaa, 0x43, 0x3d, 0x92, 0x6a, 0x53, 0x91, 0x58,
		0xd5, 0x52, 0x93, 0x73, 0xd5, 0xa5, 0xbe, 0x34, 0xcf, 0x53, 0x9a, 0xda, 0x42, 0xad, 0xab, 0x3a,
		0xd5, 0x3d, 0x44, 0x17, 0xaa, 0xd4, 0x5c, 0xa5, 0x5a, 0xab, 0x56, 0x67, 0x2a, 0xd6, 0x99, 0xaa,
		0x75, 0xa1, 0x72, 0x75, 0x55, 0xaf, 0xb2, 0x0a, 0x36, 0x53, 0xc5, 0x93, 0x85, 0xa2, 0x6f, 0x5d,
		0x3b, 0xc1, 0x1f, 0xdf, 0xec, 0xdb, 0x45, 0x8d, 0x24, 0xcf, 0x66, 0x18, 0x9b, 0x99, 0x4f, 0xeb,
		0x52, 0x31, 0x3b, 0x53, 0xd0, 0xae, 0x14, 0xb5, 0x73, 0x85, 0xed, 0x5c, 0x71, 0xbb, 0x54, 0xe0,
		0x36, 0x8a, 0xdc, 0x48, 0xa1, 0x4f, 0x36, 0x52, 0x3d, 0x79, 0x61, 0xee, 0x6d, 0xd5, 0x4f, 0x66,
		0x98, 0xeb, 0x05, 0x1f, 0x18, 0xae, 0x39, 0xd3, 0xe2, 0xef, 0xd6, 0xd8, 0x6c, 0x94, 0x43, 0x50,
		0x0d, 0x84, 0x54, 0xa9, 0xd2, 0xe7, 0x97, 0xd2, 0xa9, 0x51, 0x01, 0xe4, 0x18, 0x9d, 0x99, 0xa3,
		0x34, 0x9c, 0x02, 0x9c, 0x02, 0x9c, 0x82, 0x02, 0x3a, 0x05, 0x56, 0x68, 0xcf, 0x09, 0xea, 0x73,
		0x88, 0xfe, 0x1c, 0xa1, 0x40, 0x67, 0x68, 0xd0, 0xa5, 0x01, 0x70, 0x6e, 0x08, 0x5c, 0x1b, 0x04,
		0x6f, 0x0c, 0x83, 0x37, 0x06, 0xc2, 0x07, 0x43, 0x61, 0x6b, 0x30, 0x8c, 0x0d, 0x87, 0x3b, 0x54,
		0x39, 0x73, 0xdb, 0x07, 0x71, 0x92, 0xbe, 0x70, 0x71, 0xdb, 0x33, 0xd5, 0xbe, 0xe7, 0x60, 0xe9,
		0xf7, 0xc3, 0xde, 0x25, 0x1a, 0xcd, 0x58, 0x16, 0xf9, 0x71, 0xa3, 0xdd, 0x36, 0xb3, 0x01, 0xe9,
		0xce, 0xd4, 0xab, 0x63, 0x9b, 0x3e, 0xf3, 0x1a, 0x1f, 0xc3, 0xf6, 0x20, 0xf2, 0xe0, 0x3d, 0x5e,
		0xf7, 0xc2, 0x46, 0x1a, 0x77, 0x92, 0xdf, 0xe3, 0xab, 0x78, 0x34, 0xb7, 0xde, 0xd9, 0xfb, 0xdc,
		0x3c, 0x73, 0x28, 0x9a, 0xe1, 0x37, 0x44, 0xf3, 0x81, 0x68, 0x1e, 0x20, 0x9a, 0x6e, 0xdc, 0x00,
		0x77, 0xab, 0x5e, 0x6e, 0x94, 0xf3, 0xfb, 0x0c, 0x55, 0x4b, 0x25, 0x4e, 0x82, 0x4e, 0x23, 0x8d,
		0xd2, 0xbe, 0x3b, 0xa8, 0x7c, 0xf7, 0x0a, 0x00, 0x66, 0x00, 0x33, 0x80, 0x19, 0xc0, 0x0c, 0x60,
		0x2e, 0x09, 0x60, 0xce, 0x4a, 0x51, 0xf6, 0x6b, 0x0e, 0x41, 0xf3, 0x0b, 0x40, 0x33, 0xa0, 0x19,
		0xd0, 0x0c, 0x68, 0x06, 0x34, 0xcf, 0x88, 0xe6, 0xce, 0x8b, 0x5a, 0x6d, 0xff, 0xa0, 0x56, 0xdb,
		0x3e, 0xd8, 0x3d, 0xd8, 0x3e, 0xdc, 0xdb, 0xdb, 0xd9, 0xdf, 0xd9, 0x43, 0x5a, 0xc1, 0xd1, 0xe0,
		0xe8, 0x15, 0x70, 0x74, 0xf7, 0xdf, 0x8e, 0x51, 0xf4, 0xf0, 0x05, 0xc0, 0xd0, 0x60, 0x68, 0x30,
		0x34, 0x18, 0x1a, 0x0c, 0x0d, 0x86, 0x06, 0x43, 0x83, 0xa1, 0xc1, 0xd0, 0x60, 0x68, 0x30, 0x34,
		0x18, 0x1a, 0x0c, 0x0d, 0x86, 0xf6, 0x1c, 0x43, 0x77, 0x06, 0xa9, 0xf3, 0x60, 0xf4, 0xd4, 0x3b,
		0x80, 0xa4, 0x41, 0xd2, 0x20, 0x69, 0x90, 0x34, 0x48, 0x1a, 0x24, 0x0d, 0x92, 0x06, 0x49, 0x83,
		0xa4, 0x41, 0xd2, 0x20, 0x69, 0x90, 0x34, 0x48, 0x1a, 0x24, 0x5d, 0x00, 0x24, 0xed, 0x36, 0x1c,
		0x3d, 0x79, 0x03, 0x50, 0x34, 0x28, 0x1a, 0x14, 0x0d, 0x8a, 0x06, 0x45, 0x83, 0xa2, 0x41, 0xd1,
		0xa0, 0x68, 0x50, 0x34, 0x28, 0x1a, 0x14, 0x0d, 0x8a, 0x06, 0x45, 0x83, 0xa2, 0xbd, 0x5d, 0xc9,
		0xaa, 0x27, 0x9a, 0xf2, 0xbc, 0xcb, 0xb9, 0xeb, 0xfa, 0x34, 0xea, 0x70, 0x7a, 0x18, 0xde, 0xf4,
		0xbf, 0x6c, 0xcd, 0xce, 0x80, 0x99, 0xf9, 0x23, 0x8d, 0xb1, 0x99, 0xee, 0x24, 0xaf, 0xd8, 0xdd,
		0xdc, 0xff, 0x11, 0x7d, 0xb7, 0x69, 0x7c, 0x57, 0x39, 0x8d, 0xfb, 0xe9, 0x51, 0x9a, 0x1a, 0x35,
		0x8f, 0x7f, 0x1b, 0x27, 0xc7, 0xed, 0xe8, 0x56, 0x8e, 0xfb, 0x36, 0x56, 0xfe, 0xd6, 0xab, 0x99,
		0x5a, 0xd1, 0x8d, 0x3d, 0xaf, 0xbc, 0xeb, 0x35, 0xa3, 0x5e, 0xd4, 0x7c, 0x75, 0x7b, 0xa8, 0xc9,
		0xa0, 0xdd, 0x2e, 0xb4, 0x6c, 0x1a, 0xeb, 0xd9, 0xd2, 0xe8, 0xd7, 0x8a, 0x49, 0x2f, 0x66, 0xd1,
		0x89, 0xb4, 0x17, 0x71, 0xf3, 0xb7, 0xd1, 0x07, 0xd6, 0x5f, 0x4f, 0xbe, 0xe6, 0xb7, 0xe1, 0xc7,
		0x6c, 0x14, 0x53, 0x79, 0x17, 0x6b, 0xbe, 0x92, 0xd1, 0x55, 0x2b, 0xea, 0x15, 0x2b, 0xcc, 0x9c,
		0x78, 0x85, 0xa1, 0x96, 0xb7, 0x9b, 0x1c, 0xb4, 0xc3, 0xcf, 0x51, 0x5b, 0x7f, 0x80, 0xe0, 0xd4,
		0x5a, 0xba, 0x83, 0x03, 0xb7, 0x19, 0x1c, 0xf8, 0xeb, 0xd3, 0x60, 0x70, 0xe0, 0xaa, 0x0b, 0x32,
		0x38, 0xd0, 0x17, 0xc3, 0xa6, 0x1e, 0x79, 0x31, 0x1c, 0x62, 0x62, 0x31, 0xb4, 0x64, 0x76, 0x48,
		0xc9, 0x94, 0x4e, 0x5e, 0x63, 0x2b, 0xa8, 0x3b, 0x7b, 0xc4, 0x64, 0xd6, 0x88, 0xd9, 0xd0, 0xdc,
		0x2a, 0xb6, 0x0f, 0xdb, 0x87, 0xed, 0x73, 0x6e, 0xfb, 0xd4, 0x87, 0xe6, 0xda, 0xb5, 0x21, 0x35,
		0x6f, 0x3b, 0x6a, 0x14, 0x1f, 0x34, 0x4b, 0x41, 0x63, 0x4c, 0x6e, 0x91, 0x95, 0xaa, 0x33, 0xe5,
		0xea, 0x42, 0xc9, 0xea, 0x73, 0x73, 0x9b, 0x06, 0xe4, 0xb5, 0x59, 0xca, 0x97, 0x93, 0x14, 0x2f,
		0xc3, 0x94, 0x2e, 0xe3, 0x14, 0x2e, 0xc3, 0x78, 0xae, 0x8b, 0x14, 0x2d, 0x57, 0xa9, 0xd6, 0x8e,
		0x52, 0xb0, 0x5c, 0x26, 0xb1, 0x58, 0x96, 0x0e, 0xb8, 0x48, 0xa9, 0x72, 0x2d, 0x4a, 0xee, 0x53,
		0xa6, 0x9c, 0x4a, 0x57, 0x49, 0xd2, 0x27, 0x2e, 0x8b, 0x1a, 0xdf, 0x7b, 0xa6, 0x8a, 0xab, 0x4c,
		0xea, 0x80, 0x8c, 0xdb, 0x50, 0x82, 0xa9, 0xc0, 0x54, 0x60, 0x2a, 0x30, 0x15, 0x98, 0x0a, 0x4c,
		0x05, 0xa6, 0x02, 0x53, 0x81, 0xa9, 0xc0, 0x54, 0x60, 0x2a, 0x30, 0x95, 0x09, 0xa6, 0x32, 0x48,
		0x63, 0x9b, 0xf1, 0x1e, 0xd4, 0xd3, 0xd9, 0x40, 0x56, 0x20, 0x2b, 0x90, 0x15, 0xc8, 0xaa, 0x80,
		0xc8, 0xca, 0x4c, 0x37, 0x4e, 0xeb, 0xc7, 0x9d, 0x43, 0x83, 0xb5, 0xb2, 0xbd, 0x2c, 0x1d, 0xb4,
		0x9a, 0x9e, 0xa7, 0xbf, 0x5b, 0x35, 0xec, 0x23, 0x31, 0x3e, 0x3d, 0xc3, 0x61, 0xd1, 0x8e, 0xfa,
		0x46, 0x38, 0x68, 0x10, 0xe2, 0xb2, 0x4f, 0x84, 0xe3, 0x22, 0xfc, 0x3b, 0xd4, 0xb3, 0xef, 0xe8,
		0x05, 0x3c, 0x28, 0xb1, 0x77, 0xd0, 0x08, 0xc2, 0x69, 0x03, 0x08, 0x6f, 0x64, 0x6e, 0xbb, 0xf6,
		0x62, 0xef, 0x60, 0x6f, 0x8d, 0x05, 0xaf, 0xa4, 0xbd, 0x0e, 0x2e, 0xcb, 0xd4, 0xeb, 0xc0, 0x81,
		0x7b, 0x11, 0x25, 0x83, 0xeb, 0xa8, 0x37, 0xaa, 0x45, 0xb4, 0xf7, 0x31, 0x76, 0x6a, 0x86, 0x6b,
		0x1e, 0x27, 0x83, 0xeb, 0x5b, 0x45, 0x08, 0xef, 0xe4, 0xf6, 0xfd, 0x35, 0x79, 0x27, 0xc3, 0xf1,
		0x18, 0xf6, 0xe3, 0x30, 0xe0, 0x9d, 0x24, 0x4e, 0x0b, 0xde, 0x49, 0x78, 0x61, 0x78, 0xa7, 0x82,
		0xb8, 0x19, 0x44, 0xf4, 0x0b, 0x4a, 0x58, 0x10, 0xd1, 0x57, 0x05, 0x87, 0x44, 0xf4, 0x4b, 0xc3,
		0x3b, 0x10, 0xd1, 0x27, 0xa2, 0x0f, 0xb2, 0xd2, 0x42, 0x56, 0xb6, 0x69, 0xd2, 0x46, 0xe3, 0x11,
		0x40, 0x55, 0xa0, 0x2a, 0x50, 0x15, 0xa8, 0x0a, 0x54, 0x05, 0xaa, 0x02, 0x55, 0x81, 0xaa, 0x40,
		0x55, 0xa0, 0x2a, 0x50, 0x15, 0xa8, 0x4a, 0xf9, 0xc9, 0xf4, 0x96, 0x35, 0xe8, 0x2d, 0xab, 0xd8,
		0xfa, 0x5e, 0xa1, 0x91, 0xde, 0x86, 0xc7, 0xf2, 0x35, 0x6e, 0x5d, 0xaf, 0x96, 0x48, 0xaa, 0xdb,
		0xb1, 0x5e, 0xbf, 0x43, 0xbd, 0x93, 0x8e, 0xf4, 0xba, 0x1d, 0xe8, 0xa5, 0x45, 0x48, 0x59, 0x35,
		0x15, 0x42, 0x25, 0x55, 0x54, 0xba, 0x65, 0x2a, 0x75, 0x87, 0x97, 0xd5, 0x9c, 0x72, 0xfa, 0x4d,
		0xe6, 0x49, 0x42, 0xe2, 0xad, 0x25, 0xd6, 0xde, 0x8a, 0xb3, 0x8c, 0x54, 0xe4, 0x3f, 0x43, 0x81,
		0xf3, 0x13, 0x6e, 0x34, 0xab, 0xd2, 0x58, 0x56, 0xb8, 0x91, 0xac, 0x78, 0xe3, 0x58, 0x0d, 0xbe,
		0x59, 0x8d, 0x57, 0xd6, 0xe2, 0x8f, 0xd5, 0x79, 0x62, 0x75, 0x3e, 0x58, 0x93, 0xf7, 0xf5, 0x4b,
		0x5f, 0x4b, 0x37, 0x6a, 0x55, 0x6c, 0xcc, 0xaa, 0xde, 0x88, 0x55, 0x89, 0xd9, 0x51, 0x0b, 0x76,
		0x69, 0x06, 0xb7, 0xd4, 0x83, 0x59, 0xda, 0xc1, 0x2b, 0xb3, 0x60, 0x95, 0x59, 0x70, 0xca, 0x22,
		0x18, 0xe5, 0x37, 0xec, 0x56, 0x0b, 0x2e, 0x99, 0x04, 0x93, 0x14, 0x83, 0x47, 0xca, 0xc1, 0x22,
		0x45, 0xe6, 0xcc, 0x22, 0x18, 0x64, 0x95, 0xd4, 0x60, 0x14, 0xec, 0xb1, 0xa4, 0xdf, 0x35, 0x93,
		0x68, 0x2c, 0x82, 0x37, 0xd6, 0x47, 0x6f, 0x1f, 0x9c, 0x31, 0x95, 0x86, 0x82, 0x90, 0xc7, 0x97,
		0xbe, 0x52, 0x35, 0xcf, 0x44, 0xfd, 0x6c, 0x95, 0x0c, 0x34, 0xe5, 0xc6, 0x9c, 0xf8, 0xd8, 0xf8,
		0xd8, 0xf8, 0xd8, 0xf8, 0xd8, 0xf8, 0xd8, 0xf8, 0xd8, 0xf8, 0xd8, 0xf8, 0xd8, 0xf8, 0xd8, 0xf8,
		0xd8, 0x1e, 0xfb, 0xd8, 0x59, 0xc8, 0x2f, 0x88, 0x9b, 0x9a, 0x8e, 0xf6, 0xd4, 0x2a, 0x78, 0xdb,
		0x78, 0xdb, 0x78, 0xdb, 0x78, 0xdb, 0x62, 0xd2, 0xde, 0x4f, 0x7b, 0x71, 0x72, 0xa5, 0xe8, 0x6a,
		0xef, 0xbc, 0x58, 0x03, 0x4b, 0xa0, 0xd8, 0x4a, 0x45, 0xbf, 0x75, 0x0a, 0x56, 0x00, 0x2b, 0x80,
		0x15, 0x80, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0x81, 0x73, 0xf1,
		0xda, 0xd3, 0xd6, 0x0d, 0x6c, 0x2a, 0xb5, 0xd2, 0xc0, 0xcb, 0xc6, 0xcb, 0xc6, 0xcb, 0xc6, 0xcb,
		0xc6, 0xcb, 0xc6, 0xcb, 0xc6, 0xcb, 0xc6, 0xcb, 0xc6, 0xcb, 0xc6, 0xcb, 0xa6, 0xd0, 0x73, 0xe9,
		0xe7, 0x7a, 0x55, 0xe8, 0x29, 0xd7, 0x31, 0x41, 0xa0, 0xc2, 0x73, 0xc3, 0xe1, 0xb1, 0x8f, 0x3b,
		0x1e, 0x08, 0xc6, 0xaa, 0x65, 0x7b, 0x1c, 0xc8, 0xf7, 0x34, 0x30, 0xe9, 0x61, 0x20, 0xdb, 0xb3,
		0x20, 0xef, 0x21, 0x0b, 0xdf, 0x69, 0x9f, 0xee, 0x72, 0x45, 0xa4, 0x3e, 0x5a, 0xb2, 0xb5, 0x40,
		0x3e, 0xbd, 0xb2, 0xba, 0x36, 0x58, 0xed, 0x37, 0x57, 0x14, 0x2d, 0x29, 0x91, 0x72, 0x2f, 0x4a,
		0xab, 0x1d, 0xd7, 0xf2, 0x9b, 0xbd, 0xdc, 0x6f, 0x2c, 0x79, 0x2c, 0x79, 0x8f, 0xc3, 0xd1, 0x31,
		0xac, 0x70, 0x79, 0x45, 0x2e, 0xeb, 0x72, 0x67, 0xbe, 0xf8, 0xc9, 0x2d, 0xf6, 0x37, 0x17, 0x3c,
		0xdb, 0x55, 0xcf, 0xd4, 0xe8, 0x2c, 0x97, 0x38, 0xbb, 0xd5, 0xce, 0x6c, 0xb1, 0x43, 0xfa, 0xf5,
		0x96, 0x2f, 0xb0, 0xdd, 0x95, 0x34, 0x0a, 0xae, 0xda, 0x9d, 0xcf, 0x61, 0x3b, 0x08, 0xd3, 0xb4,
		0x17, 0x7f, 0x1e, 0xa4, 0xd1, 0xe2, 0x44, 0xf5, 0x84, 0x26, 0x7a, 0xf4, 0x29, 0x0b, 0x1e, 0xf6,
		0x72, 0xfd, 0x2f, 0x96, 0x26, 0x8f, 0x57, 0x21, 0x85, 0xa7, 0xc9, 0xde, 0x5b, 0x29, 0x58, 0xe6,
		0xc4, 0x57, 0xa4, 0x71, 0x73, 0xd3, 0xb3, 0xb9, 0x69, 0xd7, 0x87, 0x74, 0xea, 0xf0, 0xc3, 0x1d,
		0x29, 0x80, 0x65, 0x7b, 0x38, 0x8c, 0xfa, 0x96, 0x85, 0xcd, 0xeb, 0x38, 0x09, 0xae, 0x7a, 0x9d,
		0x41, 0x77, 0xf9, 0x60, 0xcb, 0xfd, 0x59, 0xba, 0xf7, 0x1e, 0xb5, 0xe4, 0x3e, 0xae, 0xd6, 0xd0,
		0x65, 0xe5, 0xa8, 0x48, 0x9e, 0xa8, 0x47, 0x0e, 0x41, 0xcf, 0x2b, 0xf0, 0x62, 0x82, 0x2f, 0x76,
		0x01, 0x64, 0x2e, 0x82, 0x8d, 0xd7, 0xb3, 0x6a, 0x93, 0x93, 0xca, 0x94, 0x60, 0xaf, 0x7e, 0x64,
		0x63, 0xa9, 0x99, 0x7e, 0xd8, 0x8a, 0x7b, 0x9d, 0xaf, 0xfb, 0x51, 0xee, 0x50, 0xa2, 0x44, 0xc8,
		0x50, 0xe0, 0x12, 0x49, 0x5d, 0x26, 0xf1, 0x4b, 0x25, 0x7e, 0xb9, 0x64, 0x2f, 0x99, 0x1b, 0x04,
		0x98, 0xb7, 0xc3, 0xd0, 0xf4, 0xbd, 0x09, 0x32, 0xdf, 0x30, 0xe7, 0x79, 0x3f, 0x72, 0x23, 0x47,
		0x4f, 0xce, 0x4b, 0x92, 0x89, 0x84, 0x0b, 0xc4, 0x22, 0xfe, 0x92, 0x11, 0x7e, 0xc1, 0x6b, 0x2b,
		0x7d, 0x7d, 0xd5, 0xae, 0xb1, 0xda, 0x75, 0xd6, 0xb9, 0xd6, 0x7e, 0x10, 0xc5, 0x62, 0x51, 0xf6,
		0x89, 0xc4, 0xb5, 0xa3, 0xb0, 0xd5, 0x8b, 0x5a, 0x12, 0x12, 0x37, 0xb6, 0x9f, 0x02, 0xe3, 0xfc,
		0x2b, 0xe7, 0x19, 0x70, 0x7e, 0xfe, 0x7c, 0x14, 0x27, 0xd8, 0x9a, 0xd1, 0x26, 0xae, 0x08, 0xbe,
		0x1c, 0x16, 0xb5, 0x31, 0x56, 0x3d, 0x42, 0x1a, 0x36, 0x7b, 0x9e, 0x8c, 0x5e, 0xdd, 0x41, 0xaf,
		0xa2, 0x57, 0xd7, 0x55, 0xaf, 0x4a, 0x35, 0x6a, 0x94, 0x77, 0xa7, 0xb4, 0xdd, 0x2a, 0x61, 0xf7,
		0x4a, 0x5c, 0x1d, 0x68, 0xa8, 0x05, 0x45, 0xf5, 0xa0, 0xa5, 0x26, 0xd4, 0xd5, 0x85, 0xba, 0xda,
		0xd0, 0x55, 0x1f, 0x32, 0x6a, 0x44, 0x48, 0x9d, 0xc8, 0xbb, 0x6b, 0x33, 0x12, 0x2b, 0x5e, 0x78,
		0x2a, 0x5c, 0x70, 0xea, 0x47, 0xcf, 0xed, 0xcf, 0x71, 0x1a, 0x74, 0x3b, 0xfd, 0x58, 0x34, 0x91,
		0x66, 0x72, 0x06, 0xf7, 0x9e, 0x8e, 0x16, 0x46, 0x0b, 0xa3, 0x85, 0xd7, 0x4c, 0x0b, 0x0f, 0xe2,
		0x24, 0xdd, 0xad, 0x2a, 0x68, 0xe1, 0x03, 0xc1, 0x47, 0xea, 0xe4, 0x9f, 0xeb, 0x0c, 0xce, 0x51,
		0x2c, 0x39, 0x51, 0x4d, 0x36, 0xd6, 0xce, 0x2f, 0xb7, 0xc8, 0x24, 0xbe, 0xd1, 0x99, 0x54, 0x54,
		0xf8, 0x23, 0xad, 0x55, 0x0f, 0x6b, 0x87, 0xfb, 0x07, 0xd5, 0xc3, 0xbd, 0x02, 0x9f, 0xad, 0xa7,
		0x59, 0xd7, 0x97, 0xa4, 0xff, 0x16, 0x23, 0x33, 0xf4, 0xb1, 0xac, 0x9a, 0xad, 0x99, 0xf4, 0x84,
		0x69, 0x96, 0x76, 0x2b, 0x63, 0x27, 0x0b, 0xc8, 0xd3, 0xca, 0x8c, 0xea, 0x11, 0x1d, 0xd1, 0x23,
		0xce, 0xd2, 0x56, 0x61, 0x69, 0x7d, 0x70, 0xf8, 0x61, 0x69, 0x97, 0xf8, 0x24, 0x58, 0x5a, 0xf8,
		0x01, 0xf8, 0x01, 0xf8, 0x81, 0xc2, 0xf0, 0x03, 0xb0, 0xb4, 0x8b, 0x7c, 0x13, 0x2c, 0x2d, 0x5a,
		0x18, 0x2d, 0x8c, 0x16, 0x86, 0xa5, 0x85, 0xa5, 0x85, 0xa5, 0xb5, 0xb9, 0x6e, 0xf7, 0x8f, 0x14,
		0x96, 0xd6, 0x8f, 0xb3, 0x85, 0xa5, 0xf5, 0x98, 0x7d, 0x28, 0x27, 0x4b, 0x2b, 0xd0, 0x85, 0xa3,
		0x28, 0xd5, 0xf2, 0x59, 0x97, 0x0d, 0x21, 0x6a, 0x46, 0xa6, 0xc3, 0x86, 0x5c, 0x67, 0x0d, 0xd5,
		0x8e, 0x1a, 0x32, 0x9d, 0x34, 0x4a, 0xd8, 0xe6, 0x60, 0xf9, 0x1b, 0x57, 0xc9, 0x15, 0x98, 0xf8,
		0x65, 0x09, 0xf7, 0x87, 0xe8, 0xcd, 0xf0, 0x7d, 0x8e, 0x26, 0xaf, 0x53, 0x3f, 0xba, 0x5d, 0xfc,
		0xcd, 0x70, 0x6d, 0xda, 0x2c, 0xb8, 0x14, 0x03, 0xb5, 0x8e, 0x07, 0xcb, 0x74, 0x01, 0xe8, 0xb5,
		0xaf, 0x72, 0x54, 0x24, 0x8f, 0x7e, 0x9d, 0x2a, 0x64, 0x45, 0x3a, 0x83, 0x2a, 0xe4, 0x4d, 0xcb,
		0x2a, 0xe4, 0x5b, 0x89, 0xce, 0x5f, 0x7e, 0x3c, 0x7c, 0x0a, 0x75, 0xc7, 0xd4, 0x1d, 0x3b, 0x63,
		0xf7, 0x0a, 0x56, 0x77, 0x4c, 0x2d, 0x9c, 0xd1, 0xd5, 0x54, 0xb8, 0xa2, 0xd2, 0x57, 0x55, 0xed,
		0xca, 0xaa, 0x5d, 0x5d, 0x9d, 0x2b, 0xec, 0x07, 0xcf, 0x21, 0x96, 0x65, 0xd1, 0xe8, 0xf4, 0x53,
		0xf9, 0x78, 0xde, 0xf0, 0xa9, 0xc4, 0xf1, 0x3c, 0x52, 0x03, 0x5a, 0xea, 0x40, 0x5d, 0x2d, 0xa8,
		0xab, 0x07, 0x5d, 0x35, 0x21, 0x4b, 0xf4, 0x12, 0xc7, 0x13, 0x79, 0x24, 0x71, 0x3c, 0xe2, 0x78,
		0x86, 0xd7, 0xed, 0xfe, 0x91, 0x12, 0xc7, 0xf3, 0xe3, 0x6c, 0x89, 0xe3, 0x69, 0xcb, 0x7e, 0xa5,
		0xd5, 0xee, 0x74, 0x9a, 0x71, 0x72, 0x15, 0xa4, 0x92, 0xf6, 0x66, 0x62, 0x6b, 0xee, 0x3f, 0x5e,
		0xc8, 0x34, 0xfe, 0x1e, 0xb5, 0xc2, 0x41, 0x7b, 0xe8, 0x04, 0xbc, 0x3e, 0x7d, 0xf7, 0xee, 0xf7,
		0xe3, 0xdf, 0xeb, 0x17, 0xef, 0x4f, 0xdf, 0xe0, 0xcd, 0xe2, 0xcd, 0xe2, 0xcd, 0xae, 0x9b, 0x37,
		0x3b, 0x8c, 0x0e, 0xf5, 0x7b, 0xed, 0xab, 0x40, 0x43, 0xd7, 0xdc, 0x63, 0xb3, 0x6a, 0x82, 0xcf,
		0x3c, 0x4e, 0x06, 0xd7, 0xb7, 0x1b, 0x72, 0x53, 0x22, 0x5b, 0xa2, 0x53, 0x02, 0x42, 0xd9, 0x07,
		0xaa, 0x1d, 0xd5, 0xbe, 0x8e, 0xaa, 0x9d, 0xb2, 0x8f, 0x45, 0xbe, 0xe9, 0x6b, 0x86, 0xf8, 0x84,
		0xd5, 0xee, 0xe8, 0xb1, 0xe8, 0x5d, 0xf4, 0x2e, 0x7a, 0x77, 0xcd, 0xf4, 0x2e, 0x04, 0xb1, 0xa4,
		0x48, 0x42, 0x10, 0xcf, 0x7f, 0x3e, 0x04, 0xb1, 0xb3, 0x23, 0x85, 0x20, 0xd6, 0x7b, 0x1a, 0x85,
		0x1e, 0x45, 0x2e, 0xf4, 0x18, 0xe6, 0xe6, 0x0e, 0xff, 0x7f, 0x81, 0x7b, 0xef, 0xc8, 0xce, 0xa0,
		0x60, 0xee, 0x84, 0xb5, 0xaf, 0x4f, 0x4e, 0x18, 0x73, 0x27, 0x16, 0x91, 0xb8, 0xa2, 0xcc, 0x9d,
		0x28, 0xea, 0xac, 0x09, 0x7a, 0x98, 0xa1, 0x49, 0xd1, 0xa4, 0xfe, 0x69, 0x52, 0xb2, 0x6b, 0x5d,
		0x3b, 0x50, 0x1a, 0xd7, 0x5f, 0x51, 0x0d, 0x68, 0xa9, 0x03, 0x75, 0xb5, 0xa0, 0xae, 0x1e, 0x74,
		0xd5, 0x84, 0x2c, 0xba, 0x86, 0x3c, 0x15, 0x79, 0x24, 0xe4, 0x29, 0xe4, 0xa9, 0xe1, 0x75, 0xbb,
		0x7f, 0xa4, 0x90, 0xa7, 0x7e, 0x9c, 0x2d, 0xe4, 0xa9, 0xb6, 0xec, 0x93, 0x5d, 0x8b, 0x37, 0x8b,
		0x37, 0x8b, 0x37, 0x5b, 0x5c, 0x6f, 0x96, 0xec, 0x5a, 0xb2, 0x6b, 0x51, 0xed, 0xa8, 0x76, 0x54,
		0x7b, 0xe9, 0x54, 0x3b, 0xd9, 0xb5, 0x8b, 0x7c, 0x13, 0xd9, 0xb5, 0xe8, 0x5d, 0xf4, 0x2e, 0x7a,
		0x57, 0x4e, 0x62, 0x21, 0x88, 0x25, 0x45, 0x12, 0x82, 0x78, 0xfe, 0xf3, 0x21, 0x88, 0x9d, 0x1d,
		0x29, 0x04, 0xb1, 0xde, 0xd3, 0xc8, 0xae, 0x2d, 0x49, 0x76, 0xad, 0xdb, 0x9e, 0xe9, 0x39, 0x93,
		0xc2, 0xe2, 0xc6, 0x88, 0x17, 0xbb, 0x8e, 0xae, 0x3f, 0x47, 0xbd, 0xbe, 0x6c, 0x8a, 0xd8, 0xc3,
		0x87, 0xd3, 0x8e, 0xd1, 0x10, 0x08, 0x90, 0x30, 0x46, 0xc2, 0xd8, 0x4f, 0x1e, 0x94, 0xdd, 0xc9,
		0xa0, 0x1d, 0x6b, 0x24, 0x8e, 0xdd, 0x7b, 0xba, 0x2c, 0x3f, 0xb0, 0x03, 0x3f, 0x00, 0x3f, 0x00,
		0x3f, 0x20, 0x14, 0x25, 0x17, 0x52, 0x27, 0x93, 0x07, 0x0a, 0x35, 0x72, 0x9e, 0x7b, 0x11, 0x44,
		0x1a, 0x3b, 0x2b, 0xab, 0x16, 0x35, 0x15, 0xa3, 0xa9, 0x6a, 0x0c, 0x54, 0x8e, 0xb6, 0xea, 0x31,
		0x53, 0x41, 0x66, 0xaa, 0xc8, 0x46, 0x25, 0x29, 0x21, 0x65, 0x61, 0x99, 0x97, 0x56, 0x55, 0x93,
		0x07, 0xb7, 0x7a, 0x9d, 0xeb, 0x20, 0x6c, 0x36, 0x7b, 0x51, 0xbf, 0xaf, 0x27, 0x93, 0x93, 0x64,
		0xa7, 0xe9, 0xd5, 0x9e, 0x15, 0x92, 0x1d, 0xd2, 0x52, 0x6b, 0x16, 0xea, 0xcd, 0x50, 0xcd, 0x59,
		0xa9, 0x3b, 0x73, 0xb5, 0x67, 0xae, 0xfe, 0x6c, 0xd5, 0xa0, 0x8e, 0x3a, 0x54, 0x52, 0x8b, 0x93,
		0xad, 0x11, 0x8f, 0xf4, 0xcc, 0xbd, 0x31, 0x71, 0x57, 0x59, 0x7f, 0xdd, 0x73, 0xc9, 0x0e, 0x15,
		0xd7, 0xc8, 0xf6, 0xec, 0x93, 0xaa, 0xd0, 0xea, 0x5e, 0xfa, 0x07, 0x27, 0xf3, 0xb5, 0x66, 0x70,
		0x36, 0x33, 0x67, 0xf4, 0xc2, 0x60, 0xad, 0xf3, 0x30, 0x4d, 0xa3, 0x5e, 0xa2, 0x7e, 0x5c, 0x93,
		0x05, 0xff, 0xf5, 0xe4, 0xc9, 0xa7, 0xed, 0xe0, 0xf0, 0xf2, 0xc7, 0xa7, 0x9d, 0xe0, 0xf0, 0x72,
		0xf4, 0x8f, 0x3b, 0xc3, 0xff, 0x19, 0xfd, 0x73, 0xf5, 0xd3, 0x76, 0x50, 0x1b, 0xff, 0xf3, 0xde,
		0xa7, 0xed, 0x60, 0xef, 0xf2, 0xe9, 0x9f, 0x7f, 0x3e, 0x7f, 0xfa, 0xf7, 0xee, 0xcd, 0xf2, 0xbf,
		0xf8, 0x5f, 0x15, 0xf5, 0x8f, 0xba, 0xb4, 0x38, 0xa4, 0x77, 0x17, 0x27, 0xff, 0xcb, 0x49, 0xe5,
		0x3d, 0x29, 0xd5, 0x15, 0x6e, 0x9e, 0x95, 0x48, 0xdd, 0xed, 0xa3, 0xee, 0x64, 0x2f, 0x51, 0x18,
		0xb4, 0x8e, 0x82, 0xd7, 0x97, 0x7f, 0xef, 0x3c, 0xab, 0xdd, 0xbc, 0x7c, 0xfa, 0xf7, 0xc1, 0xcd,
		0xc3, 0x3f, 0xfc, 0xf1, 0xd8, 0x5f, 0xdb, 0x79, 0x76, 0x70, 0xf3, 0x72, 0xce, 0x7f, 0xd9, 0xbf,
		0x79, 0xb9, 0xe0, 0x33, 0xf6, 0x6e, 0x9e, 0xcc, 0xfc, 0xd5, 0xdb, 0x3f, 0xaf, 0xce, 0xfb, 0x85,
		0xda, 0x9c, 0x5f, 0xd8, 0x9d, 0xf7, 0x0b, 0xbb, 0x73, 0x7e, 0x61, 0xee, 0x2b, 0x55, 0xe7, 0xfc,
		0xc2, 0xde, 0xcd, 0x8f, 0x99, 0xbf, 0xff, 0xe4, 0xf1, 0xbf, 0xba, 0x7f, 0xf3, 0xf4, 0xc7, 0xbc,
		0xff, 0x76, 0x70, 0xf3, 0xe3, 0xe5, 0x53, 0x94, 0x3f, 0x72, 0x8b, 0xdc, 0x3a, 0x31, 0x85, 0x1b,
		0xc5, 0x7a, 0xef, 0x9b, 0x42, 0x24, 0x3e, 0xa5, 0x1d, 0x3b, 0x36, 0x6d, 0x6a, 0x2d, 0xb8, 0x34,
		0xb8, 0x34, 0xb8, 0x34, 0xb8, 0x34, 0xb8, 0x34, 0xb8, 0x34, 0xb8, 0x34, 0xb8, 0x34, 0xe0, 0x14,
		0x27, 0x05, 0x97, 0x06, 0x97, 0x06, 0x97, 0x06, 0x27, 0x81, 0xf2, 0x47, 0x6e, 0x91, 0x5b, 0xb8,
		0x34, 0x5d, 0x2e, 0xcd, 0xeb, 0xf4, 0x39, 0xe1, 0x42, 0xab, 0x99, 0xe7, 0x3b, 0x2a, 0xbc, 0x7a,
		0x50, 0x62, 0xb4, 0x35, 0x5d, 0x78, 0x20, 0x32, 0xf7, 0x40, 0xef, 0x94, 0x05, 0x4f, 0x58, 0x37,
		0x87, 0xd1, 0x22, 0x77, 0x51, 0x89, 0x67, 0x25, 0x05, 0xdb, 0x0d, 0x8f, 0x4a, 0x0a, 0x76, 0x19,
		0x6d, 0x88, 0x1a, 0x2f, 0xaa, 0x30, 0x07, 0x62, 0x2e, 0xe2, 0x3c, 0x50, 0x78, 0xf6, 0xcc, 0x9c,
		0x88, 0x7b, 0x9a, 0x72, 0x0d, 0xec, 0x8f, 0xcc, 0x7c, 0x89, 0xb9, 0x62, 0x21, 0x31, 0x6f, 0x62,
		0xae, 0x40, 0x68, 0x59, 0x9c, 0x2a, 0x16, 0x07, 0x8b, 0x83, 0xc5, 0xc9, 0xb5, 0x05, 0x14, 0xfd,
		0x38, 0x76, 0xa0, 0xd5, 0x1d, 0x69, 0x0b, 0xf5, 0x66, 0xa8, 0xe6, 0xac, 0xd4, 0x9d, 0xb9, 0xda,
		0x33, 0x57, 0x7f, 0xb6, 0x6a, 0x50, 0x97, 0xc6, 0x22, 0x51, 0x61, 0x39, 0x97, 0x8c, 0x44, 0x85,
		0x65, 0x4e, 0x86, 0x44, 0x05, 0xb1, 0x05, 0x49, 0x54, 0x58, 0xe1, 0x90, 0x48, 0x54, 0x90, 0x38,
		0x29, 0x12, 0x15, 0x16, 0x55, 0x77, 0x24, 0x2a, 0x08, 0x5f, 0x22, 0x02, 0xbe, 0x24, 0x2a, 0x14,
		0x51, 0xf9, 0x23, 0xb7, 0x24, 0x2a, 0x78, 0x82, 0xf0, 0x36, 0x29, 0xfa, 0xa1, 0xe8, 0x07, 0x2e,
		0x0d, 0x2e, 0x0d, 0x2e, 0x0d, 0x2e, 0x0d, 0x2e, 0x0d, 0x2e, 0x0d, 0x70, 0x09, 0x97, 0x06, 0x97,
		0x06, 0x97, 0x06, 0x97, 0x06, 0x97, 0x06, 0x27, 0x01, 0x97, 0x06, 0x97, 0x86, 0xdc, 0xc2, 0xa5,
		0x95, 0x8f, 0x4b, 0xa3, 0xe8, 0xc7, 0xb3, 0xa2, 0x1f, 0x81, 0x71, 0x4c, 0x7a, 0x87, 0xec, 0xd7,
		0xf4, 0x87, 0x7f, 0x44, 0xdf, 0x95, 0xb2, 0x13, 0x2b, 0xa7, 0x71, 0x3f, 0x3d, 0x4a, 0x53, 0xe1,
		0xe9, 0x12, 0x6f, 0xe3, 0xe4, 0xb8, 0x1d, 0x5d, 0x47, 0xc9, 0x68, 0x56, 0x9c, 0x60, 0x02, 0xfb,
		0xdb, 0xf0, 0xdb, 0xd4, 0x93, 0x77, 0x5e, 0xd4, 0x6a, 0xfb, 0x07, 0xb5, 0xda, 0xf6, 0xc1, 0xee,
		0xc1, 0xf6, 0xe1, 0xde, 0xde, 0xce, 0xfe, 0x8e, 0xe0, 0x04, 0xbc, 0xca, 0xbb, 0x5e, 0x33, 0xea,
		0x45, 0xcd, 0x57, 0xb7, 0xbb, 0x9f, 0x0c, 0xda, 0x6d, 0xaf, 0x84, 0x42, 0x49, 0x67, 0xf8, 0xa8,
		0x2b, 0x2a, 0xa2, 0x15, 0x10, 0xbd, 0x41, 0x23, 0xcd, 0xa6, 0xdb, 0x57, 0xce, 0x46, 0xef, 0x7b,
		0x92, 0xbd, 0x6e, 0xfd, 0x6d, 0xb7, 0xdd, 0xaf, 0x7f, 0x88, 0xde, 0x0c, 0xdf, 0xf6, 0x68, 0xf2,
		0xb2, 0xf5, 0x8b, 0x5e, 0xfb, 0xaa, 0xfe, 0x76, 0xf4, 0x4a, 0xb7, 0x57, 0xa6, 0xc2, 0x50, 0xc0,
		0xf2, 0x0c, 0x05, 0x7c, 0x38, 0xfe, 0xce, 0xd5, 0x88, 0xc0, 0x0d, 0xc3, 0x33, 0x1c, 0xdb, 0x94,
		0xe1, 0x45, 0x58, 0xf1, 0x11, 0x22, 0xb6, 0x43, 0xce, 0x56, 0xa8, 0xda, 0x06, 0x19, 0x5b, 0xb0,
		0xea, 0x61, 0x09, 0x5d, 0x34, 0x07, 0x17, 0xac, 0x92, 0x6b, 0xee, 0xe5, 0xaa, 0xaa, 0x7a, 0xb5,
		0x2b, 0xbc, 0xfc, 0x05, 0x5c, 0xee, 0x37, 0x96, 0x3c, 0xfd, 0xbc, 0xa7, 0x6e, 0x7b, 0xda, 0xcb,
		0x6d, 0xf9, 0xe2, 0x1b, 0xb7, 0xc4, 0xa6, 0x55, 0xd2, 0x28, 0x68, 0xf7, 0xbb, 0x41, 0x1a, 0x5f,
		0xaf, 0x32, 0x22, 0xf5, 0x2e, 0x6f, 0xe1, 0xde, 0x63, 0x96, 0x3c, 0xb4, 0xd5, 0xaa, 0x15, 0x57,
		0x4e, 0x35, 0xc8, 0x93, 0x42, 0x20, 0x90, 0x1a, 0x90, 0x37, 0xe4, 0x2f, 0x16, 0xca, 0x17, 0x0b,
		0xd1, 0xcb, 0x84, 0xde, 0x75, 0x15, 0xc3, 0xaa, 0xd5, 0x76, 0x79, 0xa7, 0xfe, 0xc9, 0x4c, 0xf7,
		0xcb, 0x59, 0xd0, 0x9b, 0x3b, 0x2b, 0x47, 0x22, 0xeb, 0x46, 0x30, 0xab, 0x46, 0x2a, 0x6b, 0x46,
		0x3c, 0x2b, 0x46, 0x3c, 0xeb, 0x45, 0x36, 0xab, 0xc5, 0xd6, 0x5d, 0xce, 0x5b, 0xe0, 0x5a, 0x69,
		0xb4, 0xa3, 0x30, 0x19, 0x74, 0x83, 0x66, 0xd4, 0x0e, 0xbf, 0xcb, 0x8d, 0xef, 0xbe, 0xff, 0x58,
		0x99, 0xc1, 0xdd, 0xdb, 0x0c, 0xee, 0xb6, 0xbc, 0xb8, 0x6a, 0x17, 0x58, 0xed, 0x22, 0xeb, 0x5c,
		0x68, 0x3f, 0x38, 0x0d, 0xb1, 0xf4, 0xb2, 0x89, 0xc4, 0x0d, 0xe2, 0x24, 0xdd, 0xd9, 0x97, 0x10,
		0xb8, 0xec, 0x7e, 0xee, 0x0b, 0x3c, 0xea, 0x7d, 0x98, 0x5c, 0xc9, 0xa5, 0x84, 0xc9, 0x52, 0xc7,
		0x0a, 0xb3, 0xae, 0x75, 0x9a, 0x56, 0x7d, 0x0c, 0xdb, 0x83, 0x48, 0xe1, 0xb9, 0xaf, 0x7b, 0x61,
		0xe3, 0x16, 0xf6, 0xfd, 0x1e, 0x5f, 0xc5, 0x23, 0x56, 0xc4, 0xcb, 0x66, 0x32, 0x6f, 0xc3, 0x6f,
		0x85, 0x3b, 0xaa, 0xfd, 0xbd, 0xbd, 0xdd, 0xbd, 0x02, 0x1d, 0x97, 0x27, 0x3c, 0xf3, 0xa5, 0x2b,
		0x4e, 0x34, 0x87, 0x5f, 0x3d, 0x64, 0x2e, 0xda, 0x6d, 0x69, 0x8f, 0xeb, 0xfe, 0x63, 0xf1, 0xb8,
		0xf0, 0xb8, 0xf0, 0xb8, 0xf0, 0xb8, 0xf0, 0xb8, 0xf0, 0xb8, 0xf0, 0xb8, 0x1e, 0x3b, 0xaa, 0xdd,
		0xfd, 0xed, 0x6d, 0x1c, 0xae, 0x75, 0x70, 0xb8, 0x7a, 0x51, 0xa7, 0x9b, 0xc6, 0xd7, 0xf1, 0xff,
		0x8d, 0x46, 0xb1, 0x13, 0x39, 0x9f, 0x6b, 0xe6, 0xc9, 0xb8, 0x5d, 0xb8, 0x5d, 0xb8, 0x5d, 0xb8,
		0x5d, 0xb8, 0x5d, 0xb8, 0x5d, 0xb8, 0x5d, 0x10, 0x5d, 0xc5, 0xf7, 0xbb, 0xc8, 0x27, 0xfb, 0x49,
		0x86, 0xd1, 0xbd, 0x8c, 0x9c, 0x5c, 0xe3, 0x42, 0x56, 0xc8, 0xf1, 0x5a, 0x21, 0x2b, 0x26, 0x5f,
		0x9b, 0x75, 0x91, 0x76, 0xea, 0x62, 0x59, 0x16, 0x55, 0xb2, 0x2c, 0x34, 0x7d, 0x57, 0xb2, 0x2c,
		0xa6, 0x5e, 0x9d, 0x2c, 0x0b, 0xc0, 0x27, 0xe0, 0x13, 0xf0, 0x09, 0xf8, 0x04, 0x7c, 0x02, 0x3e,
		0x01, 0x9f, 0x80, 0x4f, 0x1b, 0xf0, 0x49, 0x96, 0x05, 0x1e, 0x17, 0x1e, 0x17, 0x1e, 0x17, 0x1e,
		0x17, 0x1e, 0x17, 0x1e, 0x17, 0x59, 0x16, 0x38, 0x5c, 0xfe, 0x3a, 0x5c, 0x64, 0x59, 0xe0, 0x76,
		0xe1, 0x76, 0xe1, 0x76, 0xe1, 0x76, 0xe1, 0x76, 0xe1, 0x76, 0x41, 0x74, 0xe1, 0x77, 0x69, 0xff,
		0xe6, 0x7a, 0x66, 0x59, 0xe4, 0xe8, 0xcf, 0x48, 0x23, 0x1d, 0x81, 0x03, 0xa8, 0xac, 0x94, 0x77,
		0xb2, 0x4a, 0xc7, 0xa4, 0x0f, 0xd1, 0x69, 0xbf, 0xfb, 0x61, 0xb4, 0xa8, 0x56, 0x17, 0x9f, 0x0d,
		0xc1, 0x73, 0x5d, 0xf5, 0x3c, 0xad, 0xce, 0x71, 0x89, 0x93, 0x5b, 0xed, 0xc4, 0x16, 0x3b, 0xa5,
		0x5f, 0xef, 0xf9, 0x02, 0xfb, 0x5d, 0x49, 0xa3, 0x20, 0x4e, 0xd2, 0xa8, 0xd7, 0x0a, 0x1b, 0xd1,
		0xf4, 0x37, 0x2e, 0xba, 0xf1, 0xd3, 0x5d, 0x95, 0x1e, 0x7d, 0xd0, 0x82, 0x67, 0xbe, 0x5c, 0x3a,
		0xd3, 0xd2, 0xa0, 0x71, 0x15, 0x70, 0x98, 0x03, 0x04, 0xae, 0x0a, 0xf6, 0x72, 0x83, 0xba, 0xdc,
		0xe0, 0x2d, 0x1f, 0x48, 0x93, 0xd5, 0x03, 0xcb, 0xa6, 0x0b, 0x55, 0x26, 0x02, 0xb8, 0x7a, 0x73,
		0xb0, 0xbb, 0x47, 0xd0, 0x18, 0x4c, 0x91, 0xcd, 0xa0, 0x31, 0xd8, 0x26, 0x8d, 0xc1, 0x8c, 0x89,
		0x42, 0x52, 0x56, 0x1d, 0x11, 0x80, 0x6b, 0x9d, 0xb2, 0x1a, 0x36, 0xaf, 0xe3, 0x24, 0xb8, 0xea,
		0x75, 0x06, 0x5d, 0x39, 0x2a, 0x7f, 0xfa, 0xa1, 0xb0, 0xf8, 0x06, 0x97, 0x55, 0xfa, 0xd2, 0xaa,
		0x5d, 0x5e, 0xb5, 0x4b, 0xac, 0x73, 0x99, 0x65, 0x38, 0x27, 0xff, 0x58, 0xfc, 0x7e, 0xda, 0x8b,
		0x93, 0x2b, 0x41, 0x16, 0x7f, 0xe7, 0x85, 0xd3, 0x1d, 0x12, 0x9d, 0x23, 0x21, 0x3f, 0x3f, 0xc2,
		0x64, 0x6e, 0x84, 0xec, 0xbc, 0x08, 0x57, 0xe9, 0x7c, 0x63, 0x88, 0x1e, 0x37, 0x25, 0xb3, 0xf9,
		0xa6, 0x9e, 0x8a, 0x3d, 0xc2, 0x1e, 0x61, 0x8f, 0x3c, 0xb3, 0x47, 0x82, 0x37, 0x54, 0xd2, 0x2a,
		0x39, 0xd1, 0x81, 0xd3, 0xc3, 0x40, 0xbe, 0xc4, 0x82, 0x5e, 0xf9, 0xc3, 0x07, 0xa3, 0x09, 0xd1,
		0x84, 0x68, 0x42, 0xcf, 0x34, 0x61, 0x3b, 0x0a, 0x5b, 0xbd, 0xa8, 0x25, 0xa9, 0x04, 0x0f, 0x04,
		0x9e, 0x75, 0x9e, 0x45, 0xad, 0x9e, 0x3f, 0xdf, 0x9a, 0xfc, 0xdf, 0xaf, 0x86, 0x1b, 0x0d, 0xc3,
		0x4a, 0xc0, 0x02, 0x60, 0x41, 0x6e, 0x93, 0x98, 0x46, 0xc1, 0x75, 0x94, 0xf6, 0xe2, 0x86, 0x9c,
		0x31, 0xbc, 0x7b, 0x24, 0x66, 0x10, 0x33, 0x88, 0x19, 0xf4, 0xcc, 0x0c, 0x0e, 0xe2, 0x24, 0xdd,
		0xad, 0x0a, 0x5a, 0xc1, 0x03, 0xd2, 0x4c, 0x9d, 0x28, 0xb6, 0x99, 0xc7, 0x92, 0x66, 0x5a, 0xb8,
		0xa3, 0xaa, 0x55, 0x0f, 0x6b, 0x87, 0xfb, 0x07, 0xd5, 0x43, 0x72, 0x4d, 0x97, 0xfe, 0x21, 0xd7,
		0x74, 0x29, 0xee, 0x43, 0x25, 0x45, 0xee, 0xb1, 0xc4, 0xaf, 0xad, 0xc9, 0x1f, 0x16, 0xa0, 0xa1,
		0x57, 0x7c, 0xd5, 0x0d, 0x5a, 0xed, 0x4e, 0xa7, 0x19, 0x27, 0x57, 0xc1, 0xe7, 0x30, 0x69, 0xfe,
		0x15, 0x37, 0x87, 0x5b, 0x94, 0x33, 0x5f, 0x62, 0xce, 0x73, 0xc9, 0x9f, 0x20, 0x7f, 0xc2, 0x99,
		0x47, 0x5b, 0xb4, 0x96, 0x5f, 0xf9, 0x52, 0x97, 0x66, 0x04, 0x2f, 0x57, 0x0a, 0x93, 0xd0, 0x55,
		0x04, 0x94, 0x02, 0x4a, 0x8b, 0x0f, 0x4a, 0xf3, 0x5e, 0xed, 0xc9, 0x83, 0x9a, 0x51, 0x3b, 0x0d,
		0x83, 0x6e, 0xd4, 0x6b, 0x44, 0x49, 0x1a, 0x5e, 0x09, 0xca, 0xc9, 0x58, 0x94, 0x67, 0x56, 0x10,
		0x3a, 0x55, 0x59, 0x5c, 0x20, 0xa6, 0x0e, 0x34, 0xd4, 0x82, 0xa2, 0x7a, 0xd0, 0x52, 0x13, 0xea,
		0xea, 0x42, 0x5d, 0x6d, 0xe8, 0xaa, 0x0f, 0x61, 0x28, 0x27, 0x24, 0xb3, 0x62, 0x5c, 0xd7, 0x8c,
		0xc4, 0x8a, 0xdf, 0xff, 0x69, 0x1d, 0x20, 0x08, 0xdd, 0x85, 0x79, 0x30, 0x79, 0x3e, 0x4c, 0x95,
		0x17, 0x53, 0x26, 0x5d, 0xb4, 0x79, 0x32, 0x0b, 0xee, 0x45, 0x81, 0x37, 0x53, 0xe5, 0xcf, 0xac,
		0x8f, 0x74, 0x67, 0xbb, 0xc8, 0x87, 0xba, 0xe1, 0xe7, 0xd3, 0x2e, 0x3d, 0x21, 0xfc, 0x04, 0x84,
		0xbe, 0xd2, 0xec, 0xfc, 0x95, 0x04, 0xe9, 0x97, 0x5e, 0xd4, 0xff, 0xd2, 0x69, 0x37, 0xfb, 0x0a,
		0x0e, 0xe7, 0x83, 0x05, 0xf0, 0x37, 0xf1, 0x37, 0xf1, 0x37, 0xf1, 0x37, 0xf1, 0x37, 0xf1, 0x37,
		0xf1, 0x37, 0xf1, 0x37, 0xf1, 0x37, 0xad, 0xfc, 0x4d, 0x21, 0x2b, 0x21, 0x9a, 0xe9, 0x38, 0xad,
		0xcf, 0x64, 0x33, 0x1e, 0xa7, 0xaf, 0x95, 0x7a, 0xe6, 0xe3, 0x64, 0x31, 0xd1, 0x0c, 0x48, 0xbf,
		0x90, 0xc2, 0xc4, 0x87, 0x0f, 0xfa, 0xdd, 0xa8, 0x11, 0xb7, 0xe2, 0x46, 0xfe, 0x28, 0xfc, 0xa3,
		0xce, 0xc2, 0xbc, 0x85, 0x40, 0x0e, 0x20, 0x07, 0x90, 0xc3, 0x9a, 0x21, 0x87, 0x28, 0x19, 0x5c,
		0x47, 0x3d, 0x49, 0x05, 0x30, 0xad, 0x04, 0x76, 0x6a, 0x82, 0xcf, 0x3c, 0x4e, 0x06, 0xd7, 0xb7,
		0x9b, 0x70, 0x53, 0x4a, 0xa5, 0x9f, 0x4a, 0x1e, 0xf1, 0x23, 0xba, 0x7e, 0xf8, 0x7c, 0x54, 0x3c,
		0x2a, 0x1e, 0x15, 0x8f, 0x8a, 0x47, 0xc5, 0xdb, 0xa9, 0xf8, 0x41, 0x37, 0x50, 0x0f, 0x02, 0x3c,
		0xb2, 0x06, 0xaa, 0x1e, 0x55, 0x8f, 0xaa, 0x5f, 0x33, 0x55, 0x4f, 0x1c, 0x40, 0xf8, 0x87, 0x38,
		0xc0, 0x4f, 0x9e, 0x4f, 0x1c, 0xc0, 0xd9, 0x91, 0x12, 0x07, 0x50, 0x78, 0x1a, 0x71, 0x80, 0x9c,
		0xd7, 0x8a, 0x38, 0x80, 0x0c, 0x5e, 0x50, 0x86, 0x0a, 0xa0, 0x04, 0x50, 0x02, 0x28, 0x01, 0x94,
		0x00, 0x4a, 0x00, 0x25, 0x80, 0x12, 0x40, 0x09, 0xa0, 0x04, 0x50, 0x02, 0x28, 0xc1, 0x10, 0x25,
		0x38, 0x2d, 0xa6, 0x15, 0x6a, 0xf0, 0x31, 0x79, 0x9e, 0x93, 0x46, 0x1f, 0x8f, 0xb7, 0xbb, 0xc8,
		0xd5, 0xff, 0x23, 0xff, 0xe9, 0xe4, 0x6a, 0x15, 0x3b, 0x1c, 0x92, 0x27, 0xd7, 0x20, 0x76, 0xf8,
		0x38, 0xcf, 0x5a, 0x0f, 0x54, 0x69, 0x3d, 0xe0, 0x03, 0x5a, 0xa3, 0xf5, 0xc0, 0x12, 0x9f, 0x44,
		0xeb, 0x01, 0xc8, 0x1d, 0xc8, 0x1d, 0xc8, 0x1d, 0xc8, 0x1d, 0xc8, 0x1d, 0xc8, 0x1d, 0xc8, 0x1d,
		0xc8, 0x1d, 0xc8, 0x1d, 0x0b, 0x8a, 0x80, 0xd6, 0x03, 0xf8, 0x9b, 0xf8, 0x9b, 0xf8, 0x9b, 0xf8,
		0x9b, 0xf8, 0x9b, 0xf8, 0x9b, 0xf8, 0x9b, 0xf8, 0x9b, 0xf8, 0x9b, 0xea, 0x56, 0x82, 0x60, 0xe2,
		0x4f, 0x16, 0xa3, 0xf5, 0x40, 0x7e, 0x67, 0x81, 0xd6, 0x03, 0x20, 0x07, 0x90, 0x03, 0xc8, 0x81,
		0xba, 0x54, 0x9f, 0x94, 0x3e, 0xad, 0x07, 0x50, 0xf1, 0xa8, 0x78, 0x54, 0x3c, 0x2a, 0x9e, 0xd6,
		0x03, 0x4b, 0x1f, 0x31, 0xad, 0x07, 0x50, 0xf5, 0xa8, 0x7a, 0x54, 0x3d, 0x71, 0x00, 0xe1, 0x1f,
		0xe2, 0x00, 0x3f, 0x79, 0x3e, 0x71, 0x00, 0x67, 0x47, 0x4a, 0x1c, 0x40, 0xe1, 0x69, 0xc4, 0x01,
		0x72, 0x5e, 0x2b, 0xe2, 0x00, 0xb4, 0x1e, 0x00, 0x25, 0x80, 0x12, 0x40, 0x09, 0xa0, 0x04, 0x50,
		0x02, 0x28, 0x01, 0x94, 0x00, 0x4a, 0x00, 0x25, 0x80, 0x12, 0x40, 0x09, 0x82, 0x4f, 0xa0, 0xf5,
		0xc0, 0xfc, 0xd6, 0x03, 0xa3, 0x8a, 0x7b, 0x57, 0x9d, 0x07, 0x36, 0x0c, 0x8f, 0x53, 0xea, 0x18,
		0x7d, 0x3a, 0xbe, 0x4a, 0xae, 0xd6, 0x0d, 0xbd, 0x41, 0x23, 0x4d, 0x32, 0x0f, 0xf7, 0x6c, 0xf4,
		0x5e, 0x27, 0xd9, 0x6b, 0xd5, 0xdf, 0x76, 0xdb, 0xfd, 0xfa, 0xc9, 0x78, 0xf9, 0xfa, 0xc9, 0x55,
		0xf7, 0x75, 0xb6, 0xfa, 0xab, 0xc9, 0xe2, 0x1b, 0x36, 0x67, 0xbe, 0xc2, 0x79, 0x57, 0xee, 0x76,
		0x33, 0x6e, 0xae, 0x7c, 0xda, 0x13, 0xf7, 0xff, 0xde, 0xd3, 0x56, 0x94, 0xbe, 0x7c, 0x0e, 0x4c,
		0x6e, 0x80, 0x2f, 0x01, 0xe8, 0x05, 0x01, 0xbc, 0x14, 0x60, 0x17, 0x07, 0xe8, 0xe2, 0x80, 0x5c,
		0x16, 0x80, 0xdb, 0x6a, 0xcc, 0xdc, 0x80, 0x7a, 0x22, 0x31, 0xed, 0x28, 0x6c, 0xf5, 0xa2, 0x56,
		0x1e, 0x89, 0x19, 0x67, 0x4f, 0x1c, 0xe4, 0x78, 0xc6, 0x79, 0xa6, 0xb4, 0x9f, 0x3f, 0x1f, 0x19,
		0xbe, 0xad, 0x7b, 0x37, 0xbb, 0x10, 0xfa, 0xec, 0x76, 0x17, 0x05, 0x15, 0xda, 0xea, 0x87, 0x92,
		0xb3, 0xcf, 0x8e, 0x77, 0x1a, 0x2d, 0x6e, 0xa1, 0xcf, 0x56, 0xd0, 0x67, 0x71, 0xab, 0x28, 0xda,
		0x2c, 0x6f, 0x4f, 0x9c, 0x4a, 0x63, 0x2c, 0xb1, 0x42, 0xdd, 0xae, 0xb2, 0xe7, 0x79, 0xd6, 0xee,
		0x6a, 0xdb, 0xcf, 0x76, 0x57, 0xb9, 0xae, 0xa7, 0xf4, 0x35, 0x55, 0xbb, 0xae, 0x6a, 0xd7, 0x56,
		0xe3, 0xfa, 0xfa, 0x81, 0xce, 0xc5, 0x5a, 0x5d, 0x4d, 0x8c, 0xa2, 0x7c, 0x08, 0xf1, 0xee, 0xd1,
		0x84, 0x0f, 0xbd, 0x51, 0x06, 0x5a, 0x4a, 0x41, 0x5d, 0x39, 0xa8, 0x2b, 0x09, 0x4d, 0x65, 0x21,
		0x47, 0x0a, 0x6e, 0x16, 0x22, 0x74, 0x98, 0x1f, 0xf9, 0x68, 0x20, 0xa1, 0xb9, 0xc8, 0x68, 0x6b,
		0x78, 0xcc, 0x2f, 0x27, 0x0a, 0xab, 0xff, 0xf0, 0x0f, 0xb2, 0x7f, 0x1f, 0xf2, 0x46, 0x25, 0xca,
		0x21, 0xe9, 0x0f, 0x3e, 0x2b, 0xea, 0xff, 0x7b, 0x4f, 0xc7, 0x04, 0x60, 0x02, 0x30, 0x01, 0x98,
		0x80, 0xc2, 0x9a, 0x80, 0x4f, 0x77, 0x26, 0xe0, 0xff, 0x34, 0x06, 0xbd, 0x5e, 0x94, 0xa4, 0x4f,
		0x9e, 0x6e, 0x3d, 0x7f, 0x7e, 0xc7, 0xa6, 0x5d, 0x66, 0xbf, 0x32, 0xad, 0xf7, 0xfa, 0x8f, 0xfc,
		0xd9, 0xe4, 0xc9, 0xcd, 0xe8, 0x5b, 0x85, 0x58, 0xe3, 0xe6, 0x66, 0xe5, 0xf8, 0xdb, 0x30, 0xcc,
		0x9b, 0x3f, 0x7f, 0x47, 0x1e, 0xe0, 0x76, 0x1a, 0x41, 0xf4, 0x2d, 0x7d, 0x99, 0x46, 0xed, 0xe8,
		0x3a, 0x4a, 0x7b, 0xdf, 0x83, 0x4e, 0x12, 0x34, 0xbe, 0x0c, 0x13, 0x8e, 0x54, 0x40, 0x6f, 0x2b,
		0x6c, 0xf7, 0x35, 0x50, 0xaf, 0x6b, 0xc0, 0x7b, 0x49, 0x38, 0x7a, 0x9a, 0x78, 0xef, 0x45, 0x2d,
		0x1a, 0xe0, 0xd3, 0x00, 0x1f, 0x46, 0x10, 0x46, 0x10, 0x46, 0x10, 0x38, 0x08, 0x1c, 0x04, 0x0e,
		0x02, 0x07, 0x61, 0x04, 0x61, 0x04, 0x31, 0x01, 0x98, 0x00, 0x4c, 0x00, 0x26, 0x00, 0x46, 0x70,
		0xad, 0x19, 0xc1, 0x12, 0xd2, 0x3d, 0x14, 0x1d, 0x14, 0xf0, 0xd4, 0xec, 0x6a, 0x0d, 0xc6, 0xff,
		0xf4, 0x3e, 0x6a, 0xf9, 0x9c, 0x93, 0x9b, 0x8f, 0xfa, 0x13, 0xa1, 0xfc, 0xc4, 0x72, 0x70, 0xab,
		0x54, 0x15, 0x68, 0x3a, 0x69, 0x54, 0x15, 0x08, 0xd2, 0x73, 0x95, 0xb0, 0x79, 0x1d, 0x27, 0xc1,
		0x55, 0xaf, 0x33, 0xe8, 0xca, 0x31, 0xef, 0xd3, 0x0f, 0x95, 0xe1, 0xdf, 0xb7, 0x4b, 0x9e, 0x91,
		0xcb, 0x00, 0x5a, 0x06, 0xd0, 0xea, 0x63, 0xa7, 0x29, 0x3b, 0xd9, 0x8b, 0x93, 0x2b, 0x09, 0x81,
		0x1b, 0x1b, 0xcd, 0x17, 0x4e, 0x77, 0x48, 0xb4, 0x0e, 0x5d, 0xbe, 0xfe, 0xdc, 0xa4, 0xee, 0x5c,
		0xb6, 0xde, 0xdc, 0x4d, 0x04, 0x58, 0xa4, 0xd4, 0x74, 0x46, 0xda, 0x05, 0x4a, 0x4e, 0xb1, 0x47,
		0xd8, 0x23, 0xec, 0x91, 0x9a, 0x3d, 0x12, 0xbc, 0xa1, 0x92, 0x56, 0xc9, 0x4d, 0x16, 0x4c, 0xaf,
		0x7d, 0x15, 0x5c, 0x47, 0xd7, 0x9f, 0xa3, 0x5e, 0xff, 0x4b, 0x2c, 0xe8, 0x95, 0x3f, 0x7c, 0x30,
		0x9a, 0x10, 0x4d, 0x88, 0x26, 0xf4, 0x4c, 0x13, 0xca, 0x45, 0x33, 0x24, 0xa3, 0x18, 0xd3, 0xc5,
		0xfe, 0x93, 0xff, 0x4b, 0xa3, 0xe0, 0xaa, 0xdd, 0xf9, 0x1c, 0xb6, 0xa7, 0x09, 0xcf, 0x5b, 0x25,
		0x33, 0xfa, 0xff, 0x5b, 0xf9, 0x83, 0xd8, 0xc0, 0x02, 0x60, 0xc1, 0x70, 0x4e, 0x51, 0x14, 0x5c,
		0x47, 0x69, 0x2f, 0x6e, 0xc8, 0x19, 0xc3, 0xbb, 0x47, 0x62, 0x06, 0x31, 0x83, 0x98, 0x41, 0xcf,
		0xcc, 0xe0, 0x20, 0x4e, 0xd2, 0xdd, 0xaa, 0xa0, 0x15, 0x94, 0x30, 0x82, 0xb2, 0x0d, 0x61, 0x65,
		0x1b, 0x26, 0x2a, 0x24, 0xd7, 0xa8, 0x74, 0x09, 0xd5, 0x6a, 0xf8, 0xaa, 0xd9, 0x13, 0xf4, 0x46,
		0xb6, 0x03, 0x65, 0xe1, 0x8e, 0xaa, 0x56, 0x3d, 0xac, 0x1d, 0xee, 0x1f, 0x54, 0x0f, 0xf7, 0x0a,
		0x74, 0x66, 0x9e, 0xe4, 0xbb, 0x5c, 0x92, 0x99, 0xb1, 0x0c, 0xf7, 0xe1, 0x22, 0x33, 0x23, 0x47,
		0x06, 0xcd, 0x0a, 0xc9, 0x11, 0x1b, 0x8a, 0xe7, 0x71, 0xeb, 0x0d, 0xe5, 0xa4, 0xd3, 0xf2, 0x61,
		0xa6, 0xfc, 0x18, 0x49, 0x05, 0x13, 0xe5, 0xc3, 0x40, 0xcb, 0x1e, 0x42, 0xce, 0xcb, 0xe0, 0xe4,
		0x12, 0x54, 0x56, 0xca, 0xd9, 0x59, 0x3c, 0x11, 0x69, 0xb9, 0xeb, 0xb5, 0xf8, 0x25, 0x59, 0xec,
		0x6f, 0x2e, 0x78, 0x82, 0xab, 0x9e, 0x9c, 0xe1, 0x89, 0x2d, 0xb6, 0x8f, 0xbf, 0xde, 0x95, 0x9f,
		0xff, 0x8d, 0x5f, 0xec, 0xd7, 0xb2, 0xfb, 0xa4, 0xb0, 0x3f, 0x0b, 0xc8, 0xeb, 0x02, 0xf2, 0xf9,
		0xf3, 0xdd, 0x9c, 0xbf, 0x47, 0x3f, 0xd9, 0x9f, 0x4a, 0xb6, 0xde, 0xcf, 0x77, 0x65, 0x82, 0x73,
		0x86, 0x7f, 0xfb, 0x17, 0xbb, 0xbd, 0x98, 0x77, 0xb7, 0x30, 0x83, 0xb0, 0x0c, 0x43, 0x30, 0xcd,
		0x00, 0x24, 0x51, 0x7a, 0x7b, 0x04, 0x8b, 0xec, 0xfc, 0x92, 0x20, 0x7f, 0x65, 0x10, 0xbf, 0x32,
		0x48, 0x7f, 0x08, 0xc2, 0xc7, 0xdf, 0xa6, 0x7c, 0x6f, 0x16, 0xc6, 0xc9, 0x2b, 0xd0, 0xc1, 0xcb,
		0xd0, 0xbd, 0xb3, 0xbd, 0x5b, 0x7f, 0xcd, 0xd5, 0xae, 0x76, 0x1b, 0xba, 0x9d, 0x76, 0xdc, 0xf8,
		0x1e, 0xb4, 0x3a, 0xbd, 0xbf, 0xc2, 0x5e, 0x33, 0x4e, 0xae, 0x16, 0xbf, 0x1a, 0xb3, 0xbf, 0xba,
		0xd8, 0x3d, 0xd9, 0x71, 0x7c, 0x4f, 0xba, 0xad, 0x52, 0x5e, 0x91, 0x6e, 0x4b, 0xfb, 0x76, 0x2c,
		0x9a, 0xcb, 0x78, 0xe7, 0xde, 0x2e, 0x3e, 0xa0, 0x6c, 0x36, 0xd2, 0xbc, 0x28, 0x9b, 0xb9, 0x64,
		0x5a, 0xf0, 0xd2, 0x44, 0xee, 0x2a, 0x84, 0xed, 0xd2, 0xe2, 0x96, 0x97, 0x7e, 0xcd, 0x4d, 0xb3,
		0xe6, 0xa6, 0x53, 0x57, 0x11, 0x47, 0x1d, 0x27, 0x71, 0xd9, 0x94, 0xdb, 0x1c, 0x95, 0xef, 0xb9,
		0x2b, 0xdc, 0x57, 0xcc, 0x69, 0x5f, 0x39, 0x1a, 0x91, 0x27, 0xfa, 0xb0, 0xb2, 0x50, 0xe7, 0x15,
		0x6e, 0x31, 0x21, 0x17, 0x13, 0x76, 0x09, 0xa1, 0xb7, 0x21, 0x1c, 0x56, 0xcd, 0x3f, 0xcf, 0xdb,
		0xff, 0x59, 0xa6, 0xef, 0x73, 0xd9, 0xda, 0xae, 0x77, 0x69, 0xbb, 0x6e, 0x75, 0xad, 0xdc, 0xf0,
		0xac, 0xf9, 0xcb, 0x3d, 0xba, 0xdd, 0xf6, 0xb4, 0x4f, 0x1d, 0x8c, 0xbc, 0x6c, 0xc1, 0xd2, 0x8f,
		0x39, 0x0b, 0x10, 0x65, 0x57, 0xbf, 0xc0, 0xd2, 0x17, 0x59, 0xed, 0x42, 0xab, 0x5d, 0x6c, 0x8d,
		0x0b, 0x9e, 0xef, 0xa2, 0xe7, 0xbc, 0xf0, 0xcb, 0x33, 0x07, 0x0a, 0xcc, 0x82, 0x24, 0xf3, 0xb0,
		0x0c, 0x33, 0x31, 0xf9, 0xbf, 0xa1, 0x0a, 0x89, 0xa3, 0xfe, 0xe8, 0x1f, 0xbe, 0x67, 0x94, 0x45,
		0xc6, 0x0f, 0xac, 0x3a, 0x6b, 0x26, 0xff, 0xb9, 0x52, 0xe8, 0x80, 0xc6, 0x45, 0xe3, 0xa2, 0x71,
		0x1d, 0xdc, 0xce, 0x4d, 0x2f, 0x8a, 0x1c, 0x48, 0x31, 0xd8, 0x9a, 0x21, 0xa9, 0xb7, 0xa6, 0x3a,
		0xb2, 0xdc, 0xa5, 0x18, 0xe4, 0xe9, 0xc9, 0xca, 0x90, 0x47, 0xb0, 0x39, 0xd8, 0xdc, 0x7f, 0x05,
		0xc5, 0x80, 0x47, 0xff, 0x74, 0x19, 0x03, 0x1e, 0x95, 0xb4, 0x19, 0x03, 0x1e, 0x57, 0xd2, 0x66,
		0x0c, 0x78, 0x5c, 0x59, 0xe8, 0x18, 0xf0, 0x68, 0x75, 0x3d, 0x41, 0xb5, 0x1a, 0xd7, 0xd7, 0x0f,
		0x54, 0x4b, 0x3b, 0xf7, 0xfc, 0x8f, 0xa3, 0x97, 0x2f, 0xbd, 0x7c, 0x8d, 0x94, 0x85, 0x8c, 0xd2,
		0x10, 0x52, 0x1e, 0xf2, 0xd4, 0x98, 0x02, 0xf2, 0xd1, 0x40, 0x42, 0x73, 0x91, 0x11, 0xed, 0xdc,
		0x69, 0xe7, 0x8e, 0x09, 0xc0, 0x04, 0x60, 0x02, 0x30, 0x01, 0xb4, 0x73, 0xb7, 0x47, 0x33, 0x0c,
		0x78, 0x64, 0xc0, 0xe3, 0xaf, 0xbe, 0xc5, 0xeb, 0x8e, 0xff, 0x0b, 0x86, 0x0f, 0x19, 0xf0, 0xf8,
		0xb8, 0xa3, 0xc8, 0x80, 0x47, 0x18, 0x41, 0x18, 0x41, 0x18, 0x41, 0xe0, 0x20, 0x70, 0x10, 0x38,
		0x08, 0x1c, 0x84, 0x11, 0x84, 0x11, 0xc4, 0x04, 0x60, 0x02, 0x30, 0x01, 0x98, 0x00, 0x18, 0xc1,
		0x75, 0x64, 0x04, 0x4b, 0x48, 0xf7, 0x30, 0xe0, 0xb1, 0x80, 0xa7, 0xa6, 0x37, 0xe0, 0xf1, 0x7c,
		0xf8, 0x36, 0xaf, 0x27, 0x2f, 0xc3, 0xb0, 0x47, 0x07, 0xb4, 0x9f, 0x77, 0xc3, 0x1e, 0xa9, 0x2e,
		0x58, 0xc9, 0x1d, 0xa3, 0xf2, 0x9f, 0xca, 0x7f, 0x77, 0xb8, 0x8c, 0x3a, 0x54, 0xea, 0x50, 0xed,
		0x70, 0x15, 0x95, 0xff, 0x72, 0x5e, 0x31, 0x95, 0xff, 0x68, 0x5c, 0x34, 0x2e, 0x1a, 0xd7, 0xfe,
		0x76, 0x6e, 0x52, 0xf9, 0x5f, 0x28, 0x56, 0x80, 0xe1, 0x02, 0xd3, 0x8f, 0x60, 0xb8, 0x40, 0xde,
		0x43, 0xf0, 0x6b, 0xb8, 0xc0, 0x62, 0x97, 0x40, 0x7e, 0xb8, 0xc0, 0x7c, 0x12, 0x8c, 0x41, 0x03,
		0x32, 0xa7, 0x27, 0x36, 0x68, 0x60, 0x81, 0x5e, 0xd8, 0xb7, 0xdf, 0x13, 0xf4, 0xa3, 0x76, 0x34,
		0x1c, 0x06, 0x14, 0x5c, 0xf5, 0x3a, 0x83, 0xee, 0x0a, 0xad, 0x9d, 0x1f, 0x7f, 0x0c, 0x5d, 0x9e,
		0xed, 0x9c, 0xcf, 0x75, 0xee, 0xf2, 0xfc, 0x98, 0xf4, 0xad, 0xde, 0xf0, 0xf9, 0xd1, 0xa7, 0xd1,
		0xfb, 0x59, 0x0d, 0x87, 0xd1, 0xfb, 0x99, 0xde, 0xcf, 0xb6, 0xf4, 0x06, 0x11, 0x20, 0x27, 0xb4,
		0xc5, 0x1a, 0x47, 0x80, 0x86, 0x46, 0x44, 0x94, 0x75, 0x9c, 0x3c, 0x11, 0xc6, 0x11, 0xc6, 0x11,
		0xc6, 0xd1, 0x23, 0xc6, 0xb1, 0x9f, 0xf6, 0x7e, 0x3d, 0x31, 0xa9, 0x18, 0x5c, 0x63, 0x0e, 0xab,
		0x76, 0xdd, 0x6d, 0xf7, 0x83, 0x76, 0xbf, 0x2b, 0xa7, 0xf1, 0x26, 0x4f, 0x44, 0xe3, 0xa1, 0xf1,
		0xd0, 0x78, 0x1e, 0x69, 0xbc, 0x02, 0x45, 0xb5, 0x9f, 0x3f, 0x1f, 0xcd, 0xf8, 0x6c, 0xf7, 0xbb,
		0xfd, 0xad, 0x46, 0x27, 0xe9, 0xa7, 0xbd, 0x30, 0x4e, 0xa2, 0x66, 0x70, 0x8b, 0xfa, 0xb7, 0xd2,
		0x41, 0x92, 0x44, 0xed, 0x7e, 0xf6, 0xbf, 0x0b, 0xcf, 0xe7, 0xd3, 0x3e, 0xb1, 0x5c, 0xd4, 0xfd,
		0xcc, 0xd3, 0x72, 0x53, 0xf9, 0xb3, 0x4f, 0x54, 0xa0, 0xf6, 0x67, 0x16, 0xc9, 0x45, 0xf5, 0x0b,
		0xda, 0x44, 0xe2, 0x6f, 0x8f, 0x90, 0xd7, 0x8f, 0xf2, 0xbf, 0x8f, 0xfe, 0x69, 0x01, 0xfa, 0x71,
		0xe7, 0x06, 0x6b, 0x52, 0x20, 0x8d, 0x3e, 0xdc, 0xf0, 0x24, 0xf4, 0xe1, 0x76, 0xe8, 0x4a, 0xcc,
		0xf6, 0xe1, 0x9e, 0xdc, 0x68, 0x72, 0xfc, 0x17, 0xda, 0x7c, 0x72, 0xfc, 0xd1, 0x5c, 0x45, 0xd0,
		0x5c, 0x30, 0xbc, 0xf0, 0x1d, 0xf0, 0x1d, 0xf0, 0x1d, 0x0b, 0x5a, 0x46, 0x18, 0x5e, 0x18, 0x5e,
		0x34, 0x1e, 0x1a, 0x6f, 0x5d, 0x34, 0x1e, 0x0c, 0xaf, 0xee, 0x89, 0xc1, 0xf0, 0xc2, 0xf0, 0x96,
		0x86, 0xe1, 0x2d, 0x5f, 0xdd, 0xc5, 0x8a, 0x50, 0x8c, 0x9a, 0x8b, 0xdc, 0x07, 0xe0, 0x7b, 0xcd,
		0xc5, 0xe2, 0xd7, 0xc2, 0xa0, 0x12, 0xe3, 0xd6, 0x1c, 0x5e, 0x8c, 0x57, 0x7d, 0x33, 0x5c, 0x94,
		0x92, 0x0c, 0xe9, 0xc3, 0x35, 0xad, 0xce, 0xc8, 0x6a, 0xb0, 0x57, 0x28, 0xc8, 0x18, 0xff, 0x26,
		0x35, 0x18, 0x76, 0xd0, 0x65, 0xad, 0x6b, 0x30, 0x56, 0x6b, 0x69, 0x72, 0x5f, 0x60, 0xbf, 0x53,
		0x67, 0xa1, 0x87, 0xd4, 0xa9, 0xb3, 0xa0, 0xce, 0xc2, 0x96, 0x00, 0x23, 0x0a, 0xe7, 0x84, 0xd8,
		0x5a, 0xe3, 0x28, 0xdc, 0x5d, 0x7b, 0x1a, 0x31, 0x52, 0xfa, 0xee, 0x91, 0xb0, 0xd2, 0xb0, 0xd2,
		0xb0, 0xd2, 0x1e, 0xb1, 0xd2, 0x25, 0x8a, 0xc3, 0xc1, 0x39, 0x3e, 0x86, 0xbf, 0x1f, 0xb4, 0x20,
		0xf3, 0x3f, 0x75, 0x34, 0xbf, 0xfd, 0x11, 0xb3, 0x3b, 0x24, 0x8f, 0xe2, 0xfc, 0x91, 0x3c, 0x9a,
		0xd7, 0x20, 0x88, 0x26, 0x8f, 0xe6, 0x6c, 0x9e, 0x68, 0xa3, 0xc2, 0x7a, 0x83, 0xf6, 0x12, 0x84,
		0xe3, 0xdc, 0x33, 0x18, 0x3d, 0x06, 0xdc, 0x8a, 0xea, 0x02, 0xb7, 0x2e, 0x76, 0xe9, 0xe4, 0x20,
		0xeb, 0xf0, 0x69, 0x9e, 0xcd, 0x66, 0x04, 0xad, 0x82, 0x56, 0x8b, 0x84, 0x56, 0xc5, 0x66, 0x33,
		0x86, 0x0d, 0xb1, 0x91, 0x28, 0xf7, 0x84, 0x37, 0x7b, 0xae, 0xec, 0x48, 0xae, 0x9d, 0x35, 0x1d,
		0xc9, 0xd5, 0x65, 0x24, 0x97, 0x8b, 0x91, 0x5c, 0xdd, 0xd2, 0x8e, 0xe4, 0x92, 0x52, 0x1f, 0x93,
		0x07, 0xe6, 0x0c, 0x28, 0xfd, 0xf2, 0x12, 0xe4, 0x0a, 0x34, 0x19, 0xa9, 0x15, 0x35, 0xf5, 0xa2,
		0xa9, 0x66, 0xd4, 0xd5, 0x8d, 0xb6, 0xda, 0x31, 0x53, 0x3f, 0x66, 0x6a, 0xc8, 0x42, 0x1d, 0xc9,
		0xaa, 0x25, 0x61, 0xf5, 0xa4, 0xa6, 0xa6, 0x26, 0x0f, 0x6e, 0x46, 0x8d, 0xb0, 0xdb, 0x1f, 0xb4,
		0xc3, 0x34, 0x0a, 0xae, 0x7a, 0x8a, 0x42, 0x39, 0xbe, 0x55, 0x0f, 0x17, 0x54, 0x92, 0x98, 0xdf,
		0xa3, 0x56, 0x38, 0x68, 0x0f, 0x05, 0xa6, 0x15, 0xb6, 0xfb, 0x6a, 0xeb, 0xc8, 0x8e, 0x48, 0x35,
		0x53, 0xa0, 0x16, 0x8a, 0xd4, 0x4c, 0xa1, 0x5a, 0x29, 0x56, 0x73, 0x05, 0x6b, 0xae, 0x68, 0x2d,
		0x15, 0xae, 0x8e, 0xe2, 0x55, 0x52, 0xc0, 0x93, 0x8d, 0x11, 0x1f, 0xe1, 0x3a, 0xf7, 0xb6, 0x7c,
		0xee, 0x74, 0xda, 0x51, 0x98, 0x68, 0xde, 0x97, 0xb1, 0xd7, 0xb7, 0xb3, 0x51, 0x8c, 0x83, 0x55,
		0x38, 0xd4, 0x4a, 0x33, 0xee, 0x37, 0xc2, 0x5e, 0xd3, 0xc0, 0xf0, 0x65, 0x0b, 0x61, 0xf0, 0x30,
		0x78, 0x18, 0x3c, 0x0c, 0x1e, 0x06, 0x0f, 0x83, 0xe7, 0xc2, 0xe0, 0x3d, 0xcc, 0xe7, 0xd1, 0xb7,
		0x7c, 0x33, 0x2b, 0x62, 0x9a, 0x30, 0x4d, 0x98, 0x26, 0x4c, 0x53, 0x61, 0x4c, 0x93, 0x5c, 0x5b,
		0x85, 0x5f, 0x9a, 0xa6, 0x03, 0xc5, 0x35, 0xe6, 0xb4, 0x61, 0x98, 0xfc, 0x9f, 0x54, 0x97, 0x85,
		0xa2, 0x1b, 0xc8, 0x6f, 0x69, 0xf0, 0xa5, 0xd3, 0xb5, 0x30, 0x8c, 0xd9, 0x4a, 0x18, 0x44, 0x0c,
		0x22, 0x06, 0x11, 0x83, 0x58, 0x18, 0x83, 0x18, 0x77, 0x83, 0xb0, 0xd9, 0xec, 0x45, 0xfd, 0xbe,
		0x85, 0x4d, 0x3c, 0x54, 0x5c, 0x23, 0xdb, 0xb3, 0x4f, 0xaa, 0x22, 0xab, 0x7b, 0xe5, 0x1f, 0x9c,
		0xcc, 0xd7, 0x9a, 0xc1, 0xd9, 0xcc, 0x9c, 0xd1, 0x0b, 0x83, 0xb5, 0xce, 0xc3, 0x34, 0x8d, 0x7a,
		0x89, 0xfa, 0x71, 0x4d, 0x16, 0xfc, 0xd7, 0x93, 0x27, 0x9f, 0xb6, 0x83, 0xc3, 0xcb, 0x1f, 0x9f,
		0x76, 0x82, 0xc3, 0xcb, 0xd1, 0x3f, 0xee, 0x0c, 0xff, 0x67, 0xf4, 0xcf, 0xd5, 0x4f, 0xdb, 0x41,
		0x6d, 0xfc, 0xcf, 0x7b, 0x9f, 0xb6, 0x83, 0xbd, 0xcb, 0xa7, 0x7f, 0xfe, 0xf9, 0xfc, 0xe9, 0xdf,
		0xbb, 0x37, 0xcb, 0xff, 0xe2, 0x7f, 0x55, 0xd4, 0x3f, 0xea, 0xd2, 0xe2, 0x90, 0xde, 0x5d, 0x9c,
		0xfc, 0x2f, 0x27, 0x95, 0xf7, 0xa4, 0x54, 0x57, 0xb8, 0x79, 0x56, 0x22, 0x75, 0xb7, 0x8f, 0xba,
		0x93, 0xbd, 0x44, 0x61, 0xd0, 0x3a, 0x0a, 0x5e, 0x5f, 0xfe, 0xbd, 0xf3, 0xac, 0x76, 0xf3, 0xf2,
		0xe9, 0xdf, 0x07, 0x37, 0x0f, 0xff, 0xf0, 0xc7, 0x63, 0x7f, 0x6d, 0xe7, 0xd9, 0xc1, 0xcd, 0xcb,
		0x39, 0xff, 0x65, 0xff, 0xe6, 0xe5, 0x82, 0xcf, 0xd8, 0xbb, 0x79, 0x32, 0xf3, 0x57, 0x6f, 0xff,
		0xbc, 0x3a, 0xef, 0x17, 0x6a, 0x73, 0x7e, 0x61, 0x77, 0xde, 0x2f, 0xec, 0xce, 0xf9, 0x85, 0xb9,
		0xaf, 0x54, 0x9d, 0xf3, 0x0b, 0x7b, 0x37, 0x3f, 0x66, 0xfe, 0xfe, 0x93, 0xc7, 0xff, 0xea, 0xfe,
		0xcd, 0xd3, 0x1f, 0xf3, 0xfe, 0xdb, 0xc1, 0xcd, 0x8f, 0x97, 0x4f, 0x51, 0xfe, 0xc8, 0x2d, 0x72,
		0xeb, 0xc4, 0x14, 0x6e, 0x14, 0xeb, 0xbd, 0x8b, 0xc1, 0xa1, 0x89, 0x4c, 0xfa, 0x5e, 0xda, 0x19,
		0x10, 0x6a, 0xe7, 0x07, 0xb7, 0x06, 0xb7, 0x06, 0xb7, 0x06, 0xb7, 0xe6, 0x88, 0x5b, 0x5b, 0x87,
		0x60, 0xd3, 0xb2, 0x5d, 0x8a, 0x73, 0xce, 0x73, 0x72, 0x60, 0x54, 0xbd, 0x2e, 0x27, 0x10, 0x6a,
		0x2c, 0x33, 0xf7, 0xf9, 0xd6, 0x0d, 0x67, 0x86, 0x4d, 0x0c, 0x86, 0xff, 0x7f, 0x6b, 0x54, 0x6e,
		0x99, 0xab, 0x05, 0x8d, 0xfe, 0x99, 0x0a, 0x9e, 0x67, 0x25, 0x4a, 0x74, 0x2b, 0x38, 0x26, 0x7a,
		0xe9, 0xe1, 0x42, 0x94, 0xa0, 0x51, 0x82, 0xe6, 0xda, 0x51, 0xa2, 0x04, 0xcd, 0xcc, 0x66, 0xa8,
		0x95, 0xa0, 0x29, 0x55, 0xcc, 0xce, 0x5c, 0x26, 0x95, 0xca, 0x59, 0x65, 0xf5, 0x05, 0x1e, 0x04,
		0x0f, 0x82, 0x07, 0x7d, 0xc4, 0x83, 0x5a, 0xea, 0x70, 0xb2, 0x40, 0xdc, 0x8c, 0x92, 0x34, 0x6e,
		0x7d, 0x8f, 0x93, 0xab, 0xa0, 0xab, 0x7f, 0x39, 0xef, 0x5d, 0xd0, 0x47, 0xd6, 0x56, 0x96, 0x33,
		0x5d, 0x3a, 0xcd, 0x4c, 0x8d, 0x5a, 0xaa, 0x53, 0x73, 0xb5, 0x6a, 0xad, 0x5e, 0x9d, 0xa9, 0x59,
		0x67, 0xea, 0xd6, 0x85, 0xda, 0xd5, 0x55, 0xbf, 0xca, 0x6a, 0xd8, 0x8e, 0x9e, 0x9b, 0xd5, 0x91,
		0xdd, 0xc0, 0x4c, 0x18, 0x2d, 0x32, 0xe1, 0x1e, 0x6e, 0xa5, 0x4d, 0xec, 0xd6, 0x46, 0x83, 0x6c,
		0xce, 0x64, 0xc8, 0x99, 0xea, 0x91, 0x4d, 0xe3, 0xcc, 0x91, 0x3b, 0x2b, 0x64, 0x1c, 0x89, 0x9f,
		0x2c, 0x6c, 0x9a, 0x8e, 0xb5, 0x95, 0x2d, 0xf6, 0xf4, 0xc7, 0x93, 0x4f, 0x3b, 0x41, 0xf5, 0x72,
		0xfc, 0x2f, 0xbb, 0x9f, 0xb6, 0x83, 0xea, 0xa5, 0x49, 0x8c, 0x7a, 0xfc, 0x73, 0x69, 0x79, 0xb8,
		0x2e, 0x72, 0x2d, 0x38, 0x61, 0x93, 0x95, 0x6e, 0x9e, 0x95, 0x58, 0xfb, 0xee, 0xa3, 0x7d, 0x4d,
		0xee, 0x26, 0xf9, 0x50, 0xf6, 0xf9, 0x50, 0x5b, 0x4f, 0x76, 0x6e, 0x15, 0xd8, 0x8b, 0x91, 0x4e,
		0xdb, 0xb9, 0x9c, 0x51, 0x75, 0x23, 0xd5, 0x85, 0x49, 0x42, 0xec, 0x11, 0xfb, 0x12, 0xd8, 0x69,
		0xb2, 0x1f, 0x4b, 0xc1, 0xe6, 0x2a, 0x27, 0x44, 0x4c, 0xd6, 0x71, 0x9f, 0x18, 0xf1, 0x20, 0x8a,
		0xaf, 0x92, 0x28, 0xa1, 0x27, 0x03, 0x1a, 0xb9, 0xaa, 0xa3, 0x31, 0xe8, 0xea, 0xe1, 0xc7, 0xd1,
		0x32, 0x05, 0x8f, 0x3e, 0x56, 0x89, 0x3e, 0xfe, 0x7a, 0x21, 0xa2, 0x8f, 0x05, 0xa4, 0xc1, 0x89,
		0x3e, 0xde, 0x5b, 0x80, 0xe8, 0xa3, 0xa6, 0x1a, 0x25, 0xfa, 0xe8, 0xbf, 0x7a, 0x75, 0xa6, 0x66,
		0x9d, 0xa9, 0x5b, 0x17, 0x6a, 0xd7, 0x06, 0x48, 0x11, 0x7d, 0x14, 0xf1, 0x2e, 0x89, 0x3e, 0x4a,
		0x1c, 0x1c, 0xd1, 0x47, 0x23, 0x22, 0x90, 0xe8, 0xa3, 0xe6, 0xe1, 0x12, 0x7d, 0x24, 0xfa, 0x58,
		0x44, 0xed, 0x4b, 0xf4, 0xd1, 0xe6, 0x6e, 0x12, 0x86, 0x21, 0x0c, 0x43, 0xf4, 0x11, 0xb1, 0x27,
		0xfa, 0x58, 0x50, 0xd0, 0xbc, 0x49, 0xf4, 0xd1, 0x88, 0xcd, 0x5d, 0xdf, 0xe8, 0xe3, 0x28, 0x28,
		0xb6, 0xc6, 0xc1, 0xc7, 0x34, 0xec, 0x5d, 0x45, 0x69, 0x5f, 0x3f, 0xfc, 0x38, 0x5e, 0x88, 0xf2,
		0xc7, 0xc7, 0x7d, 0x07, 0x02, 0x90, 0xfe, 0x33, 0xe3, 0x04, 0x20, 0xbd, 0x31, 0x59, 0xea, 0x01,
		0xc8, 0x91, 0xbe, 0xb2, 0x0b, 0x3a, 0x66, 0xeb, 0xd9, 0x04, 0x1a, 0x77, 0x08, 0x34, 0xfa, 0xab,
		0x3e, 0xad, 0xd5, 0xa8, 0x33, 0x75, 0xea, 0x4c, 0xad, 0xba, 0x50, 0xaf, 0x36, 0x98, 0x49, 0x3b,
		0xd0, 0xa8, 0xad, 0x76, 0x27, 0x0b, 0x29, 0x37, 0xe5, 0x98, 0x7b, 0xb9, 0x55, 0x9b, 0x74, 0x38,
		0x52, 0xc7, 0xe6, 0x6a, 0xd9, 0x85, 0x7a, 0x76, 0xa6, 0xa6, 0x5d, 0xa9, 0x6b, 0xe7, 0x6a, 0xdb,
		0xb9, 0xfa, 0x76, 0xa9, 0xc6, 0xed, 0x28, 0xb0, 0x4d, 0xbb, 0x80, 0x98, 0x99, 0x7a, 0x9f, 0x2c,
		0xd8, 0x8c, 0xfa, 0x69, 0x9c, 0xe8, 0x53, 0x4f, 0x3f, 0xd5, 0x14, 0xd3, 0x2f, 0x61, 0x2c, 0xb9,
		0x36, 0x89, 0x7f, 0xce, 0x0d, 0x81, 0x4b, 0x83, 0xe0, 0xdc, 0x30, 0xb8, 0x36, 0x10, 0xde, 0x18,
		0x0a, 0x6f, 0x0c, 0x86, 0x0f, 0x86, 0xc3, 0xd6, 0x80, 0x18, 0x1b, 0x92, 0xc9, 0x06, 0x9b, 0x25,
		0x26, 0xce, 0xbd, 0xed, 0x96, 0x89, 0x8a, 0x73, 0xfd, 0xfb, 0x43, 0x07, 0x6b, 0x9b, 0x26, 0x32,
		0x3e, 0xfc, 0x71, 0xa3, 0xe1, 0x36, 0xdd, 0x27, 0x3a, 0xce, 0x15, 0x81, 0x17, 0x0e, 0xdf, 0xc1,
		0x55, 0x4e, 0xc2, 0xcc, 0x8b, 0xac, 0x6b, 0xda, 0xdc, 0xc3, 0x9f, 0x4b, 0x97, 0xc2, 0xe0, 0x32,
		0x4b, 0x05, 0x89, 0x98, 0x27, 0x11, 0x4e, 0x56, 0xbe, 0x79, 0xb6, 0xc6, 0xd6, 0x61, 0x1f, 0xeb,
		0xe0, 0xa5, 0x75, 0x20, 0x83, 0x8d, 0x0c, 0x36, 0x4c, 0x26, 0xd7, 0x84, 0x6b, 0x52, 0x1c, 0x3f,
		0x62, 0xa3, 0xdc, 0xdf, 0x69, 0xf7, 0x7d, 0x86, 0x1e, 0x59, 0x25, 0x6e, 0xba, 0xe3, 0xdc, 0xe3,
		0x26, 0x54, 0xbb, 0xb2, 0xd1, 0x82, 0x6a, 0x87, 0x6a, 0x87, 0x6a, 0x77, 0x66, 0xa5, 0xd6, 0x8f,
		0x6a, 0xef, 0xa7, 0xbd, 0x38, 0xb9, 0x72, 0xc9, 0xb3, 0xbf, 0xc0, 0x2b, 0xc8, 0xef, 0x15, 0x74,
		0x83, 0x34, 0x6d, 0x3b, 0xf4, 0x0c, 0x46, 0xeb, 0xe3, 0x1d, 0xe0, 0x1d, 0xe0, 0x1d, 0xe0, 0x1d,
		0xe0, 0x1d, 0x94, 0xc4, 0x3b, 0x18, 0xc4, 0x49, 0xfa, 0xc2, 0xa1, 0x73, 0xb0, 0xe7, 0x60, 0xe9,
		0xf7, 0x61, 0x72, 0xb5, 0x96, 0x41, 0xf8, 0xb7, 0x71, 0xe2, 0x4c, 0xbd, 0x3a, 0xb6, 0xe9, 0x33,
		0xaf, 0xf1, 0x31, 0x6c, 0x0f, 0x22, 0x0f, 0xde, 0xe3, 0x75, 0x6f, 0x54, 0x04, 0xfb, 0x7b, 0x7c,
		0x15, 0x0f, 0x2b, 0x3e, 0xb7, 0x9d, 0xbd, 0xcf, 0x8d, 0x43, 0x32, 0xff, 0x6d, 0xf8, 0x0d, 0xd1,
		0x7c, 0x20, 0x9a, 0xd5, 0xbd, 0x3d, 0x84, 0xd3, 0x8d, 0x23, 0xe0, 0x6e, 0x55, 0x28, 0xf4, 0xfc,
		0x62, 0xdb, 0x77, 0x54, 0xf3, 0x31, 0xa1, 0x5c, 0x46, 0xeb, 0x03, 0x96, 0x01, 0xcb, 0x80, 0x65,
		0xc0, 0x32, 0x60, 0xb9, 0x24, 0x60, 0x39, 0xee, 0x06, 0x61, 0xb3, 0xd9, 0x8b, 0xfa, 0x7d, 0xd2,
		0xd6, 0xd7, 0x03, 0x31, 0xdf, 0x4b, 0x5b, 0x77, 0x77, 0xf6, 0x33, 0x32, 0x40, 0x66, 0xa2, 0x75,
		0x96, 0x32, 0x49, 0x76, 0x9c, 0x78, 0x49, 0x41, 0xa0, 0x63, 0xfe, 0xc7, 0x97, 0xbc, 0x73, 0xd4,
		0xfb, 0x26, 0x89, 0xe7, 0x64, 0xd4, 0xfe, 0x78, 0x49, 0x11, 0x16, 0xf2, 0x8f, 0xfc, 0xaf, 0x97,
		0xe9, 0x87, 0xe7, 0x2e, 0xd4, 0x4a, 0x56, 0xad, 0x67, 0x8c, 0x7a, 0x10, 0xcf, 0xac, 0xeb, 0x5f,
		0x4f, 0xe2, 0xac, 0x53, 0x6e, 0xf6, 0xbf, 0xaa, 0x03, 0x52, 0xed, 0x45, 0xca, 0x40, 0x9c, 0x2c,
		0xeb, 0x1a, 0xec, 0xeb, 0x19, 0x8c, 0x83, 0x2f, 0xf4, 0x8c, 0x53, 0x5d, 0x98, 0x9e, 0x71, 0xf4,
		0x8c, 0x2b, 0xb8, 0xe1, 0x36, 0x0f, 0x96, 0x4c, 0x6e, 0x6b, 0x3b, 0x0a, 0x5b, 0xbd, 0xa8, 0xe5,
		0x62, 0x90, 0xd2, 0x81, 0xed, 0x20, 0xa5, 0xa1, 0x6f, 0xf2, 0xfc, 0xf9, 0x68, 0x5c, 0xc1, 0x56,
		0xdc, 0xc4, 0x1b, 0x58, 0xc2, 0xc1, 0x53, 0x1d, 0xaf, 0x3e, 0x57, 0x38, 0x35, 0xc7, 0xad, 0xcf,
		0x15, 0x4b, 0x6b, 0x9f, 0xa0, 0x8a, 0x4f, 0x80, 0x4f, 0x80, 0x4f, 0x80, 0x4f, 0xf0, 0x60, 0x23,
		0xe9, 0x23, 0x4b, 0x46, 0x5e, 0xd9, 0x0c, 0x82, 0x73, 0xc3, 0xe0, 0xda, 0x40, 0x78, 0x63, 0x28,
		0xbc, 0x31, 0x18, 0x3e, 0x18, 0x0e, 0x5b, 0x03, 0x62, 0x6c, 0x48, 0xdc, 0x81, 0xcc, 0x99, 0xdb,
		0x4e, 0x1f, 0x59, 0x17, 0x37, 0x8b, 0x3e, 0xb2, 0x0f, 0x45, 0x80, 0x84, 0x0d, 0xba, 0x86, 0x4e,
		0x7e, 0x48, 0x61, 0x40, 0x22, 0x1e, 0x48, 0x04, 0xf9, 0x7c, 0xd6, 0xd6, 0x81, 0x3e, 0xb2, 0x7e,
		0x5a, 0x07, 0xd2, 0x99, 0x68, 0x90, 0x89, 0xc9, 0xe4, 0x9a, 0x70, 0x4d, 0x8a, 0xe3, 0x47, 0x90,
		0x1c, 0x58, 0x3c, 0x8f, 0x8c, 0x3e, 0xb2, 0x16, 0xcb, 0x42, 0xb5, 0x43, 0xb5, 0x43, 0xb5, 0x43,
		0xb5, 0x5b, 0xf1, 0xbd, 0xf4, 0x91, 0xc5, 0x2b, 0xc8, 0xe7, 0x15, 0xd0, 0x47, 0x16, 0xef, 0x00,
		0xef, 0x00, 0xef, 0x00, 0xef, 0x00, 0xef, 0x40, 0xf0, 0xb6, 0xd3, 0x47, 0xd6, 0xfa, 0x87, 0x3e,
		0xb2, 0xf4, 0x91, 0x9d, 0x7a, 0x0f, 0xfa, 0xc8, 0x6e, 0xd2, 0x47, 0xf6, 0x71, 0xd1, 0xa4, 0x8f,
		0xac, 0x33, 0x47, 0xc0, 0xdd, 0xaa, 0x50, 0xe8, 0xf9, 0xc5, 0x96, 0x3e, 0xb2, 0x80, 0x65, 0xc0,
		0x32, 0x60, 0x19, 0xb0, 0x0c, 0x58, 0x96, 0xbc, 0xed, 0xf4, 0x91, 0xa5, 0x8f, 0x2c, 0x8d, 0x06,
		0xe9, 0x2a, 0x6a, 0x0d, 0x09, 0x48, 0xb2, 0x5b, 0xb7, 0x13, 0x27, 0xef, 0xdc, 0x5a, 0xbd, 0xd3,
		0x47, 0xd6, 0x53, 0xf5, 0x4e, 0x46, 0x2d, 0x7d, 0x64, 0xd7, 0xd9, 0xd8, 0x21, 0xff, 0xf4, 0x91,
		0x2d, 0x19, 0x73, 0xb0, 0x49, 0x1f, 0xd9, 0x62, 0xb8, 0x6a, 0xf4, 0x91, 0x9d, 0xd7, 0x47, 0x76,
		0xd4, 0x90, 0xac, 0x2c, 0x8d, 0xe3, 0x36, 0x0a, 0x2c, 0xab, 0x95, 0x7f, 0x44, 0xdf, 0x4d, 0x6a,
		0x17, 0x2a, 0xa7, 0x71, 0x3f, 0x3d, 0x4a, 0x53, 0x9b, 0x66, 0x4c, 0x95, 0xb7, 0x71, 0x72, 0xdc,
		0x8e, 0xae, 0xa3, 0x64, 0x14, 0x78, 0x35, 0xe8, 0xed, 0xf7, 0x36, 0xfc, 0x36, 0xb5, 0xe2, 0xce,
		0x8b, 0x5a, 0x6d, 0xff, 0xa0, 0x56, 0xdb, 0x3e, 0xd8, 0x3d, 0xd8, 0x3e, 0xdc, 0xdb, 0xdb, 0xd9,
		0xdf, 0x31, 0x08, 0x47, 0x57, 0xde, 0xf5, 0x9a, 0x51, 0x2f, 0x6a, 0xbe, 0xba, 0x3d, 0xd3, 0x64,
		0xd0, 0x6e, 0x17, 0x5a, 0x34, 0x8d, 0xd5, 0xa7, 0xf7, 0x6a, 0xb3, 0x62, 0xd2, 0xa1, 0xb2, 0x37,
		0x68, 0xa4, 0x49, 0x86, 0xec, 0xcf, 0x46, 0x1f, 0x75, 0x92, 0x7d, 0x53, 0xfd, 0x7c, 0xf8, 0xe2,
		0xaf, 0x27, 0x9f, 0x94, 0xfd, 0x41, 0xfd, 0xfd, 0xa0, 0x1d, 0xd5, 0x8f, 0x86, 0xdf, 0x50, 0x3f,
		0xbe, 0xfb, 0x86, 0x37, 0xbd, 0xa8, 0xfe, 0x61, 0xf4, 0xea, 0x1b, 0xc5, 0xd4, 0xc0, 0x3a, 0x4f,
		0x56, 0xba, 0x38, 0x56, 0x17, 0xc6, 0xdf, 0x8b, 0xa2, 0x23, 0x66, 0xf2, 0x42, 0x20, 0xfb, 0x44,
		0x61, 0x71, 0xd2, 0x16, 0x23, 0xff, 0xc4, 0x47, 0x41, 0xb1, 0x8a, 0x2b, 0x52, 0x59, 0xd1, 0x96,
		0x13, 0x40, 0x41, 0xe1, 0x53, 0x6a, 0x8f, 0xac, 0xda, 0x06, 0x59, 0xa9, 0xdd, 0xb1, 0x5a, 0x5b,
		0x63, 0xcd, 0xbc, 0x1f, 0xf5, 0xbc, 0x1e, 0xed, 0xbc, 0x1d, 0xb3, 0xbc, 0x1c, 0xb3, 0xbc, 0x1b,
		0x8b, 0xbc, 0x1a, 0xbf, 0x8d, 0x99, 0x56, 0xfb, 0xdf, 0x4a, 0x33, 0xba, 0x6f, 0x43, 0xd4, 0x84,
		0xf2, 0xae, 0xa5, 0xaf, 0xb6, 0xd1, 0x1a, 0x6d, 0x58, 0xd4, 0x0a, 0x07, 0xed, 0xa1, 0xc0, 0xb4,
		0xc2, 0x76, 0x5f, 0x6d, 0x1d, 0xdd, 0x84, 0x4b, 0xf5, 0xc4, 0x4a, 0x8b, 0x04, 0x4a, 0xb3, 0x44,
		0x49, 0xab, 0x84, 0x48, 0xf3, 0xc4, 0x47, 0xf3, 0x04, 0x47, 0xcb, 0x44, 0xc6, 0x62, 0x81, 0x53,
		0xf5, 0x04, 0xc4, 0xc9, 0x6d, 0xf9, 0xdc, 0xe9, 0xb4, 0xa3, 0x50, 0xb3, 0xef, 0xf9, 0xc4, 0xeb,
		0xdb, 0x29, 0x0a, 0xe0, 0x54, 0x70, 0xc6, 0x9a, 0x71, 0xbf, 0x11, 0xf6, 0x9a, 0x06, 0x86, 0x2f,
		0x5b, 0x08, 0x83, 0x87, 0xc1, 0xc3, 0xe0, 0x61, 0xf0, 0x30, 0x78, 0x18, 0x3c, 0x17, 0x06, 0xef,
		0x21, 0xf5, 0xa8, 0x6f, 0xf9, 0x66, 0x56, 0xc4, 0x34, 0x61, 0x9a, 0x30, 0x4d, 0x98, 0xa6, 0xc2,
		0x98, 0x26, 0xfd, 0xb9, 0x98, 0x16, 0x73, 0x30, 0xa7, 0xe7, 0x5e, 0x3e, 0xfa, 0x7f, 0xa3, 0x61,
		0x98, 0xc3, 0x68, 0xcf, 0x5a, 0x1b, 0xc8, 0x6f, 0x69, 0xf0, 0xa5, 0xd3, 0xb5, 0x30, 0x8c, 0xd9,
		0x4a, 0x18, 0x44, 0x0c, 0x22, 0x06, 0x11, 0x83, 0x58, 0x18, 0x83, 0x68, 0x52, 0x05, 0x6d, 0x51,
		0xed, 0x6c, 0x53, 0xd5, 0x6c, 0x90, 0xf6, 0xe7, 0xa8, 0x4a, 0xd9, 0xb2, 0x5c, 0xcd, 0xbc, 0x2c,
		0xad, 0x74, 0xb5, 0xa6, 0x97, 0x16, 0x87, 0xe4, 0xa2, 0x80, 0xaa, 0x7c, 0x27, 0x55, 0xe4, 0x9c,
		0x67, 0x5b, 0x75, 0xb7, 0x8f, 0xba, 0x93, 0xbd, 0x44, 0x54, 0x1b, 0x96, 0xb2, 0xda, 0xb0, 0xf4,
		0xca, 0x1f, 0xb9, 0x2d, 0xa7, 0xdc, 0x16, 0xb4, 0xea, 0xe2, 0x72, 0x8d, 0x39, 0xb4, 0x6e, 0x98,
		0x7e, 0x09, 0xfa, 0x51, 0x3b, 0x1a, 0x26, 0x81, 0x07, 0x57, 0xbd, 0xce, 0xc0, 0x80, 0x4f, 0x7b,
		0x74, 0x55, 0xb8, 0x35, 0xb8, 0x35, 0xb8, 0x35, 0xb8, 0xb5, 0xc2, 0x70, 0x6b, 0xeb, 0x10, 0x6c,
		0x7a, 0x4c, 0x53, 0xf7, 0x1f, 0xfd, 0xd3, 0x2c, 0x28, 0x35, 0xfc, 0xe7, 0x20, 0x6e, 0x52, 0x1b,
		0x27, 0x72, 0xcb, 0x4b, 0x5f, 0x1b, 0xa7, 0xd0, 0x9b, 0x41, 0xb0, 0xda, 0x6c, 0xc3, 0x23, 0xa1,
		0xd0, 0x12, 0x06, 0xf7, 0x42, 0x50, 0x11, 0x2d, 0xea, 0xcb, 0x59, 0x08, 0x29, 0x23, 0x8b, 0xf9,
		0x25, 0x47, 0x40, 0x6a, 0x2a, 0x8d, 0xb1, 0x73, 0x2a, 0x23, 0x2d, 0x13, 0xcb, 0x97, 0x3d, 0x57,
		0x48, 0xae, 0x65, 0x6b, 0x1a, 0xc5, 0x3d, 0x72, 0x0d, 0x0f, 0x5c, 0xcd, 0xe3, 0xd6, 0xf2, 0xb0,
		0xd5, 0x3d, 0x6a, 0x75, 0x0f, 0x5a, 0xd3, 0x63, 0xf6, 0xcb, 0x4e, 0x48, 0xd7, 0x20, 0x56, 0xfa,
		0xd1, 0x7f, 0x06, 0x51, 0xd2, 0x88, 0x02, 0x85, 0x71, 0xc7, 0x77, 0xe5, 0xd2, 0x53, 0x8b, 0xe8,
		0x14, 0x4d, 0x6f, 0x6b, 0x15, 0x4d, 0x6f, 0x53, 0x34, 0x6d, 0x06, 0xf1, 0x29, 0x9a, 0x2e, 0x1f,
		0xca, 0x51, 0x83, 0xec, 0xf7, 0x26, 0xe7, 0xed, 0x56, 0x35, 0xc4, 0x3d, 0xd3, 0x2d, 0x0a, 0x00,
		0x5d, 0x79, 0xf4, 0x9d, 0x22, 0x41, 0x62, 0x31, 0xba, 0xce, 0x68, 0x82, 0x8e, 0xd5, 0xe8, 0x39,
		0xcb, 0xe9, 0x5d, 0x8a, 0x49, 0x05, 0x26, 0xa3, 0xe1, 0xac, 0x8f, 0xbe, 0x56, 0x3d, 0xac, 0x1d,
		0xee, 0x1f, 0x54, 0x0f, 0xf7, 0x4a, 0x24, 0x03, 0x05, 0xa1, 0xe7, 0x2e, 0x61, 0x86, 0xd6, 0x93,
		0x19, 0xca, 0x28, 0x86, 0x12, 0x91, 0x31, 0x71, 0xf7, 0x6b, 0x4d, 0x9e, 0x8a, 0x19, 0x3e, 0x15,
		0x22, 0x46, 0x04, 0x0f, 0xfd, 0x3b, 0x0d, 0xae, 0xc3, 0xb4, 0xf1, 0x05, 0x3e, 0xc6, 0x05, 0x1f,
		0x33, 0xd9, 0x7d, 0x68, 0x99, 0xc5, 0x1e, 0x28, 0xcc, 0xee, 0xce, 0x5c, 0x09, 0x51, 0x96, 0x57,
		0x49, 0xc9, 0x94, 0x87, 0x8c, 0x51, 0x50, 0x3e, 0x70, 0x32, 0x1e, 0x2b, 0xa7, 0x62, 0x50, 0x33,
		0x8a, 0xfd, 0xec, 0xfa, 0x69, 0x9c, 0x0c, 0x7d, 0xd6, 0x49, 0x5a, 0xb8, 0x41, 0x4f, 0xbb, 0xd9,
		0x45, 0x49, 0x3b, 0xb3, 0x56, 0x7b, 0xd6, 0xea, 0xcf, 0x4a, 0x0d, 0x9a, 0xab, 0x43, 0x73, 0xb5,
		0xe8, 0x40, 0x3d, 0x2a, 0x13, 0x16, 0x25, 0x28, 0xf0, 0xfc, 0x5a, 0x0b, 0xd4, 0xa5, 0xcc, 0xa2,
		0x9c, 0xc6, 0xac, 0x8c, 0xc6, 0xb6, 0x06, 0x6d, 0x2b, 0x5b, 0xec, 0xe9, 0x8f, 0x27, 0x9f, 0x76,
		0x82, 0xea, 0xe5, 0xf8, 0x5f, 0x76, 0x3f, 0x6d, 0x07, 0xd5, 0x4b, 0xd5, 0xc4, 0xfc, 0x4b, 0xcd,
		0xc3, 0xb2, 0x2c, 0x20, 0x59, 0x9f, 0x13, 0x5b, 0xe7, 0x06, 0x8f, 0xfd, 0x86, 0x41, 0xe9, 0xc1,
		0x70, 0x15, 0x7c, 0x3e, 0x7c, 0x3e, 0x7c, 0x3e, 0x7c, 0xbe, 0x82, 0xfa, 0x7c, 0x8a, 0x3a, 0x6c,
		0x5a, 0x8f, 0x29, 0x86, 0x3b, 0x95, 0x73, 0x1b, 0xc6, 0x3f, 0x36, 0x93, 0xdf, 0xcc, 0xa6, 0x2d,
		0x1a, 0x05, 0xbe, 0x27, 0xcb, 0x19, 0xe5, 0x3e, 0x4c, 0xd6, 0x33, 0x8c, 0x7f, 0x2b, 0x2b, 0x83,
		0xfb, 0x22, 0x62, 0x90, 0x13, 0xe1, 0x5a, 0x44, 0xf6, 0x77, 0x4b, 0x2c, 0x23, 0xd4, 0x35, 0x17,
		0x0e, 0x4c, 0x7c, 0xe9, 0x74, 0x83, 0x76, 0x7c, 0x1d, 0xa7, 0xfa, 0x88, 0xe2, 0x6e, 0x29, 0x60,
		0x05, 0xb0, 0x02, 0x58, 0x01, 0xac, 0x28, 0x28, 0xac, 0x18, 0xc4, 0x49, 0xfa, 0x02, 0x5c, 0x01,
		0xae, 0x00, 0x57, 0x80, 0x2b, 0x3c, 0x11, 0x91, 0xea, 0xde, 0x1e, 0xc0, 0x02, 0x60, 0xe1, 0x0f,
		0xb0, 0xe8, 0xf6, 0x3a, 0x69, 0xa7, 0xd1, 0x69, 0x1b, 0x34, 0x49, 0x1a, 0xaf, 0x04, 0xac, 0x00,
		0x56, 0x00, 0x2b, 0x80, 0x15, 0x05, 0x85, 0x15, 0x71, 0x37, 0x18, 0xab, 0xb2, 0x20, 0xbd, 0x5d,
		0x95, 0x46, 0xe4, 0x5e, 0x20, 0x0c, 0x2b, 0xd8, 0x67, 0x08, 0xff, 0x8c, 0x61, 0xa0, 0xdd, 0x61,
		0x39, 0x81, 0x85, 0x8e, 0x7c, 0x7f, 0x57, 0x30, 0xd1, 0x25, 0x12, 0x30, 0x84, 0x8d, 0x4e, 0xe0,
		0xa3, 0x2f, 0xa2, 0x54, 0xdd, 0xab, 0xad, 0x91, 0x30, 0x6d, 0x94, 0x63, 0x15, 0x5a, 0xec, 0x2f,
		0xe8, 0x68, 0x35, 0xa3, 0x24, 0x8d, 0xd3, 0xef, 0xba, 0x3d, 0x29, 0x67, 0x7c, 0x2d, 0x0b, 0x7b,
		0x7e, 0x92, 0x7d, 0xda, 0xab, 0xb0, 0x1f, 0xd9, 0x71, 0x5e, 0xe3, 0x8d, 0x3d, 0x39, 0xaf, 0x9f,
		0xbf, 0x7f, 0xf7, 0xe1, 0xdd, 0x6f, 0xef, 0x4e, 0x2b, 0x96, 0xfc, 0x57, 0xdf, 0xcc, 0x83, 0xb1,
		0xf5, 0x62, 0x1e, 0x6e, 0xee, 0x1f, 0xbf, 0x9f, 0x57, 0xca, 0x68, 0x62, 0xdd, 0xed, 0xe8, 0x69,
		0xf5, 0x03, 0x5b, 0x2a, 0xbb, 0xa5, 0x47, 0x7f, 0x7c, 0xf8, 0x6f, 0xb6, 0x54, 0x74, 0x4b, 0xdf,
		0x5f, 0x7c, 0x44, 0x4a, 0x65, 0xb7, 0xf4, 0xe4, 0xcd, 0x5b, 0xb6, 0x54, 0x78, 0x4b, 0x7f, 0x63,
		0x4b, 0xa5, 0xbd, 0xa9, 0x93, 0xb7, 0xec, 0xa8, 0xe8, 0x8e, 0xbe, 0x79, 0x7f, 0xcc, 0x8e, 0x8a,
		0xee, 0xe8, 0x87, 0xdf, 0x2c, 0x6f, 0xbd, 0xc9, 0x4a, 0x97, 0x44, 0xb4, 0x4d, 0x77, 0xa6, 0x18,
		0x11, 0xed, 0xfe, 0x30, 0xe6, 0x68, 0xd7, 0x84, 0xe1, 0xc1, 0x7a, 0x44, 0xb7, 0x1f, 0x5d, 0x80,
		0xe8, 0x76, 0x8e, 0xb3, 0x27, 0xba, 0x5d, 0x10, 0xdd, 0x4b, 0xff, 0x85, 0xe5, 0xd4, 0x19, 0xfd,
		0x17, 0xe8, 0xbf, 0x90, 0x1d, 0x16, 0xfd, 0x17, 0xd6, 0xd9, 0x0f, 0x64, 0x6a, 0x95, 0x9b, 0xb6,
		0xb4, 0xb7, 0xea, 0x5e, 0xb4, 0x37, 0xad, 0xfc, 0x89, 0xde, 0x88, 0x4e, 0x53, 0x0a, 0xd3, 0x48,
		0x71, 0xe6, 0xc7, 0xf0, 0xf1, 0x05, 0x6b, 0x30, 0x59, 0xa5, 0xc1, 0xa4, 0xb5, 0x67, 0x4f, 0x83,
		0xc9, 0xd2, 0xda, 0x0a, 0x1a, 0x4c, 0x42, 0x70, 0x40, 0x70, 0x40, 0x70, 0x40, 0x70, 0x40, 0x70,
		0x40, 0x70, 0x40, 0x70, 0x40, 0x70, 0x40, 0x70, 0xd0, 0x60, 0x12, 0x9f, 0x0f, 0x9f, 0x0f, 0x9f,
		0x0f, 0x9f, 0xcf, 0x91, 0xcf, 0x47, 0x83, 0xc9, 0x05, 0x7f, 0x68, 0x04, 0x93, 0x6b, 0x39, 0x1a,
		0xc1, 0xc8, 0x88, 0x08, 0x0d, 0x26, 0x8b, 0x2d, 0x23, 0x64, 0xcd, 0x15, 0x0e, 0x4c, 0xd0, 0x60,
		0x12, 0x58, 0x01, 0xac, 0x00, 0x56, 0x00, 0x2b, 0x16, 0xbf, 0x3b, 0x34, 0x98, 0x04, 0x57, 0x80,
		0x2b, 0xc0, 0x15, 0x3e, 0x89, 0x08, 0x0d, 0x26, 0x01, 0x16, 0x5e, 0x01, 0x0b, 0x1a, 0x4c, 0x02,
		0x2b, 0x80, 0x15, 0xc0, 0x0a, 0x60, 0xc5, 0xa2, 0x77, 0x87, 0x06, 0x93, 0x7e, 0x22, 0x0c, 0x1a,
		0x4c, 0x16, 0xe7, 0xb0, 0x9c, 0xc0, 0x42, 0x47, 0xbe, 0xbf, 0x2b, 0x98, 0xe8, 0x12, 0x09, 0x18,
		0xc2, 0x46, 0x27, 0xf0, 0xd1, 0x17, 0x51, 0xa2, 0xc1, 0x64, 0x01, 0x57, 0xa1, 0xc1, 0xe4, 0x82,
		0x8e, 0x16, 0x0d, 0x26, 0x75, 0x36, 0x96, 0x06, 0x93, 0xba, 0x9b, 0x4b, 0x83, 0x49, 0xe9, 0x1d,
		0xa5, 0xc1, 0xa4, 0xf8, 0x96, 0xd2, 0x60, 0x52, 0x7c, 0x4b, 0x69, 0x30, 0x29, 0xbe, 0xa5, 0x34,
		0x98, 0x94, 0xdf, 0x52, 0x1a, 0x4c, 0x8a, 0x7b, 0x53, 0x34, 0x98, 0x14, 0xde, 0x51, 0x1a, 0x4c,
		0x4a, 0xef, 0x28, 0x0d, 0x26, 0xbd, 0xfb, 0x0e, 0x22, 0xda, 0x34, 0x98, 0x5c, 0x92, 0x9d, 0x20,
		0xba, 0xbd, 0xc0, 0x89, 0x10, 0xdd, 0xce, 0xb9, 0x20, 0xd1, 0x6d, 0xbf, 0x3c, 0x09, 0xfa, 0x2f,
		0xac, 0xa4, 0x72, 0xa8, 0xe6, 0x17, 0xf6, 0x2a, 0xe8, 0xbf, 0x40, 0xff, 0x05, 0x1a, 0x4c, 0xca,
		0x7b, 0xac, 0x8e, 0x1b, 0x4c, 0x8e, 0xfa, 0x22, 0xfa, 0xda, 0x5f, 0x72, 0xc3, 0x23, 0x91, 0xd0,
		0x12, 0x05, 0xd7, 0x22, 0x50, 0x11, 0x6d, 0xe2, 0xd9, 0x1b, 0x34, 0xd2, 0x24, 0xf3, 0x27, 0xce,
		0x46, 0xef, 0x76, 0x92, 0xbd, 0x5a, 0xfd, 0x7c, 0xb8, 0xfe, 0xeb, 0xc9, 0x9b, 0x65, 0x7f, 0x50,
		0x7f, 0x3f, 0x68, 0x47, 0xf5, 0x93, 0xdb, 0x57, 0xd9, 0xf0, 0x43, 0x6a, 0x04, 0x24, 0xe6, 0xd6,
		0x99, 0xda, 0x17, 0x93, 0x93, 0x69, 0x17, 0x6d, 0x5f, 0xe8, 0xc0, 0x84, 0xbb, 0x97, 0x8a, 0xc3,
		0x48, 0x0d, 0xd8, 0xa8, 0x0d, 0x13, 0xb5, 0x60, 0xa1, 0x3a, 0x0c, 0x54, 0x87, 0x7d, 0x06, 0x30,
		0xcf, 0x2f, 0x6b, 0x21, 0xdd, 0x6d, 0xb4, 0xd2, 0x18, 0xdf, 0x2f, 0xa5, 0x0e, 0xc9, 0xd9, 0xf3,
		0x0b, 0xd6, 0x22, 0x79, 0x9b, 0x16, 0xc9, 0xd6, 0xdc, 0x14, 0x2d, 0x92, 0x4b, 0x8b, 0x76, 0x68,
		0x91, 0x9c, 0x4f, 0xcd, 0x41, 0xd1, 0xbb, 0x57, 0x7f, 0x56, 0x6a, 0xd0, 0x5c, 0x1d, 0x9a, 0xab,
		0x45, 0x07, 0xea, 0x51, 0x8f, 0x66, 0xda, 0x2c, 0x0b, 0x45, 0xbf, 0x0f, 0x45, 0xbf, 0xdc, 0x42,
		0x19, 0xe1, 0x1b, 0x06, 0xad, 0xa3, 0xe0, 0xf5, 0xe5, 0xdf, 0x3b, 0xcf, 0x6a, 0x37, 0x2f, 0x9f,
		0xfe, 0x7d, 0x70, 0xf3, 0xf0, 0x0f, 0x7f, 0x3c, 0xf6, 0xd7, 0x76, 0x9e, 0x1d, 0xdc, 0xbc, 0x9c,
		0xf3, 0x5f, 0xf6, 0x6f, 0x5e, 0x2e, 0xf8, 0x8c, 0xbd, 0x9b, 0x27, 0x33, 0x7f, 0xf5, 0xf6, 0xcf,
		0xab, 0xf3, 0x7e, 0xa1, 0x36, 0xe7, 0x17, 0x76, 0xe7, 0xfd, 0xc2, 0xee, 0x9c, 0x5f, 0x98, 0xfb,
		0x4a, 0xd5, 0x39, 0xbf, 0xb0, 0x77, 0xf3, 0x63, 0xe6, 0xef, 0x3f, 0x79, 0xfc, 0xaf, 0xee, 0xdf,
		0x3c, 0xfd, 0x31, 0xef, 0xbf, 0x1d, 0xdc, 0xfc, 0x78, 0xf9, 0xf4, 0xe9, 0xd6, 0x93, 0x9d, 0xea,
		0xa7, 0xed, 0xe0, 0xc5, 0x88, 0x28, 0xdf, 0xb9, 0x9c, 0xe1, 0xcf, 0x47, 0x7c, 0x38, 0x71, 0x0b,
		0xc4, 0x18, 0x31, 0xfe, 0xa9, 0x18, 0xaf, 0x73, 0x33, 0xed, 0x29, 0x37, 0xbe, 0xd5, 0xee, 0xfc,
		0x15, 0xb4, 0xc3, 0xcf, 0x51, 0xdb, 0x16, 0x3e, 0x4c, 0xad, 0x0b, 0x82, 0x00, 0x41, 0x80, 0x20,
		0x40, 0x10, 0x45, 0x46, 0x10, 0xea, 0xea, 0x6c, 0x5a, 0xa5, 0x1d, 0xd0, 0x23, 0xef, 0xd7, 0x1f,
		0x42, 0x8f, 0x3c, 0xb9, 0xf5, 0xe8, 0x91, 0x57, 0x58, 0x11, 0xd9, 0xd9, 0xae, 0xbd, 0xd8, 0x3b,
		0xa0, 0x4f, 0x9e, 0x77, 0x4f, 0x67, 0x9a, 0x0f, 0xd3, 0x7c, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05,
		0xe0, 0xc2, 0x89, 0x0e, 0xdb, 0xa4, 0xeb, 0x36, 0x88, 0x02, 0x44, 0x01, 0xa2, 0x58, 0x52, 0x44,
		0x98, 0xe6, 0x03, 0x98, 0xf0, 0x09, 0x4c, 0x30, 0xcd, 0x07, 0x58, 0x01, 0xac, 0x00, 0x56, 0x00,
		0x2b, 0x16, 0xbf, 0x3b, 0x4c, 0xf3, 0x01, 0x57, 0x80, 0x2b, 0xc0, 0x15, 0x3e, 0x89, 0x08, 0xd3,
		0x7c, 0x00, 0x16, 0x5e, 0x01, 0x0b, 0xa6, 0xf9, 0x00, 0x2b, 0x80, 0x15, 0xc0, 0x0a, 0x60, 0xc5,
		0xa2, 0x77, 0x87, 0x69, 0x3e, 0x7e, 0x22, 0x0c, 0xa6, 0xf9, 0x14, 0xe7, 0xb0, 0x9c, 0xc0, 0x42,
		0x47, 0xbe, 0xbf, 0x2b, 0x98, 0xe8, 0x12, 0x09, 0x18, 0xc2, 0x46, 0x27, 0xf0, 0xd1, 0x17, 0x51,
		0x62, 0x9a, 0x4f, 0x01, 0x57, 0x61, 0x9a, 0xcf, 0x82, 0x8e, 0x16, 0xd3, 0x7c, 0x74, 0x36, 0x96,
		0x69, 0x3e, 0xba, 0x9b, 0xcb, 0x34, 0x1f, 0xe9, 0x1d, 0x65, 0x9a, 0x8f, 0xf8, 0x96, 0x32, 0xcd,
		0x47, 0x7c, 0x4b, 0x99, 0xe6, 0x23, 0xbe, 0xa5, 0x4c, 0xf3, 0x91, 0xdf, 0x52, 0xa6, 0xf9, 0x88,
		0x7b, 0x53, 0x4c, 0xf3, 0x11, 0xde, 0x51, 0xa6, 0xf9, 0x48, 0xef, 0x28, 0xd3, 0x7c, 0xbc, 0xfb,
		0x0e, 0x22, 0xda, 0x4c, 0xf3, 0x59, 0x92, 0x9d, 0x20, 0xba, 0xbd, 0xc0, 0x89, 0x10, 0xdd, 0xce,
		0xb9, 0x20, 0xd1, 0x6d, 0xbf, 0x3c, 0x09, 0x5a, 0x05, 0xae, 0xa4, 0x72, 0xe8, 0xb1, 0x46, 0x8f,
		0x35, 0x5a, 0x05, 0x22, 0xc6, 0x88, 0x31, 0x88, 0x61, 0x01, 0xc4, 0x60, 0xd9, 0x25, 0x70, 0x76,
		0x49, 0x70, 0x03, 0xb8, 0x01, 0xdc, 0x00, 0x6e, 0x28, 0x32, 0x6e, 0xa0, 0x41, 0xa0, 0x67, 0x64,
		0x30, 0x65, 0x77, 0x82, 0xeb, 0x51, 0x76, 0x57, 0x58, 0x11, 0xa1, 0x41, 0xa0, 0xa7, 0x4f, 0x67,
		0xdc, 0xac, 0x88, 0x1b, 0x54, 0xea, 0x71, 0xb3, 0xfb, 0x5b, 0xd9, 0x90, 0x39, 0x5f, 0xe7, 0xcd,
		0x8a, 0x8e, 0x42, 0x0d, 0xd3, 0x48, 0x6f, 0x5a, 0xdf, 0xe8, 0xf1, 0x05, 0x1b, 0xd6, 0x57, 0x65,
		0x58, 0x9f, 0x35, 0x84, 0x64, 0x58, 0x5f, 0x69, 0x6d, 0x05, 0xc3, 0xfa, 0x60, 0xd2, 0x60, 0xd2,
		0x60, 0xd2, 0x60, 0xd2, 0x7c, 0x66, 0xd2, 0x88, 0xc0, 0x2f, 0xb5, 0x10, 0xa1, 0x4b, 0x22, 0xf0,
		0x3a, 0x12, 0x4c, 0x04, 0x1e, 0x31, 0x26, 0x02, 0xaf, 0x6c, 0x61, 0x19, 0xd6, 0x07, 0x82, 0x00,
		0x41, 0x80, 0x20, 0x40, 0x10, 0x72, 0x08, 0x82, 0x58, 0xfc, 0x52, 0x3f, 0xc4, 0xe2, 0x73, 0x2d,
		0x47, 0x2c, 0x5e, 0x46, 0x44, 0x88, 0xc5, 0x97, 0x40, 0x50, 0x88, 0xc5, 0x17, 0x0f, 0x80, 0x30,
		0xac, 0x0f, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x00, 0x2e, 0xdc, 0xe9, 0xb0, 0x4d, 0x86, 0x6a, 0x80,
		0x28, 0x40, 0x14, 0x20, 0x8a, 0x25, 0x45, 0x84, 0x61, 0x7d, 0x80, 0x09, 0x9f, 0xc0, 0x04, 0xc3,
		0xfa, 0x80, 0x15, 0xc0, 0x0a, 0x60, 0x05, 0xb0, 0x62, 0xf1, 0xbb, 0xc3, 0xb0, 0x3e, 0x70, 0x05,
		0xb8, 0x02, 0x5c, 0xe1, 0x93, 0x88, 0x30, 0xac, 0x0f, 0x60, 0xe1, 0x15, 0xb0, 0x60, 0x58, 0x1f,
		0xb0, 0x02, 0x58, 0x01, 0xac, 0x00, 0x56, 0x2c, 0x7a, 0x77, 0x18, 0xd6, 0xe7, 0x27, 0xc2, 0x60,
		0x58, 0x5f, 0x71, 0x0e, 0xcb, 0x09, 0x2c, 0x74, 0xe4, 0xfb, 0xbb, 0x82, 0x89, 0x2e, 0x91, 0x80,
		0x21, 0x6c, 0x74, 0x02, 0x1f, 0x7d, 0x11, 0x25, 0x86, 0xf5, 0x15, 0x70, 0x15, 0x86, 0xf5, 0x2d,
		0xe8, 0x68, 0x31, 0xac, 0x4f, 0x67, 0x63, 0x19, 0xd6, 0xa7, 0xbb, 0xb9, 0x0c, 0xeb, 0x93, 0xde,
		0x51, 0x86, 0xf5, 0x89, 0x6f, 0x29, 0xc3, 0xfa, 0xc4, 0xb7, 0x94, 0x61, 0x7d, 0xe2, 0x5b, 0xca,
		0xb0, 0x3e, 0xf9, 0x2d, 0x65, 0x58, 0x9f, 0xb8, 0x37, 0xc5, 0xb0, 0x3e, 0xe1, 0x1d, 0x65, 0x58,
		0x9f, 0xf4, 0x8e, 0x32, 0xac, 0xcf, 0xbb, 0xef, 0x20, 0xa2, 0xcd, 0xb0, 0xbe, 0x25, 0xd9, 0x09,
		0xa2, 0xdb, 0x0b, 0x9c, 0x08, 0xd1, 0xed, 0x9c, 0x0b, 0x12, 0xdd, 0xf6, 0xcb, 0x93, 0xa0, 0x55,
		0xe0, 0x4a, 0x2a, 0x87, 0x1e, 0x6b, 0xf4, 0x58, 0xa3, 0x55, 0x20, 0x62, 0x8c, 0x18, 0x83, 0x18,
		0x16, 0x40, 0x0c, 0x0c, 0xeb, 0x03, 0x37, 0x80, 0x1b, 0xc0, 0x0d, 0xe0, 0x86, 0x55, 0x71, 0x03,
		0x0d, 0x02, 0x3d, 0x23, 0x83, 0x29, 0xbb, 0x13, 0x5c, 0x8f, 0xb2, 0xbb, 0xc2, 0x8a, 0x08, 0x0d,
		0x02, 0x3d, 0x7d, 0x3a, 0xc3, 0xfa, 0x44, 0xdc, 0xa0, 0x92, 0x0f, 0xeb, 0x1b, 0xcd, 0x98, 0xf3,
		0x75, 0x56, 0xdf, 0x86, 0x47, 0x22, 0xa1, 0x25, 0x0a, 0xae, 0x45, 0xa0, 0x22, 0x3a, 0x10, 0xb1,
		0x37, 0x68, 0xa4, 0x49, 0xe6, 0xb8, 0x9e, 0x8d, 0xde, 0xed, 0x24, 0x7b, 0xb5, 0xfa, 0xf9, 0x70,
		0xfd, 0xd7, 0x93, 0x37, 0xcb, 0xfe, 0xa0, 0xfe, 0x7e, 0xd0, 0x8e, 0xea, 0x27, 0xb7, 0xaf, 0xb2,
		0xe1, 0x87, 0xd4, 0x08, 0x48, 0x4c, 0xa5, 0x5d, 0x15, 0x93, 0x92, 0x09, 0x12, 0x68, 0x57, 0x85,
		0x0e, 0x4b, 0x78, 0x0a, 0xa4, 0x38, 0x57, 0xa1, 0xc1, 0x4d, 0x68, 0x73, 0x11, 0x5a, 0xdc, 0x83,
		0x3a, 0xd7, 0xa0, 0xce, 0x2d, 0x18, 0x70, 0x09, 0x7e, 0x59, 0x0a, 0xe9, 0xa9, 0x8d, 0x95, 0xc6,
		0xf8, 0x7e, 0x29, 0x4d, 0x9a, 0xcd, 0x9e, 0x5f, 0xb0, 0x51, 0xb3, 0xdb, 0x8c, 0x9a, 0xb5, 0x52,
		0x42, 0x66, 0xca, 0xc8, 0x4c, 0x29, 0x19, 0x2a, 0xa7, 0x62, 0x20, 0x1d, 0x93, 0x51, 0xb3, 0xd7,
		0x61, 0xc3, 0x76, 0x4e, 0xd4, 0xed, 0x82, 0xc4, 0x7f, 0xac, 0xd5, 0x9d, 0xb5, 0xda, 0xb3, 0x52,
		0x7f, 0xe6, 0x6a, 0xd0, 0x5c, 0x1d, 0x3a, 0x50, 0x8b, 0xba, 0x54, 0x58, 0xf1, 0xe3, 0x3f, 0xd7,
		0x61, 0x43, 0x39, 0x05, 0x76, 0xb3, 0x7c, 0x79, 0x63, 0xd3, 0x09, 0x21, 0x0f, 0xf3, 0x4c, 0xaa,
		0x37, 0x4f, 0xff, 0xde, 0xbb, 0x21, 0x71, 0xc9, 0xff, 0x7d, 0x64, 0xc8, 0xe6, 0xd8, 0x89, 0x09,
		0xae, 0xc3, 0xfe, 0xbf, 0xcd, 0x5d, 0xa7, 0xd1, 0xaa, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8,
		0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0x85, 0xf0, 0x9f, 0xa2, 0xf4, 0x4b, 0xd4,
		0x4b, 0x35, 0x95, 0xcc, 0x44, 0xc1, 0xdc, 0x2d, 0x85, 0xa7, 0x84, 0xa7, 0x84, 0xa7, 0x84, 0xa7,
		0x54, 0x50, 0x4f, 0x69, 0xa2, 0xc8, 0xe8, 0xbe, 0xbb, 0xe8, 0x8f, 0x71, 0xf7, 0xdd, 0x9d, 0x7d,
		0xc3, 0x7e, 0x7d, 0xfb, 0xb4, 0xdf, 0x5d, 0xfd, 0xc3, 0xd6, 0xb1, 0xfd, 0xee, 0xce, 0xde, 0xee,
		0x3e, 0x1d, 0x78, 0x55, 0xa4, 0x69, 0x0d, 0x3b, 0xf0, 0xee, 0xef, 0xed, 0xed, 0xee, 0xd1, 0x83,
		0xb7, 0x68, 0xab, 0xd0, 0x83, 0x77, 0x31, 0x73, 0x4e, 0x0f, 0x5e, 0xa5, 0x8d, 0x3d, 0xfe, 0xf0,
		0xdf, 0xc7, 0xef, 0x3f, 0xfc, 0xf3, 0xfc, 0x98, 0x0e, 0xbc, 0x6a, 0x5b, 0x5b, 0x3f, 0x39, 0xff,
		0x58, 0xa3, 0x8d, 0x9c, 0xc6, 0xce, 0xbe, 0x7f, 0xf7, 0x1b, 0x0d, 0xfa, 0x54, 0x76, 0xf6, 0xf4,
		0x94, 0xee, 0xd1, 0x3a, 0x3b, 0x7b, 0xf4, 0x9e, 0x8d, 0x55, 0xd9, 0xd8, 0x8f, 0xa7, 0x47, 0x67,
		0xec, 0xac, 0xc6, 0xce, 0xbe, 0x3d, 0x3f, 0xbd, 0x60, 0x67, 0x95, 0x5c, 0x83, 0x7d, 0xfa, 0xa1,
		0xfa, 0xf5, 0x1d, 0x94, 0x19, 0x2b, 0x76, 0x37, 0x32, 0x49, 0x6a, 0x9f, 0x5a, 0x8b, 0x28, 0xe3,
		0xa3, 0x0b, 0x10, 0x65, 0xcc, 0x71, 0xf6, 0x44, 0x19, 0x0b, 0xa2, 0x73, 0xc9, 0xc7, 0x5a, 0x4e,
		0x9d, 0x91, 0x8f, 0x25, 0x60, 0xe3, 0xc9, 0xc7, 0xc2, 0x57, 0x12, 0xf3, 0x95, 0x8c, 0x52, 0xd9,
		0x1f, 0x2e, 0x88, 0xd7, 0x84, 0xd7, 0x84, 0xd7, 0x84, 0xd7, 0x84, 0xd7, 0x84, 0xd7, 0x84, 0xd7,
		0x84, 0xd7, 0x44, 0x23, 0x3b, 0x59, 0xff, 0xce, 0x5d, 0x17, 0xb3, 0x76, 0x75, 0x2b, 0x6b, 0x60,
		0xe3, 0x6b, 0x1f, 0x3b, 0xd1, 0x16, 0x6b, 0x61, 0x1a, 0xe9, 0x75, 0x02, 0x1a, 0x3d, 0xbe, 0x60,
		0x8d, 0x80, 0xaa, 0x34, 0x02, 0xb2, 0xf6, 0x81, 0x69, 0x04, 0x54, 0x5a, 0x4b, 0x41, 0x23, 0x20,
		0x28, 0x00, 0x28, 0x00, 0x28, 0x00, 0x28, 0x00, 0x28, 0x00, 0x28, 0x00, 0x28, 0x00, 0x28, 0x00,
		0x97, 0x3a, 0x86, 0x46, 0x40, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0xf8,
		0x4f, 0xf8, 0x4f, 0xf8, 0x4f, 0x4b, 0xee, 0x3c, 0x8d, 0x80, 0xf0, 0x94, 0xf0, 0x94, 0xf0, 0x94,
		0xf0, 0x94, 0x56, 0x50, 0x64, 0x34, 0x02, 0x5a, 0xf4, 0x87, 0x46, 0x40, 0xf9, 0x96, 0xa2, 0x11,
		0x50, 0x71, 0x1c, 0x85, 0xb9, 0xcb, 0xd2, 0x08, 0x48, 0x5d, 0x9a, 0x68, 0x04, 0x54, 0x7a, 0x71,
		0xa2, 0x11, 0x90, 0xfb, 0x4b, 0x47, 0x23, 0x20, 0x89, 0xb5, 0x68, 0x04, 0x54, 0x1e, 0x47, 0x66,
		0x93, 0x46, 0x40, 0xb6, 0x3b, 0x4b, 0x23, 0x20, 0xad, 0x9d, 0xa5, 0x11, 0x90, 0xd6, 0xce, 0xd2,
		0x08, 0x48, 0x69, 0x63, 0x69, 0x04, 0xa4, 0xb5, 0xb3, 0x34, 0x02, 0x52, 0x74, 0x0d, 0x68, 0x04,
		0xe4, 0xd9, 0x77, 0xd0, 0x08, 0x88, 0x46, 0x40, 0x6e, 0xe9, 0x1e, 0xa2, 0x8c, 0xab, 0xac, 0x47,
		0x94, 0x51, 0x6a, 0x41, 0xa2, 0x8c, 0x3f, 0xdf, 0x1f, 0xf2, 0xb1, 0x56, 0x51, 0x39, 0xe4, 0x63,
		0xe5, 0xde, 0x42, 0xf2, 0xb1, 0xd6, 0xcc, 0x57, 0xa2, 0x11, 0x10, 0x5e, 0x13, 0x5e, 0x13, 0x5e,
		0x13, 0x5e, 0x13, 0x5e, 0x13, 0x5e, 0x13, 0x5e, 0x53, 0x69, 0xbc, 0x26, 0x1a, 0x01, 0x39, 0x6b,
		0x04, 0x34, 0xea, 0x5f, 0xe3, 0x6b, 0x1f, 0xa0, 0x0d, 0x8f, 0x04, 0x42, 0x4b, 0x10, 0xdc, 0x0a,
		0x40, 0x45, 0xb4, 0xd5, 0x52, 0x6f, 0xd0, 0x48, 0x93, 0xcc, 0xee, 0x9e, 0x8d, 0xde, 0xec, 0x24,
		0x7b, 0xb1, 0xfa, 0xf9, 0x70, 0xf5, 0xd7, 0x93, 0xf7, 0xca, 0xfe, 0xa0, 0xfe, 0x7e, 0xd0, 0x8e,
		0xea, 0xa7, 0x55, 0x19, 0x19, 0xcc, 0x2f, 0x31, 0x02, 0xd2, 0x52, 0xe9, 0x47, 0xff, 0x19, 0x44,
		0x49, 0x23, 0x0a, 0xe2, 0xa6, 0x98, 0xa8, 0xdc, 0xc1, 0xb3, 0xa9, 0x87, 0x0b, 0x49, 0xb6, 0x2c,
		0x14, 0x13, 0x87, 0x5e, 0x1a, 0x50, 0xeb, 0x1e, 0xb4, 0x92, 0xcc, 0x23, 0xd3, 0xc2, 0x50, 0xea,
		0x98, 0x49, 0x1d, 0x23, 0xcd, 0x60, 0xa2, 0x56, 0xa5, 0xa4, 0x96, 0x42, 0x1c, 0xdc, 0x4c, 0xa4,
		0xb5, 0x1d, 0x85, 0x2d, 0xd9, 0xbc, 0xc7, 0x09, 0x70, 0x39, 0x10, 0x7c, 0xe6, 0x79, 0x66, 0xcc,
		0x9e, 0x3f, 0x1f, 0x39, 0x18, 0x5b, 0xd3, 0x4a, 0xab, 0x4c, 0x8a, 0x5e, 0xb4, 0xb9, 0xa0, 0x4a,
		0x53, 0x41, 0xe1, 0x66, 0x82, 0xe2, 0x4d, 0x04, 0x51, 0xee, 0x28, 0xf7, 0x42, 0x29, 0x77, 0xe9,
		0x76, 0x7f, 0x95, 0x21, 0x2f, 0x18, 0x35, 0x83, 0x4e, 0x23, 0x8d, 0x86, 0xa5, 0x13, 0x4a, 0xad,
		0x4a, 0x1f, 0xac, 0xa3, 0xd3, 0xb3, 0x74, 0x5b, 0xab, 0x67, 0xe9, 0x76, 0x41, 0x7b, 0x96, 0xb6,
		0x68, 0x56, 0xea, 0x50, 0x2d, 0x59, 0xa8, 0xa7, 0x62, 0xd0, 0x58, 0x6a, 0x84, 0xfb, 0x44, 0xda,
		0x1b, 0x9d, 0x41, 0x92, 0x46, 0xbd, 0xfd, 0x9a, 0x86, 0xc4, 0x67, 0xea, 0x45, 0x81, 0x5d, 0x57,
		0xae, 0xa4, 0x55, 0x8c, 0x70, 0x58, 0x54, 0xca, 0x1a, 0xd5, 0x32, 0x4e, 0x6a, 0x17, 0xb5, 0xd7,
		0x31, 0xac, 0x53, 0x54, 0x4c, 0x5d, 0x36, 0x29, 0x6b, 0xb5, 0x3e, 0xfa, 0x9d, 0x17, 0xb5, 0xda,
		0xfe, 0x41, 0xad, 0xb6, 0x7d, 0xb0, 0x7b, 0xb0, 0x7d, 0xb8, 0xb7, 0xb7, 0xb3, 0xaf, 0x5d, 0x73,
		0x67, 0x2a, 0x0d, 0x05, 0x09, 0xc6, 0x5c, 0xae, 0xc1, 0x4c, 0x80, 0xb1, 0x27, 0xdc, 0xfd, 0xb7,
		0x85, 0xbf, 0x3d, 0x5c, 0x05, 0x6f, 0x1b, 0x6f, 0x1b, 0x6f, 0x1b, 0x6f, 0x1b, 0x6f, 0x1b, 0x6f,
		0x1b, 0x6f, 0x1b, 0x6f, 0x1b, 0x6f, 0x1b, 0x6f, 0x7b, 0x4d, 0xbc, 0x6d, 0x8d, 0x6c, 0x88, 0x19,
		0x73, 0x28, 0x9f, 0x15, 0x81, 0xaf, 0x8d, 0xaf, 0x8d, 0xaf, 0x8d, 0xaf, 0x9d, 0x35, 0x90, 0xdc,
		0xad, 0x2a, 0x3a, 0xda, 0x07, 0x38, 0xda, 0x38, 0xda, 0x38, 0xda, 0xa5, 0x74, 0xb4, 0x6b, 0xd5,
		0xc3, 0xda, 0xe1, 0xfe, 0x41, 0xf5, 0x10, 0xf7, 0x1a, 0xf7, 0x5a, 0xf4, 0x49, 0x24, 0xb6, 0xcf,
		0x4d, 0x6c, 0x17, 0x2c, 0x6b, 0xf0, 0x23, 0xd3, 0x30, 0xed, 0x85, 0x49, 0xbf, 0xdb, 0xe9, 0xa5,
		0xf2, 0xd9, 0x86, 0x77, 0x8f, 0xf6, 0x3c, 0xe3, 0xb0, 0x28, 0xe9, 0xe4, 0x0a, 0x95, 0xba, 0x24,
		0x1e, 0x2e, 0x8c, 0x7f, 0xe4, 0x2b, 0x6d, 0x4b, 0x9e, 0x7f, 0xd8, 0x18, 0xdf, 0x2f, 0x25, 0x6a,
		0x26, 0x7b, 0x7e, 0xc1, 0x66, 0xa4, 0x6f, 0x33, 0x23, 0x1d, 0x72, 0xa6, 0x00, 0xca, 0xa9, 0x18,
		0x1c, 0x8d, 0xc9, 0x8c, 0x74, 0x51, 0xf7, 0x68, 0xee, 0x25, 0x9b, 0x59, 0x91, 0xfe, 0x28, 0xd6,
		0x0a, 0xcf, 0x5a, 0xf1, 0x59, 0x29, 0x40, 0x73, 0x45, 0x68, 0xae, 0x10, 0x1d, 0x28, 0x46, 0x65,
		0xce, 0xa2, 0xf0, 0xfd, 0x51, 0x6e, 0x75, 0x58, 0x90, 0x0c, 0xae, 0x83, 0xde, 0x90, 0x30, 0x66,
		0x76, 0xd5, 0xaf, 0x7f, 0x0c, 0x87, 0x5d, 0xf4, 0xd3, 0x5e, 0x9c, 0x5c, 0x59, 0xce, 0xb9, 0x78,
		0x61, 0xb0, 0x96, 0x55, 0x03, 0x96, 0xc9, 0x82, 0xff, 0x7a, 0xb2, 0xbf, 0xb7, 0xb7, 0xfb, 0x69,
		0x3b, 0xd8, 0xbb, 0xfc, 0xb1, 0xbf, 0xb7, 0xf7, 0x69, 0x3b, 0xa8, 0x5e, 0x7e, 0xda, 0x0e, 0x0e,
		0x6f, 0xff, 0xed, 0xd3, 0x76, 0x50, 0x1b, 0xfd, 0xcb, 0xdf, 0xd5, 0x9b, 0x1f, 0xfb, 0x53, 0xff,
		0xba, 0x7b, 0xf3, 0x63, 0xf8, 0x2b, 0xa3, 0x7f, 0xab, 0x0d, 0xff, 0xed, 0xf0, 0xf2, 0xef, 0x9d,
		0x67, 0xb5, 0x9b, 0xa7, 0x7f, 0xfe, 0xf9, 0xfc, 0xcf, 0x3f, 0x9f, 0x8b, 0x3f, 0xf6, 0xbf, 0xf4,
		0x1b, 0x40, 0x5f, 0x5a, 0x1c, 0xb0, 0x65, 0x9b, 0x1d, 0x4e, 0xf9, 0xb1, 0x53, 0x66, 0x9a, 0xd0,
		0x52, 0xe6, 0xef, 0x73, 0xd4, 0x63, 0x42, 0xa0, 0xd7, 0x47, 0x36, 0xf9, 0xb0, 0x75, 0x9c, 0x10,
		0xb8, 0xcd, 0x78, 0x40, 0x15, 0x51, 0x62, 0x3c, 0x60, 0xe9, 0xc5, 0x89, 0xf1, 0x80, 0x6b, 0x65,
		0xd0, 0xa3, 0x64, 0x70, 0x1d, 0xf5, 0x46, 0xe1, 0x6c, 0x43, 0xd8, 0x54, 0x33, 0x58, 0xeb, 0x38,
		0x19, 0x5c, 0xdf, 0xaa, 0x2b, 0x46, 0x9e, 0xe8, 0xbe, 0xaf, 0x62, 0x1b, 0x6f, 0x1b, 0x8e, 0x7a,
		0x7a, 0x31, 0xe8, 0xe9, 0xc7, 0x11, 0x2a, 0xf4, 0xf4, 0xea, 0x67, 0x0f, 0x3d, 0x5d, 0x10, 0xad,
		0x0b, 0x3d, 0xbd, 0xbc, 0x25, 0x87, 0x9e, 0x5e, 0xc2, 0xd0, 0x40, 0x4f, 0x4b, 0x2c, 0x08, 0x71,
		0x39, 0xe5, 0x24, 0x42, 0x4f, 0x43, 0x4f, 0x83, 0x66, 0xa1, 0xa7, 0x0b, 0x76, 0x64, 0x93, 0x0f,
		0x83, 0x9e, 0xd6, 0x5f, 0x17, 0x7a, 0xba, 0xb4, 0xa2, 0x04, 0x3d, 0x5d, 0xc8, 0x55, 0x30, 0xe8,
		0x8b, 0x19, 0x74, 0xe8, 0x69, 0x6f, 0x45, 0x79, 0x9d, 0xe9, 0xe9, 0xb4, 0xd1, 0x0d, 0x5a, 0xed,
		0xf0, 0xaa, 0xaf, 0x4f, 0x4e, 0xdf, 0x2d, 0x05, 0x35, 0xfd, 0x38, 0x3a, 0x85, 0x9a, 0x5e, 0xfd,
		0xec, 0xa1, 0xa6, 0x0b, 0xa2, 0x71, 0x8b, 0x4f, 0x4d, 0xc7, 0xcd, 0x28, 0x49, 0xe3, 0xf4, 0xbb,
		0xec, 0x40, 0x96, 0xb9, 0x26, 0x5c, 0xd1, 0x29, 0xae, 0x9c, 0x64, 0x9f, 0xf2, 0x2a, 0xec, 0x1b,
		0x5c, 0xd2, 0xf1, 0x06, 0x7e, 0xf8, 0xed, 0xbc, 0xfe, 0xfa, 0xf4, 0xe8, 0xcd, 0x45, 0xc5, 0xa2,
		0x17, 0x43, 0xdf, 0x84, 0x6c, 0xb0, 0x01, 0x6b, 0xf7, 0xb6, 0xf0, 0xe8, 0xb7, 0x7f, 0xe8, 0x13,
		0x76, 0x06, 0xb0, 0xd7, 0xc1, 0xd6, 0xfd, 0xf1, 0xfe, 0x0d, 0x5b, 0xb7, 0xda, 0xd6, 0xfd, 0xf6,
		0x3f, 0xef, 0xd9, 0xba, 0xd5, 0xb6, 0xee, 0xe2, 0x9f, 0x67, 0x6c, 0xdd, 0x6a, 0x5b, 0x77, 0xfc,
		0xdb, 0x31, 0x5b, 0xb7, 0xda, 0xd6, 0x9d, 0x5f, 0xfc, 0x37, 0x5b, 0xb7, 0xda, 0xd6, 0xbd, 0xbf,
		0xf8, 0xc0, 0xd6, 0xad, 0xe8, 0xdf, 0x9d, 0x58, 0xe8, 0x3a, 0xd5, 0x15, 0x2e, 0x41, 0x56, 0xc3,
		0x63, 0x3d, 0x8d, 0xfb, 0xe9, 0x51, 0x9a, 0xf6, 0x74, 0xd1, 0xd5, 0xdb, 0x38, 0x39, 0x6e, 0x47,
		0xb7, 0x08, 0xb7, 0xaf, 0x1b, 0x85, 0xa8, 0xbc, 0x0d, 0xbf, 0x4d, 0xad, 0x64, 0xdb, 0x10, 0xb9,
		0xf2, 0xae, 0xd7, 0x8c, 0x7a, 0x51, 0xf3, 0xd5, 0xf7, 0xca, 0xcb, 0xcd, 0x64, 0xd0, 0x6e, 0x33,
		0xab, 0x5d, 0x82, 0x1b, 0x29, 0xef, 0xac, 0xf6, 0x49, 0x97, 0xae, 0xad, 0xac, 0x9f, 0xce, 0x3a,
		0x74, 0x8e, 0x16, 0x1d, 0xaf, 0x3a, 0x63, 0x9e, 0x24, 0xc7, 0xac, 0xce, 0xb0, 0x35, 0x5a, 0x7d,
		0x89, 0xaa, 0xf4, 0x25, 0x9a, 0x59, 0x87, 0xbe, 0x44, 0x4b, 0x2b, 0x4a, 0xfa, 0x12, 0x6d, 0xd2,
		0x97, 0x28, 0x8f, 0x82, 0x23, 0xba, 0xe6, 0x5e, 0xf1, 0x59, 0x29, 0x40, 0x73, 0x45, 0x68, 0xae,
		0x10, 0x1d, 0x28, 0xc6, 0x62, 0x62, 0x40, 0x0a, 0x3f, 0x72, 0xed, 0x1b, 0x85, 0x1f, 0x2b, 0x9f,
		0x0e, 0x85, 0x1f, 0x14, 0x7e, 0xe4, 0x3f, 0x60, 0x0a, 0x3f, 0x28, 0xfc, 0x28, 0x84, 0x82, 0xa5,
		0xf0, 0xa3, 0x28, 0x47, 0x36, 0xf9, 0x30, 0x0a, 0x3f, 0xf4, 0xd7, 0xa5, 0xf0, 0xa3, 0xb4, 0xa2,
		0x44, 0xe1, 0x47, 0x21, 0x57, 0xc1, 0xa0, 0x2f, 0x66, 0xd0, 0x29, 0xfc, 0xf0, 0x56, 0x94, 0xe9,
		0x4b, 0x44, 0x5f, 0xa2, 0x05, 0x1f, 0x0f, 0x3d, 0xbd, 0xc2, 0x7a, 0xd0, 0xd3, 0x52, 0x0b, 0x42,
		0x4f, 0xff, 0x7c, 0x7f, 0xa0, 0xa7, 0x73, 0xed, 0x1b, 0xf4, 0xf4, 0xca, 0xa7, 0x03, 0x3d, 0x0d,
		0x3d, 0x9d, 0xff, 0x80, 0xa1, 0xa7, 0xa1, 0xa7, 0x0b, 0xa1, 0x60, 0xa1, 0xa7, 0x8b, 0x72, 0x64,
		0x93, 0x0f, 0x83, 0x9e, 0xd6, 0x5f, 0x17, 0x7a, 0xba, 0xb4, 0xa2, 0x04, 0x3d, 0x5d, 0xc8, 0x55,
		0x30, 0xe8, 0x8b, 0x19, 0x74, 0xe8, 0x69, 0x6f, 0x45, 0x99, 0xbe, 0x44, 0xf4, 0x25, 0x5a, 0xe0,
		0xf1, 0x50, 0xd3, 0x2b, 0xac, 0x07, 0x35, 0x2d, 0xb5, 0x20, 0xd4, 0xf4, 0xcf, 0xf7, 0x87, 0xbe,
		0x44, 0x2b, 0xac, 0x41, 0x5f, 0xa2, 0x62, 0x11, 0x0d, 0xf4, 0x25, 0x92, 0xd9, 0x3a, 0xfa, 0x12,
		0xad, 0xbc, 0x75, 0xf4, 0x25, 0x5a, 0x79, 0xeb, 0xe8, 0x4b, 0xb4, 0xf2, 0xd6, 0xd1, 0x97, 0x68,
		0xe5, 0xad, 0xa3, 0x2f, 0xd1, 0xca, 0x5b, 0x47, 0x5f, 0xa2, 0xd5, 0xfd, 0x3b, 0xfa, 0x12, 0x95,
		0x05, 0x59, 0xd1, 0x97, 0x48, 0x70, 0x71, 0xfa, 0x12, 0xd1, 0x97, 0x68, 0xb5, 0xbe, 0x44, 0xa3,
		0x76, 0x3a, 0xbe, 0xb6, 0x25, 0xda, 0xf0, 0x48, 0x2e, 0xb4, 0xe4, 0xc1, 0x0b, 0x39, 0xa8, 0x88,
		0x36, 0x80, 0xea, 0x0d, 0x1a, 0x69, 0x92, 0x99, 0xed, 0xb3, 0xd1, 0x0b, 0x9e, 0x64, 0xef, 0x57,
		0x3f, 0x1f, 0xbe, 0xc4, 0xeb, 0xc9, 0xeb, 0x65, 0x7f, 0x50, 0x7f, 0x3f, 0x68, 0x47, 0xf5, 0x0f,
		0x93, 0xf7, 0xd9, 0xf0, 0x43, 0x7e, 0xf2, 0x3d, 0x21, 0xa7, 0xe4, 0x55, 0xfe, 0x11, 0x7d, 0x1f,
		0xe6, 0x45, 0x46, 0xff, 0x19, 0x44, 0x49, 0x23, 0x0a, 0xe2, 0x66, 0xce, 0x73, 0x92, 0xb5, 0xba,
		0xf2, 0xd6, 0xd5, 0xc4, 0x8a, 0xca, 0x5a, 0xcb, 0xbc, 0x67, 0x2c, 0xac, 0x55, 0x1c, 0x6a, 0x13,
		0x01, 0x1d, 0x92, 0x43, 0x77, 0xe4, 0xd3, 0x18, 0xab, 0xdf, 0xf3, 0xd5, 0x7e, 0x73, 0x45, 0xa9,
		0x91, 0x92, 0x16, 0x37, 0x52, 0xb2, 0xda, 0x11, 0x2d, 0xbf, 0xc1, 0x2b, 0x6c, 0x6e, 0xce, 0xae,
		0x85, 0x22, 0xdd, 0x09, 0x73, 0x76, 0x21, 0xcc, 0xdd, 0x6d, 0x50, 0x22, 0x54, 0x7c, 0x2f, 0x14,
		0x9c, 0x27, 0x90, 0x25, 0x15, 0xe3, 0x15, 0x8f, 0xe1, 0x8a, 0xc7, 0x68, 0x67, 0x62, 0xb0, 0xad,
		0x4a, 0x41, 0x94, 0x51, 0xde, 0x3e, 0x7c, 0x95, 0x4c, 0x6f, 0xc4, 0xcd, 0xfc, 0xc7, 0x7c, 0x97,
		0xe2, 0x3c, 0x7e, 0x64, 0x5e, 0xdf, 0x4b, 0x24, 0xef, 0x43, 0x2c, 0xbf, 0x43, 0x32, 0x8f, 0x43,
		0xec, 0x92, 0x4a, 0x5f, 0x56, 0xb5, 0x4b, 0xab, 0x76, 0x79, 0x35, 0x2e, 0xb1, 0x1f, 0xd8, 0x43,
		0x2c, 0xf3, 0x41, 0xbe, 0xbc, 0xeb, 0xae, 0x7c, 0x0b, 0x9f, 0xcf, 0x63, 0x9f, 0x2f, 0x07, 0xb5,
		0xb4, 0x82, 0xcf, 0xb7, 0xa1, 0x78, 0x14, 0x63, 0x20, 0xbe, 0xaa, 0x71, 0xc9, 0x07, 0xbb, 0xf3,
		0xc3, 0x6c, 0x15, 0x58, 0x9d, 0x0f, 0x46, 0x2f, 0x7b, 0x02, 0x39, 0x2f, 0x81, 0xb5, 0xf0, 0x57,
		0x56, 0x82, 0x20, 0x2b, 0x60, 0xdf, 0xe5, 0xee, 0xd7, 0xe2, 0xb7, 0x64, 0xb1, 0xbf, 0xb9, 0xe0,
		0x29, 0xae, 0x7a, 0x7a, 0x66, 0xa7, 0xb6, 0xd8, 0x2e, 0xfe, 0x7a, 0x4f, 0x7e, 0xfe, 0x37, 0x7e,
		0xb1, 0x5b, 0xcb, 0xee, 0x92, 0xf6, 0xee, 0x2c, 0x20, 0xc3, 0x4b, 0xca, 0xec, 0xcf, 0xb7, 0x79,
		0xfe, 0xe6, 0xfd, 0x64, 0xe3, 0x2a, 0xdd, 0x5e, 0x27, 0xed, 0x34, 0x3a, 0xed, 0x5f, 0xe7, 0x9a,
		0xdf, 0x61, 0x84, 0xc9, 0xaf, 0xfc, 0xe2, 0x40, 0x16, 0x03, 0xe4, 0x0b, 0xfb, 0xf8, 0xcb, 0xf8,
		0xf0, 0xd3, 0x3e, 0x7a, 0x12, 0xa5, 0xb7, 0xa7, 0xb4, 0xc8, 0x79, 0x2c, 0xe9, 0x88, 0xaf, 0xec,
		0x68, 0xaf, 0xec, 0x48, 0x3f, 0x74, 0x94, 0xc7, 0xdf, 0xa6, 0x7c, 0xb5, 0x16, 0x85, 0xaa, 0x13,
		0xd9, 0x58, 0x7c, 0x0b, 0x1f, 0x4a, 0xd5, 0xa2, 0x3b, 0xb8, 0x1c, 0xdb, 0xb3, 0x34, 0x90, 0x5c,
		0x05, 0x30, 0xae, 0x26, 0x74, 0x79, 0x51, 0x60, 0x6e, 0xb4, 0x97, 0x1b, 0xd5, 0xad, 0x2c, 0x94,
		0x3a, 0xd6, 0x72, 0x59, 0x5e, 0xa5, 0xf2, 0xf9, 0xaa, 0xbb, 0xfc, 0xae, 0x8f, 0xcf, 0xfa, 0xf6,
		0x97, 0x97, 0x75, 0x87, 0x57, 0x22, 0x2a, 0x57, 0xe6, 0x42, 0xf2, 0x70, 0x1f, 0xd3, 0x22, 0xbd,
		0xfc, 0x97, 0x4a, 0x90, 0x1b, 0x62, 0x64, 0x86, 0x18, 0x79, 0xf1, 0x50, 0xdc, 0x6f, 0xf7, 0xc5,
		0x33, 0xc0, 0xb5, 0x2a, 0xb5, 0x58, 0xb9, 0x6a, 0x77, 0x3e, 0x87, 0xed, 0xfc, 0x44, 0x7e, 0xf6,
		0x1c, 0xc7, 0x4c, 0xfe, 0xb6, 0x1f, 0x4c, 0xfe, 0x6a, 0x17, 0x47, 0x9a, 0x1d, 0x2c, 0x1e, 0x95,
		0xbf, 0xd2, 0xc5, 0x72, 0x43, 0x32, 0xe5, 0xe6, 0xf2, 0xc3, 0x56, 0x1c, 0xf4, 0xc3, 0x56, 0xdc,
		0x97, 0xe3, 0xf2, 0xef, 0x1e, 0x29, 0xc3, 0xe5, 0xef, 0x94, 0x9c, 0xcb, 0xcf, 0x77, 0x4d, 0xa5,
		0xaf, 0xab, 0xda, 0xb5, 0x55, 0xbb, 0xbe, 0x2a, 0xd7, 0x38, 0x3f, 0xdb, 0xbc, 0x29, 0xc0, 0xe6,
		0x4b, 0x8d, 0xcc, 0x9a, 0xdc, 0x49, 0x39, 0xf1, 0x78, 0x78, 0xdb, 0xa5, 0xa4, 0x43, 0x76, 0xa6,
		0x9f, 0x78, 0xa1, 0xb6, 0x46, 0x61, 0xb6, 0xbc, 0x32, 0xd0, 0x52, 0x0a, 0xea, 0xca, 0x41, 0x5d,
		0x49, 0xa8, 0x2a, 0x0b, 0x19, 0xa5, 0x21, 0xa4, 0x3c, 0xc4, 0x95, 0xc8, 0x9d, 0x32, 0x69, 0x36,
		0x83, 0x6e, 0x98, 0x7e, 0xe9, 0xeb, 0x8d, 0x0b, 0xbd, 0x5b, 0xa2, 0x60, 0x23, 0x43, 0xb7, 0x8b,
		0x39, 0x32, 0x54, 0x56, 0xed, 0x68, 0xab, 0x1f, 0x33, 0x35, 0x64, 0xa6, 0x8e, 0x4c, 0xd4, 0x92,
		0xac, 0x7a, 0x12, 0x56, 0x53, 0x6a, 0xea, 0x6a, 0xf2, 0xe0, 0xc6, 0xf8, 0x8e, 0x2a, 0xf7, 0xb6,
		0xc9, 0xd6, 0xd1, 0x6d, 0x6c, 0xb3, 0x43, 0x63, 0x1b, 0x87, 0x8a, 0xcd, 0x4a, 0xc1, 0x99, 0x2b,
		0x3a, 0x73, 0x85, 0x67, 0xaa, 0xf8, 0x74, 0x14, 0xa0, 0x92, 0x22, 0x54, 0x57, 0x88, 0x93, 0x05,
		0xa2, 0x76, 0x7c, 0x15, 0x7f, 0x6e, 0x47, 0xc1, 0x48, 0xb4, 0x82, 0x2c, 0x17, 0xc2, 0xac, 0x05,
		0xcc, 0x9c, 0xf5, 0x95, 0x05, 0xce, 0xa6, 0xc5, 0xa5, 0xba, 0x42, 0xb5, 0x54, 0xac, 0xf6, 0x0a,
		0xd6, 0x5a, 0xd1, 0x3a, 0x53, 0xb8, 0xce, 0x14, 0xaf, 0x13, 0x05, 0xac, 0xab, 0x88, 0x95, 0x15,
		0xf2, 0x64, 0xc7, 0xd4, 0xbb, 0x8c, 0xcd, 0xdc, 0xb7, 0x76, 0x14, 0xb6, 0x74, 0x3b, 0x8d, 0xcd,
		0xf8, 0x99, 0x07, 0x36, 0xb3, 0x16, 0xb2, 0x5c, 0xa8, 0x46, 0xd0, 0xeb, 0x76, 0xda, 0x2f, 0x7b,
		0x9d, 0x41, 0x1a, 0x27, 0x57, 0x99, 0x25, 0x98, 0xfc, 0x71, 0x96, 0xeb, 0xd4, 0x8c, 0x5a, 0x71,
		0x12, 0xa7, 0x71, 0x27, 0xe9, 0xcf, 0xff, 0x4f, 0x93, 0xff, 0x32, 0xcc, 0x72, 0x2a, 0x68, 0x37,
		0x52, 0x45, 0x09, 0xae, 0xf4, 0xa2, 0x46, 0x14, 0x7f, 0x35, 0xec, 0xf4, 0x36, 0x5e, 0x50, 0xf9,
		0x56, 0xfe, 0x1e, 0xb5, 0xc2, 0x41, 0x7b, 0xa8, 0xc6, 0x5a, 0x61, 0xbb, 0x1f, 0xe1, 0x47, 0xe0,
		0x47, 0xe0, 0x47, 0xe0, 0x47, 0xe0, 0x47, 0x4c, 0x25, 0x8f, 0x75, 0x3a, 0xed, 0x28, 0x34, 0x6d,
		0x3e, 0xbe, 0x83, 0x09, 0x9e, 0xd9, 0x9b, 0x7e, 0x94, 0x34, 0xed, 0xec, 0xef, 0x70, 0x35, 0x8c,
		0x2f, 0xc6, 0x17, 0xe3, 0x8b, 0xf1, 0xc5, 0xf8, 0x62, 0x7c, 0x31, 0xbe, 0xc1, 0xb5, 0xc1, 0x70,
		0xa5, 0x7b, 0x06, 0x78, 0xb8, 0x22, 0x46, 0x11, 0xa3, 0x88, 0x51, 0xc4, 0x28, 0x62, 0x14, 0x27,
		0xf7, 0x6d, 0x10, 0x27, 0xe9, 0x0b, 0x43, 0x93, 0xb8, 0xc7, 0x74, 0xcb, 0xd5, 0x3f, 0x8c, 0xe9,
		0x96, 0xfa, 0xeb, 0x32, 0xdd, 0xb2, 0xb4, 0xa2, 0x54, 0xdd, 0x63, 0xb6, 0x65, 0xe1, 0x56, 0xb9,
		0x2c, 0x2a, 0x84, 0x2a, 0x54, 0xae, 0x93, 0x72, 0xf3, 0xee, 0x3b, 0xf0, 0x27, 0xdb, 0x83, 0x63,
		0xdc, 0x99, 0x62, 0xf2, 0x4f, 0x5b, 0x9f, 0xaf, 0xba, 0x5b, 0xa3, 0x62, 0xd4, 0xad, 0x49, 0x3d,
		0xdc, 0xe4, 0x9f, 0xb6, 0x26, 0xe9, 0xed, 0x5b, 0x59, 0xb2, 0xe8, 0x1a, 0x4f, 0x9d, 0xcc, 0xd7,
		0xc2, 0x73, 0x71, 0xf0, 0x9d, 0xa3, 0xc5, 0xe7, 0xc2, 0x3c, 0x8b, 0x76, 0x52, 0x6e, 0x95, 0xa4,
		0x5c, 0x7f, 0x10, 0x35, 0x49, 0xb9, 0x6b, 0x6c, 0xa8, 0x48, 0xca, 0x2d, 0xb0, 0x67, 0x0e, 0x75,
		0x59, 0x28, 0x45, 0xeb, 0x4c, 0xe1, 0x3a, 0x53, 0xbc, 0x4e, 0x14, 0xb0, 0x0d, 0x96, 0x22, 0x29,
		0x57, 0xc0, 0xcf, 0x24, 0x29, 0xd7, 0x25, 0xa2, 0x26, 0x29, 0x77, 0x79, 0x77, 0x89, 0xbc, 0x20,
		0xfc, 0x08, 0xfc, 0x08, 0xfc, 0x08, 0xfc, 0x88, 0xb9, 0xf7, 0x8d, 0xbc, 0x20, 0x2f, 0x4c, 0x30,
		0x49, 0xb9, 0x18, 0x5f, 0x8c, 0x2f, 0xc6, 0x17, 0xe3, 0x8b, 0xf1, 0xc5, 0xf8, 0x3a, 0x30, 0xbe,
		0x24, 0xe5, 0x62, 0x14, 0x31, 0x8a, 0x18, 0x45, 0x8c, 0xa2, 0x6b, 0xa3, 0x48, 0x52, 0x6e, 0xde,
		0x1f, 0x92, 0x72, 0x55, 0x96, 0x25, 0x29, 0x57, 0x57, 0x94, 0x48, 0xca, 0x2d, 0xb9, 0x30, 0x91,
		0x94, 0xeb, 0x16, 0x42, 0x91, 0x94, 0xfb, 0x18, 0xf8, 0xf3, 0x25, 0x29, 0x37, 0xc7, 0x08, 0x54,
		0xfb, 0x93, 0xf7, 0xbb, 0x9b, 0xaf, 0xb2, 0xec, 0x78, 0x23, 0x33, 0x15, 0x95, 0xcc, 0xe8, 0x9f,
		0x4e, 0x69, 0xcc, 0xde, 0xb0, 0xfe, 0xea, 0xaa, 0x5b, 0x7f, 0x33, 0x7c, 0xc3, 0xfa, 0x51, 0x2b,
		0xbe, 0x08, 0x5b, 0x71, 0xfd, 0xa8, 0xd9, 0x3c, 0x1f, 0xbe, 0xd5, 0x86, 0x9f, 0x92, 0x26, 0x28,
		0x65, 0x93, 0x01, 0x14, 0x41, 0xb6, 0x51, 0x5a, 0x1d, 0xe9, 0xef, 0x2d, 0xa3, 0xd3, 0x95, 0x7e,
		0x9b, 0xae, 0xf4, 0x74, 0xa5, 0xf7, 0x90, 0xbc, 0xa1, 0x2b, 0xbd, 0x1e, 0xf9, 0x62, 0x90, 0x46,
		0xa8, 0x99, 0x36, 0x38, 0x49, 0x13, 0x7c, 0xfe, 0x7c, 0xe4, 0x36, 0x6d, 0xdd, 0x57, 0x94, 0x6b,
		0x60, 0x80, 0x94, 0xe6, 0x0a, 0xe8, 0xce, 0x13, 0x60, 0x10, 0x0a, 0x26, 0x07, 0x93, 0xb3, 0x9e,
		0x83, 0x50, 0x74, 0x3d, 0x66, 0x53, 0xcf, 0xd9, 0x88, 0x3d, 0x64, 0x2c, 0x8a, 0x57, 0xea, 0xce,
		0x5c, 0xed, 0x99, 0xab, 0x3f, 0x53, 0x35, 0xa8, 0xc7, 0x4d, 0x6d, 0x2a, 0xb2, 0x92, 0xea, 0xe1,
		0xd0, 0xc9, 0x7d, 0x89, 0x9b, 0x51, 0x92, 0xc6, 0xe9, 0x77, 0xdd, 0x22, 0x9f, 0x89, 0x47, 0xa6,
		0x18, 0x87, 0xa8, 0x9c, 0x64, 0x9f, 0xf2, 0x2a, 0xec, 0x1b, 0x16, 0x99, 0x1c, 0xbd, 0x3e, 0xa9,
		0x5f, 0xdc, 0xfe, 0xbf, 0x0f, 0xff, 0x3c, 0x3f, 0xd6, 0xbe, 0xa2, 0xc3, 0x80, 0x4e, 0xdf, 0x24,
		0xc2, 0x6b, 0x94, 0x1c, 0x32, 0xde, 0xc6, 0xd3, 0xdd, 0x8f, 0xe7, 0x67, 0xf5, 0x93, 0xf3, 0x8f,
		0xb5, 0xfa, 0x1f, 0x67, 0x27, 0xbf, 0x1d, 0x5d, 0x7c, 0x30, 0x48, 0x99, 0x78, 0x56, 0xba, 0x5d,
		0x3c, 0x39, 0xfb, 0xc7, 0xc5, 0x87, 0xa3, 0x0f, 0xc7, 0x6c, 0xde, 0xf2, 0x9b, 0x37, 0x14, 0xbe,
		0xd3, 0xa3, 0x57, 0xc7, 0xa7, 0xc7, 0xbf, 0x23, 0x84, 0x39, 0x84, 0xb0, 0x7a, 0x7b, 0x95, 0x3f,
		0x9e, 0x9f, 0x5e, 0xb0, 0x7b, 0x39, 0xae, 0x70, 0xfd, 0xe2, 0xfc, 0x35, 0x1b, 0x98, 0xc3, 0x92,
		0xec, 0x73, 0x89, 0x73, 0x29, 0xc3, 0x7d, 0x94, 0xa1, 0x94, 0x32, 0x3c, 0xfe, 0x78, 0x7e, 0xc6,
		0xee, 0xad, 0x28, 0x85, 0x48, 0xdf, 0xca, 0xfb, 0x77, 0xf1, 0xfe, 0xc3, 0x71, 0xfd, 0xfc, 0xdd,
		0xe9, 0xc9, 0x6f, 0xff, 0x1c, 0xfa, 0xd6, 0xec, 0x61, 0x2e, 0x64, 0xf2, 0xf6, 0x8f, 0xd3, 0x0f,
		0xc8, 0x62, 0x1e, 0xf7, 0xfa, 0xf5, 0xe9, 0xbb, 0xff, 0xb9, 0x38, 0x3f, 0xfe, 0x8d, 0x0d, 0xcc,
		0xe3, 0x19, 0x62, 0x4d, 0x56, 0xda, 0xc0, 0x8f, 0xe7, 0x67, 0x88, 0xa0, 0xa4, 0x3d, 0xd9, 0x67,
		0x0f, 0x57, 0xd4, 0x83, 0xf8, 0x34, 0x12, 0xf8, 0xce, 0xd2, 0x1e, 0xab, 0xae, 0x70, 0x59, 0xb4,
		0xb8, 0x47, 0x21, 0xba, 0xef, 0x46, 0x49, 0xf8, 0xb9, 0x1d, 0x35, 0xf5, 0xa3, 0xc0, 0xe3, 0x85,
		0xb4, 0xfa, 0x71, 0xda, 0xf4, 0xb8, 0x20, 0xce, 0xbc, 0xc4, 0x91, 0x13, 0x67, 0x5e, 0x79, 0x41,
		0xe2, 0xcc, 0xbe, 0x58, 0x71, 0xc3, 0x38, 0xb3, 0x7e, 0x0f, 0x0a, 0xe5, 0xde, 0x13, 0x14, 0xb7,
		0xc8, 0x9e, 0x96, 0xe3, 0xe2, 0x16, 0x8d, 0xd9, 0x04, 0x7e, 0xa6, 0xf0, 0x5e, 0xf5, 0xc2, 0x46,
		0xd4, 0x1a, 0xb4, 0x83, 0x5e, 0xd4, 0x4f, 0xc3, 0x5e, 0xaa, 0x97, 0xcc, 0x3b, 0xb3, 0x12, 0x69,
		0xbd, 0xa4, 0xf5, 0x3a, 0xf7, 0x3b, 0x48, 0xeb, 0xb5, 0x33, 0x1a, 0x6a, 0x69, 0xbd, 0x4a, 0x75,
		0x08, 0x33, 0xd7, 0x49, 0xa5, 0x1e, 0x41, 0x59, 0x81, 0x01, 0xb0, 0x00, 0x58, 0x00, 0x2c, 0x3f,
		0x01, 0x96, 0xfe, 0x28, 0x15, 0x65, 0x8e, 0xcb, 0x98, 0xeb, 0xb2, 0xe6, 0xbc, 0x8c, 0xb8, 0x2f,
		0x33, 0x15, 0x6d, 0xa9, 0xaa, 0xed, 0x55, 0xb6, 0xb5, 0xea, 0x76, 0xa6, 0xc2, 0x9d, 0xa9, 0x72,
		0x27, 0x2a, 0x5d, 0x57, 0xb5, 0x2b, 0xab, 0x78, 0x3b, 0x2e, 0xcd, 0x01, 0xa7, 0x66, 0xc4, 0xad,
		0xe9, 0x0b, 0x00, 0x4d, 0x89, 0x3c, 0xe4, 0xe0, 0x1e, 0xf2, 0x45, 0x0c, 0x0c, 0x65, 0x60, 0xe8,
		0x12, 0x2e, 0x14, 0x03, 0x43, 0x41, 0xb9, 0xa0, 0x5c, 0x50, 0x2e, 0x28, 0x17, 0x94, 0x0b, 0xca,
		0x05, 0xe5, 0x82, 0x72, 0x41, 0xb9, 0xa0, 0x5c, 0x50, 0xae, 0xef, 0x28, 0x97, 0x0e, 0xbc, 0x45,
		0x11, 0x21, 0xdf, 0x44, 0xc7, 0xaf, 0x46, 0xbc, 0x6f, 0xb2, 0xb7, 0x7b, 0x9f, 0xbd, 0xdc, 0x1a,
		0xe4, 0x52, 0xc5, 0xdd, 0xaf, 0xb5, 0xa0, 0x1d, 0x7e, 0x8e, 0xda, 0x51, 0x33, 0x18, 0x24, 0x71,
		0x23, 0xec, 0x2b, 0xe6, 0x53, 0x3d, 0xba, 0x1a, 0x39, 0x55, 0xe4, 0x54, 0x39, 0xf7, 0xe0, 0xc9,
		0xa9, 0xb2, 0xb3, 0x71, 0x6a, 0x39, 0x55, 0x23, 0x09, 0x09, 0xda, 0xf1, 0x75, 0x9c, 0xea, 0x53,
		0xce, 0xf7, 0x56, 0x23, 0xbf, 0xca, 0x15, 0x9d, 0x01, 0xf3, 0x5c, 0x3c, 0xba, 0x02, 0xe6, 0xd9,
		0x5c, 0x39, 0x4e, 0x16, 0x50, 0x4e, 0x3c, 0x9d, 0xb9, 0x96, 0xaa, 0x09, 0xa8, 0x46, 0x8a, 0xd2,
		0x4c, 0x61, 0x5a, 0x2a, 0x4e, 0x7b, 0x05, 0x6a, 0xad, 0x48, 0x9d, 0x29, 0x54, 0x67, 0x8a, 0xd5,
		0x89, 0x82, 0xd5, 0xa7, 0x01, 0x37, 0x0d, 0x78, 0x60, 0x6d, 0xc5, 0x3b, 0x59, 0xe8, 0x3a, 0xfc,
		0x16, 0x8c, 0xa4, 0x70, 0xd8, 0xf8, 0xd4, 0xb8, 0xd9, 0xc0, 0xbd, 0xd5, 0x8d, 0x84, 0xd1, 0x76,
		0x58, 0xa0, 0x99, 0x92, 0x76, 0xa1, 0xac, 0xdd, 0x29, 0x6d, 0x57, 0xca, 0xdb, 0xb9, 0x12, 0x77,
		0xae, 0xcc, 0x9d, 0x2a, 0x75, 0x1b, 0xe5, 0x6e, 0xa4, 0xe4, 0x27, 0x3b, 0x69, 0x16, 0xf4, 0x9b,
		0xb9, 0xaf, 0x83, 0x38, 0x49, 0x77, 0xab, 0x96, 0xf7, 0x35, 0xd3, 0xbe, 0x07, 0x86, 0x4b, 0xda,
		0x8e, 0x6d, 0x1e, 0xff, 0xd8, 0xea, 0xa3, 0x4d, 0x57, 0x63, 0x9c, 0x1d, 0x99, 0xd5, 0x99, 0xe5,
		0x1d, 0x8d, 0x75, 0x9e, 0xac, 0xef, 0x70, 0x22, 0xaf, 0xb1, 0xba, 0xba, 0x2f, 0x72, 0x0e, 0xc6,
		0x3d, 0xfb, 0x26, 0x72, 0xb5, 0xea, 0x61, 0xed, 0x70, 0xff, 0xa0, 0x7a, 0xb8, 0xb7, 0xc6, 0xb2,
		0xb7, 0x51, 0xce, 0xd5, 0x2e, 0x4b, 0x32, 0xed, 0xda, 0x40, 0x37, 0xdc, 0xfa, 0xc1, 0x5f, 0xa3,
		0x24, 0x0d, 0xd2, 0x28, 0xec, 0x35, 0x3b, 0x7f, 0x25, 0xf6, 0x70, 0x72, 0xe6, 0x0d, 0x8c, 0x1c,
		0x38, 0xe3, 0x3c, 0x53, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94, 0x05, 0xca, 0x3a, 0xc9, 0x63,
		0x7d, 0xa8, 0x7e, 0x95, 0xf3, 0x59, 0xcb, 0xe5, 0x24, 0x64, 0xa9, 0x76, 0x41, 0x1a, 0x5f, 0x47,
		0x3d, 0x7b, 0x0f, 0xe1, 0xfe, 0xf2, 0x98, 0x69, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0x36,
		0xbb, 0xaf, 0xcd, 0xa8, 0x11, 0x5f, 0x87, 0xed, 0xfd, 0x9a, 0x0b, 0x43, 0x5d, 0x35, 0x5c, 0x73,
		0x86, 0x94, 0xa9, 0x42, 0x79, 0xcb, 0x7f, 0xa8, 0x0f, 0x94, 0x77, 0x15, 0xca, 0x1b, 0xca, 0xdb,
		0x56, 0xe4, 0x76, 0x11, 0x39, 0x98, 0x6e, 0xd9, 0x1f, 0x98, 0xee, 0xc5, 0xc5, 0xf0, 0xaf, 0xb0,
		0x97, 0xc4, 0xc9, 0x55, 0x90, 0x7e, 0xe9, 0x45, 0xfd, 0x2f, 0x9d, 0x76, 0x33, 0xe8, 0x36, 0x52,
		0x7b, 0x30, 0xfb, 0xf8, 0x6b, 0x00, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0xd6, 0xec,
		0xbe, 0x76, 0xa3, 0x5e, 0x23, 0x4a, 0xd2, 0xf0, 0x2a, 0x72, 0x80, 0x6a, 0xf7, 0xc0, 0x95, 0xe5,
		0xc4, 0x95, 0xa4, 0x52, 0x81, 0x2b, 0xd7, 0x4c, 0xe4, 0x76, 0xb6, 0x41, 0x96, 0x20, 0x4b, 0x5f,
		0x91, 0x65, 0xa1, 0x2b, 0x8a, 0x8c, 0xda, 0x01, 0x4d, 0xd6, 0x73, 0xdc, 0xdb, 0xe5, 0xb1, 0xe6,
		0x1e, 0x5b, 0xd3, 0x45, 0xf2, 0xaa, 0xdd, 0x70, 0xf5, 0x45, 0x46, 0x51, 0x5c, 0x94, 0xbb, 0xe4,
		0xce, 0x78, 0xcf, 0x9a, 0xdd, 0x72, 0x1f, 0x1a, 0x38, 0xb3, 0x92, 0xdc, 0x2a, 0x25, 0xb9, 0xc5,
		0xa1, 0x23, 0x28, 0xc9, 0xa5, 0x24, 0xf7, 0x97, 0x3b, 0x46, 0x49, 0x6e, 0x49, 0xd0, 0x07, 0x5c,
		0x72, 0xa9, 0x94, 0xb7, 0x73, 0x25, 0xee, 0x5c, 0x99, 0x3b, 0x55, 0xea, 0xb6, 0x78, 0x92, 0x92,
		0x5c, 0x35, 0xed, 0x4b, 0x49, 0xae, 0xc2, 0x87, 0xc2, 0x23, 0xc3, 0x23, 0x5b, 0x8b, 0x1c, 0x3c,
		0x32, 0x25, 0xb9, 0xd0, 0xc9, 0xde, 0x7f, 0x0f, 0x25, 0xb9, 0xaa, 0x68, 0x9d, 0x92, 0x5c, 0xa0,
		0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94, 0xa5, 0x24, 0x17, 0x27, 0xe1, 0x67, 0x7b, 0x46, 0x49, 0x2e,
		0x66, 0x1a, 0x33, 0x8d, 0x99, 0xc6, 0x4c, 0xaf, 0xa7, 0x99, 0xa6, 0x24, 0xd7, 0x62, 0x71, 0x28,
		0x6f, 0x43, 0xb1, 0xa2, 0x24, 0x17, 0xca, 0xdb, 0x58, 0xe4, 0x28, 0xc9, 0x85, 0xe9, 0x16, 0xfe,
		0x81, 0xe9, 0x5e, 0x5c, 0x0c, 0x29, 0xc9, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x40,
		0x2d, 0x25, 0xb9, 0xe0, 0xca, 0x42, 0x9b, 0x56, 0x9c, 0x7c, 0x70, 0x25, 0x25, 0xb9, 0x20, 0x4b,
		0x90, 0xa5, 0xd3, 0x15, 0x28, 0xc9, 0x35, 0x2e, 0xc9, 0x1d, 0x55, 0x82, 0x16, 0xb5, 0x22, 0xb7,
		0x50, 0x93, 0x7d, 0x8d, 0x64, 0xcf, 0x7b, 0x99, 0xab, 0xa8, 0xd6, 0x51, 0xf7, 0x06, 0x8d, 0x34,
		0xc9, 0x10, 0xc9, 0xd9, 0xe8, 0x63, 0x4e, 0xb2, 0x6f, 0xa9, 0x9f, 0x67, 0x5f, 0x50, 0x7f, 0x75,
		0xd5, 0xad, 0xbf, 0x19, 0x7e, 0x41, 0xfd, 0xa8, 0x15, 0x5f, 0x84, 0xad, 0xb8, 0x7e, 0xd2, 0xfd,
		0x5a, 0x3b, 0x1d, 0xbd, 0xf5, 0x1f, 0xa3, 0x97, 0xae, 0x8f, 0xc8, 0x8f, 0xd3, 0xe1, 0x3b, 0x6f,
		0x14, 0x43, 0x7e, 0xfd, 0x1e, 0xfc, 0xaf, 0x7c, 0x03, 0x7c, 0x94, 0x7c, 0x05, 0x61, 0x17, 0x15,
		0x72, 0x59, 0xc1, 0x96, 0x13, 0x3f, 0x41, 0xd1, 0xab, 0x0c, 0xcf, 0x65, 0x7c, 0x1e, 0xd2, 0x82,
		0x37, 0xa1, 0x3f, 0xee, 0xad, 0x22, 0x7c, 0x71, 0x74, 0x5a, 0x29, 0xa8, 0xd1, 0xc9, 0x9a, 0xb4,
		0xb1, 0x3e, 0x3d, 0xac, 0x4d, 0x03, 0x9b, 0xd1, 0xbd, 0x66, 0xb4, 0xae, 0x09, 0x7d, 0xeb, 0xb7,
		0x69, 0xd3, 0x6a, 0x55, 0x50, 0x69, 0x8c, 0xef, 0xa8, 0x92, 0x30, 0x8e, 0xaf, 0x53, 0xb6, 0x8e,
		0x92, 0x80, 0xe8, 0xf6, 0x82, 0x51, 0x8f, 0x8b, 0x59, 0xc4, 0xc1, 0xec, 0xe2, 0x5e, 0x56, 0x71,
		0x2e, 0xf3, 0xb8, 0x96, 0x79, 0x1c, 0xcb, 0x34, 0x6e, 0x55, 0x2c, 0xb4, 0xab, 0xdd, 0xbb, 0xa5,
		0xd2, 0x8f, 0x92, 0x66, 0xd0, 0x1c, 0xd5, 0x9c, 0x05, 0xbd, 0xce, 0xc0, 0xb4, 0x7f, 0xd6, 0xec,
		0xda, 0xda, 0xad, 0x70, 0x6c, 0x8b, 0xeb, 0x8c, 0xa8, 0x70, 0xb3, 0x84, 0x06, 0x9a, 0x77, 0x15,
		0x5a, 0xb1, 0x3b, 0x53, 0xf0, 0x4e, 0x14, 0xbd, 0xae, 0xc2, 0x57, 0x56, 0xfc, 0x93, 0x1d, 0x33,
		0x4b, 0x44, 0x70, 0x50, 0xfc, 0x66, 0x54, 0xf4, 0x06, 0x73, 0x9e, 0x5d, 0xbe, 0x35, 0x62, 0xce,
		0xc7, 0x8c, 0xb9, 0x66, 0xaf, 0x54, 0x05, 0xde, 0x59, 0x81, 0x86, 0xb9, 0x17, 0x33, 0x50, 0xc7,
		0xbf, 0x06, 0x11, 0x0a, 0x50, 0x30, 0x28, 0x18, 0x14, 0x0c, 0x0a, 0x96, 0x5c, 0x40, 0x99, 0x1e,
		0x9c, 0xb9, 0x96, 0xaa, 0x34, 0xa1, 0x91, 0xa2, 0x04, 0x7d, 0x82, 0x3e, 0x41, 0x9f, 0xe5, 0x46,
		0x9f, 0xb4, 0x8e, 0xd6, 0x56, 0xce, 0xd4, 0x3c, 0x15, 0x59, 0x69, 0xbb, 0x52, 0xde, 0xce, 0x95,
		0xb8, 0x73, 0x65, 0xee, 0x54, 0xa9, 0xdb, 0x28, 0x77, 0x23, 0x25, 0x3f, 0xd9, 0x49, 0x5a, 0x47,
		0xab, 0x2e, 0x49, 0xbd, 0x53, 0xf9, 0xcc, 0xea, 0xcc, 0xf2, 0xd4, 0x3b, 0x51, 0xef, 0xe4, 0x48,
		0xe4, 0x68, 0x1d, 0x4d, 0xd9, 0x93, 0xef, 0xdf, 0x43, 0xeb, 0x68, 0x55, 0xb4, 0x4e, 0xeb, 0x68,
		0xa0, 0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94, 0xa5, 0x75, 0x34, 0x4e, 0xc2, 0xcf, 0xf6, 0x8c, 0xd6,
		0xd1, 0x98, 0x69, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0xbd, 0x9e, 0x66, 0x9a, 0xd6, 0xd1, 0x16, 0x8b,
		0x43, 0x79, 0x1b, 0x8a, 0x15, 0xad, 0xa3, 0xa1, 0xbc, 0x8d, 0x45, 0x8e, 0xd6, 0xd1, 0x30, 0xdd,
		0xc2, 0x3f, 0x30, 0xdd, 0x8b, 0x8b, 0x21, 0xad, 0xa3, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0,
		0x16, 0x50, 0x4b, 0xeb, 0x68, 0x70, 0x65, 0xa1, 0x4d, 0x2b, 0x4e, 0x3e, 0xb8, 0x92, 0xd6, 0xd1,
		0x20, 0x4b, 0x90, 0xa5, 0xd3, 0x15, 0x68, 0x1d, 0xad, 0xd7, 0x8c, 0xe0, 0x5e, 0xcb, 0x68, 0xcd,
		0xce, 0x04, 0xfa, 0xa2, 0x72, 0xa3, 0xda, 0x7d, 0x38, 0x34, 0xed, 0x42, 0x35, 0x5c, 0xae, 0x64,
		0xa5, 0xb8, 0x55, 0x4a, 0x71, 0x8b, 0x43, 0x43, 0x50, 0x8a, 0x4b, 0x29, 0xee, 0x2f, 0x77, 0x8c,
		0x52, 0xdc, 0x92, 0xa0, 0x0e, 0x38, 0xe4, 0x52, 0x29, 0x6f, 0xe7, 0x4a, 0xdc, 0xb9, 0x32, 0x77,
		0xaa, 0xd4, 0x6d, 0x71, 0x24, 0xa5, 0xb8, 0x6a, 0xda, 0x97, 0x52, 0x5c, 0x85, 0x0f, 0x85, 0x3f,
		0x86, 0x3f, 0xb6, 0x16, 0x39, 0xf8, 0x63, 0x4a, 0x71, 0xa1, 0x91, 0xbd, 0xff, 0x1e, 0x4a, 0x71,
		0x55, 0xd1, 0x3a, 0xa5, 0xb8, 0x40, 0x59, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x4b, 0x29, 0x2e, 0x4e,
		0xc2, 0xcf, 0xf6, 0x8c, 0x52, 0x5c, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0x5e, 0x4f, 0x33,
		0x4d, 0x29, 0xae, 0xc5, 0xe2, 0x50, 0xde, 0x86, 0x62, 0x45, 0x29, 0x2e, 0x94, 0xb7, 0xb1, 0xc8,
		0x51, 0x8a, 0x0b, 0xd3, 0x2d, 0xfc, 0x03, 0xd3, 0xbd, 0xb8, 0x18, 0x52, 0x8a, 0x0b, 0xa8, 0x05,
		0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x4a, 0x71, 0xc1, 0x95, 0x85, 0x36, 0xad, 0x38, 0xf9,
		0xe0, 0x4a, 0x4a, 0x71, 0x41, 0x96, 0x20, 0x4b, 0xa7, 0x2b, 0x50, 0x8a, 0x6b, 0x54, 0x8a, 0x3b,
		0xaa, 0x00, 0x65, 0x06, 0xbd, 0xbe, 0xec, 0xad, 0xe5, 0x0c, 0x7a, 0x83, 0x99, 0xe8, 0xa3, 0x6f,
		0x4e, 0x7b, 0x83, 0x46, 0x9a, 0x64, 0x08, 0xe4, 0x6c, 0xf4, 0x11, 0x27, 0xd9, 0x37, 0xd4, 0xcf,
		0xb3, 0x37, 0xaf, 0xbf, 0xba, 0xea, 0xd6, 0xdf, 0x0c, 0xdf, 0xbc, 0x7e, 0xd4, 0x8a, 0x2f, 0xc2,
		0x56, 0x5c, 0x3f, 0xe9, 0x7e, 0xad, 0xfd, 0x31, 0x7a, 0xdb, 0xfa, 0x88, 0xe5, 0x38, 0x1d, 0xbe,
		0xec, 0x1a, 0x8f, 0xcd, 0xd7, 0x2d, 0x42, 0x37, 0x29, 0x3e, 0x37, 0x1b, 0x94, 0x5f, 0x65, 0x50,
		0xbe, 0x3f, 0x84, 0x1a, 0x83, 0xf2, 0xd7, 0xd8, 0xbc, 0xaa, 0x0f, 0xca, 0xef, 0x47, 0x49, 0x33,
		0x68, 0x8e, 0x92, 0xdb, 0x83, 0x5e, 0x67, 0x60, 0xda, 0xa8, 0x63, 0x76, 0x6d, 0xed, 0x9a, 0x7b,
		0xdb, 0x2c, 0x7e, 0x23, 0xcc, 0xcd, 0xc0, 0xfe, 0x42, 0x29, 0x74, 0x67, 0x8a, 0xdd, 0x99, 0x82,
		0x77, 0xa2, 0xe8, 0xcb, 0x81, 0xe9, 0xcd, 0x22, 0x1e, 0x0e, 0xb2, 0xec, 0x8d, 0xb2, 0xeb, 0x81,
		0xea, 0xeb, 0x0b, 0xd5, 0x15, 0x99, 0x20, 0x05, 0xd8, 0xbb, 0xe1, 0xb1, 0x18, 0x69, 0x8b, 0x8f,
		0x4f, 0x62, 0x53, 0x51, 0xe1, 0x1f, 0x04, 0xc8, 0x1c, 0x59, 0x49, 0x96, 0x93, 0x37, 0x41, 0x59,
		0xab, 0xc4, 0xdd, 0xaf, 0xfb, 0x41, 0x3b, 0xfc, 0x1c, 0xb5, 0xa3, 0xe6, 0xe4, 0x40, 0xa4, 0x25,
		0x6e, 0x62, 0xed, 0x1e, 0x5d, 0x4d, 0xf8, 0xe6, 0xe8, 0xd0, 0x36, 0x6a, 0x5e, 0xbf, 0xa6, 0x97,
		0xaf, 0xef, 0xd5, 0x6b, 0x7b, 0xf1, 0x66, 0x5e, 0xbb, 0x99, 0x97, 0x6e, 0xe2, 0x95, 0xfb, 0x6d,
		0xdb, 0xb4, 0x68, 0x96, 0xca, 0xbd, 0x50, 0x81, 0x3a, 0xf9, 0x6c, 0x10, 0x98, 0x30, 0xe3, 0xa0,
		0xb7, 0xe1, 0xa0, 0xfd, 0xa1, 0x2c, 0xe0, 0xa0, 0xd7, 0x18, 0x37, 0xaa, 0x73, 0xd0, 0x8d, 0xf1,
		0x9d, 0x37, 0xe2, 0x9d, 0xb3, 0xf5, 0x4a, 0xd6, 0x21, 0x1a, 0xee, 0xb7, 0x00, 0x8a, 0xd4, 0x99,
		0x42, 0x75, 0xa6, 0x58, 0x9d, 0x28, 0x58, 0x7d, 0xea, 0x6f, 0x93, 0x0e, 0xd1, 0x52, 0x97, 0x9c,
		0x0e, 0xd1, 0x85, 0x56, 0xd6, 0xee, 0x94, 0xb6, 0x2b, 0xe5, 0xed, 0x5c, 0x89, 0x3b, 0x57, 0xe6,
		0x4e, 0x95, 0xba, 0x8d, 0x72, 0x37, 0x52, 0xf2, 0x93, 0x9d, 0xa4, 0x43, 0xb4, 0xea, 0x92, 0x94,
		0x35, 0x95, 0xcf, 0xac, 0xce, 0x2c, 0x4f, 0x59, 0x13, 0x65, 0x4d, 0x8e, 0x44, 0x8e, 0x0e, 0xd1,
		0x54, 0x37, 0xf9, 0xfe, 0x3d, 0x74, 0x88, 0x56, 0x45, 0xeb, 0x74, 0x88, 0x06, 0xca, 0x02, 0x65,
		0x81, 0xb2, 0x40, 0x59, 0x3a, 0x44, 0xe3, 0x24, 0xfc, 0x6c, 0xcf, 0xe8, 0x10, 0x8d, 0x99, 0xc6,
		0x4c, 0x63, 0xa6, 0x31, 0xd3, 0xeb, 0x69, 0xa6, 0xe9, 0x10, 0x6d, 0xb1, 0x38, 0x94, 0xb7, 0xa1,
		0x58, 0xd1, 0x21, 0x1a, 0xca, 0xdb, 0x58, 0xe4, 0xe8, 0x10, 0x0d, 0xd3, 0x2d, 0xfc, 0x03, 0xd3,
		0xbd, 0xb8, 0x18, 0xd2, 0x21, 0x1a, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x74,
		0x88, 0x06, 0x57, 0x16, 0xda, 0xb4, 0xe2, 0xe4, 0x83, 0x2b, 0xe9, 0x10, 0x0d, 0xb2, 0x04, 0x59,
		0x3a, 0x5d, 0x81, 0x0e, 0xd1, 0xd2, 0x3d, 0x5d, 0x66, 0x9a, 0x7b, 0xdc, 0xef, 0x14, 0x9d, 0x95,
		0x82, 0x16, 0xb5, 0xff, 0x94, 0x6a, 0xf3, 0xe1, 0xd0, 0xb4, 0x17, 0xa4, 0x62, 0xdf, 0xdc, 0x87,
		0x06, 0xce, 0xac, 0x24, 0xb7, 0x4a, 0x49, 0x6e, 0x71, 0xe8, 0x08, 0x4a, 0x72, 0x29, 0xc9, 0xfd,
		0xe5, 0x8e, 0x51, 0x92, 0x5b, 0x12, 0xf4, 0x01, 0x97, 0x5c, 0x2a, 0xe5, 0xed, 0x5c, 0x89, 0x3b,
		0x57, 0xe6, 0x4e, 0x95, 0xba, 0x2d, 0x9e, 0xa4, 0x24, 0x57, 0x4d, 0xfb, 0x52, 0x92, 0xab, 0xf0,
		0xa1, 0xf0, 0xc8, 0xf0, 0xc8, 0xd6, 0x22, 0x07, 0x8f, 0x4c, 0x49, 0x2e, 0x74, 0xb2, 0xf7, 0xdf,
		0x43, 0x49, 0xae, 0x2a, 0x5a, 0xa7, 0x24, 0x17, 0x28, 0x0b, 0x94, 0x05, 0xca, 0x02, 0x65, 0x29,
		0xc9, 0xc5, 0x49, 0xf8, 0xd9, 0x9e, 0x51, 0x92, 0x8b, 0x99, 0xc6, 0x4c, 0x63, 0xa6, 0x31, 0xd3,
		0xeb, 0x69, 0xa6, 0x29, 0xc9, 0xb5, 0x58, 0x1c, 0xca, 0xdb, 0x50, 0xac, 0x28, 0xc9, 0x85, 0xf2,
		0x36, 0x16, 0x39, 0x4a, 0x72, 0x61, 0xba, 0x85, 0x7f, 0x60, 0xba, 0x17, 0x17, 0x43, 0x4a, 0x72,
		0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x4b, 0x49, 0x2e, 0xb8, 0xb2, 0xd0, 0xa6,
		0x15, 0x27, 0x1f, 0x5c, 0x49, 0x49, 0x2e, 0xc8, 0x12, 0x64, 0xe9, 0x74, 0x05, 0x4a, 0x72, 0x8d,
		0x4b, 0x72, 0x47, 0x95, 0xa0, 0x45, 0xad, 0xc8, 0x2d, 0xd4, 0x64, 0x5f, 0x23, 0xd9, 0xf3, 0x5e,
		0xe6, 0x2a, 0xaa, 0x75, 0xd4, 0xbd, 0x41, 0x23, 0x4d, 0x32, 0x44, 0x72, 0x36, 0xfa, 0x98, 0x93,
		0xec, 0x5b, 0xea, 0xe7, 0xd9, 0x17, 0xd4, 0x5f, 0x5d, 0x75, 0xeb, 0x6f, 0x86, 0x5f, 0x50, 0x3f,
		0x6a, 0xc5, 0x17, 0x61, 0x2b, 0xae, 0x9f, 0x74, 0xbf, 0xee, 0x9f, 0x8e, 0xde, 0xfa, 0x8f, 0xd1,
		0x4b, 0xd7, 0x47, 0xe4, 0xc7, 0xe9, 0xf0, 0x9d, 0x37, 0x8a, 0x21, 0xbf, 0x7e, 0x0f, 0xfe, 0x57,
		0xbe, 0x01, 0x3e, 0x4a, 0xbe, 0x82, 0xb0, 0x8b, 0x0a, 0xb9, 0xac, 0x60, 0xcb, 0x89, 0x9f, 0xa0,
		0xe8, 0x55, 0x86, 0xe7, 0x32, 0x3e, 0x0f, 0x69, 0xc1, 0x9b, 0xd0, 0x1f, 0xf7, 0x56, 0x11, 0xbe,
		0x38, 0x3a, 0xad, 0x14, 0xd4, 0xe8, 0x64, 0x4d, 0xda, 0x58, 0x9f, 0x1e, 0xd6, 0xa6, 0x81, 0xcd,
		0xe8, 0x5e, 0x33, 0x5a, 0xd7, 0x84, 0xbe, 0xf5, 0xdb, 0xb4, 0x69, 0xb5, 0x2a, 0xa8, 0x34, 0xc6,
		0x77, 0x54, 0x49, 0x18, 0xc7, 0xd7, 0x29, 0x5b, 0x47, 0x49, 0x40, 0x74, 0x7b, 0xc1, 0xa8, 0xc7,
		0xc5, 0x2c, 0xe2, 0x60, 0x76, 0x71, 0x2f, 0xab, 0x38, 0x97, 0x79, 0x5c, 0xcb, 0x3c, 0x8e, 0x65,
		0x1a, 0xb7, 0x2a, 0x16, 0xda, 0xd5, 0xee, 0xdd, 0x52, 0xe9, 0x47, 0x49, 0x33, 0x68, 0x8e, 0x6a,
		0xce, 0x82, 0x5e, 0x67, 0x60, 0xda, 0x3f, 0x6b, 0x76, 0x6d, 0xed, 0x56, 0x38, 0xb6, 0xc5, 0x75,
		0x46, 0x54, 0xb8, 0x59, 0x42, 0x03, 0xcd, 0xbb, 0x0a, 0xad, 0xd8, 0x9d, 0x29, 0x78, 0x27, 0x8a,
		0x5e, 0x57, 0xe1, 0x2b, 0x2b, 0xfe, 0xc9, 0x8e, 0x99, 0x25, 0x22, 0x38, 0x28, 0x7e, 0x33, 0x2a,
		0x7a, 0x83, 0x39, 0xcf, 0x2e, 0xdf, 0x1a, 0x31, 0xe7, 0x63, 0xc6, 0x5c, 0xb3, 0x57, 0xaa, 0x02,
		0xef, 0xac, 0x40, 0xc3, 0xdc, 0x8b, 0x19, 0xa8, 0xe3, 0x5f, 0x83, 0x08, 0x05, 0x28, 0x18, 0x14,
		0x0c, 0x0a, 0x06, 0x05, 0x4b, 0x2e, 0xa0, 0x4c, 0x0f, 0xce, 0x5c, 0x4b, 0x55, 0x9a, 0xd0, 0x48,
		0x51, 0x82, 0x3e, 0x41, 0x9f, 0xa0, 0xcf, 0x72, 0xa3, 0x4f, 0x5a, 0x47, 0x6b, 0x2b, 0x67, 0x6a,
		0x9e, 0x8a, 0xac, 0xb4, 0x5d, 0x29, 0x6f, 0xe7, 0x4a, 0xdc, 0xb9, 0x32, 0x77, 0xaa, 0xd4, 0x6d,
		0x94, 0xbb, 0x91, 0x92, 0x9f, 0xec, 0x24, 0xad, 0xa3, 0x55, 0x97, 0xa4, 0xde, 0xa9, 0x7c, 0x66,
		0x75, 0x66, 0x79, 0xea, 0x9d, 0xa8, 0x77, 0x72, 0x24, 0x72, 0xb4, 0x8e, 0xa6, 0xec, 0xc9, 0xf7,
		0xef, 0xa1, 0x75, 0xb4, 0x2a, 0x5a, 0xa7, 0x75, 0x34, 0x50, 0x16, 0x28, 0x0b, 0x94, 0x05, 0xca,
		0xd2, 0x3a, 0x1a, 0x27, 0xe1, 0x67, 0x7b, 0x46, 0xeb, 0x68, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0x8d,
		0x99, 0x5e, 0x4f, 0x33, 0x4d, 0xeb, 0x68, 0x8b, 0xc5, 0xa1, 0xbc, 0x0d, 0xc5, 0x8a, 0xd6, 0xd1,
		0x50, 0xde, 0xc6, 0x22, 0x47, 0xeb, 0x68, 0x98, 0x6e, 0xe1, 0x1f, 0x98, 0xee, 0xc5, 0xc5, 0x90,
		0xd6, 0xd1, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0xa5, 0x75, 0x34, 0xb8, 0xb2,
		0xd0, 0xa6, 0x15, 0x27, 0x1f, 0x5c, 0x49, 0xeb, 0x68, 0x90, 0x25, 0xc8, 0xd2, 0xe9, 0x0a, 0xb4,
		0x8e, 0xd6, 0x6b, 0x46, 0x70, 0xaf, 0x65, 0xb4, 0x66, 0x67, 0x02, 0x7d, 0x51, 0xb9, 0x51, 0xed,
		0x3e, 0x1c, 0x9a, 0x76, 0xa1, 0x1a, 0x2e, 0x57, 0xb2, 0x52, 0xdc, 0x2a, 0xa5, 0xb8, 0xc5, 0xa1,
		0x21, 0x28, 0xc5, 0xa5, 0x14, 0xf7, 0x97, 0x3b, 0x46, 0x29, 0x6e, 0x49, 0x50, 0x07, 0x1c, 0x72,
		0xa9, 0x94, 0xb7, 0x73, 0x25, 0xee, 0x5c, 0x99, 0x3b, 0x55, 0xea, 0xb6, 0x38, 0x92, 0x52, 0x5c,
		0x35, 0xed, 0x4b, 0x29, 0xae, 0xc2, 0x87, 0xc2, 0x1f, 0xc3, 0x1f, 0x5b, 0x8b, 0x1c, 0xfc, 0x31,
		0xa5, 0xb8, 0xd0, 0xc8, 0xde, 0x7f, 0x0f, 0xa5, 0xb8, 0xaa, 0x68, 0x9d, 0x52, 0x5c, 0xa0, 0x2c,
		0x50, 0x16, 0x28, 0x0b, 0x94, 0xa5, 0x14, 0x17, 0x27, 0xe1, 0x67, 0x7b, 0x46, 0x29, 0x2e, 0x66,
		0x1a, 0x33, 0x8d, 0x99, 0xc6, 0x4c, 0xaf, 0xa7, 0x99, 0xa6, 0x14, 0xd7, 0x62, 0x71, 0x28, 0x6f,
		0x43, 0xb1, 0xa2, 0x14, 0x17, 0xca, 0xdb, 0x58, 0xe4, 0x28, 0xc5, 0x85, 0xe9, 0x16, 0xfe, 0x81,
		0xe9, 0x5e, 0x5c, 0x0c, 0x29, 0xc5, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d,
		0xa5, 0xb8, 0xe0, 0xca, 0x42, 0x9b, 0x56, 0x9c, 0x7c, 0x70, 0x25, 0xa5, 0xb8, 0x20, 0x4b, 0x90,
		0xa5, 0xd3, 0x15, 0x28, 0xc5, 0x35, 0x2a, 0xc5, 0x1d, 0x55, 0x80, 0x32, 0x83, 0x5e, 0x5f, 0xf6,
		0xd6, 0x72, 0x06, 0xbd, 0xc1, 0x4c, 0xf4, 0xd1, 0x37, 0xa7, 0xbd, 0x41, 0x23, 0x4d, 0x32, 0x04,
		0x72, 0x36, 0xfa, 0x88, 0x93, 0xec, 0x1b, 0xea, 0xe7, 0xd9, 0x9b, 0xd7, 0x5f, 0x5d, 0x75, 0xeb,
		0x6f, 0x86, 0x6f, 0x5e, 0x3f, 0x6a, 0xc5, 0x17, 0x61, 0x2b, 0xae, 0x9f, 0x74, 0xbf, 0xee, 0xff,
		0x31, 0x7a, 0xdb, 0xfa, 0x88, 0xe5, 0x38, 0x1d, 0xbe, 0xec, 0x1a, 0x8f, 0xcd, 0xd7, 0x2d, 0x42,
		0x37, 0x29, 0x3e, 0x37, 0x1b, 0x94, 0x5f, 0x65, 0x50, 0xbe, 0x3f, 0x84, 0x1a, 0x83, 0xf2, 0xd7,
		0xd8, 0xbc, 0xaa, 0x0f, 0xca, 0xef, 0x47, 0x49, 0x33, 0x68, 0x8e, 0x92, 0xdb, 0x83, 0x5e, 0x67,
		0x60, 0xda, 0xa8, 0x63, 0x76, 0x6d, 0xed, 0x9a, 0x7b, 0xdb, 0x2c, 0x7e, 0x23, 0xcc, 0xcd, 0xc0,
		0xfe, 0x42, 0x29, 0x74, 0x67, 0x8a, 0xdd, 0x99, 0x82, 0x77, 0xa2, 0xe8, 0xcb, 0x81, 0xe9, 0xcd,
		0x22, 0x1e, 0x0e, 0xb2, 0xec, 0x8d, 0xb2, 0xeb, 0x81, 0xea, 0xeb, 0x0b, 0xd5, 0x15, 0x99, 0x20,
		0x05, 0xd8, 0xbb, 0xe1, 0xb1, 0x18, 0x69, 0x8b, 0x8f, 0x4f, 0x62, 0x53, 0x51, 0xe1, 0x1f, 0x04,
		0xc8, 0x1c, 0x59, 0x49, 0x96, 0x93, 0x37, 0x41, 0x59, 0xab, 0xb4, 0xab, 0x5f, 0xbb, 0x49, 0x10,
		0x7d, 0xed, 0xca, 0xcb, 0xd9, 0xc4, 0xc6, 0x4d, 0xad, 0x21, 0x7c, 0x4b, 0x74, 0x28, 0x1a, 0x35,
		0x0f, 0x5f, 0xd3, 0xa3, 0xd7, 0xf7, 0xe0, 0xb5, 0x3d, 0x76, 0x33, 0x0f, 0xdd, 0xcc, 0x23, 0x37,
		0xf1, 0xc0, 0xfd, 0xb6, 0x63, 0x5a, 0x94, 0x4a, 0xe5, 0x5e, 0x58, 0x40, 0x9d, 0x68, 0x36, 0x08,
		0x42, 0x98, 0xf1, 0xcd, 0xdb, 0xf0, 0xcd, 0xfe, 0xd0, 0x13, 0xf0, 0xcd, 0x6b, 0x8c, 0x11, 0xd5,
		0xf9, 0xe6, 0xc6, 0xf8, 0xce, 0x1b, 0x71, 0xcc, 0xd9, 0x7a, 0x25, 0xeb, 0x06, 0x0d, 0xcf, 0x5b,
		0x00, 0x45, 0xea, 0x4c, 0xa1, 0x3a, 0x53, 0xac, 0x4e, 0x14, 0xac, 0x3e, 0xcd, 0xb7, 0x49, 0x37,
		0x68, 0xa9, 0x4b, 0x4e, 0x37, 0xe8, 0x42, 0x2b, 0x6b, 0x77, 0x4a, 0xdb, 0x95, 0xf2, 0x76, 0xae,
		0xc4, 0x9d, 0x2b, 0x73, 0xa7, 0x4a, 0xdd, 0x46, 0xb9, 0x1b, 0x29, 0xf9, 0xc9, 0x4e, 0xd2, 0x0d,
		0x5a, 0x75, 0x49, 0x4a, 0x98, 0xca, 0x67, 0x56, 0x67, 0x96, 0xa7, 0x84, 0x89, 0x12, 0x26, 0x47,
		0x22, 0x47, 0x37, 0x68, 0x2a, 0x99, 0x7c, 0xff, 0x1e, 0xba, 0x41, 0xab, 0xa2, 0x75, 0xba, 0x41,
		0x03, 0x65, 0x81, 0xb2, 0x40, 0x59, 0xa0, 0x2c, 0xdd, 0xa0, 0x71, 0x12, 0x7e, 0xb6, 0x67, 0x74,
		0x83, 0xc6, 0x4c, 0x63, 0xa6, 0x31, 0xd3, 0x98, 0xe9, 0xf5, 0x34, 0xd3, 0x74, 0x83, 0xb6, 0x58,
		0x1c, 0xca, 0xdb, 0x50, 0xac, 0xe8, 0x06, 0x0d, 0xe5, 0x6d, 0x2c, 0x72, 0x74, 0x83, 0x86, 0xe9,
		0x16, 0xfe, 0x81, 0xe9, 0x5e, 0x5c, 0x0c, 0xe9, 0x06, 0x0d, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01,
		0xb5, 0x80, 0x5a, 0xba, 0x41, 0x83, 0x2b, 0x0b, 0x6d, 0x5a, 0x71, 0xf2, 0xc1, 0x95, 0x74, 0x83,
		0x06, 0x59, 0x82, 0x2c, 0x9d, 0xae, 0x40, 0x37, 0x68, 0xd1, 0xfe, 0x2d, 0x77, 0x2d, 0x3d, 0xee,
		0xf7, 0x82, 0xce, 0x0a, 0x40, 0x8b, 0xda, 0x61, 0x4a, 0xb5, 0xbd, 0x70, 0x68, 0xda, 0xed, 0x51,
		0xb1, 0x33, 0xee, 0x43, 0xb3, 0x66, 0x56, 0x88, 0x5b, 0xa5, 0x10, 0xb7, 0x38, 0x24, 0x04, 0x85,
		0xb8, 0x14, 0xe2, 0xfe, 0x72, 0xc7, 0x28, 0xc4, 0x2d, 0x09, 0xe6, 0x80, 0x41, 0x2e, 0x95, 0xf2,
		0x76, 0xae, 0xc4, 0x9d, 0x2b, 0x73, 0xa7, 0x4a, 0xdd, 0x16, 0x45, 0x52, 0x88, 0xab, 0xa6, 0x7d,
		0x29, 0xc4, 0x55, 0xf8, 0x50, 0xd8, 0x63, 0xd8, 0x63, 0x6b, 0x91, 0x83, 0x3d, 0xa6, 0x10, 0x17,
		0x12, 0xd9, 0xfb, 0xef, 0xa1, 0x10, 0x57, 0x15, 0xad, 0x53, 0x88, 0x0b, 0x94, 0x05, 0xca, 0x02,
		0x65, 0x81, 0xb2, 0x14, 0xe2, 0xe2, 0x24, 0xfc, 0x6c, 0xcf, 0x28, 0xc4, 0xc5, 0x4c, 0x63, 0xa6,
		0x31, 0xd3, 0x98, 0xe9, 0xf5, 0x34, 0xd3, 0x14, 0xe2, 0x5a, 0x2c, 0x0e, 0xe5, 0x6d, 0x28, 0x56,
		0x14, 0xe2, 0x42, 0x79, 0x1b, 0x8b, 0x1c, 0x85, 0xb8, 0x30, 0xdd, 0xc2, 0x3f, 0x30, 0xdd, 0x8b,
		0x8b, 0x21, 0x85, 0xb8, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0xa5, 0x10, 0x17,
		0x5c, 0x59, 0x68, 0xd3, 0x8a, 0x93, 0x0f, 0xae, 0xa4, 0x10, 0x17, 0x64, 0x09, 0xb2, 0x74, 0xba,
		0x02, 0x85, 0xb8, 0x26, 0x85, 0xb8, 0xa3, 0xfa, 0xcf, 0xa2, 0xd6, 0xe1, 0x16, 0x6a, 0x8a, 0xaf,
		0x91, 0xc4, 0x79, 0x2a, 0x69, 0x15, 0xd5, 0x9a, 0xe9, 0xde, 0xa0, 0x91, 0x26, 0x19, 0xfa, 0x38,
		0x1b, 0x7d, 0xc2, 0x49, 0xf6, 0x05, 0xf5, 0xf3, 0xec, 0xbd, 0xeb, 0xaf, 0xae, 0xba, 0xf5, 0x37,
		0xc3, 0xf7, 0xae, 0x1f, 0xb5, 0xe2, 0x8b, 0xb0, 0x15, 0xd7, 0x4f, 0xab, 0x1f, 0xbb, 0xc9, 0xf1,
		0xd7, 0x6e, 0x52, 0x1f, 0xf1, 0x1b, 0xa7, 0xc3, 0x57, 0xdd, 0x28, 0x86, 0xb0, 0xfa, 0x3d, 0xd1,
		0x5f, 0x59, 0xdc, 0xfd, 0x11, 0x73, 0x05, 0xc9, 0x96, 0x90, 0x68, 0x59, 0x29, 0x96, 0x93, 0x35,
		0x41, 0x39, 0xab, 0x8c, 0x0e, 0xe1, 0x6b, 0xb7, 0x2d, 0x5f, 0xab, 0x3b, 0x21, 0x33, 0xa6, 0xd6,
		0x10, 0xbe, 0x21, 0x3a, 0x6d, 0x11, 0xd4, 0xa8, 0x61, 0x4d, 0x0a, 0x58, 0x9f, 0xea, 0xd5, 0xa6,
		0x74, 0xcd, 0xa8, 0x5b, 0x33, 0x8a, 0xd6, 0x84, 0x8a, 0xf5, 0xdb, 0x86, 0x69, 0xb5, 0x1d, 0xa8,
		0xdc, 0xf3, 0x8c, 0xd4, 0x44, 0x72, 0xaa, 0x0e, 0x44, 0xdb, 0x0f, 0x53, 0xee, 0xf1, 0xa2, 0x1e,
		0xef, 0xb2, 0x88, 0x6f, 0xd9, 0xc5, 0xb3, 0xac, 0xe2, 0x57, 0xe6, 0xf1, 0x2a, 0xf3, 0xf8, 0x94,
		0x69, 0x3c, 0xaa, 0x58, 0x78, 0x56, 0xbb, 0x27, 0x4b, 0xa5, 0x31, 0xbe, 0xf3, 0x46, 0xbd, 0xb0,
		0xb2, 0xf5, 0x4a, 0xd6, 0x0c, 0x6b, 0x9b, 0x66, 0x58, 0xfe, 0x2b, 0x52, 0x67, 0x0a, 0xd5, 0x99,
		0x62, 0x75, 0xa2, 0x60, 0xf5, 0x29, 0xc9, 0x4d, 0x9a, 0x61, 0x49, 0x5d, 0x72, 0x9a, 0x61, 0x15,
		0x5a, 0x59, 0xbb, 0x53, 0xda, 0xae, 0x94, 0xb7, 0x73, 0x25, 0xee, 0x5c, 0x99, 0x3b, 0x55, 0xea,
		0x36, 0xca, 0xdd, 0x48, 0xc9, 0x4f, 0x76, 0x92, 0x66, 0x58, 0xaa, 0x4b, 0x92, 0xc1, 0x55, 0x3e,
		0xb3, 0x3a, 0xb3, 0x3c, 0x19, 0x5c, 0x64, 0x70, 0x39, 0x12, 0x39, 0x9a, 0x61, 0x91, 0xc8, 0xe5,
		0xfb, 0xf7, 0xd0, 0x0c, 0x4b, 0x15, 0xad, 0xd3, 0x0c, 0x0b, 0x28, 0x0b, 0x94, 0x05, 0xca, 0x02,
		0x65, 0x69, 0x86, 0x85, 0x93, 0xf0, 0xb3, 0x3d, 0xa3, 0x19, 0x16, 0x66, 0x1a, 0x33, 0x8d, 0x99,
		0xc6, 0x4c, 0xaf, 0xa7, 0x99, 0xa6, 0x19, 0x96, 0xc5, 0xe2, 0x50, 0xde, 0x86, 0x62, 0x45, 0x33,
		0x2c, 0x28, 0x6f, 0x63, 0x91, 0xa3, 0x19, 0x16, 0x4c, 0xb7, 0xf0, 0x0f, 0x4c, 0xf7, 0xe2, 0x62,
		0x48, 0x33, 0x2c, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0xd2, 0x0c, 0x0b, 0x5c,
		0x59, 0x68, 0xd3, 0x8a, 0x93, 0x0f, 0xae, 0xa4, 0x19, 0x16, 0xc8, 0x12, 0x64, 0xe9, 0x74, 0x05,
		0x9a, 0x61, 0x29, 0xf4, 0x6e, 0xf9, 0xda, 0x1d, 0xfe, 0xc6, 0x54, 0x33, 0xac, 0xac, 0x00, 0xb4,
		0xa8, 0xdd, 0xb0, 0x54, 0x3b, 0x2c, 0x85, 0x69, 0x64, 0x57, 0x89, 0x3b, 0x5a, 0xae, 0x64, 0x85,
		0xb8, 0x55, 0x0a, 0x71, 0x8b, 0x43, 0x42, 0x50, 0x88, 0x4b, 0x21, 0xee, 0x2f, 0x77, 0x8c, 0x42,
		0xdc, 0x92, 0x60, 0x0e, 0x18, 0xe4, 0x52, 0x29, 0x6f, 0xe7, 0x4a, 0xdc, 0xb9, 0x32, 0x77, 0xaa,
		0xd4, 0x6d, 0x51, 0x24, 0x85, 0xb8, 0x6a, 0xda, 0x97, 0x42, 0x5c, 0x85, 0x0f, 0x85, 0x3d, 0x86,
		0x3d, 0xb6, 0x16, 0x39, 0xd8, 0x63, 0x0a, 0x71, 0x21, 0x91, 0xbd, 0xff, 0x1e, 0x0a, 0x71, 0x55,
		0xd1, 0x3a, 0x85, 0xb8, 0x40, 0x59, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x4b, 0x21, 0x2e, 0x4e, 0xc2,
		0xcf, 0xf6, 0x8c, 0x42, 0x5c, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0x5e, 0x4f, 0x33, 0x4d,
		0x21, 0xae, 0xc5, 0xe2, 0x50, 0xde, 0x86, 0x62, 0x45, 0x21, 0x2e, 0x94, 0xb7, 0xb1, 0xc8, 0x51,
		0x88, 0x0b, 0xd3, 0x2d, 0xfc, 0x03, 0xd3, 0xbd, 0xb8, 0x18, 0x52, 0x88, 0x0b, 0xa8, 0x05, 0xd4,
		0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x0a, 0x71, 0xc1, 0x95, 0x85, 0x36, 0xad, 0x38, 0xf9, 0xe0,
		0x4a, 0x0a, 0x71, 0x41, 0x96, 0x20, 0x4b, 0xa7, 0x2b, 0x50, 0x88, 0x6b, 0x52, 0x88, 0x3b, 0xaa,
		0xff, 0x2c, 0x6a, 0x1d, 0x6e, 0xa1, 0xa6, 0xf8, 0x1a, 0x49, 0x9c, 0xa7, 0x92, 0x56, 0x51, 0xad,
		0x99, 0xee, 0x0d, 0x1a, 0x69, 0x92, 0xa1, 0x8f, 0xb3, 0xd1, 0x27, 0x9c, 0x64, 0x5f, 0x50, 0x3f,
		0xcf, 0xde, 0xbb, 0xfe, 0xea, 0xaa, 0x5b, 0x7f, 0x33, 0x7c, 0xef, 0xfa, 0x51, 0x2b, 0xbe, 0x08,
		0x5b, 0x71, 0xfd, 0xb4, 0xfa, 0xb1, 0x9b, 0x7c, 0xec, 0xb6, 0xfb, 0xf5, 0x11, 0xbf, 0x71, 0x3a,
		0x7c, 0xd5, 0x8d, 0x62, 0x08, 0xab, 0xdf, 0x13, 0xfd, 0x95, 0xc5, 0xdd, 0x1f, 0x31, 0x57, 0x90,
		0x6c, 0x09, 0x89, 0x96, 0x95, 0x62, 0x39, 0x59, 0x13, 0x94, 0xb3, 0x4a, 0x7b, 0xf7, 0xf6, 0x10,
		0xe2, 0xee, 0xd7, 0x5a, 0x70, 0x3d, 0x68, 0xa7, 0x71, 0x23, 0xec, 0xcb, 0xf3, 0xce, 0x13, 0x5a,
		0xe3, 0xd1, 0xd5, 0x84, 0x6f, 0x8d, 0x4e, 0xab, 0x04, 0x35, 0xba, 0x58, 0x93, 0x16, 0xd6, 0xa7,
		0x7f, 0xb5, 0x69, 0x5e, 0x33, 0x3a, 0xd7, 0x8c, 0xb6, 0x35, 0xa1, 0x67, 0xfd, 0xb6, 0x6b, 0x5a,
		0xad, 0x08, 0x2a, 0xf7, 0xbc, 0x25, 0x35, 0x91, 0x9c, 0xaa, 0x0d, 0xd1, 0xf6, 0xcd, 0x94, 0xfb,
		0xbe, 0xa8, 0xc7, 0xc0, 0x2c, 0x62, 0x5e, 0x76, 0x31, 0x2e, 0xab, 0x98, 0x96, 0x79, 0x0c, 0xcb,
		0x3c, 0x66, 0x65, 0x1a, 0xa3, 0x2a, 0x16, 0xc6, 0xd5, 0xee, 0xd3, 0x52, 0x69, 0x8c, 0xef, 0xbc,
		0x51, 0x7f, 0xac, 0x6c, 0xbd, 0x92, 0x35, 0xc8, 0xda, 0xa6, 0x41, 0x96, 0xff, 0x8a, 0xd4, 0x99,
		0x42, 0x75, 0xa6, 0x58, 0x9d, 0x28, 0x58, 0x7d, 0x9a, 0x72, 0x93, 0x06, 0x59, 0x52, 0x97, 0x9c,
		0x06, 0x59, 0x85, 0x56, 0xd6, 0xee, 0x94, 0xb6, 0x2b, 0xe5, 0xed, 0x5c, 0x89, 0x3b, 0x57, 0xe6,
		0x4e, 0x95, 0xba, 0x8d, 0x72, 0x37, 0x52, 0xf2, 0x93, 0x9d, 0xa4, 0x41, 0x96, 0xea, 0x92, 0x64,
		0x75, 0x95, 0xcf, 0xac, 0xce, 0x2c, 0x4f, 0x56, 0x17, 0x59, 0x5d, 0x8e, 0x44, 0x8e, 0x06, 0x59,
		0x24, 0x77, 0xf9, 0xfe, 0x3d, 0x34, 0xc8, 0x52, 0x45, 0xeb, 0x34, 0xc8, 0x02, 0xca, 0x02, 0x65,
		0x81, 0xb2, 0x40, 0x59, 0x1a, 0x64, 0xe1, 0x24, 0xfc, 0x6c, 0xcf, 0x68, 0x90, 0x85, 0x99, 0xc6,
		0x4c, 0x63, 0xa6, 0x31, 0xd3, 0xeb, 0x69, 0xa6, 0x69, 0x90, 0x65, 0xb1, 0x38, 0x94, 0xb7, 0xa1,
		0x58, 0xd1, 0x20, 0x0b, 0xca, 0xdb, 0x58, 0xe4, 0x68, 0x90, 0x05, 0xd3, 0x2d, 0xfc, 0x03, 0xd3,
		0xbd, 0xb8, 0x18, 0xd2, 0x20, 0x0b, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x34,
		0xc8, 0x02, 0x57, 0x16, 0xda, 0xb4, 0xe2, 0xe4, 0x83, 0x2b, 0x69, 0x90, 0x05, 0xb2, 0x04, 0x59,
		0x3a, 0x5d, 0x81, 0x06, 0x59, 0xb2, 0xfd, 0x5c, 0x1e, 0x69, 0xee, 0x71, 0xbf, 0x55, 0x56, 0x56,
		0x0a, 0x5a, 0xd4, 0x5e, 0x59, 0xaa, 0xfd, 0x97, 0xc2, 0x34, 0xb2, 0xab, 0xc9, 0x1d, 0x2d, 0x57,
		0xb2, 0x92, 0xdc, 0x2a, 0x25, 0xb9, 0xc5, 0xa1, 0x23, 0x28, 0xc9, 0xa5, 0x24, 0xf7, 0x97, 0x3b,
		0x46, 0x49, 0x6e, 0x49, 0xd0, 0x07, 0x5c, 0x72, 0xa9, 0x94, 0xb7, 0x73, 0x25, 0xee, 0x5c, 0x99,
		0x3b, 0x55, 0xea, 0xb6, 0x78, 0x92, 0x92, 0x5c, 0x35, 0xed, 0x4b, 0x49, 0xae, 0xc2, 0x87, 0xc2,
		0x23, 0xc3, 0x23, 0x5b, 0x8b, 0x1c, 0x3c, 0x32, 0x25, 0xb9, 0xd0, 0xc9, 0xde, 0x7f, 0x0f, 0x25,
		0xb9, 0xaa, 0x68, 0x9d, 0x92, 0x5c, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94, 0xa5, 0x24, 0x17,
		0x27, 0xe1, 0x67, 0x7b, 0x46, 0x49, 0x2e, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0xc6, 0x4c, 0xaf, 0xa7,
		0x99, 0xa6, 0x24, 0xd7, 0x62, 0x71, 0x28, 0x6f, 0x43, 0xb1, 0xa2, 0x24, 0x17, 0xca, 0xdb, 0x58,
		0xe4, 0x28, 0xc9, 0x85, 0xe9, 0x16, 0xfe, 0x81, 0xe9, 0x5e, 0x5c, 0x0c, 0x29, 0xc9, 0x05, 0xd4,
		0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0x25, 0xb9, 0xe0, 0xca, 0x42, 0x9b, 0x56, 0x9c,
		0x7c, 0x70, 0x25, 0x25, 0xb9, 0x20, 0x4b, 0x90, 0xa5, 0xd3, 0x15, 0x28, 0xc9, 0x35, 0x2e, 0xc9,
		0x1d, 0x55, 0x82, 0x16, 0xb5, 0x22, 0xb7, 0x50, 0x93, 0x7d, 0x8d, 0x64, 0xcf, 0x7b, 0x99, 0xab,
		0xa8, 0xd6, 0x51, 0xf7, 0x06, 0x8d, 0x34, 0xc9, 0x10, 0xc9, 0xd9, 0xe8, 0x63, 0x4e, 0xb2, 0x6f,
		0xa9, 0x9f, 0x67, 0x5f, 0x50, 0x7f, 0x75, 0xd5, 0xad, 0xbf, 0x19, 0x7e, 0x41, 0xfd, 0xa8, 0x15,
		0x5f, 0x84, 0xad, 0xb8, 0x7e, 0xba, 0xfb, 0xb1, 0x9b, 0x9c, 0x74, 0xbf, 0xd6, 0xde, 0x8e, 0x5f,
		0xba, 0x3e, 0x22, 0x3f, 0x4e, 0x87, 0xef, 0xbc, 0x51, 0x0c, 0xf9, 0xf5, 0x7b, 0xf0, 0xbf, 0xf2,
		0x0d, 0xf0, 0x51, 0xf2, 0x15, 0x84, 0x5d, 0x54, 0xc8, 0x65, 0x05, 0x5b, 0x4e, 0xfc, 0x04, 0x45,
		0xaf, 0x32, 0x75, 0x2e, 0x83, 0x64, 0xf4, 0xd5, 0xd2, 0xe2, 0x37, 0x21, 0x41, 0x1e, 0x59, 0x4b,
		0xf8, 0x12, 0xe9, 0xb4, 0x55, 0x50, 0xa3, 0x96, 0x35, 0x29, 0x64, 0x7d, 0xaa, 0x58, 0x9b, 0x12,
		0x36, 0xa3, 0x7e, 0xcd, 0x28, 0x5e, 0x13, 0x2a, 0xd7, 0x6f, 0x33, 0xa7, 0xd5, 0xb6, 0xa0, 0x72,
		0xcf, 0x8b, 0x52, 0x13, 0xc9, 0xa9, 0x3a, 0x12, 0x6d, 0x9f, 0x4d, 0xb9, 0x47, 0x8c, 0x7a, 0xbc,
		0xcc, 0x22, 0x3e, 0x66, 0x17, 0x0f, 0xb3, 0x8a, 0x7f, 0x99, 0xc7, 0xbb, 0xcc, 0xe3, 0x5b, 0xa6,
		0xf1, 0xac, 0x62, 0xa1, 0x60, 0xed, 0x9e, 0x2e, 0x95, 0xc6, 0xf8, 0xce, 0x1b, 0xf5, 0xd2, 0xca,
		0xd6, 0x2b, 0x59, 0x33, 0xad, 0x6d, 0x9a, 0x69, 0xf9, 0xaf, 0x48, 0x9d, 0x29, 0x54, 0x67, 0x8a,
		0xd5, 0x89, 0x82, 0xd5, 0x27, 0x32, 0x37, 0x69, 0xa6, 0x25, 0x75, 0xc9, 0x69, 0xa6, 0x55, 0x68,
		0x65, 0xed, 0x4e, 0x69, 0xbb, 0x52, 0xde, 0xce, 0x95, 0xb8, 0x73, 0x65, 0xee, 0x54, 0xa9, 0xdb,
		0x28, 0x77, 0x23, 0x25, 0x3f, 0xd9, 0x49, 0x9a, 0x69, 0xa9, 0x2e, 0x49, 0x06, 0x58, 0xf9, 0xcc,
		0xea, 0xcc, 0xf2, 0x64, 0x80, 0x91, 0x01, 0xe6, 0x48, 0xe4, 0x68, 0xa6, 0x45, 0x22, 0x98, 0xef,
		0xdf, 0x43, 0x33, 0x2d, 0x55, 0xb4, 0x4e, 0x33, 0x2d, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94,
		0xa5, 0x99, 0x16, 0x4e, 0xc2, 0xcf, 0xf6, 0x8c, 0x66, 0x5a, 0x98, 0x69, 0xcc, 0x34, 0x66, 0x1a,
		0x33, 0xbd, 0x9e, 0x66, 0x9a, 0x66, 0x5a, 0x16, 0x8b, 0x43, 0x79, 0x1b, 0x8a, 0x15, 0xcd, 0xb4,
		0xa0, 0xbc, 0x8d, 0x45, 0x8e, 0x66, 0x5a, 0x30, 0xdd, 0xc2, 0x3f, 0x30, 0xdd, 0x8b, 0x8b, 0x21,
		0xcd, 0xb4, 0x00, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x4b, 0x33, 0x2d, 0x70, 0x65,
		0xa1, 0x4d, 0x2b, 0x4e, 0x3e, 0xb8, 0x92, 0x66, 0x5a, 0x20, 0x4b, 0x90, 0xa5, 0xd3, 0x15, 0x68,
		0xa6, 0xa5, 0xd5, 0xde, 0x25, 0x6b, 0xed, 0x71, 0xbf, 0x95, 0x56, 0x56, 0x08, 0x5a, 0xd4, 0x5e,
		0x5a, 0xaa, 0x5d, 0x99, 0xc2, 0x34, 0xb2, 0xab, 0xc8, 0x1d, 0x2d, 0x57, 0xb2, 0x82, 0xdc, 0x2a,
		0x05, 0xb9, 0xc5, 0x21, 0x23, 0x28, 0xc8, 0xa5, 0x20, 0xf7, 0x97, 0x3b, 0x46, 0x41, 0x6e, 0x49,
		0xb0, 0x07, 0x4c, 0x72, 0xa9, 0x94, 0xb7, 0x73, 0x25, 0xee, 0x5c, 0x99, 0x3b, 0x55, 0xea, 0xb6,
		0x68, 0x92, 0x82, 0x5c, 0x35, 0xed, 0x4b, 0x41, 0xae, 0xc2, 0x87, 0xc2, 0x22, 0xc3, 0x22, 0x5b,
		0x8b, 0x1c, 0x2c, 0x32, 0x05, 0xb9, 0x90, 0xc9, 0xde, 0x7f, 0x0f, 0x05, 0xb9, 0xaa, 0x68, 0x9d,
		0x82, 0x5c, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94, 0xa5, 0x20, 0x17, 0x27, 0xe1, 0x67, 0x7b,
		0x46, 0x41, 0x2e, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0xc6, 0x4c, 0xaf, 0xa7, 0x99, 0xa6, 0x20, 0xd7,
		0x62, 0x71, 0x28, 0x6f, 0x43, 0xb1, 0xa2, 0x20, 0x17, 0xca, 0xdb, 0x58, 0xe4, 0x28, 0xc8, 0x85,
		0xe9, 0x16, 0xfe, 0x81, 0xe9, 0x5e, 0x5c, 0x0c, 0x29, 0xc8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5,
		0x80, 0x5a, 0x40, 0x2d, 0x05, 0xb9, 0xe0, 0xca, 0x42, 0x9b, 0x56, 0x9c, 0x7c, 0x70, 0x25, 0x05,
		0xb9, 0x20, 0x4b, 0x90, 0xa5, 0xd3, 0x15, 0x28, 0xc8, 0x35, 0x2d, 0xc8, 0x1d, 0xd5, 0x81, 0x16,
		0xb5, 0x1e, 0xb7, 0x50, 0x53, 0x7d, 0x8d, 0x24, 0xcf, 0x73, 0x89, 0xab, 0xa8, 0xd6, 0x50, 0xf7,
		0x06, 0x8d, 0x34, 0xc9, 0xd0, 0xc8, 0xd9, 0xe8, 0x53, 0x4e, 0xb2, 0x2f, 0xa9, 0x9f, 0x67, 0xef,
		0x5f, 0x7f, 0x75, 0xd5, 0xad, 0xbf, 0x19, 0xbe, 0x7f, 0xfd, 0xa8, 0x15, 0x5f, 0x84, 0xad, 0xb8,
		0x7e, 0xba, 0xfb, 0xb1, 0x9b, 0x9c, 0x74, 0xbf, 0xd6, 0xfe, 0x18, 0xbd, 0x72, 0x7d, 0x44, 0x7b,
		0x9c, 0x0e, 0xdf, 0x78, 0xa3, 0x18, 0xb2, 0xeb, 0xf7, 0xc0, 0x7f, 0x65, 0xe9, 0xf7, 0x4f, 0xea,
		0x15, 0x04, 0x5d, 0x50, 0xc0, 0x65, 0x85, 0x5a, 0x4e, 0xf4, 0x04, 0xc5, 0xae, 0x32, 0x39, 0x93,
		0xfd, 0xe0, 0x7a, 0xd0, 0x4e, 0x47, 0xdf, 0x2d, 0x2d, 0x7c, 0x13, 0xf2, 0xe3, 0xd1, 0xd5, 0x84,
		0x2f, 0x91, 0x4e, 0x43, 0x05, 0x35, 0x52, 0x59, 0x93, 0x3c, 0xd6, 0x27, 0x89, 0xb5, 0xc9, 0x60,
		0x33, 0xd2, 0xd7, 0x8c, 0xdc, 0x35, 0x21, 0x71, 0xfd, 0x36, 0x73, 0x5a, 0x0d, 0x0b, 0x2a, 0xf7,
		0x7c, 0x28, 0x35, 0x91, 0x9c, 0xaa, 0x20, 0xd1, 0xf6, 0xd8, 0x94, 0xbb, 0xc3, 0xa8, 0x47, 0xca,
		0x2c, 0x22, 0x63, 0x76, 0x91, 0x30, 0xab, 0xc8, 0x97, 0x79, 0xa4, 0xcb, 0x3c, 0xb2, 0x65, 0x1a,
		0xc9, 0x2a, 0x16, 0x02, 0xd6, 0xee, 0xe6, 0x52, 0x69, 0x8c, 0xef, 0xbc, 0x51, 0x17, 0xad, 0x6c,
		0xbd, 0x92, 0xb5, 0xd1, 0xda, 0xa6, 0x8d, 0x96, 0xff, 0x8a, 0xd4, 0x99, 0x42, 0x75, 0xa6, 0x58,
		0x9d, 0x28, 0x58, 0x7d, 0x12, 0x73, 0x93, 0x36, 0x5a, 0x52, 0x97, 0x9c, 0x36, 0x5a, 0x85, 0x56,
		0xd6, 0xee, 0x94, 0xb6, 0x2b, 0xe5, 0xed, 0x5c, 0x89, 0x3b, 0x57, 0xe6, 0x4e, 0x95, 0xba, 0x8d,
		0x72, 0x37, 0x52, 0xf2, 0x93, 0x9d, 0xa4, 0x8d, 0x96, 0xea, 0x92, 0xe4, 0x7e, 0x95, 0xcf, 0xac,
		0xce, 0x2c, 0x4f, 0xee, 0x17, 0xb9, 0x5f, 0x8e, 0x44, 0x8e, 0x36, 0x5a, 0xa4, 0x80, 0xf9, 0xfe,
		0x3d, 0xb4, 0xd1, 0x52, 0x45, 0xeb, 0xb4, 0xd1, 0x02, 0xca, 0x02, 0x65, 0x81, 0xb2, 0x40, 0x59,
		0xda, 0x68, 0xe1, 0x24, 0xfc, 0x6c, 0xcf, 0x68, 0xa3, 0x85, 0x99, 0xc6, 0x4c, 0x63, 0xa6, 0x31,
		0xd3, 0xeb, 0x69, 0xa6, 0x69, 0xa3, 0x65, 0xb1, 0x38, 0x94, 0xb7, 0xa1, 0x58, 0xd1, 0x46, 0x0b,
		0xca, 0xdb, 0x58, 0xe4, 0x68, 0xa3, 0x05, 0xd3, 0x2d, 0xfc, 0x03, 0xd3, 0xbd, 0xb8, 0x18, 0xd2,
		0x46, 0x0b, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0xb4, 0xd1, 0x02, 0x57, 0x16,
		0xda, 0xb4, 0xe2, 0xe4, 0x83, 0x2b, 0x69, 0xa3, 0x05, 0xb2, 0x04, 0x59, 0x3a, 0x5d, 0x81, 0x36,
		0x5a, 0x3a, 0xed, 0x5d, 0xa6, 0x9a, 0x7b, 0xdc, 0x6f, 0xa4, 0x95, 0x95, 0x82, 0x16, 0xb5, 0x93,
		0x96, 0x6a, 0x57, 0xa6, 0x30, 0x8d, 0xec, 0x6a, 0x72, 0x47, 0xcb, 0x95, 0xac, 0x24, 0xb7, 0x4a,
		0x49, 0x6e, 0x71, 0xe8, 0x08, 0x4a, 0x72, 0x29, 0xc9, 0xfd, 0xe5, 0x8e, 0x51, 0x92, 0x5b, 0x12,
		0xf4, 0x01, 0x97, 0x5c, 0x2a, 0xe5, 0xed, 0x5c, 0x89, 0x3b, 0x57, 0xe6, 0x4e, 0x95, 0xba, 0x2d,
		0x9e, 0xa4, 0x24, 0x57, 0x4d, 0xfb, 0x52, 0x92, 0xab, 0xf0, 0xa1, 0xf0, 0xc8, 0xf0, 0xc8, 0xd6,
		0x22, 0x07, 0x8f, 0x4c, 0x49, 0x2e, 0x74, 0xb2, 0xf7, 0xdf, 0x43, 0x49, 0xae, 0x2a, 0x5a, 0xa7,
		0x24, 0x17, 0x28, 0x0b, 0x94, 0x05, 0xca, 0x02, 0x65, 0x29, 0xc9, 0xc5, 0x49, 0xf8, 0xd9, 0x9e,
		0x51, 0x92, 0x8b, 0x99, 0xc6, 0x4c, 0x63, 0xa6, 0x31, 0xd3, 0xeb, 0x69, 0xa6, 0x29, 0xc9, 0xb5,
		0x58, 0x1c, 0xca, 0xdb, 0x50, 0xac, 0x28, 0xc9, 0x85, 0xf2, 0x36, 0x16, 0x39, 0x4a, 0x72, 0x61,
		0xba, 0x85, 0x7f, 0x60, 0xba, 0x17, 0x17, 0x43, 0x4a, 0x72, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d,
		0xa0, 0x16, 0x50, 0x4b, 0x49, 0x2e, 0xb8, 0xb2, 0xd0, 0xa6, 0x15, 0x27, 0x1f, 0x5c, 0x49, 0x49,
		0x2e, 0xc8, 0x12, 0x64, 0xe9, 0x74, 0x05, 0x4a, 0x72, 0x8d, 0x4b, 0x72, 0x47, 0x95, 0xa0, 0x45,
		0xad, 0xc8, 0x2d, 0xd4, 0x64, 0x5f, 0x23, 0xd9, 0xf3, 0x5e, 0xe6, 0x2a, 0xaa, 0x75, 0xd4, 0xbd,
		0x41, 0x23, 0x4d, 0x32, 0x44, 0x72, 0x36, 0xfa, 0x98, 0x93, 0xec, 0x5b, 0xea, 0xe7, 0xd9, 0x17,
		0xd4, 0x5f, 0x5d, 0x75, 0xeb, 0x6f, 0x86, 0x5f, 0x50, 0x3f, 0x6a, 0xc5, 0x17, 0x61, 0x2b, 0xae,
		0x9f, 0xee, 0x7e, 0xec, 0x26, 0x27, 0xdd, 0xaf, 0xfb, 0x6f, 0xc7, 0x2f, 0x5d, 0x1f, 0x91, 0x1f,
		0xa7, 0xc3, 0x77, 0xde, 0x28, 0x86, 0xfc, 0xfa, 0x3d, 0xf8, 0x5f, 0xf9, 0x06, 0xf8, 0x28, 0xf9,
		0x0a, 0xc2, 0x2e, 0x2a, 0xe4, 0xb2, 0x82, 0x2d, 0x27, 0x7e, 0x82, 0xa2, 0x57, 0x99, 0x3a, 0x97,
		0x41, 0x32, 0xfa, 0x6a, 0x69, 0xf1, 0x9b, 0x90, 0x20, 0x8f, 0xac, 0x25, 0x7c, 0x89, 0x74, 0xda,
		0x2a, 0xa8, 0x51, 0xcb, 0x9a, 0x14, 0xb2, 0x3e, 0x55, 0xac, 0x4d, 0x09, 0x9b, 0x51, 0xbf, 0x66,
		0x14, 0xaf, 0x09, 0x95, 0xeb, 0xb7, 0x99, 0xd3, 0x6a, 0x5b, 0x50, 0xb9, 0xe7, 0x45, 0xa9, 0x89,
		0xe4, 0x54, 0x1d, 0x89, 0xb6, 0xcf, 0xa6, 0xdc, 0x23, 0x46, 0x3d, 0x5e, 0x66, 0x11, 0x1f, 0xb3,
		0x8b, 0x87, 0x59, 0xc5, 0xbf, 0xcc, 0xe3, 0x5d, 0xe6, 0xf1, 0x2d, 0xd3, 0x78, 0x56, 0xb1, 0x50,
		0xb0, 0x76, 0x4f, 0x97, 0x4a, 0x63, 0x7c, 0xe7, 0x8d, 0x7a, 0x69, 0x65, 0xeb, 0x95, 0xac, 0x99,
		0xd6, 0x36, 0xcd, 0xb4, 0xfc, 0x57, 0xa4, 0xce, 0x14, 0xaa, 0x33, 0xc5, 0xea, 0x44, 0xc1, 0xea,
		0x13, 0x99, 0x9b, 0x34, 0xd3, 0x92, 0xba, 0xe4, 0x34, 0xd3, 0x2a, 0xb4, 0xb2, 0x76, 0xa7, 0xb4,
		0x5d, 0x29, 0x6f, 0xe7, 0x4a, 0xdc, 0xb9, 0x32, 0x77, 0xaa, 0xd4, 0x6d, 0x94, 0xbb, 0x91, 0x92,
		0x9f, 0xec, 0x24, 0xcd, 0xb4, 0x54, 0x97, 0x24, 0x03, 0xac, 0x7c, 0x66, 0x75, 0x66, 0x79, 0x32,
		0xc0, 0xc8, 0x00, 0x73, 0x24, 0x72, 0x34, 0xd3, 0x22, 0x11, 0xcc, 0xf7, 0xef, 0xa1, 0x99, 0x96,
		0x2a, 0x5a, 0xa7, 0x99, 0x16, 0x50, 0x16, 0x28, 0x0b, 0x94, 0x05, 0xca, 0xd2, 0x4c, 0x0b, 0x27,
		0xe1, 0x67, 0x7b, 0x46, 0x33, 0x2d, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0x5e, 0x4f, 0x33,
		0x4d, 0x33, 0x2d, 0x8b, 0xc5, 0xa1, 0xbc, 0x0d, 0xc5, 0x8a, 0x66, 0x5a, 0x50, 0xde, 0xc6, 0x22,
		0x47, 0x33, 0x2d, 0x98, 0x6e, 0xe1, 0x1f, 0x98, 0xee, 0xc5, 0xc5, 0x90, 0x66, 0x5a, 0x80, 0x5a,
		0x40, 0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0xa5, 0x99, 0x16, 0xb8, 0xb2, 0xd0, 0xa6, 0x15, 0x27,
		0x1f, 0x5c, 0x49, 0x33, 0x2d, 0x90, 0x25, 0xc8, 0xd2, 0xe9, 0x0a, 0x34, 0xd3, 0xd2, 0x6a, 0xef,
		0x92, 0xb5, 0xf6, 0xb8, 0xdf, 0x4a, 0x2b, 0x2b, 0x04, 0x2d, 0x6a, 0x2f, 0x2d, 0xd5, 0xae, 0x4c,
		0x61, 0x1a, 0xd9, 0x55, 0xe4, 0x8e, 0x96, 0x2b, 0x59, 0x41, 0x6e, 0x95, 0x82, 0xdc, 0xe2, 0x90,
		0x11, 0x14, 0xe4, 0x52, 0x90, 0xfb, 0xcb, 0x1d, 0xa3, 0x20, 0xb7, 0x24, 0xd8, 0x03, 0x26, 0xb9,
		0x54, 0xca, 0xdb, 0xb9, 0x12, 0x77, 0xae, 0xcc, 0x9d, 0x2a, 0x75, 0x5b, 0x34, 0x49, 0x41, 0xae,
		0x9a, 0xf6, 0xa5, 0x20, 0x57, 0xe1, 0x43, 0x61, 0x91, 0x61, 0x91, 0xad, 0x45, 0x0e, 0x16, 0x99,
		0x82, 0x5c, 0xc8, 0x64, 0xef, 0xbf, 0x87, 0x82, 0x5c, 0x55, 0xb4, 0x4e, 0x41, 0x2e, 0x50, 0x16,
		0x28, 0x0b, 0x94, 0x05, 0xca, 0x52, 0x90, 0x8b, 0x93, 0xf0, 0xb3, 0x3d, 0xa3, 0x20, 0x17, 0x33,
		0x8d, 0x99, 0xc6, 0x4c, 0x63, 0xa6, 0xd7, 0xd3, 0x4c, 0x53, 0x90, 0x6b, 0xb1, 0x38, 0x94, 0xb7,
		0xa1, 0x58, 0x51, 0x90, 0x0b, 0xe5, 0x6d, 0x2c, 0x72, 0x14, 0xe4, 0xc2, 0x74, 0x0b, 0xff, 0xc0,
		0x74, 0x2f, 0x2e, 0x86, 0x14, 0xe4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x96,
		0x82, 0x5c, 0x70, 0x65, 0xa1, 0x4d, 0x2b, 0x4e, 0x3e, 0xb8, 0x92, 0x82, 0x5c, 0x90, 0x25, 0xc8,
		0xd2, 0xe9, 0x0a, 0x14, 0xe4, 0x9a, 0x16, 0xe4, 0x8e, 0xea, 0x40, 0x8b, 0x5a, 0x8f, 0x5b, 0xa8,
		0xa9, 0xbe, 0x46, 0x92, 0xe7, 0xb9, 0xc4, 0x55, 0x54, 0x6b, 0xa8, 0x7b, 0x83, 0x46, 0x9a, 0x64,
		0x68, 0xe4, 0x6c, 0xf4, 0x29, 0x27, 0xd9, 0x97, 0xd4, 0xcf, 0xb3, 0xf7, 0xaf, 0xbf, 0xba, 0xea,
		0xd6, 0xdf, 0x0c, 0xdf, 0xbf, 0x7e, 0xd4, 0x8a, 0x2f, 0xc2, 0x56, 0x5c, 0x3f, 0xdd, 0xfd, 0xd8,
		0x4d, 0x4e, 0xba, 0x5f, 0xf7, 0xff, 0x18, 0xbd, 0x72, 0x7d, 0x44, 0x7b, 0x9c, 0x0e, 0xdf, 0x78,
		0xa3, 0x18, 0xb2, 0xeb, 0xf7, 0xc0, 0x7f, 0x65, 0xe9, 0xf7, 0x4f, 0xea, 0x15, 0x04, 0x5d, 0x50,
		0xc0, 0x65, 0x85, 0x5a, 0x4e, 0xf4, 0x04, 0xc5, 0xae, 0xd2, 0xeb, 0x0c, 0xd2, 0x28, 0xe8, 0x47,
		0xed, 0x68, 0xe8, 0xd2, 0x06, 0x9d, 0xee, 0xed, 0xff, 0xc8, 0x97, 0xf7, 0xde, 0x65, 0x55, 0xcd,
		0x59, 0x50, 0xf8, 0x2a, 0xe9, 0xb4, 0x55, 0x50, 0xa3, 0x96, 0x35, 0x29, 0x64, 0x7d, 0xaa, 0x58,
		0x9b, 0x12, 0x36, 0xa3, 0x7e, 0xcd, 0x28, 0x5e, 0x13, 0x2a, 0xd7, 0x6f, 0x63, 0xa7, 0xd5, 0xb6,
		0xa0, 0xd2, 0x18, 0xdf, 0x51, 0x25, 0x61, 0x1c, 0x5f, 0xa7, 0x6c, 0x1d, 0x25, 0x01, 0xd1, 0xed,
		0x0b, 0xa3, 0x1e, 0x23, 0xb3, 0x88, 0x89, 0xd9, 0xc5, 0xc0, 0xac, 0x62, 0x5e, 0xe6, 0x31, 0x2e,
		0xf3, 0x98, 0x96, 0x69, 0x0c, 0xab, 0x58, 0xd8, 0x57, 0xbb, 0x8f, 0x4b, 0x25, 0x6c, 0x7e, 0x8d,
		0x7a, 0x69, 0xdc, 0x8f, 0x82, 0x38, 0x09, 0x1b, 0x69, 0xfc, 0x35, 0x0a, 0x86, 0xde, 0x58, 0xdf,
		0xae, 0xa5, 0xd6, 0xfc, 0x57, 0xd0, 0x6e, 0x92, 0x63, 0x5b, 0x76, 0x67, 0x44, 0x92, 0x9b, 0xa5,
		0x3a, 0xd0, 0xd6, 0xab, 0xd0, 0x6a, 0xde, 0x99, 0xba, 0x77, 0xa2, 0xf6, 0x75, 0xd5, 0xbf, 0xb2,
		0x19, 0x98, 0xec, 0x98, 0x59, 0x8a, 0x82, 0x83, 0xb2, 0x38, 0xa3, 0x72, 0xb8, 0x62, 0x76, 0xb9,
		0x0c, 0xdb, 0x7f, 0x85, 0xdf, 0xfb, 0x41, 0xa3, 0x73, 0xdd, 0x0d, 0x7b, 0x51, 0x70, 0x1d, 0x35,
		0x0d, 0xed, 0xf3, 0xec, 0xda, 0x18, 0x66, 0x0c, 0x33, 0x86, 0x19, 0xc3, 0x8c, 0x61, 0xc6, 0x30,
		0xaf, 0xb7, 0x61, 0x8e, 0x92, 0xf0, 0x73, 0x3b, 0x0a, 0xc2, 0xf8, 0xaa, 0x6b, 0x67, 0x91, 0xa7,
		0x17, 0xc5, 0x14, 0x63, 0x8a, 0x31, 0xc5, 0x98, 0x62, 0x4c, 0x31, 0xa6, 0x78, 0xcd, 0x4d, 0xf1,
		0xb7, 0x34, 0xea, 0x25, 0x61, 0x7b, 0x82, 0x54, 0x87, 0x2c, 0x72, 0x2f, 0x88, 0x0d, 0xb1, 0xf2,
		0x4f, 0xde, 0xc1, 0xce, 0x50, 0xdf, 0xaa, 0x27, 0xec, 0x34, 0x76, 0x1a, 0x3b, 0x8d, 0x9d, 0xc6,
		0x4e, 0x63, 0xa7, 0x3d, 0xb3, 0xd3, 0xf1, 0x55, 0xd2, 0xe9, 0x45, 0x41, 0xd8, 0x0f, 0xba, 0x61,
		0xfa, 0x25, 0x68, 0x47, 0xc9, 0xd5, 0x30, 0xf9, 0xd4, 0xc8, 0x44, 0x3f, 0xbe, 0x3c, 0x30, 0x1a,
		0xf3, 0x8c, 0x79, 0xc6, 0x3c, 0x63, 0x9e, 0x31, 0xcf, 0x98, 0xe7, 0x5e, 0x14, 0x24, 0xd1, 0xb7,
		0x34, 0xf8, 0xd2, 0xe9, 0x06, 0xf1, 0x55, 0x37, 0xb8, 0x8e, 0xd2, 0x5e, 0xdc, 0x30, 0xb7, 0xd1,
		0x8f, 0xbd, 0x03, 0x86, 0x1a, 0x43, 0x8d, 0xa1, 0xc6, 0x50, 0x63, 0xa8, 0x31, 0xd4, 0x05, 0x30,
		0xd4, 0x54, 0x5a, 0x3f, 0xb2, 0x8e, 0xe3, 0x9a, 0xd3, 0x39, 0xe5, 0x86, 0xaa, 0x43, 0xb6, 0x15,
		0xca, 0x96, 0x55, 0xea, 0x64, 0x35, 0x87, 0x69, 0x9b, 0x0c, 0xd1, 0x36, 0x2b, 0x92, 0xaa, 0x52,
		0x24, 0xe5, 0x8f, 0xc7, 0x44, 0x91, 0xd4, 0x1a, 0x9b, 0x2d, 0x8a, 0xa4, 0x00, 0xc4, 0x00, 0x62,
		0x00, 0x31, 0x80, 0x18, 0x40, 0x0c, 0x20, 0xf6, 0x1c, 0x10, 0x53, 0x24, 0x85, 0x61, 0xc6, 0x30,
		0x63, 0x98, 0x31, 0xcc, 0x18, 0x66, 0x0c, 0xf3, 0x7a, 0x18, 0x66, 0x8a, 0xa4, 0x30, 0xc5, 0x98,
		0x62, 0x4c, 0x31, 0xa6, 0x18, 0x53, 0x8c, 0x29, 0x76, 0x6b, 0x8a, 0x29, 0x92, 0xa2, 0x48, 0x0a,
		0x3b, 0x8d, 0x9d, 0xc6, 0x4e, 0x63, 0xa7, 0xb1, 0xd3, 0xde, 0xda, 0x69, 0x8a, 0xa4, 0x80, 0xd1,
		0x98, 0x67, 0xcc, 0x33, 0xe6, 0x19, 0xf3, 0x8c, 0x79, 0xf6, 0xd5, 0x3c, 0x53, 0x24, 0x85, 0xa1,
		0xc6, 0x50, 0x63, 0xa8, 0x31, 0xd4, 0x18, 0x6a, 0x0c, 0xb5, 0x5f, 0x4f, 0xa6, 0x48, 0x4a, 0xa5,
		0x48, 0x4a, 0x71, 0xf0, 0x29, 0xa3, 0x1d, 0xd7, 0x41, 0x82, 0xfc, 0x9a, 0xef, 0xf8, 0xfe, 0xf6,
		0x25, 0x2f, 0xc6, 0xef, 0xf8, 0x2e, 0x7b, 0xc5, 0x35, 0x18, 0xf2, 0xd8, 0xef, 0xa5, 0x51, 0xd0,
		0xed, 0xb4, 0xe3, 0xc6, 0xf7, 0x20, 0xee, 0x7e, 0xad, 0xe9, 0x4d, 0x77, 0x9c, 0x59, 0x89, 0xb1,
		0x8e, 0x8c, 0x75, 0x74, 0xee, 0xcd, 0x33, 0xd6, 0xd1, 0xce, 0xd0, 0xa9, 0x8d, 0x75, 0xbc, 0x37,
		0x20, 0x5b, 0xbd, 0x6c, 0xd9, 0x60, 0x1c, 0x37, 0x23, 0x1e, 0x7d, 0xa2, 0x34, 0xa8, 0x5e, 0x2e,
		0x24, 0x65, 0x41, 0xf5, 0xf2, 0xbd, 0x05, 0x94, 0x67, 0xdf, 0xce, 0x5c, 0x4b, 0xd5, 0x19, 0xb8,
		0x46, 0x8a, 0xd2, 0x4c, 0x61, 0x5a, 0x2a, 0x4e, 0x7b, 0x05, 0x6a, 0xad, 0x48, 0x9d, 0x29, 0x54,
		0x67, 0x8a, 0xd5, 0x89, 0x82, 0xd5, 0xa7, 0x04, 0x37, 0x0d, 0x38, 0x61, 0x6d, 0xc5, 0x3b, 0x59,
		0xe8, 0x3a, 0xfc, 0x16, 0x8c, 0xa4, 0xd0, 0xa0, 0x63, 0xc4, 0xcc, 0x25, 0xbf, 0xb7, 0xba, 0x91,
		0x30, 0xda, 0x04, 0xec, 0xcc, 0x95, 0xb4, 0x0b, 0x65, 0xed, 0x4e, 0x69, 0xbb, 0x52, 0xde, 0xce,
		0x95, 0xb8, 0x73, 0x65, 0xee, 0x54, 0xa9, 0xdb, 0x28, 0x77, 0x23, 0x25, 0x3f, 0xd9, 0x49, 0xb3,
		0x00, 0xe0, 0xcc, 0x7d, 0x1d, 0xc4, 0x49, 0xba, 0x5b, 0xb5, 0xbc, 0xaf, 0x99, 0xf6, 0x3d, 0x30,
		0x5c, 0xf2, 0x7d, 0x98, 0x5c, 0xdd, 0x7e, 0xed, 0x27, 0xd3, 0xfb, 0x61, 0xab, 0x8f, 0x86, 0x1f,
		0xfa, 0x36, 0x4e, 0xcc, 0x15, 0xa1, 0x23, 0xb3, 0x3a, 0xb3, 0xfc, 0xc7, 0xb0, 0x3d, 0x88, 0x1c,
		0xae, 0xff, 0xba, 0x17, 0x0e, 0xa3, 0x34, 0xbf, 0xc7, 0x57, 0x71, 0x7a, 0xeb, 0x49, 0x6d, 0x9b,
		0xbf, 0xc7, 0xcd, 0x33, 0x07, 0x22, 0x17, 0x7e, 0x5b, 0x7b, 0x91, 0xab, 0x55, 0x0f, 0x6b, 0x87,
		0xfb, 0x07, 0xd5, 0xc3, 0xbd, 0x35, 0x96, 0xbd, 0x8d, 0x72, 0xae, 0x76, 0xb9, 0x51, 0x8e, 0xef,
		0x31, 0xd0, 0x0d, 0xb7, 0x7e, 0xf0, 0xd7, 0x28, 0x49, 0x83, 0x34, 0x0a, 0x7b, 0xcd, 0xce, 0x5f,
		0x89, 0x3d, 0x9c, 0x9c, 0x79, 0x03, 0x23, 0x07, 0xce, 0x38, 0xe7, 0x14, 0x28, 0x0b, 0x94, 0x05,
		0xca, 0x02, 0x65, 0x81, 0xb2, 0x4e, 0x72, 0x5a, 0x1f, 0xaa, 0x5f, 0xe5, 0xdc, 0xd6, 0x72, 0x39,
		0x09, 0xbd, 0xa8, 0x9f, 0x86, 0xbd, 0x34, 0x48, 0xe3, 0xeb, 0xa8, 0x67, 0xef, 0x21, 0xdc, 0x5f,
		0x1e, 0x33, 0x8d, 0x99, 0xc6, 0x4c, 0x63, 0xa6, 0x31, 0xd3, 0x66, 0xf7, 0xb5, 0x19, 0x35, 0xe2,
		0xeb, 0xb0, 0xbd, 0x5f, 0x73, 0x61, 0xa8, 0xab, 0x86, 0x6b, 0xce, 0x90, 0x32, 0x55, 0x28, 0x6f,
		0xf9, 0x0f, 0xf5, 0x81, 0xf2, 0xae, 0x42, 0x79, 0x43, 0x79, 0xdb, 0x8a, 0xdc, 0x2e, 0x22, 0x07,
		0xd3, 0x2d, 0xfb, 0x03, 0xd3, 0xbd, 0xb8, 0x18, 0xfe, 0x15, 0xf6, 0x92, 0x38, 0xb9, 0x0a, 0xd2,
		0x2f, 0xbd, 0xa8, 0xff, 0xa5, 0xd3, 0x6e, 0x06, 0xdd, 0x46, 0x6a, 0x0f, 0x66, 0x1f, 0x7f, 0x0d,
		0x40, 0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0x9a, 0xdd, 0xd7, 0x6e, 0xd4, 0x6b, 0x44,
		0x49, 0x1a, 0x5e, 0x45, 0x0e, 0x50, 0xed, 0x1e, 0xb8, 0xb2, 0x9c, 0xb8, 0x92, 0x54, 0x2a, 0x70,
		0xe5, 0x9a, 0x89, 0xdc, 0xce, 0x36, 0xc8, 0x12, 0x64, 0xe9, 0x2b, 0xb2, 0x2c, 0x74, 0x45, 0x91,
		0x51, 0x6b, 0xa0, 0xc9, 0x7a, 0x8e, 0x1b, 0xbc, 0x3c, 0x6c, 0xec, 0xb1, 0x35, 0x5d, 0x20, 0xaf,
		0x3a, 0x4d, 0x5d, 0x5f, 0x5c, 0x34, 0x9b, 0x47, 0xea, 0x4e, 0x59, 0x9f, 0xf1, 0x9c, 0x35, 0xa7,
		0xad, 0x3f, 0x34, 0x6e, 0x66, 0xe5, 0xb8, 0x55, 0xca, 0x71, 0x8b, 0x43, 0x45, 0x50, 0x8e, 0x4b,
		0x39, 0xee, 0x2f, 0x77, 0x8c, 0x72, 0xdc, 0x92, 0x20, 0x0f, 0x78, 0xe4, 0x52, 0x29, 0x6f, 0xe7,
		0x4a, 0xdc, 0xb9, 0x32, 0x77, 0xaa, 0xd4, 0x6d, 0xb1, 0x24, 0xe5, 0xb8, 0x6a, 0xda, 0x97, 0x72,
		0x5c, 0x85, 0x0f, 0x85, 0x43, 0x86, 0x43, 0xb6, 0x16, 0x39, 0x38, 0x64, 0xca, 0x71, 0xa1, 0x92,
		0xbd, 0xff, 0x1e, 0xca, 0x71, 0x55, 0xd1, 0x3a, 0xe5, 0xb8, 0x40, 0x59, 0xa0, 0x2c, 0x50, 0x16,
		0x28, 0x4b, 0x39, 0x2e, 0x4e, 0xc2, 0xcf, 0xf6, 0x8c, 0x72, 0x5c, 0xcc, 0x34, 0x66, 0x1a, 0x33,
		0x8d, 0x99, 0x5e, 0x4f, 0x33, 0x4d, 0x39, 0xae, 0xc5, 0xe2, 0x50, 0xde, 0x86, 0x62, 0x45, 0x39,
		0x2e, 0x94, 0xb7, 0xb1, 0xc8, 0x51, 0x8e, 0x0b, 0xd3, 0x2d, 0xfc, 0x03, 0xd3, 0xbd, 0xb8, 0x18,
		0x52, 0x8e, 0x0b, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0xca, 0x71, 0xc1, 0x95,
		0x85, 0x36, 0xad, 0x38, 0xf9, 0xe0, 0x4a, 0xca, 0x71, 0x41, 0x96, 0x20, 0x4b, 0xa7, 0x2b, 0x50,
		0x8e, 0x6b, 0x58, 0x8e, 0x3b, 0xaa, 0x02, 0x2d, 0x6a, 0x35, 0x6e, 0xa1, 0x26, 0xfa, 0x1a, 0xc9,
		0x9d, 0xd7, 0xf2, 0x56, 0x51, 0xad, 0x9f, 0xee, 0x0d, 0x1a, 0x69, 0x92, 0x21, 0x91, 0xb3, 0xd1,
		0x87, 0x9c, 0x64, 0xdf, 0x51, 0x3f, 0xcf, 0xde, 0xbe, 0xfe, 0xea, 0xaa, 0x5b, 0x7f, 0x33, 0x7c,
		0xfb, 0xfa, 0x51, 0x2b, 0xbe, 0x08, 0x5b, 0x71, 0xfd, 0xa2, 0x97, 0x46, 0xe7, 0xc3, 0x37, 0x3e,
		0xe9, 0x7e, 0xad, 0xd5, 0x47, 0x84, 0xc7, 0xe9, 0xf0, 0x7d, 0x37, 0x8a, 0x21, 0xb7, 0x7e, 0x0f,
		0xfa, 0x57, 0x96, 0x7c, 0xdf, 0x24, 0x5e, 0x41, 0xc8, 0xc5, 0x84, 0x5b, 0x56, 0xa0, 0xe5, 0xc4,
		0x4e, 0x50, 0xe4, 0x2a, 0x0f, 0xce, 0x63, 0x5f, 0x5c, 0xe8, 0xee, 0x7a, 0x28, 0x3c, 0x5c, 0x49,
		0xf8, 0xe2, 0xe8, 0xb4, 0x4f, 0x50, 0xa3, 0x90, 0x35, 0xa9, 0x62, 0x7d, 0x4a, 0x58, 0x9b, 0xfa,
		0x35, 0xa3, 0x78, 0xcd, 0xa8, 0x5c, 0x13, 0xca, 0xd6, 0x6f, 0xd3, 0xa6, 0xd5, 0x9e, 0xa0, 0x72,
		0xcf, 0x6b, 0x52, 0x13, 0xc9, 0xa9, 0x7a, 0x11, 0x6d, 0x1f, 0x4d, 0xb9, 0x17, 0x8c, 0x7a, 0x5c,
		0xcc, 0x22, 0x0e, 0x66, 0x17, 0xf7, 0xb2, 0x8a, 0x73, 0x99, 0xc7, 0xb5, 0xcc, 0xe3, 0x58, 0xa6,
		0x71, 0xab, 0x62, 0x21, 0x5e, 0xed, 0xde, 0x2d, 0x95, 0xc6, 0xf8, 0xce, 0x1b, 0xf5, 0xcc, 0xca,
		0xd6, 0x2b, 0x59, 0xd3, 0xac, 0x6d, 0x9a, 0x66, 0xf9, 0xaf, 0x48, 0x9d, 0x29, 0x54, 0x67, 0x8a,
		0xd5, 0x89, 0x82, 0xd5, 0x27, 0x2d, 0x37, 0x69, 0x9a, 0x25, 0x75, 0xc9, 0x69, 0x9a, 0x55, 0x68,
		0x65, 0xed, 0x4e, 0x69, 0xbb, 0x52, 0xde, 0xce, 0x95, 0xb8, 0x73, 0x65, 0xee, 0x54, 0xa9, 0xdb,
		0x28, 0x77, 0x23, 0x25, 0x3f, 0xd9, 0x49, 0x9a, 0x66, 0xa9, 0x2e, 0x49, 0xa6, 0x57, 0xf9, 0xcc,
		0xea, 0xcc, 0xf2, 0x64, 0x7a, 0x91, 0xe9, 0xe5, 0x48, 0xe4, 0x68, 0x9a, 0x45, 0xc2, 0x97, 0xef,
		0xdf, 0x43, 0xd3, 0x2c, 0x55, 0xb4, 0x4e, 0xd3, 0x2c, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x0b, 0x94,
		0xa5, 0x69, 0x16, 0x4e, 0xc2, 0xcf, 0xf6, 0x8c, 0xa6, 0x59, 0x98, 0x69, 0xcc, 0x34, 0x66, 0x1a,
		0x33, 0xbd, 0x9e, 0x66, 0x9a, 0xa6, 0x59, 0x16, 0x8b, 0x43, 0x79, 0x1b, 0x8a, 0x15, 0x4d, 0xb3,
		0xa0, 0xbc, 0x8d, 0x45, 0x8e, 0xa6, 0x59, 0x30, 0xdd, 0xc2, 0x3f, 0x30, 0xdd, 0x8b, 0x8b, 0x21,
		0x4d, 0xb3, 0x00, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x4b, 0xd3, 0x2c, 0x70, 0x65,
		0xa1, 0x4d, 0x2b, 0x4e, 0x3e, 0xb8, 0x92, 0xa6, 0x59, 0x20, 0x4b, 0x90, 0xa5, 0xd3, 0x15, 0x68,
		0x9a, 0xa5, 0xd9, 0xd2, 0x65, 0xff, 0x7e, 0xd3, 0xac, 0xac, 0x0c, 0xb4, 0xa8, 0x5d, 0xb3, 0x54,
		0x7b, 0x30, 0x85, 0x69, 0x64, 0x57, 0x8f, 0x3b, 0x5a, 0xae, 0x64, 0xe5, 0xb8, 0x55, 0xca, 0x71,
		0x8b, 0x43, 0x45, 0x50, 0x8e, 0x4b, 0x39, 0xee, 0x2f, 0x77, 0x8c, 0x72, 0xdc, 0x92, 0x20, 0x0f,
		0x78, 0xe4, 0x52, 0x29, 0x6f, 0xe7, 0x4a, 0xdc, 0xb9, 0x32, 0x77, 0xaa, 0xd4, 0x6d, 0xb1, 0x24,
		0xe5, 0xb8, 0x6a, 0xda, 0x97, 0x72, 0x5c, 0x85, 0x0f, 0x85, 0x43, 0x86, 0x43, 0xb6, 0x16, 0x39,
		0x38, 0x64, 0xca, 0x71, 0xa1, 0x92, 0xbd, 0xff, 0x1e, 0xca, 0x71, 0x55, 0xd1, 0x3a, 0xe5, 0xb8,
		0x40, 0x59, 0xa0, 0x2c, 0x50, 0x16, 0x28, 0x4b, 0x39, 0x2e, 0x4e, 0xc2, 0xcf, 0xf6, 0x8c, 0x72,
		0x5c, 0xcc, 0x34, 0x66, 0x1a, 0x33, 0x8d, 0x99, 0x5e, 0x4f, 0x33, 0x4d, 0x39, 0xae, 0xc5, 0xe2,
		0x50, 0xde, 0x86, 0x62, 0x45, 0x39, 0x2e, 0x94, 0xb7, 0xb1, 0xc8, 0x51, 0x8e, 0x0b, 0xd3, 0x2d,
		0xfc, 0x03, 0xd3, 0xbd, 0xb8, 0x18, 0x52, 0x8e, 0x0b, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5,
		0x80, 0x5a, 0xca, 0x71, 0xc1, 0x95, 0x85, 0x36, 0xad, 0x38, 0xf9, 0xe0, 0x4a, 0xca, 0x71, 0x41,
		0x96, 0x20, 0x4b, 0xa7, 0x2b, 0x50, 0x8e, 0x6b, 0x58, 0x8e, 0x3b, 0xaa, 0x02, 0x2d, 0x6a, 0x35,
		0x6e, 0xa1, 0x26, 0xfa, 0x1a, 0xc9, 0x9d, 0xd7, 0xf2, 0x56, 0x51, 0xad, 0x9f, 0xee, 0x0d, 0x1a,
		0x69, 0x92, 0x21, 0x91, 0xb3, 0xd1, 0x87, 0x9c, 0x64, 0xdf, 0x51, 0x3f, 0xcf, 0xde, 0xbe, 0xfe,
		0xea, 0xaa, 0x5b, 0x7f, 0x33, 0x7c, 0xfb, 0xfa, 0x51, 0x2b, 0xbe, 0x08, 0x5b, 0x71, 0xfd, 0xa2,
		0x97, 0x46, 0xe7, 0xc3, 0x37, 0x3e, 0xe9, 0x7e, 0xdd, 0xaf, 0x8f, 0x08, 0x8f, 0xd3, 0xe1, 0xfb,
		0x6e, 0x14, 0x43, 0x6e, 0xfd, 0x1e, 0xf4, 0xaf, 0x2c, 0xf9, 0xbe, 0x49, 0xbc, 0x82, 0x90, 0x8b,
		0x09, 0xb7, 0xac, 0x40, 0xcb, 0x89, 0x9d, 0xa0, 0xc8, 0x29, 0x35, 0x52, 0x50, 0x6d, 0x9c, 0xa0,
		0xd4, 0x28, 0x41, 0xad, 0x31, 0x82, 0x26, 0x29, 0xac, 0x4f, 0xfe, 0x6a, 0x93, 0xbc, 0x66, 0x64,
		0xae, 0x19, 0x69, 0x6b, 0x42, 0xce, 0xfa, 0x6d, 0xc4, 0xb4, 0x1a, 0x11, 0x54, 0xc6, 0x76, 0x24,
		0xc8, 0xb4, 0xbb, 0x92, 0x4c, 0x8e, 0x6f, 0xd5, 0xfd, 0xe5, 0x94, 0xc4, 0x45, 0x97, 0x45, 0x51,
		0x8f, 0x81, 0x59, 0xc4, 0xbc, 0xec, 0x62, 0x5c, 0x56, 0x31, 0x2d, 0xf3, 0x18, 0x96, 0x79, 0xcc,
		0xca, 0x34, 0x46, 0x55, 0x2c, 0x74, 0xab, 0x1e, 0x73, 0x9a, 0xdc, 0x97, 0xb8, 0x19, 0x25, 0x69,
		0x9c, 0x7e, 0xef, 0x45, 0x2d, 0xcd, 0x4b, 0x33, 0xf6, 0xc8, 0x14, 0xa3, 0x4a, 0x95, 0x93, 0xec,
		0x53, 0x5e, 0x85, 0x7d, 0xc3, 0xce, 0x5f, 0x47, 0xaf, 0x4f, 0xea, 0x17, 0xb7, 0xff, 0xef, 0xc3,
		0x3f, 0xcf, 0x8f, 0xb5, 0xaf, 0xe8, 0x90, 0xd0, 0xee, 0x9b, 0x44, 0xca, 0x8c, 0x93, 0x4e, 0x4e,
		0x77, 0x3f, 0x9e, 0x9f, 0xd5, 0x4f, 0xce, 0x3f, 0xd6, 0xea, 0x7f, 0x9c, 0x9d, 0xfc, 0x76, 0x74,
		0xf1, 0xa1, 0x52, 0x86, 0x9c, 0x1e, 0xeb, 0x5d, 0x3c, 0x39, 0xfb, 0xc7, 0xc5, 0x87, 0xa3, 0x0f,
		0xc7, 0x6c, 0xde, 0xf2, 0x9b, 0x37, 0x14, 0xbe, 0xd3, 0xa3, 0x57, 0xc7, 0xa7, 0xc7, 0xbf, 0x23,
		0x84, 0x39, 0x84, 0xb0, 0x7a, 0x7b, 0x95, 0x3f, 0x9e, 0x9f, 0x5e, 0xb0, 0x7b, 0x39, 0xae, 0x70,
		0xfd, 0xe2, 0xfc, 0x35, 0x1b, 0x98, 0xc3, 0x92, 0xec, 0x73, 0x89, 0x73, 0x29, 0xc3, 0x7d, 0x94,
		0xa1, 0x94, 0x32, 0x3c, 0xfe, 0x78, 0x7e, 0xc6, 0xee, 0xad, 0x28, 0x85, 0x48, 0xdf, 0xca, 0xfb,
		0x77, 0xf1, 0xfe, 0xc3, 0x71, 0xfd, 0xfc, 0xdd, 0xe9, 0xc9, 0x6f, 0xff, 0x1c, 0xfa, 0xd6, 0xec,
		0x61, 0x2e, 0x64, 0xf2, 0xf6, 0x8f, 0xd3, 0x0f, 0xc8, 0x62, 0x1e, 0xf7, 0xfa, 0xf5, 0xe9, 0xbb,
		0xff, 0xb9, 0x38, 0x3f, 0xfe, 0x8d, 0x0d, 0xcc, 0xe3, 0x19, 0x62, 0x4d, 0x56, 0xda, 0xc0, 0x8f,
		0xe7, 0x67, 0x88, 0xa0, 0xa4, 0x3d, 0xd9, 0x67, 0x0f, 0x57, 0xd4, 0x83, 0xf8, 0x34, 0x12, 0xf8,
		0xce, 0xd2, 0x1e, 0xab, 0xae, 0x70, 0x59, 0xb4, 0xb8, 0xc7, 0x46, 0x01, 0xe4, 0xb4, 0x12, 0x25,
		0xe1, 0xe7, 0x76, 0xd4, 0xd4, 0x8f, 0x02, 0x8f, 0x17, 0x52, 0x8a, 0x06, 0x19, 0xf5, 0x01, 0x24,
		0xce, 0xbc, 0xc4, 0x91, 0x13, 0x67, 0x5e, 0x79, 0x41, 0xe2, 0xcc, 0xbe, 0x58, 0x71, 0xc3, 0x38,
		0xb3, 0x7e, 0x1f, 0x3d, 0xe5, 0xbe, 0x79, 0xc5, 0x30, 0x79, 0x69, 0x27, 0x0d, 0xdb, 0x41, 0x37,
		0x4c, 0xbf, 0xf4, 0xf5, 0xcd, 0xde, 0xf4, 0x62, 0x98, 0x24, 0x4c, 0x12, 0x26, 0x09, 0x93, 0x54,
		0x20, 0x93, 0xa4, 0x3e, 0xa5, 0xc4, 0x60, 0x2a, 0x89, 0x51, 0xe9, 0xbc, 0x41, 0x61, 0x9f, 0x65,
		0x69, 0xbc, 0x75, 0x97, 0x19, 0xe3, 0xd2, 0x77, 0x17, 0x55, 0xc7, 0x16, 0xfd, 0x91, 0x2c, 0x4b,
		0xd9, 0x5d, 0x89, 0x88, 0xf5, 0xd4, 0x0f, 0x27, 0xb2, 0x52, 0xd0, 0x0a, 0xd9, 0x4b, 0x80, 0x85,
		0xf6, 0x48, 0xc7, 0x87, 0xd8, 0x42, 0x77, 0x88, 0x23, 0xf0, 0x02, 0x78, 0x01, 0xbc, 0x00, 0x5e,
		0x00, 0x2f, 0x80, 0x17, 0xc0, 0x0b, 0xe0, 0x05, 0xf0, 0x02, 0x78, 0x01, 0xbc, 0xb0, 0x7d, 0x22,
		0xed, 0x51, 0x96, 0x6b, 0x8f, 0x22, 0xdf, 0x62, 0xca, 0xcf, 0xbe, 0x23, 0x83, 0x7e, 0x14, 0x5c,
		0x0f, 0xda, 0x69, 0xdc, 0x6d, 0x47, 0x4a, 0x01, 0xad, 0x3b, 0x57, 0x6d, 0x76, 0xad, 0x82, 0x75,
		0x24, 0xd9, 0xa6, 0x23, 0x89, 0x1d, 0x90, 0xa4, 0x23, 0x49, 0x09, 0xed, 0x86, 0x5a, 0x47, 0x92,
		0xc6, 0xf8, 0x8e, 0x2a, 0x33, 0x66, 0xd9, 0x3a, 0xba, 0x4c, 0xd9, 0x0e, 0x4c, 0x19, 0x4c, 0x19,
		0x4c, 0xd9, 0x3a, 0x30, 0x65, 0x5a, 0x0a, 0x71, 0xb2, 0x80, 0x76, 0x7a, 0xee, 0xcc, 0xbd, 0xd4,
		0x4d, 0xd3, 0xbd, 0xdb, 0x38, 0xdb, 0xb1, 0xdd, 0x46, 0x54, 0x82, 0xd9, 0xa8, 0x14, 0xcb, 0x11,
		0x29, 0xf6, 0xa3, 0x51, 0xac, 0x47, 0xa2, 0x38, 0x1b, 0x85, 0xe2, 0x6c, 0x04, 0x8a, 0x93, 0xd1,
		0x27, 0xc5, 0x6e, 0xe2, 0x6d, 0x36, 0xe2, 0xc4, 0xc1, 0x58, 0x6d, 0xa3, 0x71, 0xda, 0xf4, 0xe5,
		0x36, 0xa1, 0xdf, 0x7c, 0xa1, 0xe1, 0x66, 0x19, 0xa3, 0xad, 0x0c, 0x7f, 0xad, 0x73, 0xbd, 0xd5,
		0xad, 0xaa, 0xd5, 0x2f, 0xb6, 0xd2, 0x33, 0xd4, 0xa0, 0x5c, 0x50, 0x2e, 0x28, 0x17, 0x94, 0x2b,
		0xb9, 0x80, 0x32, 0xfd, 0x37, 0x73, 0x2d, 0x55, 0x69, 0x40, 0x23, 0x45, 0x09, 0xe6, 0x04, 0x73,
		0x82, 0x39, 0xcb, 0x8d, 0x39, 0xb5, 0x15, 0xef, 0x64, 0xa1, 0xb0, 0xdd, 0xee, 0xfc, 0x75, 0xe7,
		0xac, 0x87, 0x7d, 0xfb, 0x89, 0xca, 0xb3, 0xaf, 0x60, 0x24, 0x96, 0xc6, 0x54, 0xe4, 0x43, 0xf3,
		0xc0, 0x14, 0xe7, 0x22, 0x9b, 0x0d, 0x57, 0xe6, 0xc3, 0xb9, 0x19, 0x71, 0x6e, 0x4e, 0x9c, 0x9a,
		0x15, 0x1b, 0xf3, 0x62, 0x64, 0x66, 0x26, 0x3b, 0xe9, 0x6e, 0x8a, 0xb3, 0x1d, 0xd5, 0x39, 0xe3,
		0x9d, 0xef, 0x94, 0x65, 0x44, 0xa6, 0x81, 0x8f, 0x7c, 0x1d, 0x7e, 0x8b, 0xaf, 0x07, 0xd7, 0xca,
		0xbd, 0x13, 0xe6, 0x4a, 0xc9, 0xfd, 0xe5, 0xed, 0xdd, 0x83, 0x1d, 0x5c, 0x03, 0x5c, 0x03, 0x5c,
		0x03, 0x5c, 0x03, 0x5c, 0x03, 0xbb, 0xfb, 0xaa, 0x5e, 0x22, 0x36, 0x4f, 0xfb, 0x1e, 0x18, 0x2e,
		0x69, 0x53, 0x42, 0xf6, 0xf0, 0xe7, 0x6f, 0x07, 0x93, 0xf6, 0x0d, 0x4b, 0xcc, 0x1c, 0x9b, 0xd5,
		0x99, 0xe5, 0x8d, 0x4b, 0xd0, 0x66, 0xd6, 0xf7, 0x61, 0xce, 0xfe, 0x33, 0x07, 0x22, 0x17, 0x7e,
		0x5b, 0x7b, 0x91, 0xb3, 0x2e, 0x69, 0xf3, 0x52, 0xf6, 0x36, 0xca, 0xb9, 0xda, 0x65, 0x59, 0x00,
		0x6c, 0xa1, 0xa9, 0x7a, 0xa3, 0x9c, 0x9e, 0xc9, 0x7a, 0xfe, 0xe5, 0xf6, 0x44, 0xb7, 0xbf, 0xa1,
		0x99, 0xe0, 0xa3, 0x2f, 0x28, 0x8a, 0x42, 0xa2, 0x34, 0x23, 0x7c, 0xae, 0xdb, 0xac, 0x31, 0x33,
		0x7c, 0x9e, 0x75, 0x33, 0x8b, 0x70, 0x57, 0x89, 0x70, 0x17, 0x87, 0x87, 0x20, 0xc2, 0x4d, 0x84,
		0xfb, 0x97, 0x3b, 0x46, 0x84, 0xdb, 0xe0, 0x05, 0x88, 0x70, 0x17, 0xde, 0x5c, 0xb8, 0x33, 0x1b,
		0xae, 0xcc, 0x87, 0x73, 0x33, 0xe2, 0xdc, 0x9c, 0x38, 0x35, 0x2b, 0xb6, 0x38, 0x96, 0x08, 0xb7,
		0xa2, 0x77, 0x4e, 0x84, 0x7b, 0xf1, 0x3d, 0x23, 0xc2, 0x8d, 0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x80,
		0x6b, 0x80, 0x6b, 0x60, 0x75, 0x5f, 0x89, 0x70, 0xab, 0xfd, 0x10, 0xe1, 0x36, 0x5d, 0x9e, 0x08,
		0x37, 0x11, 0x6e, 0x47, 0x22, 0x47, 0x84, 0x9b, 0x08, 0xb7, 0xf7, 0x00, 0x96, 0x08, 0xf7, 0x12,
		0xeb, 0x79, 0x1a, 0xe1, 0x56, 0x68, 0x2e, 0x6b, 0x27, 0x27, 0xf4, 0x49, 0x29, 0x8e, 0xa4, 0x55,
		0x54, 0x93, 0x11, 0x7a, 0x83, 0x46, 0x9a, 0x64, 0x00, 0xe4, 0x6c, 0xf4, 0x09, 0x27, 0xd9, 0x17,
		0xd4, 0xcf, 0xb3, 0xf7, 0xae, 0xbf, 0xba, 0xea, 0xd6, 0xdf, 0x0c, 0xdf, 0xbb, 0x7e, 0xd4, 0x8a,
		0x2f, 0xc2, 0x56, 0x5c, 0xff, 0xa3, 0x1f, 0xbd, 0xcd, 0xde, 0xf5, 0xfc, 0xf6, 0x55, 0xeb, 0xc7,
		0x6a, 0x98, 0xb3, 0x18, 0x0d, 0x5d, 0x62, 0x93, 0x86, 0x2e, 0x31, 0x0d, 0x5d, 0x5c, 0x72, 0x6d,
		0x34, 0x74, 0x29, 0x1e, 0x57, 0x46, 0x43, 0x97, 0xb9, 0x3b, 0x43, 0x43, 0x17, 0x0f, 0x15, 0xa5,
		0x99, 0xc2, 0xb4, 0x54, 0x9c, 0xf6, 0x0a, 0xd4, 0x5a, 0x91, 0x3a, 0x53, 0xa8, 0xce, 0x14, 0xab,
		0x13, 0x05, 0x5b, 0x0e, 0x0c, 0x6d, 0x96, 0xee, 0x46, 0x1c, 0x9b, 0x38, 0x76, 0xc1, 0x4c, 0x84,
		0x3b, 0x53, 0xe1, 0xca, 0x64, 0x38, 0x37, 0x1d, 0xce, 0x4d, 0x88, 0x53, 0x53, 0x62, 0x63, 0x52,
		0x8c, 0x4c, 0xcb, 0x64, 0x27, 0x89, 0x63, 0xab, 0x2e, 0x49, 0x1c, 0xbb, 0x7c, 0x66, 0x75, 0x66,
		0x79, 0xe2, 0xd8, 0xc4, 0xb1, 0x1d, 0x89, 0x1c, 0x71, 0x6c, 0xe2, 0xd8, 0xbe, 0x7f, 0x0f, 0x71,
		0xec, 0x65, 0xd6, 0xf3, 0x2f, 0xba, 0x18, 0x53, 0xa9, 0xfd, 0xd3, 0x03, 0xa3, 0x52, 0x3b, 0x37,
		0x3f, 0x41, 0xa5, 0x76, 0x81, 0x78, 0x08, 0xa8, 0x6b, 0xa8, 0xeb, 0x5f, 0xee, 0x18, 0xd4, 0xb5,
		0xe6, 0xe6, 0x42, 0x5d, 0x17, 0xd9, 0x44, 0xb8, 0x33, 0x15, 0xae, 0x4c, 0x86, 0x73, 0xd3, 0xe1,
		0xdc, 0x84, 0x38, 0x35, 0x25, 0xb6, 0xd8, 0x15, 0xea, 0x5a, 0x4d, 0xfb, 0x42, 0x5d, 0x2b, 0x7c,
		0x28, 0xd4, 0x35, 0xd4, 0xb5, 0xb5, 0xc8, 0x41, 0x5d, 0x43, 0x5d, 0x43, 0x5d, 0x7b, 0xff, 0x3d,
		0x50, 0xd7, 0xcb, 0xac, 0xe7, 0x29, 0x75, 0x4d, 0x09, 0x96, 0x95, 0xe4, 0xad, 0x71, 0x09, 0x56,
		0x5c, 0x9c, 0x12, 0xac, 0x93, 0x35, 0x2f, 0xc1, 0xd2, 0x0d, 0xd8, 0x98, 0x04, 0x6a, 0xcc, 0x8a,
		0xb0, 0xaa, 0x14, 0x61, 0xf9, 0xc3, 0xa6, 0x51, 0x84, 0xb5, 0xc6, 0xa6, 0x55, 0xbd, 0x08, 0x2b,
		0x4a, 0xc2, 0xcf, 0xed, 0xa8, 0x69, 0x17, 0xc9, 0x1e, 0x2f, 0xa8, 0x1d, 0x89, 0xb2, 0x6d, 0x67,
		0x6b, 0x04, 0xaf, 0x29, 0xfb, 0x2a, 0x94, 0xea, 0x76, 0xa6, 0xc2, 0x9d, 0xa9, 0x72, 0x27, 0x2a,
		0xbd, 0x1c, 0xb8, 0xdd, 0x2c, 0xb0, 0xe1, 0xa0, 0xdd, 0xac, 0x51, 0x9b, 0x59, 0x00, 0xf9, 0xba,
		0x03, 0x72, 0x45, 0xd6, 0x47, 0x01, 0xe6, 0x6e, 0x78, 0x2c, 0x4c, 0xda, 0x42, 0xe4, 0x9f, 0xf0,
		0x54, 0x54, 0x58, 0x07, 0x29, 0x02, 0x47, 0x56, 0xa8, 0xe5, 0x44, 0x4f, 0xe6, 0x49, 0x42, 0xc2,
		0x7b, 0xeb, 0x68, 0x0d, 0xa7, 0x68, 0x64, 0xa7, 0x1c, 0x0c, 0x77, 0x5e, 0xe8, 0xd9, 0xa7, 0x71,
		0x3f, 0x3d, 0x4a, 0x53, 0x59, 0x40, 0x56, 0x79, 0x1b, 0x27, 0xc7, 0xed, 0xe8, 0xd6, 0x55, 0xea,
		0xcb, 0xba, 0xf5, 0x95, 0xb7, 0xe1, 0xb7, 0xa9, 0x27, 0xef, 0xbc, 0xa8, 0xd5, 0xf6, 0x0f, 0x6a,
		0xb5, 0xed, 0x83, 0xdd, 0x83, 0xed, 0xc3, 0xbd, 0xbd, 0x9d, 0xfd, 0x1d, 0xc1, 0x10, 0x5c, 0xe5,
		0x5d, 0xaf, 0x19, 0xf5, 0xa2, 0xe6, 0xab, 0xdb, 0xed, 0x4f, 0x06, 0xed, 0xb6, 0x57, 0x52, 0xa1,
		0xa4, 0xca, 0x1c, 0xab, 0x30, 0x41, 0x7d, 0xb5, 0xba, 0x9e, 0x92, 0x51, 0x4b, 0xf9, 0x95, 0x48,
		0xbe, 0x27, 0xe4, 0x14, 0x34, 0x69, 0x01, 0x73, 0x23, 0x58, 0xf9, 0x8e, 0x72, 0xf5, 0x03, 0xc8,
		0xb1, 0xf9, 0xc3, 0x9e, 0x3e, 0x51, 0x33, 0xea, 0xc9, 0xec, 0xfd, 0xbd, 0x56, 0x41, 0x77, 0x8f,
		0xcd, 0x29, 0x1c, 0x32, 0xac, 0xbd, 0x18, 0xf5, 0x23, 0x49, 0xed, 0xc8, 0x53, 0x37, 0xd2, 0xd4,
		0x8c, 0x1a, 0xf5, 0xa2, 0x46, 0xad, 0xa8, 0x50, 0x27, 0x6e, 0xd5, 0xa3, 0x14, 0x8b, 0x2d, 0xdd,
		0x32, 0x4c, 0xa7, 0x35, 0x98, 0x70, 0x98, 0x4e, 0x9c, 0xf3, 0xd5, 0xe0, 0x76, 0xf5, 0x38, 0x5c,
		0x2d, 0xae, 0x56, 0x9d, 0x93, 0x55, 0xe7, 0x5e, 0x55, 0x39, 0x56, 0xbf, 0x60, 0x9d, 0x74, 0x18,
		0xac, 0x12, 0x37, 0xa3, 0x24, 0x8d, 0x5b, 0x71, 0x24, 0x1f, 0x5e, 0xbb, 0x6b, 0xc7, 0x7a, 0xb7,
		0x86, 0xf0, 0xc1, 0xeb, 0x04, 0x9b, 0xd4, 0x82, 0x4b, 0x9a, 0xc1, 0x24, 0xfd, 0xe0, 0x91, 0x76,
		0xb0, 0xc8, 0x2c, 0x38, 0x64, 0x16, 0x0c, 0x32, 0x09, 0xfe, 0xf8, 0x4d, 0x9e, 0xaa, 0x05, 0x73,
		0xee, 0x06, 0xc5, 0xf6, 0x83, 0x64, 0x70, 0xfd, 0x59, 0x5c, 0xb9, 0x6c, 0xea, 0x16, 0x9e, 0x28,
		0x17, 0x98, 0x28, 0x06, 0x3b, 0x2c, 0x0a, 0x46, 0xac, 0xd2, 0x08, 0x8c, 0x0a, 0x40, 0x2c, 0x93,
		0xed, 0x35, 0x9b, 0x3d, 0x58, 0x14, 0x6e, 0x58, 0x1f, 0xbd, 0x55, 0x21, 0x86, 0xa9, 0x0c, 0x14,
		0x24, 0xf0, 0x77, 0xe9, 0x6b, 0x2c, 0x47, 0x10, 0xb6, 0x5d, 0x47, 0xb7, 0xc6, 0x49, 0x63, 0x86,
		0xfa, 0x5d, 0x15, 0xfe, 0x64, 0x09, 0xfc, 0x6b, 0xfc, 0x6b, 0xfc, 0x6b, 0xfc, 0x6b, 0xfc, 0x6b,
		0xfc, 0x6b, 0xfc, 0x6b, 0xfc, 0x6b, 0xfc, 0x6b, 0xfc, 0x6b, 0x6f, 0x6d, 0x97, 0x4a, 0x1e, 0xd1,
		0xb4, 0x1a, 0xd5, 0xc9, 0x27, 0x9a, 0xbe, 0xad, 0x66, 0x79, 0x45, 0x93, 0x45, 0x55, 0xf2, 0x8b,
		0x14, 0x10, 0x14, 0x79, 0x4f, 0xc2, 0xe9, 0x29, 0xf7, 0x52, 0x31, 0x44, 0x1b, 0x92, 0x0a, 0x24,
		0x1d, 0x09, 0xe4, 0x3b, 0xc8, 0xd6, 0xa5, 0xaa, 0xd4, 0xa1, 0xaa, 0x05, 0xb4, 0xab, 0x04, 0xb4,
		0x0b, 0x84, 0x73, 0x09, 0x68, 0x13, 0xd0, 0x26, 0xa0, 0x0d, 0xe1, 0x06, 0xe1, 0x06, 0xe1, 0x06,
		0xe1, 0x06, 0xe1, 0x06, 0xe1, 0x06, 0xe1, 0x06, 0xe1, 0x06, 0xe1, 0x46, 0x40, 0x5b, 0xca, 0x04,
		0x12, 0xd0, 0xc6, 0xbf, 0xc6, 0xbf, 0xc6, 0xbf, 0xc6, 0xbf, 0xc6, 0xbf, 0xc6, 0xbf, 0xc6, 0xbf,
		0xc6, 0xbf, 0xc6, 0xbf, 0xd6, 0xf0, 0xaf, 0x09, 0x68, 0x3f, 0xbc, 0xad, 0x04, 0xb4, 0x55, 0x9f,
		0x44, 0x40, 0x7b, 0x5e, 0x40, 0x5b, 0xb0, 0x61, 0x15, 0x4d, 0x34, 0x3c, 0x39, 0xd4, 0x8a, 0x48,
		0x5a, 0xc0, 0xb2, 0x0d, 0x59, 0x7e, 0xbb, 0xf7, 0x0a, 0x05, 0xed, 0xe5, 0x21, 0x50, 0xdc, 0x2f,
		0x5b, 0xd4, 0x4f, 0xf7, 0x0e, 0x97, 0xd4, 0x07, 0xdd, 0x3b, 0x3c, 0xd0, 0xcb, 0x62, 0xdd, 0x3b,
		0x04, 0xa9, 0xd3, 0x29, 0x56, 0x43, 0x38, 0xc9, 0x69, 0x9b, 0xae, 0x1d, 0x12, 0x4f, 0x26, 0xc9,
		0xc9, 0x52, 0x41, 0xf8, 0xe9, 0xad, 0x8b, 0x73, 0x9a, 0xaa, 0x5c, 0xa6, 0x02, 0x87, 0xa9, 0xc4,
		0x5d, 0xea, 0x80, 0x6c, 0xc5, 0x78, 0x85, 0x2a, 0x51, 0xa5, 0xcd, 0x4d, 0x5a, 0xf0, 0x51, 0x37,
		0x3a, 0xac, 0x46, 0xe1, 0x8f, 0x54, 0x9b, 0x73, 0x34, 0x39, 0x5b, 0x4f, 0x99, 0x9d, 0xcb, 0x12,
		0x25, 0xd1, 0xf7, 0x3a, 0x83, 0x34, 0xea, 0x05, 0x71, 0x53, 0xde, 0xc1, 0xbc, 0x7b, 0x34, 0x7e,
		0x26, 0x7e, 0x26, 0x7e, 0xe6, 0x5a, 0xf9, 0x99, 0xcd, 0x4e, 0x9a, 0x46, 0xcd, 0xe0, 0x3f, 0x83,
		0xb0, 0xa9, 0xe0, 0x69, 0xee, 0xbc, 0x10, 0x7c, 0xe6, 0x79, 0x98, 0xa6, 0x51, 0x2f, 0x11, 0x77,
		0x36, 0x2b, 0xff, 0x7a, 0xf2, 0xe4, 0xd3, 0x76, 0x70, 0x78, 0xf9, 0xe3, 0xd3, 0x4e, 0x70, 0x78,
		0x39, 0xfa, 0xc7, 0x9d, 0xe1, 0xff, 0x8c, 0xfe, 0xb9, 0xfa, 0x69, 0x3b, 0xa8, 0x8d, 0xff, 0x79,
		0xef, 0xd3, 0x76, 0xb0, 0x77, 0xf9, 0xf4, 0xcf, 0x3f, 0x9f, 0x3f, 0xfd, 0x7b, 0xf7, 0x66, 0xf9,
		0x5f, 0xfc, 0x2f, 0x39, 0x19, 0xbd, 0x94, 0xdc, 0xdc, 0x77, 0x17, 0x27, 0xff, 0xcb, 0x0e, 0xfb,
		0xea, 0x41, 0x10, 0xb6, 0xc8, 0x11, 0xb6, 0xc8, 0x5b, 0x4e, 0xe9, 0x26, 0x58, 0xd0, 0x1c, 0xcd,
		0x77, 0x0b, 0x86, 0xee, 0x59, 0xd0, 0x8c, 0x47, 0x9f, 0x2b, 0x17, 0x3c, 0x98, 0xf3, 0x7c, 0x82,
		0x09, 0x76, 0x3e, 0x1e, 0xc1, 0x04, 0x82, 0x09, 0xf3, 0x1f, 0x44, 0x2b, 0x70, 0xc0, 0x1e, 0x60,
		0x6f, 0xfd, 0xc0, 0x9e, 0x78, 0xe5, 0x74, 0xf4, 0xed, 0xd6, 0xab, 0x0f, 0xdb, 0xd2, 0xae, 0xc4,
		0xdc, 0x7b, 0x31, 0x6f, 0x41, 0x6a, 0x3e, 0xa8, 0xf9, 0x70, 0xa6, 0xa2, 0xcc, 0x54, 0x95, 0x89,
		0xca, 0x92, 0x55, 0x5d, 0xc2, 0x2a, 0x4c, 0x8f, 0xb7, 0x9a, 0x91, 0xf7, 0x41, 0x9c, 0xa4, 0x2f,
		0x14, 0xeb, 0x3d, 0xf6, 0xa8, 0xf7, 0xb8, 0x7b, 0xf1, 0x32, 0xd6, 0x7b, 0xec, 0x50, 0xef, 0xb1,
		0xd0, 0xd1, 0x97, 0xb0, 0xde, 0xa3, 0xba, 0x47, 0xa1, 0x87, 0xf9, 0x53, 0xd7, 0xa1, 0x90, 0x3a,
		0x4e, 0x8c, 0x1d, 0xee, 0x79, 0x0b, 0xe2, 0x70, 0xe3, 0x70, 0xe3, 0x70, 0xe3, 0x70, 0xe3, 0x70,
		0xe3, 0x70, 0xe3, 0x70, 0xe3, 0x70, 0xe3, 0x70, 0xe3, 0x70, 0x7b, 0xe3, 0x70, 0x53, 0x77, 0x2b,
		0x9c, 0xeb, 0xf0, 0x78, 0x44, 0x9f, 0x8e, 0xd2, 0x8b, 0xba, 0x36, 0x74, 0x94, 0xf6, 0x15, 0x13,
		0x11, 0x17, 0x75, 0x82, 0x79, 0x88, 0x8b, 0xca, 0xde, 0x0b, 0xe2, 0xa2, 0xd0, 0x34, 0xd0, 0x34,
		0xd0, 0x34, 0xd0, 0x34, 0xd0, 0x34, 0xd0, 0x34, 0xd0, 0x34, 0xd0, 0x34, 0xd0, 0x34, 0xde, 0xd3,
		0x34, 0xc4, 0x45, 0x71, 0xb8, 0x71, 0xb8, 0x71, 0xb8, 0x71, 0xb8, 0x71, 0xb8, 0x71, 0xb8, 0x71,
		0xb8, 0x71, 0xb8, 0x71, 0xb8, 0x71, 0xb8, 0x15, 0x1d, 0x6e, 0xe2, 0xa2, 0x36, 0x71, 0x51, 0x1a,
		0x13, 0x6b, 0x9d, 0xb2, 0x07, 0xa7, 0xeb, 0xa6, 0x43, 0xf1, 0xef, 0xa3, 0x77, 0x79, 0x7f, 0xfb,
		0x2a, 0xbf, 0x8f, 0xdf, 0xa4, 0x88, 0xbd, 0x07, 0xbe, 0x27, 0xe1, 0x75, 0xdc, 0x08, 0x92, 0x28,
		0xbe, 0xfa, 0xf2, 0xb9, 0xd3, 0x0b, 0x46, 0x40, 0x28, 0xea, 0x0b, 0xb6, 0x1f, 0x98, 0xbb, 0x04,
		0x1d, 0x08, 0xec, 0xc0, 0x35, 0x1d, 0x08, 0xe8, 0x40, 0xb0, 0xb4, 0x1a, 0x90, 0xcf, 0xbc, 0x99,
		0xb7, 0x10, 0x3d, 0x0a, 0xfc, 0xe3, 0xe1, 0xc8, 0xc5, 0x71, 0xc2, 0xb3, 0x95, 0x3c, 0x17, 0x47,
		0xb8, 0xd9, 0xc9, 0xcc, 0x35, 0x10, 0x6d, 0x7a, 0xa2, 0xa4, 0x58, 0xd4, 0x14, 0x8c, 0xa6, 0xa2,
		0xd1, 0x57, 0x38, 0xda, 0x8a, 0xc7, 0x4c, 0x01, 0x99, 0x29, 0x22, 0x13, 0x85, 0xa4, 0xc3, 0xcc,
		0x48, 0x13, 0xff, 0xd2, 0x8a, 0x6a, 0xf2, 0xe0, 0x6e, 0x14, 0xf5, 0x82, 0xab, 0x5e, 0x67, 0xd0,
		0xd5, 0x13, 0xc8, 0xf1, 0x95, 0x9a, 0x5a, 0xeb, 0x59, 0x21, 0xbb, 0x5d, 0x6b, 0x29, 0x34, 0x0b,
		0xc5, 0x66, 0xa7, 0xe0, 0xac, 0x14, 0x9d, 0xb9, 0xc2, 0x33, 0x57, 0x7c, 0xa6, 0x0a, 0x50, 0x47,
		0x11, 0x2a, 0x29, 0xc4, 0xc9, 0xce, 0xa8, 0x45, 0x44, 0x67, 0xee, 0x4b, 0x3b, 0x0a, 0x5b, 0xbd,
		0xa8, 0xa5, 0x79, 0x61, 0xc6, 0x7e, 0xd8, 0x81, 0xe2, 0x1a, 0xe7, 0x19, 0x9b, 0xf9, 0xfc, 0xf9,
		0xd6, 0xf4, 0xff, 0xdd, 0xe9, 0xe6, 0xfe, 0xd4, 0x3f, 0x8f, 0xc8, 0xe5, 0xa9, 0x3f, 0x08, 0x86,
		0x34, 0x62, 0x41, 0x42, 0x23, 0x1a, 0xc3, 0x1a, 0xba, 0xba, 0x1a, 0xfa, 0xce, 0x56, 0xaa, 0x7a,
		0x6e, 0xd8, 0x49, 0xec, 0x24, 0x76, 0x12, 0x3b, 0xa9, 0x71, 0x5f, 0xe2, 0x6e, 0xa0, 0x2e, 0x5d,
		0x13, 0x4b, 0x79, 0xa8, 0xb8, 0x46, 0xb6, 0x65, 0x9f, 0x54, 0x45, 0x56, 0xf7, 0xca, 0x3f, 0x38,
		0x98, 0xaf, 0xb5, 0xc0, 0xe4, 0xe2, 0x6f, 0x2a, 0xcd, 0x4e, 0xf8, 0x99, 0x53, 0xa3, 0xd2, 0xf1,
		0x7f, 0xee, 0x82, 0xa6, 0x93, 0x00, 0xb6, 0xb2, 0xc5, 0x9e, 0xfe, 0x78, 0xf2, 0x69, 0x27, 0xa8,
		0x5e, 0x8e, 0xff, 0x65, 0xf7, 0xd3, 0x76, 0x50, 0xbd, 0x7c, 0x2a, 0x39, 0x29, 0x60, 0xde, 0xcf,
		0xa5, 0xc5, 0x21, 0x6a, 0xce, 0x6e, 0xe0, 0x24, 0xc7, 0x27, 0xa9, 0xba, 0xc2, 0xcd, 0xb3, 0x12,
		0x69, 0xcb, 0x7d, 0xb4, 0xa5, 0xe8, 0x1d, 0x0b, 0x83, 0xd6, 0x51, 0xf0, 0xfa, 0xf2, 0xef, 0x9d,
		0x67, 0xb5, 0x9b, 0x97, 0x4f, 0xff, 0x3e, 0xb8, 0x79, 0xf8, 0x87, 0x3f, 0x1e, 0xfb, 0x6b, 0x3b,
		0xcf, 0x0e, 0x6e, 0x5e, 0xce, 0xf9, 0x2f, 0xfb, 0x37, 0x2f, 0x17, 0x7c, 0xc6, 0xde, 0xcd, 0x93,
		0x99, 0xbf, 0x7a, 0xfb, 0xe7, 0xd5, 0x79, 0xbf, 0x50, 0x9b, 0xf3, 0x0b, 0xbb, 0xf3, 0x7e, 0x61,
		0x77, 0xce, 0x2f, 0xcc, 0x7d, 0xa5, 0xea, 0x9c, 0x5f, 0xd8, 0xbb, 0xf9, 0x31, 0xf3, 0xf7, 0x9f,
		0x3c, 0xfe, 0x57, 0xf7, 0x6f, 0x9e, 0xfe, 0x98, 0xf7, 0xdf, 0x0e, 0x6e, 0x7e, 0xbc, 0x7c, 0xfa,
		0x74, 0xeb, 0xc9, 0xce, 0xad, 0x22, 0x7a, 0x31, 0xd2, 0x4d, 0x3b, 0x97, 0x33, 0x2a, 0x6b, 0xa4,
		0x82, 0x30, 0x21, 0x88, 0x37, 0xe2, 0xed, 0xb1, 0x5d, 0xdd, 0x28, 0xd6, 0x7b, 0xdf, 0xac, 0x59,
		0x7c, 0x4e, 0x29, 0xbf, 0x78, 0xf2, 0x7c, 0xd3, 0x4c, 0xd4, 0x79, 0x29, 0x8d, 0xf3, 0xfe, 0x8b,
		0x68, 0x6b, 0x26, 0xf9, 0xf3, 0x96, 0x2c, 0xfd, 0x54, 0xa2, 0x7f, 0x75, 0x69, 0x5f, 0x0a, 0x3b,
		0x2d, 0x69, 0x5d, 0xf2, 0x3b, 0xbc, 0xa4, 0x6d, 0xd7, 0xbd, 0xb0, 0x53, 0x2f, 0x7c, 0xa9, 0x19,
		0xb6, 0x9c, 0x0e, 0x57, 0x66, 0xb1, 0xc8, 0x91, 0xc8, 0xaf, 0x81, 0xad, 0x91, 0x6d, 0x0f, 0x38,
		0x23, 0x10, 0x92, 0x6d, 0x02, 0x67, 0x44, 0x41, 0xcb, 0xd2, 0x54, 0xb1, 0x34, 0x58, 0x1a, 0x2c,
		0x4d, 0x8e, 0x1d, 0x20, 0x93, 0xd0, 0xa1, 0xcb, 0xac, 0xee, 0x3a, 0x5b, 0x28, 0x36, 0x3b, 0x05,
		0x67, 0xa5, 0xe8, 0xcc, 0x15, 0x9e, 0xb9, 0xe2, 0x33, 0x55, 0x80, 0xba, 0xa4, 0x15, 0x99, 0x84,
		0x6e, 0x5d, 0xf2, 0xc7, 0x5c, 0x73, 0x32, 0x09, 0xbd, 0xa1, 0x92, 0x6c, 0x28, 0x25, 0xec, 0x24,
		0x76, 0x12, 0x3b, 0x89, 0x9d, 0x54, 0xbd, 0x2f, 0x64, 0x12, 0x2e, 0xf3, 0x43, 0x26, 0xa1, 0x90,
		0x53, 0x43, 0xfe, 0x99, 0xe6, 0x0f, 0x99, 0x84, 0x64, 0x12, 0x3a, 0x34, 0x5f, 0x6e, 0xb4, 0x25,
		0x99, 0x84, 0xb2, 0x77, 0x8c, 0x54, 0x2b, 0x32, 0x09, 0x4b, 0x6c, 0x42, 0x10, 0x6f, 0x32, 0x09,
		0x8b, 0x05, 0x36, 0x37, 0xc9, 0x24, 0x94, 0x22, 0x1e, 0xd6, 0x3a, 0x93, 0x50, 0xb0, 0x99, 0xa9,
		0xfc, 0x71, 0xfb, 0xd5, 0xbb, 0xea, 0x1f, 0xd1, 0x77, 0xf9, 0xf6, 0x84, 0xa7, 0x71, 0x3f, 0x3d,
		0x4a, 0x53, 0xe1, 0xae, 0x58, 0x6f, 0xe3, 0xe4, 0xb8, 0x1d, 0x5d, 0x47, 0xc9, 0xa8, 0x67, 0xb3,
		0x60, 0x8e, 0xcc, 0xdb, 0xf0, 0xdb, 0xd4, 0x93, 0x77, 0x5e, 0xd4, 0x6a, 0xfb, 0x07, 0xb5, 0xda,
		0xf6, 0xc1, 0xee, 0xc1, 0xf6, 0xe1, 0xde, 0xde, 0xce, 0xfe, 0x8e, 0x60, 0x47, 0xea, 0xca, 0xbb,
		0x5e, 0x33, 0xea, 0x45, 0xcd, 0x57, 0xb7, 0xfb, 0x9e, 0x0c, 0xda, 0x6d, 0x3a, 0x1c, 0xbb, 0xd6,
		0x17, 0x15, 0xd1, 0x74, 0xab, 0xa5, 0xdb, 0xe4, 0x8e, 0x5e, 0xea, 0x2c, 0x7b, 0xa7, 0x73, 0xc1,
		0xcc, 0x34, 0x3a, 0x31, 0x7b, 0x28, 0x85, 0x45, 0x6c, 0x81, 0x7c, 0xd5, 0x0b, 0x1b, 0x51, 0x6b,
		0xd0, 0x0e, 0x7a, 0x51, 0x3f, 0x0d, 0x7b, 0xa9, 0x5c, 0xe7, 0xe3, 0x99, 0x27, 0xd3, 0xf0, 0xf8,
		0x97, 0x7b, 0x46, 0xc3, 0x63, 0x1a, 0x1e, 0xcf, 0xff, 0x22, 0xb1, 0x86, 0xc7, 0xc2, 0x5d, 0x48,
		0x75, 0xba, 0x8f, 0xd2, 0xce, 0x98, 0x76, 0xc6, 0xb4, 0x33, 0x16, 0xc5, 0x00, 0xf2, 0xa3, 0xc5,
		0x93, 0xf0, 0x73, 0x3b, 0x6a, 0x2a, 0x8e, 0x12, 0xcf, 0x16, 0xa0, 0xe0, 0x8d, 0x32, 0x04, 0x67,
		0x2a, 0xc8, 0x4c, 0x15, 0x99, 0xa8, 0xa4, 0x62, 0xd0, 0x9c, 0xfa, 0x05, 0x6f, 0x9f, 0x3b, 0x9d,
		0x76, 0x14, 0x26, 0x9a, 0x05, 0x6f, 0x3b, 0x6b, 0x50, 0x85, 0xf6, 0x25, 0x6a, 0x77, 0xa3, 0x5e,
		0xd0, 0x49, 0xda, 0xdf, 0xf5, 0xcc, 0xc0, 0xf4, 0x22, 0x98, 0x02, 0x4c, 0x01, 0xa6, 0x00, 0x53,
		0x80, 0x29, 0xf0, 0xcd, 0x14, 0x64, 0x44, 0x5f, 0x90, 0xc6, 0xd7, 0x8a, 0x75, 0xc9, 0xf7, 0x56,
		0xc1, 0x18, 0x60, 0x0c, 0x30, 0x06, 0x18, 0x03, 0x41, 0x79, 0x1f, 0xc4, 0x49, 0xba, 0xb3, 0xaf,
		0x68, 0x0b, 0xf6, 0x19, 0x71, 0x7e, 0xf7, 0xe2, 0x65, 0x1c, 0x71, 0xbe, 0xcd, 0x88, 0xf3, 0x85,
		0x8e, 0xbe, 0x84, 0x23, 0xce, 0x6b, 0xdb, 0x87, 0xfb, 0xcc, 0x38, 0xb7, 0x7e, 0xea, 0xe5, 0x7a,
		0x74, 0xfb, 0x69, 0x47, 0xa3, 0xe9, 0xcf, 0x7d, 0x65, 0x0f, 0x7b, 0x76, 0x29, 0xdc, 0x6c, 0xdc,
		0x6c, 0xdc, 0x6c, 0xdc, 0x6c, 0x41, 0x79, 0x6f, 0x46, 0x8d, 0xf8, 0x3a, 0x6c, 0xef, 0xd7, 0x34,
		0x59, 0x97, 0xaa, 0xc2, 0xb3, 0x67, 0xec, 0x6f, 0x15, 0x7f, 0xde, 0x8d, 0x3f, 0x5f, 0xc5, 0x9f,
		0x5f, 0x57, 0x7f, 0x7e, 0x97, 0xa3, 0xc7, 0x99, 0x37, 0x76, 0xe6, 0x49, 0xe7, 0x17, 0x4e, 0xa4,
		0x7e, 0x98, 0x21, 0x2c, 0xda, 0x27, 0x5c, 0x20, 0x43, 0x5e, 0x20, 0x0d, 0x57, 0xb6, 0x47, 0xab,
		0x4a, 0x6f, 0x56, 0xb5, 0x3c, 0xcb, 0x2a, 0x79, 0x96, 0x05, 0x42, 0x59, 0xe4, 0x59, 0x92, 0x67,
		0x49, 0x9e, 0x25, 0x44, 0x0f, 0x44, 0x0f, 0x44, 0x8f, 0xa8, 0xbc, 0x93, 0x5c, 0x23, 0xf2, 0xad,
		0xe4, 0x59, 0x62, 0x0a, 0x30, 0x05, 0x98, 0x02, 0x4c, 0xc1, 0xda, 0x9b, 0x02, 0xf2, 0x2c, 0x31,
		0x06, 0x18, 0x03, 0x8c, 0x41, 0xb1, 0x8d, 0x01, 0x79, 0x96, 0x33, 0x3f, 0xe4, 0x59, 0x2e, 0xb4,
		0x0c, 0x71, 0xd9, 0xe5, 0x8e, 0x9e, 0x3c, 0x4b, 0xdf, 0x4f, 0x9f, 0xd0, 0xac, 0x37, 0xce, 0x35,
		0x79, 0x96, 0xb8, 0xd9, 0xb8, 0xd9, 0xb8, 0xd9, 0x65, 0x71, 0xb3, 0xc9, 0xb3, 0xc4, 0x9f, 0xcf,
		0x79, 0xbc, 0xe4, 0x59, 0xae, 0xad, 0x3f, 0x4f, 0x9e, 0x25, 0xce, 0xbc, 0xb5, 0x33, 0x4f, 0x9e,
		0xa5, 0x76, 0x9e, 0xa5, 0x60, 0x17, 0x75, 0x1a, 0x11, 0xfb, 0x73, 0xae, 0x15, 0x91, 0x84, 0xd5,
		0x65, 0xbb, 0x5c, 0xbf, 0xc9, 0xde, 0xe2, 0x7d, 0xf6, 0x12, 0x05, 0x6c, 0x82, 0x3c, 0x84, 0xe0,
		0x41, 0x3f, 0x6a, 0x47, 0x43, 0x23, 0x11, 0x74, 0xba, 0xb7, 0xff, 0xd3, 0x97, 0xeb, 0x85, 0x3c,
		0x6f, 0x01, 0x5a, 0x22, 0xdb, 0xe1, 0x75, 0x5a, 0x22, 0xd3, 0x12, 0x79, 0xfe, 0x83, 0x68, 0x89,
		0xec, 0x29, 0x81, 0x47, 0xaa, 0xbe, 0x3d, 0x41, 0x47, 0xaa, 0xfe, 0xea, 0x0f, 0x0c, 0x9b, 0x5f,
		0xa3, 0x5e, 0x1a, 0xf7, 0xa3, 0x20, 0x4e, 0x6e, 0x31, 0xe7, 0xd7, 0x31, 0xc3, 0xaf, 0x17, 0x47,
		0x98, 0xbf, 0xa4, 0xb0, 0x58, 0xfc, 0x1e, 0xb5, 0xc2, 0x41, 0x7b, 0x28, 0x15, 0xad, 0xb0, 0xdd,
		0x27, 0x5e, 0x41, 0xbc, 0xc2, 0xa1, 0x1a, 0x34, 0x53, 0x87, 0x26, 0x6a, 0x51, 0x87, 0xe8, 0x21,
		0x47, 0xf4, 0x11, 0xef, 0x69, 0x1d, 0x72, 0x44, 0xc3, 0xf6, 0x5f, 0xe1, 0xf7, 0x7e, 0xd0, 0xe8,
		0x5c, 0x77, 0xc3, 0x5e, 0x14, 0x5c, 0x6b, 0x16, 0x8f, 0x3d, 0xb2, 0x16, 0x86, 0x07, 0xc3, 0x83,
		0xe1, 0xc1, 0xf0, 0x60, 0x78, 0xd6, 0xcd, 0xf0, 0x8c, 0x2a, 0x89, 0x83, 0x30, 0xbe, 0xea, 0x6a,
		0x97, 0x2b, 0x8f, 0x16, 0xc1, 0xd4, 0x60, 0x6a, 0x30, 0x35, 0x98, 0x1a, 0x4c, 0xcd, 0xda, 0x99,
		0x9a, 0x6f, 0x69, 0xd4, 0x4b, 0xc2, 0xf6, 0x04, 0x79, 0x0c, 0x59, 0xaf, 0x5e, 0x10, 0x6b, 0x36,
		0xca, 0x98, 0xbf, 0xa6, 0x9e, 0x21, 0xba, 0xbd, 0xee, 0xd8, 0x21, 0xec, 0x10, 0x76, 0x08, 0x3b,
		0x84, 0x1d, 0xf2, 0xce, 0x0e, 0xc5, 0x57, 0x49, 0xa7, 0x17, 0x05, 0x61, 0x3f, 0xe8, 0x86, 0xe9,
		0x97, 0xa0, 0x1d, 0x25, 0x57, 0xc3, 0xf4, 0x1f, 0x25, 0x13, 0xf4, 0xf8, 0x72, 0xc0, 0x20, 0xcc,
		0x0f, 0xe6, 0x07, 0xf3, 0x83, 0xf9, 0x59, 0x53, 0xf3, 0x93, 0x44, 0xdf, 0xd2, 0xe0, 0x4b, 0xa7,
		0x1b, 0xc4, 0x57, 0xdd, 0xe0, 0x3a, 0x4a, 0x7b, 0x71, 0x43, 0xdd, 0x06, 0x3d, 0xb6, 0x26, 0x86,
		0x08, 0x43, 0x84, 0x21, 0xc2, 0x10, 0x61, 0x88, 0x0a, 0x61, 0x88, 0xa8, 0xb6, 0x11, 0xae, 0xca,
		0x98, 0x93, 0xeb, 0x4f, 0x73, 0xf3, 0x45, 0x6f, 0x23, 0xcd, 0xcd, 0x7d, 0x35, 0xe3, 0x64, 0x4c,
		0x3b, 0x31, 0xd3, 0x64, 0x4c, 0x4b, 0xdf, 0x0c, 0x32, 0xa6, 0x41, 0x2f, 0xa0, 0x17, 0xd0, 0x0b,
		0xe8, 0x05, 0x1a, 0x6d, 0x62, 0x86, 0xc8, 0x98, 0xc6, 0xf0, 0x60, 0x78, 0x30, 0x3c, 0x18, 0x1e,
		0x0c, 0x8f, 0xa5, 0xe1, 0x21, 0x63, 0x1a, 0x53, 0x83, 0xa9, 0xc1, 0xd4, 0x60, 0x6a, 0x30, 0x35,
		0xda, 0xa6, 0x86, 0x8c, 0x69, 0xec, 0x10, 0x76, 0x08, 0x3b, 0x84, 0x1d, 0xc2, 0x0e, 0x39, 0xb4,
		0x43, 0x64, 0x4c, 0x63, 0x7e, 0x30, 0x3f, 0x98, 0x1f, 0xcc, 0x0f, 0xe6, 0xc7, 0x9d, 0xf9, 0x21,
		0x63, 0x1a, 0x43, 0x84, 0x21, 0xc2, 0x10, 0x61, 0x88, 0x30, 0x44, 0xd6, 0x4f, 0x22, 0x63, 0xfa,
		0xd7, 0x19, 0xd3, 0x8c, 0x29, 0xd0, 0x3a, 0x66, 0x1f, 0x8e, 0xd7, 0xcd, 0xb4, 0x82, 0xf7, 0xb7,
		0x2f, 0x73, 0x31, 0x7e, 0x97, 0x77, 0xd9, 0xab, 0x14, 0x70, 0x66, 0x81, 0x4c, 0xf2, 0xbd, 0x68,
		0xd2, 0xbd, 0xf8, 0x3c, 0x82, 0x2a, 0xf3, 0x08, 0x3c, 0xf0, 0xe4, 0x98, 0x47, 0xb0, 0x04, 0xf6,
		0x92, 0x9a, 0x47, 0x10, 0xf6, 0xe5, 0x0b, 0x6b, 0xc2, 0xbe, 0x70, 0x55, 0xcd, 0x36, 0x73, 0x08,
		0x3c, 0x86, 0x78, 0x54, 0xd5, 0x14, 0xc8, 0x8f, 0x17, 0x87, 0x6c, 0x53, 0xb7, 0x3e, 0x48, 0x06,
		0xd7, 0x9f, 0xa3, 0x9e, 0xa4, 0xc8, 0x66, 0x0a, 0xe0, 0x40, 0xf0, 0x91, 0x3a, 0xa3, 0x38, 0x15,
		0x30, 0xb0, 0xe6, 0xe8, 0x4d, 0xe5, 0x39, 0xea, 0xda, 0xf3, 0x16, 0x2d, 0xe6, 0x2c, 0x2a, 0x8c,
		0xd6, 0x54, 0x1d, 0xa9, 0x69, 0x75, 0xa4, 0xb5, 0xea, 0x61, 0xed, 0x70, 0xff, 0xa0, 0x7a, 0xb8,
		0x57, 0xe0, 0xb3, 0xf5, 0x94, 0xf3, 0xb9, 0x2c, 0x51, 0xd5, 0xb6, 0x7c, 0xca, 0xd7, 0xfd, 0x31,
		0x77, 0x82, 0x99, 0x5d, 0xf8, 0x99, 0xf8, 0x99, 0xf8, 0x99, 0x05, 0xf1, 0x33, 0x9b, 0x9d, 0x34,
		0x8d, 0x9a, 0xc1, 0x7f, 0x06, 0x61, 0x53, 0xc1, 0xd3, 0xdc, 0x79, 0x21, 0xf8, 0xcc, 0xf3, 0x30,
		0x4d, 0xa3, 0x5e, 0x22, 0xee, 0x6c, 0x56, 0xfe, 0xf5, 0xe4, 0xc9, 0xa7, 0xed, 0xe0, 0xf0, 0xf2,
		0xc7, 0xa7, 0x9d, 0xe0, 0xf0, 0x72, 0xf4, 0x8f, 0x3b, 0xc3, 0xff, 0x19, 0xfd, 0x73, 0xf5, 0xd3,
		0x76, 0x50, 0x1b, 0xff, 0xf3, 0xde, 0xa7, 0xed, 0x60, 0xef, 0xf2, 0xe9, 0x9f, 0x7f, 0x3e, 0x7f,
		0xfa, 0xf7, 0xee, 0xcd, 0xf2, 0xbf, 0xf8, 0x5f, 0x72, 0x32, 0x7a, 0x29, 0xb9, 0xb9, 0xef, 0x2e,
		0x4e, 0xfe, 0x97, 0x1d, 0x2e, 0xb1, 0x07, 0x91, 0x76, 0xd2, 0xb0, 0x3d, 0x4c, 0xa5, 0x53, 0x20,
		0xa9, 0xa6, 0x1f, 0x8e, 0x17, 0x81, 0x17, 0x81, 0x17, 0xb1, 0x56, 0x5e, 0xc4, 0x20, 0x4e, 0xd2,
		0xdd, 0x2a, 0x54, 0x15, 0x54, 0x15, 0x54, 0x15, 0x54, 0x15, 0x54, 0x15, 0x8e, 0x66, 0x30, 0xf2,
		0x06, 0x22, 0x3d, 0x5f, 0x73, 0xfc, 0x7c, 0xdc, 0x4d, 0xdc, 0x4d, 0xdc, 0x4d, 0xdc, 0x4d, 0xdc,
		0x4d, 0xdc, 0x4d, 0xdc, 0x4d, 0xdc, 0x4d, 0xdc, 0xcd, 0x02, 0xb9, 0x9b, 0xa4, 0x67, 0xaf, 0x98,
		0x9e, 0x2d, 0x90, 0x65, 0xef, 0x26, 0x03, 0x7a, 0xd0, 0x8f, 0x82, 0xeb, 0x41, 0x3b, 0x8d, 0xbb,
		0xed, 0x48, 0x88, 0x8d, 0xbe, 0xf3, 0x0b, 0x66, 0x9f, 0xed, 0x59, 0x6e, 0xf4, 0x36, 0xb9, 0xd1,
		0x1e, 0x78, 0xfb, 0xe4, 0x46, 0x2f, 0xfe, 0x45, 0x62, 0xb9, 0xd1, 0x8d, 0xf1, 0x1d, 0x10, 0xa6,
		0x03, 0xb2, 0xe7, 0x7a, 0x3e, 0x79, 0x00, 0x1a, 0x00, 0x1a, 0x60, 0x3d, 0x69, 0x00, 0xf1, 0xc9,
		0x03, 0xa3, 0xa6, 0x98, 0x4d, 0xed, 0xae, 0x9b, 0x34, 0x77, 0xd6, 0x51, 0x61, 0x9a, 0xaa, 0x4c,
		0x5f, 0xa5, 0x69, 0xab, 0x36, 0x33, 0x15, 0x67, 0xa6, 0xea, 0x4c, 0x54, 0x9e, 0x12, 0xe0, 0xa6,
		0xc2, 0x7f, 0xd6, 0x33, 0xa2, 0xc2, 0xdf, 0x01, 0xb7, 0xe0, 0x84, 0x63, 0x98, 0x85, 0xd3, 0x25,
		0x1c, 0x87, 0x16, 0x7d, 0x16, 0x6c, 0xe0, 0x7d, 0xe7, 0x42, 0xc8, 0x59, 0x1d, 0x20, 0x09, 0x90,
		0x04, 0x48, 0xe2, 0x37, 0x24, 0x11, 0xe6, 0x36, 0x74, 0x39, 0x0e, 0x25, 0xc5, 0x02, 0x60, 0x00,
		0x30, 0x00, 0x18, 0x84, 0x29, 0x03, 0x61, 0x45, 0x35, 0x79, 0x70, 0xd8, 0x6e, 0x77, 0xfe, 0xba,
		0x73, 0xee, 0xc2, 0xbe, 0x9e, 0x5c, 0xde, 0x4d, 0xcf, 0x7a, 0xb8, 0xa4, 0x92, 0xd8, 0x28, 0xf3,
		0x2c, 0xca, 0x7c, 0x8b, 0xba, 0x1a, 0xb5, 0x50, 0xa7, 0x76, 0x6a, 0xd5, 0x4a, 0xbd, 0x9a, 0xab,
		0x59, 0x73, 0x75, 0x6b, 0xaa, 0x76, 0x75, 0xd4, 0xaf, 0x92, 0x1a, 0xd6, 0xe7, 0x6f, 0x0c, 0x79,
		0x1c, 0x65, 0x3e, 0x47, 0xef, 0x60, 0x35, 0xf2, 0xa4, 0xae, 0xc3, 0x6f, 0xf1, 0xf5, 0xe0, 0x5a,
		0xb8, 0x2a, 0x6e, 0xee, 0xa9, 0xde, 0x5f, 0x4e, 0xdf, 0xfc, 0xed, 0x60, 0xfa, 0x30, 0x7d, 0x98,
		0x3e, 0x4c, 0x5f, 0x91, 0x4c, 0x9f, 0x78, 0x72, 0xf7, 0x3c, 0xed, 0x75, 0xa0, 0xb8, 0x84, 0x4e,
		0xf2, 0xf7, 0xc3, 0x1f, 0xdd, 0xfb, 0xbe, 0xa9, 0x9d, 0x1c, 0x6e, 0x6c, 0x56, 0x66, 0x96, 0x53,
		0x4e, 0x1e, 0x9f, 0x59, 0xcf, 0x20, 0xe1, 0xd8, 0x48, 0x1d, 0xdc, 0x17, 0x91, 0xf0, 0x5b, 0xe9,
		0x45, 0x44, 0x3b, 0x19, 0xdd, 0x0b, 0x59, 0xd9, 0x28, 0xe6, 0xd3, 0x2f, 0x8b, 0x02, 0x60, 0xbc,
		0xa6, 0x1a, 0x95, 0x02, 0xd6, 0x93, 0xe7, 0x3b, 0x0e, 0x5c, 0x47, 0xb7, 0xff, 0x59, 0x32, 0x7a,
		0x2d, 0x7f, 0xaa, 0x92, 0xb3, 0x72, 0x64, 0xfa, 0x8c, 0xcf, 0xf5, 0xd1, 0x24, 0xfa, 0x8e, 0xcf,
		0x25, 0x24, 0xb4, 0xc2, 0x51, 0x55, 0xc2, 0x51, 0x76, 0xa0, 0x91, 0x70, 0x54, 0x09, 0x6d, 0x04,
		0xe1, 0xa8, 0x55, 0x36, 0x8d, 0x70, 0x94, 0x6b, 0x75, 0x6a, 0xa7, 0x56, 0xad, 0xd4, 0xab, 0xb9,
		0x9a, 0x35, 0x57, 0xb7, 0xa6, 0x6a, 0x57, 0x17, 0xa4, 0x10, 0x8e, 0x5a, 0xc2, 0xfb, 0x23, 0x1c,
		0x45, 0x38, 0x0a, 0xd3, 0x87, 0xe9, 0xc3, 0xf4, 0x61, 0xfa, 0x7c, 0x30, 0x7d, 0x84, 0xa3, 0x16,
		0xfe, 0x21, 0x1c, 0x95, 0x6b, 0x39, 0xc2, 0x51, 0x32, 0x22, 0x42, 0x38, 0xaa, 0x1c, 0xb2, 0x42,
		0x38, 0x4a, 0x17, 0xc0, 0x10, 0x8e, 0x72, 0x1c, 0x8e, 0x12, 0x9c, 0x94, 0x2c, 0x7f, 0xa8, 0x94,
		0xd3, 0x1a, 0x89, 0x41, 0x45, 0x34, 0xec, 0xb7, 0xec, 0x64, 0xe5, 0x3f, 0xfa, 0xd1, 0xdb, 0xec,
		0x9d, 0xce, 0x6f, 0x5f, 0xa9, 0x7e, 0x2c, 0x86, 0x32, 0xfc, 0xa8, 0xef, 0x8d, 0x55, 0xea, 0x7b,
		0x63, 0xea, 0x7b, 0xfd, 0x64, 0x23, 0xa8, 0xef, 0x75, 0xc2, 0x26, 0x50, 0xdf, 0x9b, 0xeb, 0x1a,
		0x50, 0xdf, 0x4b, 0x42, 0x85, 0x6b, 0x05, 0x64, 0xa6, 0x88, 0x4c, 0x14, 0x52, 0x31, 0x50, 0x8e,
		0x5a, 0x42, 0x05, 0x91, 0x24, 0x1f, 0xf9, 0x1c, 0x22, 0x49, 0x5e, 0xa9, 0x54, 0x73, 0xd5, 0x6a,
		0xae, 0x62, 0x4d, 0x55, 0xad, 0x2e, 0xb5, 0x46, 0x24, 0x69, 0x61, 0xed, 0x45, 0x24, 0x69, 0x81,
		0x0f, 0x21, 0x92, 0x24, 0xb7, 0x1e, 0x91, 0xa4, 0xc2, 0x8a, 0x08, 0x91, 0x24, 0x7f, 0x9f, 0x4e,
		0x24, 0x49, 0xc4, 0xf5, 0x29, 0x77, 0x24, 0x29, 0xa6, 0xb0, 0x49, 0xd0, 0x47, 0xa3, 0xb0, 0x09,
		0x1e, 0xce, 0x13, 0xb0, 0x08, 0x0f, 0x67, 0x67, 0x23, 0xe0, 0xe1, 0x96, 0xd9, 0x2c, 0x78, 0x38,
		0x97, 0x2a, 0xd4, 0x4e, 0x95, 0x5a, 0xa9, 0x54, 0x73, 0xd5, 0x6a, 0xae, 0x62, 0x4d, 0x55, 0xad,
		0x2e, 0x30, 0x81, 0x87, 0x5b, 0x58, 0x7b, 0xc1, 0xc3, 0x2d, 0x42, 0xb2, 0xc0, 0xc3, 0x15, 0x9a,
		0x5b, 0x81, 0x87, 0x13, 0x11, 0x11, 0x78, 0x38, 0x7f, 0x9f, 0x0e, 0x0f, 0x27, 0xe2, 0xfa, 0xac,
		0x01, 0x0f, 0x47, 0x46, 0xb7, 0x6b, 0x71, 0xf0, 0x41, 0x0c, 0x3c, 0xcb, 0xe8, 0x3e, 0x29, 0x59,
		0x46, 0xb7, 0x2c, 0x05, 0xac, 0x42, 0xfd, 0xaa, 0xe5, 0x74, 0x57, 0xc9, 0xe9, 0x2e, 0x10, 0xdf,
		0x40, 0x4e, 0x37, 0x63, 0x64, 0x19, 0x23, 0xfb, 0x40, 0x85, 0x91, 0x35, 0x6e, 0xa0, 0xda, 0xcc,
		0x54, 0x9c, 0x99, 0xaa, 0x33, 0x51, 0x79, 0xc5, 0x40, 0x52, 0x8c, 0x91, 0x05, 0x25, 0x15, 0x1b,
		0x25, 0x09, 0xe2, 0x64, 0x01, 0x4c, 0xb2, 0xe1, 0xf0, 0xa4, 0xa5, 0x4f, 0xd8, 0xf1, 0xc9, 0x56,
		0x44, 0xf0, 0x5d, 0x5e, 0xc8, 0x9b, 0x4f, 0xb2, 0x56, 0x97, 0x87, 0xd5, 0x7e, 0x73, 0x45, 0x09,
		0x92, 0x92, 0x1c, 0x4b, 0x89, 0xc9, 0x21, 0x1e, 0xcb, 0x8b, 0xc5, 0x6a, 0x52, 0xb0, 0xfc, 0x19,
		0xae, 0x70, 0x7e, 0x95, 0x24, 0x8a, 0xaf, 0xbe, 0x7c, 0xee, 0xf4, 0x56, 0xcf, 0x09, 0x99, 0xd8,
		0xea, 0xbb, 0x47, 0xad, 0x28, 0x47, 0xf9, 0xb8, 0x8a, 0xdc, 0x8e, 0xbd, 0x84, 0x03, 0x2f, 0xe7,
		0xa8, 0x4b, 0x39, 0xe4, 0xe2, 0x8e, 0xb7, 0xb8, 0x83, 0x2d, 0xea, 0x48, 0xdb, 0x6a, 0xbe, 0xbc,
		0x5c, 0xc0, 0xe4, 0xce, 0xe4, 0x3f, 0xe6, 0x87, 0xb7, 0x30, 0xef, 0x29, 0xcb, 0x10, 0x87, 0x62,
		0x68, 0x5b, 0x12, 0x5d, 0xcb, 0xa3, 0x69, 0x69, 0xf4, 0xac, 0x86, 0x96, 0xd5, 0xd0, 0xb1, 0x0a,
		0x1a, 0x76, 0xeb, 0x10, 0x4b, 0x11, 0x7d, 0x95, 0xb0, 0x15, 0x07, 0xfd, 0xb0, 0x15, 0xf7, 0xe5,
		0x63, 0x05, 0x77, 0x8f, 0xa6, 0x07, 0x8c, 0x7f, 0xe4, 0x1a, 0xf1, 0x02, 0x27, 0xe4, 0x59, 0xc9,
		0xe3, 0x05, 0xe3, 0x3b, 0xaf, 0x17, 0x30, 0x98, 0xac, 0x40, 0x1f, 0x18, 0x18, 0x7d, 0x67, 0x4a,
		0xc8, 0x4c, 0x19, 0x99, 0x28, 0x25, 0x59, 0xe5, 0x24, 0xac, 0xa4, 0xd4, 0x94, 0xd5, 0x9d, 0xd2,
		0x6a, 0x36, 0xad, 0x6a, 0x4f, 0xee, 0x96, 0xd2, 0xad, 0x09, 0xd9, 0xa1, 0x26, 0xc4, 0xa1, 0x7a,
		0xb3, 0x52, 0x73, 0xe6, 0xea, 0xce, 0x5c, 0xed, 0x99, 0xaa, 0x3f, 0x1d, 0x35, 0xa8, 0xa4, 0x0e,
		0xd5, 0xd5, 0xe2, 0x64, 0x01, 0xa5, 0xbe, 0x7e, 0x73, 0xaf, 0xa5, 0x4a, 0x9f, 0x3f, 0x63, 0x45,
		0x69, 0xa6, 0x30, 0x2d, 0x15, 0xa7, 0xbd, 0x02, 0xb5, 0x56, 0xa4, 0xce, 0x14, 0xaa, 0x33, 0xc5,
		0xea, 0x44, 0xc1, 0xea, 0x2a, 0x5a, 0x65, 0x85, 0x6b, 0xa6, 0x78, 0x27, 0x0b, 0x45, 0xed, 0xf8,
		0x2a, 0xfe, 0xdc, 0x8e, 0x82, 0x91, 0x28, 0x06, 0xdd, 0x4e, 0x3b, 0x6e, 0x7c, 0xb7, 0xbb, 0x0c,
		0x93, 0x5c, 0xbd, 0xc7, 0xdf, 0xe3, 0x59, 0x29, 0x6b, 0x8e, 0xac, 0x14, 0xb7, 0x0b, 0x05, 0xee,
		0x4e, 0x91, 0xbb, 0x52, 0xe8, 0xce, 0x15, 0xbb, 0x73, 0x05, 0xef, 0x54, 0xd1, 0xdb, 0x28, 0x7c,
		0x23, 0xc5, 0x3f, 0xd9, 0x49, 0xf5, 0x6a, 0xec, 0xb9, 0xf7, 0xb5, 0x1d, 0x85, 0xad, 0x5e, 0xd4,
		0xb2, 0xbc, 0xb0, 0x63, 0x7f, 0xf9, 0xc0, 0x70, 0xcd, 0xf3, 0x49, 0xba, 0x4d, 0x23, 0xe8, 0x75,
		0x3b, 0xed, 0x97, 0xbd, 0xce, 0x20, 0x8d, 0x93, 0xab, 0xcc, 0xf2, 0x4c, 0xfe, 0x78, 0xf4, 0xaf,
		0x41, 0x33, 0x6a, 0xc5, 0x49, 0x9c, 0xc6, 0x9d, 0xa4, 0x3f, 0xff, 0x3f, 0x4d, 0xfe, 0xcb, 0x30,
		0x49, 0x66, 0xa3, 0x1c, 0x52, 0x6f, 0x51, 0x60, 0xdc, 0x8b, 0x1a, 0x51, 0xfc, 0x35, 0xb2, 0x77,
		0x3b, 0xc6, 0x0b, 0x1b, 0xdd, 0x6a, 0xa3, 0x51, 0xd4, 0xf8, 0x37, 0xf8, 0x37, 0xf8, 0x37, 0xf8,
		0x37, 0xf8, 0x37, 0x8f, 0xdc, 0x57, 0xfd, 0x51, 0xda, 0x73, 0xfd, 0x9b, 0x1d, 0x5c, 0x82, 0x85,
		0xf7, 0xac, 0x1f, 0x25, 0x4d, 0x7b, 0x7f, 0x60, 0xb8, 0x2a, 0xce, 0x00, 0xce, 0x00, 0xce, 0x00,
		0xce, 0x00, 0xce, 0x00, 0xce, 0x00, 0xce, 0x80, 0x2f, 0xce, 0x40, 0x70, 0x6d, 0xd9, 0x85, 0x6c,
		0xda, 0x21, 0x18, 0xae, 0x8c, 0x71, 0xc6, 0x38, 0x63, 0x9c, 0x31, 0xce, 0x18, 0x67, 0xb3, 0xfb,
		0x3a, 0x88, 0x93, 0xf4, 0x85, 0x03, 0xd3, 0xbc, 0x67, 0xb8, 0xa4, 0x4d, 0x1b, 0xd9, 0x87, 0x3f,
		0xb6, 0xea, 0x68, 0xd3, 0xba, 0xcd, 0xac, 0x63, 0xab, 0x3a, 0xb3, 0xbc, 0x71, 0x1b, 0xda, 0x99,
		0xf5, 0x1d, 0xb4, 0x1a, 0x75, 0xa4, 0xad, 0xee, 0x8b, 0x5c, 0xf8, 0x6d, 0xed, 0x45, 0xae, 0xba,
		0xb7, 0xb7, 0xc6, 0x42, 0xb7, 0x51, 0xce, 0xd5, 0x2e, 0xcb, 0x02, 0x1d, 0x0b, 0x9d, 0xa3, 0xa7,
		0xdc, 0x4f, 0x77, 0x16, 0x04, 0x5b, 0xb4, 0x09, 0x99, 0x34, 0xb3, 0x98, 0xfc, 0xd3, 0xd6, 0xa4,
		0xd6, 0x76, 0xf2, 0x4f, 0x5b, 0x93, 0x52, 0x13, 0x95, 0xc1, 0x57, 0x76, 0x62, 0xa2, 0x28, 0x22,
		0x4a, 0x83, 0xb2, 0xe6, 0x13, 0x15, 0x0a, 0x83, 0xb3, 0xe6, 0x19, 0x35, 0xb3, 0xc4, 0xf6, 0x2a,
		0x89, 0xed, 0xc5, 0x61, 0x1f, 0x48, 0x6c, 0x27, 0xb1, 0xfd, 0x97, 0x3b, 0x46, 0x62, 0x3b, 0x89,
		0xed, 0xc5, 0x54, 0xe0, 0xee, 0x14, 0xb9, 0x2b, 0x85, 0xee, 0x5c, 0xb1, 0x3b, 0x57, 0xf0, 0x4e,
		0x15, 0xbd, 0x2d, 0xae, 0x24, 0xb1, 0x5d, 0xd1, 0x5f, 0x26, 0xb1, 0xdd, 0x47, 0xf6, 0x81, 0xc4,
		0x76, 0x39, 0xb7, 0x8e, 0x5c, 0x36, 0xfc, 0x1b, 0xfc, 0x1b, 0xfc, 0x1b, 0xfc, 0x1b, 0x72, 0xd9,
		0x70, 0x09, 0x7e, 0xb6, 0x67, 0x24, 0xb6, 0xe3, 0x0c, 0xe0, 0x0c, 0xe0, 0x0c, 0xe0, 0x0c, 0xe0,
		0x0c, 0xe0, 0x0c, 0xe0, 0x0c, 0x90, 0xd8, 0x8e, 0x71, 0xc6, 0x38, 0x63, 0x9c, 0x31, 0xce, 0x6b,
		0x63, 0x9c, 0x49, 0x6c, 0xd7, 0xfa, 0x21, 0xb1, 0xdd, 0x74, 0x79, 0x12, 0xdb, 0x49, 0x6c, 0x77,
		0x24, 0x72, 0x24, 0xb6, 0x97, 0x70, 0x35, 0x12, 0xdb, 0x3d, 0x50, 0x39, 0x24, 0xb6, 0x0b, 0x4f,
		0xc8, 0xb5, 0x97, 0x92, 0x62, 0x75, 0x99, 0x37, 0x92, 0x37, 0x2f, 0xe5, 0xac, 0xa2, 0x5a, 0x81,
		0xb0, 0xf0, 0xc0, 0xd6, 0xb3, 0xec, 0x5d, 0xeb, 0x47, 0xad, 0xf8, 0x22, 0x6c, 0xc5, 0xf5, 0xa3,
		0x66, 0x53, 0x60, 0x92, 0xaf, 0x9d, 0x7c, 0x2a, 0xc8, 0xe6, 0x64, 0x1c, 0x54, 0x90, 0x6d, 0xa1,
		0xf6, 0xfc, 0x96, 0x7b, 0xcb, 0xe9, 0xce, 0x70, 0xd9, 0x66, 0x86, 0x8b, 0x07, 0xb4, 0x1a, 0x33,
		0x5c, 0x0a, 0x49, 0x8b, 0x15, 0xcb, 0xba, 0xaa, 0xd3, 0x5c, 0x86, 0x09, 0xb6, 0x16, 0x09, 0xb5,
		0x93, 0x04, 0xda, 0xe7, 0xcf, 0x47, 0x4e, 0xe0, 0xd6, 0x7d, 0xc5, 0xbc, 0xce, 0x06, 0xb1, 0xdb,
		0x6d, 0x7f, 0xd7, 0xae, 0xa4, 0xb9, 0xb3, 0x87, 0xd3, 0xab, 0x31, 0xd2, 0xcc, 0x07, 0x73, 0xd8,
		0xeb, 0x76, 0xda, 0xd8, 0xc3, 0x02, 0xda, 0xc3, 0xe1, 0xc1, 0x61, 0x10, 0x37, 0x19, 0x6a, 0xe6,
		0xa9, 0xaa, 0x34, 0x53, 0x99, 0x96, 0xaa, 0xd3, 0x81, 0x0a, 0xb5, 0x56, 0xa5, 0xce, 0x54, 0xaa,
		0x33, 0xd5, 0xea, 0x46, 0xc5, 0xea, 0xaa, 0x5a, 0x65, 0x95, 0x6b, 0xa6, 0x7a, 0x27, 0x0b, 0x35,
		0x47, 0x29, 0xc8, 0x41, 0xf4, 0xad, 0xdb, 0xe9, 0xa5, 0xce, 0x8a, 0xbf, 0x1f, 0x7f, 0x0d, 0xfb,
		0x34, 0xec, 0xf7, 0xc7, 0xff, 0xdf, 0xf1, 0x6f, 0x1f, 0xea, 0xef, 0xdf, 0xfd, 0xf1, 0xe1, 0x98,
		0x84, 0xaf, 0xc2, 0xd9, 0x0f, 0x87, 0x76, 0xc4, 0x95, 0x3d, 0x71, 0x6e, 0x57, 0x9c, 0xdb, 0x17,
		0xb7, 0x76, 0xc6, 0xc6, 0xde, 0x18, 0xd9, 0x1d, 0x3b, 0x2e, 0xec, 0x97, 0x96, 0x20, 0x2b, 0xad,
		0x4e, 0x6f, 0x5f, 0xc4, 0x41, 0x6e, 0x76, 0xcd, 0x70, 0xcd, 0xe3, 0x64, 0x70, 0x7d, 0xbb, 0xd9,
		0x37, 0xe4, 0x83, 0x2f, 0xed, 0xb7, 0xc4, 0xd7, 0x5e, 0xf8, 0x2d, 0xf7, 0x5f, 0x03, 0xbf, 0x05,
		0xbf, 0x05, 0xbf, 0x05, 0xbf, 0x05, 0xbf, 0x05, 0xbf, 0x05, 0xbf, 0x05, 0xbf, 0x65, 0x6a, 0xcf,
		0x1c, 0xf3, 0x2c, 0x4e, 0xf8, 0x15, 0x1c, 0x05, 0x1c, 0x05, 0x1c, 0x05, 0x1c, 0x05, 0x1c, 0x05,
		0xba, 0xeb, 0x15, 0xae, 0xbb, 0x9e, 0x91, 0x3c, 0x9e, 0xc6, 0xfd, 0xf4, 0x28, 0x4d, 0x7b, 0xb6,
		0x32, 0xf9, 0x36, 0x4e, 0x8e, 0xdb, 0xd1, 0xad, 0x4a, 0xe9, 0xdb, 0x56, 0x2a, 0x55, 0xde, 0x86,
		0xdf, 0xa6, 0x56, 0xde, 0x79, 0x51, 0xab, 0xed, 0x1f, 0xd4, 0x6a, 0xdb, 0x07, 0xbb, 0x07, 0xdb,
		0x87, 0x7b, 0x7b, 0x3b, 0xfb, 0x3b, 0x96, 0x25, 0x98, 0xef, 0x7a, 0xcd, 0xa8, 0x17, 0x35, 0x5f,
		0x7d, 0xb7, 0x37, 0x6a, 0x93, 0x4a, 0xd7, 0x7e, 0xd4, 0xb3, 0xb6, 0x67, 0x8e, 0x0c, 0xf9, 0x43,
		0x63, 0xde, 0x19, 0xed, 0x7e, 0xf0, 0xf9, 0x7b, 0xc5, 0x41, 0x89, 0xa0, 0x6b, 0xa3, 0x3e, 0x63,
		0xd8, 0x87, 0x92, 0x50, 0xd2, 0xb2, 0x35, 0x90, 0xe2, 0xe2, 0x32, 0xe1, 0x98, 0xd9, 0x76, 0xc2,
		0x68, 0x83, 0x14, 0x41, 0x8a, 0x20, 0x45, 0x90, 0x22, 0x48, 0x11, 0xa4, 0x08, 0x52, 0x04, 0x29,
		0x82, 0x14, 0x41, 0x8a, 0x20, 0x45, 0x90, 0x62, 0x81, 0x91, 0x22, 0x0d, 0x4e, 0x96, 0x58, 0xcf,
		0xa7, 0xc6, 0x13, 0x53, 0x45, 0x95, 0x0c, 0xef, 0x9c, 0x7f, 0x62, 0x0c, 0xef, 0xcc, 0xcd, 0x3e,
		0x54, 0x29, 0xe0, 0x2a, 0x90, 0x73, 0x42, 0x01, 0x17, 0x05, 0x5c, 0xbf, 0xde, 0x32, 0x0a, 0xb8,
		0x48, 0x84, 0xd6, 0xb6, 0x1b, 0xb0, 0xd6, 0x65, 0x02, 0xbb, 0xb0, 0xd6, 0xb0, 0xd6, 0x72, 0x5b,
		0x49, 0x22, 0x34, 0x89, 0xd0, 0x3e, 0x0b, 0x29, 0x05, 0x5c, 0xf8, 0x2d, 0xf8, 0x2d, 0xf8, 0x2d,
		0xf8, 0x2d, 0xf8, 0x2d, 0xf8, 0x2d, 0xf8, 0x2d, 0x85, 0xf1, 0x5b, 0x28, 0xe0, 0xc2, 0x51, 0xc0,
		0x51, 0xc0, 0x51, 0xc0, 0x51, 0x58, 0x57, 0x47, 0x81, 0xb4, 0x3c, 0xd2, 0xf2, 0x66, 0xb7, 0x8b,
		0xb4, 0x3c, 0xd2, 0xf2, 0x48, 0xcb, 0x23, 0x2d, 0x8f, 0xb4, 0x3c, 0x90, 0xe2, 0x48, 0x26, 0x28,
		0xe0, 0x02, 0x29, 0x82, 0x14, 0x41, 0x8a, 0x20, 0x45, 0x90, 0x22, 0x48, 0x11, 0xa4, 0x08, 0x52,
		0x04, 0x29, 0x82, 0x14, 0x41, 0x8a, 0x20, 0xc5, 0x42, 0x21, 0x45, 0x0a, 0xb8, 0x96, 0x58, 0xcf,
		0xd7, 0x02, 0x2e, 0x86, 0x54, 0x5b, 0x89, 0xde, 0x5a, 0x0e, 0xa9, 0xd6, 0x1f, 0xc0, 0xb8, 0x99,
		0x7b, 0x4e, 0xf5, 0xed, 0x3b, 0x9e, 0x8f, 0x5e, 0x71, 0x8d, 0x27, 0x73, 0x2a, 0x8f, 0x9c, 0xb3,
		0x19, 0x35, 0xc7, 0x34, 0xce, 0xe5, 0x68, 0x33, 0x86, 0x53, 0x17, 0xc3, 0x61, 0x66, 0x38, 0xf5,
		0xdc, 0x9d, 0x51, 0x9f, 0xc5, 0x69, 0x33, 0xc3, 0x7f, 0xe6, 0x76, 0x5a, 0xcc, 0xf2, 0x7f, 0xa8,
		0x36, 0xb7, 0x99, 0xcc, 0xe9, 0xb1, 0x3a, 0x75, 0xc5, 0x59, 0x50, 0xd7, 0xad, 0xaa, 0x6e, 0xcb,
		0x81, 0xa7, 0xcd, 0x62, 0x09, 0x77, 0x61, 0xdc, 0x66, 0x94, 0xa4, 0x71, 0xfa, 0xdd, 0x26, 0x8e,
		0x30, 0xf1, 0x2c, 0x0d, 0x38, 0xd9, 0xca, 0x49, 0xf6, 0x69, 0xaf, 0xc2, 0x7e, 0x64, 0x1f, 0x1f,
		0x3f, 0x7a, 0x7d, 0x52, 0xbf, 0xb8, 0xfd, 0x7f, 0x1f, 0xfe, 0x79, 0x6e, 0x56, 0x72, 0xf5, 0x31,
		0x6c, 0x0f, 0xa2, 0x7e, 0xe5, 0xe5, 0xe6, 0x27, 0x33, 0x22, 0xce, 0x11, 0xcb, 0x7d, 0xba, 0xfb,
		0xf1, 0xfc, 0xac, 0x7e, 0x72, 0xfe, 0xb1, 0x56, 0xff, 0xe3, 0xec, 0xe4, 0xb7, 0xa3, 0x8b, 0x0f,
		0x86, 0xf1, 0xcb, 0x67, 0xa5, 0xdf, 0xdd, 0x93, 0xb3, 0x7f, 0x5c, 0x7c, 0x38, 0xfa, 0x70, 0xcc,
		0xa6, 0xca, 0x6d, 0xea, 0x50, 0x58, 0x4f, 0x8f, 0x5e, 0x1d, 0x9f, 0x1e, 0xff, 0x8e, 0xd0, 0x2a,
		0x08, 0x6d, 0xf5, 0x56, 0x25, 0x7c, 0x3c, 0x3f, 0xbd, 0x60, 0x57, 0x15, 0x54, 0x41, 0xfd, 0xe2,
		0xfc, 0x35, 0x1b, 0xab, 0x60, 0xc1, 0xf6, 0x51, 0x06, 0x2a, 0xca, 0x76, 0x1f, 0x65, 0xab, 0xad,
		0x6c, 0x8f, 0x3f, 0x9e, 0x9f, 0xb1, 0xab, 0xc2, 0x52, 0x8b, 0xb4, 0x8a, 0xef, 0xeb, 0xc5, 0xfb,
		0x0f, 0xc7, 0xf5, 0xf3, 0x77, 0xa7, 0x27, 0xbf, 0xfd, 0x73, 0x88, 0x19, 0xd8, 0x5b, 0x15, 0x24,
		0xf6, 0xf6, 0x8f, 0xd3, 0x0f, 0xc8, 0xae, 0x06, 0x6c, 0x78, 0x7d, 0xfa, 0xee, 0x7f, 0x2e, 0xce,
		0x8f, 0x7f, 0x63, 0x63, 0x35, 0x3c, 0x5b, 0xac, 0x98, 0xe8, 0xc6, 0x7e, 0x3c, 0x3f, 0x43, 0x64,
		0x2d, 0xec, 0xd8, 0x3e, 0x7b, 0x2b, 0xac, 0x67, 0xf1, 0xbd, 0x34, 0x71, 0xae, 0x0b, 0xff, 0xc0,
		0x64, 0xa5, 0xcb, 0xa2, 0xc7, 0xb5, 0x0a, 0xd9, 0x1c, 0x3e, 0x4a, 0xc2, 0xcf, 0xed, 0xa8, 0x69,
		0x97, 0x4d, 0x30, 0x5e, 0x50, 0xbb, 0xb9, 0xf3, 0x5d, 0xdf, 0xbe, 0x56, 0xd8, 0xee, 0x93, 0xb7,
		0xb0, 0xe4, 0x42, 0xe4, 0x2d, 0x88, 0x4a, 0x07, 0x79, 0x0b, 0xe4, 0x2d, 0xfc, 0x62, 0xc7, 0xec,
		0xf3, 0x16, 0x3e, 0x77, 0x3a, 0xed, 0x28, 0x4c, 0x2c, 0x73, 0x16, 0x76, 0xc8, 0xef, 0xd7, 0x17,
		0xa9, 0x75, 0xcc, 0xef, 0xd7, 0x1c, 0xff, 0x53, 0x8c, 0xb4, 0xf9, 0xab, 0x5e, 0xd8, 0x88, 0x5a,
		0x83, 0x76, 0xd0, 0x8b, 0xfa, 0x69, 0xd8, 0x4b, 0xf5, 0x13, 0xe8, 0x67, 0x56, 0x24, 0x95, 0xde,
		0x95, 0x2f, 0x45, 0x2a, 0x7d, 0xf1, 0x7c, 0x25, 0x52, 0xe9, 0xe7, 0xa3, 0x37, 0xed, 0x54, 0x7a,
		0xe5, 0x1a, 0xa3, 0x99, 0x6b, 0xa9, 0x5a, 0x6b, 0x64, 0xa4, 0x28, 0x01, 0xa1, 0x80, 0x50, 0x40,
		0x68, 0xb9, 0x41, 0xa8, 0xd9, 0x4c, 0x34, 0x2b, 0xde, 0x71, 0xe6, 0x7e, 0xdb, 0xf0, 0x8f, 0x77,
		0x1b, 0x6a, 0xcb, 0x43, 0x3e, 0x34, 0x05, 0x74, 0x79, 0x2b, 0xb2, 0x89, 0x70, 0x65, 0x2a, 0x9c,
		0x9b, 0x0c, 0xe7, 0xa6, 0xc3, 0xa9, 0x09, 0xb1, 0x31, 0x25, 0x46, 0x26, 0x65, 0xb2, 0x93, 0xee,
		0x7a, 0xbc, 0xd9, 0xf1, 0x9c, 0x33, 0x9e, 0xf8, 0x0e, 0x2d, 0x76, 0x3c, 0xf0, 0x6a, 0xd6, 0xb8,
		0xc5, 0xce, 0x43, 0x8e, 0x8e, 0x39, 0xe9, 0xf3, 0x4f, 0x8d, 0x39, 0xe9, 0xb9, 0xdd, 0xbf, 0x2a,
		0x8c, 0x00, 0x8c, 0x00, 0x8c, 0x00, 0x8c, 0xc0, 0xf2, 0x0b, 0x85, 0xcd, 0xaf, 0x51, 0x2f, 0x8d,
		0xfb, 0x2e, 0x48, 0x81, 0xa9, 0xb5, 0xc1, 0xe7, 0xe0, 0x73, 0xf0, 0x39, 0xf8, 0x1c, 0x7c, 0x0e,
		0x3e, 0x2f, 0x10, 0x3e, 0x7f, 0x06, 0x65, 0x2f, 0xe6, 0xf1, 0x40, 0xd9, 0xe3, 0x12, 0xe0, 0x12,
		0xe0, 0x12, 0xe0, 0x12, 0xe0, 0x12, 0xe0, 0x12, 0xfc, 0x6c, 0xcf, 0x7a, 0x51, 0x23, 0x8a, 0xbf,
		0xba, 0xf0, 0x09, 0x26, 0x2b, 0x63, 0x9c, 0x31, 0xce, 0x18, 0x67, 0x8c, 0x33, 0xc6, 0x19, 0xe3,
		0x5c, 0x20, 0xe3, 0x4c, 0x3c, 0x7d, 0x89, 0xf5, 0x7c, 0x8e, 0xa7, 0x33, 0xb6, 0xc6, 0x4a, 0xfc,
		0xd6, 0xb1, 0xac, 0xcd, 0xa8, 0xc4, 0x6a, 0x33, 0xef, 0xe8, 0x9a, 0x37, 0xd9, 0x7b, 0xbe, 0xcf,
		0x5e, 0x73, 0x8d, 0xeb, 0xf0, 0xe2, 0xee, 0xd7, 0x5a, 0xd0, 0x0e, 0x3f, 0x47, 0xed, 0xa8, 0x19,
		0x0c, 0x92, 0xb8, 0x11, 0xf6, 0x0d, 0x6a, 0xf1, 0x1e, 0x5d, 0x95, 0x7a, 0x3c, 0x57, 0x58, 0x87,
		0x7a, 0xbc, 0xe2, 0x61, 0x15, 0xea, 0xf1, 0xe6, 0xee, 0x8c, 0x7a, 0x3d, 0xde, 0x48, 0xa2, 0x82,
		0x76, 0x7c, 0x1d, 0xa7, 0x76, 0x29, 0x78, 0xf7, 0x56, 0xa5, 0x36, 0xcf, 0x57, 0xc2, 0x88, 0x4c,
		0xbc, 0xf2, 0x11, 0x42, 0x64, 0xe2, 0x79, 0xa7, 0x84, 0x27, 0x0b, 0x19, 0x15, 0x47, 0xcf, 0x5c,
		0x6f, 0x93, 0x22, 0x69, 0x63, 0x85, 0x6c, 0xae, 0x98, 0x5d, 0x28, 0x68, 0x77, 0x8a, 0xda, 0x95,
		0xc2, 0x76, 0xae, 0xb8, 0x9d, 0x2b, 0x70, 0xa7, 0x8a, 0xdc, 0x46, 0xa1, 0x1b, 0x29, 0x76, 0x73,
		0x05, 0x3f, 0x59, 0xf0, 0x3a, 0xfc, 0x16, 0x8c, 0xa4, 0x76, 0x38, 0xf0, 0xca, 0x51, 0x73, 0xd3,
		0x7b, 0x6f, 0x61, 0x2c, 0xbc, 0xb6, 0x61, 0x5d, 0x67, 0xc6, 0xc0, 0xa5, 0x51, 0x70, 0x6f, 0x1c,
		0x5c, 0x1b, 0x09, 0x6f, 0x8c, 0x85, 0x37, 0x46, 0xc3, 0x0b, 0xe3, 0x61, 0x6b, 0x44, 0x8c, 0x8d,
		0xc9, 0x64, 0x87, 0xcd, 0xc3, 0xc4, 0x33, 0xf7, 0x7d, 0x10, 0x27, 0xe9, 0x6e, 0xd5, 0xc5, 0x7d,
		0xcf, 0xb4, 0xfb, 0x81, 0x83, 0xa5, 0xdf, 0x87, 0xc9, 0x55, 0x64, 0x3a, 0x44, 0x72, 0xfa, 0xc7,
		0x8d, 0x7e, 0x1b, 0x7e, 0xf8, 0xdb, 0x38, 0x71, 0xa6, 0x60, 0x1d, 0x9b, 0xf5, 0x99, 0xd7, 0x18,
		0x8e, 0x12, 0xf5, 0xe0, 0x3d, 0x5e, 0xf7, 0xc2, 0x46, 0x1a, 0x77, 0x92, 0xdf, 0xe3, 0xab, 0x38,
		0xbd, 0xf5, 0xf4, 0xb6, 0x9d, 0xbd, 0xcf, 0xcd, 0x33, 0x87, 0xa2, 0x19, 0x7e, 0x43, 0x34, 0x1f,
		0x88, 0x66, 0xad, 0x7a, 0x58, 0x3b, 0xdc, 0x3f, 0xa8, 0x1e, 0xee, 0x21, 0xa3, 0x6e, 0x1c, 0x02,
		0x77, 0xab, 0x5e, 0x6e, 0x94, 0xf3, 0xfb, 0x0c, 0x75, 0xcc, 0xad, 0x1f, 0xff, 0x35, 0x4a, 0xd2,
		0x20, 0x8d, 0xc2, 0x5e, 0xb3, 0xf3, 0x57, 0xe2, 0x0e, 0x46, 0xcf, 0xbc, 0x89, 0xb1, 0xa3, 0xe9,
		0xa8, 0x6c, 0x0a, 0x28, 0x0f, 0x94, 0x07, 0xca, 0x03, 0xe5, 0x81, 0xf2, 0x06, 0xf7, 0xdd, 0x3e,
		0xf3, 0xfb, 0xa1, 0x7a, 0x37, 0xca, 0x00, 0x2f, 0xb7, 0xd3, 0x92, 0x25, 0x93, 0x06, 0x69, 0x7c,
		0x1d, 0xf5, 0xdc, 0x79, 0x2c, 0xf7, 0x5f, 0x03, 0x77, 0x01, 0x77, 0x01, 0x77, 0x01, 0x77, 0x01,
		0x77, 0xa1, 0x34, 0xee, 0x42, 0x33, 0x6a, 0xc4, 0xd7, 0x61, 0x7b, 0xbf, 0xe6, 0xd2, 0x61, 0xa8,
		0x3a, 0x58, 0x7b, 0x86, 0xcc, 0xaa, 0x12, 0x82, 0xb0, 0xfb, 0x70, 0x9f, 0x42, 0x10, 0x55, 0x42,
		0x10, 0x9b, 0x84, 0x20, 0xee, 0x44, 0xd3, 0xa3, 0x10, 0xc4, 0x2e, 0xa2, 0xb9, 0x49, 0xe4, 0x81,
		0xc8, 0x43, 0x41, 0x41, 0xfc, 0x5f, 0x61, 0x2f, 0x89, 0x93, 0xab, 0x20, 0xfd, 0xd2, 0x8b, 0xfa,
		0x5f, 0x3a, 0xed, 0x66, 0xd0, 0x6d, 0xa4, 0xee, 0xc0, 0xfc, 0xe3, 0xaf, 0x03, 0xa8, 0x07, 0xd4,
		0x03, 0xea, 0x01, 0xf5, 0x80, 0xfa, 0xd2, 0x80, 0xfa, 0x6e, 0xd4, 0x6b, 0x44, 0x49, 0x1a, 0x5e,
		0x45, 0x0e, 0x51, 0xfd, 0x1e, 0x78, 0x7a, 0x3d, 0xf1, 0x34, 0x29, 0x7d, 0xe0, 0x69, 0x4f, 0xf1,
		0xb4, 0x2f, 0xa2, 0xb9, 0xb3, 0x8d, 0x70, 0x82, 0xa8, 0xcb, 0x82, 0xa8, 0x4b, 0x55, 0xe1, 0x67,
		0xdc, 0x38, 0x6d, 0xb2, 0xae, 0x47, 0x1d, 0xad, 0x1e, 0x6b, 0x54, 0xb4, 0x35, 0xdd, 0x88, 0xc3,
		0x64, 0x42, 0x99, 0x9d, 0x78, 0x59, 0xb4, 0xe1, 0xb5, 0x99, 0x5c, 0x36, 0x83, 0x04, 0x2c, 0x26,
		0x98, 0x3d, 0x34, 0xb2, 0xe6, 0xe5, 0xfa, 0x55, 0xca, 0xf5, 0xcb, 0x43, 0xdd, 0x50, 0xae, 0x4f,
		0xb9, 0xbe, 0xd8, 0x4e, 0x52, 0xae, 0x4f, 0xb9, 0x7e, 0xf9, 0x8c, 0x82, 0x7b, 0xe3, 0xe0, 0xda,
		0x48, 0x78, 0x63, 0x2c, 0xbc, 0x31, 0x1a, 0x5e, 0x18, 0x0f, 0x37, 0xd8, 0x9a, 0x72, 0x7d, 0x73,
		0xed, 0x4e, 0xb9, 0xbe, 0xe1, 0x87, 0xc3, 0xed, 0xdf, 0xbd, 0x06, 0xdc, 0xbe, 0x6b, 0xf5, 0x77,
		0x5f, 0x34, 0xe1, 0xf6, 0x67, 0x44, 0x93, 0x72, 0x7d, 0xd7, 0x0e, 0x81, 0xbb, 0x55, 0x49, 0x9a,
		0xcb, 0x2f, 0xb6, 0x94, 0xeb, 0x4f, 0xd8, 0x0b, 0xca, 0xf5, 0x81, 0xf2, 0x40, 0x79, 0xa0, 0x3c,
		0x50, 0xbe, 0xb4, 0x50, 0x9e, 0x72, 0xfd, 0x52, 0x38, 0x2d, 0x94, 0xeb, 0xe3, 0x2e, 0xe0, 0x2e,
		0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0x68, 0xde, 0x77, 0xca, 0xf5, 0x29, 0xd7, 0x77, 0xa0, 0x5a,
		0x28, 0xd7, 0xbf, 0x7b, 0x0d, 0x42, 0x10, 0xae, 0xf5, 0xf0, 0x7d, 0xd1, 0xa4, 0x5c, 0x1f, 0xd1,
		0xf4, 0xc5, 0x21, 0x71, 0xb7, 0x2a, 0x91, 0x87, 0xfc, 0x62, 0x4b, 0xb9, 0x3e, 0xa0, 0x1e, 0x50,
		0x0f, 0xa8, 0x07, 0xd4, 0x03, 0xea, 0x2d, 0xef, 0x3b, 0xe5, 0xfa, 0xe0, 0x69, 0x77, 0xa0, 0x85,
		0x94, 0x3e, 0xf0, 0xb4, 0xa7, 0x78, 0x9a, 0x72, 0x7d, 0x10, 0x35, 0x88, 0xba, 0x90, 0x2b, 0x51,
		0xae, 0xef, 0x51, 0xb9, 0xfe, 0xa8, 0x0a, 0xbc, 0x2c, 0xd5, 0xfa, 0x1b, 0x05, 0x96, 0x5b, 0x6b,
		0x79, 0x2d, 0x94, 0x9c, 0x56, 0x4c, 0xfa, 0x30, 0xf4, 0x06, 0x8d, 0x34, 0xc9, 0x90, 0xd7, 0xd9,
		0xe8, 0x03, 0x4f, 0xb2, 0xef, 0xab, 0x9f, 0x67, 0x5f, 0x55, 0x7f, 0x75, 0xd5, 0xad, 0x9f, 0x65,
		0xdf, 0x52, 0x3f, 0x6a, 0xc5, 0x17, 0x61, 0x2b, 0xae, 0x9f, 0x74, 0xbf, 0xd6, 0x4e, 0x47, 0xef,
		0xff, 0xc7, 0xe8, 0xf5, 0xeb, 0x23, 0xba, 0xe8, 0x74, 0xf8, 0xf6, 0x1b, 0xc5, 0x94, 0x7a, 0x9d,
		0x27, 0x2b, 0xdd, 0x23, 0xab, 0xfb, 0xe3, 0xfb, 0xbd, 0x51, 0xbc, 0x2a, 0xc2, 0x57, 0x44, 0xe7,
		0x5a, 0xc8, 0x0b, 0xad, 0x82, 0xc0, 0x56, 0x86, 0x27, 0x37, 0x3e, 0x31, 0x2d, 0x71, 0x9d, 0xd0,
		0x48, 0xf7, 0x56, 0x53, 0xba, 0x7e, 0xba, 0x2d, 0x5e, 0xd4, 0x69, 0x7f, 0x0b, 0x7a, 0xdf, 0x8e,
		0xc6, 0xb7, 0xa2, 0xeb, 0xcd, 0x69, 0x79, 0x73, 0xfa, 0xdd, 0x94, 0x66, 0x2f, 0x96, 0xc1, 0xd5,
		0x6e, 0xa1, 0x52, 0x69, 0x8c, 0xef, 0xbc, 0xb2, 0x10, 0x8f, 0xaf, 0x65, 0xb6, 0x9e, 0xb2, 0x40,
		0xd9, 0xf4, 0xc2, 0x32, 0x8b, 0x93, 0x5a, 0xc6, 0x45, 0xed, 0xe3, 0xa0, 0xd6, 0x71, 0x4f, 0x67,
		0x71, 0x4e, 0x67, 0x71, 0x4d, 0x27, 0x71, 0xcc, 0x62, 0x33, 0x05, 0x56, 0xbd, 0xab, 0x2a, 0xfd,
		0x28, 0x69, 0x06, 0xcd, 0x51, 0xad, 0x69, 0xd0, 0xeb, 0x0c, 0x9c, 0xf4, 0x29, 0x9c, 0x7d, 0x07,
		0xab, 0x16, 0x61, 0x6e, 0x8a, 0x6c, 0x8d, 0x43, 0x1c, 0xe6, 0x09, 0x35, 0x34, 0x4b, 0x2c, 0xb5,
		0x21, 0x71, 0x6e, 0x50, 0x9c, 0x1a, 0x16, 0x1b, 0x03, 0x63, 0x64, 0x68, 0x26, 0x3b, 0x69, 0x9e,
		0x08, 0xe3, 0xb0, 0x08, 0xd6, 0xb8, 0xf8, 0x95, 0xa8, 0xc8, 0x2f, 0x2e, 0xf1, 0x9a, 0x47, 0x45,
		0xc6, 0xd1, 0x10, 0x8b, 0xbe, 0xda, 0x8a, 0x91, 0x04, 0x45, 0xaa, 0xeb, 0x5e, 0x9c, 0xc8, 0x8c,
		0x2b, 0x30, 0x8c, 0x4e, 0xc1, 0x18, 0xc0, 0x18, 0xc0, 0x18, 0xc0, 0x18, 0x14, 0x81, 0x31, 0x30,
		0xa2, 0x6c, 0x67, 0xae, 0xb7, 0x09, 0x75, 0x6b, 0xac, 0x90, 0x41, 0xe8, 0x20, 0x74, 0x10, 0x3a,
		0x08, 0xdd, 0x27, 0x05, 0x3f, 0x59, 0x90, 0x71, 0x06, 0xd4, 0x3f, 0x6e, 0x96, 0xdf, 0x38, 0xb8,
		0x36, 0x12, 0xde, 0x18, 0x0b, 0x6f, 0x8c, 0x86, 0x17, 0xc6, 0xc3, 0xd6, 0x88, 0x18, 0x1b, 0x93,
		0xc9, 0x0e, 0x33, 0xce, 0x80, 0x71, 0x06, 0x96, 0x1f, 0x4e, 0xed, 0xe3, 0xdd, 0x6b, 0x50, 0xfb,
		0xe8, 0x5a, 0xfd, 0xdd, 0x17, 0x4d, 0x6a, 0x1f, 0x67, 0x44, 0x93, 0x71, 0x06, 0xae, 0x1d, 0x02,
		0x77, 0xab, 0xd2, 0x54, 0x28, 0xbf, 0xd8, 0x32, 0xce, 0x60, 0xc2, 0x5e, 0x30, 0xce, 0x00, 0x28,
		0x0f, 0x94, 0x07, 0xca, 0x03, 0xe5, 0x4b, 0x0b, 0xe5, 0x19, 0x67, 0x50, 0x0a, 0xa7, 0x85, 0x71,
		0x06, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0x9a, 0xf7, 0x9d, 0x71, 0x06,
		0x8c, 0x33, 0x70, 0xa0, 0x5a, 0x18, 0x67, 0x70, 0xf7, 0x1a, 0x84, 0x20, 0x5c, 0xeb, 0xe1, 0xfb,
		0xa2, 0xc9, 0x38, 0x03, 0x44, 0xd3, 0x17, 0x87, 0xc4, 0xdd, 0xaa, 0x44, 0x1e, 0xf2, 0x8b, 0x2d,
		0xe3, 0x0c, 0x00, 0xf5, 0x80, 0x7a, 0x40, 0x3d, 0xa0, 0x1e, 0x50, 0x6f, 0x79, 0xdf, 0x19, 0x67,
		0x00, 0x9e, 0x76, 0x07, 0x5a, 0x48, 0xe9, 0x03, 0x4f, 0x7b, 0x8a, 0xa7, 0x19, 0x67, 0x00, 0xa2,
		0x06, 0x51, 0x17, 0x72, 0x25, 0xc6, 0x19, 0xb8, 0x69, 0x88, 0x72, 0x6f, 0x8c, 0x81, 0x45, 0x77,
		0x14, 0x3b, 0xb1, 0xba, 0x31, 0xe9, 0x76, 0x1f, 0x3a, 0xe9, 0xe6, 0x37, 0x5c, 0xb6, 0xe4, 0x65,
		0xfa, 0x55, 0xca, 0xf4, 0xcb, 0x43, 0xd9, 0x50, 0xa6, 0x4f, 0x99, 0xbe, 0xd8, 0x4e, 0x52, 0xa6,
		0x4f, 0x99, 0x7e, 0xf9, 0x8c, 0x82, 0x7b, 0xe3, 0xe0, 0xda, 0x48, 0x78, 0x63, 0x2c, 0xbc, 0x31,
		0x1a, 0x5e, 0x18, 0x0f, 0x37, 0x98, 0x9a, 0x32, 0x7d, 0x73, 0xed, 0x4e, 0x99, 0xbe, 0xe1, 0x87,
		0xc3, 0xe9, 0xdf, 0xbd, 0x06, 0x9c, 0xbe, 0x6b, 0xf5, 0x77, 0x5f, 0x34, 0xe1, 0xf4, 0x67, 0x44,
		0x93, 0x32, 0x7d, 0xd7, 0x0e, 0x81, 0xbb, 0x55, 0x49, 0x96, 0xcb, 0x2f, 0xb6, 0x94, 0xe9, 0x4f,
		0xd8, 0x0b, 0xca, 0xf4, 0x81, 0xf2, 0x40, 0x79, 0xa0, 0x3c, 0x50, 0xbe, 0xb4, 0x50, 0x9e, 0x32,
		0xfd, 0x52, 0x38, 0x2d, 0x94, 0xe9, 0xe3, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e,
		0x68, 0xde, 0x77, 0xca, 0xf4, 0x29, 0xd3, 0x77, 0xa0, 0x5a, 0x28, 0xd3, 0xbf, 0x7b, 0x0d, 0x42,
		0x10, 0xae, 0xf5, 0xf0, 0x7d, 0xd1, 0xa4, 0x4c, 0x1f, 0xd1, 0xf4, 0xc5, 0x21, 0x71, 0xb7, 0x2a,
		0x91, 0x87, 0xfc, 0x62, 0x4b, 0x99, 0x3e, 0xa0, 0x1e, 0x50, 0x0f, 0xa8, 0x07, 0xd4, 0x03, 0xea,
		0x2d, 0xef, 0x3b, 0x65, 0xfa, 0xe0, 0x69, 0x77, 0xa0, 0x85, 0x94, 0x3e, 0xf0, 0xb4, 0xa7, 0x78,
		0x9a, 0x32, 0x7d, 0x10, 0x35, 0x88, 0xba, 0x90, 0x2b, 0x51, 0xa6, 0xef, 0x41, 0x99, 0xfe, 0xa8,
		0xfa, 0xbb, 0x2c, 0x55, 0xfa, 0x1b, 0x05, 0x96, 0x57, 0x6b, 0x39, 0x2d, 0x84, 0x7c, 0x56, 0x4c,
		0xfa, 0x2e, 0xf4, 0x06, 0x8d, 0x34, 0xc9, 0x90, 0xd6, 0xd9, 0xe8, 0xc3, 0x4e, 0xb2, 0xef, 0xaa,
		0x9f, 0x67, 0x5f, 0x53, 0x7f, 0x75, 0xd5, 0xad, 0x9f, 0x65, 0xdf, 0x50, 0x3f, 0x6a, 0xc5, 0x17,
		0x61, 0x2b, 0xae, 0x9f, 0x74, 0xbf, 0xd6, 0xfe, 0x18, 0xbd, 0x77, 0x7d, 0xc4, 0x0b, 0x9d, 0x0e,
		0x5f, 0x7b, 0xa3, 0x98, 0x62, 0xae, 0x28, 0xe2, 0x46, 0xed, 0x2d, 0x4c, 0xdb, 0x5a, 0x18, 0xb5,
		0xb3, 0x30, 0x6b, 0x63, 0x61, 0x49, 0x6d, 0xda, 0x53, 0x99, 0xd6, 0xd4, 0xa5, 0x33, 0xaa, 0xd2,
		0x19, 0x35, 0xe9, 0x84, 0x8a, 0x2c, 0xb6, 0xd1, 0xb7, 0x6a, 0x3f, 0x51, 0xe9, 0x47, 0x49, 0x33,
		0x68, 0x8e, 0xca, 0x45, 0x82, 0x5e, 0x67, 0xe0, 0xa4, 0xd5, 0xd0, 0xec, 0x3b, 0x58, 0x75, 0xf9,
		0x70, 0x53, 0x27, 0x63, 0xcc, 0x52, 0x98, 0xc7, 0xc4, 0xe8, 0x77, 0x54, 0x6a, 0x43, 0xe2, 0xdc,
		0xa0, 0x38, 0x35, 0x2c, 0xe5, 0x64, 0x43, 0xcc, 0x63, 0x59, 0x0e, 0xeb, 0x58, 0x8c, 0xeb, 0x57,
		0x20, 0x38, 0x20, 0x38, 0x16, 0x21, 0x38, 0x0c, 0x38, 0x37, 0x45, 0x8a, 0x60, 0xa3, 0x40, 0xa2,
		0x67, 0x25, 0x72, 0xbe, 0x8a, 0x5a, 0x45, 0x95, 0xcf, 0x11, 0xa1, 0xcd, 0x74, 0xee, 0x81, 0xbc,
		0x94, 0x2a, 0x48, 0x68, 0x25, 0xee, 0x7e, 0xdd, 0x0f, 0xda, 0xe1, 0xe7, 0xa8, 0x1d, 0x35, 0x27,
		0x47, 0xa6, 0x25, 0xa7, 0x13, 0x3b, 0xfc, 0xe8, 0xaa, 0x4a, 0xf7, 0x4f, 0x97, 0x20, 0x53, 0xc7,
		0x3b, 0xff, 0x8f, 0xbd, 0xb7, 0x6b, 0x6e, 0xdb, 0x4a, 0xf6, 0x7e, 0xef, 0xf5, 0x29, 0x5c, 0xac,
		0x7d, 0x91, 0x54, 0x85, 0xb1, 0x44, 0xeb, 0x25, 0xca, 0x1d, 0x25, 0xd3, 0x0e, 0xf7, 0x50, 0x14,
		0x8f, 0x28, 0x79, 0x92, 0xe3, 0xf1, 0x46, 0xc1, 0x14, 0x24, 0xa3, 0x86, 0x02, 0x79, 0x40, 0x50,
		0x89, 0x6b, 0xe2, 0xef, 0x7e, 0x8a, 0x24, 0x08, 0x0a, 0xa2, 0x35, 0x7e, 0x21, 0xba, 0x7b, 0x01,
		0xfc, 0xb9, 0x9e, 0xda, 0xa3, 0xc7, 0xb1, 0xd0, 0x0b, 0x0b, 0xbd, 0xfa, 0xdf, 0xff, 0x7e, 0x5b,
		0x1a, 0xfc, 0x46, 0x8f, 0xcf, 0x68, 0xf1, 0x17, 0x75, 0xbe, 0xa2, 0xce, 0x4f, 0x54, 0xf9, 0x48,
		0xb9, 0x10, 0x57, 0x3a, 0xa0, 0x55, 0xcb, 0xa5, 0x87, 0xd4, 0xd2, 0x09, 0x8a, 0x49, 0x29, 0xf5,
		0xac, 0xc2, 0x2e, 0x59, 0x85, 0xf2, 0x04, 0x85, 0xc8, 0x2a, 0x90, 0x55, 0x30, 0x37, 0xc2, 0x99,
		0xa0, 0xc1, 0xd2, 0x86, 0x28, 0x67, 0x12, 0x52, 0xb9, 0x15, 0xbf, 0xb5, 0x80, 0x28, 0x7e, 0x05,
		0x0c, 0xb6, 0xb9, 0xe1, 0x36, 0x37, 0xe0, 0xa6, 0x86, 0x5c, 0xc7, 0xa0, 0x2b, 0x19, 0x76, 0x75,
		0x03, 0x9f, 0x09, 0xe4, 0xd6, 0x02, 0xda, 0x1c, 0x9f, 0x55, 0x1f, 0x1c, 0xac, 0x41, 0xc2, 0x19,
		0xb0, 0x70, 0x06, 0x34, 0x9c, 0x00, 0x0f, 0x5d, 0x10, 0x51, 0x06, 0x93, 0x6c, 0x87, 0xb9, 0xb5,
		0x80, 0x5b, 0x0b, 0x34, 0x5f, 0x9c, 0x16, 0xc7, 0xd5, 0x32, 0x68, 0x71, 0xb4, 0x36, 0x7f, 0x79,
		0xd5, 0xa4, 0xc5, 0x71, 0x4d, 0x35, 0xb9, 0xb5, 0xc0, 0xda, 0x21, 0xb0, 0x93, 0xca, 0xec, 0xa0,
		0xcd, 0xd5, 0x96, 0x5b, 0x0b, 0xb2, 0xe8, 0x05, 0xb7, 0x16, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79,
		0xa8, 0x7c, 0x65, 0xa9, 0x3c, 0xb7, 0x16, 0x54, 0xc2, 0x69, 0xe1, 0xd6, 0x02, 0xdc, 0x05, 0xdc,
		0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xc9, 0xf3, 0xce, 0xad, 0x05, 0xdc, 0x5a, 0x60, 0x60,
		0x5a, 0xb8, 0xb5, 0x60, 0xb5, 0x0c, 0x52, 0x10, 0xd6, 0x76, 0x38, 0xaf, 0x9a, 0xdc, 0x5a, 0x80,
		0x6a, 0xba, 0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0, 0xb9, 0xda, 0x72, 0x6b, 0x01, 0xa4, 0x1e,
		0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b, 0xb7, 0x16, 0xc0, 0xa7, 0xed, 0x48,
		0x0b, 0x25, 0x7d, 0xf0, 0x69, 0x47, 0xf9, 0x34, 0xb7, 0x16, 0xc0, 0xa8, 0x61, 0xd4, 0xa5, 0x94,
		0xc4, 0xad, 0x05, 0x9a, 0x93, 0xac, 0xd6, 0x06, 0x15, 0xe5, 0x6f, 0x2f, 0x48, 0xdb, 0xc0, 0xab,
		0x32, 0xdd, 0x4f, 0x65, 0xd8, 0xbd, 0x6f, 0x32, 0xf9, 0x57, 0x61, 0x1a, 0xfb, 0x63, 0x90, 0x55,
		0x6f, 0xd7, 0x6f, 0xd0, 0xae, 0x5f, 0x9d, 0xd0, 0x0d, 0xed, 0xfa, 0xb4, 0xeb, 0x17, 0xb6, 0x93,
		0xb4, 0xeb, 0xd3, 0xae, 0x5f, 0x3d, 0x50, 0xb0, 0x07, 0x07, 0x6b, 0x90, 0x70, 0x06, 0x2c, 0x9c,
		0x01, 0x0d, 0x27, 0xc0, 0xc3, 0x86, 0x5b, 0xd3, 0xae, 0xaf, 0x6e, 0xdd, 0x69, 0xd7, 0x57, 0x7c,
		0x71, 0x62, 0xfb, 0xab, 0x65, 0x10, 0xdb, 0xb7, 0x36, 0x7f, 0x79, 0xd5, 0x24, 0xb6, 0xbf, 0xa6,
		0x9a, 0xb4, 0xeb, 0x5b, 0x3b, 0x04, 0x76, 0x52, 0x29, 0x9a, 0xdb, 0x5c, 0x6d, 0x69, 0xd7, 0xcf,
		0xa2, 0x17, 0xb4, 0xeb, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x65, 0xa9, 0x3c, 0xed,
		0xfa, 0x95, 0x70, 0x5a, 0x68, 0xd7, 0xc7, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d,
		0x90, 0x3c, 0xef, 0xb4, 0xeb, 0xd3, 0xae, 0x6f, 0x60, 0x5a, 0x68, 0xd7, 0x5f, 0x2d, 0x83, 0x14,
		0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0xed, 0xfa, 0xa8, 0xa6, 0x2b, 0x0e, 0x89, 0x9d, 0x54, 0x32,
		0x0f, 0x9b, 0xab, 0x2d, 0xed, 0xfa, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xd7,
		0x3c, 0xef, 0xb4, 0xeb, 0xc3, 0xa7, 0xed, 0x48, 0x0b, 0x25, 0x7d, 0xf0, 0x69, 0x47, 0xf9, 0x34,
		0xed, 0xfa, 0x30, 0x6a, 0x18, 0x75, 0x29, 0x25, 0xd1, 0xae, 0xef, 0x50, 0xbb, 0xfe, 0xa2, 0x0b,
		0xbc, 0x2a, 0xdd, 0xfa, 0x3b, 0x25, 0xd6, 0x5b, 0x6d, 0x7d, 0x2d, 0x95, 0x9e, 0xd6, 0x54, 0xe6,
		0x30, 0xc4, 0xd3, 0x41, 0x12, 0xa5, 0xcc, 0xab, 0xbb, 0x78, 0xc1, 0x76, 0xfa, 0x7e, 0x5e, 0x2f,
		0x7d, 0x2b, 0xef, 0xe4, 0x76, 0xec, 0x75, 0xd3, 0x77, 0xf1, 0x9a, 0x37, 0x61, 0xdf, 0xbf, 0x09,
		0xbd, 0xf6, 0xf8, 0xfe, 0xb0, 0xb3, 0x58, 0xff, 0xd5, 0x62, 0xf9, 0xde, 0x22, 0x5c, 0xd4, 0x99,
		0xaf, 0x7e, 0xa7, 0x9c, 0x5a, 0x2f, 0xf3, 0x64, 0xa1, 0x73, 0xa4, 0x75, 0x7e, 0x5c, 0x3f, 0x37,
		0x82, 0x47, 0xa5, 0xe0, 0x23, 0x22, 0x73, 0x2c, 0x8a, 0x57, 0x5a, 0x01, 0x85, 0xad, 0xcd, 0xbf,
		0xdc, 0xf2, 0x8b, 0x49, 0xa9, 0x6b, 0x16, 0x46, 0xca, 0x49, 0x13, 0x3a, 0x7e, 0xb2, 0x23, 0x5e,
		0xc4, 0xc3, 0xfe, 0x1a, 0xe1, 0x7d, 0xbd, 0x30, 0xbe, 0x56, 0xb8, 0x5e, 0x3d, 0x2c, 0xaf, 0x1e,
		0x7e, 0x57, 0x0d, 0xb3, 0x97, 0x0b, 0x70, 0xa5, 0x47, 0xa8, 0xd4, 0x06, 0xcb, 0x33, 0x2f, 0xac,
		0xc4, 0xcb, 0x63, 0x99, 0xca, 0x13, 0x56, 0x28, 0x9d, 0x59, 0x58, 0x6a, 0x79, 0x52, 0xcd, 0xbc,
		0xa8, 0x7e, 0x1e, 0x54, 0x3b, 0xef, 0x69, 0x96, 0xe7, 0x34, 0xcb, 0x6b, 0x9a, 0xe4, 0x31, 0xcb,
		0x1d, 0x29, 0xd0, 0x9a, 0x5d, 0x55, 0x9b, 0x04, 0xd1, 0x75, 0xfd, 0x7a, 0xd1, 0x6b, 0x5a, 0x8f,
		0x47, 0x53, 0x93, 0x39, 0x85, 0xeb, 0x6b, 0xd0, 0x1a, 0x11, 0x66, 0xd3, 0x64, 0xab, 0x9c, 0xe2,
		0x50, 0x2f, 0xa8, 0x61, 0x58, 0x62, 0xa5, 0x81, 0xc4, 0x1c, 0x50, 0x4c, 0x81, 0x45, 0x07, 0x60,
		0x94, 0x80, 0x26, 0xdb, 0x49, 0xf5, 0x42, 0x18, 0xc3, 0x26, 0x58, 0xe5, 0xe6, 0x57, 0xb2, 0x22,
		0x5f, 0x38, 0xc4, 0x5b, 0x9e, 0x15, 0x59, 0x66, 0x43, 0x34, 0xe6, 0x6a, 0x0b, 0x66, 0x12, 0x04,
		0x43, 0x5d, 0xb9, 0x3c, 0x91, 0x5a, 0xac, 0x40, 0x31, 0x3b, 0x45, 0xc4, 0x80, 0x88, 0x01, 0x11,
		0x03, 0x22, 0x06, 0x65, 0x88, 0x18, 0x28, 0x85, 0x6c, 0xd7, 0x8e, 0xb7, 0x4a, 0xe8, 0x56, 0xd9,
		0x20, 0xc3, 0xd0, 0x61, 0xe8, 0x30, 0x74, 0x18, 0xba, 0x4b, 0x06, 0x3e, 0x13, 0xc8, 0x75, 0x06,
		0xf4, 0x3f, 0x3e, 0xab, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x33, 0x60, 0xe1, 0x0c, 0x68, 0x38, 0x01,
		0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x73, 0x9d, 0x01, 0xd7, 0x19, 0x68, 0xbe, 0x38,
		0xbd, 0x8f, 0xab, 0x65, 0xd0, 0xfb, 0x68, 0x6d, 0xfe, 0xf2, 0xaa, 0x49, 0xef, 0xe3, 0x9a, 0x6a,
		0x72, 0x9d, 0x81, 0xb5, 0x43, 0x60, 0x27, 0x95, 0xa1, 0x42, 0x9b, 0xab, 0x2d, 0xd7, 0x19, 0x64,
		0xd1, 0x0b, 0xae, 0x33, 0x80, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xca, 0x52, 0x79, 0xae,
		0x33, 0xa8, 0x84, 0xd3, 0xc2, 0x75, 0x06, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8,
		0x0b, 0x92, 0xe7, 0x9d, 0xeb, 0x0c, 0xb8, 0xce, 0xc0, 0xc0, 0xb4, 0x70, 0x9d, 0xc1, 0x6a, 0x19,
		0xa4, 0x20, 0xac, 0xed, 0x70, 0x5e, 0x35, 0xb9, 0xce, 0x00, 0xd5, 0x74, 0xc5, 0x21, 0xb1, 0x93,
		0x4a, 0xe6, 0x61, 0x73, 0xb5, 0xe5, 0x3a, 0x03, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87,
		0xd4, 0x6b, 0x9e, 0x77, 0xae, 0x33, 0x80, 0x4f, 0xdb, 0x91, 0x16, 0x4a, 0xfa, 0xe0, 0xd3, 0x8e,
		0xf2, 0x69, 0xae, 0x33, 0x80, 0x51, 0xc3, 0xa8, 0x4b, 0x29, 0x89, 0xeb, 0x0c, 0x6c, 0x06, 0xa2,
		0xe4, 0xae, 0x31, 0xd0, 0x98, 0x8e, 0xa2, 0xa7, 0x56, 0x9f, 0x54, 0xa6, 0xdd, 0xfb, 0x26, 0xd3,
		0xfc, 0xe6, 0x62, 0x2b, 0xde, 0xa6, 0xdf, 0xa0, 0x4d, 0xbf, 0x3a, 0x21, 0x1b, 0xda, 0xf4, 0x69,
		0xd3, 0x2f, 0x6c, 0x27, 0x69, 0xd3, 0xa7, 0x4d, 0xbf, 0x7a, 0xa0, 0x60, 0x0f, 0x0e, 0xd6, 0x20,
		0xe1, 0x0c, 0x58, 0x38, 0x03, 0x1a, 0x4e, 0x80, 0x87, 0x0d, 0xa7, 0xa6, 0x4d, 0x5f, 0xdd, 0xba,
		0xd3, 0xa6, 0xaf, 0xf8, 0xe2, 0xc4, 0xf4, 0x57, 0xcb, 0x20, 0xa6, 0x6f, 0x6d, 0xfe, 0xf2, 0xaa,
		0x49, 0x4c, 0x7f, 0x4d, 0x35, 0x69, 0xd3, 0xb7, 0x76, 0x08, 0xec, 0xa4, 0x52, 0x2c, 0xb7, 0xb9,
		0xda, 0xd2, 0xa6, 0x9f, 0x45, 0x2f, 0x68, 0xd3, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9,
		0xca, 0x52, 0x79, 0xda, 0xf4, 0x2b, 0xe1, 0xb4, 0xd0, 0xa6, 0x8f, 0xbb, 0x80, 0xbb, 0x80, 0xbb,
		0x80, 0xbb, 0x80, 0xbb, 0x20, 0x79, 0xde, 0x69, 0xd3, 0xa7, 0x4d, 0xdf, 0xc0, 0xb4, 0xd0, 0xa6,
		0xbf, 0x5a, 0x06, 0x29, 0x08, 0x6b, 0x3b, 0x9c, 0x57, 0x4d, 0xda, 0xf4, 0x51, 0x4d, 0x57, 0x1c,
		0x12, 0x3b, 0xa9, 0x64, 0x1e, 0x36, 0x57, 0x5b, 0xda, 0xf4, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d,
		0xa4, 0x1e, 0x52, 0xaf, 0x79, 0xde, 0x69, 0xd3, 0x87, 0x4f, 0xdb, 0x91, 0x16, 0x4a, 0xfa, 0xe0,
		0xd3, 0x8e, 0xf2, 0x69, 0xda, 0xf4, 0x61, 0xd4, 0x30, 0xea, 0x52, 0x4a, 0xa2, 0x4d, 0xdf, 0x81,
		0x36, 0xfd, 0x45, 0xf7, 0x77, 0x55, 0xba, 0xf4, 0x77, 0x4a, 0xac, 0xaf, 0xda, 0x7a, 0x5a, 0x0a,
		0xfd, 0xac, 0xa9, 0xcc, 0x5d, 0x88, 0xa7, 0x83, 0x24, 0x4a, 0x99, 0x56, 0x77, 0xf1, 0x62, 0xed,
		0xf4, 0xbd, 0xbc, 0x5e, 0xfa, 0x36, 0xde, 0xc9, 0xed, 0xd8, 0xeb, 0xa6, 0xef, 0xe0, 0x35, 0x6f,
		0xc2, 0xbe, 0x7f, 0x13, 0x7a, 0xed, 0xf1, 0xfd, 0xe1, 0xd5, 0x62, 0xdd, 0xde, 0x22, 0x2e, 0xd4,
		0x99, 0x2f, 0x7b, 0xa7, 0x9c, 0x6a, 0x2e, 0xa8, 0xe2, 0x4a, 0xe3, 0x2d, 0x54, 0xc7, 0x5a, 0x28,
		0x8d, 0xb3, 0x50, 0x1b, 0x63, 0xa1, 0x19, 0xda, 0xd4, 0x0f, 0x65, 0x6a, 0x87, 0x2e, 0xcd, 0x42,
		0x95, 0x66, 0xa1, 0x49, 0x93, 0x50, 0x64, 0xb9, 0x41, 0x5f, 0x6b, 0xfc, 0x44, 0x6d, 0x12, 0x44,
		0xd7, 0xf5, 0xeb, 0x45, 0xbb, 0x48, 0x3d, 0x1e, 0x4d, 0x4d, 0x46, 0x0d, 0xad, 0xaf, 0x41, 0x6b,
		0xca, 0x87, 0x4d, 0x9f, 0x8c, 0x72, 0x94, 0x42, 0x3d, 0x27, 0xc6, 0xbc, 0xa3, 0x4a, 0x03, 0x89,
		0x39, 0xa0, 0x98, 0x02, 0x4b, 0x35, 0xa3, 0x21, 0xea, 0xb9, 0x2c, 0xc3, 0x3e, 0x16, 0xe5, 0xfe,
		0x15, 0x02, 0x1c, 0x04, 0x38, 0xbe, 0x26, 0xc0, 0xa1, 0x10, 0x73, 0x13, 0x0c, 0x11, 0xec, 0x94,
		0x48, 0xf5, 0xb4, 0x54, 0xce, 0x55, 0x55, 0xab, 0x89, 0xc6, 0x73, 0x0a, 0x09, 0x9b, 0xc9, 0x9c,
		0x83, 0xe2, 0xb5, 0x54, 0x40, 0x43, 0x6b, 0xc3, 0xc6, 0xfd, 0x38, 0xaa, 0x07, 0xf7, 0x63, 0x39,
		0xed, 0xcc, 0xd0, 0xf7, 0x81, 0x2c, 0xa1, 0xb3, 0x26, 0x1b, 0x0c, 0x13, 0xe7, 0x36, 0x1a, 0x5c,
		0x46, 0x8f, 0xbb, 0x68, 0x71, 0x15, 0x75, 0x6e, 0xa2, 0xce, 0x45, 0x54, 0xb9, 0x47, 0xb9, 0xd0,
		0x55, 0x3a, 0x78, 0x55, 0xcb, 0xa5, 0x82, 0xd4, 0x52, 0x07, 0x8a, 0x09, 0x28, 0xf5, 0x0c, 0xc2,
		0x2e, 0x19, 0x84, 0xf2, 0x04, 0x80, 0xc8, 0x20, 0x90, 0x41, 0x30, 0x37, 0xc2, 0x99, 0xa0, 0xc1,
		0xd2, 0x86, 0x28, 0x67, 0x0d, 0x52, 0xb9, 0x15, 0xbf, 0xa1, 0x80, 0x88, 0x7d, 0x05, 0x0c, 0xb6,
		0xb9, 0xe1, 0x36, 0x37, 0xe0, 0xa6, 0x86, 0x5c, 0xc7, 0xa0, 0x2b, 0x19, 0x76, 0x75, 0x03, 0x9f,
		0x09, 0xe4, 0x86, 0x02, 0x5a, 0x1a, 0x9f, 0x55, 0x1f, 0x1c, 0xac, 0x41, 0xc2, 0x19, 0xb0, 0x70,
		0x06, 0x34, 0x9c, 0x00, 0x0f, 0x5d, 0x10, 0x51, 0x06, 0x93, 0x6c, 0x87, 0xb9, 0xa1, 0x80, 0x1b,
		0x0a, 0x34, 0x5f, 0x9c, 0x76, 0xc6, 0xd5, 0x32, 0x68, 0x67, 0xb4, 0x36, 0x7f, 0x79, 0xd5, 0xa4,
		0x9d, 0x71, 0x4d, 0x35, 0xb9, 0xa1, 0xc0, 0xda, 0x21, 0xb0, 0x93, 0xca, 0x9c, 0xa0, 0xcd, 0xd5,
		0x96, 0x1b, 0x0a, 0xb2, 0xe8, 0x05, 0x37, 0x14, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c,
		0x65, 0xa9, 0x3c, 0x37, 0x14, 0x54, 0xc2, 0x69, 0xe1, 0x86, 0x02, 0xdc, 0x05, 0xdc, 0x05, 0xdc,
		0x05, 0xdc, 0x05, 0xdc, 0x05, 0xc9, 0xf3, 0xce, 0x0d, 0x05, 0xdc, 0x50, 0x60, 0x60, 0x5a, 0xb8,
		0xa1, 0x60, 0xb5, 0x0c, 0x52, 0x10, 0xd6, 0x76, 0x38, 0xaf, 0x9a, 0xdc, 0x50, 0x80, 0x6a, 0xba,
		0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0, 0xb9, 0xda, 0x72, 0x43, 0x01, 0xa4, 0x1e, 0x52, 0x0f,
		0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b, 0x37, 0x14, 0xc0, 0xa7, 0xed, 0x48, 0x0b, 0x25,
		0x7d, 0xf0, 0x69, 0x47, 0xf9, 0x34, 0x37, 0x14, 0xc0, 0xa8, 0x61, 0xd4, 0xa5, 0x94, 0xc4, 0x0d,
		0x05, 0x6a, 0x53, 0xab, 0x56, 0xe3, 0x89, 0xf2, 0xf7, 0x13, 0xa4, 0xcd, 0xdf, 0x55, 0x99, 0xdf,
		0xa7, 0x32, 0xce, 0xde, 0x37, 0x99, 0xed, 0xab, 0x30, 0x6f, 0xfd, 0x31, 0xb4, 0xaa, 0x37, 0xe9,
		0x37, 0x68, 0xd2, 0xaf, 0x4e, 0xc0, 0x86, 0x26, 0x7d, 0x9a, 0xf4, 0x0b, 0xdb, 0x49, 0x9a, 0xf4,
		0x69, 0xd2, 0xaf, 0x1e, 0x28, 0xd8, 0x83, 0x83, 0x35, 0x48, 0x38, 0x03, 0x16, 0xce, 0x80, 0x86,
		0x13, 0xe0, 0x61, 0xc3, 0xa8, 0x69, 0xd2, 0x57, 0xb7, 0xee, 0x34, 0xe9, 0x2b, 0xbe, 0x38, 0x11,
		0xfd, 0xd5, 0x32, 0x88, 0xe8, 0x5b, 0x9b, 0xbf, 0xbc, 0x6a, 0x12, 0xd1, 0x5f, 0x53, 0x4d, 0x9a,
		0xf4, 0xad, 0x1d, 0x02, 0x3b, 0xa9, 0x94, 0xca, 0x6d, 0xae, 0xb6, 0x34, 0xe9, 0x67, 0xd1, 0x0b,
		0x9a, 0xf4, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb2, 0x54, 0x9e, 0x26, 0xfd, 0x4a,
		0x38, 0x2d, 0x34, 0xe9, 0xe3, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0x48, 0x9e,
		0x77, 0x9a, 0xf4, 0x69, 0xd2, 0x37, 0x30, 0x2d, 0x34, 0xe9, 0xaf, 0x96, 0x41, 0x0a, 0xc2, 0xda,
		0x0e, 0xe7, 0x55, 0x93, 0x26, 0x7d, 0x54, 0xd3, 0x15, 0x87, 0xc4, 0x4e, 0x2a, 0x99, 0x87, 0xcd,
		0xd5, 0x96, 0x26, 0x7d, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x6b, 0x9e, 0x77,
		0x9a, 0xf4, 0xe1, 0xd3, 0x76, 0xa4, 0x85, 0x92, 0x3e, 0xf8, 0xb4, 0xa3, 0x7c, 0x9a, 0x26, 0x7d,
		0x18, 0x35, 0x8c, 0xba, 0x94, 0x92, 0x68, 0xd2, 0x37, 0x6f, 0xd2, 0x5f, 0xf4, 0x7e, 0x57, 0xa5,
		0x47, 0x7f, 0xa7, 0xc4, 0xda, 0xaa, 0xad, 0xa5, 0x25, 0xd0, 0xce, 0x9a, 0xca, 0xcc, 0x85, 0x78,
		0x3a, 0x48, 0xa2, 0x94, 0x65, 0x75, 0x17, 0xaf, 0xd5, 0x4e, 0xdf, 0xca, 0xeb, 0xa5, 0xef, 0xe2,
		0x9d, 0xdc, 0x8e, 0xbd, 0x6e, 0xfa, 0x06, 0x5e, 0xf3, 0x26, 0xec, 0xfb, 0x37, 0xa1, 0xd7, 0x69,
		0xbc, 0x19, 0x47, 0xad, 0xfb, 0x71, 0xe4, 0x2d, 0x22, 0x42, 0x9d, 0xf9, 0xa2, 0x77, 0xca, 0xa9,
		0xe2, 0x32, 0x4f, 0x16, 0x3a, 0x34, 0x5a, 0x87, 0xc5, 0xcd, 0x43, 0x22, 0x78, 0x2e, 0x8a, 0x39,
		0x0f, 0x32, 0x67, 0xa0, 0x78, 0x0d, 0x15, 0xd0, 0xce, 0xda, 0xe2, 0x33, 0xdd, 0x8f, 0x87, 0x72,
		0xbd, 0xfd, 0x59, 0x50, 0xe8, 0x81, 0x2c, 0xa1, 0x73, 0x26, 0x3b, 0xae, 0x45, 0x3c, 0x84, 0xaf,
		0x11, 0xaa, 0xd7, 0x0b, 0xc9, 0x6b, 0x85, 0xde, 0xd5, 0x43, 0xec, 0xea, 0xa1, 0x74, 0xd5, 0x90,
		0x79, 0xb9, 0x90, 0x55, 0x7a, 0x1c, 0x4a, 0x2d, 0xe7, 0xe1, 0x89, 0xab, 0xf2, 0x83, 0x3e, 0x2d,
		0x2d, 0xbf, 0x52, 0x69, 0xc6, 0x95, 0x5a, 0xfe, 0x53, 0x33, 0xdf, 0xa9, 0x9f, 0xdf, 0xd4, 0xce,
		0x67, 0x9a, 0xe5, 0x2f, 0xcd, 0xf2, 0x95, 0x26, 0xf9, 0xc9, 0x72, 0xc7, 0x02, 0xb4, 0x66, 0x52,
		0xd5, 0x06, 0x4b, 0x1b, 0xa2, 0x3c, 0x73, 0x30, 0x95, 0x5b, 0xf1, 0xa1, 0x83, 0xbb, 0x0c, 0x1d,
		0x2c, 0xbf, 0xc1, 0x36, 0x37, 0xdc, 0xe6, 0x06, 0xdc, 0xd4, 0x90, 0xeb, 0x18, 0x74, 0x25, 0xc3,
		0xae, 0x6e, 0xe0, 0x33, 0x81, 0x0c, 0x1d, 0xa4, 0x4a, 0xf1, 0x59, 0xf5, 0xc1, 0xc1, 0x1a, 0x24,
		0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3, 0x09, 0xf0, 0xd0, 0x05, 0x11, 0x65, 0x30, 0xc9, 0x76, 0x98,
		0xa1, 0x83, 0x0c, 0x1d, 0xd4, 0x7c, 0x71, 0x2a, 0x14, 0x57, 0xcb, 0xa0, 0x42, 0xd1, 0xda, 0xfc,
		0xe5, 0x55, 0x93, 0x0a, 0xc5, 0x35, 0xd5, 0x64, 0xe8, 0xa0, 0xb5, 0x43, 0x60, 0x27, 0x95, 0xd6,
		0xbf, 0xcd, 0xd5, 0x96, 0xa1, 0x83, 0x59, 0xf4, 0x82, 0xa1, 0x83, 0x50, 0x79, 0xa8, 0x3c, 0x54,
		0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0xcf, 0xd0, 0xc1, 0x4a, 0x38, 0x2d, 0x0c, 0x1d, 0xc4, 0x5d, 0xc0,
		0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0x90, 0x3c, 0xef, 0x0c, 0x1d, 0x64, 0xe8, 0xa0, 0x81,
		0x69, 0x61, 0xe8, 0xe0, 0x6a, 0x19, 0xa4, 0x20, 0xac, 0xed, 0x70, 0x5e, 0x35, 0x19, 0x3a, 0x88,
		0x6a, 0xba, 0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0, 0xb9, 0xda, 0x32, 0x74, 0x10, 0x52, 0x0f,
		0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x9a, 0xe7, 0x9d, 0xa1, 0x83, 0xf0, 0x69, 0x3b, 0xd2,
		0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0xcd, 0xd0, 0x41, 0x18, 0x35, 0x8c, 0xba, 0x94, 0x92,
		0x18, 0x3a, 0xa8, 0x3c, 0xb1, 0xea, 0x7e, 0x3c, 0xff, 0xed, 0x07, 0x43, 0x07, 0xd3, 0xe6, 0xef,
		0xaa, 0x4c, 0x1d, 0x54, 0x99, 0x52, 0xe7, 0x27, 0x81, 0x7e, 0x97, 0xfe, 0x42, 0x6c, 0xc5, 0x9b,
		0xf4, 0x1b, 0x34, 0xe9, 0x57, 0x27, 0x60, 0x43, 0x93, 0x3e, 0x4d, 0xfa, 0x85, 0xed, 0x24, 0x4d,
		0xfa, 0x34, 0xe9, 0x57, 0x0f, 0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40,
		0xc3, 0x09, 0xf0, 0xb0, 0x61, 0xd4, 0x34, 0xe9, 0xab, 0x5b, 0x77, 0x9a, 0xf4, 0x15, 0x5f, 0x9c,
		0x88, 0xfe, 0x6a, 0x19, 0x44, 0xf4, 0xad, 0xcd, 0x5f, 0x5e, 0x35, 0x89, 0xe8, 0xaf, 0xa9, 0x26,
		0x4d, 0xfa, 0xd6, 0x0e, 0x81, 0x9d, 0x54, 0x4a, 0xe5, 0x36, 0x57, 0x5b, 0x9a, 0xf4, 0xb3, 0xe8,
		0x05, 0x4d, 0xfa, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0x4f, 0x93, 0x7e,
		0x25, 0x9c, 0x16, 0x9a, 0xf4, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x24,
		0xcf, 0x3b, 0x4d, 0xfa, 0x34, 0xe9, 0x1b, 0x98, 0x16, 0x9a, 0xf4, 0x57, 0xcb, 0x20, 0x05, 0x61,
		0x6d, 0x87, 0xf3, 0xaa, 0x49, 0x93, 0x3e, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27, 0x95, 0xcc, 0xc3,
		0xe6, 0x6a, 0x4b, 0x93, 0x3e, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf,
		0x3b, 0x4d, 0xfa, 0xf0, 0x69, 0x3b, 0xd2, 0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0x4d, 0x93,
		0x3e, 0x8c, 0x1a, 0x46, 0x5d, 0x4a, 0x49, 0x34, 0xe9, 0x9b, 0x37, 0xe9, 0x2f, 0x7a, 0xbf, 0xab,
		0xd2, 0xa3, 0xbf, 0x53, 0x62, 0x6d, 0xd5, 0xd6, 0xd2, 0x12, 0x68, 0x67, 0x4d, 0x65, 0xe6, 0x42,
		0x3c, 0x1d, 0x24, 0x51, 0xca, 0xb2, 0xba, 0x8b, 0xd7, 0x6a, 0xa7, 0x6f, 0xe5, 0xf5, 0xd2, 0x77,
		0xf1, 0x4e, 0x6e, 0xc7, 0x5e, 0x37, 0x7d, 0x03, 0xaf, 0x79, 0x13, 0xf6, 0xfd, 0x9b, 0xd0, 0xeb,
		0x34, 0xde, 0x8c, 0xa3, 0x37, 0xe3, 0xe1, 0xc4, 0x5b, 0x44, 0x84, 0x3a, 0xf3, 0x45, 0xef, 0x94,
		0x53, 0xc5, 0x65, 0x9e, 0x2c, 0x74, 0x68, 0xb4, 0x0e, 0x8b, 0x9b, 0x87, 0x44, 0xf0, 0x5c, 0x14,
		0x73, 0x1e, 0x64, 0xce, 0x40, 0xf1, 0x1a, 0x2a, 0xa0, 0x9d, 0xb5, 0xe1, 0x8b, 0xd9, 0x67, 0x0a,
		0xc7, 0xf7, 0xfb, 0xf5, 0xbb, 0xe9, 0x30, 0x09, 0x07, 0xfe, 0x44, 0x2e, 0x3f, 0x90, 0x85, 0x87,
		0x3e, 0x2b, 0x55, 0xe8, 0xec, 0xc9, 0x8e, 0x70, 0x11, 0x0f, 0xeb, 0x6b, 0x84, 0xef, 0xf5, 0xc2,
		0xf4, 0x5a, 0xe1, 0x78, 0xf5, 0xb0, 0xbb, 0x7a, 0x78, 0x5d, 0x35, 0x8c, 0x5e, 0x2e, 0xb4, 0x95,
		0x1e, 0x91, 0x52, 0xcb, 0x79, 0x7d, 0xe2, 0xaa, 0xfc, 0xa0, 0x77, 0x4b, 0xcb, 0xd7, 0x54, 0x9a,
		0x7b, 0xa5, 0x96, 0x13, 0xd5, 0xcc, 0x81, 0xea, 0xe7, 0x3c, 0xb5, 0x73, 0x9c, 0x66, 0x39, 0x4d,
		0xb3, 0x1c, 0xa6, 0x49, 0xce, 0xb2, 0xdc, 0xf1, 0x01, 0xad, 0x39, 0x55, 0xb5, 0xc1, 0xd2, 0x86,
		0x28, 0xcf, 0x21, 0x4c, 0xe5, 0x56, 0x7c, 0x10, 0xe1, 0x2e, 0x83, 0x08, 0xcb, 0x6f, 0xb0, 0xcd,
		0x0d, 0xb7, 0xb9, 0x01, 0x37, 0x35, 0xe4, 0x3a, 0x06, 0x5d, 0xc9, 0xb0, 0xab, 0x1b, 0xf8, 0x4c,
		0x20, 0x83, 0x08, 0xa9, 0x5c, 0x7c, 0x56, 0x7d, 0x70, 0xb0, 0x06, 0x09, 0x67, 0xc0, 0xc2, 0x19,
		0xd0, 0x70, 0x02, 0x3c, 0x74, 0x41, 0x44, 0x19, 0x4c, 0xb2, 0x1d, 0x66, 0x10, 0x21, 0x83, 0x08,
		0x35, 0x5f, 0x9c, 0xaa, 0xc5, 0xd5, 0x32, 0xa8, 0x5a, 0xb4, 0x36, 0x7f, 0x79, 0xd5, 0xa4, 0x6a,
		0x71, 0x4d, 0x35, 0x19, 0x44, 0x68, 0xed, 0x10, 0xd8, 0x49, 0xa5, 0x1d, 0x70, 0x73, 0xb5, 0x65,
		0x10, 0x61, 0x16, 0xbd, 0x60, 0x10, 0x21, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x57, 0x96,
		0xca, 0x33, 0x88, 0xb0, 0x12, 0x4e, 0x0b, 0x83, 0x08, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70,
		0x17, 0x70, 0x17, 0x24, 0xcf, 0x3b, 0x83, 0x08, 0x19, 0x44, 0x68, 0x60, 0x5a, 0x18, 0x44, 0xb8,
		0x5a, 0x06, 0x29, 0x08, 0x6b, 0x3b, 0x9c, 0x57, 0x4d, 0x06, 0x11, 0xa2, 0x9a, 0xae, 0x38, 0x24,
		0x76, 0x52, 0xc9, 0x3c, 0x6c, 0xae, 0xb6, 0x0c, 0x22, 0x84, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90,
		0x7a, 0x48, 0xbd, 0xe6, 0x79, 0x67, 0x10, 0x21, 0x7c, 0xda, 0x8e, 0xb4, 0x50, 0xd2, 0x07, 0x9f,
		0x76, 0x94, 0x4f, 0x33, 0x88, 0x10, 0x46, 0x0d, 0xa3, 0x2e, 0xa5, 0x24, 0x06, 0x11, 0xea, 0x4d,
		0xb1, 0xfa, 0xcc, 0xa0, 0xa2, 0xfc, 0x48, 0xc2, 0xb4, 0x0d, 0xbc, 0x2a, 0x33, 0x09, 0x55, 0x66,
		0xd8, 0xf9, 0x49, 0xa0, 0xdf, 0xaf, 0xbf, 0x10, 0x5b, 0xf1, 0x76, 0xfd, 0x06, 0xed, 0xfa, 0xd5,
		0x09, 0xdd, 0xd0, 0xae, 0x4f, 0xbb, 0x7e, 0x61, 0x3b, 0x49, 0xbb, 0x3e, 0xed, 0xfa, 0xd5, 0x03,
		0x05, 0x7b, 0x70, 0xb0, 0x06, 0x09, 0x67, 0xc0, 0xc2, 0x19, 0xd0, 0x70, 0x02, 0x3c, 0x6c, 0xb8,
		0x35, 0xed, 0xfa, 0xea, 0xd6, 0x9d, 0x76, 0x7d, 0xc5, 0x17, 0x27, 0xb6, 0xbf, 0x5a, 0x06, 0xb1,
		0x7d, 0x6b, 0xf3, 0x97, 0x57, 0x4d, 0x62, 0xfb, 0x6b, 0xaa, 0x49, 0xbb, 0xbe, 0xb5, 0x43, 0x60,
		0x27, 0x95, 0xa2, 0xb9, 0xcd, 0xd5, 0x96, 0x76, 0xfd, 0x2c, 0x7a, 0x41, 0xbb, 0x3e, 0x54, 0x1e,
		0x2a, 0x0f, 0x95, 0x87, 0xca, 0x57, 0x96, 0xca, 0xd3, 0xae, 0x5f, 0x09, 0xa7, 0x85, 0x76, 0x7d,
		0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xc9, 0xf3, 0x4e, 0xbb, 0x3e, 0xed,
		0xfa, 0x06, 0xa6, 0x85, 0x76, 0xfd, 0xd5, 0x32, 0x48, 0x41, 0x58, 0xdb, 0xe1, 0xbc, 0x6a, 0xd2,
		0xae, 0x8f, 0x6a, 0xba, 0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0, 0xb9, 0xda, 0xd2, 0xae, 0x0f,
		0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0xcd, 0xf3, 0x4e, 0xbb, 0x3e, 0x7c, 0xda,
		0x8e, 0xb4, 0x50, 0xd2, 0x07, 0x9f, 0x76, 0x94, 0x4f, 0xd3, 0xae, 0x0f, 0xa3, 0x86, 0x51, 0x97,
		0x52, 0x12, 0xed, 0xfa, 0x0e, 0xb5, 0xeb, 0x2f, 0xba, 0xc0, 0xab, 0xd2, 0xad, 0xbf, 0x53, 0x62,
		0xbd, 0xd5, 0xd6, 0xd7, 0x52, 0xe9, 0x69, 0x4d, 0x65, 0x0e, 0x43, 0x3c, 0x1d, 0x24, 0x51, 0xca,
		0xbc, 0xba, 0x8b, 0x17, 0x6c, 0xa7, 0xef, 0xe7, 0xf5, 0xd2, 0xb7, 0xf2, 0x4e, 0x6e, 0xc7, 0x5e,
		0x37, 0x7d, 0x17, 0xaf, 0x79, 0x13, 0xf6, 0xfd, 0x9b, 0xd0, 0xeb, 0xbc, 0x78, 0x33, 0x8e, 0xda,
		0xe3, 0xfb, 0xfd, 0xb3, 0xe5, 0xf2, 0xbd, 0x45, 0xb8, 0xa8, 0x33, 0x5f, 0xfd, 0x4e, 0x39, 0xb5,
		0x5e, 0xe6, 0xc9, 0x42, 0xe7, 0x48, 0xeb, 0xfc, 0xb8, 0x7e, 0x6e, 0x04, 0x8f, 0x4a, 0xc1, 0x47,
		0x44, 0xe6, 0x58, 0x14, 0xaf, 0xb4, 0x02, 0x0a, 0x5b, 0x7b, 0xf0, 0xe5, 0xa6, 0xd1, 0x62, 0x37,
		0xa4, 0x94, 0x36, 0x0b, 0x26, 0x7d, 0x46, 0xa6, 0xd0, 0x51, 0x94, 0x1d, 0xf7, 0x22, 0x9e, 0x02,
		0xd0, 0x08, 0xf5, 0xeb, 0x85, 0xf4, 0xb5, 0x42, 0xf7, 0xea, 0x21, 0x7a, 0xf5, 0x50, 0xbc, 0x6a,
		0xc8, 0xbd, 0x5c, 0xe0, 0x2b, 0x3d, 0x4e, 0xa5, 0x96, 0xf3, 0x06, 0xc5, 0x55, 0xf9, 0x41, 0x9f,
		0x97, 0x96, 0x0f, 0xaa, 0x34, 0x23, 0x4b, 0x2d, 0x7f, 0xaa, 0x99, 0x2f, 0xd5, 0xcf, 0x8f, 0x6a,
		0xe7, 0x43, 0xcd, 0xf2, 0x9f, 0x66, 0xf9, 0x4e, 0x93, 0xfc, 0x66, 0xb9, 0x23, 0x08, 0x5a, 0x33,
		0xad, 0x6a, 0x83, 0xa5, 0x0d, 0x51, 0x9e, 0x59, 0x98, 0xca, 0xad, 0xf8, 0xd0, 0xc2, 0x5d, 0x86,
		0x16, 0x96, 0xdf, 0x60, 0x9b, 0x1b, 0x6e, 0x73, 0x03, 0x6e, 0x6a, 0xc8, 0x75, 0x0c, 0xba, 0x92,
		0x61, 0x57, 0x37, 0xf0, 0x99, 0x40, 0x86, 0x16, 0x52, 0xe5, 0xf8, 0xac, 0xfa, 0xe0, 0x60, 0x0d,
		0x12, 0xce, 0x80, 0x85, 0x33, 0xa0, 0xe1, 0x04, 0x78, 0xe8, 0x82, 0x88, 0x32, 0x98, 0x64, 0x3b,
		0xcc, 0xd0, 0x42, 0x86, 0x16, 0x6a, 0xbe, 0x38, 0x15, 0x8e, 0xab, 0x65, 0x50, 0xe1, 0x68, 0x6d,
		0xfe, 0xf2, 0xaa, 0x49, 0x85, 0xe3, 0x9a, 0x6a, 0x32, 0xb4, 0xd0, 0xda, 0x21, 0xb0, 0x93, 0x4a,
		0xeb, 0xe0, 0xe6, 0x6a, 0xcb, 0xd0, 0xc2, 0x2c, 0x7a, 0xc1, 0xd0, 0x42, 0xa8, 0x3c, 0x54, 0x1e,
		0x2a, 0x0f, 0x95, 0xaf, 0x2c, 0x95, 0x67, 0x68, 0x61, 0x25, 0x9c, 0x16, 0x86, 0x16, 0xe2, 0x2e,
		0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0x48, 0x9e, 0x77, 0x86, 0x16, 0x32, 0xb4, 0xd0,
		0xc0, 0xb4, 0x30, 0xb4, 0x70, 0xb5, 0x0c, 0x52, 0x10, 0xd6, 0x76, 0x38, 0xaf, 0x9a, 0x0c, 0x2d,
		0x44, 0x35, 0x5d, 0x71, 0x48, 0xec, 0xa4, 0x92, 0x79, 0xd8, 0x5c, 0x6d, 0x19, 0x5a, 0x08, 0xa9,
		0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0xcd, 0xf3, 0xce, 0xd0, 0x42, 0xf8, 0xb4, 0x1d,
		0x69, 0xa1, 0xa4, 0x0f, 0x3e, 0xed, 0x28, 0x9f, 0x66, 0x68, 0x21, 0x8c, 0x1a, 0x46, 0x5d, 0x4a,
		0x49, 0x0c, 0x2d, 0xb4, 0x18, 0x6a, 0x95, 0x8e, 0x29, 0xca, 0x8f, 0x2c, 0x4c, 0x9b, 0xc0, 0xab,
		0x32, 0xb3, 0x50, 0x65, 0xb2, 0x9d, 0x9f, 0x04, 0xfa, 0xdd, 0xfa, 0x0b, 0xb1, 0x15, 0x6f, 0xd6,
		0x6f, 0xd0, 0xac, 0x5f, 0x9d, 0xc0, 0x0d, 0xcd, 0xfa, 0x34, 0xeb, 0x17, 0xb6, 0x93, 0x34, 0xeb,
		0xd3, 0xac, 0x5f, 0x3d, 0x50, 0xb0, 0x07, 0x07, 0x6b, 0x90, 0x70, 0x06, 0x2c, 0x9c, 0x01, 0x0d,
		0x27, 0xc0, 0xc3, 0x86, 0x59, 0xd3, 0xac, 0xaf, 0x6e, 0xdd, 0x69, 0xd6, 0x57, 0x7c, 0x71, 0x22,
		0xfb, 0xab, 0x65, 0x10, 0xd9, 0xb7, 0x36, 0x7f, 0x79, 0xd5, 0x24, 0xb2, 0xbf, 0xa6, 0x9a, 0x34,
		0xeb, 0x5b, 0x3b, 0x04, 0x76, 0x52, 0x29, 0x99, 0xdb, 0x5c, 0x6d, 0x69, 0xd6, 0xcf, 0xa2, 0x17,
		0x34, 0xeb, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x65, 0xa9, 0x3c, 0xcd, 0xfa, 0x95,
		0x70, 0x5a, 0x68, 0xd6, 0xc7, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0x90, 0x3c,
		0xef, 0x34, 0xeb, 0xd3, 0xac, 0x6f, 0x60, 0x5a, 0x68, 0xd6, 0x5f, 0x2d, 0x83, 0x14, 0x84, 0xb5,
		0x1d, 0xce, 0xab, 0x26, 0xcd, 0xfa, 0xa8, 0xa6, 0x2b, 0x0e, 0x89, 0x9d, 0x54, 0x32, 0x0f, 0x9b,
		0xab, 0x2d, 0xcd, 0xfa, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xd7, 0x3c, 0xef,
		0x34, 0xeb, 0xc3, 0xa7, 0xed, 0x48, 0x0b, 0x25, 0x7d, 0xf0, 0x69, 0x47, 0xf9, 0x34, 0xcd, 0xfa,
		0x30, 0x6a, 0x18, 0x75, 0x29, 0x25, 0xd1, 0xac, 0xef, 0x4c, 0xb3, 0xfe, 0xa2, 0x07, 0xbc, 0x2a,
		0xbd, 0xfa, 0x3b, 0x25, 0xd6, 0x5a, 0x6d, 0x6d, 0x2d, 0x91, 0x96, 0xd6, 0x54, 0x66, 0x30, 0xc4,
		0xd3, 0x41, 0x12, 0xa5, 0xac, 0xab, 0xbb, 0x78, 0xbd, 0x76, 0xfa, 0x76, 0x5e, 0x2f, 0x7d, 0x27,
		0xef, 0xe4, 0x76, 0xec, 0x75, 0xd3, 0x37, 0xf1, 0x9a, 0x37, 0x61, 0xdf, 0xbf, 0x09, 0xbd, 0xce,
		0x8b, 0x37, 0xe3, 0xa8, 0x3d, 0xbe, 0xdf, 0xbf, 0x5a, 0x2c, 0xde, 0x5b, 0x04, 0x8a, 0x3a, 0xf3,
		0xb5, 0xef, 0x94, 0x53, 0xe3, 0x65, 0x9e, 0x2c, 0x74, 0x86, 0xb4, 0xce, 0x8e, 0xdb, 0x67, 0x46,
		0xf0, 0x98, 0x14, 0x7a, 0x3c, 0x64, 0x8e, 0x44, 0xf1, 0x0a, 0x2b, 0xa0, 0xac, 0xb5, 0xec, 0xab,
		0x1d, 0xd6, 0xef, 0xa6, 0xc3, 0x64, 0xb1, 0x1f, 0x52, 0x2a, 0x9b, 0x05, 0x91, 0x3e, 0x2b, 0x55,
		0xe8, 0x28, 0xca, 0x0e, 0x7a, 0x11, 0x0f, 0xfe, 0x6b, 0x04, 0xf9, 0xf5, 0x82, 0xf9, 0x5a, 0x41,
		0x7b, 0xf5, 0xe0, 0xbc, 0x7a, 0x10, 0x5e, 0x35, 0xd8, 0x5e, 0x2e, 0xf0, 0x95, 0x1e, 0xa4, 0x52,
		0xcb, 0xf9, 0x82, 0xe2, 0xaa, 0xfc, 0xa0, 0xc3, 0x4b, 0xcb, 0x03, 0x55, 0x9a, 0x8e, 0xa5, 0x96,
		0x39, 0xd5, 0xcc, 0x94, 0xea, 0x67, 0x46, 0xb5, 0x33, 0xa1, 0x66, 0x99, 0x4f, 0xb3, 0x4c, 0xa7,
		0x49, 0x66, 0xb3, 0xdc, 0xd1, 0x03, 0xad, 0x69, 0x56, 0xb5, 0xc1, 0xd2, 0x86, 0x28, 0x4f, 0x2b,
		0x4c, 0xe5, 0x56, 0x7c, 0x5c, 0xe1, 0x2e, 0xe3, 0x0a, 0xcb, 0x6f, 0xb0, 0xcd, 0x0d, 0xb7, 0xb9,
		0x01, 0x37, 0x35, 0xe4, 0x3a, 0x06, 0x5d, 0xc9, 0xb0, 0xab, 0x1b, 0xf8, 0x4c, 0x20, 0xe3, 0x0a,
		0xa9, 0x6f, 0x7c, 0x56, 0x7d, 0x70, 0xb0, 0x06, 0x09, 0x67, 0xc0, 0xc2, 0x19, 0xd0, 0x70, 0x02,
		0x3c, 0x74, 0x41, 0x44, 0x19, 0x4c, 0xb2, 0x1d, 0x66, 0x5c, 0x21, 0xe3, 0x0a, 0x35, 0x5f, 0x9c,
		0xda, 0xc6, 0xd5, 0x32, 0xa8, 0x6d, 0xb4, 0x36, 0x7f, 0x79, 0xd5, 0xa4, 0xb6, 0x71, 0x4d, 0x35,
		0x19, 0x57, 0x68, 0xed, 0x10, 0xd8, 0x49, 0xa5, 0x69, 0x70, 0x73, 0xb5, 0x65, 0x5c, 0x61, 0x16,
		0xbd, 0x60, 0x5c, 0x21, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x57, 0x96, 0xca, 0x33, 0xae,
		0xb0, 0x12, 0x4e, 0x0b, 0xe3, 0x0a, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17,
		0x24, 0xcf, 0x3b, 0xe3, 0x0a, 0x19, 0x57, 0x68, 0x60, 0x5a, 0x18, 0x57, 0xb8, 0x5a, 0x06, 0x29,
		0x08, 0x6b, 0x3b, 0x9c, 0x57, 0x4d, 0xc6, 0x15, 0xa2, 0x9a, 0xae, 0x38, 0x24, 0x76, 0x52, 0xc9,
		0x3c, 0x6c, 0xae, 0xb6, 0x8c, 0x2b, 0x84, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd,
		0xe6, 0x79, 0x67, 0x5c, 0x21, 0x7c, 0xda, 0x8e, 0xb4, 0x50, 0xd2, 0x07, 0x9f, 0x76, 0x94, 0x4f,
		0x33, 0xae, 0x10, 0x46, 0x0d, 0xa3, 0x2e, 0xa5, 0x24, 0xc6, 0x15, 0xea, 0x0f, 0xb5, 0x7a, 0x30,
		0xa8, 0x28, 0x3f, 0xb0, 0x30, 0x6d, 0x03, 0xaf, 0xca, 0xc4, 0x42, 0x95, 0xc9, 0x76, 0x7e, 0x12,
		0xe8, 0xf7, 0xeb, 0x2f, 0xc4, 0x56, 0xbc, 0x5d, 0xbf, 0x41, 0xbb, 0x7e, 0x75, 0x42, 0x37, 0xb4,
		0xeb, 0xd3, 0xae, 0x5f, 0xd8, 0x4e, 0xd2, 0xae, 0x4f, 0xbb, 0x7e, 0xf5, 0x40, 0xc1, 0x1e, 0x1c,
		0xac, 0x41, 0xc2, 0x19, 0xb0, 0x70, 0x06, 0x34, 0x9c, 0x00, 0x0f, 0x1b, 0x6e, 0x4d, 0xbb, 0xbe,
		0xba, 0x75, 0xa7, 0x5d, 0x5f, 0xf1, 0xc5, 0x89, 0xed, 0xaf, 0x96, 0x41, 0x6c, 0xdf, 0xda, 0xfc,
		0xe5, 0x55, 0x93, 0xd8, 0xfe, 0x9a, 0x6a, 0xd2, 0xae, 0x6f, 0xed, 0x10, 0xd8, 0x49, 0xa5, 0x68,
		0x6e, 0x73, 0xb5, 0xa5, 0x5d, 0x3f, 0x8b, 0x5e, 0xd0, 0xae, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5,
		0xa1, 0xf2, 0x95, 0xa5, 0xf2, 0xb4, 0xeb, 0x57, 0xc2, 0x69, 0xa1, 0x5d, 0x1f, 0x77, 0x01, 0x77,
		0x01, 0x77, 0x01, 0x77, 0x01, 0x77, 0x41, 0xf2, 0xbc, 0xd3, 0xae, 0x4f, 0xbb, 0xbe, 0x81, 0x69,
		0xa1, 0x5d, 0x7f, 0xb5, 0x0c, 0x52, 0x10, 0xd6, 0x76, 0x38, 0xaf, 0x9a, 0xb4, 0xeb, 0xa3, 0x9a,
		0xae, 0x38, 0x24, 0x76, 0x52, 0xc9, 0x3c, 0x6c, 0xae, 0xb6, 0xb4, 0xeb, 0x43, 0xea, 0x21, 0xf5,
		0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0xd3, 0xae, 0x0f, 0x9f, 0xb6, 0x23, 0x2d, 0x94,
		0xf4, 0xc1, 0xa7, 0x1d, 0xe5, 0xd3, 0xb4, 0xeb, 0xc3, 0xa8, 0x61, 0xd4, 0xa5, 0x94, 0x44, 0xbb,
		0xbe, 0x43, 0xed, 0xfa, 0x8b, 0x2e, 0xf0, 0xaa, 0x74, 0xeb, 0xef, 0x94, 0x58, 0x6f, 0xb5, 0xf5,
		0xb5, 0x54, 0x7a, 0x5a, 0x53, 0x99, 0xc3, 0x10, 0x4f, 0x07, 0x49, 0x94, 0x32, 0xaf, 0xee, 0xe2,
		0x05, 0xdb, 0xe9, 0xfb, 0x79, 0xbd, 0xf4, 0xad, 0xbc, 0x93, 0xdb, 0xb1, 0xd7, 0x4d, 0xdf, 0xc5,
		0x6b, 0xde, 0x84, 0x7d, 0xff, 0x26, 0xf4, 0x3a, 0x2f, 0xde, 0x8c, 0xa3, 0xf6, 0xf8, 0xfe, 0xf0,
		0x6c, 0xb9, 0x7c, 0x6f, 0x11, 0x2e, 0xea, 0xcc, 0x57, 0xbf, 0x53, 0x4e, 0xad, 0x97, 0x79, 0xb2,
		0xd0, 0x39, 0xd2, 0x3a, 0x3f, 0xae, 0x9f, 0x1b, 0xc1, 0xa3, 0x52, 0xf0, 0x11, 0x91, 0x39, 0x16,
		0xc5, 0x2b, 0xad, 0x80, 0xc2, 0xd6, 0x1e, 0x7c, 0xb9, 0x69, 0xb4, 0xd8, 0x0d, 0x29, 0xa5, 0xcd,
		0x82, 0x49, 0x9f, 0x91, 0x29, 0x74, 0x14, 0x65, 0xc7, 0xbd, 0x88, 0xa7, 0x00, 0x34, 0x42, 0xfd,
		0x7a, 0x21, 0x7d, 0xad, 0xd0, 0xbd, 0x7a, 0x88, 0x5e, 0x3d, 0x14, 0xaf, 0x1a, 0x72, 0x2f, 0x17,
		0xf8, 0x4a, 0x8f, 0x53, 0xa9, 0xe5, 0xbc, 0x41, 0x71, 0x55, 0x7e, 0xd0, 0xe7, 0xa5, 0xe5, 0x83,
		0x2a, 0xcd, 0xc8, 0x52, 0xcb, 0x9f, 0x6a, 0xe6, 0x4b, 0xf5, 0xf3, 0xa3, 0xda, 0xf9, 0x50, 0xb3,
		0xfc, 0xa7, 0x59, 0xbe, 0xd3, 0x24, 0xbf, 0x59, 0xee, 0x08, 0x82, 0xd6, 0x4c, 0xab, 0xda, 0x60,
		0x69, 0x43, 0x94, 0x67, 0x16, 0xa6, 0x72, 0x2b, 0x3e, 0xb4, 0x70, 0x97, 0xa1, 0x85, 0xe5, 0x37,
		0xd8, 0xe6, 0x86, 0xdb, 0xdc, 0x80, 0x9b, 0x1a, 0x72, 0x1d, 0x83, 0xae, 0x64, 0xd8, 0xd5, 0x0d,
		0x7c, 0x26, 0x90, 0xa1, 0x85, 0x54, 0x39, 0x3e, 0xab, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x33, 0x60,
		0xe1, 0x0c, 0x68, 0x38, 0x01, 0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x33, 0xb4, 0x90,
		0xa1, 0x85, 0x9a, 0x2f, 0x4e, 0x85, 0xe3, 0x6a, 0x19, 0x54, 0x38, 0x5a, 0x9b, 0xbf, 0xbc, 0x6a,
		0x52, 0xe1, 0xb8, 0xa6, 0x9a, 0x0c, 0x2d, 0xb4, 0x76, 0x08, 0xec, 0xa4, 0xd2, 0x3a, 0xb8, 0xb9,
		0xda, 0x32, 0xb4, 0x30, 0x8b, 0x5e, 0x30, 0xb4, 0x10, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5,
		0x2b, 0x4b, 0xe5, 0x19, 0x5a, 0x58, 0x09, 0xa7, 0x85, 0xa1, 0x85, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8,
		0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0x92, 0xe7, 0x9d, 0xa1, 0x85, 0x0c, 0x2d, 0x34, 0x30, 0x2d, 0x0c,
		0x2d, 0x5c, 0x2d, 0x83, 0x14, 0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0x43, 0x0b, 0x51, 0x4d, 0x57,
		0x1c, 0x12, 0x3b, 0xa9, 0x64, 0x1e, 0x36, 0x57, 0x5b, 0x86, 0x16, 0x42, 0xea, 0x21, 0xf5, 0x90,
		0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0x33, 0xb4, 0x10, 0x3e, 0x6d, 0x47, 0x5a, 0x28, 0xe9,
		0x83, 0x4f, 0x3b, 0xca, 0xa7, 0x19, 0x5a, 0x08, 0xa3, 0x86, 0x51, 0x97, 0x52, 0x12, 0x43, 0x0b,
		0x2d, 0x86, 0x5a, 0xa5, 0x63, 0x8a, 0xf2, 0x23, 0x0b, 0xd3, 0x26, 0xf0, 0xaa, 0xcc, 0x2c, 0x54,
		0x99, 0x6c, 0xe7, 0x27, 0x81, 0x7e, 0xb7, 0xfe, 0x42, 0x6c, 0xc5, 0x9b, 0xf5, 0x1b, 0x34, 0xeb,
		0x57, 0x27, 0x70, 0x43, 0xb3, 0x3e, 0xcd, 0xfa, 0x85, 0xed, 0x24, 0xcd, 0xfa, 0x34, 0xeb, 0x57,
		0x0f, 0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3, 0x09, 0xf0, 0xb0,
		0x61, 0xd6, 0x34, 0xeb, 0xab, 0x5b, 0x77, 0x9a, 0xf5, 0x15, 0x5f, 0x9c, 0xc8, 0xfe, 0x6a, 0x19,
		0x44, 0xf6, 0xad, 0xcd, 0x5f, 0x5e, 0x35, 0x89, 0xec, 0xaf, 0xa9, 0x26, 0xcd, 0xfa, 0xd6, 0x0e,
		0x81, 0x9d, 0x54, 0x4a, 0xe6, 0x36, 0x57, 0x5b, 0x9a, 0xf5, 0xb3, 0xe8, 0x05, 0xcd, 0xfa, 0x50,
		0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0x4f, 0xb3, 0x7e, 0x25, 0x9c, 0x16, 0x9a,
		0xf5, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x24, 0xcf, 0x3b, 0xcd, 0xfa,
		0x34, 0xeb, 0x1b, 0x98, 0x16, 0x9a, 0xf5, 0x57, 0xcb, 0x20, 0x05, 0x61, 0x6d, 0x87, 0xf3, 0xaa,
		0x49, 0xb3, 0x3e, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27, 0x95, 0xcc, 0xc3, 0xe6, 0x6a, 0x4b, 0xb3,
		0x3e, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b, 0xcd, 0xfa, 0xf0,
		0x69, 0x3b, 0xd2, 0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0x4d, 0xb3, 0x3e, 0x8c, 0x1a, 0x46,
		0x5d, 0x4a, 0x49, 0x34, 0xeb, 0x3b, 0xd3, 0xac, 0xbf, 0xe8, 0x01, 0xaf, 0x4a, 0xaf, 0xfe, 0x4e,
		0x89, 0xb5, 0x56, 0x5b, 0x5b, 0x4b, 0xa4, 0xa5, 0x35, 0x95, 0x19, 0x0c, 0xf1, 0x74, 0x90, 0x44,
		0x29, 0xeb, 0xea, 0x2e, 0x5e, 0xaf, 0x9d, 0xbe, 0x9d, 0xd7, 0x4b, 0xdf, 0xc9, 0x3b, 0xb9, 0x1d,
		0x7b, 0xdd, 0xf4, 0x4d, 0xbc, 0xe6, 0x4d, 0xd8, 0xf7, 0x6f, 0x42, 0xaf, 0xf3, 0xe2, 0xcd, 0x38,
		0x6a, 0x8f, 0xef, 0x0f, 0xaf, 0x16, 0x8b, 0xf7, 0x16, 0x81, 0xa2, 0xce, 0x7c, 0xed, 0x3b, 0xe5,
		0xd4, 0x78, 0x99, 0x27, 0x0b, 0x9d, 0x21, 0xad, 0xb3, 0xe3, 0xf6, 0x99, 0x11, 0x3c, 0x26, 0x85,
		0x1e, 0x0f, 0x99, 0x23, 0x51, 0xbc, 0xc2, 0x0a, 0x28, 0x6b, 0x6d, 0x12, 0x27, 0x41, 0x7d, 0x3c,
		0x1a, 0x86, 0x83, 0x8f, 0xb3, 0x6f, 0xb7, 0x2f, 0xa6, 0xae, 0xab, 0x29, 0x2f, 0x8f, 0x25, 0x0a,
		0x1d, 0x41, 0xd9, 0x01, 0x2f, 0xe2, 0x41, 0x7f, 0x8d, 0xe0, 0xbe, 0x5e, 0x10, 0x5f, 0x2b, 0x58,
		0xaf, 0x1e, 0x94, 0x57, 0x0f, 0xbe, 0xab, 0x06, 0xd9, 0xcb, 0x05, 0xba, 0xd2, 0x03, 0x54, 0x6a,
		0x39, 0x1f, 0x50, 0x5c, 0x95, 0x1f, 0x74, 0x76, 0x69, 0x79, 0x9e, 0x4a, 0x53, 0xb1, 0xd4, 0x32,
		0xa6, 0x9a, 0x19, 0x52, 0xfd, 0x8c, 0xa8, 0x76, 0x06, 0xd4, 0x2c, 0xe3, 0x69, 0x96, 0xe1, 0x34,
		0xc9, 0x68, 0x96, 0x3b, 0x6a, 0xa0, 0x35, 0xc5, 0xaa, 0x36, 0x58, 0xda, 0x10, 0xe5, 0x29, 0x85,
		0xa9, 0xdc, 0x8a, 0x8f, 0x29, 0xdc, 0x65, 0x4c, 0x61, 0xf9, 0x0d, 0xb6, 0xb9, 0xe1, 0x36, 0x37,
		0xe0, 0xa6, 0x86, 0x5c, 0xc7, 0xa0, 0x2b, 0x19, 0x76, 0x75, 0x03, 0x9f, 0x09, 0x64, 0x4c, 0x21,
		0x75, 0x8d, 0xcf, 0xaa, 0x0f, 0x0e, 0xd6, 0x20, 0xe1, 0x0c, 0x58, 0x38, 0x03, 0x1a, 0x4e, 0x80,
		0x87, 0x2e, 0x88, 0x28, 0x83, 0x49, 0xb6, 0xc3, 0x8c, 0x29, 0x64, 0x4c, 0xa1, 0xe6, 0x8b, 0x53,
		0xd3, 0xb8, 0x5a, 0x06, 0x35, 0x8d, 0xd6, 0xe6, 0x2f, 0xaf, 0x9a, 0xd4, 0x34, 0xae, 0xa9, 0x26,
		0x63, 0x0a, 0xad, 0x1d, 0x02, 0x3b, 0xa9, 0x34, 0x0b, 0x6e, 0xae, 0xb6, 0x8c, 0x29, 0xcc, 0xa2,
		0x17, 0x8c, 0x29, 0x84, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xca, 0x52, 0x79, 0xc6, 0x14,
		0x56, 0xc2, 0x69, 0x61, 0x4c, 0x21, 0xee, 0x02, 0xee, 0x02, 0xee, 0x02, 0xee, 0x02, 0xee, 0x82,
		0xe4, 0x79, 0x67, 0x4c, 0x21, 0x63, 0x0a, 0x0d, 0x4c, 0x0b, 0x63, 0x0a, 0x57, 0xcb, 0x20, 0x05,
		0x61, 0x6d, 0x87, 0xf3, 0xaa, 0xc9, 0x98, 0x42, 0x54, 0xd3, 0x15, 0x87, 0xc4, 0x4e, 0x2a, 0x99,
		0x87, 0xcd, 0xd5, 0x96, 0x31, 0x85, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xd7,
		0x3c, 0xef, 0x8c, 0x29, 0x84, 0x4f, 0xdb, 0x91, 0x16, 0x4a, 0xfa, 0xe0, 0xd3, 0x8e, 0xf2, 0x69,
		0xc6, 0x14, 0xc2, 0xa8, 0x61, 0xd4, 0xa5, 0x94, 0xc4, 0x98, 0x42, 0xb5, 0x61, 0x56, 0x8f, 0x87,
		0x14, 0xe5, 0x87, 0x14, 0xa6, 0x2d, 0xe0, 0x55, 0x99, 0x52, 0xa8, 0x32, 0xcd, 0xce, 0x4f, 0x02,
		0xfd, 0x5e, 0xfd, 0x85, 0xd8, 0x8a, 0xb7, 0xea, 0x37, 0x68, 0xd5, 0xaf, 0x4e, 0xd8, 0x86, 0x56,
		0x7d, 0x5a, 0xf5, 0x0b, 0xdb, 0x49, 0x5a, 0xf5, 0x69, 0xd5, 0xaf, 0x1e, 0x28, 0xd8, 0x83, 0x83,
		0x35, 0x48, 0x38, 0x03, 0x16, 0xce, 0x80, 0x86, 0x13, 0xe0, 0x61, 0xc3, 0xab, 0x69, 0xd5, 0x57,
		0xb7, 0xee, 0xb4, 0xea, 0x2b, 0xbe, 0x38, 0x71, 0xfd, 0xd5, 0x32, 0x88, 0xeb, 0x5b, 0x9b, 0xbf,
		0xbc, 0x6a, 0x12, 0xd7, 0x5f, 0x53, 0x4d, 0x5a, 0xf5, 0xad, 0x1d, 0x02, 0x3b, 0xa9, 0x14, 0xcc,
		0x6d, 0xae, 0xb6, 0xb4, 0xea, 0x67, 0xd1, 0x0b, 0x5a, 0xf5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c,
		0x54, 0xbe, 0xb2, 0x54, 0x9e, 0x56, 0xfd, 0x4a, 0x38, 0x2d, 0xb4, 0xea, 0xe3, 0x2e, 0xe0, 0x2e,
		0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0x48, 0x9e, 0x77, 0x5a, 0xf5, 0x69, 0xd5, 0x37, 0x30, 0x2d,
		0xb4, 0xea, 0xaf, 0x96, 0x41, 0x0a, 0xc2, 0xda, 0x0e, 0xe7, 0x55, 0x93, 0x56, 0x7d, 0x54, 0xd3,
		0x15, 0x87, 0xc4, 0x4e, 0x2a, 0x99, 0x87, 0xcd, 0xd5, 0x96, 0x56, 0x7d, 0x48, 0x3d, 0xa4, 0x1e,
		0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x6b, 0x9e, 0x77, 0x5a, 0xf5, 0xe1, 0xd3, 0x76, 0xa4, 0x85, 0x92,
		0x3e, 0xf8, 0xb4, 0xa3, 0x7c, 0x9a, 0x56, 0x7d, 0x18, 0x35, 0x8c, 0xba, 0x94, 0x92, 0x68, 0xd5,
		0x77, 0xa4, 0x55, 0x7f, 0xd1, 0x01, 0x5e, 0x95, 0x4e, 0xfd, 0x9d, 0x12, 0xeb, 0xac, 0xb6, 0xae,
		0x96, 0x46, 0x47, 0x6b, 0x2a, 0xf3, 0x17, 0xe2, 0xe9, 0x20, 0x89, 0x52, 0xc6, 0xd5, 0x5d, 0xbc,
		0x5c, 0x3b, 0x7d, 0x37, 0xaf, 0x97, 0xbe, 0x91, 0x77, 0x72, 0x3b, 0xf6, 0xba, 0xe9, 0x7b, 0x78,
		0xcd, 0x9b, 0xb0, 0xef, 0xdf, 0x84, 0x5e, 0x3f, 0x4e, 0x82, 0xde, 0x7c, 0xed, 0xed, 0xf1, 0xfd,
		0xbe, 0xb7, 0x08, 0x11, 0x75, 0xe6, 0x2b, 0xdf, 0x29, 0xa7, 0xb6, 0xcb, 0x3c, 0x59, 0xe8, 0xfc,
		0x68, 0x9d, 0x1b, 0x97, 0xcf, 0x8b, 0xe0, 0x11, 0x29, 0xf0, 0x68, 0xc8, 0x1c, 0x87, 0xe2, 0x95,
		0x55, 0x40, 0x51, 0x6b, 0x8f, 0xbe, 0xd8, 0xa1, 0x98, 0xaa, 0xae, 0x66, 0xbb, 0x3c, 0x96, 0x28,
		0x74, 0xfc, 0x64, 0xc7, 0xba, 0x88, 0x87, 0xfa, 0x35, 0x42, 0xfa, 0x7a, 0xa1, 0x7b, 0xad, 0x10,
		0xbd, 0x7a, 0x28, 0x5e, 0x3d, 0xe4, 0xae, 0x1a, 0x5a, 0x2f, 0x17, 0xe0, 0x4a, 0x8f, 0x4d, 0xa9,
		0xe5, 0xbc, 0x3f, 0x71, 0x55, 0x7e, 0xd0, 0xcf, 0xa5, 0xe5, 0x73, 0x2a, 0xcd, 0xc2, 0x52, 0xcb,
		0x93, 0x6a, 0xe6, 0x45, 0xf5, 0xf3, 0xa0, 0xda, 0x79, 0x4f, 0xb3, 0x3c, 0xa7, 0x59, 0x5e, 0xd3,
		0x24, 0x8f, 0x59, 0xee, 0x68, 0x81, 0xd6, 0xec, 0xaa, 0xda, 0x60, 0x69, 0x43, 0x94, 0x67, 0x13,
		0xa6, 0x72, 0x2b, 0x3e, 0x9c, 0x70, 0x97, 0xe1, 0x84, 0xe5, 0x37, 0xd8, 0xe6, 0x86, 0xdb, 0xdc,
		0x80, 0x9b, 0x1a, 0x72, 0x1d, 0x83, 0xae, 0x64, 0xd8, 0xd5, 0x0d, 0x7c, 0x26, 0x90, 0xe1, 0x84,
		0x54, 0x33, 0x3e, 0xab, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x33, 0x60, 0xe1, 0x0c, 0x68, 0x38, 0x01,
		0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x33, 0x9c, 0x90, 0xe1, 0x84, 0x9a, 0x2f, 0x4e,
		0x25, 0xe3, 0x6a, 0x19, 0x54, 0x32, 0x5a, 0x9b, 0xbf, 0xbc, 0x6a, 0x52, 0xc9, 0xb8, 0xa6, 0x9a,
		0x0c, 0x27, 0xb4, 0x76, 0x08, 0xec, 0xa4, 0xd2, 0x22, 0xb8, 0xb9, 0xda, 0x32, 0x9c, 0x30, 0x8b,
		0x5e, 0x30, 0x9c, 0x10, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x2b, 0x4b, 0xe5, 0x19, 0x4e,
		0x58, 0x09, 0xa7, 0x85, 0xe1, 0x84, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b,
		0x92, 0xe7, 0x9d, 0xe1, 0x84, 0x0c, 0x27, 0x34, 0x30, 0x2d, 0x0c, 0x27, 0x5c, 0x2d, 0x83, 0x14,
		0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0xc3, 0x09, 0x51, 0x4d, 0x57, 0x1c, 0x12, 0x3b, 0xa9, 0x64,
		0x1e, 0x36, 0x57, 0x5b, 0x86, 0x13, 0x42, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e,
		0xf3, 0xbc, 0x33, 0x9c, 0x10, 0x3e, 0x6d, 0x47, 0x5a, 0x28, 0xe9, 0x83, 0x4f, 0x3b, 0xca, 0xa7,
		0x19, 0x4e, 0x08, 0xa3, 0x86, 0x51, 0x97, 0x52, 0x12, 0xc3, 0x09, 0xad, 0x06, 0x59, 0x1d, 0xe6,
		0x87, 0x13, 0xa6, 0x2d, 0xe0, 0x55, 0x99, 0x4e, 0xa8, 0x32, 0xc7, 0xce, 0x4f, 0x02, 0xfd, 0x5e,
		0xfd, 0x85, 0xd8, 0x8a, 0xb7, 0xea, 0x37, 0x68, 0xd5, 0xaf, 0x4e, 0xd8, 0x86, 0x56, 0x7d, 0x5a,
		0xf5, 0x0b, 0xdb, 0x49, 0x5a, 0xf5, 0x69, 0xd5, 0xaf, 0x1e, 0x28, 0xd8, 0x83, 0x83, 0x35, 0x48,
		0x38, 0x03, 0x16, 0xce, 0x80, 0x86, 0x13, 0xe0, 0x61, 0xc3, 0xab, 0x69, 0xd5, 0x57, 0xb7, 0xee,
		0xb4, 0xea, 0x2b, 0xbe, 0x38, 0x71, 0xfd, 0xd5, 0x32, 0x88, 0xeb, 0x5b, 0x9b, 0xbf, 0xbc, 0x6a,
		0x12, 0xd7, 0x5f, 0x53, 0x4d, 0x5a, 0xf5, 0xad, 0x1d, 0x02, 0x3b, 0xa9, 0x14, 0xcc, 0x6d, 0xae,
		0xb6, 0xb4, 0xea, 0x67, 0xd1, 0x0b, 0x5a, 0xf5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe,
		0xb2, 0x54, 0x9e, 0x56, 0xfd, 0x4a, 0x38, 0x2d, 0xb4, 0xea, 0xe3, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e,
		0xe0, 0x2e, 0xe0, 0x2e, 0x48, 0x9e, 0x77, 0x5a, 0xf5, 0x69, 0xd5, 0x37, 0x30, 0x2d, 0xb4, 0xea,
		0xaf, 0x96, 0x41, 0x0a, 0xc2, 0xda, 0x0e, 0xe7, 0x55, 0x93, 0x56, 0x7d, 0x54, 0xd3, 0x15, 0x87,
		0xc4, 0x4e, 0x2a, 0x99, 0x87, 0xcd, 0xd5, 0x96, 0x56, 0x7d, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f,
		0xa9, 0x87, 0xd4, 0x6b, 0x9e, 0x77, 0x5a, 0xf5, 0xe1, 0xd3, 0x76, 0xa4, 0x85, 0x92, 0x3e, 0xf8,
		0xb4, 0xa3, 0x7c, 0x9a, 0x56, 0x7d, 0x18, 0x35, 0x8c, 0xba, 0x94, 0x92, 0x68, 0xd5, 0x77, 0xa4,
		0x55, 0x7f, 0xd1, 0x01, 0x5e, 0x95, 0x4e, 0xfd, 0x9d, 0x12, 0xeb, 0xac, 0xb6, 0xae, 0x96, 0x46,
		0x47, 0x6b, 0x2a, 0xf3, 0x17, 0xe2, 0xe9, 0x20, 0x89, 0x52, 0xc6, 0xd5, 0x5d, 0xbc, 0x5c, 0x3b,
		0x7d, 0x37, 0xaf, 0x97, 0xbe, 0x91, 0x77, 0x72, 0x3b, 0xf6, 0xba, 0xe9, 0x7b, 0x78, 0xcd, 0x9b,
		0xb0, 0xef, 0xdf, 0x84, 0x5e, 0x3f, 0x4e, 0x82, 0xde, 0x7c, 0xed, 0xed, 0xf1, 0xfd, 0xa1, 0xb7,
		0x08, 0x11, 0x75, 0xe6, 0x2b, 0xdf, 0x29, 0xa7, 0xb6, 0xcb, 0x3c, 0x59, 0xe8, 0xfc, 0x68, 0x9d,
		0x1b, 0x97, 0xcf, 0x8b, 0xe0, 0x11, 0x29, 0xf0, 0x68, 0xc8, 0x1c, 0x87, 0xe2, 0x95, 0x55, 0x40,
		0x51, 0x85, 0x07, 0xbc, 0xa8, 0x0c, 0x74, 0x11, 0x1e, 0xe0, 0x22, 0x3e, 0xb0, 0x45, 0x23, 0x78,
		0xaf, 0x17, 0xa4, 0xd7, 0x0a, 0xc6, 0xab, 0x07, 0xdd, 0xd5, 0x83, 0xeb, 0xaa, 0x41, 0xf4, 0x72,
		0x41, 0xab, 0xf4, 0x80, 0x94, 0x9a, 0x3f, 0x48, 0xc2, 0x7b, 0x05, 0x25, 0x5e, 0x1e, 0xcb, 0x54,
		0x9e, 0xb0, 0x42, 0xe9, 0xc4, 0xa7, 0xd4, 0xb2, 0xa0, 0x9a, 0x59, 0x4f, 0xfd, 0x2c, 0xa7, 0x76,
		0x56, 0xd3, 0x2c, 0x8b, 0x69, 0x96, 0xb5, 0x34, 0xc9, 0x52, 0x96, 0x3b, 0x16, 0xa0, 0x96, 0x75,
		0x34, 0xe8, 0x34, 0x52, 0xea, 0x2c, 0x12, 0xa4, 0xc7, 0x82, 0x5e, 0xdd, 0x92, 0xe2, 0xd5, 0x53,
		0xc2, 0xa5, 0x85, 0x8b, 0x39, 0xb1, 0xc0, 0x23, 0xf0, 0x08, 0x3c, 0x02, 0x8f, 0xc0, 0x63, 0x76,
		0xde, 0xc2, 0xeb, 0x20, 0x4a, 0xc2, 0xe4, 0x63, 0x1c, 0xdc, 0x68, 0x42, 0xa4, 0x42, 0xd9, 0x4d,
		0xad, 0x9d, 0xbe, 0xda, 0x89, 0x3f, 0x31, 0x18, 0x41, 0xdc, 0x7c, 0xd5, 0xf6, 0xfa, 0xb3, 0xff,
		0x73, 0xf9, 0x47, 0xaf, 0xa5, 0x75, 0xd4, 0xe7, 0x99, 0xfb, 0x89, 0x6a, 0x69, 0x91, 0x51, 0x95,
		0x70, 0xe7, 0xc5, 0x9b, 0x5e, 0xd7, 0x6b, 0xf7, 0xde, 0xec, 0x7b, 0x57, 0xdd, 0xf6, 0x69, 0xb3,
		0x7f, 0x59, 0xab, 0x62, 0x71, 0xb6, 0xd5, 0xee, 0xb6, 0xbb, 0xff, 0xe8, 0x5f, 0x36, 0x2f, 0x5b,
		0x6c, 0x6a, 0x71, 0x9b, 0x3a, 0x57, 0xd6, 0x4e, 0xf3, 0xa4, 0xd5, 0x69, 0xbd, 0x44, 0x69, 0x05,
		0x94, 0xb6, 0x31, 0x33, 0x09, 0x6f, 0x7a, 0x9d, 0x3e, 0xbb, 0x2a, 0x60, 0x0a, 0xbc, 0x7e, 0xef,
		0x15, 0x1b, 0x2b, 0x80, 0x60, 0x87, 0x18, 0x03, 0x11, 0x63, 0x7b, 0x88, 0xb1, 0x95, 0x36, 0xb6,
		0xad, 0x37, 0xbd, 0x2e, 0xbb, 0x5a, 0xb0, 0xd6, 0xa2, 0xad, 0x85, 0xef, 0x6b, 0xff, 0xe2, 0xb2,
		0xe5, 0xf5, 0xce, 0x3b, 0xed, 0xd3, 0x3f, 0xe6, 0x9c, 0x81, 0xbd, 0x15, 0x61, 0x62, 0x67, 0x57,
		0x9d, 0x4b, 0x74, 0x57, 0x82, 0x36, 0xbc, 0xea, 0x9c, 0xff, 0xb3, 0xdf, 0x6b, 0x9d, 0xb2, 0xb1,
		0x12, 0x9e, 0x2d, 0x28, 0x56, 0xe8, 0xc6, 0xbe, 0xe9, 0x75, 0x51, 0x59, 0x0d, 0x1c, 0x3b, 0x64,
		0x6f, 0x0b, 0xb6, 0xb3, 0xf8, 0x5e, 0x92, 0x3c, 0xd7, 0xc2, 0x3f, 0x50, 0x91, 0xf4, 0xae, 0xec,
		0x79, 0xad, 0x52, 0xd6, 0x14, 0x04, 0x91, 0xff, 0x7e, 0x18, 0x5c, 0xeb, 0x55, 0x13, 0x2c, 0x05,
		0x0a, 0x67, 0x01, 0x95, 0x07, 0xa0, 0x53, 0xb7, 0x50, 0x80, 0x6a, 0x50, 0xb7, 0x50, 0xb8, 0x60,
		0xea, 0x16, 0xca, 0xe2, 0x65, 0x50, 0xd6, 0xb7, 0xad, 0x10, 0xac, 0x76, 0xe9, 0xe7, 0xc3, 0xdb,
		0x49, 0x34, 0x2e, 0xf8, 0x54, 0xba, 0xd5, 0x19, 0x50, 0x04, 0x14, 0x01, 0xc5, 0x6a, 0x82, 0xa2,
		0xd6, 0x2d, 0xcc, 0xb5, 0x79, 0xef, 0xed, 0x50, 0x83, 0x09, 0xad, 0x9d, 0xf0, 0x95, 0x68, 0xdd,
		0xcb, 0xf6, 0x77, 0xb5, 0x2f, 0xdb, 0xdf, 0xe5, 0xb2, 0xfd, 0xf2, 0x9b, 0x6d, 0x73, 0xf3, 0x6d,
		0x6e, 0xc6, 0x4d, 0xcd, 0xb9, 0x8e, 0x59, 0x57, 0x32, 0xef, 0xfa, 0xdc, 0x67, 0xed, 0xbc, 0xaa,
		0xdf, 0x87, 0x6c, 0x70, 0x0f, 0xb2, 0xd1, 0xb0, 0x44, 0x83, 0xb1, 0x98, 0x96, 0xc3, 0x11, 0x8d,
		0x27, 0xcf, 0x59, 0x0f, 0x43, 0x74, 0x61, 0xce, 0x9c, 0xc1, 0xf0, 0x43, 0xd3, 0xa1, 0x87, 0xae,
		0xa8, 0x9c, 0xf5, 0xbd, 0xc5, 0x4e, 0xe8, 0x5e, 0x45, 0x67, 0xfe, 0xbd, 0xab, 0xca, 0xfc, 0x37,
		0x85, 0x08, 0x4a, 0x1c, 0x0c, 0x82, 0xf0, 0xde, 0x82, 0x43, 0x66, 0x92, 0xa1, 0x90, 0x50, 0x48,
		0x28, 0x24, 0x14, 0x12, 0x0a, 0x09, 0x85, 0x84, 0x42, 0x42, 0x21, 0xa1, 0x90, 0x50, 0x48, 0x28,
		0x24, 0x14, 0x12, 0x0a, 0x59, 0x2e, 0x0a, 0x59, 0x1f, 0xc7, 0xcb, 0x29, 0xbe, 0x76, 0x6c, 0xf2,
		0xe1, 0x22, 0x20, 0x96, 0x10, 0x4b, 0x88, 0x25, 0xc4, 0x12, 0x62, 0x09, 0xb1, 0x84, 0x58, 0x42,
		0x2c, 0x21, 0x96, 0x10, 0x4b, 0x88, 0x25, 0xc4, 0x12, 0x62, 0x59, 0x0e, 0x62, 0x39, 0x59, 0x38,
		0x83, 0xca, 0x4c, 0x72, 0x2e, 0x15, 0xea, 0x08, 0x75, 0x84, 0x3a, 0x42, 0x1d, 0xa1, 0x8e, 0x50,
		0x47, 0xa8, 0x23, 0xd4, 0x11, 0xea, 0x08, 0x75, 0x84, 0x3a, 0x42, 0x1d, 0xa1, 0x8e, 0xae, 0x4b,
		0xe0, 0x5a, 0x63, 0xb9, 0x6b, 0x5a, 0x13, 0x3f, 0x09, 0x9e, 0x2b, 0x75, 0xe2, 0x3f, 0xdb, 0xf4,
		0xb2, 0xd6, 0xde, 0x72, 0x9d, 0xdc, 0x5a, 0x2c, 0x7f, 0x3c, 0xb6, 0xf2, 0xd6, 0x62, 0xb9, 0xbb,
		0xe6, 0xcb, 0x71, 0x09, 0xf0, 0x74, 0x12, 0xd4, 0xef, 0xa6, 0xc3, 0x24, 0x1c, 0x0f, 0x83, 0xfa,
		0xec, 0x93, 0x4c, 0xe4, 0x6f, 0x04, 0xfe, 0x8c, 0xcc, 0x92, 0x5f, 0x0f, 0xbc, 0xcb, 0xf5, 0xc0,
		0xee, 0xc4, 0xd6, 0xb8, 0x1e, 0x78, 0x8b, 0x31, 0x4c, 0xfc, 0x7a, 0xe0, 0xc1, 0xf2, 0xcc, 0x2b,
		0x0d, 0x4d, 0x4a, 0xe5, 0x31, 0x32, 0xc9, 0x35, 0xc3, 0xa9, 0x6f, 0x40, 0xb5, 0x0d, 0xa9, 0x99,
		0x41, 0x35, 0x33, 0xac, 0x26, 0x06, 0xb6, 0x1a, 0x9c, 0x5a, 0x6d, 0x64, 0x92, 0xd6, 0xe8, 0xd8,
		0xb5, 0xf3, 0xad, 0x33, 0x42, 0x76, 0xb5, 0xa1, 0xba, 0xa3, 0x64, 0x1f, 0x43, 0x01, 0xf9, 0xec,
		0x32, 0x43, 0x84, 0x15, 0x54, 0x98, 0x43, 0x86, 0x39, 0x74, 0x98, 0x42, 0x88, 0x0e, 0x94, 0x28,
		0x41, 0x4a, 0xb6, 0x93, 0x76, 0xf9, 0x6c, 0xbd, 0x51, 0xb5, 0x6b, 0x9e, 0xf8, 0x1e, 0x99, 0x02,
		0x07, 0xbc, 0x9a, 0x2d, 0xce, 0x14, 0xac, 0x47, 0xe9, 0x9e, 0xa7, 0x5c, 0x94, 0x61, 0xca, 0xeb,
		0x4e, 0xe9, 0xcc, 0xbc, 0xeb, 0x5d, 0x66, 0x20, 0xef, 0x44, 0x10, 0x11, 0x20, 0x22, 0x40, 0x44,
		0x80, 0x88, 0x40, 0x19, 0x22, 0x02, 0x4a, 0x21, 0xd9, 0xb5, 0xe3, 0xad, 0x12, 0x9a, 0x55, 0x36,
		0xc8, 0xf0, 0x72, 0x78, 0x39, 0xbc, 0x1c, 0x5e, 0xee, 0x92, 0x81, 0xcf, 0x04, 0xfa, 0xc3, 0xe1,
		0xe8, 0xcf, 0x15, 0x29, 0xf1, 0x27, 0xfa, 0xe7, 0x67, 0x69, 0x31, 0xd6, 0x97, 0xa2, 0xac, 0xc6,
		0x46, 0xe1, 0xe1, 0xc7, 0x70, 0xa4, 0x5c, 0x2c, 0xab, 0x0e, 0x4b, 0x96, 0xf0, 0x64, 0x0f, 0x53,
		0xd6, 0x70, 0xe5, 0x0c, 0x6c, 0x39, 0x03, 0x5f, 0x4e, 0xc0, 0x98, 0x2e, 0x9c, 0x29, 0xc3, 0x5a,
		0xb6, 0xc3, 0xea, 0x61, 0xe7, 0xb5, 0xf3, 0xae, 0x1f, 0x7e, 0x5e, 0x63, 0x1b, 0x7b, 0x15, 0x2d,
		0xc4, 0xaf, 0x96, 0x27, 0xa6, 0x1c, 0xa6, 0xce, 0xe4, 0xba, 0x1d, 0xae, 0x0e, 0x66, 0xbf, 0xad,
		0x11, 0xb3, 0xd6, 0x53, 0x2a, 0x95, 0x96, 0xfd, 0x79, 0x4d, 0xb4, 0x7e, 0xcf, 0xfe, 0x5c, 0x6c,
		0xc5, 0x83, 0x29, 0x0d, 0x82, 0x29, 0x04, 0x53, 0x08, 0xa6, 0x00, 0xe1, 0x04, 0x53, 0x08, 0xa6,
		0x10, 0x4c, 0x21, 0x98, 0x42, 0x30, 0x85, 0x60, 0x0a, 0xc1, 0x14, 0x82, 0x29, 0x04, 0x53, 0x08,
		0xa6, 0xb8, 0x1f, 0x4c, 0x11, 0x6c, 0x97, 0x36, 0x88, 0xa5, 0x50, 0x99, 0x5a, 0x29, 0xed, 0x74,
		0x7d, 0x98, 0xc5, 0xd5, 0x24, 0x38, 0x4b, 0x57, 0xdd, 0x9b, 0x2d, 0xda, 0x6b, 0x89, 0xfb, 0x19,
		0xe5, 0x2c, 0xa6, 0xd5, 0x09, 0x40, 0xaa, 0x06, 0x1e, 0xd5, 0xcb, 0x69, 0x1b, 0x94, 0xd3, 0x96,
		0x87, 0xa1, 0x51, 0x4e, 0x4b, 0x39, 0xed, 0x97, 0x63, 0x54, 0x34, 0xd8, 0x16, 0xbc, 0xa1, 0x34,
		0xd8, 0x56, 0x25, 0xb8, 0x47, 0xee, 0x89, 0xdc, 0x13, 0xb9, 0xa7, 0xf2, 0x04, 0xe7, 0x68, 0xb0,
		0xc5, 0xab, 0x21, 0x8c, 0xb1, 0x1e, 0xc6, 0x50, 0x88, 0xaf, 0x31, 0xec, 0x52, 0x55, 0xf1, 0xdc,
		0x56, 0xb8, 0x9a, 0x68, 0x14, 0xa7, 0xb8, 0x50, 0x59, 0x69, 0x26, 0x74, 0xee, 0x38, 0xac, 0xfa,
		0x33, 0x97, 0x71, 0x5e, 0x6d, 0x91, 0xea, 0x43, 0x7d, 0xfe, 0x6d, 0x0a, 0x96, 0xd1, 0x09, 0x27,
		0x49, 0x33, 0x49, 0x64, 0xa8, 0x6a, 0xed, 0x2c, 0x8c, 0x5a, 0xc3, 0x60, 0xe6, 0xf4, 0x4d, 0x64,
		0x08, 0x4d, 0xed, 0xcc, 0xff, 0xeb, 0x81, 0x84, 0xbd, 0x5f, 0xf6, 0xf7, 0x0f, 0x8f, 0xf6, 0xf7,
		0x77, 0x8f, 0x5e, 0x1c, 0xed, 0x1e, 0x1f, 0x1c, 0xec, 0x1d, 0xee, 0x09, 0x0c, 0x65, 0xaf, 0x9d,
		0xc7, 0xd7, 0x41, 0x1c, 0x5c, 0x9f, 0xcc, 0x3e, 0x4f, 0x34, 0x1d, 0x0e, 0x9d, 0xd6, 0x22, 0x61,
		0xc3, 0xe9, 0x90, 0xc1, 0x14, 0xb0, 0x8e, 0x9b, 0x58, 0xc5, 0x62, 0x8d, 0x60, 0x71, 0xa6, 0xaa,
		0x98, 0x27, 0x15, 0xa4, 0xa6, 0x52, 0xea, 0x69, 0xaf, 0x96, 0xc5, 0x7c, 0xfe, 0xcd, 0x3f, 0x56,
		0x01, 0x1f, 0xaa, 0xe6, 0x8f, 0xc7, 0xc3, 0x8f, 0x45, 0xdf, 0x33, 0xbe, 0x2a, 0x27, 0x7c, 0xf8,
		0xf4, 0x82, 0xd4, 0xaa, 0xd8, 0xfc, 0x4d, 0xe1, 0x41, 0x39, 0x89, 0xa0, 0xdb, 0xc3, 0xa0, 0x5a,
		0x3c, 0x1e, 0x0d, 0x0b, 0x34, 0x87, 0x52, 0x51, 0x33, 0xf1, 0xa8, 0x98, 0x78, 0xd4, 0xeb, 0x71,
		0x54, 0x6b, 0xbe, 0xf1, 0x15, 0x35, 0xd5, 0x45, 0x67, 0x34, 0xa4, 0x06, 0x81, 0xc8, 0x0e, 0xfc,
		0x10, 0x4a, 0x0d, 0x8b, 0xc5, 0xfd, 0x25, 0xe3, 0xfb, 0x82, 0x26, 0x47, 0xda, 0xf4, 0xa8, 0x99,
		0x20, 0x35, 0x53, 0xa4, 0x63, 0x92, 0xca, 0x41, 0x9d, 0xa5, 0x92, 0xaf, 0xb5, 0xeb, 0x45, 0x12,
		0xb2, 0x1e, 0xfc, 0x35, 0x1e, 0xc5, 0x49, 0xd1, 0x2e, 0xd1, 0x93, 0xe7, 0xeb, 0xf3, 0x62, 0xa5,
		0x66, 0xf2, 0xaf, 0x12, 0xad, 0x17, 0xad, 0xff, 0x6d, 0x9d, 0x5e, 0x7a, 0x17, 0xe7, 0x57, 0x97,
		0x2d, 0xe1, 0x4b, 0x3f, 0x76, 0xb9, 0xf4, 0xc3, 0xd2, 0xce, 0x6a, 0xd9, 0x5b, 0x75, 0xbb, 0xab,
		0x6e, 0x7f, 0x75, 0xed, 0xb0, 0x8c, 0x3d, 0x16, 0xb2, 0xcb, 0xd9, 0xd6, 0x88, 0x67, 0x30, 0xd7,
		0x2c, 0xe7, 0xc2, 0x64, 0xd6, 0x93, 0x99, 0x60, 0xc1, 0xd3, 0xb3, 0x74, 0x0e, 0xf7, 0x05, 0x65,
		0xb4, 0xa2, 0xe9, 0xdd, 0x6c, 0xf3, 0x3e, 0x6d, 0xf1, 0x3d, 0x58, 0xcb, 0xcf, 0x1a, 0xde, 0x99,
		0xe0, 0x70, 0x5e, 0x2c, 0x38, 0x0c, 0x0e, 0x83, 0xc3, 0xe0, 0x30, 0x38, 0x0c, 0x0e, 0x6f, 0x19,
		0x0e, 0x2b, 0xf3, 0x60, 0x15, 0xfe, 0x0b, 0x10, 0x02, 0x84, 0x00, 0x21, 0x40, 0x28, 0x73, 0x62,
		0x86, 0x81, 0x7f, 0x13, 0x07, 0x37, 0x1a, 0xe0, 0x77, 0x24, 0x28, 0xa3, 0x97, 0x65, 0xd6, 0x17,
		0x8a, 0xf4, 0x6b, 0x3c, 0x9a, 0x26, 0x61, 0x74, 0x9b, 0xda, 0xe6, 0xec, 0xaf, 0x53, 0xbc, 0xbf,
		0x0e, 0x6e, 0xc2, 0x28, 0x4c, 0xc2, 0x51, 0x34, 0x79, 0xfa, 0x3f, 0x65, 0xff, 0x65, 0x5e, 0x6f,
		0x51, 0x2a, 0xfd, 0x11, 0xad, 0xa3, 0xca, 0xa4, 0x88, 0xd7, 0x53, 0xad, 0x24, 0x19, 0xd4, 0x55,
		0x65, 0xc2, 0x1f, 0xd6, 0x57, 0x29, 0x35, 0x95, 0x4e, 0x27, 0x41, 0x2c, 0x6d, 0xef, 0x15, 0x5b,
		0x4f, 0x1e, 0x82, 0xd9, 0x68, 0xb1, 0x9b, 0xf5, 0xf7, 0x1f, 0x35, 0x5a, 0x31, 0x2d, 0xda, 0x4c,
		0x72, 0xc0, 0x36, 0xff, 0x92, 0x94, 0x64, 0x97, 0x8e, 0x49, 0x28, 0x47, 0xf2, 0x54, 0x22, 0x78,
		0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30,
		0x09, 0x98, 0x04, 0x4c, 0x42, 0xee, 0x89, 0xf4, 0x4e, 0x7d, 0x65, 0x93, 0xca, 0x83, 0x8e, 0x0b,
		0x91, 0x1b, 0x17, 0x0a, 0xec, 0x56, 0x2a, 0xb0, 0x8b, 0x41, 0x66, 0x50, 0x99, 0xe8, 0x60, 0x32,
		0xf1, 0x6a, 0xf3, 0x06, 0xd5, 0xe6, 0x8a, 0xc8, 0x4a, 0xb5, 0x79, 0x15, 0x61, 0x82, 0x6a, 0xf3,
		0x4d, 0x36, 0x8f, 0x2a, 0x37, 0x42, 0x72, 0x84, 0xe4, 0x08, 0xc9, 0x51, 0xe5, 0xf6, 0xdd, 0xce,
		0x21, 0x55, 0x6e, 0xa2, 0x4a, 0x44, 0xb5, 0x39, 0x38, 0x0c, 0x0e, 0x83, 0xc3, 0xe0, 0x30, 0x38,
		0x0c, 0x0e, 0x1b, 0xe2, 0x30, 0xd5, 0xe6, 0x00, 0x21, 0x40, 0x08, 0x10, 0x02, 0x84, 0x5f, 0x7b,
		0x62, 0xa8, 0x11, 0xa1, 0x46, 0xe4, 0x7b, 0xa5, 0x50, 0x23, 0x22, 0x75, 0x2a, 0xa9, 0x11, 0x29,
		0x29, 0xa8, 0x3d, 0xa3, 0x46, 0xa4, 0x1a, 0x4c, 0x82, 0x6a, 0x73, 0x98, 0x04, 0x4c, 0x02, 0x26,
		0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0xa2, 0xf2, 0x4c,
		0x82, 0x6a, 0x73, 0xeb, 0x6a, 0x73, 0x81, 0x2b, 0xb3, 0xb8, 0x1a, 0xa3, 0x7c, 0x7a, 0x50, 0x2b,
		0xb4, 0xac, 0xff, 0x3b, 0xee, 0x68, 0x99, 0xad, 0xa5, 0xb7, 0x58, 0x4a, 0x95, 0x2e, 0xea, 0x98,
		0xcc, 0x2f, 0x0a, 0xab, 0x8f, 0xc6, 0x73, 0x97, 0x55, 0xe0, 0xae, 0x8e, 0x47, 0x02, 0xb8, 0xae,
		0xa3, 0x88, 0x50, 0x44, 0xb1, 0x77, 0xe0, 0x72, 0x5b, 0xc7, 0xd7, 0x46, 0x12, 0x0a, 0xbd, 0x83,
		0x96, 0xcb, 0x3a, 0x36, 0x3a, 0x06, 0x5c, 0xd6, 0xa1, 0xd8, 0x3e, 0x25, 0x73, 0xe9, 0x36, 0xdd,
		0x53, 0x4e, 0x19, 0xa4, 0x72, 0xb0, 0x1e, 0xb1, 0xe6, 0x29, 0x7f, 0x38, 0x1c, 0xfd, 0x59, 0x1f,
		0xfd, 0x19, 0xd5, 0xfd, 0x89, 0x7c, 0x86, 0x27, 0x27, 0x4d, 0xbe, 0x44, 0x7b, 0x97, 0x24, 0x92,
		0xba, 0x01, 0xd5, 0x33, 0xa4, 0xda, 0xa1, 0xb7, 0xed, 0xcb, 0x21, 0x89, 0x18, 0x5a, 0xe1, 0x70,
		0x58, 0xe9, 0x53, 0x48, 0xd3, 0x30, 0x4a, 0x7e, 0x51, 0x48, 0x20, 0x49, 0xc6, 0xf8, 0x2f, 0xfc,
		0xe8, 0x76, 0xf6, 0x32, 0x6f, 0x45, 0xd5, 0x55, 0x21, 0xd2, 0x7e, 0x16, 0xea, 0x5c, 0xe1, 0xaf,
		0x80, 0x2a, 0x6b, 0xe2, 0xde, 0xf8, 0xc3, 0x69, 0xa0, 0x28, 0xef, 0x55, 0xec, 0x0f, 0x92, 0x70,
		0x14, 0xbd, 0x0c, 0x6f, 0xc3, 0x45, 0x8a, 0x4b, 0x5c, 0xee, 0x27, 0x85, 0xf4, 0xc4, 0x99, 0xff,
		0x57, 0xe5, 0x55, 0xa4, 0x71, 0x70, 0x50, 0x61, 0x25, 0x29, 0x69, 0x3e, 0xe9, 0xdd, 0x36, 0xf7,
		0x9a, 0x86, 0x13, 0xff, 0xfd, 0x30, 0xa8, 0x8f, 0x83, 0x20, 0xae, 0xfb, 0x93, 0xfa, 0x4d, 0x38,
		0x4c, 0x82, 0x58, 0xa1, 0xd9, 0xf4, 0xf3, 0x72, 0xe5, 0xa9, 0xcc, 0x8d, 0x3f, 0x9c, 0x04, 0xd0,
		0x19, 0xe8, 0x0c, 0x74, 0x06, 0x3a, 0x53, 0x26, 0x3a, 0xf3, 0x7e, 0x34, 0x1a, 0x06, 0x7e, 0xa4,
		0x51, 0x11, 0xb7, 0xb7, 0xc5, 0x80, 0x18, 0x07, 0xe3, 0xa1, 0x3f, 0xc8, 0x80, 0x49, 0x1e, 0x09,
		0x1f, 0x0b, 0x04, 0x02, 0x81, 0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x81, 0x40, 0xed, 0x27, 0x52,
		0x63, 0xf8, 0x95, 0xb5, 0x65, 0xf9, 0xba, 0x24, 0x86, 0xda, 0x16, 0x75, 0xc2, 0x19, 0x6a, 0x4b,
		0x55, 0x86, 0x23, 0xae, 0x06, 0x55, 0x19, 0x7a, 0x38, 0x41, 0x55, 0xc6, 0xf7, 0xf0, 0x38, 0xaa,
		0x32, 0xe0, 0x70, 0x70, 0x38, 0x38, 0x5c, 0xa9, 0x38, 0x1c, 0x55, 0x19, 0x5f, 0xfb, 0x87, 0xaa,
		0x8c, 0x8d, 0xc4, 0x51, 0x95, 0x51, 0x8c, 0x8a, 0x50, 0x95, 0x51, 0x72, 0x25, 0xa1, 0x2a, 0x43,
		0x74, 0xbd, 0x54, 0x65, 0x14, 0x40, 0x65, 0x48, 0x49, 0x41, 0x67, 0xa0, 0x33, 0xd0, 0x99, 0xd2,
		0xd1, 0x19, 0x52, 0x52, 0x2a, 0x80, 0x48, 0x55, 0x06, 0x10, 0x08, 0x04, 0x02, 0x81, 0x40, 0x20,
		0x10, 0x58, 0x06, 0x08, 0xa4, 0x2a, 0xc3, 0x81, 0xaa, 0x0c, 0x86, 0x3f, 0x59, 0xab, 0x84, 0x2b,
		0xaa, 0x60, 0x3e, 0xff, 0x69, 0xd2, 0xf3, 0x93, 0x0f, 0xe7, 0xe9, 0x62, 0x2a, 0x34, 0x01, 0xaa,
		0xe0, 0x31, 0x2d, 0x32, 0xe3, 0x59, 0x98, 0xf7, 0xc4, 0xbc, 0x27, 0xe6, 0x3d, 0x15, 0x8a, 0x17,
		0x85, 0xcf, 0x7b, 0xf2, 0xa7, 0xc9, 0x87, 0xfa, 0xd8, 0x9f, 0x4c, 0x52, 0x15, 0x10, 0xaa, 0x2f,
		0xcc, 0x8b, 0x91, 0xa9, 0x33, 0xdc, 0x65, 0xfa, 0x13, 0x75, 0x86, 0x0e, 0x92, 0x66, 0xea, 0x0c,
		0xe5, 0x48, 0xf1, 0x2a, 0x6e, 0xb8, 0x9c, 0xef, 0x2e, 0x63, 0x63, 0x72, 0xee, 0xcc, 0x2f, 0x5b,
		0x50, 0x6f, 0x7e, 0x1d, 0x4c, 0x06, 0x71, 0x38, 0x16, 0x21, 0xab, 0x0f, 0xee, 0xef, 0x5c, 0x09,
		0x01, 0x13, 0xc0, 0x04, 0x30, 0x01, 0x4c, 0x28, 0x50, 0xdf, 0x27, 0x49, 0x1c, 0x46, 0xb7, 0x20,
		0xc1, 0x66, 0xef, 0x1a, 0x44, 0xfe, 0xfb, 0x61, 0x20, 0xc8, 0x0d, 0x96, 0x02, 0x8a, 0xee, 0x6d,
		0x58, 0xa5, 0xf8, 0x66, 0xe7, 0x18, 0x80, 0x01, 0x60, 0x00, 0x18, 0x00, 0xa6, 0x48, 0x7d, 0x97,
		0xcb, 0xc0, 0x09, 0x65, 0xde, 0xdc, 0x44, 0x98, 0xe1, 0x68, 0xe0, 0x0f, 0x25, 0xaa, 0x4b, 0x56,
		0xb7, 0x9a, 0x2d, 0x25, 0x00, 0x02, 0x80, 0x00, 0x20, 0x00, 0x08, 0x14, 0xa8, 0xef, 0xfe, 0xa4,
		0x1e, 0x4d, 0xef, 0xde, 0x8b, 0x94, 0x6b, 0x2f, 0x0d, 0x8c, 0xc0, 0x55, 0x89, 0xc2, 0xcd, 0x54,
		0xb2, 0xd7, 0x0c, 0x2a, 0x94, 0x70, 0xa9, 0x74, 0xc4, 0x68, 0x35, 0x4b, 0x69, 0xf6, 0xbf, 0x7c,
		0x92, 0xbd, 0xf7, 0xb1, 0x72, 0x9f, 0x7e, 0xbf, 0x71, 0xbc, 0x7f, 0x7c, 0x78, 0xd4, 0x38, 0x3e,
		0xa8, 0x90, 0x0e, 0x94, 0xa4, 0x5e, 0xec, 0xdd, 0x16, 0x78, 0xd7, 0xcb, 0xda, 0x9c, 0xba, 0x7f,
		0x7d, 0x1d, 0x07, 0x13, 0x41, 0x2f, 0x7b, 0x4d, 0x12, 0xde, 0x36, 0xde, 0x36, 0xde, 0x36, 0xde,
		0x76, 0x81, 0xfa, 0x1e, 0x8e, 0x85, 0xac, 0x4b, 0x2e, 0xea, 0x72, 0x2c, 0xf0, 0xec, 0x74, 0x6f,
		0x4a, 0xe7, 0x6e, 0xaf, 0x76, 0xfe, 0x7e, 0x5f, 0x70, 0xef, 0xd7, 0xbe, 0xc1, 0x2f, 0xb2, 0xd7,
		0xc3, 0x27, 0x41, 0x1c, 0x89, 0x8f, 0x92, 0xa8, 0xfd, 0xdf, 0x0f, 0x3f, 0xbc, 0xdd, 0xad, 0x1f,
		0xbf, 0xfb, 0xfb, 0xed, 0x5e, 0xfd, 0xf8, 0xdd, 0xe2, 0xc7, 0xbd, 0xf9, 0xff, 0x2c, 0x7e, 0x6e,
		0xbc, 0xdd, 0xad, 0xef, 0x2f, 0x7f, 0x3e, 0x78, 0xbb, 0x5b, 0x3f, 0x78, 0xf7, 0xe3, 0xbf, 0xfe,
		0xf5, 0xf3, 0x8f, 0xff, 0x79, 0xf1, 0xe9, 0xdb, 0x7f, 0xf1, 0x7f, 0xe4, 0x7a, 0x30, 0xde, 0x49,
		0x7e, 0x8c, 0xf3, 0x7e, 0xfb, 0x77, 0xbe, 0x88, 0xa9, 0xeb, 0x2a, 0x4c, 0xde, 0x74, 0xcc, 0xd3,
		0x21, 0xe6, 0xe9, 0xfb, 0x0e, 0x83, 0x5f, 0xbf, 0x69, 0xd6, 0x5f, 0xbd, 0xfb, 0xcf, 0xde, 0x4f,
		0xfb, 0x9f, 0x7e, 0xfd, 0xf1, 0x3f, 0x47, 0x9f, 0x1e, 0xff, 0xe5, 0xdf, 0x9f, 0xfb, 0x67, 0x7b,
		0x3f, 0x1d, 0x7d, 0xfa, 0xf5, 0x89, 0xff, 0x72, 0xf8, 0xe9, 0xd7, 0xaf, 0x7c, 0xc6, 0xc1, 0xa7,
		0x1f, 0xd6, 0xfe, 0xe9, 0xec, 0xef, 0x1b, 0x4f, 0xfd, 0xc2, 0xfe, 0x13, 0xbf, 0xf0, 0xe2, 0xa9,
		0x5f, 0x78, 0xf1, 0xc4, 0x2f, 0x3c, 0xb9, 0xa4, 0xc6, 0x13, 0xbf, 0x70, 0xf0, 0xe9, 0xef, 0xb5,
		0x7f, 0xff, 0xc3, 0xe7, 0xff, 0xe9, 0xe1, 0xa7, 0x1f, 0xff, 0x7e, 0xea, 0xbf, 0x1d, 0x7d, 0xfa,
		0xfb, 0xd7, 0x1f, 0x31, 0xd6, 0xe8, 0xe7, 0xd6, 0xea, 0x27, 0xd1, 0x21, 0x67, 0xa2, 0x43, 0x52,
		0x8d, 0xfd, 0x19, 0x2e, 0xcb, 0x34, 0xf2, 0x13, 0x0b, 0x22, 0x16, 0x44, 0x2c, 0x88, 0xcc, 0x2b,
		0x99, 0x57, 0x4d, 0xae, 0x45, 0xe6, 0xf5, 0xdb, 0xe5, 0x90, 0x79, 0x75, 0xf6, 0xd3, 0x93, 0x79,
		0xc5, 0xb7, 0x16, 0xf7, 0xad, 0x6f, 0xe3, 0xd1, 0x74, 0x2c, 0xec, 0x5e, 0x2f, 0x64, 0xe0, 0x61,
		0xe3, 0x61, 0xe3, 0x61, 0xe3, 0x61, 0x17, 0xa8, 0xef, 0xc3, 0xc0, 0xbf, 0x89, 0x83, 0x1b, 0xc9,
		0x54, 0xab, 0x84, 0x83, 0xdd, 0x4b, 0xe7, 0xde, 0xfc, 0xfc, 0xf3, 0xf3, 0xec, 0xff, 0xad, 0x0c,
		0xe5, 0xe4, 0xc1, 0xcf, 0x0f, 0x7e, 0xac, 0xcf, 0x47, 0xcb, 0x6c, 0x0b, 0x2c, 0x25, 0x12, 0xba,
		0x93, 0x47, 0xa5, 0xb9, 0x08, 0x40, 0x09, 0x50, 0x02, 0x94, 0x00, 0xa5, 0x12, 0x18, 0x97, 0x1c,
		0x2c, 0xed, 0x0b, 0x3c, 0xbb, 0x15, 0x4d, 0xef, 0x66, 0x5b, 0xf3, 0x69, 0x0b, 0x40, 0x26, 0x0e,
		0xee, 0x46, 0xf7, 0x41, 0x7d, 0x1c, 0x87, 0xf7, 0x7e, 0x12, 0x88, 0x66, 0x18, 0xd6, 0x45, 0x01,
		0x3a, 0x80, 0x0e, 0xa0, 0x03, 0xe8, 0x48, 0x1a, 0x99, 0x74, 0xc4, 0xa5, 0x24, 0x06, 0x09, 0x84,
		0x25, 0x6b, 0xed, 0xeb, 0x20, 0x4a, 0xc2, 0xe4, 0xe3, 0x89, 0x3f, 0x09, 0xe4, 0xa7, 0xb9, 0x5f,
		0xb4, 0xce, 0xce, 0xdf, 0xb4, 0xbc, 0xde, 0x45, 0xfb, 0x4d, 0xf3, 0xb2, 0xe5, 0x35, 0xfb, 0xde,
		0x79, 0xef, 0xb2, 0x7d, 0xde, 0x95, 0x3a, 0x72, 0xf3, 0xc8, 0xee, 0x44, 0xb4, 0x2e, 0x45, 0x38,
		0x04, 0xbe, 0xdc, 0xb9, 0x07, 0x5b, 0x96, 0x6e, 0x62, 0xb3, 0xd3, 0xa9, 0x95, 0x31, 0x75, 0x60,
		0xb1, 0x61, 0xbd, 0x4e, 0xf3, 0x54, 0x7a, 0xc7, 0x44, 0x9e, 0xfc, 0xce, 0x75, 0xc3, 0xed, 0xa6,
		0xb3, 0x39, 0x9a, 0x26, 0x41, 0xfd, 0x66, 0xe8, 0x8f, 0xeb, 0xd7, 0xfe, 0xdd, 0x38, 0x8c, 0x6e,
		0x05, 0xbd, 0xcd, 0x75, 0x59, 0x72, 0x83, 0x6b, 0x24, 0xee, 0xa6, 0xc0, 0x9d, 0xc5, 0x9d, 0xc5,
		0x9d, 0x65, 0x72, 0x0d, 0x93, 0x6b, 0x36, 0x7f, 0xd7, 0x49, 0x10, 0x5d, 0xd7, 0x07, 0xa3, 0xbb,
		0xbb, 0x69, 0x14, 0x26, 0x1f, 0xe5, 0x40, 0xe7, 0x91, 0x1c, 0x39, 0xc0, 0xe9, 0x9e, 0x77, 0x5b,
		0xe0, 0x0d, 0x78, 0x03, 0xde, 0x80, 0x37, 0x45, 0xea, 0x7b, 0x66, 0xbb, 0x08, 0xdc, 0x4b, 0x40,
		0x1a, 0x77, 0xda, 0x08, 0xde, 0x69, 0x93, 0xde, 0x89, 0x52, 0xa1, 0xdb, 0x63, 0x82, 0xf7, 0xb7,
		0xe3, 0xfa, 0xdd, 0x74, 0x98, 0x84, 0x1f, 0x46, 0xe3, 0xe2, 0x2f, 0x91, 0xc9, 0x3f, 0x9e, 0xbb,
		0x64, 0xdc, 0xf3, 0x16, 0xb8, 0x4b, 0xc6, 0xc4, 0x1b, 0xa8, 0xf8, 0x5d, 0x32, 0x05, 0x5f, 0x4a,
		0xf5, 0x19, 0x27, 0xa2, 0xc0, 0xcb, 0xa9, 0x84, 0x0c, 0x0b, 0xf4, 0x04, 0x7a, 0x02, 0x3d, 0x29,
		0x38, 0x3e, 0x51, 0xb0, 0xa1, 0x5a, 0xf9, 0x41, 0x42, 0xa3, 0xed, 0xd7, 0x3d, 0x22, 0x91, 0x11,
		0xf7, 0x9f, 0x0b, 0xe0, 0x70, 0x9b, 0xb5, 0x8d, 0xe9, 0xd4, 0x33, 0xa1, 0x5a, 0xa6, 0x54, 0xdd,
		0xa4, 0xaa, 0x9b, 0x56, 0x55, 0x13, 0x2b, 0x63, 0x6a, 0x85, 0x4c, 0xae, 0x7c, 0x64, 0x68, 0xed,
		0xbc, 0x70, 0x9b, 0xb5, 0xc6, 0x47, 0xad, 0x2d, 0x69, 0x79, 0x3d, 0x49, 0x86, 0xf2, 0xb8, 0x97,
		0x93, 0x06, 0x28, 0x01, 0x4a, 0x80, 0x12, 0xa0, 0x54, 0x22, 0x50, 0x9a, 0x86, 0x51, 0xf2, 0x8b,
		0x02, 0x24, 0x09, 0x36, 0xa0, 0x0b, 0x4f, 0x9b, 0x58, 0xfe, 0x91, 0x3d, 0xee, 0xcf, 0xb4, 0xa6,
		0x4f, 0x28, 0xa1, 0xca, 0x9a, 0x38, 0xa5, 0x69, 0x14, 0x99, 0x3c, 0xc5, 0x89, 0x04, 0xc2, 0xd6,
		0x20, 0xaf, 0x22, 0x0a, 0x53, 0x2a, 0xac, 0x55, 0xa4, 0x71, 0x70, 0x50, 0x61, 0x25, 0xd9, 0x29,
		0xe7, 0xd3, 0xcb, 0x32, 0xd2, 0xce, 0xed, 0x40, 0x9f, 0x50, 0xe6, 0x38, 0x7b, 0xbe, 0x55, 0x06,
		0x39, 0x97, 0x10, 0x2d, 0x34, 0x9f, 0x5c, 0xfc, 0x77, 0x2d, 0xb4, 0x3c, 0x2e, 0xf1, 0x13, 0xc1,
		0x2e, 0xf3, 0xc5, 0xe3, 0x4b, 0x96, 0x0e, 0x6a, 0x90, 0x0e, 0xd2, 0xa3, 0x8b, 0xa4, 0x83, 0x2a,
		0x88, 0x12, 0xa4, 0x83, 0xbe, 0xb4, 0x41, 0xa4, 0x83, 0xac, 0x4d, 0xa7, 0x9e, 0x09, 0xd5, 0x32,
		0xa5, 0xea, 0x26, 0x55, 0xdd, 0xb4, 0xaa, 0x9a, 0x58, 0x59, 0x4a, 0x42, 0x3a, 0xe8, 0x1b, 0x3c,
		0x3d, 0xd2, 0x41, 0xa4, 0x83, 0x00, 0x25, 0x40, 0x09, 0x50, 0x02, 0x94, 0xfe, 0xfb, 0x79, 0x21,
		0x1d, 0xf4, 0xb5, 0x7f, 0x48, 0x07, 0x6d, 0x24, 0x8e, 0x74, 0x50, 0x31, 0x2a, 0x42, 0x3a, 0xa8,
		0xe4, 0x4a, 0x42, 0x3a, 0x48, 0x96, 0x52, 0x90, 0x0e, 0x32, 0x4f, 0x07, 0x2d, 0xb2, 0x18, 0x74,
		0x96, 0xda, 0x29, 0x84, 0x1b, 0x8a, 0x50, 0x2b, 0x34, 0xf1, 0x16, 0x4f, 0x07, 0x49, 0x94, 0xba,
		0xad, 0xdd, 0xc5, 0x0a, 0xdb, 0xe9, 0x02, 0xbd, 0x5e, 0xba, 0x2c, 0xef, 0xe4, 0x76, 0xec, 0x75,
		0xd3, 0xc5, 0x78, 0xad, 0xf7, 0xb7, 0xe3, 0xb3, 0xe5, 0x5a, 0xaa, 0xd4, 0xec, 0x1a, 0xc7, 0xa3,
		0xb8, 0xfe, 0xc1, 0x8f, 0xae, 0x87, 0x45, 0x0e, 0x86, 0x5a, 0x05, 0xf3, 0xf3, 0xcf, 0xa7, 0xdd,
		0xd5, 0xbd, 0xb0, 0x04, 0xed, 0xae, 0x26, 0x61, 0x05, 0xda, 0x5d, 0x37, 0x3a, 0x06, 0xb4, 0xbb,
		0x52, 0xdf, 0x60, 0x6d, 0x80, 0xd4, 0x0c, 0x91, 0x8a, 0x41, 0x2a, 0x07, 0xed, 0x11, 0xab, 0x6f,
		0x48, 0xe2, 0xc0, 0x4f, 0xea, 0xfe, 0xa4, 0xfe, 0x67, 0x98, 0x7c, 0xb8, 0x8e, 0xfd, 0x3f, 0xe5,
		0x33, 0x3e, 0xeb, 0x22, 0xa9, 0x79, 0xb0, 0x30, 0xa3, 0x1a, 0xe6, 0x54, 0xcf, 0xac, 0x6a, 0x99,
		0x57, 0x75, 0x33, 0xab, 0x6e, 0x6e, 0x55, 0xcd, 0xae, 0x6c, 0xdc, 0x8d, 0x9a, 0x87, 0x6f, 0xf0,
		0xfe, 0xf6, 0x08, 0x50, 0xba, 0x1b, 0x8f, 0xb2, 0x8f, 0x4b, 0xe5, 0x42, 0x1a, 0x14, 0xac, 0x17,
		0x75, 0xc0, 0x29, 0x58, 0x87, 0xd0, 0x41, 0xe8, 0x20, 0x74, 0x45, 0x3d, 0x78, 0x66, 0xa7, 0xa3,
		0x60, 0x34, 0x9d, 0xd4, 0xa7, 0xe3, 0x6b, 0x3f, 0x09, 0xea, 0x77, 0xc1, 0x64, 0xe2, 0xdf, 0x06,
		0x13, 0x85, 0x12, 0xf6, 0x27, 0x45, 0x43, 0xbc, 0x20, 0x5e, 0x10, 0x2f, 0x88, 0x57, 0x89, 0x88,
		0xd7, 0x34, 0x8c, 0x92, 0x17, 0x0d, 0x05, 0xde, 0x75, 0x44, 0x61, 0xdf, 0x97, 0x5f, 0x84, 0xc2,
		0xbe, 0xe2, 0xe4, 0x51, 0xd8, 0x57, 0x5a, 0x15, 0xd9, 0x6f, 0x1c, 0xef, 0x1f, 0x1f, 0x1e, 0x35,
		0x8e, 0xa9, 0xef, 0x73, 0xee, 0xe9, 0xef, 0xb6, 0xb8, 0x65, 0x88, 0x2c, 0x12, 0x64, 0x06, 0x32,
		0x03, 0x99, 0x81, 0xcc, 0xb8, 0x49, 0x66, 0xc8, 0x22, 0x09, 0x3f, 0x91, 0x2c, 0xd2, 0x77, 0x65,
		0x91, 0xa8, 0x73, 0xb7, 0xd6, 0x08, 0x47, 0x34, 0xc1, 0xbc, 0xd0, 0x7d, 0xb6, 0x9a, 0xdf, 0x96,
		0x8b, 0xa9, 0x50, 0xa5, 0xfb, 0x6d, 0xec, 0x0f, 0x82, 0x9b, 0xe9, 0xb0, 0x1e, 0x07, 0x93, 0xc4,
		0x8f, 0x93, 0xe2, 0x6b, 0xdd, 0xd7, 0x24, 0x50, 0xed, 0xee, 0x9e, 0x7f, 0x4b, 0xb5, 0xbb, 0x89,
		0x7f, 0x4a, 0xb5, 0xfb, 0x46, 0xc7, 0x80, 0x6a, 0x77, 0x8a, 0x23, 0x5c, 0x21, 0xd0, 0x14, 0x47,
		0xe8, 0xb1, 0x1f, 0xa6, 0xf9, 0x11, 0x2b, 0x24, 0x56, 0x48, 0xac, 0x90, 0x58, 0x21, 0xb1, 0x42,
		0x27, 0x62, 0x85, 0x02, 0x7e, 0xd1, 0x87, 0x60, 0x38, 0x0e, 0xe2, 0xfa, 0x28, 0x1a, 0x7e, 0x94,
		0x87, 0xa3, 0x87, 0xc2, 0x80, 0x24, 0x20, 0x09, 0x48, 0x02, 0x92, 0x80, 0x24, 0x20, 0x29, 0xbf,
		0x07, 0x69, 0x00, 0xb7, 0x9e, 0x84, 0x77, 0x81, 0x3c, 0x26, 0xe5, 0xa4, 0x01, 0x4a, 0x80, 0x12,
		0xa0, 0x04, 0x28, 0x95, 0x08, 0x94, 0xa6, 0x61, 0x94, 0xec, 0x1d, 0x2a, 0x60, 0xd2, 0x21, 0x05,
		0xe2, 0x5f, 0x7e, 0x11, 0x0a, 0xc4, 0x8b, 0x93, 0x47, 0x81, 0x78, 0x69, 0x55, 0x64, 0x7f, 0xf7,
		0xf8, 0x90, 0xd2, 0x70, 0xd7, 0x9e, 0xbe, 0xcd, 0xa5, 0xe1, 0x93, 0xc4, 0x1f, 0x06, 0xf5, 0x78,
		0x34, 0x4d, 0x82, 0x89, 0x12, 0xb3, 0x58, 0x17, 0x09, 0xbd, 0x80, 0x5e, 0x40, 0x2f, 0xa0, 0x17,
		0x25, 0xa2, 0x17, 0xd7, 0xc1, 0x20, 0xbc, 0xf3, 0x87, 0x87, 0xfb, 0x1a, 0x51, 0xaf, 0x86, 0xa0,
		0x8c, 0x35, 0x3f, 0xa1, 0x01, 0x9f, 0x71, 0x93, 0xcf, 0x34, 0xe0, 0x33, 0xf0, 0x99, 0xff, 0xae,
		0x22, 0x2f, 0x50, 0x11, 0xc8, 0x4c, 0x49, 0xc8, 0x0c, 0x0d, 0x3e, 0x06, 0x6d, 0x1d, 0x8f, 0xbb,
		0x01, 0x18, 0x14, 0x57, 0x20, 0xab, 0x65, 0x50, 0x1c, 0xb5, 0xd0, 0x2e, 0x30, 0x53, 0x6a, 0xa1,
		0xf5, 0x80, 0x82, 0x5a, 0xe8, 0xaf, 0x33, 0x61, 0x04, 0xe1, 0x2c, 0x4d, 0x9b, 0x96, 0x89, 0x53,
		0x37, 0x75, 0xea, 0x26, 0x4f, 0xd5, 0xf4, 0xc9, 0xb2, 0x05, 0x0a, 0xcf, 0xbe, 0xc1, 0x03, 0xa3,
		0x16, 0x9a, 0x5a, 0x68, 0x20, 0x09, 0x48, 0x02, 0x92, 0x80, 0x24, 0x20, 0xc9, 0x1c, 0x92, 0x86,
		0xa3, 0x81, 0x9f, 0x05, 0xb1, 0x8a, 0xbc, 0x23, 0xf2, 0xc9, 0x0f, 0xbb, 0x26, 0x11, 0x70, 0x02,
		0x9c, 0x00, 0x27, 0xc0, 0x09, 0x70, 0x02, 0x9c, 0xf2, 0x7b, 0x70, 0x37, 0xba, 0x56, 0x28, 0xa3,
		0x9b, 0x4b, 0x01, 0x84, 0x00, 0x21, 0x40, 0x08, 0x10, 0x2a, 0x11, 0x08, 0x05, 0xd1, 0xf4, 0x2e,
		0x88, 0x17, 0xb9, 0x75, 0x05, 0x20, 0xda, 0x17, 0x94, 0xd1, 0x8a, 0xa6, 0x77, 0xb3, 0x4d, 0xfb,
		0xb4, 0xc5, 0x60, 0x37, 0x0e, 0x82, 0xb8, 0xae, 0xdb, 0x9a, 0xba, 0x2e, 0x12, 0x18, 0x04, 0x06,
		0x81, 0x41, 0x60, 0xb0, 0x44, 0x30, 0x48, 0x7f, 0xea, 0x57, 0xff, 0xa1, 0x3f, 0x75, 0x23, 0x71,
		0xd4, 0x73, 0x17, 0xa3, 0x22, 0xf4, 0xa7, 0x96, 0x5d, 0x4b, 0x28, 0xe9, 0x2e, 0x35, 0xbd, 0x50,
		0xc9, 0xf3, 0x3c, 0x16, 0x08, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x25, 0xa2, 0x16, 0xa4,
		0x79, 0x54, 0xa0, 0x89, 0x79, 0x6c, 0x80, 0x12, 0xa0, 0x04, 0x28, 0x01, 0x4a, 0x5f, 0x73, 0x5e,
		0x88, 0x77, 0x7d, 0xf5, 0x1f, 0xe2, 0x5d, 0x85, 0x04, 0x33, 0x88, 0x77, 0x6d, 0xa6, 0x22, 0xc4,
		0xbb, 0xca, 0xae, 0x25, 0xc4, 0xbb, 0x4a, 0x47, 0x2a, 0x98, 0xc7, 0x06, 0xbd, 0x80, 0x5e, 0x40,
		0x2f, 0xa0, 0x17, 0xdf, 0x76, 0x5e, 0x98, 0xc7, 0x06, 0x9f, 0x61, 0x1e, 0x1b, 0x7c, 0xc6, 0x2d,
		0x3e, 0xc3, 0x3c, 0x36, 0xc8, 0x0c, 0xf3, 0xd8, 0x8a, 0x70, 0xb1, 0xb6, 0x65, 0x1e, 0xdb, 0x62,
		0x8c, 0x98, 0xab, 0xe3, 0xd8, 0x9c, 0xba, 0x2f, 0x5b, 0x48, 0x27, 0x9c, 0xd1, 0x85, 0x5a, 0xa1,
		0xc3, 0xef, 0xe2, 0xe9, 0x20, 0x89, 0x52, 0x67, 0xb9, 0xbb, 0x58, 0x64, 0x3b, 0x5d, 0xa3, 0xd7,
		0x4b, 0x57, 0xe6, 0x9d, 0xdc, 0x8e, 0xbd, 0x6e, 0xba, 0x1e, 0xef, 0x75, 0xba, 0x9e, 0x8b, 0x74,
		0x39, 0x3b, 0x6e, 0xa8, 0x50, 0x01, 0xea, 0x53, 0x1b, 0x8e, 0x6e, 0x6f, 0xc3, 0xe8, 0xb6, 0x3e,
		0x1a, 0xcf, 0xd4, 0x67, 0x52, 0x98, 0xfe, 0x3c, 0xe8, 0x16, 0xcf, 0x0b, 0x28, 0x48, 0xe5, 0x8b,
		0x9d, 0x07, 0x58, 0x78, 0xc4, 0x44, 0x22, 0x42, 0x22, 0x17, 0x11, 0x91, 0x8a, 0x80, 0x88, 0x47,
		0x3c, 0xc4, 0x23, 0x1c, 0xa2, 0x11, 0x0d, 0xb7, 0x40, 0xa4, 0xe8, 0xf9, 0x7d, 0xb5, 0xc1, 0xf2,
		0x4c, 0x09, 0xcd, 0x19, 0x4d, 0x9f, 0x5f, 0xb2, 0x41, 0xa3, 0xbb, 0x0c, 0x1a, 0x95, 0x37, 0x3c,
		0x6a, 0x06, 0x48, 0xcd, 0x10, 0xa9, 0x18, 0xa4, 0x72, 0x30, 0x20, 0xb1, 0x41, 0xa3, 0xc3, 0xd1,
		0xcc, 0xb1, 0x5d, 0xf8, 0x7c, 0xf5, 0x39, 0xfd, 0xa8, 0x0f, 0x3e, 0xf8, 0xd1, 0x6d, 0x30, 0xd1,
		0x18, 0xaa, 0xf3, 0xa4, 0x6c, 0x21, 0x45, 0x7a, 0x19, 0xdc, 0xf8, 0xd3, 0xe1, 0x5c, 0x8f, 0x66,
		0xea, 0x4a, 0xaa, 0x4b, 0xdd, 0xbe, 0xea, 0xd9, 0x59, 0x2d, 0x7b, 0xab, 0x6e, 0x77, 0xd5, 0xed,
		0xaf, 0xaa, 0x1d, 0x96, 0x8d, 0xc9, 0x51, 0xde, 0xfd, 0x0d, 0xee, 0xe0, 0x1e, 0xc1, 0x4b, 0x77,
		0x03, 0x55, 0xe6, 0x01, 0xab, 0x47, 0x41, 0x0e, 0xee, 0x92, 0x28, 0xea, 0x84, 0x73, 0x97, 0x04,
		0x14, 0x0f, 0x8a, 0x07, 0xc5, 0x83, 0xe2, 0x41, 0xf1, 0xa0, 0x78, 0x50, 0x3c, 0x28, 0x1e, 0x14,
		0x0f, 0x8a, 0x07, 0xc5, 0xb3, 0xa7, 0x78, 0x94, 0xa7, 0x58, 0xab, 0x84, 0x2b, 0xaa, 0x60, 0x5d,
		0x9d, 0xd2, 0x59, 0x2c, 0xe7, 0x3c, 0x5d, 0x4d, 0x85, 0x8a, 0x53, 0x32, 0x6f, 0xd9, 0xbf, 0xbe,
		0x8e, 0x83, 0x89, 0x40, 0x75, 0xca, 0x9a, 0x84, 0x62, 0xcb, 0x53, 0x76, 0x29, 0x4f, 0x71, 0xd8,
		0xa5, 0xa5, 0x3c, 0xa5, 0x44, 0x20, 0x52, 0xb8, 0xcb, 0xb9, 0xe2, 0xe5, 0x81, 0x7f, 0x13, 0x07,
		0x37, 0x45, 0x2a, 0xec, 0xd2, 0xa5, 0x3c, 0x2a, 0xf0, 0x99, 0xbd, 0x14, 0xe7, 0x7e, 0xfe, 0x79,
		0xe1, 0x7b, 0x3c, 0x5f, 0xb3, 0x5d, 0x15, 0xb2, 0xfc, 0xf3, 0x1e, 0xcc, 0x7a, 0x1c, 0xdc, 0x0c,
		0x83, 0x41, 0x32, 0x8a, 0x8b, 0x37, 0xfc, 0x8f, 0x05, 0x50, 0x96, 0x88, 0xdd, 0xc7, 0xee, 0x3b,
		0x68, 0xf7, 0x29, 0x4b, 0x7c, 0x46, 0x59, 0xa2, 0x92, 0xc1, 0x91, 0x36, 0x3c, 0x6a, 0x06, 0x48,
		0xcd, 0x10, 0xa9, 0x18, 0xa4, 0x72, 0x04, 0xbe, 0xc4, 0x72, 0x56, 0x8f, 0x5c, 0x95, 0xfa, 0x60,
		0x18, 0x2e, 0x36, 0x5a, 0x7a, 0xce, 0xde, 0xe7, 0xe5, 0xca, 0xe7, 0xaa, 0x6e, 0xfc, 0xe1, 0x84,
		0x64, 0x95, 0xbe, 0x61, 0xd5, 0x33, 0xb0, 0x5a, 0x86, 0x56, 0xdd, 0xe0, 0xaa, 0x1b, 0x5e, 0x55,
		0x03, 0x2c, 0x63, 0x88, 0x85, 0x0c, 0xb2, 0x5c, 0xe4, 0xe0, 0xc9, 0xf3, 0x42, 0xb2, 0x4a, 0xe3,
		0xa3, 0x7e, 0x06, 0x98, 0xa6, 0x93, 0x24, 0x88, 0xeb, 0xe1, 0xb5, 0x05, 0x28, 0x66, 0xb2, 0x01,
		0x2c, 0x00, 0x0b, 0xc0, 0x02, 0xb0, 0x4a, 0x04, 0x58, 0xf1, 0x43, 0x03, 0x56, 0x4f, 0x66, 0x72,
		0x15, 0xb0, 0xeb, 0x58, 0x50, 0x46, 0xba, 0x77, 0xa5, 0x1f, 0xe3, 0xf4, 0x70, 0x58, 0xf0, 0x8b,
		0x46, 0x4d, 0x61, 0x2a, 0x50, 0xfa, 0x75, 0x8e, 0x14, 0x44, 0xe9, 0x0c, 0xdb, 0xd2, 0xfb, 0x5a,
		0xd9, 0x8b, 0x69, 0x0e, 0xdf, 0x52, 0x72, 0x10, 0x9e, 0x14, 0xab, 0x3c, 0x69, 0x29, 0x93, 0x6b,
		0x30, 0x71, 0x49, 0xd8, 0xe0, 0x7f, 0x5e, 0x95, 0x14, 0x87, 0x74, 0xb9, 0xa2, 0x4a, 0xfb, 0x8d,
		0xe3, 0xfd, 0xe3, 0xc3, 0xa3, 0xc6, 0xf1, 0xc1, 0x16, 0xe9, 0xd4, 0x4e, 0x35, 0xa4, 0xbc, 0xdb,
		0x29, 0xf1, 0xc9, 0x53, 0x04, 0xf4, 0x70, 0x7c, 0xbf, 0x5f, 0x70, 0xb5, 0xd1, 0x57, 0x39, 0x5d,
		0xbf, 0x28, 0xc8, 0xea, 0xf9, 0x49, 0x12, 0xc4, 0x91, 0x1a, 0xb2, 0xd7, 0xfe, 0xef, 0x87, 0x1f,
		0xde, 0xee, 0xd6, 0x8f, 0xdf, 0xfd, 0xfd, 0x76, 0xaf, 0x7e, 0xfc, 0x6e, 0xf1, 0xe3, 0xde, 0xfc,
		0x7f, 0x16, 0x3f, 0x37, 0xde, 0xee, 0xd6, 0xf7, 0x97, 0x3f, 0x1f, 0xbc, 0xdd, 0xad, 0x1f, 0xbc,
		0xfb, 0xf1, 0x5f, 0xff, 0xfa, 0xf9, 0xc7, 0xff, 0xbc, 0xf8, 0xf4, 0xed, 0xbf, 0xf8, 0x3f, 0x35,
		0xf9, 0x43, 0xa4, 0xf1, 0x91, 0xce, 0xfb, 0xed, 0xdf, 0xf9, 0x52, 0x6e, 0x9b, 0x3b, 0x86, 0x30,
		0x52, 0xe4, 0x6e, 0x50, 0xd9, 0xfc, 0x28, 0xba, 0x49, 0x1f, 0x73, 0x51, 0xa8, 0x4f, 0x1f, 0x33,
		0x35, 0x21, 0x5f, 0xfa, 0x9a, 0xd4, 0x84, 0x54, 0x0e, 0x27, 0xa8, 0x09, 0xd9, 0x6c, 0xfb, 0xa8,
		0x09, 0xb1, 0x36, 0xac, 0x7a, 0x06, 0x56, 0xcb, 0xd0, 0xaa, 0x1b, 0x5c, 0x75, 0xc3, 0xab, 0x6a,
		0x80, 0x65, 0x29, 0x0b, 0x35, 0x21, 0xdf, 0xe0, 0x07, 0x52, 0x13, 0x42, 0x4d, 0x08, 0x80, 0x05,
		0x60, 0x01, 0x58, 0x00, 0xd6, 0x06, 0xd6, 0x8c, 0x9a, 0x90, 0xef, 0xf9, 0x43, 0x4d, 0xc8, 0x66,
		0xa2, 0xa8, 0x09, 0x29, 0x8f, 0x83, 0xf0, 0xa4, 0x58, 0x6a, 0x42, 0x64, 0x55, 0x89, 0x9a, 0x90,
		0xed, 0xd0, 0x29, 0x6a, 0x42, 0xec, 0x4f, 0x1e, 0x35, 0x21, 0xc5, 0x50, 0x3d, 0x2a, 0x0d, 0x36,
		0x3c, 0x44, 0xd4, 0x84, 0x50, 0x13, 0x42, 0x4d, 0x08, 0x35, 0x21, 0x8e, 0xd4, 0x84, 0x30, 0xf8,
		0xd0, 0x5a, 0x25, 0x5c, 0x51, 0x05, 0xeb, 0xc1, 0x87, 0x17, 0xb3, 0xe5, 0x5c, 0x64, 0xab, 0xa9,
		0xd0, 0xf8, 0xab, 0x62, 0xab, 0x91, 0x44, 0xaa, 0x90, 0xc4, 0x46, 0x5d, 0x35, 0x18, 0x75, 0x55,
		0xa4, 0xab, 0xcf, 0xa8, 0xab, 0xd2, 0xc0, 0x45, 0xe1, 0xa3, 0xae, 0xfc, 0x69, 0xf2, 0xa1, 0x3e,
		0xf6, 0x27, 0x93, 0x54, 0x05, 0x84, 0x8a, 0x1b, 0xf3, 0x62, 0x64, 0x8a, 0x1c, 0x77, 0x19, 0x7c,
		0x45, 0x91, 0xa3, 0x43, 0x66, 0x49, 0xc5, 0x3c, 0x95, 0x83, 0xf8, 0x88, 0xa5, 0x26, 0x73, 0x05,
		0x16, 0x61, 0x74, 0x2b, 0x65, 0x63, 0xf2, 0x31, 0xb1, 0x2d, 0x28, 0x76, 0xbf, 0x0e, 0x26, 0x83,
		0x38, 0x1c, 0x8b, 0x70, 0xd5, 0xec, 0xa3, 0x3d, 0x14, 0x02, 0x26, 0x80, 0x09, 0x60, 0x02, 0x98,
		0x50, 0x28, 0x97, 0x8d, 0xc3, 0xe8, 0x16, 0x24, 0xd8, 0x10, 0x09, 0x3e, 0x46, 0xfe, 0x5d, 0x38,
		0xf0, 0x87, 0xc3, 0x8f, 0xf5, 0x45, 0x08, 0x69, 0x1a, 0x07, 0x82, 0x54, 0xe1, 0x09, 0x79, 0x45,
		0xb7, 0x5d, 0xc8, 0xf6, 0x0d, 0x80, 0x3f, 0xe0, 0x0f, 0xf8, 0xb3, 0xe5, 0xf8, 0x23, 0x57, 0xd7,
		0x2f, 0x54, 0xcf, 0xef, 0x26, 0x00, 0x05, 0x91, 0xff, 0x7e, 0x28, 0x89, 0x38, 0x4b, 0x01, 0x72,
		0x10, 0x23, 0x70, 0xb5, 0x26, 0x08, 0x03, 0xc2, 0x80, 0x30, 0x20, 0x0c, 0x08, 0x53, 0x00, 0xc2,
		0x4c, 0x12, 0xff, 0xfd, 0x30, 0x9c, 0x7c, 0x08, 0xae, 0xeb, 0x49, 0xec, 0x47, 0x93, 0x70, 0x71,
		0x4f, 0x9e, 0x1c, 0xe2, 0x3c, 0x21, 0x10, 0x88, 0x00, 0x22, 0x80, 0x08, 0x20, 0xa2, 0x40, 0x7d,
		0x1f, 0x8c, 0xa6, 0x51, 0x12, 0xc4, 0x87, 0xfb, 0x82, 0x20, 0x21, 0x50, 0x24, 0x2c, 0xdc, 0xec,
		0x23, 0xd8, 0x24, 0xa7, 0xd1, 0xcc, 0xa3, 0xd4, 0x71, 0xa1, 0xd5, 0xac, 0xa3, 0xd9, 0x48, 0x21,
		0xd8, 0x12, 0xa0, 0xd2, 0x7c, 0xa3, 0xfd, 0xe9, 0xf7, 0x7e, 0xd9, 0xdf, 0x3f, 0x3c, 0xda, 0xdf,
		0xdf, 0x3d, 0x7a, 0x71, 0xb4, 0x7b, 0x7c, 0x70, 0xb0, 0x77, 0xb8, 0x77, 0x50, 0x21, 0x6d, 0x28,
		0x49, 0x5d, 0xf3, 0xbb, 0x2d, 0xf0, 0xc2, 0x87, 0xfe, 0x24, 0xa9, 0x3f, 0xf0, 0x8c, 0xe5, 0xdc,
		0xef, 0x35, 0x49, 0xf8, 0xdd, 0xf8, 0xdd, 0xf8, 0xdd, 0xf8, 0xdd, 0x05, 0xea, 0x7b, 0x12, 0xde,
		0x05, 0x49, 0x38, 0xf8, 0xf7, 0xa4, 0x74, 0x9e, 0xf7, 0x55, 0xb4, 0x40, 0xdd, 0x5a, 0xe4, 0x47,
		0xa3, 0x49, 0x30, 0x18, 0x45, 0xd7, 0x12, 0x2d, 0x87, 0x78, 0xf8, 0x78, 0xf8, 0x78, 0xf8, 0x78,
		0xf8, 0x78, 0xf8, 0xdb, 0xe3, 0xe1, 0x8f, 0x06, 0xfe, 0xb0, 0xee, 0x0b, 0x06, 0xd6, 0x33, 0x09,
		0x78, 0xf4, 0x78, 0xf4, 0x78, 0xf4, 0x78, 0xf4, 0x05, 0xea, 0xbb, 0x3f, 0xa9, 0x47, 0xd3, 0xbb,
		0xf7, 0x41, 0x2c, 0xe8, 0xcf, 0x1f, 0xe1, 0x67, 0xe3, 0x67, 0xe3, 0x67, 0x57, 0xd2, 0xcf, 0xd6,
		0x1a, 0x53, 0x85, 0x77, 0xbd, 0x9d, 0xde, 0xf5, 0x5d, 0x30, 0x99, 0xf8, 0xb7, 0x81, 0xa0, 0x77,
		0x9d, 0x49, 0x28, 0xd9, 0x2d, 0x25, 0x78, 0xd7, 0x78, 0xd7, 0x78, 0xd7, 0x9b, 0xec, 0x80, 0xdc,
		0x2d, 0x25, 0xc1, 0x20, 0x08, 0xef, 0x03, 0x8d, 0x11, 0xec, 0x4b, 0x49, 0xb2, 0x03, 0xd7, 0xf7,
		0x18, 0xb8, 0x6e, 0x68, 0xdc, 0xb4, 0x8c, 0x9c, 0xba, 0xb1, 0x53, 0x37, 0x7a, 0xaa, 0xc6, 0x4f,
		0xd8, 0x9d, 0x94, 0xba, 0x7b, 0x48, 0xc8, 0x28, 0xae, 0x8e, 0xcb, 0xf9, 0x65, 0xfb, 0x55, 0xfb,
		0xb4, 0x79, 0xd9, 0x3e, 0xef, 0xca, 0xab, 0xf2, 0xf2, 0x70, 0xe6, 0xa4, 0xfe, 0x54, 0x09, 0x0a,
		0x26, 0x6d, 0x3c, 0x35, 0x8d, 0xa8, 0xbe, 0x31, 0xd5, 0x36, 0xaa, 0x66, 0xc6, 0xd5, 0xcc, 0xc8,
		0x9a, 0x18, 0x5b, 0x59, 0xa3, 0xab, 0x10, 0x25, 0x7a, 0xa6, 0x72, 0xeb, 0xc5, 0xda, 0x79, 0x9b,
		0x86, 0x51, 0x22, 0x52, 0xd4, 0xf1, 0x94, 0x75, 0xfc, 0x85, 0xbb, 0x15, 0xbe, 0xff, 0xc5, 0xb8,
		0x5b, 0x41, 0x5e, 0x2e, 0x77, 0x2b, 0x54, 0x56, 0x95, 0xf4, 0x8b, 0x43, 0x9c, 0xd2, 0x2e, 0x6e,
		0x59, 0x30, 0x5d, 0xbf, 0x64, 0x8a, 0xe9, 0xaa, 0xf7, 0xb2, 0x79, 0xd9, 0xd2, 0xa3, 0x55, 0xa9,
		0x3c, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0x82, 0x50, 0x41, 0xa8, 0x20, 0x54, 0x10, 0x2a,
		0x08, 0x15, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0x2a, 0x3f, 0xa1, 0x9a, 0x77, 0xd5, 0x46, 0xa3, 0x24,
		0xbc, 0x09, 0x07, 0xf3, 0x1b, 0x6d, 0xea, 0x41, 0x1c, 0x8f, 0xe2, 0xfa, 0x60, 0x74, 0x1d, 0xe8,
		0xd1, 0xac, 0xff, 0xba, 0x0a, 0xc8, 0x17, 0xe4, 0x0b, 0xf2, 0x05, 0xf9, 0x82, 0x7c, 0xad, 0x2e,
		0x16, 0xbd, 0x0e, 0xa2, 0x24, 0x4c, 0x3e, 0xc6, 0xc1, 0x8d, 0xe6, 0xbd, 0xa2, 0x0a, 0x3e, 0x4f,
		0xad, 0x9d, 0xbe, 0xda, 0x89, 0x3f, 0x51, 0x3c, 0xe6, 0xcb, 0x8d, 0x3d, 0x79, 0xdd, 0xf3, 0x5a,
		0x17, 0x17, 0xe7, 0x17, 0xde, 0xe9, 0xf9, 0xcb, 0x96, 0xd6, 0x59, 0x9f, 0xbb, 0x99, 0x13, 0x35,
		0xde, 0xa9, 0xcb, 0x3d, 0x73, 0xfb, 0xfb, 0xaa, 0xdd, 0x6d, 0x5f, 0xb6, 0xbc, 0xfe, 0x65, 0xf3,
		0xb2, 0xe5, 0x9d, 0x35, 0x4f, 0x7f, 0x6b, 0x77, 0x5b, 0x8b, 0x0d, 0xaf, 0x55, 0x91, 0x2c, 0x19,
		0xed, 0xf2, 0x6f, 0xe7, 0x9d, 0x97, 0xde, 0x65, 0xfb, 0xac, 0x75, 0xe1, 0xb5, 0x7e, 0xef, 0xb5,
		0x2f, 0x5a, 0x2f, 0xd9, 0xdd, 0xe2, 0x76, 0xf7, 0xb4, 0xd5, 0xec, 0xb7, 0xd8, 0xd0, 0xe2, 0x36,
		0xf4, 0xbc, 0xd7, 0xea, 0x7a, 0x67, 0xad, 0x7e, 0xbf, 0xf9, 0x1a, 0x63, 0x50, 0xf8, 0xee, 0x2e,
		0x52, 0x58, 0xec, 0xaf, 0xd4, 0xfe, 0x5e, 0x9c, 0x5f, 0x5d, 0xb6, 0xbc, 0x8b, 0xd6, 0xab, 0x8b,
		0x56, 0xff, 0x37, 0xb6, 0x59, 0x6a, 0x9b, 0x97, 0x1b, 0xfb, 0x5b, 0xab, 0xf9, 0x72, 0x86, 0x6b,
		0xca, 0xfb, 0xab, 0x22, 0xe9, 0x5d, 0xd9, 0x89, 0x56, 0xa5, 0x42, 0x60, 0x93, 0xe9, 0x7b, 0x37,
		0xa2, 0x60, 0xcb, 0x85, 0x10, 0x08, 0xfb, 0x26, 0x41, 0x04, 0xc2, 0x0a, 0xd5, 0x0e, 0x02, 0x61,
		0x04, 0xc2, 0xbe, 0xb0, 0x63, 0x04, 0xc2, 0x0a, 0x94, 0xe5, 0x4a, 0x20, 0xac, 0x7f, 0x75, 0x42,
		0x2c, 0x4c, 0x81, 0x98, 0xe9, 0xee, 0xb3, 0xe5, 0x7e, 0xdb, 0xec, 0xfb, 0xda, 0xfe, 0x37, 0x2f,
		0x2f, 0x2f, 0xda, 0x27, 0x33, 0xf2, 0xd6, 0x69, 0x75, 0x5f, 0x5f, 0xfe, 0xa6, 0xcd, 0x29, 0x0c,
		0xb8, 0x9b, 0x23, 0x3b, 0xdf, 0xee, 0xbe, 0x69, 0x76, 0xda, 0x2f, 0xbd, 0xf3, 0x8b, 0xf6, 0xeb,
		0x76, 0xd7, 0xcb, 0x3e, 0x04, 0x7b, 0xaf, 0x60, 0x75, 0xba, 0x17, 0xad, 0xd3, 0xf3, 0xd7, 0xdd,
		0xf6, 0xff, 0xdb, 0x7a, 0xe9, 0xfd, 0xb3, 0xd5, 0xe9, 0x78, 0xff, 0xe8, 0x9e, 0xff, 0x93, 0x8f,
		0xa0, 0xfa, 0x11, 0xce, 0x7b, 0x97, 0xed, 0xf3, 0x6e, 0xb3, 0xb3, 0xda, 0x75, 0x8c, 0x8f, 0xbe,
		0xd9, 0x7f, 0xd5, 0x69, 0xbe, 0xee, 0xb3, 0xf1, 0x5a, 0x1b, 0x7f, 0xd6, 0xec, 0xbc, 0x3a, 0xbf,
		0x38, 0x6b, 0xbd, 0xf4, 0x9a, 0x7d, 0xaf, 0xd7, 0xbc, 0xfc, 0x8d, 0x4d, 0xd7, 0x83, 0xda, 0x6e,
		0xeb, 0xf2, 0x9f, 0xe7, 0x17, 0xff, 0xf0, 0x5e, 0xb5, 0x5b, 0x9d, 0x97, 0x6c, 0xbc, 0x82, 0xb6,
		0xb7, 0xfb, 0xfd, 0x76, 0xf7, 0x35, 0x10, 0x6b, 0x6f, 0x6d, 0x56, 0x7e, 0x7e, 0xbb, 0x7f, 0xc9,
		0xde, 0x6b, 0x1a, 0x9d, 0xdf, 0x2f, 0xbd, 0xdf, 0xce, 0x7b, 0xa6, 0x9a, 0xaf, 0x2a, 0xf1, 0x1d,
		0x19, 0xbf, 0xca, 0xf0, 0xf3, 0xea, 0xef, 0xb0, 0x3d, 0x0f, 0xdf, 0x82, 0xf2, 0x0b, 0x77, 0xf8,
		0xf6, 0x36, 0x54, 0x12, 0x59, 0xf3, 0xea, 0x6d, 0x32, 0xcb, 0x26, 0xfc, 0x79, 0x0b, 0x2a, 0x5d,
		0xec, 0x78, 0xf2, 0xf6, 0x40, 0x9e, 0x11, 0x1f, 0xde, 0x02, 0xed, 0x75, 0x82, 0xf7, 0x6e, 0x95,
		0x95, 0x30, 0xe2, 0xb7, 0xdb, 0x64, 0x2c, 0xec, 0x78, 0x6c, 0xf5, 0x77, 0xf9, 0xb3, 0x3d, 0x21,
		0x64, 0xc3, 0x95, 0xbf, 0xc2, 0x45, 0xeb, 0xb4, 0xd5, 0x7e, 0xd3, 0xf2, 0xae, 0xba, 0xad, 0xdf,
		0x7b, 0xad, 0xd3, 0xcb, 0xd6, 0xcb, 0xac, 0x32, 0xe1, 0xbc, 0xd7, 0xea, 0x9e, 0x9e, 0x77, 0x5f,
		0xb5, 0x2f, 0xce, 0x88, 0x9e, 0x99, 0x7e, 0x89, 0x56, 0xff, 0xb2, 0x79, 0xd2, 0x69, 0xf7, 0x7f,
		0x6b, 0x11, 0xc3, 0xb7, 0x3f, 0x13, 0xfd, 0x56, 0xf7, 0x92, 0x80, 0x26, 0x40, 0x57, 0x56, 0x13,
		0xbb, 0xd5, 0x3b, 0x6e, 0x62, 0x4a, 0xb7, 0x5e, 0xc7, 0x75, 0x4d, 0xe6, 0x36, 0x44, 0x97, 0xfb,
		0xbd, 0xd6, 0x69, 0xfb, 0x55, 0xfb, 0x94, 0x5d, 0x2d, 0x6e, 0x57, 0xe7, 0x1d, 0xbe, 0x50, 0x10,
		0xed, 0x6d, 0x6f, 0xbe, 0x3c, 0x6b, 0x77, 0xdb, 0xfd, 0xcb, 0x8b, 0xe6, 0xe5, 0xcc, 0x84, 0x5c,
		0xb4, 0xfa, 0x2d, 0xd2, 0xf5, 0x1a, 0xea, 0x7e, 0xde, 0xed, 0x7a, 0xa7, 0xe7, 0x9d, 0x4e, 0xbb,
		0xdf, 0x3e, 0xef, 0xce, 0xf6, 0xfd, 0xbc, 0x73, 0x35, 0xbf, 0x48, 0x84, 0xcd, 0x17, 0xdf, 0xfc,
		0xf3, 0xab, 0x4b, 0xef, 0xfc, 0xd5, 0x7c, 0xd3, 0xaf, 0x2e, 0x4e, 0x5b, 0x7d, 0xf6, 0x5c, 0x7e,
		0xcf, 0x7b, 0xad, 0xd6, 0x85, 0xf7, 0xb2, 0xe5, 0xcd, 0x3d, 0xee, 0xd7, 0x57, 0x17, 0xb0, 0x69,
		0x03, 0xf3, 0xde, 0xff, 0xed, 0xea, 0xf2, 0xe5, 0xf9, 0x3f, 0x31, 0x32, 0x4a, 0x16, 0xbe, 0x75,
		0x7a, 0xb9, 0xb0, 0xee, 0xff, 0x3b, 0x77, 0xcb, 0xd9, 0x76, 0x05, 0xdb, 0x7e, 0xf9, 0x5b, 0xeb,
		0x22, 0xb5, 0x32, 0xde, 0xe9, 0x6f, 0xcd, 0xee, 0x6b, 0x4a, 0x3f, 0x15, 0xb6, 0xfd, 0xac, 0xf9,
		0xbb, 0xd7, 0xbd, 0x3a, 0xf3, 0x7a, 0x17, 0xad, 0x57, 0xed, 0xdf, 0x5b, 0x7d, 0xef, 0xa2, 0xd5,
		0x3c, 0xb5, 0x09, 0x99, 0x12, 0xab, 0x2b, 0x29, 0x05, 0xb4, 0xe5, 0x22, 0x5b, 0x40, 0xb1, 0xed,
		0x39, 0xc7, 0x16, 0x94, 0xc3, 0x99, 0x71, 0x8b, 0xea, 0xef, 0xad, 0x25, 0x87, 0xd8, 0x3a, 0xf3,
		0xab, 0xcf, 0x15, 0xb6, 0xc3, 0x02, 0x9b, 0x71, 0x82, 0x2d, 0xb0, 0xbd, 0x96, 0xbe, 0xff, 0x36,
		0x94, 0xbf, 0x59, 0xfb, 0xf8, 0xdb, 0x36, 0xd9, 0x90, 0x74, 0x88, 0xf2, 0xf6, 0x2f, 0xab, 0x0f,
		0x97, 0xf9, 0xd3, 0x45, 0x17, 0x14, 0x24, 0x96, 0x03, 0x5c, 0x16, 0x0d, 0xda, 0xba, 0xa9, 0xa4,
		0xd8, 0x48, 0x3b, 0x27, 0xb6, 0x7b, 0x7e, 0xe9, 0xf5, 0xff, 0xe8, 0x9e, 0xfe, 0x76, 0x71, 0x3e,
		0x6f, 0xb6, 0x23, 0xd2, 0x2a, 0xbf, 0xfd, 0x27, 0x4d, 0x07, 0xe0, 0x69, 0xab, 0x77, 0xfd, 0xf2,
		0x8f, 0x1e, 0x4d, 0xf5, 0x00, 0x56, 0xb9, 0x0c, 0x66, 0xf5, 0xb7, 0xd9, 0xd2, 0x30, 0x6e, 0xd7,
		0xee, 0xea, 0x1a, 0xc0, 0x2d, 0xbb, 0x8c, 0x03, 0x7f, 0xd6, 0x40, 0xb3, 0x4f, 0x5e, 0xf7, 0xbc,
		0xf6, 0xcb, 0x56, 0xf7, 0xb2, 0xfd, 0xaa, 0xdd, 0x62, 0x32, 0x9d, 0xc2, 0xae, 0x5f, 0x75, 0x9b,
		0xa7, 0xa7, 0xad, 0xde, 0x65, 0xf3, 0xa4, 0xd3, 0xf2, 0xb2, 0xcb, 0x93, 0xd8, 0x79, 0x8d, 0x9d,
		0xef, 0x5f, 0xf5, 0x7a, 0xe7, 0x17, 0x97, 0xad, 0x97, 0xde, 0x69, 0xb3, 0xd7, 0x3c, 0x69, 0x77,
		0xda, 0x97, 0x7f, 0xb0, 0xf3, 0x3a, 0x96, 0x66, 0x9e, 0xc3, 0x6c, 0x52, 0x72, 0xaa, 0xac, 0xe8,
		0x6f, 0x5a, 0x17, 0xf3, 0xa2, 0x87, 0xee, 0xd5, 0xd9, 0x09, 0x06, 0x5e, 0x7b, 0xf7, 0xb3, 0x19,
		0x41, 0xbd, 0xe6, 0x45, 0xf3, 0xac, 0x75, 0x69, 0xf2, 0x05, 0xe0, 0xcf, 0x25, 0xa6, 0x1e, 0x56,
		0x0e, 0xda, 0x36, 0xb4, 0xb3, 0xd9, 0x3a, 0x62, 0x5b, 0xd1, 0x30, 0x68, 0xea, 0x70, 0x6d, 0x87,
		0x85, 0x50, 0x77, 0xac, 0xb6, 0x4b, 0x71, 0xad, 0x1c, 0xa8, 0xed, 0xda, 0x65, 0x4b, 0x47, 0x89,
		0xfb, 0x16, 0x6d, 0x9f, 0xae, 0x7b, 0xdf, 0x62, 0x12, 0xde, 0x99, 0x5e, 0xb3, 0x38, 0x97, 0xcf,
		0xed, 0x8a, 0xdf, 0x24, 0x88, 0xdb, 0x15, 0x0b, 0xd5, 0x0e, 0x6e, 0x57, 0xe4, 0x76, 0xc5, 0x2f,
		0xec, 0x98, 0xfe, 0xed, 0x8a, 0x33, 0xbb, 0x98, 0x84, 0x83, 0x7f, 0x4f, 0x0e, 0xf7, 0x15, 0x6f,
		0x57, 0xfc, 0x45, 0x41, 0xd4, 0x55, 0x14, 0x26, 0x93, 0xd9, 0x2b, 0x46, 0x7e, 0x34, 0x9a, 0x04,
		0x83, 0x51, 0x74, 0x3d, 0xd1, 0x78, 0xc5, 0x0b, 0x3f, 0xba, 0x0d, 0xd4, 0x12, 0x5b, 0x7a, 0x4e,
		0x64, 0xed, 0x2c, 0x8c, 0xd4, 0xac, 0xa5, 0x32, 0xa6, 0xae, 0x89, 0x9d, 0xa7, 0x27, 0x0d, 0xe4,
		0xbe, 0x8a, 0xfd, 0xc1, 0xcc, 0x5f, 0x79, 0x19, 0xde, 0x2e, 0xb4, 0x77, 0xb7, 0x8a, 0xcc, 0xa7,
		0x76, 0xe6, 0xff, 0xb5, 0x75, 0xaa, 0xb4, 0xf7, 0xcb, 0xfe, 0xfe, 0xe1, 0xd1, 0xfe, 0xfe, 0xee,
		0xd1, 0x8b, 0xa3, 0xdd, 0xe3, 0x83, 0x83, 0xbd, 0x43, 0x8d, 0x3b, 0x66, 0x9d, 0xd1, 0xae, 0x9d,
		0x6a, 0x48, 0x79, 0x57, 0x56, 0xb6, 0xb7, 0x53, 0x22, 0x9b, 0x51, 0x6b, 0x46, 0xd1, 0x28, 0x99,
		0x13, 0x37, 0x51, 0x33, 0x51, 0x9b, 0x0c, 0x3e, 0x04, 0x77, 0xfe, 0xd8, 0x4f, 0x3e, 0xcc, 0x1c,
		0x85, 0xe7, 0xa3, 0x71, 0x10, 0x0d, 0xe6, 0xec, 0xaa, 0x1e, 0x05, 0xc9, 0x9f, 0xa3, 0xf8, 0xdf,
		0xf5, 0x30, 0x9a, 0x24, 0x7e, 0x34, 0x08, 0x9e, 0x3f, 0xfe, 0x8b, 0xc9, 0xda, 0xdf, 0x3c, 0x1f,
		0xc7, 0xa3, 0x64, 0x34, 0x18, 0x0d, 0x27, 0xd9, 0x4f, 0xcf, 0xdf, 0xdf, 0x8e, 0x9f, 0x47, 0x41,
		0x78, 0xfb, 0xe1, 0xfd, 0x28, 0x9e, 0x64, 0x3f, 0x3d, 0x9f, 0x24, 0x7e, 0x12, 0x3c, 0xbf, 0x0b,
		0x26, 0x13, 0xff, 0x36, 0x98, 0x3c, 0x8f, 0x83, 0x41, 0x10, 0xde, 0x07, 0xd7, 0x82, 0xee, 0x49,
		0x6d, 0x92, 0xc4, 0xd3, 0x41, 0x12, 0xa5, 0x6e, 0x5f, 0x77, 0xb1, 0xf6, 0x76, 0xba, 0x74, 0xaf,
		0x97, 0x2e, 0xd8, 0x3b, 0xb9, 0x1d, 0x7b, 0xdd, 0x74, 0x99, 0xde, 0x59, 0xba, 0x40, 0xef, 0x62,
		0xb9, 0xc0, 0x9d, 0x72, 0xe8, 0xa6, 0x80, 0x5e, 0xd6, 0x26, 0x0b, 0x26, 0x23, 0xa3, 0x8d, 0x99,
		0x3f, 0x3e, 0x97, 0x22, 0x74, 0xaa, 0x96, 0x57, 0x9b, 0x0b, 0x3d, 0x5e, 0x3a, 0x2e, 0xa1, 0x11,
		0x8f, 0xd0, 0x8b, 0x43, 0x68, 0xc5, 0x1f, 0xd4, 0xe3, 0x0e, 0xea, 0xf1, 0x06, 0xd5, 0x38, 0x43,
		0xb9, 0x70, 0xf4, 0x65, 0x18, 0x0b, 0x1f, 0x97, 0xf3, 0xcb, 0xf6, 0xab, 0xf6, 0x69, 0x73, 0x3e,
		0xd6, 0x43, 0x2d, 0xbc, 0x9b, 0x93, 0x4a, 0x50, 0xd7, 0x35, 0x23, 0xaa, 0x6f, 0x4c, 0xb5, 0x8d,
		0xaa, 0x99, 0x71, 0x35, 0x33, 0xb2, 0x26, 0xc6, 0x56, 0x87, 0xd6, 0x55, 0x2f, 0xa8, 0x3b, 0x0d,
		0xa3, 0xa4, 0x72, 0xf1, 0x5c, 0xe2, 0xaa, 0x15, 0x0a, 0x86, 0x11, 0x57, 0x95, 0x51, 0x25, 0xe2,
		0xaa, 0xc4, 0x55, 0x4b, 0x29, 0xe5, 0x1d, 0x55, 0x34, 0x6b, 0x6a, 0x75, 0xd5, 0x7b, 0xd9, 0xbc,
		0x6c, 0xe9, 0xd1, 0xaa, 0x54, 0x1e, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0x82, 0x50, 0x41, 0xa8, 0x20,
		0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0x82, 0x50, 0x95, 0x9f, 0x50, 0xad,
		0xb7, 0x05, 0x04, 0x71, 0x3c, 0x8a, 0xeb, 0x83, 0xd1, 0xb5, 0x69, 0x73, 0xc2, 0x83, 0x55, 0x40,
		0xbe, 0x20, 0x5f, 0x90, 0x2f, 0xc8, 0x17, 0xe4, 0x2b, 0x3b, 0x6f, 0xe1, 0x75, 0x10, 0x25, 0x61,
		0xf2, 0x31, 0x0e, 0x6e, 0x14, 0x19, 0x98, 0x86, 0xcf, 0x53, 0x6b, 0xa7, 0xaf, 0x76, 0xe2, 0x4f,
		0x14, 0x8f, 0x79, 0xd6, 0xc6, 0xfc, 0xba, 0xe7, 0xb5, 0x2e, 0x2e, 0xce, 0x2f, 0x3c, 0xc5, 0x09,
		0x60, 0x16, 0x93, 0xbf, 0x8c, 0x3a, 0x6d, 0x5f, 0xb5, 0xbb, 0xed, 0xcb, 0x96, 0xd7, 0xbf, 0x6c,
		0x5e, 0xb6, 0xbc, 0xb3, 0xe6, 0xe9, 0x6f, 0xed, 0x6e, 0x6b, 0xb1, 0xe1, 0xf4, 0x33, 0x17, 0xb7,
		0xcb, 0xd9, 0x0c, 0x89, 0x0b, 0xaf, 0xf5, 0x7b, 0xaf, 0xcd, 0x2d, 0x2d, 0x85, 0xee, 0xee, 0xfc,
		0x9e, 0x64, 0x36, 0xb4, 0xb8, 0x0d, 0xcd, 0x0d, 0x5f, 0xc4, 0x18, 0x14, 0xbc, 0xbb, 0x8b, 0x14,
		0x16, 0xfb, 0x2b, 0xb5, 0xbf, 0xf9, 0xfb, 0x42, 0xd8, 0x66, 0xa1, 0x6d, 0x7e, 0x74, 0xe7, 0x80,
		0xf6, 0xfe, 0x32, 0x99, 0xc3, 0xf4, 0xe9, 0x16, 0x21, 0xb0, 0xc9, 0xf4, 0xbd, 0x1b, 0x51, 0xb0,
		0xe5, 0x42, 0x08, 0x84, 0x7d, 0x93, 0x20, 0x02, 0x61, 0x85, 0x6a, 0x07, 0x81, 0x30, 0x02, 0x61,
		0x5f, 0xd8, 0x31, 0x02, 0x61, 0x05, 0xca, 0x72, 0x25, 0x10, 0xa6, 0x3b, 0x0d, 0x7f, 0x8b, 0x62,
		0x61, 0x8f, 0x88, 0x19, 0xb7, 0x0e, 0x28, 0xef, 0x7f, 0xf3, 0xf2, 0xf2, 0xa2, 0x7d, 0x32, 0x23,
		0x6f, 0x8b, 0xbb, 0x4a, 0xb4, 0x39, 0x85, 0x01, 0x77, 0x73, 0x64, 0xe7, 0x97, 0x37, 0xf4, 0x9d,
		0x5f, 0xb4, 0x5f, 0xb7, 0xbb, 0x5e, 0xf6, 0x21, 0xd8, 0x7b, 0x05, 0xab, 0xd3, 0xbd, 0x68, 0x9d,
		0x9e, 0xbf, 0x9e, 0xdf, 0x7d, 0xe4, 0xfd, 0xb3, 0xd5, 0xe9, 0x78, 0xff, 0xe8, 0x9e, 0xff, 0x93,
		0x8f, 0xa0, 0xfa, 0x11, 0xb2, 0x21, 0xa3, 0x2b, 0x1b, 0x84, 0xf1, 0x51, 0x37, 0xfb, 0xaf, 0x3a,
		0xcd, 0xd7, 0x7d, 0x36, 0x5e, 0x6b, 0xe3, 0xcf, 0x9a, 0x9d, 0x57, 0xe7, 0x17, 0x67, 0xad, 0x97,
		0x5e, 0xb3, 0xef, 0xf5, 0x9a, 0xdc, 0x9a, 0xa8, 0x09, 0xb5, 0xdd, 0xd6, 0xe5, 0x3f, 0xcf, 0x2f,
		0xfe, 0xe1, 0xbd, 0x6a, 0xb7, 0x3a, 0x5c, 0x12, 0xaa, 0xa1, 0xed, 0xed, 0x7e, 0xbf, 0xdd, 0x7d,
		0x0d, 0xc4, 0xda, 0x5b, 0x9b, 0x95, 0x9f, 0xdf, 0xee, 0x5f, 0xb2, 0xf7, 0x9a, 0x46, 0xe7, 0xf7,
		0x4b, 0xef, 0xb7, 0xf3, 0x9e, 0xa9, 0xe6, 0x73, 0xe9, 0x4c, 0x49, 0xe3, 0x23, 0xd6, 0xfc, 0x7c,
		0x7b, 0x6e, 0xca, 0xb7, 0xe3, 0xe1, 0xdb, 0x70, 0xb7, 0x84, 0x33, 0x7c, 0x7b, 0x1b, 0x2a, 0x89,
		0xac, 0x79, 0xf5, 0x36, 0x99, 0x65, 0x13, 0xfe, 0xbc, 0x05, 0x95, 0x2e, 0x76, 0x3c, 0x79, 0x7b,
		0x20, 0xcf, 0x88, 0x0f, 0x6f, 0x81, 0xf6, 0x3a, 0xc1, 0x7b, 0xb7, 0xca, 0x4a, 0x18, 0xf1, 0xdb,
		0x6d, 0x32, 0x16, 0x76, 0x3c, 0xb6, 0xfa, 0xbb, 0xfc, 0xd9, 0x9e, 0x10, 0xb2, 0xe1, 0xca, 0x5f,
		0xe1, 0xa2, 0x75, 0xda, 0x6a, 0xbf, 0x69, 0x79, 0x57, 0xdd, 0xd6, 0xef, 0xbd, 0xd6, 0xe9, 0x65,
		0xeb, 0x65, 0x56, 0x99, 0x70, 0xde, 0x6b, 0x75, 0x4f, 0xcf, 0xbb, 0xaf, 0xda, 0x17, 0x67, 0x44,
		0xcf, 0x4c, 0xbf, 0x44, 0xab, 0x7f, 0xd9, 0x3c, 0xe9, 0xb4, 0xfb, 0xbf, 0xb5, 0x88, 0xe1, 0xdb,
		0x9f, 0x89, 0x7e, 0xab, 0x7b, 0x49, 0x40, 0x13, 0xa0, 0x2b, 0xab, 0x89, 0xdd, 0xea, 0x1d, 0x37,
		0x31, 0xa5, 0x5b, 0xaf, 0xe3, 0xba, 0x26, 0x73, 0x2b, 0x6e, 0x2e, 0xee, 0xb5, 0x4e, 0xdb, 0xaf,
		0xda, 0xa7, 0xec, 0x6a, 0x71, 0xbb, 0x3a, 0xef, 0xf0, 0x85, 0x82, 0x68, 0x6f, 0x7b, 0xf3, 0xe5,
		0x59, 0xbb, 0xdb, 0xee, 0x5f, 0x5e, 0x34, 0x2f, 0x67, 0x26, 0xe4, 0xa2, 0xd5, 0x6f, 0x91, 0xae,
		0xd7, 0x50, 0xf7, 0xf3, 0x6e, 0xd7, 0x3b, 0x3d, 0xef, 0x74, 0xda, 0xf3, 0xfb, 0xe5, 0x2f, 0x5a,
		0xfd, 0xf3, 0xce, 0xd5, 0xfc, 0x22, 0x11, 0x36, 0x5f, 0x7c, 0xf3, 0xcf, 0xaf, 0x2e, 0xbd, 0xf3,
		0x57, 0xf3, 0x4d, 0xbf, 0xba, 0x38, 0x6d, 0xf5, 0xd9, 0x73, 0xf9, 0x3d, 0xef, 0xb5, 0x5a, 0x17,
		0xde, 0xcb, 0x96, 0x37, 0xf7, 0xb8, 0x5f, 0x5f, 0x5d, 0xc0, 0xa6, 0x0d, 0xcc, 0x7b, 0xff, 0xb7,
		0xab, 0xcb, 0x97, 0xe7, 0xff, 0xc4, 0xc8, 0x28, 0x59, 0xf8, 0xd6, 0xe9, 0xe5, 0xc2, 0xba, 0xff,
		0xef, 0xdc, 0x2d, 0x67, 0xdb, 0x15, 0x6c, 0xfb, 0xe5, 0x6f, 0xad, 0x8b, 0xd4, 0xca, 0x78, 0xa7,
		0xbf, 0x35, 0xbb, 0xaf, 0x29, 0xfd, 0x54, 0xd8, 0xf6, 0xb3, 0xe6, 0xef, 0x5e, 0xf7, 0xea, 0xcc,
		0xeb, 0x5d, 0xb4, 0x5e, 0xb5, 0x7f, 0x6f, 0xf5, 0xbd, 0x8b, 0x56, 0xf3, 0xd4, 0x26, 0x64, 0x4a,
		0xac, 0xae, 0xa4, 0x14, 0xd0, 0x96, 0x8b, 0x6c, 0x01, 0xc5, 0xb6, 0xe7, 0x1c, 0x5b, 0x50, 0x0e,
		0x67, 0xc6, 0x2d, 0xaa, 0xbf, 0xb7, 0x96, 0x1c, 0x62, 0xeb, 0xcc, 0xaf, 0x3e, 0x57, 0xd8, 0x0e,
		0x0b, 0x6c, 0xc6, 0x09, 0xb6, 0xc0, 0xf6, 0x5a, 0xfa, 0xfe, 0xdb, 0x50, 0xfe, 0x66, 0xed, 0xe3,
		0x6f, 0xdb, 0x64, 0x43, 0xd2, 0x21, 0xca, 0xdb, 0xbf, 0xac, 0x3e, 0x5c, 0xe6, 0x4f, 0x17, 0x5d,
		0x50, 0x90, 0x58, 0x0e, 0x70, 0x59, 0x34, 0x68, 0xeb, 0xa6, 0x92, 0x62, 0x23, 0xed, 0x9c, 0xd8,
		0xee, 0xf9, 0xa5, 0xd7, 0xff, 0xa3, 0x7b, 0xfa, 0xdb, 0xc5, 0xf9, 0xbc, 0xd9, 0x8e, 0x48, 0xab,
		0xfc, 0xf6, 0x9f, 0x34, 0x1d, 0x80, 0xa7, 0xad, 0xde, 0xf5, 0xcb, 0x3f, 0x7a, 0x34, 0xd5, 0x03,
		0x58, 0xe5, 0x32, 0x98, 0xd5, 0xdf, 0x66, 0x4b, 0xc3, 0xb8, 0x5d, 0xbb, 0xab, 0x6b, 0x00, 0xb7,
		0xec, 0x32, 0x0e, 0xfc, 0x59, 0x03, 0xcd, 0x3e, 0x79, 0xdd, 0xf3, 0xda, 0x2f, 0x5b, 0xdd, 0xcb,
		0xf6, 0xab, 0x76, 0x8b, 0xc9, 0x74, 0x0a, 0xbb, 0x7e, 0xd5, 0x6d, 0x9e, 0x9e, 0xb6, 0x7a, 0x97,
		0xcd, 0x93, 0x4e, 0xcb, 0xcb, 0x2e, 0x4f, 0x62, 0xe7, 0x35, 0x76, 0xbe, 0x7f, 0xd5, 0xeb, 0x9d,
		0x5f, 0x5c, 0xb6, 0x5e, 0x7a, 0xa7, 0xcd, 0x5e, 0xf3, 0xa4, 0xdd, 0x69, 0x5f, 0xfe, 0xc1, 0xce,
		0xeb, 0x58, 0x9a, 0x79, 0x0e, 0xb3, 0x49, 0xc9, 0xa9, 0xb2, 0xa2, 0xbf, 0x69, 0x5d, 0xcc, 0x8b,
		0x1e, 0xba, 0x57, 0x67, 0x27, 0x18, 0x78, 0xed, 0xdd, 0xcf, 0x66, 0x04, 0xf5, 0x9a, 0x17, 0xcd,
		0xb3, 0xd6, 0xa5, 0xc9, 0x17, 0x80, 0x3f, 0x97, 0x98, 0x7a, 0x58, 0x39, 0x68, 0xdb, 0xd0, 0xce,
		0x66, 0xeb, 0x88, 0x6d, 0x45, 0xc3, 0xa0, 0xa9, 0xc3, 0xb5, 0x1d, 0x16, 0x42, 0xdd, 0xb1, 0xda,
		0x2e, 0xc5, 0xb5, 0x72, 0xa0, 0xb6, 0x6b, 0x97, 0x2d, 0x1d, 0x25, 0xee, 0x5b, 0xb4, 0x7d, 0xba,
		0xee, 0x7d, 0x8b, 0x49, 0x78, 0x67, 0x7a, 0xcd, 0xe2, 0x5c, 0x3e, 0xb7, 0x2b, 0x7e, 0x93, 0x20,
		0x6e, 0x57, 0x2c, 0x54, 0x3b, 0xb8, 0x5d, 0x91, 0xdb, 0x15, 0xbf, 0xb0, 0x63, 0xfa, 0xb7, 0x2b,
		0xce, 0xec, 0x62, 0x12, 0x0e, 0xfe, 0x3d, 0x39, 0xdc, 0x57, 0xbc, 0x5d, 0xf1, 0x17, 0x05, 0x51,
		0x57, 0x51, 0x98, 0x4c, 0x66, 0xaf, 0x18, 0xf9, 0xd1, 0x68, 0x12, 0x0c, 0x46, 0xd1, 0xf5, 0x44,
		0xe3, 0x15, 0x2f, 0xfc, 0xe8, 0x36, 0x50, 0x4b, 0x6c, 0xe9, 0x39, 0x91, 0xb5, 0xb3, 0x30, 0x52,
		0xb3, 0x96, 0xca, 0x98, 0xba, 0x26, 0x76, 0x9e, 0x9e, 0x34, 0x90, 0xfb, 0x2a, 0xf6, 0x07, 0x33,
		0x7f, 0xe5, 0x65, 0x78, 0xbb, 0xd0, 0xde, 0xdd, 0x2a, 0x32, 0x9f, 0xda, 0x99, 0xff, 0xd7, 0xd6,
		0xa9, 0xd2, 0xde, 0x2f, 0xfb, 0xfb, 0x87, 0x47, 0xfb, 0xfb, 0xbb, 0x47, 0x2f, 0x8e, 0x76, 0x8f,
		0x0f, 0x0e, 0xf6, 0x0e, 0x35, 0xee, 0x98, 0x75, 0x46, 0xbb, 0x76, 0xaa, 0x21, 0xe5, 0x5d, 0x59,
		0xd9, 0xde, 0x4e, 0x89, 0x6c, 0x46, 0xad, 0x19, 0x45, 0xa3, 0x64, 0x4e, 0xdc, 0x44, 0xcd, 0x44,
		0x6d, 0x32, 0xf8, 0x10, 0xdc, 0xf9, 0x63, 0x3f, 0xf9, 0x30, 0x73, 0x14, 0x9e, 0x8f, 0xc6, 0x41,
		0x34, 0x98, 0xb3, 0xab, 0x7a, 0x14, 0x24, 0x7f, 0x8e, 0xe2, 0x7f, 0xd7, 0xc3, 0x68, 0x92, 0xf8,
		0xd1, 0x20, 0x78, 0xfe, 0xf8, 0x2f, 0x26, 0x6b, 0x7f, 0xf3, 0x7c, 0x1c, 0x8f, 0x92, 0xd1, 0x60,
		0x34, 0x9c, 0x64, 0x3f, 0x3d, 0x7f, 0x7f, 0x3b, 0x7e, 0x1e, 0x05, 0xe1, 0xed, 0x87, 0xf7, 0xa3,
		0x78, 0x92, 0xfd, 0xf4, 0x7c, 0x92, 0xf8, 0x49, 0xf0, 0xfc, 0x2e, 0x98, 0x4c, 0xfc, 0xdb, 0x60,
		0xf2, 0x7c, 0x32, 0x73, 0x92, 0x05, 0xe9, 0xf8, 0x24, 0x89, 0xa7, 0x83, 0x24, 0x4a, 0x5d, 0xbe,
		0xee, 0x62, 0xdd, 0xed, 0x74, 0xd9, 0x5e, 0x2f, 0x5d, 0xac, 0x77, 0x72, 0x3b, 0xf6, 0xba, 0xe9,
		0x12, 0xbd, 0xb3, 0x74, 0x71, 0x5e, 0x7f, 0xb6, 0xb8, 0x9d, 0x72, 0xe8, 0x64, 0xb1, 0x4f, 0x2c,
		0x58, 0xbb, 0xa5, 0xb5, 0xda, 0x11, 0x6d, 0x16, 0x50, 0xe4, 0x8d, 0x14, 0xb8, 0x58, 0xdd, 0x2d,
		0x4e, 0xc3, 0x0a, 0xd4, 0xae, 0xda, 0xf2, 0x53, 0xd4, 0xfd, 0xeb, 0xeb, 0x38, 0x98, 0x4c, 0x0a,
		0xd7, 0xaf, 0x8c, 0x2f, 0xae, 0x49, 0x2a, 0xf8, 0x8c, 0xc8, 0x38, 0x69, 0x62, 0x31, 0x33, 0xc9,
		0x18, 0x99, 0x7c, 0x4c, 0x4c, 0x3a, 0x06, 0xa6, 0x16, 0xf3, 0x52, 0x8b, 0x71, 0xa9, 0xc4, 0xb4,
		0xdc, 0x46, 0x31, 0xb1, 0x18, 0x55, 0xa6, 0xef, 0xe1, 0x58, 0xc8, 0xba, 0x3c, 0xb4, 0x30, 0x7b,
		0xc7, 0x02, 0xcf, 0x4e, 0xf7, 0x46, 0x26, 0xf4, 0x23, 0xe8, 0x07, 0xaf, 0x76, 0xfe, 0x7e, 0x5f,
		0x70, 0xef, 0xd7, 0xbe, 0x81, 0x60, 0x1c, 0xb0, 0xd6, 0xf3, 0x93, 0x24, 0x88, 0x23, 0xf1, 0x48,
		0x5c, 0xed, 0xff, 0x7e, 0xf8, 0xe1, 0xed, 0x6e, 0xfd, 0xf8, 0xdd, 0xdf, 0x6f, 0xf7, 0xea, 0xc7,
		0xef, 0x16, 0x3f, 0xee, 0xcd, 0xff, 0x67, 0xf1, 0x73, 0xe3, 0xed, 0x6e, 0x7d, 0x7f, 0xf9, 0xf3,
		0xc1, 0xdb, 0xdd, 0xfa, 0xc1, 0xbb, 0x1f, 0xff, 0xf5, 0xaf, 0x9f, 0x7f, 0xfc, 0xcf, 0x8b, 0x4f,
		0xdf, 0xfe, 0x8b, 0xff, 0x23, 0x17, 0x42, 0x7f, 0x27, 0xf9, 0x31, 0xce, 0xfb, 0xed, 0xdf, 0xf9,
		0x22, 0x4e, 0x04, 0x1b, 0x84, 0x48, 0xbb, 0x8e, 0x79, 0x3a, 0xc4, 0x3c, 0x7d, 0xdf, 0x61, 0xf0,
		0xeb, 0x37, 0xcd, 0xfa, 0xab, 0x77, 0xff, 0xd9, 0xfb, 0x69, 0xff, 0xd3, 0xaf, 0x3f, 0xfe, 0xe7,
		0xe8, 0xd3, 0xe3, 0xbf, 0xfc, 0xfb, 0x73, 0xff, 0x6c, 0xef, 0xa7, 0xa3, 0x4f, 0xbf, 0x3e, 0xf1,
		0x5f, 0x0e, 0x3f, 0xfd, 0xfa, 0x95, 0xcf, 0x38, 0xf8, 0xf4, 0xc3, 0xda, 0x3f, 0x9d, 0xfd, 0x7d,
		0xe3, 0xa9, 0x5f, 0xd8, 0x7f, 0xe2, 0x17, 0x5e, 0x3c, 0xf5, 0x0b, 0x2f, 0x9e, 0xf8, 0x85, 0x27,
		0x97, 0xd4, 0x78, 0xe2, 0x17, 0x0e, 0x3e, 0xfd, 0xbd, 0xf6, 0xef, 0x7f, 0xf8, 0xfc, 0x3f, 0x3d,
		0xfc, 0xf4, 0xe3, 0xdf, 0x4f, 0xfd, 0xb7, 0xa3, 0x4f, 0x7f, 0xff, 0xfa, 0x23, 0xc6, 0x1a, 0xfd,
		0xdc, 0x5a, 0xfd, 0x2c, 0x49, 0xc4, 0xf0, 0xdd, 0x16, 0x44, 0x87, 0xc6, 0x41, 0x10, 0xd7, 0x7d,
		0xc1, 0xa0, 0xd0, 0x52, 0x00, 0xb1, 0x20, 0x62, 0x41, 0xc4, 0x82, 0x88, 0x05, 0x15, 0xa8, 0xef,
		0xfe, 0xa4, 0x1e, 0x4d, 0xef, 0xde, 0x07, 0xb1, 0x60, 0x28, 0xe8, 0x48, 0xe0, 0xd1, 0xb2, 0x55,
		0x40, 0x82, 0x5c, 0x4b, 0xa3, 0xca, 0x47, 0xab, 0x52, 0x56, 0xa9, 0x8a, 0x47, 0xb3, 0xae, 0x42,
		0xb2, 0x6a, 0x5b, 0xa3, 0x2a, 0x47, 0xfb, 0xd3, 0xef, 0x37, 0x8e, 0xf7, 0x8f, 0x0f, 0x8f, 0x1a,
		0xc7, 0x07, 0x15, 0xd2, 0x01, 0x7c, 0x6b, 0xb7, 0x7c, 0xeb, 0xdb, 0x78, 0x34, 0x1d, 0x0b, 0xbb,
		0xd7, 0x0b, 0x19, 0x78, 0xd8, 0x78, 0xd8, 0x78, 0xd8, 0x78, 0xd8, 0x05, 0xea, 0xfb, 0x30, 0xf0,
		0x6f, 0xe2, 0xe0, 0x46, 0x32, 0xd5, 0x2a, 0xe1, 0x60, 0xf7, 0xd2, 0x32, 0xa7, 0x9f, 0x7f, 0x7e,
		0x9e, 0xfd, 0xbf, 0x95, 0xa1, 0x9c, 0x3c, 0xf8, 0xf9, 0xc1, 0x8f, 0xf5, 0x79, 0x09, 0xd1, 0xb6,
		0xc0, 0x52, 0x22, 0xa1, 0x3b, 0x79, 0x54, 0x9a, 0x8b, 0x00, 0x94, 0x00, 0x25, 0x40, 0x09, 0x50,
		0x2a, 0x81, 0x71, 0xc9, 0xc1, 0xd2, 0xbe, 0xc0, 0xb3, 0x5b, 0xd1, 0xf4, 0x6e, 0xb6, 0x35, 0x9f,
		0xb6, 0x00, 0x64, 0xfe, 0xbf, 0x69, 0xb0, 0x98, 0xe1, 0x28, 0x84, 0x30, 0xe9, 0xf3, 0x65, 0xe0,
		0x65, 0x0f, 0x78, 0x01, 0x5e, 0x80, 0x17, 0x17, 0xe1, 0xe5, 0x65, 0x18, 0xcb, 0xa8, 0x7b, 0x18,
		0x8d, 0xa7, 0x89, 0x9c, 0x2e, 0x66, 0x65, 0x4a, 0x73, 0x31, 0x42, 0xea, 0x21, 0x1b, 0x3f, 0x15,
		0x1f, 0x2e, 0xa1, 0x31, 0x54, 0x42, 0x6f, 0x98, 0x84, 0xd6, 0x10, 0x09, 0xf5, 0xe1, 0x11, 0xea,
		0x43, 0x23, 0x54, 0x87, 0x45, 0x94, 0xab, 0x19, 0x52, 0x7c, 0x28, 0x44, 0x76, 0x5e, 0xa6, 0x61,
		0x94, 0xbc, 0x68, 0x28, 0x54, 0x56, 0x1e, 0x09, 0x8a, 0xd0, 0x99, 0xbf, 0xa0, 0x30, 0xa2, 0x43,
		0x73, 0xde, 0x82, 0x72, 0x73, 0xbc, 0xf6, 0x7c, 0x05, 0x8b, 0xce, 0x77, 0x85, 0x79, 0x0a, 0xaa,
		0x73, 0x14, 0xac, 0x54, 0x44, 0x2b, 0x83, 0x6b, 0xaa, 0x2b, 0x25, 0x9d, 0x2a, 0x50, 0x96, 0x2a,
		0x4f, 0x81, 0xb3, 0x58, 0x1b, 0x4d, 0x13, 0x15, 0x36, 0x91, 0xca, 0x81, 0x4e, 0x40, 0x27, 0xa0,
		0x13, 0xd0, 0x09, 0xe8, 0x04, 0x74, 0x02, 0x3a, 0x01, 0x9d, 0x80, 0x4e, 0x40, 0x27, 0xa0, 0x13,
		0x46, 0x74, 0x82, 0x31, 0x53, 0x66, 0x63, 0xa6, 0x44, 0x92, 0xc2, 0xcf, 0xbe, 0x77, 0xc8, 0xd4,
		0xff, 0xb3, 0x58, 0xcd, 0x16, 0x24, 0xfb, 0xe3, 0xe0, 0x6e, 0x74, 0x1f, 0xd4, 0xc7, 0x71, 0x78,
		0xef, 0x27, 0x81, 0x68, 0x3b, 0xe1, 0xba, 0x28, 0x2a, 0xcc, 0x28, 0x01, 0x30, 0x27, 0xb3, 0x94,
		0x00, 0xe8, 0x61, 0x98, 0x7c, 0x85, 0xd9, 0x9a, 0x91, 0xa9, 0x8f, 0xc6, 0x73, 0xcc, 0x14, 0x2c,
		0x38, 0x13, 0x70, 0x39, 0x6b, 0xed, 0xeb, 0x20, 0x4a, 0xc2, 0xe4, 0xe3, 0x89, 0x3f, 0x09, 0xe4,
		0x83, 0x91, 0x17, 0xad, 0xb3, 0xf3, 0x37, 0x2d, 0xaf, 0x77, 0xd1, 0x7e, 0xd3, 0xbc, 0x6c, 0x79,
		0xcd, 0x7e, 0x7a, 0x85, 0x8c, 0xd4, 0x91, 0x53, 0xb8, 0x26, 0x58, 0xe9, 0x4a, 0x92, 0x07, 0x5b,
		0x96, 0x6e, 0x62, 0xb3, 0xd3, 0xa9, 0x95, 0xb1, 0x4f, 0xd0, 0x62, 0xc3, 0x7a, 0x9d, 0xe6, 0xa9,
		0xf4, 0x8e, 0xed, 0x94, 0x83, 0xd2, 0x6c, 0x43, 0x65, 0x69, 0x3c, 0x9a, 0x26, 0x41, 0xfd, 0x66,
		0xe8, 0x8f, 0xeb, 0xd7, 0xfe, 0xdd, 0x38, 0x8c, 0x6e, 0x05, 0xbd, 0xcd, 0x75, 0x59, 0x45, 0xd7,
		0xb3, 0x05, 0x37, 0xfe, 0x74, 0x38, 0x47, 0xf3, 0x1b, 0x7f, 0x38, 0xa1, 0x61, 0x02, 0x77, 0x16,
		0x77, 0x16, 0x77, 0xb6, 0x50, 0x7d, 0x7f, 0x3f, 0x1a, 0x0d, 0x03, 0x5f, 0xd4, 0x7b, 0xdd, 0xdb,
		0x02, 0xe0, 0x99, 0x04, 0xd1, 0x75, 0x7d, 0x30, 0xba, 0xbb, 0x9b, 0x46, 0x61, 0xf2, 0x51, 0x0e,
		0x74, 0x1e, 0xc9, 0x91, 0x03, 0x9c, 0xee, 0x79, 0xb7, 0x05, 0xde, 0x80, 0x37, 0xe0, 0x0d, 0x78,
		0x53, 0xa4, 0xbe, 0x67, 0xb6, 0x8b, 0x2e, 0x3d, 0xe7, 0x21, 0x6d, 0x32, 0x09, 0x47, 0x51, 0x7d,
		0x9e, 0x3e, 0x91, 0x44, 0xb4, 0x87, 0x62, 0x40, 0x1c, 0x10, 0x07, 0xc4, 0x01, 0x71, 0x0a, 0xd4,
		0xf7, 0x20, 0x9a, 0xde, 0x05, 0xb1, 0x2f, 0x1d, 0xa3, 0x07, 0x6e, 0x36, 0x84, 0x9b, 0xe9, 0x78,
		0x3c, 0x8a, 0x93, 0xe0, 0xba, 0x3e, 0xf0, 0xc7, 0xfe, 0xfb, 0x70, 0x18, 0x26, 0xa1, 0x64, 0x93,
		0xf8, 0x13, 0xf2, 0x00, 0x20, 0x00, 0x08, 0x00, 0x02, 0x80, 0x0a, 0xd4, 0xf7, 0x30, 0xcd, 0xb4,
		0x0a, 0x0f, 0xcb, 0x2a, 0x7f, 0x92, 0xf8, 0xe4, 0x75, 0xcf, 0x3b, 0x6d, 0xf6, 0x9a, 0x27, 0xed,
		0x4e, 0xfb, 0xf2, 0x0f, 0x52, 0xc3, 0x5f, 0xda, 0xaf, 0xb3, 0xde, 0xc9, 0xeb, 0x1e, 0xa9, 0xe0,
		0xa7, 0x37, 0xa8, 0xd9, 0xef, 0xbe, 0x68, 0xb0, 0x41, 0x4f, 0x6f, 0xd0, 0xeb, 0x8b, 0xe6, 0x69,
		0xeb, 0xd5, 0x55, 0xc7, 0xbb, 0x68, 0xf5, 0x2f, 0x9b, 0x17, 0x97, 0xec, 0xd5, 0xd3, 0x7b, 0x75,
		0x71, 0x7e, 0x75, 0xd9, 0xf2, 0x2e, 0x5a, 0xaf, 0x2e, 0x5a, 0xfd, 0xdf, 0xd8, 0xa8, 0xff, 0x72,
		0xea, 0x5e, 0xbe, 0xf4, 0x7a, 0xcd, 0xcb, 0xdf, 0xfa, 0x6c, 0xd2, 0xd3, 0x9b, 0xd4, 0xfa, 0xfd,
		0xb2, 0xd5, 0x7d, 0xd9, 0x7a, 0xe9, 0x75, 0x5b, 0xbf, 0x5f, 0xfe, 0x76, 0xde, 0xf3, 0x5a, 0xdd,
		0xd3, 0xf3, 0x97, 0xed, 0xee, 0x6b, 0x0a, 0x55, 0xdc, 0xf6, 0x17, 0x3b, 0xe1, 0x24, 0x69, 0x26,
		0x89, 0xd0, 0xa4, 0xa1, 0xb3, 0x30, 0x6a, 0x0d, 0x83, 0x99, 0x47, 0x3e, 0x91, 0xe9, 0x71, 0xa9,
		0x9d, 0xf9, 0x7f, 0x3d, 0x90, 0xb0, 0xf7, 0xcb, 0xfe, 0xfe, 0xe1, 0xd1, 0xfe, 0xfe, 0xee, 0xd1,
		0x8b, 0xa3, 0xdd, 0xe3, 0x83, 0x83, 0xbd, 0x43, 0x11, 0x3f, 0xf2, 0x3c, 0xbe, 0x0e, 0xe2, 0xe0,
		0xfa, 0xe4, 0x63, 0xed, 0xd7, 0x67, 0xd1, 0x74, 0x38, 0x74, 0x35, 0x9e, 0xb1, 0xe3, 0x90, 0xc6,
		0x49, 0xf5, 0x63, 0xd8, 0xf6, 0x61, 0x14, 0x63, 0xde, 0x36, 0xff, 0x50, 0x05, 0x7c, 0xa4, 0x5a,
		0x12, 0xde, 0x05, 0x71, 0x71, 0x21, 0xaa, 0x0c, 0x1b, 0xd2, 0xe7, 0x16, 0xa4, 0x46, 0xc5, 0xce,
		0x2d, 0x2c, 0x3c, 0xf4, 0x24, 0x11, 0x72, 0x92, 0x0b, 0x35, 0x49, 0x85, 0x98, 0xc4, 0x43, 0x4b,
		0xe2, 0x21, 0x25, 0xd1, 0x50, 0x92, 0x5b, 0x86, 0xb9, 0xe8, 0x39, 0x83, 0xb5, 0xc1, 0xf2, 0x4c,
		0x09, 0xc5, 0xba, 0xd3, 0xe7, 0x33, 0x10, 0x95, 0xd8, 0xb6, 0x99, 0x01, 0x52, 0x33, 0x44, 0x2a,
		0x06, 0xa9, 0x1c, 0x5c, 0x45, 0x6c, 0x20, 0xea, 0x60, 0x14, 0x45, 0xc1, 0x20, 0xa9, 0xc7, 0x41,
		0x12, 0x7f, 0x94, 0x0f, 0x0c, 0xe7, 0xc5, 0x09, 0xa9, 0xcb, 0x83, 0xe2, 0xc7, 0x17, 0xbb, 0x8c,
		0x4d, 0x52, 0xb7, 0xa1, 0x7a, 0xb6, 0x54, 0xcb, 0xa6, 0xaa, 0xdb, 0x56, 0x75, 0x1b, 0xab, 0x6a,
		0x6b, 0x65, 0xe3, 0x58, 0xe5, 0x1f, 0x9b, 0x74, 0x1d, 0x0c, 0xc2, 0x3b, 0x7f, 0x78, 0xb8, 0xaf,
		0x71, 0xc5, 0x7d, 0x43, 0x50, 0xc6, 0xda, 0xe4, 0x93, 0x06, 0x73, 0x9a, 0xbe, 0x22, 0xb0, 0x67,
		0x30, 0xa7, 0xa9, 0xc1, 0x9c, 0x26, 0xc7, 0xed, 0x4f, 0x5e, 0x45, 0x0c, 0xe6, 0x34, 0xbd, 0x40,
		0x45, 0xdc, 0x06, 0x3e, 0xf9, 0xa7, 0x6f, 0xf3, 0xb4, 0xd7, 0x0f, 0xa3, 0xe1, 0x75, 0x3d, 0x09,
		0xef, 0x14, 0xca, 0x67, 0x56, 0xa2, 0xe4, 0x19, 0xd2, 0x31, 0x0c, 0x09, 0x86, 0x04, 0x43, 0x82,
		0x21, 0xc1, 0x90, 0x60, 0x48, 0x30, 0x24, 0x18, 0x12, 0x0c, 0x09, 0x86, 0x04, 0x43, 0x82, 0x21,
		0x7d, 0xbb, 0x9a, 0xfc, 0x3b, 0x08, 0xc6, 0xfe, 0x30, 0xbc, 0x0f, 0xea, 0x61, 0x94, 0x04, 0xf1,
		0xbd, 0x3f, 0x94, 0xa7, 0x4a, 0x9f, 0x91, 0x49, 0x56, 0x09, 0xce, 0x04, 0x67, 0x82, 0x33, 0xc1,
		0x99, 0xe0, 0x4c, 0x70, 0x26, 0x38, 0x13, 0x9c, 0x09, 0xce, 0x04, 0x67, 0x82, 0x33, 0x39, 0xc9,
		0x99, 0xee, 0xc2, 0x28, 0xbc, 0x9b, 0xde, 0xd5, 0xfd, 0xeb, 0xfb, 0x20, 0x4e, 0xc2, 0xc9, 0xbc,
		0x9f, 0x47, 0x91, 0x3f, 0x7d, 0x41, 0x3e, 0x5c, 0x0a, 0x2e, 0x05, 0x97, 0x82, 0x4b, 0xc1, 0xa5,
		0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0x05, 0x97, 0x82, 0x4b, 0x39, 0xf6, 0x44,
		0x2e, 0x50, 0xfc, 0xba, 0xc6, 0xfd, 0x45, 0x3f, 0xfa, 0xf3, 0xb4, 0x8b, 0x74, 0x1b, 0x66, 0x51,
		0x0a, 0x8f, 0x3c, 0x16, 0x1c, 0x75, 0x2c, 0xd6, 0x8d, 0xdb, 0xa0, 0x1b, 0x57, 0x8f, 0x97, 0xd2,
		0x8d, 0x5b, 0x41, 0x78, 0xa0, 0x1b, 0xf7, 0x5b, 0x36, 0x8b, 0x58, 0x9f, 0xa9, 0x0d, 0xd5, 0xb3,
		0xa5, 0x5a, 0x36, 0x55, 0xdd, 0xb6, 0xaa, 0xdb, 0x58, 0x55, 0x5b, 0x2b, 0x4b, 0x4a, 0x88, 0xf5,
		0x7d, 0x93, 0xd3, 0x47, 0xac, 0xef, 0x9b, 0xfe, 0x10, 0xeb, 0x23, 0x90, 0x63, 0x62, 0x7f, 0xf2,
		0x2a, 0x42, 0xac, 0xaf, 0xd4, 0x2a, 0x42, 0xac, 0x4f, 0x74, 0xbd, 0x74, 0xe3, 0x7e, 0x35, 0x43,
		0xa2, 0x1b, 0x17, 0x86, 0x04, 0x43, 0x82, 0x21, 0xc1, 0x90, 0x60, 0x48, 0x30, 0x24, 0x18, 0x12,
		0x0c, 0x09, 0x86, 0x04, 0x43, 0x82, 0x21, 0x7d, 0x87, 0x9a, 0xd0, 0x8d, 0x0b, 0x67, 0x82, 0x33,
		0xc1, 0x99, 0xe0, 0x4c, 0x70, 0x26, 0x38, 0x13, 0x9c, 0x09, 0xce, 0x04, 0x67, 0x82, 0x33, 0xc1,
		0x99, 0xe0, 0x4c, 0x4f, 0xab, 0x09, 0xdd, 0xb8, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0x05,
		0x97, 0x82, 0x4b, 0xc1, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0xf5, 0xed,
		0x6a, 0x12, 0x05, 0xb7, 0xa3, 0x24, 0xf4, 0x93, 0xe0, 0xba, 0xae, 0x58, 0xac, 0xf7, 0x59, 0xa9,
		0x50, 0x1a, 0x28, 0x0d, 0x94, 0x06, 0x4a, 0x03, 0xa5, 0x81, 0xd2, 0x40, 0x69, 0xa0, 0x34, 0x50,
		0x1a, 0x28, 0x0d, 0x94, 0xa6, 0xe2, 0x94, 0x86, 0x01, 0x43, 0x76, 0x03, 0x86, 0x16, 0x73, 0x71,
		0x5c, 0x9d, 0x2f, 0xb4, 0xe3, 0x90, 0x46, 0x48, 0x69, 0x82, 0xb1, 0x06, 0xd4, 0x0a, 0x9d, 0xe1,
		0x14, 0x4f, 0x07, 0x49, 0x94, 0x3a, 0xc6, 0xdd, 0xc5, 0xd2, 0xda, 0xe9, 0xca, 0xbc, 0x5e, 0xba,
		0x1e, 0xef, 0xe4, 0x76, 0xec, 0x75, 0xd3, 0x55, 0x78, 0x97, 0x8b, 0x55, 0xec, 0xb8, 0xa1, 0x2f,
		0x05, 0xe8, 0x4a, 0x2d, 0x89, 0xfd, 0x68, 0x32, 0x1e, 0xc5, 0x49, 0x61, 0x6a, 0x92, 0x71, 0x8d,
		0xd5, 0xa3, 0x0b, 0xd2, 0xe9, 0x62, 0x27, 0x58, 0x15, 0x1e, 0x08, 0x91, 0x08, 0x7c, 0xc8, 0x05,
		0x3a, 0xa4, 0x02, 0x1b, 0xe2, 0x81, 0x0c, 0xf1, 0xc0, 0x85, 0x68, 0xa0, 0xc2, 0x2d, 0x94, 0x28,
		0x7a, 0xe2, 0x54, 0x6d, 0xb0, 0x3c, 0x53, 0x42, 0x93, 0xf1, 0xd2, 0xe7, 0x97, 0x6c, 0x34, 0xde,
		0x2e, 0xa3, 0xf1, 0xe4, 0x0d, 0x8f, 0x9a, 0x01, 0x52, 0x33, 0x44, 0x2a, 0x06, 0xa9, 0x1c, 0xc4,
		0x46, 0x6c, 0x34, 0xde, 0x70, 0x34, 0xf0, 0x87, 0x75, 0xff, 0xfa, 0x3a, 0x0e, 0x26, 0x13, 0xf9,
		0x3c, 0x52, 0x5e, 0x1c, 0x09, 0x24, 0x6d, 0xf3, 0xa6, 0x67, 0xe6, 0xb4, 0xcc, 0x9d, 0xba, 0xd9,
		0x53, 0x37, 0x7f, 0xaa, 0x66, 0x50, 0x36, 0xd2, 0x55, 0xfe, 0x04, 0xd2, 0x34, 0x0a, 0x47, 0x91,
		0x46, 0xf2, 0xe8, 0x58, 0x50, 0x46, 0xba, 0x5d, 0xa5, 0x4f, 0xe7, 0x2c, 0x3f, 0x4a, 0x38, 0x16,
		0x86, 0x14, 0xed, 0x2f, 0xa4, 0xfb, 0xa5, 0xf4, 0xbe, 0xd8, 0x67, 0xbe, 0xdc, 0xfd, 0xbe, 0xe2,
		0xb7, 0x5b, 0xfb, 0x86, 0xbf, 0x28, 0xca, 0xec, 0xf9, 0x49, 0x12, 0xc4, 0x91, 0xda, 0xe7, 0xcc,
		0x04, 0xff, 0xdf, 0x0f, 0x3f, 0xbc, 0xdd, 0xad, 0x1f, 0xbf, 0xfb, 0xfb, 0xed, 0x5e, 0xfd, 0xf8,
		0xdd, 0xe2, 0xc7, 0xbd, 0xf9, 0xff, 0x2c, 0x7e, 0x6e, 0xbc, 0xdd, 0xad, 0xef, 0x2f, 0x7f, 0x3e,
		0x78, 0xbb, 0x5b, 0x3f, 0x78, 0xf7, 0xe3, 0xbf, 0xfe, 0xf5, 0xf3, 0x8f, 0xff, 0x79, 0xf1, 0xe9,
		0xdb, 0x7f, 0xf1, 0x7f, 0x6a, 0x6a, 0x2f, 0xf7, 0x4e, 0xf3, 0xe3, 0x9d, 0xf7, 0xdb, 0xbf, 0xf3,
		0x05, 0x8b, 0xfe, 0x82, 0x2a, 0x92, 0x3e, 0xfd, 0x54, 0x61, 0xf3, 0x79, 0x88, 0xf9, 0xd4, 0x39,
		0x7c, 0x7e, 0xfd, 0xa6, 0x59, 0x7f, 0xf5, 0xee, 0x3f, 0x7b, 0x3f, 0xed, 0x7f, 0xfa, 0xf5, 0xc7,
		0xff, 0x1c, 0x7d, 0x7a, 0xfc, 0x97, 0x7f, 0x7f, 0xee, 0x9f, 0xed, 0xfd, 0x74, 0xf4, 0xe9, 0xd7,
		0x27, 0xfe, 0xcb, 0xe1, 0xa7, 0x5f, 0xbf, 0xf2, 0x19, 0x07, 0x9f, 0x7e, 0x58, 0xfb, 0xa7, 0xb3,
		0xbf, 0x6f, 0x3c, 0xf5, 0x0b, 0xfb, 0x4f, 0xfc, 0xc2, 0x8b, 0xa7, 0x7e, 0xe1, 0xc5, 0x13, 0xbf,
		0xf0, 0xe4, 0x92, 0x1a, 0x4f, 0xfc, 0xc2, 0xc1, 0xa7, 0xbf, 0xd7, 0xfe, 0xfd, 0x0f, 0x9f, 0xff,
		0xa7, 0x87, 0x9f, 0x7e, 0xfc, 0xfb, 0xa9, 0xff, 0x76, 0xf4, 0xe9, 0xef, 0x5f, 0x7f, 0x04, 0x4c,
		0xd0, 0x67, 0xf4, 0xd9, 0x69, 0x68, 0xdd, 0x29, 0xf7, 0x7b, 0x08, 0xbb, 0x06, 0x8a, 0x1c, 0x78,
		0x92, 0xc4, 0x61, 0x74, 0xab, 0xc9, 0x7f, 0x7f, 0xa1, 0xd4, 0x4a, 0x74, 0xbd, 0x22, 0x9d, 0xf8,
		0xc9, 0xb4, 0x7e, 0x1d, 0x4e, 0x06, 0xa3, 0xfb, 0x40, 0xe3, 0x26, 0x9c, 0xbc, 0x38, 0xf9, 0x3e,
		0xfb, 0x1b, 0x7f, 0x38, 0xa1, 0x2f, 0xe5, 0x29, 0xaf, 0x83, 0xb4, 0xc2, 0xf7, 0x7c, 0x75, 0xd2,
		0x0a, 0xce, 0x5b, 0xf5, 0xf2, 0xa7, 0x15, 0xde, 0x8f, 0x46, 0xc3, 0xc0, 0x57, 0x49, 0x2c, 0xec,
		0x6d, 0x31, 0xfc, 0x8d, 0xfd, 0xc9, 0x24, 0xbc, 0x0f, 0xea, 0x77, 0xa3, 0x6b, 0x85, 0xa6, 0xc9,
		0x9c, 0x34, 0xc0, 0x0f, 0xf0, 0x03, 0xfc, 0x00, 0x3f, 0xc0, 0x0f, 0xf0, 0xb3, 0x01, 0xbf, 0x64,
		0x30, 0xae, 0xdf, 0x69, 0x14, 0x79, 0x2d, 0x05, 0x01, 0x45, 0x40, 0x11, 0x50, 0x04, 0x14, 0x95,
		0x08, 0x8a, 0xa6, 0x61, 0x94, 0xec, 0x1d, 0x2a, 0x20, 0xd1, 0x21, 0xed, 0xfa, 0x5f, 0x7e, 0x11,
		0x8b, 0x76, 0xfd, 0x5d, 0x7a, 0xb1, 0x1d, 0x37, 0x07, 0x79, 0x15, 0x31, 0x68, 0xd7, 0xd7, 0x56,
		0x91, 0xc3, 0x83, 0x83, 0x17, 0x07, 0xb4, 0xec, 0xbb, 0xf6, 0x74, 0x5a, 0xf6, 0x0b, 0xf1, 0x7a,
		0xaa, 0xda, 0xb2, 0xbf, 0xec, 0xfe, 0x7d, 0x9e, 0xf6, 0xec, 0xb9, 0xda, 0xb6, 0x5f, 0x68, 0x4b,
		0xb9, 0x9f, 0x04, 0x72, 0xcd, 0x8f, 0x8b, 0xc7, 0x97, 0xac, 0xf7, 0xb1, 0x41, 0xef, 0xa3, 0x1e,
		0x5b, 0xa4, 0xf7, 0xb1, 0x82, 0x08, 0x41, 0xef, 0x23, 0xc1, 0x31, 0x82, 0x63, 0x04, 0xc7, 0x08,
		0x8e, 0x59, 0x07, 0xc7, 0xe8, 0x7d, 0x74, 0x27, 0x36, 0x46, 0xef, 0x63, 0xc9, 0xbe, 0xd8, 0x67,
		0xbe, 0x1c, 0xbd, 0x8f, 0xe2, 0x82, 0xe9, 0x7d, 0x2c, 0xe0, 0xe3, 0xd1, 0xfb, 0x28, 0xf1, 0x05,
		0xe9, 0x7d, 0xdc, 0xd4, 0x7c, 0xd2, 0xfb, 0xa8, 0x74, 0xf8, 0xe8, 0x15, 0xa3, 0xf7, 0xb1, 0x4a,
		0x60, 0x82, 0x3e, 0xd3, 0xfb, 0xe8, 0x68, 0x98, 0x40, 0xef, 0x3d, 0xe8, 0x7d, 0xdc, 0x00, 0xfc,
		0xc9, 0x59, 0x8b, 0xae, 0x57, 0xa2, 0xfe, 0x75, 0x11, 0x7f, 0x2f, 0x74, 0xd6, 0xf3, 0x93, 0x1a,
		0xf9, 0x40, 0x16, 0x81, 0xfe, 0xcf, 0xfb, 0x01, 0x04, 0xfa, 0xbf, 0xe7, 0xab, 0x13, 0xe8, 0x77,
		0xde, 0xce, 0x96, 0x3f, 0xd0, 0x3f, 0xb3, 0x5b, 0xf5, 0x68, 0x7a, 0xf7, 0x3e, 0x88, 0x29, 0x85,
		0x75, 0xc3, 0xd5, 0xa1, 0x14, 0xb6, 0x38, 0x79, 0x94, 0xc2, 0x96, 0x56, 0x45, 0x28, 0x85, 0x85,
		0x56, 0x38, 0x46, 0x2b, 0x18, 0xa9, 0x02, 0x89, 0x81, 0xc4, 0x40, 0x62, 0x20, 0x31, 0x6e, 0x91,
		0x18, 0xba, 0xca, 0x55, 0xe0, 0x8f, 0x91, 0x2a, 0x80, 0x1f, 0xe0, 0x07, 0xf8, 0x01, 0x7e, 0x80,
		0xdf, 0xd6, 0x81, 0x5f, 0x1c, 0xdc, 0x8d, 0x92, 0x40, 0xaf, 0x85, 0xe4, 0x91, 0x3c, 0x80, 0x09,
		0x60, 0x02, 0x98, 0x00, 0xa6, 0x12, 0x01, 0x93, 0x4a, 0xbb, 0x02, 0x8d, 0x24, 0xdf, 0xf5, 0x65,
		0x54, 0xdb, 0x11, 0x34, 0xeb, 0x68, 0xd5, 0xeb, 0x67, 0x2b, 0x57, 0xb4, 0xfe, 0x4e, 0xe3, 0x23,
		0x59, 0x54, 0x86, 0x56, 0xef, 0x4b, 0x51, 0x33, 0xf8, 0xb5, 0xe6, 0xee, 0x10, 0x73, 0x57, 0xec,
		0x21, 0xa2, 0xac, 0xba, 0x92, 0x65, 0xd5, 0x95, 0x37, 0xfe, 0xe8, 0x6d, 0x35, 0xf5, 0x96, 0x6a,
		0x8a, 0xb2, 0x46, 0xd4, 0x74, 0xaa, 0xb4, 0x1f, 0x0a, 0x23, 0x96, 0x46, 0x2c, 0x8d, 0x58, 0x1a,
		0xb1, 0xb4, 0x12, 0xc5, 0xd2, 0x28, 0xd3, 0x76, 0x8e, 0x5d, 0x52, 0xa6, 0x5d, 0x9c, 0x3c, 0xca,
		0xb4, 0x4b, 0xab, 0x22, 0x94, 0x69, 0x43, 0x2c, 0x1c, 0x23, 0x16, 0xdc, 0x7e, 0x02, 0xa1, 0x80,
		0x50, 0x40, 0x28, 0x20, 0x14, 0x4f, 0x9f, 0x17, 0x6e, 0x3f, 0x81, 0x4b, 0xc0, 0x25, 0xe0, 0x12,
		0x70, 0x09, 0xb8, 0x44, 0x65, 0xb8, 0x04, 0xb7, 0x9f, 0x98, 0xde, 0x7e, 0xb2, 0xb8, 0xb4, 0xc3,
		0xd5, 0xcb, 0x4f, 0x76, 0x1c, 0x52, 0x0a, 0x29, 0x65, 0xb0, 0x57, 0x82, 0x5a, 0xa1, 0x77, 0xcc,
		0xc4, 0xd3, 0x41, 0x12, 0xa5, 0x1e, 0x6b, 0x77, 0xb1, 0xba, 0x76, 0xba, 0x38, 0xaf, 0x97, 0x2e,
		0xc9, 0x3b, 0xb9, 0x1d, 0x7b, 0xdd, 0x74, 0x21, 0xde, 0x65, 0xb6, 0x90, 0x1d, 0x37, 0xb4, 0xa6,
		0x00, 0x8d, 0xa9, 0x4d, 0x27, 0x41, 0xfd, 0x6e, 0x3a, 0x4c, 0xc2, 0xf1, 0x30, 0xa8, 0xcf, 0x3e,
		0x6e, 0x71, 0xb1, 0x8d, 0x15, 0x21, 0x58, 0x97, 0x51, 0x90, 0xae, 0x17, 0x7b, 0xed, 0x4e, 0xe1,
		0x61, 0x0b, 0x89, 0x30, 0x85, 0x5c, 0x58, 0x42, 0x2a, 0x0c, 0x21, 0x1e, 0x76, 0x10, 0x0f, 0x33,
		0x88, 0x86, 0x15, 0xdc, 0x42, 0x8f, 0xa2, 0xaf, 0xc9, 0xa9, 0x0d, 0x96, 0x67, 0x4a, 0xe8, 0x3a,
		0xaf, 0xf4, 0xf9, 0x25, 0xbb, 0xcf, 0x6b, 0x97, 0xfb, 0xbc, 0xe4, 0x0d, 0x8f, 0x9a, 0x01, 0x52,
		0x33, 0x44, 0x2a, 0x06, 0xa9, 0x1c, 0x9c, 0x47, 0xec, 0x3e, 0xaf, 0x20, 0xf2, 0xdf, 0x0f, 0x83,
		0x6b, 0xf9, 0x14, 0xcf, 0x52, 0x10, 0x03, 0x08, 0x2c, 0x4c, 0xa6, 0x86, 0xe9, 0xd4, 0x33, 0xa1,
		0x5a, 0xa6, 0x54, 0xdd, 0xa4, 0xaa, 0x9b, 0x56, 0x55, 0x13, 0x2b, 0x1b, 0x60, 0x63, 0x00, 0xc1,
		0x37, 0x78, 0x7a, 0x7b, 0x44, 0x22, 0xdd, 0x0d, 0x3e, 0x99, 0x07, 0xa1, 0xd6, 0x43, 0x18, 0x5b,
		0x74, 0x21, 0x73, 0x30, 0xb3, 0x7d, 0x62, 0x04, 0x2e, 0x28, 0x1e, 0x11, 0xa1, 0x6f, 0xd0, 0x37,
		0xe8, 0xdb, 0x76, 0xd2, 0x37, 0xa1, 0x78, 0x93, 0x4e, 0xdc, 0x49, 0xd8, 0x80, 0x41, 0xaa, 0x20,
		0x55, 0x90, 0x2a, 0x37, 0x49, 0x95, 0x94, 0x41, 0xcc, 0x04, 0xf8, 0xc3, 0xe1, 0xe8, 0xcf, 0x95,
		0x13, 0xeb, 0x4f, 0xe4, 0xf5, 0x79, 0x79, 0x42, 0xd7, 0x45, 0x0b, 0xab, 0x99, 0x52, 0xec, 0x4b,
		0x29, 0x06, 0xa6, 0x66, 0xb6, 0x35, 0xcd, 0xb7, 0xbe, 0x19, 0xd7, 0x36, 0xe7, 0x66, 0x66, 0xdd,
		0xcc, 0xbc, 0x9b, 0x98, 0x79, 0x59, 0x73, 0x2f, 0x6c, 0xf6, 0xf5, 0x62, 0x6a, 0x06, 0xb1, 0x35,
		0xa5, 0x18, 0x9b, 0xbc, 0x02, 0x94, 0xcb, 0x93, 0x10, 0x8e, 0xc1, 0xb9, 0x18, 0x8b, 0x0b, 0x66,
		0xff, 0x54, 0x22, 0x20, 0x27, 0xa7, 0x01, 0x12, 0xdd, 0x69, 0x8b, 0x2a, 0x49, 0x71, 0xea, 0xbb,
		0x10, 0x53, 0x72, 0xe6, 0xdb, 0x80, 0xf9, 0xc2, 0x7c, 0x61, 0xbe, 0x30, 0x5f, 0x98, 0x2f, 0xcc,
		0x17, 0xe6, 0x0b, 0xf3, 0x85, 0xf9, 0xc2, 0x7c, 0x61, 0xbe, 0x30, 0xdf, 0x12, 0x32, 0x5f, 0x81,
		0xee, 0x38, 0x41, 0xe2, 0x4b, 0x01, 0x93, 0x3b, 0xaa, 0x53, 0x13, 0x89, 0x42, 0x7c, 0x7b, 0x6f,
		0xdd, 0xd5, 0x24, 0x38, 0x4b, 0x57, 0xd7, 0x9b, 0x2d, 0xce, 0x6b, 0x15, 0x8e, 0x9c, 0x6e, 0xd6,
		0x56, 0xc9, 0x84, 0x6c, 0x44, 0x43, 0x35, 0xe2, 0xd5, 0x55, 0x0d, 0xaa, 0xab, 0xf4, 0x7c, 0x76,
		0xaa, 0xab, 0x2a, 0x88, 0x62, 0x34, 0xc7, 0xb8, 0x11, 0x26, 0xa1, 0x39, 0xc6, 0xa5, 0x30, 0x08,
		0xd1, 0xec, 0x52, 0x86, 0x39, 0x68, 0x8e, 0xb1, 0x0a, 0x63, 0xd0, 0x1c, 0x03, 0xb7, 0xfc, 0x3e,
		0x6e, 0xc9, 0xbc, 0x1e, 0x6b, 0xad, 0x70, 0x48, 0x1b, 0xac, 0x07, 0xf7, 0x3c, 0x0e, 0x2e, 0x38,
		0x33, 0xbf, 0x67, 0xc7, 0x50, 0xff, 0x66, 0x4e, 0xca, 0x6c, 0x0b, 0x97, 0xdf, 0xad, 0xa0, 0x5b,
		0xcc, 0x6a, 0x9d, 0x70, 0x92, 0x34, 0x93, 0xa4, 0x18, 0xfe, 0x51, 0x3b, 0x0b, 0xa3, 0xd6, 0x30,
		0x98, 0x79, 0x1a, 0x93, 0x62, 0xbc, 0xdc, 0xda, 0x99, 0xff, 0xd7, 0x83, 0x27, 0xee, 0xfd, 0xb2,
		0xbf, 0x7f, 0x78, 0xb4, 0xbf, 0xbf, 0x7b, 0xf4, 0xe2, 0x68, 0xf7, 0xf8, 0xe0, 0x60, 0xef, 0x70,
		0xaf, 0x80, 0x29, 0x81, 0xb5, 0xf3, 0xf8, 0x3a, 0x88, 0x83, 0xeb, 0x93, 0xd9, 0x0e, 0x47, 0xd3,
		0xe1, 0xd0, 0xf4, 0x43, 0x17, 0x6c, 0x60, 0xac, 0x0c, 0x4b, 0x01, 0x56, 0xe4, 0x7b, 0xac, 0xc7,
		0x66, 0xc6, 0xe2, 0xfb, 0x8f, 0xf8, 0xf7, 0xfd, 0xe6, 0x77, 0xea, 0x4a, 0x51, 0x3a, 0xa2, 0xac,
		0x1b, 0xdf, 0xf7, 0x6d, 0xbe, 0x7d, 0x67, 0xbf, 0x63, 0x57, 0x6b, 0xe3, 0x20, 0x88, 0xeb, 0xb7,
		0xf1, 0x68, 0x3a, 0xfe, 0xfe, 0x72, 0x93, 0xd5, 0x1d, 0x2d, 0x0f, 0x1e, 0xf6, 0x9d, 0x5f, 0x78,
		0xb3, 0xa0, 0xed, 0xc6, 0x91, 0x86, 0x22, 0x22, 0x09, 0xc5, 0x45, 0x0a, 0x8a, 0x8a, 0x04, 0x14,
		0xce, 0xf4, 0x0b, 0x67, 0xf2, 0x85, 0x32, 0x75, 0x5d, 0x9b, 0xb4, 0x69, 0x10, 0xf3, 0xc1, 0xa9,
		0xd9, 0xfc, 0x43, 0xaf, 0x9f, 0xc4, 0x4d, 0xbf, 0x74, 0x31, 0x59, 0x94, 0xc2, 0x42, 0x80, 0x45,
		0x86, 0xfa, 0x8a, 0x0f, 0xe9, 0x15, 0x1d, 0xba, 0x13, 0x0b, 0xd1, 0x89, 0x85, 0xe2, 0x44, 0x42,
		0x6e, 0xb6, 0x0c, 0xa4, 0xa8, 0x2c, 0x45, 0xcd, 0xbf, 0x09, 0xeb, 0x13, 0xff, 0x26, 0x14, 0x98,
		0x5d, 0xba, 0x7a, 0x34, 0x23, 0x4b, 0xdd, 0x31, 0x07, 0x52, 0x66, 0x41, 0xdc, 0x3c, 0x88, 0x9b,
		0x09, 0x51, 0x73, 0xe1, 0x66, 0x00, 0xad, 0xf0, 0x91, 0xa5, 0xcb, 0x33, 0x2f, 0x57, 0x96, 0x91,
		0x49, 0x60, 0xee, 0x0d, 0x95, 0x19, 0x66, 0x46, 0x48, 0xcd, 0x18, 0xa9, 0x18, 0xa5, 0x62, 0x8d,
		0x53, 0xc1, 0x46, 0x4a, 0xcc, 0x58, 0xad, 0x8c, 0xd6, 0xf5, 0x75, 0xc1, 0xf3, 0xdb, 0x9f, 0xb6,
		0x5e, 0x99, 0x28, 0xa6, 0xdf, 0x68, 0x9b, 0x35, 0x3d, 0xf3, 0xa6, 0x65, 0xe6, 0xd4, 0xcd, 0x9d,
		0xba, 0xd9, 0x53, 0x35, 0x7f, 0x32, 0x66, 0x50, 0xc8, 0x1c, 0x8a, 0x9b, 0xc5, 0x4c, 0x80, 0xf0,
		0x58, 0xb0, 0xb5, 0x63, 0x29, 0x3a, 0x1e, 0x4c, 0xc9, 0x50, 0xaa, 0x19, 0x4c, 0x4d, 0xc3, 0xa9,
		0x6f, 0x40, 0xb5, 0x0d, 0xa9, 0x99, 0x41, 0x35, 0x33, 0xac, 0x26, 0x06, 0x56, 0xd6, 0xd0, 0x0a,
		0x1b, 0x5c, 0x35, 0xc3, 0x9b, 0x09, 0x0a, 0x86, 0xe1, 0x6d, 0xf8, 0x7e, 0x18, 0xd4, 0x17, 0xaa,
		0x58, 0x1f, 0x8f, 0x86, 0xe1, 0xe0, 0xa3, 0xde, 0x61, 0xc8, 0x0a, 0x8b, 0x3f, 0xbf, 0x8e, 0x9f,
		0x2a, 0x79, 0xfb, 0xa1, 0x96, 0xe1, 0xb6, 0x30, 0xe0, 0x76, 0x86, 0xdc, 0xca, 0xa0, 0x9b, 0x1b,
		0x76, 0x73, 0x03, 0x6f, 0x6a, 0xe8, 0x75, 0x0c, 0xbe, 0x92, 0xe1, 0xcf, 0x76, 0x52, 0xad, 0xfd,
		0x7a, 0xed, 0xbc, 0x0e, 0x03, 0xff, 0x26, 0x0e, 0x6e, 0x34, 0x0f, 0xec, 0xd2, 0x5f, 0x3e, 0x52,
		0x94, 0xd9, 0xcb, 0x8a, 0x61, 0x06, 0xf5, 0x78, 0x3c, 0x1a, 0xfe, 0x1a, 0x8f, 0xa6, 0x49, 0x18,
		0xdd, 0xa6, 0xc8, 0x93, 0xfd, 0xf5, 0xe2, 0xff, 0x5b, 0xbf, 0x0e, 0x6e, 0xc2, 0x28, 0x4c, 0xc2,
		0x51, 0x34, 0x79, 0xfa, 0x3f, 0x65, 0xff, 0x65, 0x5e, 0xca, 0xb4, 0x53, 0x0d, 0xad, 0xd7, 0xb8,
		0xea, 0x38, 0x0e, 0x06, 0x41, 0x78, 0x1f, 0xe8, 0xbb, 0x1d, 0x4b, 0xc1, 0x4a, 0xa7, 0x5a, 0x79,
		0x0c, 0x0c, 0xfe, 0x0d, 0xfe, 0x0d, 0xfe, 0x0d, 0xfe, 0x0d, 0xfe, 0x8d, 0xc9, 0x98, 0x99, 0x35,
		0xff, 0x66, 0x0f, 0x97, 0xe0, 0xab, 0xf7, 0x6c, 0x12, 0x44, 0xd7, 0xfa, 0xfe, 0xc0, 0x5c, 0x2a,
		0xce, 0x00, 0xce, 0x00, 0xce, 0x00, 0xce, 0x00, 0xce, 0x00, 0xce, 0x00, 0xce, 0x80, 0x2b, 0xce,
		0x40, 0xfd, 0xce, 0xff, 0xcb, 0xc6, 0x21, 0x98, 0x4b, 0x06, 0x9c, 0x01, 0x67, 0xc0, 0x19, 0x70,
		0x06, 0x9c, 0xd5, 0xce, 0xeb, 0x34, 0x8c, 0x92, 0x5f, 0x0c, 0xa0, 0xf9, 0x40, 0x51, 0xe4, 0x85,
		0x1f, 0xdd, 0xce, 0x5e, 0xf6, 0xad, 0xea, 0xf1, 0xd0, 0x35, 0x47, 0xcf, 0xd2, 0x91, 0x01, 0xea,
		0x76, 0xd0, 0x08, 0x55, 0xd7, 0xc4, 0xbf, 0xf1, 0x87, 0xd3, 0xc0, 0x50, 0xfe, 0xab, 0xd8, 0x1f,
		0x24, 0xe1, 0x28, 0x7a, 0x19, 0xde, 0x86, 0x8b, 0x89, 0x0d, 0xea, 0xeb, 0xf8, 0xf4, 0x93, 0x81,
		0xca, 0xf9, 0x7f, 0x6d, 0xbd, 0xca, 0x35, 0x0e, 0x0e, 0xb6, 0x58, 0xe9, 0x76, 0xaa, 0x29, 0xed,
		0x5d, 0x55, 0xa8, 0x63, 0xa9, 0x6b, 0xf4, 0x94, 0xc6, 0x9a, 0xaf, 0x48, 0xb0, 0xc6, 0x10, 0x8f,
		0x07, 0x23, 0x2d, 0x1e, 0xfc, 0xfc, 0x3c, 0xeb, 0xb7, 0xcd, 0x7e, 0x7a, 0x9e, 0xb5, 0x9b, 0x88,
		0xde, 0xf0, 0x25, 0xaf, 0x2a, 0x82, 0x6a, 0x22, 0x7c, 0xf3, 0xd7, 0x7a, 0xb0, 0x42, 0xf0, 0x06,
		0xb0, 0xc7, 0xc0, 0xa6, 0x56, 0xdc, 0xde, 0xa0, 0xb8, 0xbd, 0x3c, 0x11, 0x08, 0x8a, 0xdb, 0x29,
		0x6e, 0xff, 0xe2, 0x8e, 0x51, 0xdc, 0x4e, 0x71, 0x7b, 0x39, 0x0d, 0xb8, 0x9d, 0x21, 0xb7, 0x32,
		0xe8, 0xe6, 0x86, 0xdd, 0xdc, 0xc0, 0x9b, 0x1a, 0x7a, 0x5d, 0x6e, 0x49, 0x71, 0xbb, 0xa0, 0xbf,
		0x4c, 0x71, 0xbb, 0x8b, 0x11, 0x08, 0x8a, 0xdb, 0x8b, 0x73, 0xeb, 0xa8, 0x67, 0xc3, 0xbf, 0xc1,
		0xbf, 0xc1, 0xbf, 0xc1, 0xbf, 0xa1, 0x9e, 0x0d, 0x97, 0xe0, 0xbf, 0xed, 0x19, 0xc5, 0xed, 0x38,
		0x03, 0x38, 0x03, 0x38, 0x03, 0x38, 0x03, 0x38, 0x03, 0x38, 0x03, 0x38, 0x03, 0x14, 0xb7, 0x03,
		0xce, 0x80, 0x33, 0xe0, 0x0c, 0x38, 0x6f, 0x0d, 0x38, 0x53, 0xdc, 0x2e, 0xf5, 0x87, 0xe2, 0x76,
		0x55, 0xf1, 0x14, 0xb7, 0x53, 0xdc, 0x6e, 0xa4, 0x72, 0x14, 0xb7, 0x57, 0x50, 0x1a, 0xc5, 0xed,
		0x0e, 0x98, 0x1c, 0x8a, 0xdb, 0xaf, 0xe5, 0xae, 0xcc, 0xd6, 0xd3, 0x94, 0x72, 0x4d, 0x9b, 0x57,
		0xd2, 0x39, 0x67, 0x75, 0xad, 0x26, 0xda, 0x89, 0xf0, 0xd5, 0x57, 0xec, 0xf6, 0x82, 0x20, 0x7e,
		0x3d, 0x5b, 0xac, 0xd7, 0xbc, 0x09, 0xfb, 0xfe, 0x4d, 0xe8, 0x35, 0xaf, 0xaf, 0x0b, 0xbc, 0xa1,
		0x5b, 0x5e, 0x49, 0x05, 0x14, 0x34, 0xbb, 0x1b, 0xaa, 0x9e, 0xee, 0xa1, 0xf4, 0x65, 0x2e, 0x39,
		0x71, 0xb2, 0x17, 0xba, 0xec, 0x72, 0xa1, 0x8b, 0x03, 0xf1, 0x35, 0x2e, 0x74, 0x29, 0x65, 0x7c,
		0xac, 0x5c, 0x10, 0x2b, 0x1e, 0xef, 0x52, 0xac, 0xb4, 0xd5, 0xa8, 0xac, 0xcd, 0x2a, 0x69, 0x7f,
		0xfe, 0x79, 0xe1, 0x09, 0x3e, 0xcf, 0x1b, 0xe6, 0x6d, 0x06, 0xc4, 0xf1, 0x78, 0xf8, 0x51, 0xba,
		0xa5, 0x66, 0x85, 0x87, 0x0f, 0xa5, 0x71, 0xbf, 0x99, 0x0b, 0x70, 0x18, 0x8f, 0x47, 0x43, 0xf0,
		0xb0, 0x84, 0x78, 0x38, 0xff, 0x70, 0x00, 0xe2, 0x33, 0x6e, 0x38, 0x73, 0xd4, 0x54, 0xaa, 0x99,
		0x4c, 0x4d, 0xd3, 0x69, 0x60, 0x42, 0xb5, 0x4d, 0xa9, 0x99, 0x49, 0x35, 0x33, 0xad, 0x36, 0x26,
		0x56, 0xd6, 0xd4, 0x0a, 0x9b, 0x5c, 0x35, 0xd3, 0x9b, 0x09, 0xba, 0x5e, 0xd4, 0x22, 0xd7, 0x83,
		0xbf, 0xc6, 0xa3, 0x38, 0x31, 0xeb, 0x02, 0xff, 0xfc, 0x32, 0xf4, 0xeb, 0xb1, 0x2f, 0x5a, 0xff,
		0xdb, 0x3a, 0xbd, 0xf4, 0x2e, 0xce, 0xaf, 0x2e, 0x5b, 0x54, 0x7e, 0x95, 0x0e, 0x3f, 0x0c, 0x71,
		0xc4, 0x0a, 0x4f, 0xcc, 0x71, 0xc5, 0x1c, 0x5f, 0x6c, 0x71, 0x46, 0x07, 0x6f, 0x94, 0x70, 0x47,
		0x2f, 0x16, 0xf6, 0x45, 0x24, 0x48, 0x7b, 0xac, 0x93, 0xd9, 0x42, 0x0c, 0x8a, 0xb4, 0xf7, 0x15,
		0x65, 0xb6, 0xa2, 0xe9, 0xdd, 0x6c, 0xb3, 0x3f, 0x51, 0x18, 0xfe, 0xcd, 0x7e, 0x4b, 0x78, 0xe7,
		0x84, 0xdf, 0x92, 0x5f, 0x06, 0x7e, 0x0b, 0x7e, 0x0b, 0x7e, 0x0b, 0x7e, 0x0b, 0x7e, 0x0b, 0x7e,
		0x0b, 0x7e, 0x0b, 0x7e, 0xcb, 0x83, 0x3d, 0x33, 0x8e, 0xb3, 0x98, 0xc4, 0x57, 0x70, 0x14, 0x70,
		0x14, 0x70, 0x14, 0x70, 0x14, 0x70, 0x14, 0x18, 0xb3, 0x57, 0xba, 0x31, 0x7b, 0x4a, 0xfa, 0xd8,
		0x09, 0x27, 0x49, 0x33, 0x49, 0x62, 0x5d, 0x9d, 0x3c, 0x0b, 0xa3, 0xd6, 0x30, 0x98, 0x99, 0x94,
		0x89, 0x6e, 0xcb, 0x52, 0xed, 0xcc, 0xff, 0xeb, 0x81, 0xe4, 0xbd, 0x5f, 0xf6, 0xf7, 0x0f, 0x8f,
		0xf6, 0xf7, 0x77, 0x8f, 0x5e, 0x1c, 0xed, 0x1e, 0x1f, 0x1c, 0xec, 0x1d, 0xee, 0x69, 0xf6, 0x62,
		0x9e, 0xc7, 0xd7, 0x41, 0x1c, 0x5c, 0x9f, 0x7c, 0xd4, 0x07, 0xb5, 0xac, 0xe5, 0x75, 0x12, 0xc4,
		0xda, 0x78, 0x66, 0x04, 0xe4, 0x8f, 0xc1, 0x7c, 0xb4, 0xd8, 0xfd, 0xfa, 0xfb, 0x8f, 0x35, 0x83,
		0x5e, 0x41, 0x6b, 0x50, 0x5f, 0x03, 0xf6, 0xb9, 0x26, 0x54, 0xb4, 0x7f, 0x0d, 0xa6, 0xf8, 0xf5,
		0x3a, 0x61, 0x1c, 0xd9, 0x36, 0x89, 0x68, 0xc3, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x22, 0x4c,
		0x11, 0xa6, 0x08, 0x53, 0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x62, 0x89, 0x99,
		0x22, 0x93, 0x4e, 0xbe, 0x41, 0x9e, 0x6b, 0xd3, 0x27, 0x1e, 0x34, 0x56, 0x72, 0x93, 0xe7, 0xd3,
		0x5f, 0x8d, 0x9b, 0x3c, 0x37, 0x8e, 0x40, 0x34, 0x68, 0xe2, 0x2a, 0x91, 0x83, 0x42, 0x13, 0x17,
		0x4d, 0x5c, 0x5f, 0xde, 0x32, 0x9a, 0xb8, 0x28, 0x86, 0x96, 0xc6, 0x0d, 0x22, 0xd7, 0x55, 0x22,
		0xbc, 0x44, 0xae, 0x89, 0x5c, 0x17, 0xb7, 0x95, 0x14, 0x43, 0x53, 0x0c, 0xed, 0xb2, 0x92, 0xd2,
		0xc4, 0x85, 0xdf, 0x82, 0xdf, 0x82, 0xdf, 0x82, 0xdf, 0x82, 0xdf, 0x82, 0xdf, 0x82, 0xdf, 0x52,
		0x1a, 0xbf, 0x85, 0x26, 0x2e, 0x1c, 0x05, 0x1c, 0x05, 0x1c, 0x05, 0x1c, 0x85, 0x6d, 0x75, 0x14,
		0x28, 0xcd, 0xa3, 0x34, 0x6f, 0x7d, 0xbb, 0x28, 0xcd, 0xa3, 0x34, 0x8f, 0xd2, 0x3c, 0x4a, 0xf3,
		0x28, 0xcd, 0x83, 0x29, 0x2e, 0x74, 0x82, 0x26, 0x2e, 0x98, 0x22, 0x4c, 0x11, 0xa6, 0x08, 0x53,
		0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x22, 0x4c, 0x11, 0xa6, 0x08, 0x53, 0x2c,
		0x15, 0x53, 0xa4, 0x89, 0xeb, 0x1b, 0xe4, 0xb9, 0xdc, 0xc4, 0xc5, 0x8d, 0xd5, 0x5a, 0xea, 0xb7,
		0xb5, 0x37, 0x56, 0xcb, 0x5f, 0xc6, 0xf8, 0x6c, 0xf3, 0x4b, 0xab, 0x67, 0x8b, 0xec, 0x2d, 0xd6,
		0xb8, 0xc5, 0xd7, 0x74, 0x0a, 0xdf, 0x3f, 0xa7, 0x73, 0xef, 0x1c, 0x57, 0x73, 0x7e, 0x5b, 0xfc,
		0x8c, 0x9b, 0xaa, 0xcb, 0xe1, 0x39, 0x73, 0x53, 0xf5, 0x93, 0x3b, 0x23, 0x7e, 0x31, 0xa7, 0xce,
		0x85, 0xfe, 0x6b, 0xa7, 0x53, 0xe3, 0x62, 0xff, 0xc7, 0x66, 0x73, 0x97, 0x6b, 0x3a, 0x1d, 0x36,
		0xa7, 0x56, 0xc1, 0x0b, 0x1a, 0xbc, 0x45, 0xcd, 0x6d, 0x35, 0x88, 0xb5, 0x5a, 0x52, 0x61, 0x95,
		0xcf, 0xbd, 0x0e, 0xa2, 0x24, 0x4c, 0x3e, 0xea, 0x24, 0x14, 0x32, 0xcf, 0x52, 0x21, 0x38, 0x5b,
		0x6b, 0xa7, 0xaf, 0x76, 0xe2, 0x4f, 0x02, 0xfd, 0x44, 0x79, 0xf3, 0x55, 0xdb, 0xeb, 0xcf, 0xfe,
		0xcf, 0xe5, 0x1f, 0x3d, 0xb5, 0xde, 0xab, 0x37, 0xfe, 0x70, 0x1a, 0x4c, 0x6a, 0xbf, 0x3e, 0x7b,
		0xab, 0x16, 0x91, 0x33, 0x0a, 0x77, 0x77, 0x5e, 0xbc, 0xe9, 0x75, 0xbd, 0x76, 0xef, 0xcd, 0xbe,
		0x77, 0xd5, 0x6d, 0x9f, 0x36, 0xfb, 0x97, 0x8a, 0x89, 0xcc, 0x9f, 0x2a, 0xbf, 0xbb, 0xed, 0xee,
		0x3f, 0xfa, 0x97, 0xcd, 0xcb, 0x16, 0x9b, 0x5a, 0xdc, 0xa6, 0xce, 0x95, 0xb5, 0xd3, 0x3c, 0x69,
		0x75, 0x5a, 0x2f, 0x51, 0x5a, 0x01, 0xa5, 0x6d, 0xcc, 0x4c, 0xc2, 0x9b, 0x5e, 0xa7, 0xcf, 0xae,
		0x0a, 0x98, 0x02, 0xaf, 0xdf, 0x7b, 0xc5, 0xc6, 0x0a, 0x20, 0xd8, 0x21, 0xc6, 0x40, 0xc4, 0xd8,
		0x1e, 0x62, 0x6c, 0xa5, 0x8d, 0x6d, 0xeb, 0x4d, 0xaf, 0xcb, 0xae, 0x16, 0xac, 0xb5, 0x68, 0x6b,
		0xe1, 0xfb, 0xda, 0xbf, 0xb8, 0x6c, 0x79, 0xbd, 0xf3, 0x4e, 0xfb, 0xf4, 0x8f, 0x39, 0x67, 0x60,
		0x6f, 0x45, 0x98, 0xd8, 0xd9, 0x55, 0xe7, 0x12, 0xdd, 0x95, 0xa0, 0x0d, 0xaf, 0x3a, 0xe7, 0xff,
		0xec, 0xf7, 0x5a, 0xa7, 0x6c, 0xac, 0x84, 0x67, 0x0b, 0x8a, 0x15, 0xba, 0xb1, 0x6f, 0x7a, 0x5d,
		0x54, 0x56, 0x03, 0xc7, 0x0e, 0xd9, 0xdb, 0x82, 0xed, 0x2c, 0xbe, 0x97, 0x24, 0xcf, 0xb5, 0xf0,
		0x0f, 0x54, 0x24, 0xbd, 0x2b, 0x7b, 0x5e, 0xab, 0x94, 0x53, 0xe2, 0x83, 0xc8, 0x7f, 0x3f, 0x0c,
		0xae, 0xf5, 0xaa, 0x09, 0x96, 0x02, 0xa5, 0xa7, 0x3c, 0xaf, 0x06, 0xf8, 0xdd, 0xf8, 0xc3, 0x09,
		0x75, 0x0b, 0xdf, 0x28, 0x88, 0xba, 0x85, 0x42, 0xb5, 0x83, 0xba, 0x05, 0xea, 0x16, 0xbe, 0xb0,
		0x63, 0xfa, 0x75, 0x0b, 0xef, 0x47, 0xa3, 0x61, 0xe0, 0x47, 0x9a, 0x35, 0x0b, 0x7b, 0x14, 0xf9,
		0xcb, 0xab, 0xd4, 0xb6, 0x16, 0xf9, 0x4b, 0xde, 0x05, 0x54, 0x8e, 0xd2, 0xf9, 0xdb, 0xd8, 0x1f,
		0x04, 0x37, 0xd3, 0x61, 0x3d, 0x0e, 0x26, 0x89, 0x1f, 0x27, 0xf2, 0x45, 0xf4, 0x6b, 0x12, 0x29,
		0xa7, 0xb7, 0xf2, 0xa7, 0x28, 0xa7, 0x2f, 0x9f, 0xbf, 0x44, 0x39, 0xfd, 0xd3, 0x0c, 0x4e, 0xba,
		0x9c, 0x5e, 0xb8, 0xcf, 0x68, 0xed, 0x58, 0x8a, 0xf6, 0x1b, 0x29, 0x19, 0x4a, 0x88, 0x28, 0x44,
		0x14, 0x22, 0x5a, 0x6d, 0x22, 0xaa, 0x76, 0x41, 0x9a, 0x56, 0xec, 0x71, 0xed, 0x7c, 0xeb, 0xc4,
		0x20, 0x57, 0x1b, 0xaa, 0x1b, 0x8b, 0x7c, 0x0c, 0x05, 0x8c, 0x7c, 0x2b, 0x33, 0x44, 0x58, 0x41,
		0x85, 0x39, 0x64, 0x98, 0x43, 0x87, 0x29, 0x84, 0xe8, 0x40, 0x89, 0x12, 0xa4, 0x64, 0x3b, 0x69,
		0x37, 0xf0, 0x4d, 0x2f, 0xd6, 0xb9, 0xe6, 0x89, 0xef, 0x31, 0x6f, 0xc7, 0x01, 0xaf, 0x66, 0xcb,
		0xe7, 0xed, 0x3c, 0x8e, 0xd3, 0x71, 0x71, 0xfa, 0xd3, 0x5f, 0x8e, 0x8b, 0xd3, 0x37, 0x76, 0x01,
		0x1b, 0x44, 0x05, 0x88, 0x0a, 0x10, 0x15, 0x20, 0x2a, 0x40, 0x54, 0x80, 0xa8, 0x00, 0x51, 0x01,
		0xa2, 0x02, 0x44, 0x05, 0x88, 0x0a, 0x10, 0x15, 0x20, 0x2a, 0x40, 0x54, 0xc0, 0xe9, 0xa8, 0x00,
		0x93, 0x78, 0xb5, 0x54, 0x70, 0x5b, 0x8b, 0xf4, 0x94, 0x0a, 0xc6, 0x9e, 0x6d, 0x3c, 0x8d, 0xf7,
		0x75, 0xba, 0xd0, 0x8b, 0x74, 0x9d, 0x5b, 0x5c, 0x56, 0x18, 0x8e, 0xef, 0xf7, 0xeb, 0x43, 0xff,
		0x7d, 0x30, 0x0c, 0xae, 0xeb, 0xd3, 0x28, 0x1c, 0xf8, 0x13, 0x85, 0xd2, 0xc2, 0xcf, 0x4a, 0xa5,
		0xbc, 0xd0, 0x8a, 0xf4, 0x50, 0x5e, 0x58, 0x3e, 0xd2, 0x42, 0x79, 0xa1, 0x59, 0x3c, 0x2b, 0xd5,
		0xa8, 0xfa, 0x30, 0xbc, 0x0b, 0x13, 0xbd, 0x6c, 0x42, 0x4e, 0x2a, 0xa5, 0x86, 0xae, 0x46, 0x8e,
		0x48, 0x2a, 0x54, 0x2f, 0x32, 0x44, 0x52, 0xc1, 0x39, 0x23, 0x9c, 0x09, 0x52, 0xaa, 0xf5, 0x5e,
		0x3b, 0xde, 0x2a, 0x35, 0xdf, 0xca, 0x06, 0x59, 0xdd, 0x30, 0x5b, 0x18, 0x68, 0x3b, 0x43, 0x6d,
		0x65, 0xb0, 0xcd, 0x0d, 0xb7, 0xb9, 0x01, 0x37, 0x35, 0xe4, 0x3a, 0x06, 0x5d, 0xc9, 0xb0, 0xab,
		0x1b, 0xf8, 0x4c, 0xe0, 0x9d, 0xff, 0x57, 0x7d, 0xa1, 0xb5, 0xf3, 0x19, 0xde, 0x46, 0xf3, 0x5a,
		0x72, 0xab, 0x50, 0x56, 0x5e, 0xdd, 0xfc, 0xae, 0x19, 0x18, 0x58, 0x82, 0x82, 0x3d, 0x38, 0x58,
		0x83, 0x84, 0x33, 0x60, 0xe1, 0x0c, 0x68, 0x38, 0x01, 0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9,
		0x0e, 0xab, 0xe7, 0x8b, 0xd7, 0xce, 0xfb, 0x34, 0x8c, 0x92, 0x17, 0x0d, 0x8b, 0xf3, 0x9e, 0x5a,
		0xf7, 0x23, 0x03, 0xd1, 0x17, 0x7e, 0x74, 0x1b, 0xa8, 0xde, 0x8b, 0xf1, 0xf0, 0x8f, 0x8d, 0x7d,
		0x7b, 0x96, 0x5e, 0xd0, 0x6d, 0x66, 0x60, 0x8d, 0x61, 0x7d, 0x6d, 0x19, 0xf3, 0xdb, 0x51, 0x1c,
		0x58, 0xc7, 0xab, 0xd8, 0x1f, 0x24, 0xe1, 0x28, 0x7a, 0x19, 0xde, 0x86, 0x8b, 0x7b, 0xd3, 0xcd,
		0xd6, 0xf3, 0xe9, 0x27, 0x43, 0xd5, 0xf4, 0xff, 0x42, 0x35, 0x1f, 0xa9, 0xe6, 0x7e, 0xe3, 0x78,
		0xff, 0xf8, 0xf0, 0xa8, 0x71, 0x7c, 0x80, 0x8e, 0xda, 0x38, 0x04, 0x76, 0x52, 0xdf, 0x55, 0xf5,
		0xce, 0x76, 0xc5, 0xb8, 0xd3, 0x38, 0x0e, 0xee, 0x83, 0x28, 0xa9, 0x27, 0x81, 0x1f, 0x5f, 0x8f,
		0xfe, 0x8c, 0xec, 0x68, 0xf4, 0xda, 0x4a, 0x94, 0x1d, 0x4d, 0xa3, 0x12, 0x6d, 0xa8, 0x3c, 0x54,
		0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x2b, 0x9c, 0x77, 0xfd, 0x12, 0xf0, 0xc7, 0xe6, 0x5d, 0xa9,
		0x14, 0xbc, 0xda, 0x4e, 0x4b, 0x5a, 0x4d, 0x5a, 0x4f, 0xc2, 0xbb, 0x20, 0xb6, 0xf3, 0x58, 0xf2,
		0xcb, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xa8, 0x8c, 0xbb, 0x70, 0x1d,
		0x0c, 0xc2, 0x3b, 0x7f, 0x78, 0xb8, 0x6f, 0xe9, 0x30, 0x34, 0x0c, 0x64, 0xaf, 0x05, 0xb3, 0x1a,
		0xa4, 0x20, 0xf4, 0x5e, 0xdc, 0xa5, 0x14, 0x44, 0x83, 0x14, 0xc4, 0x33, 0x52, 0x10, 0x2b, 0xd5,
		0x74, 0x28, 0x05, 0xf1, 0x02, 0xd5, 0x7c, 0x46, 0xe6, 0x81, 0xcc, 0x43, 0x49, 0x49, 0xfc, 0x9f,
		0x7e, 0x1c, 0x85, 0xd1, 0x6d, 0x3d, 0xf9, 0x10, 0x07, 0x93, 0x0f, 0xa3, 0xe1, 0x75, 0x7d, 0x3c,
		0x48, 0xec, 0xc8, 0xfc, 0xe7, 0x97, 0x03, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0xfa,
		0xca, 0x90, 0xfa, 0x71, 0x10, 0x0f, 0x82, 0x28, 0xf1, 0x6f, 0x03, 0x43, 0x56, 0x7f, 0x00, 0x9f,
		0xde, 0x4e, 0x3e, 0x4d, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0xed, 0x8a, 0x6a, 0xee, 0xed, 0xa2,
		0x9c, 0x30, 0xea, 0xaa, 0x30, 0xea, 0x4a, 0x75, 0xf8, 0x29, 0x4f, 0x50, 0xcb, 0xe4, 0x3a, 0x36,
		0xd6, 0xea, 0x73, 0xc3, 0x8a, 0x9e, 0x3f, 0x1c, 0xc6, 0xa1, 0x32, 0x70, 0x5d, 0x4f, 0xc5, 0x14,
		0xd4, 0x4b, 0x69, 0x10, 0xfb, 0x1a, 0x1b, 0xd0, 0x18, 0xc8, 0xfe, 0x18, 0x68, 0xd5, 0x5b, 0xf6,
		0x1b, 0xb4, 0xec, 0x57, 0x27, 0x7c, 0x43, 0xcb, 0x3e, 0x2d, 0xfb, 0x85, 0xed, 0x24, 0x2d, 0xfb,
		0xb4, 0xec, 0x57, 0x0f, 0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3,
		0x09, 0xf0, 0xb0, 0xe1, 0xd7, 0xb4, 0xec, 0xab, 0x5b, 0x77, 0x5a, 0xf6, 0x15, 0x5f, 0x9c, 0xf8,
		0xfe, 0x6a, 0x19, 0xc4, 0xf7, 0xad, 0xcd, 0x5f, 0x5e, 0x35, 0x89, 0xef, 0xaf, 0xa9, 0x26, 0x2d,
		0xfb, 0xd6, 0x0e, 0x81, 0x9d, 0x54, 0x0a, 0xe7, 0x36, 0x57, 0x5b, 0x5a, 0xf6, 0xb3, 0xe8, 0x05,
		0x2d, 0xfb, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0x4f, 0xcb, 0x7e, 0x25,
		0x9c, 0x16, 0x5a, 0xf6, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x24, 0xcf,
		0x3b, 0x2d, 0xfb, 0xb4, 0xec, 0x1b, 0x98, 0x16, 0x5a, 0xf6, 0x57, 0xcb, 0x20, 0x05, 0x61, 0x6d,
		0x87, 0xf3, 0xaa, 0x49, 0xcb, 0x3e, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27, 0x95, 0xcc, 0xc3, 0xe6,
		0x6a, 0x4b, 0xcb, 0x3e, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b,
		0x2d, 0xfb, 0xf0, 0x69, 0x3b, 0xd2, 0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0x4d, 0xcb, 0x3e,
		0x8c, 0x1a, 0x46, 0x5d, 0x4a, 0x49, 0xb4, 0xec, 0x3b, 0xd6, 0xb2, 0xbf, 0xe8, 0x04, 0xaf, 0x4a,
		0xc7, 0xfe, 0x4e, 0x89, 0x75, 0x57, 0x5b, 0x67, 0x4b, 0xa7, 0xab, 0x35, 0x95, 0x79, 0x0c, 0xf1,
		0x74, 0x90, 0x44, 0x29, 0x03, 0xeb, 0x2e, 0x5e, 0xb2, 0x9d, 0xbe, 0xa3, 0xd7, 0x4b, 0xdf, 0xcc,
		0x3b, 0xb9, 0x1d, 0x7b, 0xbd, 0x20, 0x88, 0x5f, 0xcf, 0x5e, 0xc6, 0x6b, 0xde, 0x84, 0x7d, 0xff,
		0x26, 0xf4, 0xda, 0xe3, 0xfb, 0xfd, 0xce, 0xe2, 0x05, 0xae, 0x16, 0xeb, 0xf7, 0x16, 0x71, 0xa3,
		0xce, 0x7c, 0xf9, 0x3b, 0xe5, 0x54, 0x7d, 0x99, 0x27, 0x0b, 0x1d, 0x26, 0xad, 0x43, 0x54, 0x86,
		0xc3, 0x23, 0x78, 0x5e, 0x8a, 0x3e, 0x27, 0x32, 0x67, 0xa3, 0x78, 0xcd, 0x15, 0xd0, 0xda, 0xda,
		0xfc, 0xd3, 0x2d, 0x3f, 0x99, 0x94, 0xce, 0x66, 0x41, 0xa5, 0x9c, 0x34, 0xa1, 0x33, 0x28, 0x3b,
		0xf0, 0x45, 0x3c, 0x09, 0xa0, 0x11, 0xec, 0xd7, 0x0b, 0xea, 0x6b, 0x05, 0xef, 0xd5, 0x83, 0xf4,
		0xea, 0xc1, 0x78, 0xd5, 0xa0, 0x7b, 0xb9, 0x50, 0x57, 0x7a, 0xa0, 0x4a, 0x6d, 0xb0, 0x3c, 0xf3,
		0xc2, 0x4a, 0xbc, 0x3c, 0x96, 0xa9, 0x3c, 0x61, 0x85, 0xd2, 0x99, 0x8c, 0xa5, 0x96, 0x35, 0xd5,
		0xcc, 0x92, 0xea, 0x67, 0x45, 0xb5, 0xb3, 0xa0, 0x66, 0x59, 0x4f, 0xb3, 0x2c, 0xa7, 0x49, 0x56,
		0xb3, 0xdc, 0x31, 0x03, 0xad, 0x49, 0x56, 0xb5, 0x49, 0x10, 0x5d, 0xd7, 0xaf, 0x17, 0x9d, 0xa7,
		0xf5, 0x78, 0x34, 0x35, 0x99, 0x5a, 0xb8, 0xbe, 0x06, 0xad, 0x81, 0x61, 0x36, 0x2d, 0xb7, 0xca,
		0x09, 0x0f, 0xf5, 0xf2, 0x1a, 0x46, 0x27, 0x56, 0x1a, 0x48, 0xcc, 0x01, 0xc5, 0x14, 0x58, 0x74,
		0x00, 0x46, 0x09, 0x68, 0xb2, 0x9d, 0x54, 0x2f, 0x8b, 0x31, 0x6c, 0x89, 0x55, 0x6e, 0x85, 0x25,
		0x3f, 0xf2, 0x85, 0x43, 0x4c, 0x7e, 0x24, 0xcb, 0x8b, 0x68, 0x4c, 0xda, 0x16, 0x4c, 0x29, 0x08,
		0x86, 0xbb, 0x72, 0x19, 0x23, 0xb5, 0x78, 0x81, 0x62, 0x9e, 0x8a, 0xa8, 0x01, 0x51, 0x03, 0xa2,
		0x06, 0x44, 0x0d, 0xca, 0x10, 0x35, 0x50, 0x0a, 0xdb, 0xae, 0x1d, 0x6f, 0x95, 0xf0, 0xad, 0xb2,
		0x41, 0x86, 0xa5, 0xc3, 0xd2, 0x61, 0xe9, 0xb0, 0x74, 0x97, 0x0c, 0x7c, 0x26, 0x90, 0x0b, 0x0e,
		0xe8, 0x88, 0x7c, 0x56, 0x7d, 0x70, 0xb0, 0x06, 0x09, 0x67, 0xc0, 0xc2, 0x19, 0xd0, 0x70, 0x02,
		0x3c, 0x74, 0x41, 0x44, 0x19, 0x4c, 0xb2, 0x1d, 0xe6, 0x82, 0x03, 0x2e, 0x38, 0xd0, 0x7c, 0x71,
		0xba, 0x21, 0x57, 0xcb, 0xa0, 0x1b, 0xd2, 0xda, 0xfc, 0xe5, 0x55, 0x93, 0x6e, 0xc8, 0x35, 0xd5,
		0xe4, 0x82, 0x03, 0x6b, 0x87, 0xc0, 0x4e, 0x2a, 0x63, 0x86, 0x36, 0x57, 0x5b, 0x2e, 0x38, 0xc8,
		0xa2, 0x17, 0x5c, 0x70, 0x00, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x95, 0xa5, 0xf2, 0x5c,
		0x70, 0x50, 0x09, 0xa7, 0x85, 0x0b, 0x0e, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70,
		0x17, 0x24, 0xcf, 0x3b, 0x17, 0x1c, 0x70, 0xc1, 0x81, 0x81, 0x69, 0xe1, 0x82, 0x83, 0xd5, 0x32,
		0x48, 0x41, 0x58, 0xdb, 0xe1, 0xbc, 0x6a, 0x72, 0xc1, 0x01, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27,
		0x95, 0xcc, 0xc3, 0xe6, 0x6a, 0xcb, 0x05, 0x07, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f,
		0xa9, 0xd7, 0x3c, 0xef, 0x5c, 0x70, 0x00, 0x9f, 0xb6, 0x23, 0x2d, 0x94, 0xf4, 0xc1, 0xa7, 0x1d,
		0xe5, 0xd3, 0x5c, 0x70, 0x00, 0xa3, 0x86, 0x51, 0x97, 0x52, 0x12, 0x17, 0x1c, 0xd8, 0x0d, 0x45,
		0xc9, 0x5d, 0x6c, 0xa0, 0x31, 0x21, 0x45, 0x4f, 0xb5, 0x3e, 0xa9, 0xcc, 0xbe, 0xf7, 0x4d, 0xa6,
		0xfa, 0xcd, 0xc5, 0x56, 0xbc, 0x55, 0xbf, 0x41, 0xab, 0x7e, 0x75, 0xc2, 0x36, 0xb4, 0xea, 0xd3,
		0xaa, 0x5f, 0xd8, 0x4e, 0xd2, 0xaa, 0x4f, 0xab, 0x7e, 0xf5, 0x40, 0xc1, 0x1e, 0x1c, 0xac, 0x41,
		0xc2, 0x19, 0xb0, 0x70, 0x06, 0x34, 0x9c, 0x00, 0x0f, 0x1b, 0x5e, 0x4d, 0xab, 0xbe, 0xba, 0x75,
		0xa7, 0x55, 0x5f, 0xf1, 0xc5, 0x89, 0xeb, 0xaf, 0x96, 0x41, 0x5c, 0xdf, 0xda, 0xfc, 0xe5, 0x55,
		0x93, 0xb8, 0xfe, 0x9a, 0x6a, 0xd2, 0xaa, 0x6f, 0xed, 0x10, 0xd8, 0x49, 0xa5, 0x60, 0x6e, 0x73,
		0xb5, 0xa5, 0x55, 0x3f, 0x8b, 0x5e, 0xd0, 0xaa, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2,
		0x95, 0xa5, 0xf2, 0xb4, 0xea, 0x57, 0xc2, 0x69, 0xa1, 0x55, 0x1f, 0x77, 0x01, 0x77, 0x01, 0x77,
		0x01, 0x77, 0x01, 0x77, 0x41, 0xf2, 0xbc, 0xd3, 0xaa, 0x4f, 0xab, 0xbe, 0x81, 0x69, 0xa1, 0x55,
		0x7f, 0xb5, 0x0c, 0x52, 0x10, 0xd6, 0x76, 0x38, 0xaf, 0x9a, 0xb4, 0xea, 0xa3, 0x9a, 0xae, 0x38,
		0x24, 0x76, 0x52, 0xc9, 0x3c, 0x6c, 0xae, 0xb6, 0xb4, 0xea, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a,
		0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0xd3, 0xaa, 0x0f, 0x9f, 0xb6, 0x23, 0x2d, 0x94, 0xf4, 0xc1,
		0xa7, 0x1d, 0xe5, 0xd3, 0xb4, 0xea, 0xc3, 0xa8, 0x61, 0xd4, 0xa5, 0x94, 0x44, 0xab, 0xbe, 0x23,
		0xad, 0xfa, 0x8b, 0x0e, 0xf0, 0xaa, 0x74, 0xea, 0xef, 0x94, 0x58, 0x67, 0xb5, 0x75, 0xb5, 0x34,
		0x3a, 0x5a, 0x53, 0x99, 0xbf, 0x10, 0x4f, 0x07, 0x49, 0x94, 0x32, 0xae, 0xee, 0xe2, 0xe5, 0xda,
		0xe9, 0xbb, 0x79, 0xbd, 0xf4, 0x8d, 0xbc, 0x93, 0xdb, 0xb1, 0xd7, 0x0b, 0x82, 0xf8, 0xf5, 0xec,
		0x25, 0xbc, 0xe6, 0x4d, 0xd8, 0xf7, 0x6f, 0x42, 0xaf, 0x3d, 0xbe, 0xdf, 0xbf, 0x5a, 0x2c, 0xdc,
		0x5b, 0x04, 0x88, 0x3a, 0xf3, 0x75, 0xef, 0x94, 0x53, 0xd7, 0x05, 0xf5, 0x5c, 0x69, 0xce, 0x85,
		0xea, 0x7c, 0x0b, 0xa5, 0xb9, 0x16, 0x6a, 0xf3, 0x2c, 0x34, 0x63, 0x9c, 0xfa, 0x31, 0x4d, 0xed,
		0x18, 0xa6, 0x59, 0xcc, 0xd2, 0x2c, 0x46, 0x69, 0x12, 0x93, 0x2c, 0x37, 0xf2, 0x6b, 0xcd, 0xa1,
		0xa8, 0x4d, 0x82, 0xe8, 0xba, 0x7e, 0xbd, 0xe8, 0x1b, 0xa9, 0xc7, 0xa3, 0xa9, 0xc9, 0xcc, 0xa1,
		0xf5, 0x35, 0x68, 0x8d, 0xfb, 0xb0, 0x69, 0x98, 0x51, 0x0e, 0x57, 0xa8, 0x27, 0xc7, 0x18, 0x7c,
		0x54, 0x69, 0x20, 0x31, 0x07, 0x14, 0x53, 0x60, 0xa9, 0x66, 0x58, 0x44, 0x3d, 0xa9, 0x65, 0xd8,
		0xd0, 0xa2, 0xdc, 0xc8, 0x42, 0x94, 0x83, 0x28, 0xc7, 0xd7, 0x46, 0x39, 0x14, 0x82, 0x6f, 0x82,
		0x61, 0x82, 0x9d, 0x12, 0xa9, 0x9f, 0x96, 0xda, 0xb9, 0xac, 0x6e, 0x35, 0xd1, 0xb8, 0x4e, 0x31,
		0xf1, 0x33, 0x99, 0xc3, 0x50, 0xbc, 0xaa, 0x0a, 0xa8, 0x69, 0x2d, 0x1c, 0xdf, 0x1f, 0xd6, 0x87,
		0xfe, 0xfb, 0x60, 0x18, 0x5c, 0x67, 0xdf, 0x4c, 0x4a, 0x59, 0x33, 0x40, 0xfe, 0xac, 0x54, 0xa1,
		0x43, 0x28, 0x1b, 0x29, 0x13, 0x27, 0x3e, 0x1a, 0x44, 0x47, 0x8f, 0xd8, 0x68, 0x11, 0x19, 0x75,
		0xe2, 0xa2, 0x4e, 0x54, 0x54, 0x89, 0x49, 0xb9, 0x60, 0x57, 0x3a, 0xb2, 0x55, 0xcb, 0x25, 0x8a,
		0xd4, 0xf2, 0x0a, 0x8a, 0xe9, 0x29, 0xf5, 0xf4, 0xc2, 0x2e, 0xe9, 0x85, 0xf2, 0x44, 0x87, 0x48,
		0x2f, 0x90, 0x5e, 0x30, 0x37, 0xc2, 0x99, 0xa0, 0xc1, 0xd2, 0x86, 0x28, 0xa7, 0x14, 0x52, 0xb9,
		0x15, 0xbf, 0xc7, 0x80, 0x70, 0x7e, 0x05, 0x0c, 0xb6, 0xb9, 0xe1, 0x36, 0x37, 0xe0, 0xa6, 0x86,
		0x5c, 0xc7, 0xa0, 0x2b, 0x19, 0x76, 0x75, 0x03, 0x9f, 0x09, 0xe4, 0x1e, 0x03, 0x1a, 0x1f, 0x9f,
		0x55, 0x1f, 0x1c, 0xac, 0x41, 0xc2, 0x19, 0xb0, 0x70, 0x06, 0x34, 0x9c, 0x00, 0x0f, 0x5d, 0x10,
		0x51, 0x06, 0x93, 0x6c, 0x87, 0xb9, 0xc7, 0x80, 0x7b, 0x0c, 0x34, 0x5f, 0x9c, 0xa6, 0xc7, 0xd5,
		0x32, 0x68, 0x7a, 0xb4, 0x36, 0x7f, 0x79, 0xd5, 0xa4, 0xe9, 0x71, 0x4d, 0x35, 0xb9, 0xc7, 0xc0,
		0xda, 0x21, 0xb0, 0x93, 0xca, 0x34, 0xa1, 0xcd, 0xd5, 0x96, 0x7b, 0x0c, 0xb2, 0xe8, 0x05, 0xf7,
		0x18, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x65, 0xa9, 0x3c, 0xf7, 0x18, 0x54, 0xc2,
		0x69, 0xe1, 0x1e, 0x03, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xc9, 0xf3,
		0xce, 0x3d, 0x06, 0xdc, 0x63, 0x60, 0x60, 0x5a, 0xb8, 0xc7, 0x60, 0xb5, 0x0c, 0x52, 0x10, 0xd6,
		0x76, 0x38, 0xaf, 0x9a, 0xdc, 0x63, 0x80, 0x6a, 0xba, 0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0,
		0xb9, 0xda, 0x72, 0x8f, 0x01, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf,
		0x3b, 0xf7, 0x18, 0xc0, 0xa7, 0xed, 0x48, 0x0b, 0x25, 0x7d, 0xf0, 0x69, 0x47, 0xf9, 0x34, 0xf7,
		0x18, 0xc0, 0xa8, 0x61, 0xd4, 0xa5, 0x94, 0xc4, 0x3d, 0x06, 0xda, 0xe3, 0xac, 0xd6, 0x86, 0x15,
		0xe5, 0xef, 0x33, 0x48, 0x5b, 0xc1, 0xab, 0x32, 0xea, 0x4f, 0x65, 0xf4, 0xbd, 0x6f, 0x32, 0x06,
		0x58, 0x61, 0x34, 0xfb, 0x63, 0xa0, 0x55, 0x6f, 0xd9, 0x6f, 0xd0, 0xb2, 0x5f, 0x9d, 0xf0, 0x0d,
		0x2d, 0xfb, 0xb4, 0xec, 0x17, 0xb6, 0x93, 0xb4, 0xec, 0xd3, 0xb2, 0x5f, 0x3d, 0x50, 0xb0, 0x07,
		0x07, 0x6b, 0x90, 0x70, 0x06, 0x2c, 0x9c, 0x01, 0x0d, 0x27, 0xc0, 0xc3, 0x86, 0x5f, 0xd3, 0xb2,
		0xaf, 0x6e, 0xdd, 0x69, 0xd9, 0x57, 0x7c, 0x71, 0xe2, 0xfb, 0xab, 0x65, 0x10, 0xdf, 0xb7, 0x36,
		0x7f, 0x79, 0xd5, 0x24, 0xbe, 0xbf, 0xa6, 0x9a, 0xb4, 0xec, 0x5b, 0x3b, 0x04, 0x76, 0x52, 0x29,
		0x9c, 0xdb, 0x5c, 0x6d, 0x69, 0xd9, 0xcf, 0xa2, 0x17, 0xb4, 0xec, 0x43, 0xe5, 0xa1, 0xf2, 0x50,
		0x79, 0xa8, 0x7c, 0x65, 0xa9, 0x3c, 0x2d, 0xfb, 0x95, 0x70, 0x5a, 0x68, 0xd9, 0xc7, 0x5d, 0xc0,
		0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0x90, 0x3c, 0xef, 0xb4, 0xec, 0xd3, 0xb2, 0x6f, 0x60,
		0x5a, 0x68, 0xd9, 0x5f, 0x2d, 0x83, 0x14, 0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0x2d, 0xfb, 0xa8,
		0xa6, 0x2b, 0x0e, 0x89, 0x9d, 0x54, 0x32, 0x0f, 0x9b, 0xab, 0x2d, 0x2d, 0xfb, 0x90, 0x7a, 0x48,
		0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xd7, 0x3c, 0xef, 0xb4, 0xec, 0xc3, 0xa7, 0xed, 0x48, 0x0b,
		0x25, 0x7d, 0xf0, 0x69, 0x47, 0xf9, 0x34, 0x2d, 0xfb, 0x30, 0x6a, 0x18, 0x75, 0x29, 0x25, 0xd1,
		0xb2, 0xef, 0x58, 0xcb, 0xfe, 0xa2, 0x13, 0xbc, 0x2a, 0x1d, 0xfb, 0x3b, 0x25, 0xd6, 0x5d, 0x6d,
		0x9d, 0x2d, 0x9d, 0xae, 0xd6, 0x54, 0xe6, 0x31, 0xc4, 0xd3, 0x41, 0x12, 0xa5, 0x0c, 0xac, 0xbb,
		0x78, 0xc9, 0x76, 0xfa, 0x8e, 0x5e, 0x2f, 0x7d, 0x33, 0xef, 0xe4, 0x76, 0xec, 0xf5, 0x82, 0x20,
		0x7e, 0x3d, 0x7b, 0x19, 0xaf, 0x79, 0x13, 0xf6, 0xfd, 0x9b, 0xd0, 0x6b, 0x8f, 0xef, 0x0f, 0x3b,
		0x8b, 0x17, 0xb8, 0x5a, 0xac, 0xdf, 0x5b, 0xc4, 0x8d, 0x3a, 0xf3, 0xe5, 0xef, 0x94, 0x53, 0xf5,
		0x65, 0x9e, 0x2c, 0x74, 0x98, 0xb4, 0x0e, 0x51, 0x19, 0x0e, 0x8f, 0xe0, 0x79, 0x29, 0xfa, 0x9c,
		0xc8, 0x9c, 0x8d, 0xe2, 0x35, 0x57, 0x40, 0x6b, 0x6b, 0xf3, 0x4f, 0xb7, 0xfc, 0x64, 0x52, 0x3a,
		0x9b, 0x05, 0x95, 0x72, 0xd2, 0x84, 0xce, 0xa0, 0xec, 0xc0, 0x17, 0xf1, 0x24, 0x80, 0x46, 0xb0,
		0x5f, 0x2f, 0xa8, 0xaf, 0x15, 0xbc, 0x57, 0x0f, 0xd2, 0xab, 0x07, 0xe3, 0x55, 0x83, 0xee, 0xe5,
		0x42, 0x5d, 0xe9, 0x81, 0x2a, 0xb5, 0xc1, 0xf2, 0xcc, 0x0b, 0x2b, 0xf1, 0xf2, 0x58, 0xa6, 0xf2,
		0x84, 0x15, 0x4a, 0x67, 0x32, 0x96, 0x5a, 0xd6, 0x54, 0x33, 0x4b, 0xaa, 0x9f, 0x15, 0xd5, 0xce,
		0x82, 0x9a, 0x65, 0x3d, 0xcd, 0xb2, 0x9c, 0x26, 0x59, 0xcd, 0x72, 0xc7, 0x0c, 0xb4, 0x26, 0x59,
		0xd5, 0x26, 0x41, 0x74, 0x5d, 0xbf, 0x5e, 0x74, 0x9e, 0xd6, 0xe3, 0xd1, 0xd4, 0x64, 0x6a, 0xe1,
		0xfa, 0x1a, 0xb4, 0x06, 0x86, 0xd9, 0xb4, 0xdc, 0x2a, 0x27, 0x3c, 0xd4, 0xcb, 0x6b, 0x18, 0x9d,
		0x58, 0x69, 0x20, 0x31, 0x07, 0x14, 0x53, 0x60, 0xd1, 0x01, 0x18, 0x25, 0xa0, 0xc9, 0x76, 0x52,
		0xbd, 0x2c, 0xc6, 0xb0, 0x25, 0x56, 0xb9, 0x15, 0x96, 0xfc, 0xc8, 0x17, 0x0e, 0x31, 0xf9, 0x91,
		0x2c, 0x2f, 0xa2, 0x31, 0x69, 0x5b, 0x30, 0xa5, 0x20, 0x18, 0xee, 0xca, 0x65, 0x8c, 0xd4, 0xe2,
		0x05, 0x8a, 0x79, 0x2a, 0xa2, 0x06, 0x44, 0x0d, 0x88, 0x1a, 0x10, 0x35, 0x28, 0x43, 0xd4, 0x40,
		0x29, 0x6c, 0xbb, 0x76, 0xbc, 0x55, 0xc2, 0xb7, 0xca, 0x06, 0x19, 0x96, 0x0e, 0x4b, 0x87, 0xa5,
		0xc3, 0xd2, 0x5d, 0x32, 0xf0, 0x99, 0x40, 0x2e, 0x38, 0xa0, 0x23, 0xf2, 0x59, 0xf5, 0xc1, 0xc1,
		0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3, 0x09, 0xf0, 0xd0, 0x05, 0x11, 0x65, 0x30, 0xc9,
		0x76, 0x98, 0x0b, 0x0e, 0xb8, 0xe0, 0x40, 0xf3, 0xc5, 0xe9, 0x86, 0x5c, 0x2d, 0x83, 0x6e, 0x48,
		0x6b, 0xf3, 0x97, 0x57, 0x4d, 0xba, 0x21, 0xd7, 0x54, 0x93, 0x0b, 0x0e, 0xac, 0x1d, 0x02, 0x3b,
		0xa9, 0x8c, 0x19, 0xda, 0x5c, 0x6d, 0xb9, 0xe0, 0x20, 0x8b, 0x5e, 0x70, 0xc1, 0x01, 0x54, 0x1e,
		0x2a, 0x0f, 0x95, 0x87, 0xca, 0x57, 0x96, 0xca, 0x73, 0xc1, 0x41, 0x25, 0x9c, 0x16, 0x2e, 0x38,
		0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0x90, 0x3c, 0xef, 0x5c, 0x70, 0xc0,
		0x05, 0x07, 0x06, 0xa6, 0x85, 0x0b, 0x0e, 0x56, 0xcb, 0x20, 0x05, 0x61, 0x6d, 0x87, 0xf3, 0xaa,
		0xc9, 0x05, 0x07, 0xa8, 0xa6, 0x2b, 0x0e, 0x89, 0x9d, 0x54, 0x32, 0x0f, 0x9b, 0xab, 0x2d, 0x17,
		0x1c, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0x73, 0xc1, 0x01,
		0x7c, 0xda, 0x8e, 0xb4, 0x50, 0xd2, 0x07, 0x9f, 0x76, 0x94, 0x4f, 0x73, 0xc1, 0x01, 0x8c, 0x1a,
		0x46, 0x5d, 0x4a, 0x49, 0x5c, 0x70, 0x60, 0x37, 0x14, 0x25, 0x77, 0xb1, 0x81, 0xc6, 0x84, 0x14,
		0x3d, 0xd5, 0xfa, 0xa4, 0x32, 0xfb, 0xde, 0x37, 0x99, 0xea, 0x37, 0x17, 0x5b, 0xf1, 0x56, 0xfd,
		0x06, 0xad, 0xfa, 0xd5, 0x09, 0xdb, 0xd0, 0xaa, 0x4f, 0xab, 0x7e, 0x61, 0x3b, 0x49, 0xab, 0x3e,
		0xad, 0xfa, 0xd5, 0x03, 0x05, 0x7b, 0x70, 0xb0, 0x06, 0x09, 0x67, 0xc0, 0xc2, 0x19, 0xd0, 0x70,
		0x02, 0x3c, 0x6c, 0x78, 0x35, 0xad, 0xfa, 0xea, 0xd6, 0x9d, 0x56, 0x7d, 0xc5, 0x17, 0x27, 0xae,
		0xbf, 0x5a, 0x06, 0x71, 0x7d, 0x6b, 0xf3, 0x97, 0x57, 0x4d, 0xe2, 0xfa, 0x6b, 0xaa, 0x49, 0xab,
		0xbe, 0xb5, 0x43, 0x60, 0x27, 0x95, 0x82, 0xb9, 0xcd, 0xd5, 0x96, 0x56, 0xfd, 0x2c, 0x7a, 0x41,
		0xab, 0x3e, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x57, 0x96, 0xca, 0xd3, 0xaa, 0x5f, 0x09,
		0xa7, 0x85, 0x56, 0x7d, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xdc, 0x05, 0xc9, 0xf3,
		0x4e, 0xab, 0x3e, 0xad, 0xfa, 0x06, 0xa6, 0x85, 0x56, 0xfd, 0xd5, 0x32, 0x48, 0x41, 0x58, 0xdb,
		0xe1, 0xbc, 0x6a, 0xd2, 0xaa, 0x8f, 0x6a, 0xba, 0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0, 0xb9,
		0xda, 0xd2, 0xaa, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0xcd, 0xf3, 0x4e,
		0xab, 0x3e, 0x7c, 0xda, 0x8e, 0xb4, 0x50, 0xd2, 0x07, 0x9f, 0x76, 0x94, 0x4f, 0xd3, 0xaa, 0x0f,
		0xa3, 0x86, 0x51, 0x97, 0x52, 0x12, 0xad, 0xfa, 0x8e, 0xb4, 0xea, 0x2f, 0x3a, 0xc0, 0xab, 0xd2,
		0xa9, 0xbf, 0x53, 0x62, 0x9d, 0xd5, 0xd6, 0xd5, 0xd2, 0xe8, 0x68, 0x4d, 0x65, 0xfe, 0x42, 0x3c,
		0x1d, 0x24, 0x51, 0xca, 0xb8, 0xba, 0x8b, 0x97, 0x6b, 0xa7, 0xef, 0xe6, 0xf5, 0xd2, 0x37, 0xf2,
		0x4e, 0x6e, 0xc7, 0x5e, 0x2f, 0x08, 0xe2, 0xd7, 0xb3, 0x97, 0xf0, 0x9a, 0x37, 0x61, 0xdf, 0xbf,
		0x09, 0xbd, 0xf6, 0xf8, 0xfe, 0xf0, 0x6a, 0xb1, 0x70, 0x6f, 0x11, 0x20, 0xea, 0xcc, 0xd7, 0xbd,
		0x53, 0x4e, 0x5d, 0x17, 0xd4, 0x73, 0xa5, 0x39, 0x17, 0xaa, 0xf3, 0x2d, 0x94, 0xe6, 0x5a, 0xa8,
		0xcd, 0xb3, 0xd0, 0x8c, 0x71, 0xea, 0xc7, 0x34, 0xb5, 0x63, 0x98, 0x66, 0x31, 0x4b, 0xb3, 0x18,
		0xa5, 0x49, 0x4c, 0xb2, 0xdc, 0xc8, 0xaf, 0x35, 0x87, 0xa2, 0x36, 0x09, 0xa2, 0xeb, 0xfa, 0xf5,
		0xa2, 0x6f, 0xa4, 0x1e, 0x8f, 0xa6, 0x26, 0x33, 0x87, 0xd6, 0xd7, 0xa0, 0x35, 0xee, 0xc3, 0xa6,
		0x61, 0x46, 0x39, 0x5c, 0xa1, 0x9e, 0x1c, 0x63, 0xf0, 0x51, 0xa5, 0x81, 0xc4, 0x1c, 0x50, 0x4c,
		0x81, 0xa5, 0x9a, 0x61, 0x11, 0xf5, 0xa4, 0x96, 0x61, 0x43, 0x8b, 0x72, 0x23, 0x0b, 0x51, 0x0e,
		0xa2, 0x1c, 0x5f, 0x1b, 0xe5, 0x50, 0x08, 0xbe, 0x09, 0x86, 0x09, 0x76, 0x4a, 0xa4, 0x7e, 0x5a,
		0x6a, 0xe7, 0xb2, 0xba, 0xd5, 0x44, 0xe3, 0x3a, 0xc5, 0xc4, 0xcf, 0x64, 0x0e, 0x43, 0xf1, 0xaa,
		0x2a, 0xa0, 0xa6, 0xb5, 0x61, 0xe3, 0x7e, 0x1c, 0xd5, 0x83, 0xfb, 0xb1, 0x9c, 0x8a, 0x66, 0x30,
		0xfc, 0x40, 0x96, 0xd0, 0x81, 0x93, 0x8d, 0x8a, 0x89, 0x93, 0x1c, 0x0d, 0x52, 0xa3, 0x47, 0x62,
		0xb4, 0x48, 0x8b, 0x3a, 0x49, 0x51, 0x27, 0x25, 0xaa, 0x24, 0xa4, 0x5c, 0x10, 0x2b, 0x1d, 0xc5,
		0xaa, 0xe5, 0x92, 0x42, 0x6a, 0x39, 0x04, 0xc5, 0x54, 0x94, 0x7a, 0x2a, 0x61, 0x97, 0x54, 0x42,
		0x79, 0x22, 0x41, 0xa4, 0x12, 0x48, 0x25, 0x98, 0x1b, 0xe1, 0x4c, 0xd0, 0x60, 0x69, 0x43, 0x94,
		0xd3, 0x07, 0xa9, 0xdc, 0x8a, 0xdf, 0x59, 0x40, 0xe8, 0xbe, 0x02, 0x06, 0xdb, 0xdc, 0x70, 0x9b,
		0x1b, 0x70, 0x53, 0x43, 0xae, 0x63, 0xd0, 0x95, 0x0c, 0xbb, 0xba, 0x81, 0xcf, 0x04, 0x72, 0x67,
		0x01, 0x4d, 0x8e, 0xcf, 0xaa, 0x0f, 0x0e, 0xd6, 0x20, 0xe1, 0x0c, 0x58, 0x38, 0x03, 0x1a, 0x4e,
		0x80, 0x87, 0x2e, 0x88, 0x28, 0x83, 0x49, 0xb6, 0xc3, 0xdc, 0x59, 0xc0, 0x9d, 0x05, 0x9a, 0x2f,
		0x4e, 0x83, 0xe3, 0x6a, 0x19, 0x34, 0x38, 0x5a, 0x9b, 0xbf, 0xbc, 0x6a, 0xd2, 0xe0, 0xb8, 0xa6,
		0x9a, 0xdc, 0x59, 0x60, 0xed, 0x10, 0xd8, 0x49, 0x65, 0x72, 0xd0, 0xe6, 0x6a, 0xcb, 0x9d, 0x05,
		0x59, 0xf4, 0x82, 0x3b, 0x0b, 0xa0, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb2, 0x54, 0x9e,
		0x3b, 0x0b, 0x2a, 0xe1, 0xb4, 0x70, 0x67, 0x01, 0xee, 0x02, 0xee, 0x02, 0xee, 0x02, 0xee, 0x02,
		0xee, 0x82, 0xe4, 0x79, 0xe7, 0xce, 0x02, 0xee, 0x2c, 0x30, 0x30, 0x2d, 0xdc, 0x59, 0xb0, 0x5a,
		0x06, 0x29, 0x08, 0x6b, 0x3b, 0x9c, 0x57, 0x4d, 0xee, 0x2c, 0x40, 0x35, 0x5d, 0x71, 0x48, 0xec,
		0xa4, 0x92, 0x79, 0xd8, 0x5c, 0x6d, 0xb9, 0xb3, 0x00, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea,
		0x21, 0xf5, 0x9a, 0xe7, 0x9d, 0x3b, 0x0b, 0xe0, 0xd3, 0x76, 0xa4, 0x85, 0x92, 0x3e, 0xf8, 0xb4,
		0xa3, 0x7c, 0x9a, 0x3b, 0x0b, 0x60, 0xd4, 0x30, 0xea, 0x52, 0x4a, 0xe2, 0xce, 0x02, 0xd5, 0xd1,
		0x55, 0xab, 0x11, 0x45, 0xf9, 0x1b, 0x0b, 0xd2, 0x06, 0xf0, 0xaa, 0x0c, 0xf3, 0x53, 0x19, 0x6e,
		0xef, 0x9b, 0x0c, 0xfa, 0x55, 0x18, 0xbe, 0xfe, 0x18, 0x5e, 0xd5, 0x1b, 0xf5, 0x1b, 0x34, 0xea,
		0x57, 0x27, 0x68, 0x43, 0xa3, 0x3e, 0x8d, 0xfa, 0x85, 0xed, 0x24, 0x8d, 0xfa, 0x34, 0xea, 0x57,
		0x0f, 0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3, 0x09, 0xf0, 0xb0,
		0x61, 0xd5, 0x34, 0xea, 0xab, 0x5b, 0x77, 0x1a, 0xf5, 0x15, 0x5f, 0x9c, 0xa8, 0xfe, 0x6a, 0x19,
		0x44, 0xf5, 0xad, 0xcd, 0x5f, 0x5e, 0x35, 0x89, 0xea, 0xaf, 0xa9, 0x26, 0x8d, 0xfa, 0xd6, 0x0e,
		0x81, 0x9d, 0x54, 0xca, 0xe5, 0x36, 0x57, 0x5b, 0x1a, 0xf5, 0xb3, 0xe8, 0x05, 0x8d, 0xfa, 0x50,
		0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0x4f, 0xa3, 0x7e, 0x25, 0x9c, 0x16, 0x1a,
		0xf5, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x24, 0xcf, 0x3b, 0x8d, 0xfa,
		0x34, 0xea, 0x1b, 0x98, 0x16, 0x1a, 0xf5, 0x57, 0xcb, 0x20, 0x05, 0x61, 0x6d, 0x87, 0xf3, 0xaa,
		0x49, 0xa3, 0x3e, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27, 0x95, 0xcc, 0xc3, 0xe6, 0x6a, 0x4b, 0xa3,
		0x3e, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b, 0x8d, 0xfa, 0xf0,
		0x69, 0x3b, 0xd2, 0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0x4d, 0xa3, 0x3e, 0x8c, 0x1a, 0x46,
		0x5d, 0x4a, 0x49, 0x34, 0xea, 0x3b, 0xd1, 0xa8, 0xbf, 0xe8, 0xff, 0xae, 0x4a, 0x9f, 0xfe, 0x4e,
		0x89, 0x35, 0x56, 0x5b, 0x53, 0x4b, 0xa2, 0xa1, 0x35, 0x95, 0xd9, 0x0b, 0xf1, 0x74, 0x90, 0x44,
		0x29, 0xdb, 0xea, 0x2e, 0x5e, 0xad, 0x9d, 0xbe, 0x99, 0xd7, 0x4b, 0xdf, 0xc7, 0x3b, 0xb9, 0x1d,
		0x7b, 0xbd, 0x20, 0x88, 0x5f, 0xcf, 0x5e, 0xc1, 0x6b, 0xde, 0x84, 0x7d, 0xff, 0x26, 0xf4, 0x3a,
		0x8d, 0x37, 0xe3, 0xa8, 0x75, 0x3f, 0x8e, 0xbc, 0x45, 0x68, 0xa8, 0x33, 0x5f, 0xf5, 0x4e, 0x39,
		0xf5, 0x5c, 0xe6, 0xc9, 0x42, 0x27, 0x47, 0xeb, 0xc4, 0xb8, 0x7b, 0x52, 0x04, 0x0f, 0x47, 0x41,
		0x87, 0x42, 0xe6, 0x20, 0x14, 0xaf, 0xa6, 0x02, 0x2a, 0x5a, 0x5b, 0x7c, 0xa7, 0xfb, 0xf1, 0x50,
		0xae, 0xd3, 0x3f, 0x0b, 0x11, 0x3d, 0x90, 0x25, 0x74, 0xd8, 0x64, 0x87, 0xb7, 0x88, 0x07, 0xf4,
		0x35, 0x02, 0xf7, 0x7a, 0x01, 0x7a, 0xad, 0x40, 0xbc, 0x7a, 0xc0, 0x5d, 0x3d, 0xb0, 0xae, 0x1a,
		0x40, 0x2f, 0x17, 0xbc, 0x4a, 0x0f, 0x47, 0xa9, 0xe5, 0xfc, 0x3c, 0x71, 0x55, 0x7e, 0xd0, 0xb5,
		0xa5, 0xe5, 0x5d, 0x2a, 0x4d, 0xbc, 0x52, 0xcb, 0x86, 0x6a, 0x66, 0x3f, 0xf5, 0xb3, 0x9d, 0xda,
		0xd9, 0x4d, 0xb3, 0x6c, 0xa6, 0x59, 0xf6, 0xd2, 0x24, 0x5b, 0x59, 0xee, 0xa8, 0x80, 0xd6, 0x84,
		0xaa, 0xda, 0x60, 0x69, 0x43, 0x94, 0x27, 0x10, 0xa6, 0x72, 0x2b, 0x3e, 0x82, 0x70, 0x97, 0x11,
		0x84, 0xe5, 0x37, 0xd8, 0xe6, 0x86, 0xdb, 0xdc, 0x80, 0x9b, 0x1a, 0x72, 0x1d, 0x83, 0xae, 0x64,
		0xd8, 0xd5, 0x0d, 0x7c, 0x26, 0x90, 0x11, 0x84, 0xd4, 0x2c, 0x3e, 0xab, 0x3e, 0x38, 0x58, 0x83,
		0x84, 0x33, 0x60, 0xe1, 0x0c, 0x68, 0x38, 0x01, 0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e,
		0x33, 0x82, 0x90, 0x11, 0x84, 0x9a, 0x2f, 0x4e, 0xbd, 0xe2, 0x6a, 0x19, 0xd4, 0x2b, 0x5a, 0x9b,
		0xbf, 0xbc, 0x6a, 0x52, 0xaf, 0xb8, 0xa6, 0x9a, 0x8c, 0x20, 0xb4, 0x76, 0x08, 0xec, 0xa4, 0xd2,
		0x08, 0xb8, 0xb9, 0xda, 0x32, 0x82, 0x30, 0x8b, 0x5e, 0x30, 0x82, 0x10, 0x2a, 0x0f, 0x95, 0x87,
		0xca, 0x43, 0xe5, 0x2b, 0x4b, 0xe5, 0x19, 0x41, 0x58, 0x09, 0xa7, 0x85, 0x11, 0x84, 0xb8, 0x0b,
		0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0x92, 0xe7, 0x9d, 0x11, 0x84, 0x8c, 0x20, 0x34,
		0x30, 0x2d, 0x8c, 0x20, 0x5c, 0x2d, 0x83, 0x14, 0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0x23, 0x08,
		0x51, 0x4d, 0x57, 0x1c, 0x12, 0x3b, 0xa9, 0x64, 0x1e, 0x36, 0x57, 0x5b, 0x46, 0x10, 0x42, 0xea,
		0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0x33, 0x82, 0x10, 0x3e, 0x6d, 0x47,
		0x5a, 0x28, 0xe9, 0x83, 0x4f, 0x3b, 0xca, 0xa7, 0x19, 0x41, 0x08, 0xa3, 0x86, 0x51, 0x97, 0x52,
		0x12, 0x23, 0x08, 0x0d, 0xc6, 0x56, 0xdd, 0x8f, 0xe7, 0x4f, 0x78, 0x30, 0x82, 0x30, 0x6d, 0x00,
		0xaf, 0xca, 0x0c, 0x42, 0x95, 0x79, 0x75, 0x7e, 0x12, 0xe8, 0x77, 0xea, 0x2f, 0xc4, 0x56, 0xbc,
		0x51, 0xbf, 0x41, 0xa3, 0x7e, 0x75, 0x82, 0x36, 0x34, 0xea, 0xd3, 0xa8, 0x5f, 0xd8, 0x4e, 0xd2,
		0xa8, 0x4f, 0xa3, 0x7e, 0xf5, 0x40, 0xc1, 0x1e, 0x1c, 0xac, 0x41, 0xc2, 0x19, 0xb0, 0x70, 0x06,
		0x34, 0x9c, 0x00, 0x0f, 0x1b, 0x56, 0x4d, 0xa3, 0xbe, 0xba, 0x75, 0xa7, 0x51, 0x5f, 0xf1, 0xc5,
		0x89, 0xea, 0xaf, 0x96, 0x41, 0x54, 0xdf, 0xda, 0xfc, 0xe5, 0x55, 0x93, 0xa8, 0xfe, 0x9a, 0x6a,
		0xd2, 0xa8, 0x6f, 0xed, 0x10, 0xd8, 0x49, 0xa5, 0x5c, 0x6e, 0x73, 0xb5, 0xa5, 0x51, 0x3f, 0x8b,
		0x5e, 0xd0, 0xa8, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x95, 0xa5, 0xf2, 0x34, 0xea,
		0x57, 0xc2, 0x69, 0xa1, 0x51, 0x1f, 0x77, 0x01, 0x77, 0x01, 0x77, 0x01, 0x77, 0x01, 0x77, 0x41,
		0xf2, 0xbc, 0xd3, 0xa8, 0x4f, 0xa3, 0xbe, 0x81, 0x69, 0xa1, 0x51, 0x7f, 0xb5, 0x0c, 0x52, 0x10,
		0xd6, 0x76, 0x38, 0xaf, 0x9a, 0x34, 0xea, 0xa3, 0x9a, 0xae, 0x38, 0x24, 0x76, 0x52, 0xc9, 0x3c,
		0x6c, 0xae, 0xb6, 0x34, 0xea, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xf3,
		0xbc, 0xd3, 0xa8, 0x0f, 0x9f, 0xb6, 0x23, 0x2d, 0x94, 0xf4, 0xc1, 0xa7, 0x1d, 0xe5, 0xd3, 0x34,
		0xea, 0xc3, 0xa8, 0x61, 0xd4, 0xa5, 0x94, 0x44, 0xa3, 0xbe, 0x13, 0x8d, 0xfa, 0x8b, 0xfe, 0xef,
		0xaa, 0xf4, 0xe9, 0xef, 0x94, 0x58, 0x63, 0xb5, 0x35, 0xb5, 0x24, 0x1a, 0x5a, 0x53, 0x99, 0xbd,
		0x10, 0x4f, 0x07, 0x49, 0x94, 0xb2, 0xad, 0xee, 0xe2, 0xd5, 0xda, 0xe9, 0x9b, 0x79, 0xbd, 0xf4,
		0x7d, 0xbc, 0x93, 0xdb, 0xb1, 0xd7, 0x0b, 0x82, 0xf8, 0xf5, 0xec, 0x15, 0xbc, 0xe6, 0x4d, 0xd8,
		0xf7, 0x6f, 0x42, 0xaf, 0xd3, 0x78, 0x33, 0x8e, 0xde, 0x8c, 0x87, 0x13, 0x6f, 0x11, 0x1a, 0xea,
		0xcc, 0x57, 0xbd, 0x53, 0x4e, 0x3d, 0x97, 0x79, 0xb2, 0xd0, 0xc9, 0xd1, 0x3a, 0x31, 0xee, 0x9e,
		0x14, 0xc1, 0xc3, 0x51, 0xd0, 0xa1, 0x90, 0x39, 0x08, 0xc5, 0xab, 0xa9, 0x80, 0x8a, 0xd6, 0x86,
		0x2f, 0x66, 0xdf, 0x29, 0x1c, 0xdf, 0xef, 0xd7, 0xef, 0xa6, 0xc3, 0x24, 0x1c, 0xf8, 0x13, 0xb9,
		0x6c, 0x41, 0x16, 0x2c, 0xfa, 0xac, 0x54, 0xa1, 0x03, 0x28, 0x3b, 0xd0, 0x45, 0x3c, 0xc8, 0xaf,
		0x11, 0xcc, 0xd7, 0x0b, 0xda, 0x6b, 0x05, 0xe7, 0xd5, 0x83, 0xf0, 0xea, 0xc1, 0x76, 0xd5, 0xa0,
		0x7a, 0xb9, 0x20, 0x57, 0x7a, 0x60, 0x4a, 0x2d, 0xe7, 0xfb, 0x89, 0xab, 0xf2, 0x83, 0x4e, 0x2e,
		0x2d, 0x8f, 0x53, 0x69, 0x0a, 0x96, 0x5a, 0x86, 0x54, 0x33, 0x23, 0xaa, 0x9f, 0x01, 0xd5, 0xce,
		0x78, 0x9a, 0x65, 0x38, 0xcd, 0x32, 0x9a, 0x26, 0x19, 0xcc, 0x72, 0x47, 0x0a, 0xb4, 0xa6, 0x56,
		0xd5, 0x06, 0x4b, 0x1b, 0xa2, 0x3c, 0x95, 0x30, 0x95, 0x5b, 0xf1, 0xb1, 0x84, 0xbb, 0x8c, 0x25,
		0x2c, 0xbf, 0xc1, 0x36, 0x37, 0xdc, 0xe6, 0x06, 0xdc, 0xd4, 0x90, 0xeb, 0x18, 0x74, 0x25, 0xc3,
		0xae, 0x6e, 0xe0, 0x33, 0x81, 0x8c, 0x25, 0xa4, 0x8e, 0xf1, 0x59, 0xf5, 0xc1, 0xc1, 0x1a, 0x24,
		0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3, 0x09, 0xf0, 0xd0, 0x05, 0x11, 0x65, 0x30, 0xc9, 0x76, 0x98,
		0xb1, 0x84, 0x8c, 0x25, 0xd4, 0x7c, 0x71, 0x6a, 0x18, 0x57, 0xcb, 0xa0, 0x86, 0xd1, 0xda, 0xfc,
		0xe5, 0x55, 0x93, 0x1a, 0xc6, 0x35, 0xd5, 0x64, 0x2c, 0xa1, 0xb5, 0x43, 0x60, 0x27, 0x95, 0xe6,
		0xc0, 0xcd, 0xd5, 0x96, 0xb1, 0x84, 0x59, 0xf4, 0x82, 0xb1, 0x84, 0x50, 0x79, 0xa8, 0x3c, 0x54,
		0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0xcf, 0x58, 0xc2, 0x4a, 0x38, 0x2d, 0x8c, 0x25, 0xc4, 0x5d, 0xc0,
		0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0xc0, 0x5d, 0x90, 0x3c, 0xef, 0x8c, 0x25, 0x64, 0x2c, 0xa1, 0x81,
		0x69, 0x61, 0x2c, 0xe1, 0x6a, 0x19, 0xa4, 0x20, 0xac, 0xed, 0x70, 0x5e, 0x35, 0x19, 0x4b, 0x88,
		0x6a, 0xba, 0xe2, 0x90, 0xd8, 0x49, 0x25, 0xf3, 0xb0, 0xb9, 0xda, 0x32, 0x96, 0x10, 0x52, 0x0f,
		0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x9a, 0xe7, 0x9d, 0xb1, 0x84, 0xf0, 0x69, 0x3b, 0xd2,
		0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0xcd, 0x58, 0x42, 0x18, 0x35, 0x8c, 0xba, 0x94, 0x92,
		0x18, 0x4b, 0xa8, 0x3b, 0xca, 0xea, 0x33, 0xc3, 0x8a, 0xf2, 0x03, 0x0a, 0xd3, 0x56, 0xf0, 0xaa,
		0x4c, 0x28, 0x54, 0x99, 0x66, 0xe7, 0x27, 0x81, 0x7e, 0xcf, 0xfe, 0x42, 0x6c, 0xc5, 0x5b, 0xf6,
		0x1b, 0xb4, 0xec, 0x57, 0x27, 0x7c, 0x43, 0xcb, 0x3e, 0x2d, 0xfb, 0x85, 0xed, 0x24, 0x2d, 0xfb,
		0xb4, 0xec, 0x57, 0x0f, 0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3,
		0x09, 0xf0, 0xb0, 0xe1, 0xd7, 0xb4, 0xec, 0xab, 0x5b, 0x77, 0x5a, 0xf6, 0x15, 0x5f, 0x9c, 0xf8,
		0xfe, 0x6a, 0x19, 0xc4, 0xf7, 0xad, 0xcd, 0x5f, 0x5e, 0x35, 0x89, 0xef, 0xaf, 0xa9, 0x26, 0x2d,
		0xfb, 0xd6, 0x0e, 0x81, 0x9d, 0x54, 0x0a, 0xe7, 0x36, 0x57, 0x5b, 0x5a, 0xf6, 0xb3, 0xe8, 0x05,
		0x2d, 0xfb, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0x4f, 0xcb, 0x7e, 0x25,
		0x9c, 0x16, 0x5a, 0xf6, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x24, 0xcf,
		0x3b, 0x2d, 0xfb, 0xb4, 0xec, 0x1b, 0x98, 0x16, 0x5a, 0xf6, 0x57, 0xcb, 0x20, 0x05, 0x61, 0x6d,
		0x87, 0xf3, 0xaa, 0x49, 0xcb, 0x3e, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27, 0x95, 0xcc, 0xc3, 0xe6,
		0x6a, 0x4b, 0xcb, 0x3e, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b,
		0x2d, 0xfb, 0xf0, 0x69, 0x3b, 0xd2, 0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0x4d, 0xcb, 0x3e,
		0x8c, 0x1a, 0x46, 0x5d, 0x4a, 0x49, 0xb4, 0xec, 0x3b, 0xd6, 0xb2, 0xbf, 0xe8, 0x04, 0xaf, 0x4a,
		0xc7, 0xfe, 0x4e, 0x89, 0x75, 0x57, 0x5b, 0x67, 0x4b, 0xa7, 0xab, 0x35, 0x95, 0x79, 0x0c, 0xf1,
		0x74, 0x90, 0x44, 0x29, 0x03, 0xeb, 0x2e, 0x5e, 0xb2, 0x9d, 0xbe, 0xa3, 0xd7, 0x4b, 0xdf, 0xcc,
		0x3b, 0xb9, 0x1d, 0x7b, 0xbd, 0x20, 0x88, 0x5f, 0xcf, 0x5e, 0xc6, 0x6b, 0xde, 0x84, 0x7d, 0xff,
		0x26, 0xf4, 0x3a, 0x2f, 0xde, 0x8c, 0xa3, 0xf6, 0xf8, 0x7e, 0xff, 0x6c, 0xb9, 0x7e, 0x6f, 0x11,
		0x37, 0xea, 0xcc, 0x97, 0xbf, 0x53, 0x4e, 0xd5, 0x97, 0x79, 0xb2, 0xd0, 0x61, 0xd2, 0x3a, 0x44,
		0x65, 0x38, 0x3c, 0x82, 0xe7, 0xa5, 0xe8, 0x73, 0x22, 0x73, 0x36, 0x8a, 0xd7, 0x5c, 0x01, 0xad,
		0xad, 0x3d, 0xf8, 0x74, 0xd3, 0x68, 0xb1, 0x1b, 0x52, 0x9a, 0x9b, 0x85, 0x96, 0x3e, 0x23, 0x53,
		0xe8, 0x3c, 0xca, 0x0e, 0x7f, 0x11, 0x4f, 0x08, 0x68, 0x04, 0xfe, 0xf5, 0x02, 0xfc, 0x5a, 0x81,
		0x7c, 0xf5, 0x80, 0xbd, 0x7a, 0x60, 0x5e, 0x35, 0x00, 0x5f, 0x2e, 0x04, 0x96, 0x1e, 0xae, 0x52,
		0xcb, 0xf9, 0x84, 0xe2, 0xaa, 0xfc, 0xa0, 0xeb, 0x4b, 0xcb, 0x13, 0x55, 0x9a, 0x98, 0xa5, 0x96,
		0x4d, 0xd5, 0xcc, 0x9e, 0xea, 0x67, 0x4b, 0xb5, 0xb3, 0xa3, 0x66, 0xd9, 0x50, 0xb3, 0xec, 0xa7,
		0x49, 0xb6, 0xb3, 0xdc, 0xb1, 0x04, 0xad, 0x09, 0x57, 0xb5, 0xc1, 0xd2, 0x86, 0x28, 0x4f, 0x30,
		0x4c, 0xe5, 0x56, 0x7c, 0x84, 0xe1, 0x2e, 0x23, 0x0c, 0xcb, 0x6f, 0xb0, 0xcd, 0x0d, 0xb7, 0xb9,
		0x01, 0x37, 0x35, 0xe4, 0x3a, 0x06, 0x5d, 0xc9, 0xb0, 0xab, 0x1b, 0xf8, 0x4c, 0x20, 0x23, 0x0c,
		0xa9, 0x79, 0x7c, 0x56, 0x7d, 0x70, 0xb0, 0x06, 0x09, 0x67, 0xc0, 0xc2, 0x19, 0xd0, 0x70, 0x02,
		0x3c, 0x74, 0x41, 0x44, 0x19, 0x4c, 0xb2, 0x1d, 0x66, 0x84, 0x21, 0x23, 0x0c, 0x35, 0x5f, 0x9c,
		0x7a, 0xc7, 0xd5, 0x32, 0xa8, 0x77, 0xb4, 0x36, 0x7f, 0x79, 0xd5, 0xa4, 0xde, 0x71, 0x4d, 0x35,
		0x19, 0x61, 0x68, 0xed, 0x10, 0xd8, 0x49, 0xa5, 0x91, 0x70, 0x73, 0xb5, 0x65, 0x84, 0x61, 0x16,
		0xbd, 0x60, 0x84, 0x21, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x57, 0x96, 0xca, 0x33, 0xc2,
		0xb0, 0x12, 0x4e, 0x0b, 0x23, 0x0c, 0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17,
		0x24, 0xcf, 0x3b, 0x23, 0x0c, 0x19, 0x61, 0x68, 0x60, 0x5a, 0x18, 0x61, 0xb8, 0x5a, 0x06, 0x29,
		0x08, 0x6b, 0x3b, 0x9c, 0x57, 0x4d, 0x46, 0x18, 0xa2, 0x9a, 0xae, 0x38, 0x24, 0x76, 0x52, 0xc9,
		0x3c, 0x6c, 0xae, 0xb6, 0x8c, 0x30, 0x84, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd,
		0xe6, 0x79, 0x67, 0x84, 0x21, 0x7c, 0xda, 0x8e, 0xb4, 0x50, 0xd2, 0x07, 0x9f, 0x76, 0x94, 0x4f,
		0x33, 0xc2, 0x10, 0x46, 0x0d, 0xa3, 0x2e, 0xa5, 0x24, 0x46, 0x18, 0x5a, 0x4d, 0xb6, 0x4a, 0x47,
		0x15, 0xe5, 0x07, 0x18, 0xa6, 0x8d, 0xe0, 0x55, 0x99, 0x60, 0xa8, 0x32, 0xe3, 0xce, 0x4f, 0x02,
		0xfd, 0x8e, 0xfd, 0x85, 0xd8, 0x8a, 0x37, 0xec, 0x37, 0x68, 0xd8, 0xaf, 0x4e, 0xf0, 0x86, 0x86,
		0x7d, 0x1a, 0xf6, 0x0b, 0xdb, 0x49, 0x1a, 0xf6, 0x69, 0xd8, 0xaf, 0x1e, 0x28, 0xd8, 0x83, 0x83,
		0x35, 0x48, 0x38, 0x03, 0x16, 0xce, 0x80, 0x86, 0x13, 0xe0, 0x61, 0xc3, 0xae, 0x69, 0xd8, 0x57,
		0xb7, 0xee, 0x34, 0xec, 0x2b, 0xbe, 0x38, 0xd1, 0xfd, 0xd5, 0x32, 0x88, 0xee, 0x5b, 0x9b, 0xbf,
		0xbc, 0x6a, 0x12, 0xdd, 0x5f, 0x53, 0x4d, 0x1a, 0xf6, 0xad, 0x1d, 0x02, 0x3b, 0xa9, 0x94, 0xcd,
		0x6d, 0xae, 0xb6, 0x34, 0xec, 0x67, 0xd1, 0x0b, 0x1a, 0xf6, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c,
		0x54, 0xbe, 0xb2, 0x54, 0x9e, 0x86, 0xfd, 0x4a, 0x38, 0x2d, 0x34, 0xec, 0xe3, 0x2e, 0xe0, 0x2e,
		0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0x48, 0x9e, 0x77, 0x1a, 0xf6, 0x69, 0xd8, 0x37, 0x30, 0x2d,
		0x34, 0xec, 0xaf, 0x96, 0x41, 0x0a, 0xc2, 0xda, 0x0e, 0xe7, 0x55, 0x93, 0x86, 0x7d, 0x54, 0xd3,
		0x15, 0x87, 0xc4, 0x4e, 0x2a, 0x99, 0x87, 0xcd, 0xd5, 0x96, 0x86, 0x7d, 0x48, 0x3d, 0xa4, 0x1e,
		0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x6b, 0x9e, 0x77, 0x1a, 0xf6, 0xe1, 0xd3, 0x76, 0xa4, 0x85, 0x92,
		0x3e, 0xf8, 0xb4, 0xa3, 0x7c, 0x9a, 0x86, 0x7d, 0x18, 0x35, 0x8c, 0xba, 0x94, 0x92, 0x68, 0xd8,
		0x77, 0xaa, 0x61, 0x7f, 0xd1, 0x07, 0x5e, 0x95, 0x7e, 0xfd, 0x9d, 0x12, 0x6b, 0xae, 0xb6, 0xc6,
		0x96, 0x4c, 0x53, 0x6b, 0x2a, 0xb3, 0x18, 0xe2, 0xe9, 0x20, 0x89, 0x52, 0xf6, 0xd5, 0x5d, 0xbc,
		0x62, 0x3b, 0x7d, 0x43, 0xaf, 0x97, 0xbe, 0x97, 0x77, 0x72, 0x3b, 0xf6, 0x7a, 0x41, 0x10, 0xbf,
		0x9e, 0xbd, 0x8a, 0xd7, 0xbc, 0x09, 0xfb, 0xfe, 0x4d, 0xe8, 0x75, 0x5e, 0xbc, 0x19, 0x47, 0xed,
		0xf1, 0xfd, 0xfe, 0xd5, 0x62, 0xf5, 0xde, 0x22, 0x62, 0xd4, 0x99, 0x2f, 0x7e, 0xa7, 0x9c, 0x6a,
		0x2f, 0xf3, 0x64, 0xa1, 0x83, 0xa4, 0x75, 0x80, 0xdc, 0x3f, 0x38, 0x82, 0x67, 0xa5, 0xd8, 0x33,
		0x22, 0x73, 0x2e, 0x8a, 0xd7, 0x5a, 0x01, 0x8d, 0xad, 0x65, 0x9f, 0xed, 0xb0, 0x7e, 0x37, 0x1d,
		0x26, 0x8b, 0xfd, 0x90, 0xd2, 0xdb, 0x2c, 0xa4, 0xf4, 0x59, 0xa9, 0x42, 0xe7, 0x51, 0x76, 0xec,
		0x8b, 0x78, 0x2a, 0x40, 0x23, 0xe4, 0xaf, 0x17, 0xda, 0xd7, 0x0a, 0xe1, 0xab, 0x87, 0xea, 0xd5,
		0x43, 0xf2, 0xaa, 0xa1, 0xf7, 0x72, 0x21, 0xb0, 0xf4, 0x58, 0x95, 0x5a, 0xce, 0x23, 0x14, 0x57,
		0xe5, 0x07, 0xfd, 0x5e, 0x5a, 0x7e, 0xa8, 0xd2, 0xac, 0x2c, 0xb5, 0x3c, 0xaa, 0x66, 0xde, 0x54,
		0x3f, 0x4f, 0xaa, 0x9d, 0x17, 0x35, 0xcb, 0x83, 0x9a, 0xe5, 0x3d, 0x4d, 0xf2, 0x9c, 0xe5, 0x8e,
		0x23, 0x68, 0xcd, 0xb6, 0xaa, 0x0d, 0x96, 0x36, 0x44, 0x79, 0x76, 0x61, 0x2a, 0xb7, 0xe2, 0xc3,
		0x0b, 0x77, 0x19, 0x5e, 0x58, 0x7e, 0x83, 0x6d, 0x6e, 0xb8, 0xcd, 0x0d, 0xb8, 0xa9, 0x21, 0xd7,
		0x31, 0xe8, 0x4a, 0x86, 0x5d, 0xdd, 0xc0, 0x67, 0x02, 0x19, 0x5e, 0x48, 0xb5, 0xe3, 0xb3, 0xea,
		0x83, 0x83, 0x35, 0x48, 0x38, 0x03, 0x16, 0xce, 0x80, 0x86, 0x13, 0xe0, 0xa1, 0x0b, 0x22, 0xca,
		0x60, 0x92, 0xed, 0x30, 0xc3, 0x0b, 0x19, 0x5e, 0xa8, 0xf9, 0xe2, 0x54, 0x3a, 0xae, 0x96, 0x41,
		0xa5, 0xa3, 0xb5, 0xf9, 0xcb, 0xab, 0x26, 0x95, 0x8e, 0x6b, 0xaa, 0xc9, 0xf0, 0x42, 0x6b, 0x87,
		0xc0, 0x4e, 0x2a, 0x2d, 0x84, 0x9b, 0xab, 0x2d, 0xc3, 0x0b, 0xb3, 0xe8, 0x05, 0xc3, 0x0b, 0xa1,
		0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb2, 0x54, 0x9e, 0xe1, 0x85, 0x95, 0x70, 0x5a, 0x18,
		0x5e, 0x88, 0xbb, 0x80, 0xbb, 0x80, 0xbb, 0x80, 0xbb, 0x80, 0xbb, 0x20, 0x79, 0xde, 0x19, 0x5e,
		0xc8, 0xf0, 0x42, 0x03, 0xd3, 0xc2, 0xf0, 0xc2, 0xd5, 0x32, 0x48, 0x41, 0x58, 0xdb, 0xe1, 0xbc,
		0x6a, 0x32, 0xbc, 0x10, 0xd5, 0x74, 0xc5, 0x21, 0xb1, 0x93, 0x4a, 0xe6, 0x61, 0x73, 0xb5, 0x65,
		0x78, 0x21, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b, 0xc3, 0x0b,
		0xe1, 0xd3, 0x76, 0xa4, 0x85, 0x92, 0x3e, 0xf8, 0xb4, 0xa3, 0x7c, 0x9a, 0xe1, 0x85, 0x30, 0x6a,
		0x18, 0x75, 0x29, 0x25, 0x31, 0xbc, 0xd0, 0x66, 0xb2, 0xd5, 0x83, 0x61, 0x45, 0xf9, 0xf1, 0x85,
		0x69, 0x2b, 0x78, 0x55, 0xe6, 0x17, 0xaa, 0xcc, 0xb8, 0xf3, 0x93, 0x40, 0xbf, 0x67, 0x7f, 0x21,
		0xb6, 0xe2, 0x2d, 0xfb, 0x0d, 0x5a, 0xf6, 0xab, 0x13, 0xbe, 0xa1, 0x65, 0x9f, 0x96, 0xfd, 0xc2,
		0x76, 0x92, 0x96, 0x7d, 0x5a, 0xf6, 0xab, 0x07, 0x0a, 0xf6, 0xe0, 0x60, 0x0d, 0x12, 0xce, 0x80,
		0x85, 0x33, 0xa0, 0xe1, 0x04, 0x78, 0xd8, 0xf0, 0x6b, 0x5a, 0xf6, 0xd5, 0xad, 0x3b, 0x2d, 0xfb,
		0x8a, 0x2f, 0x4e, 0x7c, 0x7f, 0xb5, 0x0c, 0xe2, 0xfb, 0xd6, 0xe6, 0x2f, 0xaf, 0x9a, 0xc4, 0xf7,
		0xd7, 0x54, 0x93, 0x96, 0x7d, 0x6b, 0x87, 0xc0, 0x4e, 0x2a, 0x85, 0x73, 0x9b, 0xab, 0x2d, 0x2d,
		0xfb, 0x59, 0xf4, 0x82, 0x96, 0x7d, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0xaf, 0x2c, 0x95,
		0xa7, 0x65, 0xbf, 0x12, 0x4e, 0x0b, 0x2d, 0xfb, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b,
		0xb8, 0x0b, 0x92, 0xe7, 0x9d, 0x96, 0x7d, 0x5a, 0xf6, 0x0d, 0x4c, 0x0b, 0x2d, 0xfb, 0xab, 0x65,
		0x90, 0x82, 0xb0, 0xb6, 0xc3, 0x79, 0xd5, 0xa4, 0x65, 0x1f, 0xd5, 0x74, 0xc5, 0x21, 0xb1, 0x93,
		0x4a, 0xe6, 0x61, 0x73, 0xb5, 0xa5, 0x65, 0x1f, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21,
		0xf5, 0x9a, 0xe7, 0x9d, 0x96, 0x7d, 0xf8, 0xb4, 0x1d, 0x69, 0xa1, 0xa4, 0x0f, 0x3e, 0xed, 0x28,
		0x9f, 0xa6, 0x65, 0x1f, 0x46, 0x0d, 0xa3, 0x2e, 0xa5, 0x24, 0x5a, 0xf6, 0x1d, 0x6b, 0xd9, 0x5f,
		0x74, 0x82, 0x57, 0xa5, 0x63, 0x7f, 0xa7, 0xc4, 0xba, 0xab, 0xad, 0xb3, 0xa5, 0xd3, 0xd5, 0x9a,
		0xca, 0x3c, 0x86, 0x78, 0x3a, 0x48, 0xa2, 0x94, 0x81, 0x75, 0x17, 0x2f, 0xd9, 0x4e, 0xdf, 0xd1,
		0xeb, 0xa5, 0x6f, 0xe6, 0x9d, 0xdc, 0x8e, 0xbd, 0x5e, 0x10, 0xc4, 0xaf, 0x67, 0x2f, 0xe3, 0x35,
		0x6f, 0xc2, 0xbe, 0x7f, 0x13, 0x7a, 0x9d, 0x17, 0x6f, 0xc6, 0x51, 0x7b, 0x7c, 0x7f, 0x78, 0xb6,
		0x5c, 0xbf, 0xb7, 0x88, 0x1b, 0x75, 0xe6, 0xcb, 0xdf, 0x29, 0xa7, 0xea, 0xcb, 0x3c, 0x59, 0xe8,
		0x30, 0x69, 0x1d, 0xa2, 0x32, 0x1c, 0x1e, 0xc1, 0xf3, 0x52, 0xf4, 0x39, 0x91, 0x39, 0x1b, 0xc5,
		0x6b, 0xae, 0x80, 0xd6, 0xd6, 0x1e, 0x7c, 0xba, 0x69, 0xb4, 0xd8, 0x0d, 0x29, 0xcd, 0xcd, 0x42,
		0x4b, 0x9f, 0x91, 0x29, 0x74, 0x1e, 0x65, 0x87, 0xbf, 0x88, 0x27, 0x04, 0x34, 0x02, 0xff, 0x7a,
		0x01, 0x7e, 0xad, 0x40, 0xbe, 0x7a, 0xc0, 0x5e, 0x3d, 0x30, 0xaf, 0x1a, 0x80, 0x2f, 0x17, 0x02,
		0x4b, 0x0f, 0x57, 0xa9, 0xe5, 0x7c, 0x42, 0x71, 0x55, 0x7e, 0xd0, 0xf5, 0xa5, 0xe5, 0x89, 0x2a,
		0x4d, 0xcc, 0x52, 0xcb, 0xa6, 0x6a, 0x66, 0x4f, 0xf5, 0xb3, 0xa5, 0xda, 0xd9, 0x51, 0xb3, 0x6c,
		0xa8, 0x59, 0xf6, 0xd3, 0x24, 0xdb, 0x59, 0xee, 0x58, 0x82, 0xd6, 0x84, 0xab, 0xda, 0x60, 0x69,
		0x43, 0x94, 0x27, 0x18, 0xa6, 0x72, 0x2b, 0x3e, 0xc2, 0x70, 0x97, 0x11, 0x86, 0xe5, 0x37, 0xd8,
		0xe6, 0x86, 0xdb, 0xdc, 0x80, 0x9b, 0x1a, 0x72, 0x1d, 0x83, 0xae, 0x64, 0xd8, 0xd5, 0x0d, 0x7c,
		0x26, 0x90, 0x11, 0x86, 0xd4, 0x3c, 0x3e, 0xab, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x33, 0x60, 0xe1,
		0x0c, 0x68, 0x38, 0x01, 0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x33, 0xc2, 0x90, 0x11,
		0x86, 0x9a, 0x2f, 0x4e, 0xbd, 0xe3, 0x6a, 0x19, 0xd4, 0x3b, 0x5a, 0x9b, 0xbf, 0xbc, 0x6a, 0x52,
		0xef, 0xb8, 0xa6, 0x9a, 0x8c, 0x30, 0xb4, 0x76, 0x08, 0xec, 0xa4, 0xd2, 0x48, 0xb8, 0xb9, 0xda,
		0x32, 0xc2, 0x30, 0x8b, 0x5e, 0x30, 0xc2, 0x10, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x2b,
		0x4b, 0xe5, 0x19, 0x61, 0x58, 0x09, 0xa7, 0x85, 0x11, 0x86, 0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b,
		0xb8, 0x0b, 0xb8, 0x0b, 0x92, 0xe7, 0x9d, 0x11, 0x86, 0x8c, 0x30, 0x34, 0x30, 0x2d, 0x8c, 0x30,
		0x5c, 0x2d, 0x83, 0x14, 0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0x23, 0x0c, 0x51, 0x4d, 0x57, 0x1c,
		0x12, 0x3b, 0xa9, 0x64, 0x1e, 0x36, 0x57, 0x5b, 0x46, 0x18, 0x42, 0xea, 0x21, 0xf5, 0x90, 0x7a,
		0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0x33, 0xc2, 0x10, 0x3e, 0x6d, 0x47, 0x5a, 0x28, 0xe9, 0x83,
		0x4f, 0x3b, 0xca, 0xa7, 0x19, 0x61, 0x08, 0xa3, 0x86, 0x51, 0x97, 0x52, 0x12, 0x23, 0x0c, 0xad,
		0x26, 0x5b, 0xa5, 0xa3, 0x8a, 0xf2, 0x03, 0x0c, 0xd3, 0x46, 0xf0, 0xaa, 0x4c, 0x30, 0x54, 0x99,
		0x71, 0xe7, 0x27, 0x81, 0x7e, 0xc7, 0xfe, 0x42, 0x6c, 0xc5, 0x1b, 0xf6, 0x1b, 0x34, 0xec, 0x57,
		0x27, 0x78, 0x43, 0xc3, 0x3e, 0x0d, 0xfb, 0x85, 0xed, 0x24, 0x0d, 0xfb, 0x34, 0xec, 0x57, 0x0f,
		0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0x9c, 0x01, 0x0b, 0x67, 0x40, 0xc3, 0x09, 0xf0, 0xb0, 0x61,
		0xd7, 0x34, 0xec, 0xab, 0x5b, 0x77, 0x1a, 0xf6, 0x15, 0x5f, 0x9c, 0xe8, 0xfe, 0x6a, 0x19, 0x44,
		0xf7, 0xad, 0xcd, 0x5f, 0x5e, 0x35, 0x89, 0xee, 0xaf, 0xa9, 0x26, 0x0d, 0xfb, 0xd6, 0x0e, 0x81,
		0x9d, 0x54, 0xca, 0xe6, 0x36, 0x57, 0x5b, 0x1a, 0xf6, 0xb3, 0xe8, 0x05, 0x0d, 0xfb, 0x50, 0x79,
		0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x59, 0x2a, 0x4f, 0xc3, 0x7e, 0x25, 0x9c, 0x16, 0x1a, 0xf6,
		0x71, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x70, 0x17, 0x24, 0xcf, 0x3b, 0x0d, 0xfb, 0x34,
		0xec, 0x1b, 0x98, 0x16, 0x1a, 0xf6, 0x57, 0xcb, 0x20, 0x05, 0x61, 0x6d, 0x87, 0xf3, 0xaa, 0x49,
		0xc3, 0x3e, 0xaa, 0xe9, 0x8a, 0x43, 0x62, 0x27, 0x95, 0xcc, 0xc3, 0xe6, 0x6a, 0x4b, 0xc3, 0x3e,
		0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xcf, 0x3b, 0x0d, 0xfb, 0xf0, 0x69,
		0x3b, 0xd2, 0x42, 0x49, 0x1f, 0x7c, 0xda, 0x51, 0x3e, 0x4d, 0xc3, 0x3e, 0x8c, 0x1a, 0x46, 0x5d,
		0x4a, 0x49, 0x34, 0xec, 0x3b, 0xd5, 0xb0, 0xbf, 0xe8, 0x03, 0xaf, 0x4a, 0xbf, 0xfe, 0x4e, 0x89,
		0x35, 0x57, 0x5b, 0x63, 0x4b, 0xa6, 0xa9, 0x35, 0x95, 0x59, 0x0c, 0xf1, 0x74, 0x90, 0x44, 0x29,
		0xfb, 0xea, 0x2e, 0x5e, 0xb1, 0x9d, 0xbe, 0xa1, 0xd7, 0x4b, 0xdf, 0xcb, 0x3b, 0xb9, 0x1d, 0x7b,
		0xbd, 0x20, 0x88, 0x5f, 0xcf, 0x5e, 0xc5, 0x6b, 0xde, 0x84, 0x7d, 0xff, 0x26, 0xf4, 0x3a, 0x2f,
		0xde, 0x8c, 0xa3, 0xf6, 0xf8, 0xfe, 0xf0, 0x6a, 0xb1, 0x7a, 0x6f, 0x11, 0x31, 0xea, 0xcc, 0x17,
		0xbf, 0x53, 0x4e, 0xb5, 0x97, 0x79, 0xb2, 0xd0, 0x41, 0xd2, 0x3a, 0x40, 0xee, 0x1f, 0x1c, 0xc1,
		0xb3, 0x52, 0xec, 0x19, 0x91, 0x39, 0x17, 0xc5, 0x6b, 0xad, 0x80, 0xc6, 0xd6, 0x26, 0x71, 0x12,
		0xd4, 0xc7, 0xa3, 0x61, 0x38, 0xf8, 0x38, 0xfb, 0x78, 0xfb, 0x62, 0x3a, 0xbb, 0x9a, 0xf9, 0xf2,
		0x58, 0xa2, 0xd0, 0x39, 0x94, 0x1d, 0xf7, 0x22, 0x9e, 0x02, 0xd0, 0x08, 0xf5, 0xeb, 0x85, 0xf4,
		0xb5, 0x42, 0xf7, 0xea, 0x21, 0x7a, 0xf5, 0x50, 0xbc, 0x6a, 0xc8, 0xbd, 0x5c, 0xc8, 0x2b, 0x3d,
		0x4e, 0xa5, 0x96, 0xf3, 0x04, 0xc5, 0x55, 0xf9, 0x41, 0x9f, 0x97, 0x96, 0xff, 0xa9, 0x34, 0x23,
		0x4b, 0x2d, 0x7f, 0xaa, 0x99, 0x2f, 0xd5, 0xcf, 0x8f, 0x6a, 0xe7, 0x43, 0xcd, 0xf2, 0x9f, 0x66,
		0xf9, 0x4e, 0x93, 0xfc, 0x66, 0xb9, 0xe3, 0x07, 0x5a, 0x33, 0xad, 0x6a, 0x83, 0xa5, 0x0d, 0x51,
		0x9e, 0x59, 0x98, 0xca, 0xad, 0xf8, 0xd0, 0xc2, 0x5d, 0x86, 0x16, 0x96, 0xdf, 0x60, 0x9b, 0x1b,
		0x6e, 0x73, 0x03, 0x6e, 0x6a, 0xc8, 0x75, 0x0c, 0xba, 0x92, 0x61, 0x57, 0x37, 0xf0, 0x99, 0x40,
		0x86, 0x16, 0x52, 0xe5, 0xf8, 0xac, 0xfa, 0xe0, 0x60, 0x0d, 0x12, 0xce, 0x80, 0x85, 0x33, 0xa0,
		0xe1, 0x04, 0x78, 0xe8, 0x82, 0x88, 0x32, 0x98, 0x64, 0x3b, 0xcc, 0xd0, 0x42, 0x86, 0x16, 0x6a,
		0xbe, 0x38, 0x15, 0x8e, 0xab, 0x65, 0x50, 0xe1, 0x68, 0x6d, 0xfe, 0xf2, 0xaa, 0x49, 0x85, 0xe3,
		0x9a, 0x6a, 0x32, 0xb4, 0xd0, 0xda, 0x21, 0xb0, 0x93, 0x4a, 0xeb, 0xe0, 0xe6, 0x6a, 0xcb, 0xd0,
		0xc2, 0x2c, 0x7a, 0xc1, 0xd0, 0x42, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0xaf, 0x2c, 0x95,
		0x67, 0x68, 0x61, 0x25, 0x9c, 0x16, 0x86, 0x16, 0xe2, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e,
		0xe0, 0x2e, 0x48, 0x9e, 0x77, 0x86, 0x16, 0x32, 0xb4, 0xd0, 0xc0, 0xb4, 0x30, 0xb4, 0x70, 0xb5,
		0x0c, 0x52, 0x10, 0xd6, 0x76, 0x38, 0xaf, 0x9a, 0x0c, 0x2d, 0x44, 0x35, 0x5d, 0x71, 0x48, 0xec,
		0xa4, 0x92, 0x79, 0xd8, 0x5c, 0x6d, 0x19, 0x5a, 0x08, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5,
		0x90, 0x7a, 0xcd, 0xf3, 0xce, 0xd0, 0x42, 0xf8, 0xb4, 0x1d, 0x69, 0xa1, 0xa4, 0x0f, 0x3e, 0xed,
		0x28, 0x9f, 0x66, 0x68, 0x21, 0x8c, 0x1a, 0x46, 0x5d, 0x4a, 0x49, 0x0c, 0x2d, 0x54, 0x9d, 0x68,
		0xf5, 0x78, 0x50, 0x51, 0x7e, 0x64, 0x61, 0xda, 0x06, 0x5e, 0x95, 0x99, 0x85, 0x2a, 0x73, 0xed,
		0xfc, 0x24, 0xd0, 0xef, 0xd7, 0x5f, 0x88, 0xad, 0x78, 0xbb, 0x7e, 0x83, 0x76, 0xfd, 0xea, 0x84,
		0x6e, 0x68, 0xd7, 0xa7, 0x5d, 0xbf, 0xb0, 0x9d, 0xa4, 0x5d, 0x9f, 0x76, 0xfd, 0xea, 0x81, 0x82,
		0x3d, 0x38, 0x58, 0x83, 0x84, 0x33, 0x60, 0xe1, 0x0c, 0x68, 0x38, 0x01, 0x1e, 0x36, 0xdc, 0x9a,
		0x76, 0x7d, 0x75, 0xeb, 0x4e, 0xbb, 0xbe, 0xe2, 0x8b, 0x13, 0xdb, 0x5f, 0x2d, 0x83, 0xd8, 0xbe,
		0xb5, 0xf9, 0xcb, 0xab, 0x26, 0xb1, 0xfd, 0x35, 0xd5, 0xa4, 0x5d, 0xdf, 0xda, 0x21, 0xb0, 0x93,
		0x4a, 0xd1, 0xdc, 0xe6, 0x6a, 0x4b, 0xbb, 0x7e, 0x16, 0xbd, 0xa0, 0x5d, 0x1f, 0x2a, 0x0f, 0x95,
		0x87, 0xca, 0x43, 0xe5, 0x2b, 0x4b, 0xe5, 0x69, 0xd7, 0xaf, 0x84, 0xd3, 0x42, 0xbb, 0x3e, 0xee,
		0x02, 0xee, 0x02, 0xee, 0x02, 0xee, 0x02, 0xee, 0x82, 0xe4, 0x79, 0xa7, 0x5d, 0x9f, 0x76, 0x7d,
		0x03, 0xd3, 0x42, 0xbb, 0xfe, 0x6a, 0x19, 0xa4, 0x20, 0xac, 0xed, 0x70, 0x5e, 0x35, 0x69, 0xd7,
		0x47, 0x35, 0x5d, 0x71, 0x48, 0xec, 0xa4, 0x92, 0x79, 0xd8, 0x5c, 0x6d, 0x69, 0xd7, 0x87, 0xd4,
		0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xe6, 0x79, 0xa7, 0x5d, 0x1f, 0x3e, 0x6d, 0x47,
		0x5a, 0x28, 0xe9, 0x83, 0x4f, 0x3b, 0xca, 0xa7, 0x69, 0xd7, 0x87, 0x51, 0xc3, 0xa8, 0x4b, 0x29,
		0x89, 0x76, 0x7d, 0x87, 0xda, 0xf5, 0x17, 0x5d, 0xe0, 0x55, 0xe9, 0xd6, 0xdf, 0x29, 0xb1, 0xde,
		0x6a, 0xeb, 0x6b, 0xa9, 0xf4, 0xb4, 0xa6, 0x32, 0x87, 0x21, 0x9e, 0x0e, 0x92, 0x28, 0x65, 0x5e,
		0xdd, 0xc5, 0x0b, 0xb6, 0xd3, 0xf7, 0xf3, 0x7a, 0xe9, 0x5b, 0x79, 0x27, 0xb7, 0x63, 0xaf, 0x17,
		0x04, 0xf1, 0xeb, 0xd9, 0x8b, 0x78, 0xcd, 0x9b, 0xb0, 0xef, 0xdf, 0x84, 0x5e, 0x3f, 0x4e, 0x82,
		0xde, 0x7c, 0xf1, 0xed, 0xf1, 0xfd, 0xbe, 0xb7, 0x88, 0x15, 0x75, 0xe6, 0x4b, 0xdf, 0x29, 0xa7,
		0xca, 0xcb, 0x3c, 0x59, 0xe8, 0x10, 0x69, 0x1d, 0x1e, 0xd7, 0x0f, 0x8d, 0xe0, 0x39, 0x29, 0xf2,
		0x7c, 0xc8, 0x9c, 0x89, 0xe2, 0x35, 0x56, 0x40, 0x5b, 0x6b, 0x8f, 0x3e, 0xd9, 0xa1, 0x98, 0xbe,
		0xae, 0x26, 0xbd, 0x3c, 0x96, 0x28, 0x74, 0x06, 0x65, 0x87, 0xbc, 0x88, 0x07, 0xfe, 0x35, 0x02,
		0xfc, 0x7a, 0x81, 0x7c, 0xad, 0x80, 0xbd, 0x7a, 0x60, 0x5e, 0x3d, 0x00, 0xaf, 0x1a, 0x68, 0x2f,
		0x17, 0xea, 0x4a, 0x0f, 0x51, 0xa9, 0xe5, 0x7c, 0x40, 0x71, 0x55, 0x7e, 0xd0, 0xdd, 0xa5, 0xe5,
		0x79, 0x2a, 0x4d, 0xc6, 0x52, 0xcb, 0x9a, 0x6a, 0x66, 0x49, 0xf5, 0xb3, 0xa2, 0xda, 0x59, 0x50,
		0xb3, 0xac, 0xa7, 0x59, 0x96, 0xd3, 0x24, 0xab, 0x59, 0xee, 0xb8, 0x81, 0xd6, 0x24, 0xab, 0xda,
		0x60, 0x69, 0x43, 0x94, 0x27, 0x15, 0xa6, 0x72, 0x2b, 0x3e, 0xaa, 0x70, 0x97, 0x51, 0x85, 0xe5,
		0x37, 0xd8, 0xe6, 0x86, 0xdb, 0xdc, 0x80, 0x9b, 0x1a, 0x72, 0x1d, 0x83, 0xae, 0x64, 0xd8, 0xd5,
		0x0d, 0x7c, 0x26, 0x90, 0x51, 0x85, 0xd4, 0x36, 0x3e, 0xab, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x33,
		0x60, 0xe1, 0x0c, 0x68, 0x38, 0x01, 0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x33, 0xaa,
		0x90, 0x51, 0x85, 0x9a, 0x2f, 0x4e, 0x5d, 0xe3, 0x6a, 0x19, 0xd4, 0x35, 0x5a, 0x9b, 0xbf, 0xbc,
		0x6a, 0x52, 0xd7, 0xb8, 0xa6, 0x9a, 0x8c, 0x2a, 0xb4, 0x76, 0x08, 0xec, 0xa4, 0xd2, 0x30, 0xb8,
		0xb9, 0xda, 0x32, 0xaa, 0x30, 0x8b, 0x5e, 0x30, 0xaa, 0x10, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43,
		0xe5, 0x2b, 0x4b, 0xe5, 0x19, 0x55, 0x58, 0x09, 0xa7, 0x85, 0x51, 0x85, 0xb8, 0x0b, 0xb8, 0x0b,
		0xb8, 0x0b, 0xb8, 0x0b, 0xb8, 0x0b, 0x92, 0xe7, 0x9d, 0x51, 0x85, 0x8c, 0x2a, 0x34, 0x30, 0x2d,
		0x8c, 0x2a, 0x5c, 0x2d, 0x83, 0x14, 0x84, 0xb5, 0x1d, 0xce, 0xab, 0x26, 0xa3, 0x0a, 0x51, 0x4d,
		0x57, 0x1c, 0x12, 0x3b, 0xa9, 0x64, 0x1e, 0x36, 0x57, 0x5b, 0x46, 0x15, 0x42, 0xea, 0x21, 0xf5,
		0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xf3, 0xbc, 0x33, 0xaa, 0x10, 0x3e, 0x6d, 0x47, 0x5a, 0x28,
		0xe9, 0x83, 0x4f, 0x3b, 0xca, 0xa7, 0x19, 0x55, 0x08, 0xa3, 0x86, 0x51, 0x97, 0x52, 0x12, 0xa3,
		0x0a, 0x2d, 0xa7, 0x59, 0x1d, 0xe6, 0x47, 0x15, 0xa6, 0x6d, 0xe0, 0x55, 0x99, 0x55, 0xa8, 0x32,
		0xd1, 0xce, 0x4f, 0x02, 0xfd, 0x7e, 0xfd, 0x85, 0xd8, 0x8a, 0xb7, 0xeb, 0x37, 0x68, 0xd7, 0xaf,
		0x4e, 0xe8, 0x86, 0x76, 0x7d, 0xda, 0xf5, 0x0b, 0xdb, 0x49, 0xda, 0xf5, 0x69, 0xd7, 0xaf, 0x1e,
		0x28, 0xd8, 0x83, 0x83, 0x35, 0x48, 0x38, 0x03, 0x16, 0xce, 0x80, 0x86, 0x13, 0xe0, 0x61, 0xc3,
		0xad, 0x69, 0xd7, 0x57, 0xb7, 0xee, 0xb4, 0xeb, 0x2b, 0xbe, 0x38, 0xb1, 0xfd, 0xd5, 0x32, 0x88,
		0xed, 0x5b, 0x9b, 0xbf, 0xbc, 0x6a, 0x12, 0xdb, 0x5f, 0x53, 0x4d, 0xda, 0xf5, 0xad, 0x1d, 0x02,
		0x3b, 0xa9, 0x14, 0xcd, 0x6d, 0xae, 0xb6, 0xb4, 0xeb, 0x67, 0xd1, 0x0b, 0xda, 0xf5, 0xa1, 0xf2,
		0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb2, 0x54, 0x9e, 0x76, 0xfd, 0x4a, 0x38, 0x2d, 0xb4, 0xeb,
		0xe3, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0xe0, 0x2e, 0x48, 0x9e, 0x77, 0xda, 0xf5, 0x69,
		0xd7, 0x37, 0x30, 0x2d, 0xb4, 0xeb, 0xaf, 0x96, 0x41, 0x0a, 0xc2, 0xda, 0x0e, 0xe7, 0x55, 0x93,
		0x76, 0x7d, 0x54, 0xd3, 0x15, 0x87, 0xc4, 0x4e, 0x2a, 0x99, 0x87, 0xcd, 0xd5, 0x96, 0x76, 0x7d,
		0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x6b, 0x9e, 0x77, 0xda, 0xf5, 0xe1, 0xd3,
		0x76, 0xa4, 0x85, 0x92, 0x3e, 0xf8, 0xb4, 0xa3, 0x7c, 0x9a, 0x76, 0x7d, 0x18, 0x35, 0x8c, 0xba,
		0x94, 0x92, 0x68, 0xd7, 0x77, 0xa8, 0x5d, 0x7f, 0xd1, 0x05, 0x5e, 0x95, 0x6e, 0xfd, 0x9d, 0x12,
		0xeb, 0xad, 0xb6, 0xbe, 0x96, 0x4a, 0x4f, 0x6b, 0x2a, 0x73, 0x18, 0xe2, 0xe9, 0x20, 0x89, 0x52,
		0xe6, 0xd5, 0x5d, 0xbc, 0x60, 0x3b, 0x7d, 0x3f, 0xaf, 0x97, 0xbe, 0x95, 0x77, 0x72, 0x3b, 0xf6,
		0x7a, 0x41, 0x10, 0xbf, 0x9e, 0xbd, 0x88, 0xd7, 0xbc, 0x09, 0xfb, 0xfe, 0x4d, 0xe8, 0xf5, 0xe3,
		0x24, 0xe8, 0xcd, 0x17, 0xdf, 0x1e, 0xdf, 0x1f, 0x7a, 0x8b, 0x58, 0x51, 0x67, 0xbe, 0xf4, 0x9d,
		0x72, 0xaa, 0xbc, 0xcc, 0x93, 0x85, 0x0e, 0x91, 0xd6, 0xe1, 0x71, 0xfd, 0xd0, 0x08, 0x9e, 0x93,
		0x22, 0xcf, 0x87, 0xcc, 0x99, 0x28, 0x5e, 0x63, 0x05, 0xb4, 0x55, 0x78, 0xdc, 0x8b, 0xca, 0x78,
		0x17, 0xe1, 0x71, 0x2e, 0xe2, 0xe3, 0x5b, 0x34, 0x42, 0xf9, 0x7a, 0x21, 0x7b, 0xad, 0xd0, 0xbc,
		0x7a, 0x08, 0x5e, 0x3d, 0xd4, 0xae, 0x1a, 0x52, 0x2f, 0x17, 0xbe, 0x4a, 0x8f, 0x4b, 0xa9, 0x2d,
		0x21, 0xad, 0x9e, 0x02, 0x8c, 0xb0, 0x2e, 0x2f, 0x4f, 0x67, 0x5e, 0xac, 0xb0, 0x7a, 0xe9, 0xc4,
		0xae, 0xd4, 0x32, 0xa4, 0x9a, 0x19, 0x51, 0xfd, 0x0c, 0xa8, 0x76, 0xc6, 0xd3, 0x2c, 0xc3, 0x69,
		0x96, 0xd1, 0x34, 0xc9, 0x60, 0x96, 0x3b, 0x46, 0xa0, 0x96, 0x91, 0xcc, 0xce, 0x5b, 0x78, 0x1d,
		0x44, 0x49, 0x98, 0x7c, 0x8c, 0x83, 0x1b, 0x8d, 0x43, 0xb7, 0xf4, 0x2c, 0x15, 0x72, 0x8e, 0xb5,
		0x76, 0xfa, 0x6a, 0x27, 0xfe, 0xc4, 0x60, 0xfe, 0x62, 0xf3, 0x55, 0xdb, 0xeb, 0xcf, 0xfe, 0xcf,
		0xe5, 0x1f, 0xbd, 0x96, 0xd6, 0x51, 0x9f, 0xa7, 0x2d, 0x26, 0xaa, 0x79, 0x55, 0xa3, 0x12, 0xa9,
		0xce, 0x8b, 0x37, 0xbd, 0xae, 0xd7, 0xee, 0xbd, 0xd9, 0xf7, 0xae, 0xba, 0xed, 0xd3, 0x66, 0xff,
		0xb2, 0x56, 0xc5, 0xca, 0x34, 0xab, 0xdd, 0x6d, 0x77, 0xff, 0xd1, 0xbf, 0x6c, 0x5e, 0xb6, 0xd8,
		0xd4, 0xe2, 0x36, 0x75, 0xae, 0xac, 0x9d, 0xe6, 0x49, 0xab, 0xd3, 0x7a, 0x89, 0xd2, 0x0a, 0x28,
		0x6d, 0x63, 0x66, 0x12, 0xde, 0xf4, 0x3a, 0x7d, 0x76, 0x55, 0xc0, 0x14, 0x78, 0xfd, 0xde, 0x2b,
		0x36, 0x56, 0x00, 0xc1, 0x0e, 0x31, 0x06, 0x22, 0xc6, 0xf6, 0x10, 0x63, 0x2b, 0x6d, 0x6c, 0x5b,
		0x6f, 0x7a, 0x5d, 0x76, 0xb5, 0x60, 0xad, 0x45, 0x5b, 0x0b, 0xdf, 0xd7, 0xfe, 0xc5, 0x65, 0xcb,
		0xeb, 0x9d, 0x77, 0xda, 0xa7, 0x7f, 0xcc, 0x39, 0x03, 0x7b, 0x2b, 0xc2, 0xc4, 0xce, 0xae, 0x3a,
		0x97, 0xe8, 0xae, 0x04, 0x6d, 0x78, 0xd5, 0x39, 0xff, 0x67, 0xbf, 0xd7, 0x3a, 0x65, 0x63, 0x25,
		0x3c, 0x5b, 0x50, 0xac, 0xd0, 0x8d, 0x7d, 0xd3, 0xeb, 0xa2, 0xb2, 0x1a, 0x38, 0x76, 0xc8, 0xde,
		0x16, 0x6c, 0x67, 0xf1, 0xbd, 0x24, 0x79, 0xae, 0x85, 0x7f, 0xa0, 0x22, 0xe9, 0x5d, 0xd9, 0xf3,
		0x5a, 0x3b, 0x25, 0xd4, 0xef, 0x5a, 0x10, 0xf9, 0xef, 0x87, 0xc1, 0xb5, 0x5e, 0x35, 0xc1, 0x52,
		0xa0, 0x70, 0x16, 0x50, 0x79, 0xfa, 0x2b, 0x75, 0x0b, 0x05, 0xa8, 0x06, 0x75, 0x0b, 0x85, 0x0b,
		0xa6, 0x6e, 0xa1, 0x2c, 0x5e, 0x86, 0x41, 0xdd, 0x82, 0xde, 0xf4, 0x54, 0xa5, 0x69, 0xa9, 0x54,
		0xfa, 0xa7, 0x87, 0x6f, 0x4b, 0x2b, 0xfd, 0xe5, 0x1a, 0xb5, 0xca, 0x51, 0x37, 0x3f, 0x9d, 0x04,
		0xf5, 0xbb, 0xe9, 0x30, 0x09, 0xc7, 0xc3, 0xa0, 0x3e, 0xfb, 0x2c, 0x13, 0xf9, 0x22, 0xfa, 0xcf,
		0xc8, 0x2c, 0x79, 0x45, 0xfd, 0x2e, 0x15, 0xf5, 0xee, 0xb8, 0x50, 0x54, 0xd4, 0x6f, 0x31, 0x8e,
		0x89, 0x57, 0xd4, 0x0f, 0x96, 0x67, 0x5e, 0x89, 0xfc, 0xa6, 0xf2, 0x74, 0xb8, 0xe8, 0x1e, 0x5c,
		0x14, 0x2e, 0x0a, 0x17, 0x85, 0x8b, 0xba, 0x67, 0x78, 0x33, 0x41, 0x5a, 0xe1, 0xc7, 0xb5, 0xf3,
		0xad, 0x13, 0x86, 0x5c, 0x6d, 0xa8, 0xcd, 0x65, 0x54, 0xca, 0xa3, 0x80, 0xd4, 0x07, 0x4f, 0x5a,
		0x0c, 0x9c, 0xb4, 0x1b, 0x34, 0x69, 0x35, 0x60, 0xd2, 0x7c, 0xb0, 0xa4, 0xf9, 0x40, 0x49, 0xd3,
		0x41, 0x92, 0xd5, 0x1a, 0x39, 0xa4, 0x3e, 0x30, 0xd2, 0xf0, 0xb2, 0x28, 0xe5, 0x4b, 0xa2, 0x98,
		0x1e, 0xf4, 0x85, 0x43, 0xbc, 0xdd, 0xd3, 0x83, 0xd6, 0x23, 0x75, 0xcf, 0x53, 0x3e, 0x4a, 0x5e,
		0x7c, 0xdd, 0x31, 0x9d, 0x99, 0x78, 0xbd, 0xa4, 0xb8, 0xbc, 0x23, 0x41, 0x54, 0x80, 0xa8, 0x00,
		0x51, 0x01, 0xa2, 0x02, 0x65, 0x88, 0x0a, 0x28, 0x85, 0x65, 0xd7, 0x8e, 0xb7, 0x4a, 0x78, 0x56,
		0xd9, 0x20, 0xc3, 0xcd, 0xe1, 0xe6, 0x70, 0x73, 0xb8, 0xb9, 0x4b, 0x06, 0x3e, 0x13, 0xe8, 0x0f,
		0x87, 0xa3, 0x3f, 0x57, 0xa4, 0xc4, 0x9f, 0xd8, 0xdd, 0x17, 0xb4, 0xbe, 0x14, 0x65, 0x35, 0x36,
		0x0a, 0x11, 0x3f, 0x86, 0x23, 0xee, 0x2a, 0xaa, 0x32, 0x4c, 0x59, 0xc3, 0x95, 0x33, 0xb0, 0xe5,
		0x0c, 0x7c, 0x39, 0x01, 0x63, 0xba, 0x70, 0xa6, 0x0c, 0x6b, 0xd9, 0x0e, 0xdb, 0xdf, 0x55, 0xa4,
		0x1f, 0x82, 0x5e, 0x63, 0x1b, 0x7b, 0x5c, 0x75, 0xb8, 0xf1, 0x5e, 0xde, 0xf9, 0x7f, 0x85, 0x77,
		0xd3, 0x3b, 0xe1, 0x12, 0xcb, 0x2f, 0x6a, 0x53, 0x7e, 0x19, 0x76, 0xee, 0xca, 0x1e, 0xae, 0x0a,
		0xae, 0x0a, 0xae, 0x0a, 0xae, 0x0a, 0xae, 0x4a, 0x75, 0x5c, 0x95, 0x69, 0x18, 0x25, 0x2f, 0x1a,
		0x86, 0x9e, 0xca, 0x11, 0x57, 0x2a, 0xea, 0xbd, 0x38, 0x57, 0x2a, 0xae, 0x96, 0xc1, 0x95, 0x8a,
		0xd6, 0xe6, 0x2f, 0xaf, 0x9a, 0x5c, 0xa9, 0xb8, 0xa6, 0x9a, 0xfb, 0x8d, 0xe3, 0xfd, 0xe3, 0xc3,
		0xa3, 0xc6, 0xf1, 0x01, 0x3a, 0x6a, 0xe3, 0x10, 0xd8, 0x49, 0xe5, 0x66, 0xc5, 0x12, 0x58, 0x32,
		0x6e, 0x56, 0x7c, 0xb2, 0xe6, 0x2c, 0x98, 0x3d, 0x41, 0xa3, 0xf0, 0x4c, 0x4f, 0xb1, 0x3e, 0xa9,
		0x5c, 0xbd, 0x27, 0x79, 0x27, 0xd6, 0x93, 0x34, 0x40, 0xf2, 0x8e, 0xac, 0xa7, 0x50, 0x56, 0xbd,
		0x22, 0xa2, 0x41, 0x45, 0x44, 0x75, 0xe2, 0x36, 0x54, 0x44, 0x50, 0x11, 0x51, 0xd8, 0x4e, 0x52,
		0x11, 0x41, 0x45, 0x04, 0x69, 0x86, 0x2a, 0xc3, 0x94, 0x35, 0x5c, 0x39, 0x03, 0x5b, 0xce, 0xc0,
		0x97, 0x13, 0x30, 0x66, 0xc3, 0xef, 0xa9, 0x88, 0xd0, 0x37, 0xef, 0x54, 0x44, 0x14, 0xb0, 0x97,
		0x54, 0x44, 0x50, 0x11, 0x81, 0xab, 0x82, 0xab, 0x82, 0xab, 0x82, 0xab, 0x52, 0x55, 0x57, 0x85,
		0x8a, 0x08, 0xf5, 0x3f, 0x54, 0x44, 0x50, 0x11, 0xf1, 0x60, 0x1d, 0x54, 0x44, 0x3c, 0xa3, 0x22,
		0xe2, 0xf3, 0xaa, 0x49, 0x45, 0x84, 0xb5, 0x43, 0x60, 0x27, 0x95, 0x8a, 0x88, 0x12, 0x58, 0x32,
		0x2a, 0x22, 0xfe, 0x7b, 0x45, 0x84, 0xe0, 0xf0, 0x72, 0x7d, 0xbd, 0x62, 0x4e, 0x54, 0xf5, 0x34,
		0xb4, 0xa6, 0x52, 0xe4, 0x12, 0x4f, 0x07, 0x49, 0x94, 0x12, 0xae, 0xee, 0xe2, 0xd5, 0xda, 0xe9,
		0x9b, 0x79, 0xbd, 0xf4, 0x7d, 0xbc, 0x93, 0xdb, 0xb1, 0xd7, 0x0b, 0x82, 0xf8, 0xf5, 0xec, 0x15,
		0xbc, 0xe6, 0x4d, 0xd8, 0xf7, 0x6f, 0x42, 0xef, 0x6a, 0x12, 0x9c, 0xa5, 0xcb, 0xee, 0xcd, 0x56,
		0xed, 0xb5, 0xc4, 0x69, 0x78, 0x39, 0x67, 0x5b, 0x85, 0xaa, 0xb3, 0xad, 0x42, 0x66, 0x5b, 0x7d,
		0xb3, 0x20, 0x66, 0x5b, 0x15, 0xaa, 0x1d, 0xcc, 0xb6, 0x62, 0xb6, 0xd5, 0x17, 0x76, 0x8c, 0xd9,
		0x56, 0x25, 0x34, 0xc8, 0xea, 0x86, 0xd9, 0xc2, 0x40, 0xdb, 0x19, 0x6a, 0x2b, 0x83, 0x6d, 0x6e,
		0xb8, 0xcd, 0x0d, 0xb8, 0xa9, 0x21, 0xaf, 0x66, 0xf8, 0x41, 0xbd, 0x92, 0x93, 0x92, 0x08, 0x4a,
		0x22, 0x34, 0x05, 0x53, 0x12, 0x41, 0x49, 0x04, 0x25, 0x11, 0x16, 0x10, 0xa6, 0x0c, 0x65, 0xd9,
		0x0e, 0x53, 0x12, 0x41, 0x49, 0x84, 0xe6, 0x8b, 0x53, 0x12, 0xb1, 0x5a, 0x06, 0x25, 0x11, 0xd6,
		0xe6, 0x2f, 0xaf, 0x9a, 0x94, 0x44, 0xac, 0xa9, 0x26, 0x25, 0x11, 0xd6, 0x0e, 0x81, 0x9d, 0x54,
		0x4a, 0x22, 0xca, 0x10, 0x93, 0xa0, 0x24, 0xe2, 0xa9, 0x84, 0x73, 0xc8, 0x90, 0x88, 0xef, 0xfa,
		0xb0, 0x0c, 0x89, 0x10, 0x8b, 0xe7, 0x30, 0x24, 0xa2, 0x42, 0x71, 0x1b, 0x52, 0x0b, 0xa4, 0x16,
		0x0a, 0xdb, 0x49, 0x52, 0x0b, 0xa4, 0x16, 0x54, 0xa1, 0x88, 0xd4, 0x82, 0xe6, 0x0a, 0x48, 0x2d,
		0x38, 0x02, 0x59, 0x4e, 0x40, 0x97, 0x0d, 0xa7, 0x27, 0xb5, 0xa0, 0x6e, 0xdd, 0x49, 0x2d, 0x28,
		0xbe, 0x38, 0xa9, 0x85, 0xd5, 0x32, 0x48, 0x2d, 0x58, 0x9b, 0xbf, 0xbc, 0x6a, 0x92, 0x5a, 0x58,
		0x53, 0x4d, 0x52, 0x0b, 0xd6, 0x0e, 0x81, 0x9d, 0x54, 0x52, 0x0b, 0x65, 0x88, 0x49, 0x90, 0x5a,
		0xf8, 0xaf, 0xa9, 0x05, 0xba, 0x2d, 0x5d, 0xd1, 0x58, 0xba, 0x2d, 0x3f, 0xab, 0xa1, 0xe5, 0xeb,
		0xb6, 0x6c, 0xd3, 0x6d, 0xf9, 0xc4, 0x2e, 0x6b, 0xe4, 0xe4, 0x54, 0x73, 0x71, 0xea, 0xfd, 0x96,
		0x0d, 0xfa, 0x2d, 0x37, 0x90, 0x48, 0xbf, 0xa5, 0xb8, 0xb7, 0x45, 0xbf, 0xe5, 0x37, 0xee, 0x98,
		0x5a, 0xbf, 0x65, 0x10, 0xf9, 0xef, 0x87, 0xc1, 0xb5, 0x7e, 0x51, 0xc4, 0x52, 0xb0, 0x56, 0x12,
		0xd2, 0x66, 0x58, 0xba, 0x72, 0x64, 0x82, 0x4e, 0xcf, 0x4a, 0x41, 0x85, 0x39, 0x64, 0x98, 0x43,
		0x87, 0x29, 0x84, 0x54, 0x33, 0xf4, 0xa1, 0x9e, 0xbb, 0x32, 0x1c, 0x66, 0xae, 0x3c, 0xc4, 0x9c,
		0x58, 0x06, 0xb1, 0x8c, 0x6f, 0x8b, 0x65, 0x28, 0x04, 0xda, 0x04, 0xc3, 0x02, 0x3b, 0x25, 0x52,
		0x42, 0x2d, 0xe5, 0x73, 0x5f, 0xe9, 0x6a, 0xa2, 0xd1, 0x9c, 0x02, 0x63, 0x66, 0x32, 0xe7, 0xa2,
		0x78, 0xad, 0x2d, 0xf6, 0x89, 0x05, 0xeb, 0xff, 0xcc, 0x77, 0x9c, 0x5f, 0x57, 0x95, 0x2a, 0x44,
		0x7d, 0xfe, 0x71, 0x0a, 0x96, 0xd1, 0x09, 0x27, 0x49, 0x33, 0x49, 0x64, 0x38, 0x6b, 0xed, 0x2c,
		0x8c, 0x5a, 0xc3, 0x60, 0xe6, 0xfd, 0x4d, 0x64, 0x98, 0x4d, 0xed, 0xcc, 0xff, 0xeb, 0x81, 0x84,
		0xbd, 0x5f, 0xf6, 0xf7, 0x0f, 0x8f, 0xf6, 0xf7, 0x77, 0x8f, 0x5e, 0x1c, 0xed, 0x1e, 0x1f, 0x1c,
		0xec, 0x1d, 0xee, 0x09, 0x24, 0x72, 0x6b, 0xe7, 0xf1, 0x75, 0x10, 0x07, 0xd7, 0x27, 0xb3, 0xcf,
		0x13, 0x4d, 0x87, 0x43, 0xa7, 0xb5, 0x48, 0xd8, 0x7a, 0x3a, 0x66, 0x35, 0x05, 0x4c, 0xe4, 0x46,
		0xa6, 0xb1, 0x58, 0x4b, 0x58, 0x9c, 0xbd, 0x2a, 0xe6, 0x49, 0x05, 0xe9, 0xaa, 0x94, 0x8e, 0xba,
		0xa1, 0x9b, 0xc5, 0xa8, 0xc0, 0xe6, 0x1f, 0xac, 0x80, 0x8f, 0x55, 0xf3, 0xc7, 0xe3, 0xe1, 0xc7,
		0xfa, 0x78, 0x34, 0x0c, 0x07, 0x1f, 0x0b, 0xfb, 0x54, 0xab, 0x8b, 0x19, 0x1f, 0x3e, 0xbd, 0x20,
		0xd5, 0x2a, 0x36, 0xa3, 0x53, 0x78, 0x98, 0x4e, 0x22, 0x0c, 0xf7, 0x30, 0xcc, 0x16, 0x8f, 0x47,
		0xc3, 0x02, 0x6d, 0xa2, 0x54, 0x1c, 0x4d, 0x3c, 0x4e, 0x26, 0x1e, 0x07, 0x7b, 0x1c, 0xe7, 0x9a,
		0x6f, 0x7c, 0x45, 0xcd, 0x75, 0xd1, 0x39, 0x0e, 0xa9, 0xd9, 0x91, 0xb2, 0x33, 0x22, 0x85, 0x92,
		0xc5, 0x62, 0x99, 0x00, 0xc9, 0x88, 0xbf, 0xa0, 0xc9, 0x91, 0x36, 0x3d, 0x6a, 0x26, 0x48, 0xcd,
		0x14, 0xe9, 0x98, 0xa4, 0x72, 0x70, 0x68, 0xa9, 0x74, 0x6c, 0xed, 0x7a, 0x91, 0x96, 0xac, 0x07,
		0x7f, 0x8d, 0x47, 0x71, 0x52, 0xb4, 0x4b, 0xf4, 0xe4, 0xf9, 0xfa, 0xbc, 0x58, 0x21, 0xfd, 0x79,
		0x90, 0x7a, 0xbd, 0x68, 0xfd, 0x6f, 0xeb, 0xf4, 0xd2, 0xbb, 0x38, 0xbf, 0xba, 0x6c, 0x49, 0x89,
		0x93, 0xcd, 0xb8, 0x8a, 0x67, 0x58, 0x35, 0x32, 0xaa, 0x0a, 0x76, 0x56, 0xcb, 0xde, 0xaa, 0xdb,
		0x5d, 0x75, 0xfb, 0xab, 0x6b, 0x87, 0x65, 0xec, 0xb1, 0x90, 0x5d, 0xce, 0xb6, 0x46, 0x3c, 0xa7,
		0xb9, 0x66, 0x39, 0x17, 0x26, 0xb3, 0x9e, 0xcc, 0x04, 0x0b, 0x9e, 0x9e, 0xa5, 0x73, 0xb8, 0x2f,
		0x28, 0xa3, 0x15, 0x4d, 0xef, 0x66, 0x9b, 0xf7, 0xa9, 0x2c, 0xe1, 0xf6, 0x9f, 0xe4, 0x70, 0x38,
		0xbc, 0x33, 0xc1, 0xe1, 0xbc, 0x58, 0x70, 0x18, 0x1c, 0x06, 0x87, 0xc1, 0x61, 0x70, 0x18, 0x1c,
		0xde, 0x32, 0x1c, 0x56, 0xe6, 0xc1, 0x2a, 0xfc, 0x17, 0x20, 0x04, 0x08, 0x01, 0x42, 0x80, 0x50,
		0xe6, 0xc4, 0x0c, 0x03, 0xff, 0x26, 0x0e, 0x6e, 0x34, 0xc0, 0x4f, 0x70, 0xe4, 0x4b, 0xad, 0x97,
		0x65, 0xd7, 0x17, 0x8a, 0xf4, 0x6b, 0x3c, 0x9a, 0x26, 0x61, 0x74, 0x9b, 0xda, 0xe6, 0xec, 0xaf,
		0x53, 0xbc, 0xbf, 0x0e, 0x6e, 0xc2, 0x28, 0x4c, 0xc2, 0x51, 0x34, 0x79, 0xfa, 0x3f, 0x65, 0xff,
		0x65, 0x5e, 0x74, 0x51, 0x2a, 0xfd, 0x11, 0x2d, 0xa8, 0xca, 0xa4, 0x88, 0x17, 0x56, 0xad, 0x24,
		0x19, 0x14, 0x58, 0x65, 0xc2, 0x1f, 0x16, 0x5a, 0x29, 0xb5, 0x99, 0x4e, 0x27, 0x41, 0x2c, 0x6d,
		0xef, 0x15, 0x9b, 0x51, 0x1e, 0x82, 0xd9, 0x68, 0xb1, 0x9b, 0xf5, 0xf7, 0x1f, 0x35, 0x9a, 0x33,
		0x2d, 0x1a, 0x4f, 0x72, 0xc0, 0x36, 0xff, 0x92, 0x14, 0x68, 0x97, 0x8e, 0x49, 0x28, 0x47, 0xf2,
		0x54, 0x22, 0x78, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24,
		0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x42, 0xee, 0x89, 0x34, 0x51, 0x7d, 0x43, 0xa3, 0xca,
		0x83, 0xae, 0x0b, 0x91, 0xab, 0x89, 0x0a, 0xec, 0x5a, 0x2a, 0xb0, 0x93, 0x41, 0x66, 0x7c, 0x99,
		0xe8, 0xb8, 0x32, 0xf1, 0x8a, 0xf3, 0x06, 0x15, 0xe7, 0x8a, 0xe8, 0x4a, 0xc5, 0x79, 0x15, 0xa1,
		0x82, 0x8a, 0xf3, 0x4d, 0x36, 0x8f, 0x4a, 0x37, 0xc2, 0x72, 0x84, 0xe5, 0x08, 0xcb, 0x51, 0xe9,
		0xf6, 0xdd, 0xce, 0x21, 0x95, 0x6e, 0xa2, 0x4a, 0x44, 0xc5, 0x39, 0x38, 0x0c, 0x0e, 0x83, 0xc3,
		0xe0, 0x30, 0x38, 0x0c, 0x0e, 0x1b, 0xe2, 0x30, 0x15, 0xe7, 0x00, 0x21, 0x40, 0x08, 0x10, 0x02,
		0x84, 0x5f, 0x7b, 0x62, 0xa8, 0x13, 0xa1, 0x4e, 0xe4, 0x7b, 0xa5, 0x50, 0x27, 0x22, 0x75, 0x2a,
		0xa9, 0x13, 0x29, 0x29, 0xa8, 0x3d, 0xa3, 0x4e, 0xa4, 0x1a, 0x4c, 0x82, 0x8a, 0x73, 0x98, 0x04,
		0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c,
		0xa2, 0xf2, 0x4c, 0x82, 0x8a, 0x73, 0x17, 0x2a, 0xce, 0x05, 0x2e, 0xd2, 0xe2, 0x9a, 0x8c, 0x72,
		0xea, 0x42, 0xad, 0xd0, 0xf2, 0xfe, 0xef, 0xb9, 0xb4, 0x65, 0xb6, 0x98, 0xde, 0x62, 0x2d, 0x55,
		0xba, 0xb5, 0x63, 0x32, 0xbf, 0x3f, 0xac, 0x3e, 0x1a, 0xcf, 0x7d, 0x57, 0x81, 0x8b, 0x3b, 0x1e,
		0x09, 0xe0, 0xee, 0x8e, 0x22, 0x62, 0x12, 0xc5, 0x5e, 0x91, 0xcb, 0xd5, 0x1d, 0x5f, 0x1b, 0x52,
		0x28, 0xf4, 0x8a, 0x5a, 0x6e, 0xee, 0xd8, 0xe8, 0x18, 0x70, 0x73, 0x87, 0x62, 0x1f, 0x95, 0xcc,
		0x9d, 0xdc, 0xb4, 0x51, 0x39, 0x65, 0x90, 0xca, 0x41, 0x7f, 0xc4, 0xba, 0xa8, 0xfc, 0xe1, 0x70,
		0xf4, 0x67, 0x7d, 0xf4, 0x67, 0x54, 0xf7, 0x27, 0xf2, 0xa9, 0x9e, 0x9c, 0x34, 0xf9, 0x5a, 0xed,
		0x5d, 0xb2, 0x49, 0xea, 0x06, 0x54, 0xcf, 0x90, 0x6a, 0xc7, 0xe0, 0xb6, 0x2f, 0x99, 0x24, 0x62,
		0x68, 0x85, 0xe3, 0x62, 0xa5, 0xcf, 0x25, 0x4d, 0xc3, 0x28, 0xf9, 0x45, 0x21, 0x93, 0x24, 0x19,
		0xec, 0xbf, 0xf0, 0xa3, 0xdb, 0xd9, 0xcb, 0xbc, 0x15, 0x55, 0x57, 0x85, 0x90, 0xfb, 0x59, 0xa8,
		0x73, 0xc3, 0xbf, 0x02, 0xaa, 0xac, 0x89, 0x7b, 0xe3, 0x0f, 0xa7, 0x81, 0xa2, 0xbc, 0x57, 0xb1,
		0x3f, 0x48, 0xc2, 0x51, 0xf4, 0x32, 0xbc, 0x0d, 0x17, 0xb9, 0x2e, 0x71, 0xb9, 0x9f, 0x14, 0xf2,
		0x14, 0x67, 0xfe, 0x5f, 0x95, 0x57, 0x91, 0xc6, 0xc1, 0x41, 0x85, 0x95, 0xa4, 0xa4, 0x89, 0xa5,
		0x77, 0xdb, 0xdc, 0x74, 0x1a, 0x4e, 0xfc, 0xf7, 0xc3, 0xa0, 0x3e, 0x8f, 0x9c, 0xfb, 0x93, 0xfa,
		0x4d, 0x38, 0x4c, 0x82, 0x58, 0xa1, 0xeb, 0xf4, 0xf3, 0x72, 0xe5, 0xa9, 0xcc, 0x8d, 0x3f, 0x9c,
		0x04, 0xd0, 0x19, 0xe8, 0x0c, 0x74, 0x06, 0x3a, 0x53, 0x26, 0x3a, 0xf3, 0x7e, 0x34, 0x1a, 0x06,
		0x7e, 0xa4, 0x51, 0x1a, 0xb7, 0xb7, 0xc5, 0x80, 0x18, 0x07, 0xe3, 0xa1, 0x3f, 0xc8, 0x80, 0x49,
		0x1e, 0x09, 0x1f, 0x0b, 0x04, 0x02, 0x81, 0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x81, 0x40, 0xed,
		0x27, 0x52, 0x6c, 0xf8, 0x0d, 0x05, 0x66, 0xf9, 0xda, 0x24, 0x26, 0xdc, 0x16, 0x75, 0xca, 0x99,
		0x70, 0x4b, 0x65, 0x86, 0x23, 0xee, 0x06, 0x95, 0x19, 0x7a, 0x58, 0x41, 0x65, 0xc6, 0xf7, 0x70,
		0x39, 0x2a, 0x33, 0xe0, 0x71, 0xf0, 0x38, 0x78, 0x5c, 0xa9, 0x78, 0x1c, 0x95, 0x19, 0x5f, 0xfb,
		0x87, 0xca, 0x8c, 0x8d, 0xc4, 0x51, 0x99, 0x51, 0x8c, 0x8a, 0x50, 0x99, 0x51, 0x72, 0x25, 0xa1,
		0x32, 0x43, 0x74, 0xbd, 0x54, 0x66, 0x14, 0x40, 0x65, 0x48, 0x4b, 0x41, 0x67, 0xa0, 0x33, 0xd0,
		0x99, 0xd2, 0xd1, 0x19, 0xd2, 0x52, 0x2a, 0x80, 0x48, 0x65, 0x06, 0x10, 0x08, 0x04, 0x02, 0x81,
		0x40, 0x20, 0x10, 0x58, 0x06, 0x08, 0xa4, 0x32, 0xc3, 0x91, 0xca, 0x0c, 0x26, 0x41, 0x59, 0xab,
		0x85, 0x4b, 0xea, 0x60, 0x3f, 0x0c, 0x6a, 0xd2, 0xf3, 0x93, 0x0f, 0xe7, 0xe9, 0x6a, 0x2a, 0x34,
		0x0e, 0xaa, 0xe0, 0x99, 0x2d, 0x32, 0xb3, 0x5a, 0x18, 0xfe, 0xc4, 0xf0, 0x27, 0x86, 0x3f, 0x15,
		0x0a, 0x1a, 0x85, 0x0f, 0x7f, 0xf2, 0xa7, 0xc9, 0x87, 0xfa, 0xd8, 0x9f, 0x4c, 0x52, 0x15, 0x10,
		0x2a, 0x34, 0xcc, 0x8b, 0x91, 0x29, 0x38, 0xdc, 0x65, 0x14, 0x14, 0x05, 0x87, 0x0e, 0xb2, 0x67,
		0x0a, 0x0e, 0xe5, 0xd8, 0xf1, 0x2a, 0x80, 0xb8, 0x9c, 0xfa, 0x2e, 0x63, 0x63, 0x72, 0xee, 0xcc,
		0x2f, 0x5b, 0x50, 0x78, 0x7e, 0x1d, 0x4c, 0x06, 0x71, 0x38, 0x16, 0x61, 0xad, 0x0f, 0x6e, 0xf5,
		0x5c, 0x09, 0x01, 0x13, 0xc0, 0x04, 0x30, 0x01, 0x4c, 0x28, 0x50, 0xdf, 0x27, 0x49, 0x1c, 0x46,
		0xb7, 0x20, 0xc1, 0x66, 0xef, 0x3a, 0x1c, 0x0d, 0xfc, 0xa1, 0x44, 0x12, 0x70, 0x75, 0x13, 0xcd,
		0x52, 0x02, 0x18, 0x00, 0x06, 0x80, 0x01, 0x60, 0x40, 0x91, 0x81, 0x87, 0x49, 0x3d, 0x9a, 0xde,
		0xbd, 0x17, 0xa9, 0xaa, 0x5b, 0x1a, 0x18, 0x81, 0xeb, 0xad, 0x84, 0x6b, 0xde, 0x65, 0xaf, 0x86,
		0x52, 0xc8, 0xb4, 0xab, 0x14, 0x2e, 0x6b, 0xd5, 0xb4, 0x6b, 0x96, 0x29, 0x7f, 0x92, 0xbd, 0xab,
		0xab, 0x72, 0x9f, 0x7e, 0xbf, 0x71, 0xbc, 0x7f, 0x7c, 0x78, 0xd4, 0x38, 0x3e, 0xa8, 0x90, 0x0e,
		0x94, 0x24, 0xad, 0xff, 0x6e, 0x0b, 0xbc, 0x6b, 0xa9, 0x0a, 0xbb, 0x0c, 0x00, 0x65, 0x2a, 0xea,
		0xf0, 0xad, 0xf1, 0xad, 0xf1, 0xad, 0xf1, 0xad, 0xf1, 0xad, 0xf1, 0xad, 0xf1, 0xad, 0xf1, 0xad,
		0xf1, 0xad, 0xf1, 0xad, 0xdd, 0xf4, 0xad, 0xe7, 0x85, 0x89, 0xf5, 0xb4, 0x6e, 0x50, 0xd2, 0xc7,
		0x7e, 0x20, 0x08, 0x5f, 0x1b, 0x5f, 0x1b, 0x5f, 0x1b, 0x5f, 0xbb, 0x40, 0x7d, 0x27, 0x97, 0x59,
		0x18, 0x22, 0x24, 0x12, 0x1f, 0x2b, 0x8f, 0x05, 0x73, 0x11, 0xa0, 0x00, 0x28, 0x00, 0x0a, 0x80,
		0x02, 0x25, 0x30, 0x2e, 0x39, 0x20, 0xd8, 0x17, 0x78, 0x76, 0x2b, 0x9a, 0xde, 0xcd, 0xb6, 0xe6,
		0xd3, 0x16, 0x80, 0x4c, 0x1c, 0xdc, 0x8d, 0xee, 0x83, 0xfa, 0x38, 0x0e, 0xef, 0xfd, 0x24, 0x10,
		0x0d, 0xee, 0xaf, 0x8b, 0x02, 0x74, 0x00, 0x1d, 0x40, 0x07, 0xd0, 0x91, 0x34, 0x32, 0x69, 0x7b,
		0xa7, 0x24, 0x06, 0x09, 0x44, 0x04, 0x6b, 0xed, 0xeb, 0x20, 0x4a, 0xc2, 0xe4, 0xe3, 0x89, 0x3f,
		0x09, 0xe4, 0x27, 0x9a, 0x5c, 0xb4, 0xce, 0xce, 0xdf, 0xb4, 0xbc, 0xde, 0x45, 0xfb, 0x4d, 0xf3,
		0xb2, 0xe5, 0x35, 0xfb, 0xde, 0x79, 0xef, 0xb2, 0x7d, 0xde, 0x95, 0x3a, 0x72, 0xf3, 0xa0, 0xea,
		0x44, 0x74, 0x4a, 0xa6, 0x70, 0xf4, 0x79, 0xb9, 0x73, 0x0f, 0xb6, 0x2c, 0xdd, 0xc4, 0x66, 0xa7,
		0x53, 0x2b, 0x63, 0xd4, 0xde, 0x62, 0xc3, 0x7a, 0x9d, 0xe6, 0xa9, 0xf4, 0x8e, 0x89, 0x3c, 0xf9,
		0x9d, 0xeb, 0x86, 0xdb, 0x4d, 0x67, 0x73, 0x34, 0x4d, 0x82, 0xfa, 0xcd, 0xd0, 0x1f, 0xd7, 0xaf,
		0xfd, 0xbb, 0x71, 0x18, 0xdd, 0x0a, 0x7a, 0x9b, 0xeb, 0xb2, 0x8a, 0x1e, 0x4c, 0x2f, 0x3b, 0x9f,
		0x09, 0x77, 0x16, 0x77, 0x16, 0x77, 0x76, 0xcb, 0xdd, 0x59, 0xb9, 0xf9, 0x49, 0x42, 0x73, 0x93,
		0x1c, 0xbd, 0x99, 0x28, 0x88, 0xae, 0xeb, 0x83, 0xd1, 0xdd, 0xdd, 0x34, 0x0a, 0x93, 0x8f, 0x82,
		0x57, 0x14, 0xe5, 0xe5, 0xc8, 0x01, 0x4e, 0xf7, 0xbc, 0xdb, 0x02, 0x6f, 0xc0, 0x1b, 0xf0, 0x06,
		0xbc, 0x29, 0x52, 0xdf, 0x33, 0xdb, 0x45, 0xe0, 0x5e, 0x02, 0xd2, 0x98, 0xe9, 0x26, 0x3c, 0xd3,
		0xad, 0xc8, 0xcb, 0x16, 0xdd, 0x18, 0x9e, 0x16, 0xbc, 0xbf, 0x1d, 0xd7, 0xef, 0xa6, 0xc3, 0x24,
		0xfc, 0x30, 0x1a, 0x17, 0x3f, 0x43, 0x2d, 0xff, 0x78, 0x46, 0xa9, 0xb9, 0xe7, 0x31, 0x30, 0x4a,
		0xcd, 0xc4, 0x23, 0xa8, 0xf8, 0x28, 0xb5, 0x82, 0x67, 0x32, 0x7e, 0xc6, 0x91, 0x28, 0x70, 0x36,
		0xa3, 0x90, 0x61, 0x81, 0xa2, 0x40, 0x51, 0xa0, 0x28, 0x25, 0xb9, 0xad, 0x35, 0x88, 0xfc, 0xf7,
		0xc3, 0xe0, 0x5a, 0x3e, 0x17, 0xba, 0x14, 0xc4, 0xad, 0x0e, 0x16, 0x26, 0x53, 0xc3, 0x74, 0xea,
		0x99, 0x50, 0x2d, 0x53, 0xaa, 0x6e, 0x52, 0xd5, 0x4d, 0xab, 0xaa, 0x89, 0x95, 0x31, 0xb5, 0x42,
		0x26, 0x57, 0x3e, 0x3a, 0xb4, 0x76, 0x5e, 0xb8, 0xd5, 0x41, 0xe3, 0xa3, 0xd6, 0x96, 0xb4, 0xbc,
		0x9e, 0x24, 0x43, 0x79, 0xdc, 0xcb, 0x49, 0x03, 0x94, 0x00, 0x25, 0x40, 0x09, 0x50, 0x2a, 0x11,
		0x28, 0x71, 0x79, 0xf8, 0xd7, 0xfe, 0xe1, 0xf2, 0xf0, 0x8d, 0xc4, 0x71, 0x79, 0x78, 0x31, 0x2a,
		0xc2, 0xe5, 0xe1, 0x25, 0x57, 0x12, 0x2e, 0x0f, 0x97, 0xa5, 0x14, 0x5c, 0x14, 0x67, 0x94, 0x45,
		0xce, 0x25, 0x45, 0x0b, 0xcd, 0x29, 0x17, 0xff, 0x6d, 0x0b, 0x2d, 0x93, 0x9b, 0x5f, 0x88, 0x27,
		0x57, 0x1d, 0x37, 0x7f, 0x7c, 0xc9, 0x52, 0x42, 0x0d, 0x52, 0x42, 0x7a, 0x94, 0x91, 0x94, 0x50,
		0x05, 0x91, 0x82, 0x94, 0xd0, 0x97, 0x36, 0x88, 0x94, 0x90, 0xb5, 0xe9, 0xd4, 0x33, 0xa1, 0x5a,
		0xa6, 0x54, 0xdd, 0xa4, 0xaa, 0x9b, 0x56, 0x55, 0x13, 0x2b, 0x4b, 0x4b, 0x48, 0x09, 0x7d, 0x83,
		0xa7, 0x47, 0x4a, 0x88, 0x94, 0x10, 0xa0, 0x04, 0x28, 0x01, 0x4a, 0x80, 0xd2, 0x7f, 0x3f, 0x2f,
		0xa4, 0x84, 0xbe, 0xf6, 0x0f, 0x29, 0xa1, 0x8d, 0xc4, 0x91, 0x12, 0x2a, 0x46, 0x45, 0x48, 0x09,
		0x95, 0x5c, 0x49, 0x48, 0x09, 0xc9, 0x52, 0x0a, 0x52, 0x42, 0x4e, 0xa4, 0x84, 0x16, 0x99, 0x0c,
		0xba, 0x4c, 0xed, 0x94, 0xc2, 0x1d, 0x65, 0xa8, 0x15, 0x9a, 0x80, 0x8b, 0xa7, 0x83, 0x24, 0x9d,
		0xff, 0x5f, 0xeb, 0x2e, 0x56, 0xd9, 0x4e, 0x17, 0xe9, 0xf5, 0xd2, 0xa5, 0x79, 0x27, 0xb7, 0x63,
		0xaf, 0x17, 0x04, 0xf1, 0xeb, 0xd9, 0x6a, 0xbc, 0xd6, 0xfb, 0xdb, 0xf1, 0xd9, 0x72, 0x31, 0x55,
		0xea, 0x7c, 0x8d, 0xe3, 0x51, 0x5c, 0xff, 0xe0, 0x47, 0xd7, 0xc3, 0x22, 0x27, 0x45, 0xad, 0xa2,
		0xfa, 0xf9, 0xe7, 0xd3, 0xfb, 0xea, 0x5e, 0x7c, 0x82, 0xde, 0x57, 0x93, 0xf8, 0x02, 0xbd, 0xaf,
		0x1b, 0x1d, 0x03, 0x7a, 0x5f, 0x29, 0x74, 0xb0, 0x36, 0x40, 0x6a, 0x86, 0x48, 0xc5, 0x20, 0x95,
		0x83, 0xff, 0x88, 0x15, 0x3a, 0x24, 0x71, 0xe0, 0x27, 0x75, 0x7f, 0x52, 0xff, 0x33, 0x4c, 0x3e,
		0x5c, 0xc7, 0xfe, 0x9f, 0xf2, 0xa9, 0x9f, 0x75, 0x91, 0x14, 0x3f, 0x58, 0x98, 0x51, 0x0d, 0x73,
		0xaa, 0x67, 0x56, 0xb5, 0xcc, 0xab, 0xba, 0x99, 0x55, 0x37, 0xb7, 0xaa, 0x66, 0x57, 0x36, 0x00,
		0x47, 0xf1, 0xc3, 0x37, 0x78, 0x7f, 0x7b, 0x44, 0x2a, 0xdd, 0x0d, 0x4a, 0xb9, 0x11, 0x9c, 0xca,
		0x85, 0x35, 0xa8, 0x5e, 0x2f, 0xea, 0x90, 0x53, 0xbd, 0x0e, 0xa9, 0x83, 0xd4, 0x41, 0xea, 0x20,
		0x75, 0x90, 0x3a, 0x48, 0x1d, 0xa4, 0x0e, 0x52, 0x07, 0xa9, 0x83, 0xd4, 0x41, 0xea, 0x2c, 0x48,
		0x1d, 0xf5, 0x27, 0xd6, 0x5a, 0xe1, 0x90, 0x36, 0xd8, 0x17, 0xa0, 0xcc, 0x96, 0xf3, 0xdb, 0x72,
		0x35, 0x15, 0xaa, 0x40, 0xb9, 0x8d, 0xfd, 0x41, 0x70, 0x33, 0x1d, 0xd6, 0xe3, 0x60, 0x92, 0xf8,
		0x71, 0x52, 0x7c, 0x0d, 0xca, 0x9a, 0x04, 0xaa, 0x50, 0xdc, 0x73, 0x74, 0xa9, 0x42, 0x31, 0x71,
		0x54, 0xa9, 0x42, 0xd9, 0xe8, 0x18, 0x50, 0x85, 0x42, 0xc0, 0xd2, 0x15, 0x26, 0x4d, 0xc0, 0x52,
		0x8f, 0x06, 0x31, 0x6e, 0x83, 0xa0, 0x21, 0x41, 0x43, 0x82, 0x86, 0x04, 0x0d, 0x09, 0x1a, 0x3a,
		0x11, 0x34, 0x14, 0xf0, 0x8b, 0x3e, 0x04, 0xc3, 0x71, 0x10, 0xd7, 0x47, 0xd1, 0xf0, 0xa3, 0x3c,
		0x1c, 0x3d, 0x14, 0x06, 0x24, 0x01, 0x49, 0x40, 0x12, 0x90, 0x04, 0x24, 0x01, 0x49, 0xf9, 0x3d,
		0x48, 0x03, 0xb8, 0xf5, 0x24, 0xbc, 0x0b, 0xe4, 0x31, 0x29, 0x27, 0x0d, 0x50, 0x02, 0x94, 0x00,
		0x25, 0x40, 0xa9, 0x44, 0xa0, 0x34, 0x0d, 0xa3, 0x64, 0xef, 0x50, 0x01, 0x93, 0x0e, 0x19, 0xcd,
		0xf4, 0xe5, 0x17, 0x61, 0x34, 0x53, 0x71, 0xf2, 0x18, 0xcd, 0x54, 0x5a, 0x15, 0xd9, 0xdf, 0x3d,
		0x3e, 0x64, 0x36, 0x93, 0x6b, 0x4f, 0x7f, 0xb7, 0xc5, 0xa4, 0x62, 0x92, 0xf8, 0xc3, 0xa0, 0x1e,
		0x8f, 0xa6, 0x49, 0x30, 0x51, 0x62, 0x16, 0xeb, 0x22, 0xa1, 0x17, 0xd0, 0x0b, 0xe8, 0x05, 0xf4,
		0xa2, 0x44, 0xf4, 0xe2, 0x3a, 0x18, 0x84, 0x77, 0xfe, 0xf0, 0x70, 0x5f, 0x23, 0xea, 0xd5, 0x10,
		0x94, 0xb1, 0xe6, 0x27, 0x34, 0xe0, 0x33, 0x6e, 0xf2, 0x99, 0x06, 0x7c, 0x06, 0x3e, 0xf3, 0xdf,
		0x55, 0xe4, 0x05, 0x2a, 0x02, 0x99, 0x29, 0x09, 0x99, 0xa1, 0xd3, 0xc7, 0xa8, 0xb7, 0xe3, 0x71,
		0x47, 0x00, 0x03, 0x1c, 0x0a, 0x64, 0xb6, 0x0c, 0x70, 0xa0, 0x1e, 0xda, 0x05, 0x76, 0x4a, 0x3d,
		0xb4, 0x1e, 0x58, 0x50, 0x0f, 0xfd, 0x75, 0x26, 0x8c, 0x40, 0x9c, 0xa5, 0x69, 0xd3, 0x32, 0x71,
		0xea, 0xa6, 0x4e, 0xdd, 0xe4, 0xa9, 0x9a, 0x3e, 0x59, 0xc6, 0x40, 0xf1, 0xd9, 0x37, 0x78, 0x60,
		0xd4, 0x43, 0x53, 0x0f, 0x0d, 0x24, 0x01, 0x49, 0x40, 0x12, 0x90, 0x04, 0x24, 0x99, 0x43, 0x12,
		0xf5, 0xd0, 0x80, 0x12, 0xa0, 0x04, 0x28, 0x01, 0x4a, 0x5f, 0x73, 0x5e, 0xa8, 0x87, 0xfe, 0xea,
		0x3f, 0xd4, 0x43, 0x6f, 0x24, 0x8e, 0xfa, 0x81, 0x62, 0x54, 0x84, 0x7a, 0xe8, 0xb2, 0x6b, 0x09,
		0x25, 0x04, 0xa5, 0x23, 0x15, 0xd4, 0x43, 0x43, 0x2f, 0xa0, 0x17, 0xd0, 0x0b, 0xe8, 0xc5, 0xb7,
		0x9d, 0x17, 0xea, 0xa1, 0xe1, 0x33, 0xd4, 0x43, 0xc3, 0x67, 0xdc, 0xe2, 0x33, 0xd4, 0x43, 0x43,
		0x66, 0xa8, 0x87, 0x2e, 0xc2, 0xc5, 0xda, 0xa6, 0x7a, 0x68, 0xee, 0x3e, 0xb0, 0xd6, 0x0b, 0xa7,
		0xf4, 0xc1, 0xfc, 0xf6, 0x83, 0xd7, 0xe9, 0x82, 0x2e, 0xd2, 0xf5, 0x54, 0xe8, 0xfe, 0x83, 0xe1,
		0xe8, 0xf6, 0x36, 0x8c, 0x6e, 0xeb, 0xa3, 0xf1, 0x4c, 0x87, 0x26, 0xc5, 0x5f, 0x7f, 0xf0, 0x58,
		0x00, 0xb7, 0x1f, 0xb8, 0x17, 0x1a, 0xe1, 0xf6, 0x03, 0x93, 0xd0, 0x06, 0xb7, 0x1f, 0x6c, 0x74,
		0x0c, 0xb8, 0xfd, 0x80, 0x6e, 0x1f, 0x6b, 0x03, 0xa4, 0x66, 0x88, 0x54, 0x0c, 0x52, 0x39, 0xa8,
		0x90, 0x58, 0xb7, 0xcf, 0x70, 0x34, 0xf3, 0x6e, 0xc3, 0xdb, 0x0f, 0xef, 0x47, 0x71, 0x7d, 0xce,
		0x41, 0xea, 0x83, 0x0f, 0x7e, 0x74, 0x1b, 0x4c, 0xe4, 0x73, 0x50, 0xff, 0x45, 0xb6, 0xfc, 0x05,
		0xae, 0x33, 0x75, 0x25, 0xe7, 0xa5, 0x6e, 0x5f, 0xf5, 0xec, 0xac, 0x96, 0xbd, 0x55, 0xb7, 0xbb,
		0xea, 0xf6, 0x57, 0xd5, 0x0e, 0xcb, 0x06, 0xe7, 0xa8, 0xf3, 0xfe, 0x06, 0x77, 0x90, 0xfb, 0x5b,
		0x1d, 0x8e, 0x56, 0x39, 0x11, 0xb5, 0x7a, 0x14, 0xe8, 0x60, 0xa8, 0x43, 0x51, 0xa7, 0x9c, 0xa1,
		0x0e, 0xd0, 0x3c, 0x68, 0x1e, 0x34, 0x0f, 0x9a, 0x07, 0xcd, 0x83, 0xe6, 0x41, 0xf3, 0xa0, 0x79,
		0xd0, 0x3c, 0x68, 0x1e, 0x34, 0xcf, 0x0d, 0x9a, 0x47, 0xad, 0x8a, 0xb5, 0x5a, 0xb8, 0xa4, 0x0e,
		0xe6, 0xa5, 0x2a, 0x9d, 0xc5, 0x7a, 0xce, 0xd3, 0xe5, 0x54, 0xa8, 0x52, 0x65, 0xb5, 0xe9, 0xf5,
		0x74, 0x4f, 0x0a, 0xae, 0x54, 0x79, 0x2c, 0xa0, 0xd8, 0x4a, 0x95, 0x5d, 0x2a, 0x55, 0x1c, 0xf6,
		0x6c, 0xa9, 0x54, 0x29, 0x11, 0x8e, 0x14, 0xee, 0x79, 0xae, 0xe8, 0x79, 0xe0, 0xdf, 0xc4, 0xc1,
		0x4d, 0x91, 0x0a, 0xbb, 0xf4, 0x2c, 0x8f, 0x0a, 0x7c, 0x66, 0x2f, 0x85, 0xba, 0x9f, 0x7f, 0x5e,
		0xb8, 0x1f, 0xcf, 0x1f, 0x9b, 0xae, 0x0a, 0x99, 0xfd, 0x79, 0x5b, 0x66, 0x3d, 0x0e, 0x6e, 0x86,
		0xc1, 0x20, 0x19, 0xc5, 0xc5, 0x9b, 0xfd, 0xc7, 0x02, 0x28, 0x50, 0xc4, 0xec, 0x63, 0xf6, 0x1d,
		0x34, 0xfb, 0x14, 0x28, 0x3e, 0xa3, 0x40, 0x51, 0xc9, 0xe0, 0x48, 0x1b, 0x1e, 0x35, 0x03, 0xa4,
		0x66, 0x88, 0x54, 0x0c, 0x52, 0x39, 0xc2, 0x5f, 0x62, 0x99, 0xab, 0x47, 0xae, 0x4a, 0x7d, 0x30,
		0x0c, 0x17, 0x1b, 0x2d, 0x3d, 0x7a, 0xef, 0xf3, 0x72, 0xe5, 0x33, 0x56, 0x37, 0xfe, 0x70, 0x42,
		0xca, 0x4a, 0xdf, 0xb0, 0xea, 0x19, 0x58, 0x2d, 0x43, 0xab, 0x6e, 0x70, 0xd5, 0x0d, 0xaf, 0xaa,
		0x01, 0x96, 0x31, 0xc4, 0x42, 0x06, 0x59, 0x2e, 0x70, 0xf0, 0xe4, 0x79, 0x21, 0x65, 0xa5, 0xf1,
		0x51, 0x3f, 0x03, 0x4c, 0xd3, 0x49, 0x12, 0xc4, 0xf5, 0xf0, 0xda, 0x02, 0x14, 0x33, 0xd9, 0x00,
		0x16, 0x80, 0x05, 0x60, 0x01, 0x58, 0x25, 0x02, 0xac, 0xf8, 0xa1, 0x01, 0xab, 0x27, 0x33, 0xb9,
		0x0a, 0xd8, 0x75, 0x2c, 0x28, 0x23, 0xdd, 0xbb, 0xd2, 0x4f, 0x76, 0x7a, 0x38, 0x3f, 0xf8, 0x45,
		0xa3, 0xa6, 0x30, 0x28, 0x28, 0xfd, 0x3a, 0x47, 0x0a, 0xa2, 0x74, 0xe6, 0x6f, 0xe9, 0x7d, 0xad,
		0xec, 0xc5, 0x34, 0xe7, 0x71, 0x29, 0x39, 0x08, 0x4f, 0x8a, 0x55, 0x1e, 0xbe, 0x94, 0xc9, 0x35,
		0x18, 0xc2, 0x24, 0x6c, 0xf0, 0x3f, 0xaf, 0x4a, 0x8a, 0x73, 0xbb, 0x5c, 0x51, 0xa5, 0xfd, 0xc6,
		0xf1, 0xfe, 0xf1, 0xe1, 0x51, 0xe3, 0xf8, 0x60, 0x8b, 0x74, 0x6a, 0xa7, 0x1a, 0x52, 0xde, 0xed,
		0x94, 0xf8, 0xe4, 0x29, 0x02, 0x7a, 0x38, 0xbe, 0xdf, 0xaf, 0xfb, 0xd7, 0xd7, 0x71, 0x30, 0x99,
		0x28, 0xc2, 0xfa, 0xde, 0x2f, 0x0a, 0xb2, 0x7a, 0x7e, 0x92, 0x04, 0x71, 0xa4, 0x86, 0xec, 0xb5,
		0xff, 0xfb, 0xe1, 0x87, 0xb7, 0xbb, 0xf5, 0xe3, 0x77, 0x7f, 0xbf, 0xdd, 0xab, 0x1f, 0xbf, 0x5b,
		0xfc, 0xb8, 0x37, 0xff, 0x9f, 0xc5, 0xcf, 0x8d, 0xb7, 0xbb, 0xf5, 0xfd, 0xe5, 0xcf, 0x07, 0x6f,
		0x77, 0xeb, 0x07, 0xef, 0x7e, 0xfc, 0xd7, 0xbf, 0x7e, 0xfe, 0xf1, 0x3f, 0x2f, 0x3e, 0x7d, 0xfb,
		0x2f, 0xfe, 0x4f, 0x4d, 0xfe, 0x10, 0x69, 0x7c, 0xa4, 0xf3, 0x7e, 0xfb, 0x77, 0xbe, 0x94, 0xdb,
		0xe6, 0x8e, 0xb9, 0x8c, 0x94, 0xba, 0x1b, 0xd5, 0x36, 0x3f, 0x8a, 0x70, 0xd2, 0xd1, 0x5c, 0x14,
		0xf2, 0xd3, 0xd1, 0x4c, 0x5d, 0xc8, 0x97, 0xbe, 0x26, 0x75, 0x21, 0x95, 0xc3, 0x0a, 0xea, 0x42,
		0x36, 0xdb, 0x3e, 0xea, 0x42, 0xac, 0x0d, 0xeb, 0xff, 0xcf, 0xde, 0xf5, 0xfe, 0xa4, 0xb1, 0x7c,
		0xef, 0xf7, 0xfd, 0x2b, 0xcc, 0xe6, 0xbe, 0xd0, 0xa4, 0xdb, 0x05, 0xe5, 0x87, 0xf6, 0x1d, 0xbd,
		0xda, 0x1b, 0xf2, 0xb1, 0x62, 0xd0, 0xde, 0xdc, 0x6f, 0x2c, 0x97, 0x2c, 0x30, 0xd8, 0x69, 0x71,
		0x96, 0xec, 0x0e, 0x56, 0x53, 0xfd, 0xdf, 0xbf, 0x81, 0x85, 0x55, 0x04, 0x6e, 0x8b, 0xb0, 0x33,
		0xcf, 0xc2, 0x43, 0x9a, 0xb8, 0x45, 0x71, 0x8f, 0x3b, 0xe7, 0x9c, 0xe7, 0x39, 0xcf, 0xcc, 0x9c,
		0x31, 0x97, 0x60, 0x4d, 0x25, 0x5a, 0xe3, 0x09, 0xd7, 0x78, 0xe2, 0x35, 0x9a, 0x80, 0xd3, 0x2d,
		0x5b, 0xb8, 0x2e, 0x64, 0x09, 0x1e, 0xc8, 0x75, 0x21, 0x5c, 0x17, 0x42, 0xc0, 0x22, 0x60, 0x11,
		0xb0, 0x08, 0x58, 0x2b, 0x64, 0x33, 0xae, 0x0b, 0x79, 0xcd, 0x8b, 0xeb, 0x42, 0x56, 0xbb, 0x15,
		0xd7, 0x85, 0x64, 0x87, 0x20, 0x2c, 0xbc, 0x2d, 0xd7, 0x85, 0xa4, 0xeb, 0x4a, 0x5c, 0x17, 0xb2,
		0x1d, 0x3e, 0xc5, 0x75, 0x21, 0xf6, 0x23, 0x8f, 0xeb, 0x42, 0xd6, 0x53, 0xea, 0x71, 0xb5, 0xc1,
		0x8a, 0x41, 0xc4, 0x75, 0x21, 0x5c, 0x17, 0xc2, 0x75, 0x21, 0x5c, 0x17, 0x02, 0xb4, 0x2e, 0x84,
		0x2d, 0x10, 0x6d, 0xbb, 0x05, 0x92, 0x3b, 0x58, 0x6f, 0x81, 0x58, 0x1f, 0xda, 0x53, 0x4f, 0xcc,
		0xd9, 0xa0, 0x5e, 0x58, 0xeb, 0x5d, 0x96, 0x94, 0xca, 0x72, 0xa4, 0xd4, 0xfa, 0x5e, 0xed, 0xb3,
		0xef, 0xd5, 0x3a, 0x39, 0x3f, 0xfb, 0x5e, 0x65, 0x06, 0x33, 0xd6, 0xde, 0xf7, 0xca, 0x1f, 0xe8,
		0xaf, 0x6e, 0xdf, 0x8f, 0xa2, 0xb1, 0x0b, 0xa4, 0xb4, 0xca, 0x71, 0xfa, 0x36, 0xe9, 0xac, 0x76,
		0xcc, 0xb1, 0x0b, 0x16, 0x57, 0x3b, 0x02, 0xa5, 0x25, 0x23, 0xe9, 0x29, 0x1b, 0x15, 0x50, 0x6a,
		0x73, 0x94, 0x53, 0x2b, 0x2d, 0xa4, 0xba, 0x4e, 0x2b, 0xc7, 0x4c, 0x8b, 0x63, 0x5b, 0xb0, 0xea,
		0xbd, 0x23, 0xa2, 0x76, 0x28, 0xfb, 0xa9, 0x14, 0xad, 0xc9, 0xa0, 0x3d, 0xbf, 0x09, 0x31, 0x81,
		0x98, 0x40, 0x4c, 0x20, 0x26, 0xac, 0xb5, 0x96, 0x0d, 0xa5, 0xba, 0x26, 0x12, 0xac, 0xf6, 0xb7,
		0xf6, 0x82, 0xb6, 0xdf, 0x73, 0xfd, 0x28, 0x3d, 0x18, 0x48, 0xee, 0x40, 0x0c, 0x20, 0x06, 0x10,
		0x03, 0x88, 0x01, 0xeb, 0x14, 0x1e, 0x22, 0x57, 0x0d, 0x6e, 0x5a, 0x22, 0x4c, 0x11, 0x06, 0x52,
		0x58, 0x04, 0x97, 0xf2, 0xa2, 0xb7, 0x14, 0x17, 0x8b, 0x9a, 0x58, 0xd4, 0x66, 0x68, 0xe5, 0x91,
		0xa9, 0x45, 0x6b, 0x26, 0x17, 0x14, 0xa5, 0xb8, 0x34, 0xc6, 0xc8, 0x22, 0x34, 0xd3, 0x43, 0x6f,
		0x6a, 0x91, 0x99, 0x51, 0x1f, 0xc8, 0xc8, 0xac, 0x7e, 0x63, 0x0b, 0xd8, 0xf5, 0x68, 0xee, 0x34,
		0x4d, 0x72, 0x3d, 0xb9, 0x01, 0xb9, 0x35, 0xb9, 0x35, 0xb9, 0x35, 0xb9, 0x35, 0xb9, 0x35, 0xb9,
		0x35, 0xb9, 0x35, 0xb9, 0x35, 0xb9, 0x35, 0xb9, 0xf5, 0x36, 0x70, 0xeb, 0x14, 0x4e, 0x09, 0x9e,
		0xcf, 0xb1, 0xd7, 0x7e, 0x5a, 0x30, 0xb9, 0x36, 0xb9, 0x36, 0xb9, 0x36, 0xb9, 0x36, 0xe7, 0x32,
		0xd7, 0x8b, 0x08, 0x3a, 0x8d, 0xc1, 0x9a, 0xc6, 0x82, 0x14, 0x7a, 0x23, 0x10, 0x05, 0x88, 0x02,
		0x44, 0x81, 0x2d, 0x47, 0x81, 0xb4, 0x92, 0xcb, 0x14, 0x10, 0x14, 0x52, 0xf8, 0xdd, 0x27, 0x6a,
		0x70, 0x33, 0x7c, 0x34, 0x8f, 0x5b, 0x00, 0x32, 0xa1, 0xb8, 0x09, 0x6e, 0x85, 0xdb, 0x0f, 0xe5,
		0xad, 0xaf, 0x45, 0xaa, 0xe2, 0xfe, 0xec, 0xad, 0x08, 0x3a, 0x04, 0x1d, 0x82, 0x0e, 0x41, 0x27,
		0xcd, 0x24, 0xe3, 0x06, 0x69, 0x2c, 0xd9, 0x9e, 0xc2, 0xa0, 0x14, 0x14, 0x41, 0xa7, 0xda, 0x11,
		0x4a, 0x4b, 0x7d, 0xff, 0xc1, 0x8f, 0x44, 0xfa, 0xad, 0x1f, 0xeb, 0x27, 0x9f, 0x6a, 0x7f, 0x9f,
		0x34, 0xcf, 0xeb, 0xd5, 0xbf, 0x2b, 0x97, 0x27, 0xcd, 0xca, 0x45, 0xb3, 0x76, 0x7e, 0x59, 0xad,
		0x9d, 0xa5, 0x15, 0x72, 0x23, 0x51, 0x35, 0x4a, 0xb5, 0x45, 0x43, 0xca, 0xea, 0xf3, 0xe4, 0xc9,
		0x3d, 0x7b, 0x64, 0xe3, 0x87, 0x58, 0x39, 0x3d, 0x75, 0xb2, 0xa8, 0xda, 0xdb, 0x78, 0x60, 0xe7,
		0xa7, 0x95, 0x3f, 0xd3, 0x7e, 0x62, 0xa9, 0xfc, 0xe6, 0x06, 0x7a, 0xe2, 0xc6, 0x24, 0x9b, 0xa3,
		0x0d, 0xf7, 0xdd, 0x9e, 0xdf, 0x77, 0x3b, 0xfe, 0x4d, 0x5f, 0xaa, 0xeb, 0x14, 0xd9, 0xe6, 0xec,
		0xbd, 0xd6, 0xdd, 0x15, 0x3f, 0xdd, 0xb6, 0xee, 0xa4, 0xb3, 0xa4, 0xb3, 0xa4, 0xb3, 0x5b, 0x4e,
		0x67, 0xd3, 0x6b, 0xbb, 0x9e, 0x52, 0xbb, 0x75, 0xd0, 0x63, 0x91, 0x84, 0xea, 0xb8, 0xed, 0xe0,
		0xe6, 0x66, 0xa0, 0xa4, 0xbe, 0x4f, 0xf1, 0x7c, 0xa4, 0xe9, 0xfb, 0xa4, 0x07, 0x38, 0x67, 0xb5,
		0xb3, 0x13, 0xe2, 0x0d, 0xf1, 0x86, 0x78, 0x43, 0xbc, 0x59, 0xa7, 0xbf, 0x27, 0xb9, 0x8b, 0xc2,
		0x3d, 0x38, 0xa4, 0xe9, 0x40, 0xfb, 0x3d, 0xb7, 0xef, 0xeb, 0xaf, 0x29, 0x4a, 0xf6, 0xcf, 0x6f,
		0x42, 0xb4, 0x21, 0xda, 0x10, 0x6d, 0x88, 0x36, 0x6b, 0xf4, 0xf7, 0xd4, 0x4e, 0x80, 0xe0, 0x82,
		0xfc, 0x39, 0x86, 0x73, 0x41, 0xfe, 0xf2, 0xf7, 0xe1, 0x82, 0x7c, 0xd8, 0xa1, 0xe7, 0x82, 0x7c,
		0x7b, 0xbf, 0xb5, 0xb1, 0x3d, 0x04, 0x7b, 0xc4, 0x66, 0x44, 0xfa, 0x1c, 0x7b, 0x72, 0x1f, 0xd2,
		0x6c, 0xd2, 0x6c, 0xd2, 0x6c, 0xd2, 0x6c, 0xd2, 0x6c, 0xd2, 0x6c, 0xd2, 0x6c, 0xd2, 0x6c, 0xd2,
		0x6c, 0xd2, 0x6c, 0x38, 0x9a, 0xcd, 0xa3, 0x49, 0x52, 0x3e, 0x9a, 0x64, 0x8d, 0x27, 0xd3, 0x60,
		0x9c, 0x00, 0xa2, 0xe5, 0x8d, 0x08, 0xa3, 0xf5, 0x1f, 0x01, 0x32, 0xfe, 0xbd, 0xe0, 0x67, 0x80,
		0xe4, 0x78, 0x06, 0x48, 0x86, 0xaa, 0x20, 0x9e, 0x01, 0x02, 0x7c, 0x06, 0x48, 0x7b, 0x12, 0x53,
		0x29, 0xc9, 0x31, 0xe3, 0xdf, 0x9f, 0x8e, 0x0c, 0x93, 0xa7, 0x0c, 0x43, 0x19, 0x86, 0x32, 0x0c,
		0xa2, 0x0c, 0xb3, 0xee, 0x44, 0xf5, 0x3c, 0x61, 0x29, 0xd1, 0xd6, 0x6e, 0x28, 0x74, 0x78, 0x9f,
		0xfe, 0x56, 0x9e, 0xe9, 0xdb, 0xa5, 0xe4, 0x2e, 0xcf, 0x56, 0x22, 0x1e, 0xe4, 0xd2, 0xba, 0x49,
		0xba, 0x85, 0x6e, 0x6a, 0xb9, 0xd3, 0x44, 0x0e, 0x35, 0x97, 0x4b, 0x4d, 0xe5, 0x54, 0xe3, 0xb9,
		0xd5, 0x78, 0x8e, 0x35, 0x9a, 0x6b, 0x53, 0x56, 0x3a, 0x52, 0x8a, 0x98, 0xd4, 0xa4, 0xf0, 0x99,
		0x78, 0xe9, 0x88, 0xb6, 0xbc, 0xf1, 0x7b, 0xa5, 0x42, 0x9a, 0x21, 0x33, 0x21, 0x7d, 0xfb, 0x29,
		0xde, 0x63, 0x46, 0x35, 0x4b, 0xf3, 0x66, 0xe9, 0x6a, 0xf2, 0x93, 0x97, 0x81, 0x13, 0xeb, 0x4d,
		0x68, 0xf4, 0x2f, 0xdd, 0x60, 0xff, 0xad, 0x99, 0xdb, 0x19, 0xd2, 0xec, 0x17, 0x7b, 0x60, 0x2e,
		0xf5, 0xfb, 0x3e, 0x1a, 0x38, 0x4b, 0xde, 0x84, 0x96, 0xff, 0xd2, 0x45, 0x0e, 0xe8, 0x22, 0xd8,
		0xc0, 0x97, 0xfe, 0x6f, 0xcf, 0xcc, 0x21, 0xf6, 0x29, 0x94, 0xed, 0x5f, 0x83, 0x5e, 0xc7, 0xd5,
		0xf2, 0xc6, 0x40, 0xc3, 0x83, 0xa7, 0x5b, 0xa5, 0x5f, 0x21, 0x1d, 0xb1, 0x42, 0x62, 0x85, 0xc4,
		0x0a, 0x89, 0x15, 0x12, 0x2b, 0x24, 0x56, 0x48, 0xac, 0x90, 0x58, 0x21, 0xb1, 0x42, 0x62, 0x85,
		0xc4, 0x0a, 0x89, 0x15, 0xd2, 0xf2, 0x6e, 0xf2, 0x5d, 0x88, 0xbe, 0xdf, 0x93, 0xb7, 0xc2, 0x95,
		0x4a, 0x8b, 0xf0, 0xd6, 0xef, 0xa5, 0x5f, 0x2a, 0xcd, 0xb9, 0x27, 0x67, 0x95, 0x58, 0x33, 0xb1,
		0x66, 0x62, 0xcd, 0xc4, 0x9a, 0x89, 0x35, 0x13, 0x6b, 0x26, 0xd6, 0x4c, 0xac, 0x99, 0x58, 0x33,
		0xb1, 0x66, 0x62, 0xcd, 0x04, 0x59, 0x33, 0xdd, 0x48, 0x25, 0x6f, 0x06, 0x37, 0xae, 0xdf, 0xb9,
		0x15, 0xa1, 0x96, 0x91, 0x18, 0xb2, 0x24, 0x83, 0xf5, 0xd3, 0x2f, 0xee, 0xcf, 0x5a, 0x8a, 0xb5,
		0x14, 0x6b, 0x29, 0xd6, 0x52, 0xac, 0xa5, 0x58, 0x4b, 0xb1, 0x96, 0x62, 0x2d, 0xc5, 0x5a, 0x8a,
		0xb5, 0x14, 0x6b, 0x29, 0xd6, 0x52, 0x60, 0xbf, 0x71, 0xdd, 0xdb, 0xad, 0x52, 0xda, 0xb4, 0x9f,
		0xfc, 0x7e, 0x9b, 0x9b, 0xf7, 0xe3, 0x3d, 0xe9, 0xde, 0x78, 0x27, 0xe9, 0x36, 0xb4, 0xd7, 0x1f,
		0x75, 0x2b, 0x48, 0xaf, 0xab, 0xfe, 0xe8, 0xd7, 0x67, 0x6c, 0x47, 0xee, 0x3e, 0x77, 0xe4, 0x9a,
		0xab, 0x4d, 0xb9, 0x23, 0x77, 0x03, 0x21, 0x82, 0x3b, 0x72, 0x97, 0x79, 0x58, 0xd4, 0xfb, 0xac,
		0xe6, 0x50, 0x73, 0xb9, 0xd4, 0x54, 0x4e, 0x35, 0x9e, 0x5b, 0x8d, 0xe7, 0x58, 0xa3, 0xb9, 0x36,
		0xdd, 0xc2, 0x84, 0x7a, 0xdf, 0x52, 0xa4, 0x8f, 0x7a, 0xdf, 0x52, 0x2f, 0xea, 0x7d, 0x14, 0x73,
		0xac, 0xe4, 0x9f, 0x69, 0x17, 0xa1, 0xde, 0x97, 0x69, 0x17, 0xa1, 0xde, 0x97, 0xaa, 0xbd, 0xdc,
		0x91, 0xfb, 0xdb, 0x15, 0x12, 0x77, 0xe4, 0xb2, 0x42, 0x62, 0x85, 0xc4, 0x0a, 0x89, 0x15, 0x12,
		0x2b, 0x24, 0x56, 0x48, 0xac, 0x90, 0x58, 0x21, 0xb1, 0x42, 0x62, 0x85, 0xc4, 0x0a, 0xe9, 0x15,
		0x6e, 0xc2, 0x1d, 0xb9, 0xac, 0x99, 0x58, 0x33, 0xb1, 0x66, 0x62, 0xcd, 0xc4, 0x9a, 0x89, 0x35,
		0x13, 0x6b, 0x26, 0xd6, 0x4c, 0xac, 0x99, 0x58, 0x33, 0xb1, 0x66, 0x62, 0xcd, 0xb4, 0xd8, 0x4d,
		0xb8, 0x23, 0x97, 0xb5, 0x14, 0x6b, 0x29, 0xd6, 0x52, 0xac, 0xa5, 0x58, 0x4b, 0xb1, 0x96, 0x62,
		0x2d, 0xc5, 0x5a, 0x8a, 0xb5, 0x14, 0x6b, 0x29, 0xd6, 0x52, 0x1b, 0x5f, 0x4b, 0x71, 0x47, 0xae,
		0xdd, 0x1d, 0xb9, 0x6b, 0x3c, 0x55, 0x7b, 0xfd, 0x63, 0xca, 0x43, 0xd5, 0xcd, 0x78, 0x81, 0xb3,
		0xd6, 0x8d, 0xcf, 0xe1, 0xa0, 0xad, 0xd5, 0x98, 0x20, 0x9f, 0xc5, 0xe6, 0x55, 0xc7, 0xd6, 0x35,
		0xcf, 0xc7, 0x36, 0x35, 0x3f, 0x5c, 0xf7, 0x9b, 0xe7, 0x42, 0x84, 0x7f, 0x0d, 0xcd, 0x68, 0x5e,
		0xc6, 0x66, 0x6c, 0xd2, 0xe1, 0xee, 0xa1, 0xaf, 0xa2, 0x7e, 0x10, 0xea, 0x14, 0xce, 0x77, 0x4f,
		0x7e, 0x35, 0x8f, 0x78, 0xc7, 0x53, 0x3c, 0x78, 0xc4, 0xbb, 0x15, 0xc5, 0x82, 0x47, 0xbc, 0xaf,
		0x14, 0x06, 0x3c, 0xe2, 0x9d, 0x0d, 0x25, 0x6c, 0x27, 0x20, 0x63, 0x89, 0xc8, 0x48, 0x42, 0xca,
		0x46, 0x85, 0x93, 0x5a, 0x43, 0x89, 0x5e, 0xd0, 0xf6, 0x7b, 0xae, 0xdf, 0xe9, 0x84, 0x22, 0x8a,
		0xd2, 0x9f, 0xbf, 0x9a, 0xbe, 0x1d, 0x67, 0x92, 0x4c, 0xa7, 0x37, 0x73, 0x69, 0xce, 0x54, 0xba,
		0x33, 0x9e, 0xf6, 0x8c, 0xa7, 0x3f, 0xa3, 0x69, 0x30, 0x5d, 0xc9, 0x2b, 0xfb, 0x33, 0x49, 0x03,
		0x25, 0x03, 0x65, 0x62, 0x16, 0xe9, 0x28, 0xc5, 0x7b, 0x8c, 0x1f, 0x57, 0xe6, 0xe7, 0x75, 0x26,
		0x83, 0x22, 0xfb, 0x29, 0x43, 0x8a, 0xe9, 0x11, 0x32, 0x3b, 0x52, 0xe6, 0x46, 0x6c, 0xce, 0xc8,
		0xdd, 0x16, 0x0c, 0x8e, 0xdd, 0xcc, 0x18, 0x1e, 0x1a, 0xbc, 0xe7, 0xb9, 0xaf, 0xb5, 0x08, 0x95,
		0xb1, 0xe1, 0x4c, 0x6e, 0xfc, 0xef, 0xee, 0xee, 0x55, 0xce, 0x3d, 0x6a, 0x3c, 0x5c, 0xe5, 0xdd,
		0xa3, 0x46, 0x7c, 0x99, 0x1f, 0x7d, 0x89, 0xaf, 0xf7, 0xaf, 0x72, 0x6e, 0x61, 0x72, 0x5d, 0xbc,
		0xca, 0xb9, 0xc5, 0xc6, 0xde, 0x97, 0x2f, 0xef, 0xf6, 0x7e, 0x1e, 0x3c, 0x2e, 0xff, 0xc1, 0x3f,
		0x1c, 0x63, 0x7f, 0x5c, 0xc3, 0xe4, 0xe0, 0xd5, 0x2e, 0xaa, 0xff, 0x70, 0x04, 0xd7, 0x3d, 0x82,
		0x46, 0xee, 0xf4, 0xf8, 0x76, 0x83, 0xd3, 0x67, 0x89, 0xe9, 0xd3, 0x4c, 0xf0, 0xf9, 0x6e, 0xb7,
		0xe2, 0x7e, 0x6c, 0xfc, 0xcc, 0xbf, 0x2d, 0x3c, 0xbe, 0xdf, 0xfb, 0x59, 0x7e, 0x7c, 0xf9, 0xe6,
		0xc3, 0xbc, 0x1f, 0xcb, 0xbf, 0x2d, 0x3f, 0xbe, 0x5f, 0xf0, 0x9d, 0xd2, 0xe3, 0xfb, 0xdf, 0xfc,
		0x1d, 0xc5, 0xc7, 0xdd, 0x99, 0x1f, 0x1d, 0xbe, 0xbf, 0xbf, 0xe8, 0x03, 0x85, 0x05, 0x1f, 0x38,
		0x58, 0xf4, 0x81, 0x83, 0x05, 0x1f, 0x58, 0x68, 0xd2, 0xfe, 0x82, 0x0f, 0x14, 0x1f, 0x1f, 0x66,
		0x7e, 0x7e, 0x77, 0xfe, 0x8f, 0x96, 0x1e, 0xf7, 0x1e, 0x16, 0x7d, 0xaf, 0xfc, 0xf8, 0xf0, 0x7e,
		0x8f, 0x60, 0x42, 0x7f, 0xa6, 0x3f, 0x43, 0x43, 0xeb, 0x9b, 0x6c, 0xff, 0x1d, 0x29, 0x53, 0x03,
		0x83, 0x35, 0x70, 0xa4, 0x43, 0xa9, 0xae, 0x4d, 0xd6, 0xbf, 0x87, 0x5c, 0x73, 0x95, 0xaa, 0xbd,
		0xa9, 0xec, 0x5f, 0xd1, 0x03, 0xb7, 0x23, 0xa3, 0x76, 0x70, 0x2b, 0x4c, 0xf4, 0x8f, 0x9e, 0xbe,
		0x5d, 0xfa, 0xbb, 0x53, 0xba, 0x7e, 0x2f, 0x12, 0x9c, 0x56, 0x58, 0xc0, 0x3a, 0x38, 0xad, 0xf0,
		0x9a, 0x51, 0xe7, 0xb4, 0x02, 0x7c, 0x56, 0xcf, 0xfe, 0xb4, 0x42, 0x2b, 0x08, 0x7a, 0xc2, 0x37,
		0x32, 0xb1, 0x90, 0xdf, 0x62, 0xf8, 0xeb, 0xfb, 0x51, 0x24, 0x6f, 0x85, 0x7b, 0x13, 0x74, 0x0c,
		0xf4, 0x05, 0x9d, 0xba, 0x1b, 0xc1, 0x8f, 0xe0, 0x47, 0xf0, 0x23, 0xf8, 0x11, 0xfc, 0x08, 0x7e,
		0x76, 0xc0, 0x4f, 0xb7, 0xfb, 0xee, 0x8d, 0x89, 0x45, 0x5e, 0x93, 0x1b, 0x11, 0x8a, 0x08, 0x45,
		0x84, 0x22, 0x42, 0x51, 0x86, 0xa0, 0x68, 0x20, 0x95, 0xce, 0x97, 0x0c, 0x20, 0x51, 0x89, 0xfb,
		0xf6, 0x7f, 0xfd, 0x87, 0xd8, 0xd8, 0xb7, 0x9f, 0xe3, 0xa6, 0x6c, 0xf0, 0x74, 0x30, 0xed, 0x22,
		0x16, 0xf6, 0xed, 0x9b, 0x76, 0x91, 0x52, 0xb1, 0x78, 0x50, 0xe4, 0xde, 0x7d, 0xb4, 0xdf, 0xce,
		0xbd, 0xfb, 0x6b, 0x61, 0x3d, 0x9b, 0xbc, 0x77, 0x7f, 0xb2, 0x03, 0x98, 0x07, 0x6a, 0xaf, 0x8b,
		0xa0, 0xf1, 0x40, 0x6d, 0xee, 0x7f, 0x04, 0xa9, 0x14, 0xb9, 0xff, 0xd1, 0x1c, 0x4a, 0x70, 0xff,
		0x23, 0x05, 0x32, 0x0a, 0x64, 0x14, 0xc8, 0x28, 0x90, 0xd9, 0x16, 0xc8, 0xb8, 0xff, 0x11, 0x47,
		0x1f, 0xe3, 0xfe, 0xc7, 0x8c, 0x8d, 0xd8, 0x9c, 0x91, 0xe3, 0xfe, 0xc7, 0xd4, 0x6f, 0xcc, 0xfd,
		0x8f, 0x6b, 0x18, 0x3c, 0xee, 0x7f, 0x4c, 0x63, 0x04, 0xb9, 0xff, 0x71, 0xd5, 0xf4, 0xc9, 0xfd,
		0x8f, 0x86, 0x82, 0x8f, 0xfb, 0xc5, 0xb8, 0xff, 0x71, 0x93, 0xc0, 0x84, 0xfe, 0xcc, 0xfd, 0x8f,
		0xa0, 0x32, 0x81, 0xb9, 0xbf, 0x83, 0xfb, 0x1f, 0x57, 0x00, 0x7f, 0xce, 0x5b, 0xa7, 0x6a, 0x2f,
		0xf7, 0x3f, 0xfe, 0xde, 0xcd, 0xb8, 0x05, 0xe4, 0x37, 0x59, 0x07, 0xa7, 0x15, 0x5e, 0x33, 0xea,
		0x9c, 0x56, 0x80, 0xcf, 0xea, 0xdc, 0x02, 0xb2, 0x04, 0x6c, 0x73, 0xff, 0x23, 0xf7, 0x3f, 0x12,
		0xfc, 0x08, 0x7e, 0x04, 0x3f, 0x82, 0x1f, 0xc1, 0x6f, 0x8b, 0xc0, 0x8f, 0xfb, 0x1f, 0x09, 0x45,
		0x84, 0x22, 0x42, 0x11, 0xa1, 0x68, 0x71, 0xbc, 0x70, 0xff, 0xe3, 0x6f, 0xbf, 0xb8, 0xff, 0x71,
		0xa5, 0xdb, 0x71, 0xff, 0xe3, 0x7a, 0x5c, 0x84, 0xfb, 0x1f, 0x33, 0xef, 0x26, 0x9c, 0x47, 0x4a,
		0xb7, 0x96, 0xe0, 0xfe, 0x47, 0xeb, 0xfb, 0x1f, 0x79, 0x7c, 0xb1, 0x6d, 0x87, 0xc0, 0x70, 0x04,
		0xfb, 0x27, 0x18, 0x27, 0x96, 0x6c, 0xd0, 0x21, 0xc6, 0x83, 0x48, 0xb8, 0x37, 0x83, 0x9e, 0x96,
		0xfd, 0x9e, 0x70, 0x87, 0x23, 0x1c, 0xad, 0xff, 0x34, 0xe3, 0x39, 0xf7, 0xe0, 0xb1, 0xc6, 0x78,
		0xfa, 0x04, 0x8f, 0x35, 0xb6, 0xa2, 0x2f, 0xf0, 0x58, 0xe3, 0x95, 0xc2, 0x80, 0xc7, 0x1a, 0x73,
		0x5b, 0xbf, 0xed, 0x04, 0x64, 0x2c, 0x11, 0x19, 0x49, 0x48, 0xd9, 0x28, 0x7e, 0x52, 0xdb, 0xd6,
		0x2f, 0x94, 0xdf, 0xea, 0x89, 0x4e, 0xfa, 0x73, 0x3d, 0x93, 0x1b, 0x71, 0x79, 0x83, 0x8d, 0x94,
		0x69, 0x22, 0x75, 0x9a, 0x4b, 0xa1, 0xa6, 0x52, 0xa9, 0xf1, 0x94, 0x6a, 0x3c, 0xb5, 0x1a, 0x4d,
		0xb1, 0xe9, 0x2a, 0x6d, 0x5c, 0xde, 0xb0, 0x04, 0xd3, 0xcb, 0x53, 0x92, 0xc4, 0x55, 0xa0, 0x20,
		0x94, 0xa8, 0x59, 0x19, 0x63, 0x8b, 0x7a, 0xb3, 0x89, 0x61, 0xfe, 0x4b, 0xad, 0x88, 0x13, 0xeb,
		0x47, 0x45, 0x96, 0x70, 0x2c, 0xe1, 0x58, 0xc2, 0x6d, 0x67, 0x09, 0x97, 0x92, 0xe6, 0x64, 0x46,
		0x7b, 0x4a, 0x39, 0x81, 0xb1, 0xb0, 0x62, 0x61, 0xc5, 0xc2, 0x0a, 0xb3, 0xb0, 0x4a, 0x2b, 0x21,
		0x26, 0x37, 0xf0, 0x7b, 0xbd, 0xe0, 0xc7, 0x13, 0x89, 0xf5, 0xa3, 0xf4, 0xfd, 0x79, 0x12, 0xa1,
		0xb3, 0xb7, 0x4e, 0xd9, 0xcd, 0x0c, 0xe9, 0x5f, 0x86, 0x74, 0x30, 0x63, 0x69, 0xdb, 0x64, 0xfa,
		0x36, 0x9f, 0xc6, 0x4d, 0xa7, 0x73, 0x6b, 0x69, 0xdd, 0x5a, 0x7a, 0xb7, 0x92, 0xe6, 0xd3, 0x4d,
		0xf7, 0x29, 0xa7, 0x7d, 0x73, 0xba, 0x9a, 0x05, 0x7d, 0xcd, 0x90, 0xce, 0x96, 0xbe, 0x03, 0xa4,
		0x38, 0xf8, 0xce, 0x8d, 0x7f, 0x27, 0x6f, 0x06, 0x37, 0x6b, 0x5e, 0x7f, 0xf3, 0xcb, 0xd1, 0x9f,
		0xbe, 0xad, 0x39, 0x38, 0xce, 0x13, 0x8a, 0x09, 0xc5, 0x84, 0x62, 0x42, 0x31, 0xa1, 0x78, 0x7a,
		0xfb, 0xd4, 0xc1, 0xbe, 0x41, 0x24, 0x2e, 0x1b, 0xb8, 0x95, 0x99, 0xed, 0x54, 0x93, 0x97, 0xc1,
		0x2e, 0xa2, 0x26, 0xb7, 0x57, 0x19, 0x86, 0xb5, 0x99, 0xdb, 0x1a, 0xde, 0x6e, 0x95, 0xdc, 0xd7,
		0xc2, 0x7e, 0x1a, 0x43, 0xe9, 0x65, 0xda, 0x95, 0x0c, 0x6e, 0xc3, 0x42, 0x71, 0xa5, 0xc2, 0xfe,
		0x51, 0xe1, 0xa8, 0x54, 0xde, 0x3f, 0x2a, 0x6e, 0x91, 0x4f, 0xb1, 0xab, 0xa4, 0xdd, 0x02, 0x2e,
		0x53, 0x52, 0x70, 0xca, 0x0b, 0x29, 0x92, 0xfb, 0x80, 0x2d, 0xa8, 0x10, 0xc3, 0x1f, 0x4f, 0x63,
		0x55, 0x45, 0x7a, 0x5e, 0x90, 0x46, 0xbf, 0x91, 0x74, 0x4e, 0xc2, 0x9b, 0xe1, 0x9c, 0x69, 0x9c,
		0x88, 0x37, 0x23, 0xf8, 0xa4, 0x3d, 0x7d, 0xb9, 0xcf, 0xe9, 0x4b, 0x9c, 0x22, 0x9b, 0xd3, 0x97,
		0x5b, 0x8c, 0x59, 0x9c, 0xbe, 0x5c, 0xe7, 0xc3, 0xe4, 0xf4, 0x25, 0x7a, 0xfa, 0x36, 0x9f, 0xc6,
		0x4d, 0xa7, 0x73, 0x6b, 0x69, 0xdd, 0x5a, 0x7a, 0xb7, 0x92, 0xe6, 0xcd, 0x14, 0x6f, 0x9c, 0xbe,
		0x5c, 0x03, 0x9b, 0xe5, 0xf4, 0xe5, 0xec, 0xb3, 0xe1, 0xf4, 0x25, 0xa1, 0x98, 0x50, 0x4c, 0x28,
		0x26, 0x14, 0x6f, 0x2f, 0x14, 0x73, 0xfa, 0x72, 0xe5, 0x17, 0xa7, 0x2f, 0x53, 0xb9, 0x2d, 0xa7,
		0x2f, 0xd3, 0x75, 0x25, 0x4e, 0x5f, 0x6e, 0x87, 0x4f, 0x71, 0xfa, 0xd2, 0x6e, 0x01, 0xc7, 0xe9,
		0xcb, 0x39, 0xf7, 0x41, 0x9c, 0xbe, 0x4c, 0xa1, 0x61, 0x65, 0x7a, 0x4e, 0xc0, 0x76, 0x02, 0x60,
		0xee, 0xe3, 0xa4, 0x32, 0x9d, 0xfc, 0x8a, 0x76, 0x97, 0x9f, 0x23, 0xf1, 0x69, 0x6c, 0xde, 0xf9,
		0xd0, 0xba, 0xe6, 0xc9, 0xda, 0x0b, 0x2f, 0xcc, 0x56, 0x07, 0x32, 0xd5, 0x56, 0x07, 0x92, 0xad,
		0x0e, 0xd8, 0xea, 0x00, 0x42, 0xe0, 0x61, 0xab, 0x03, 0x73, 0x40, 0xc6, 0x56, 0x07, 0x16, 0x12,
		0x58, 0xea, 0x89, 0xcc, 0x44, 0x42, 0x33, 0x97, 0xd8, 0x4c, 0x25, 0x38, 0xe3, 0x89, 0xce, 0x78,
		0xc2, 0x33, 0x9a, 0xf8, 0xb2, 0x59, 0x20, 0xa6, 0xbe, 0x56, 0x88, 0x93, 0x92, 0x59, 0x94, 0xdc,
		0x38, 0x29, 0x99, 0xa9, 0x14, 0x6e, 0x2d, 0x95, 0x5b, 0x4b, 0xe9, 0x56, 0x52, 0x7b, 0xba, 0x29,
		0x3e, 0xe5, 0x54, 0x9f, 0x3c, 0x31, 0x4e, 0x4a, 0xae, 0xe5, 0x56, 0x9c, 0x94, 0xcc, 0x1e, 0xac,
		0xcd, 0xdc, 0x96, 0x93, 0x92, 0xe9, 0xba, 0x12, 0x27, 0x25, 0xb7, 0xc3, 0xa7, 0x38, 0x29, 0x69,
		0xd5, 0x7e, 0x4e, 0x4a, 0xce, 0xbb, 0x0f, 0xd8, 0xac, 0x92, 0xe4, 0x9e, 0x4a, 0xee, 0xa9, 0x5c,
		0xae, 0xf8, 0xe6, 0x9e, 0x4a, 0xa0, 0x22, 0x9b, 0x3a, 0xe9, 0x16, 0x63, 0x16, 0x75, 0xd2, 0x75,
		0x3c, 0x44, 0xea, 0xa4, 0xc8, 0x29, 0xdb, 0x7c, 0xea, 0x36, 0x9d, 0xc2, 0xad, 0xa5, 0x72, 0x6b,
		0x29, 0xdd, 0x4a, 0x6a, 0x37, 0x53, 0xb0, 0x51, 0x27, 0x5d, 0x39, 0x3b, 0x52, 0x27, 0x5d, 0x45,
		0xdc, 0xa2, 0x4e, 0xba, 0xd1, 0x9a, 0x16, 0x75, 0xd2, 0x54, 0x5d, 0x89, 0x3a, 0x69, 0x76, 0xef,
		0x42, 0x9d, 0xd4, 0x44, 0xcd, 0xb9, 0xcd, 0x3a, 0x29, 0x37, 0x6f, 0x64, 0xc5, 0x8d, 0x10, 0xdd,
		0x07, 0x77, 0xf3, 0x46, 0x75, 0x4b, 0x36, 0x6f, 0xa4, 0xa3, 0xf2, 0xa7, 0xaa, 0xee, 0xa7, 0xbe,
		0x7d, 0x63, 0x9f, 0xdb, 0x37, 0xcc, 0x49, 0x3e, 0xdc, 0xbe, 0xb1, 0x81, 0x50, 0x96, 0xda, 0xf6,
		0x0d, 0xa1, 0xfc, 0x56, 0x4f, 0x74, 0xd2, 0x9f, 0x96, 0x9c, 0xdc, 0x28, 0xad, 0x69, 0x0a, 0x33,
		0xdd, 0x0a, 0x53, 0xae, 0x1d, 0xb9, 0x51, 0x04, 0x2a, 0x95, 0x1a, 0x4f, 0xa9, 0xc6, 0x53, 0xab,
		0xd1, 0x14, 0x9b, 0xcd, 0x62, 0x34, 0x75, 0x35, 0xdc, 0x60, 0x37, 0xc1, 0x94, 0xbb, 0x08, 0xb2,
		0xc0, 0xdc, 0xe8, 0x02, 0x33, 0x05, 0x69, 0x62, 0x8d, 0x35, 0xdc, 0x1b, 0x20, 0x0f, 0x49, 0xcb,
		0x33, 0xc0, 0x3c, 0xc2, 0x59, 0x6b, 0xdd, 0xbc, 0x06, 0x95, 0x61, 0x3d, 0xce, 0xb9, 0xba, 0x2b,
		0xad, 0xf6, 0x1b, 0x56, 0x74, 0xc2, 0x21, 0x5b, 0x19, 0x31, 0x95, 0x64, 0xe8, 0xdc, 0xd1, 0x63,
		0x5d, 0xf1, 0xb7, 0x9e, 0xca, 0x48, 0x57, 0xb4, 0x5e, 0x4f, 0x1d, 0xe2, 0x7c, 0x92, 0xea, 0xa4,
		0x27, 0x86, 0x8c, 0x23, 0x5a, 0x0f, 0xdb, 0x75, 0x3e, 0xf9, 0x77, 0xcf, 0x7e, 0x63, 0xfe, 0xb0,
		0x50, 0x28, 0x95, 0x0b, 0x85, 0x5c, 0xf9, 0xa0, 0x9c, 0x3b, 0x2a, 0x16, 0xf3, 0xa5, 0xfc, 0x1a,
		0xa6, 0x5b, 0x9c, 0x5a, 0xd8, 0x11, 0xa1, 0xe8, 0x7c, 0x18, 0x3e, 0x60, 0x35, 0xe8, 0xf5, 0xac,
		0x8e, 0xf3, 0x9a, 0x93, 0x8c, 0xcd, 0xe4, 0xb2, 0x86, 0x4c, 0xf2, 0xaa, 0x0c, 0xb2, 0x5a, 0xc2,
		0x78, 0x7d, 0x98, 0xbf, 0xee, 0x93, 0xaf, 0x74, 0x98, 0x75, 0x39, 0x8a, 0x71, 0x07, 0x79, 0xdd,
		0xe8, 0x2c, 0xff, 0x6c, 0x5f, 0xf1, 0x5c, 0x9d, 0x50, 0xb6, 0x5e, 0xfd, 0x30, 0x13, 0xc6, 0x3f,
		0xfc, 0x25, 0xaf, 0x1c, 0xd3, 0xd5, 0x34, 0xdb, 0x95, 0xb5, 0xd9, 0x75, 0x08, 0x09, 0xcf, 0x85,
		0x82, 0x50, 0xb6, 0x56, 0x14, 0x0b, 0xd6, 0x25, 0x06, 0xac, 0xbd, 0xd8, 0x5f, 0x7b, 0x31, 0xff,
		0xb2, 0x58, 0x9f, 0x3c, 0xbb, 0x8c, 0x64, 0xa3, 0x55, 0xb5, 0x4c, 0xc7, 0xef, 0x4a, 0x37, 0xf2,
		0xbb, 0x72, 0xf5, 0xd5, 0xc2, 0x4f, 0xa7, 0xab, 0x24, 0xbf, 0x72, 0x55, 0xee, 0xb5, 0x96, 0xa9,
		0x94, 0xb5, 0x4d, 0x9d, 0xac, 0x53, 0xef, 0x5b, 0x6f, 0xb8, 0xa6, 0xa5, 0xe1, 0xa5, 0xa6, 0xd5,
		0xa5, 0xa6, 0xc9, 0xad, 0x3d, 0x9c, 0x31, 0xaa, 0x90, 0x75, 0x4d, 0x59, 0x24, 0xb1, 0xb9, 0x3e,
		0x17, 0x79, 0x19, 0xf5, 0xeb, 0xf2, 0x90, 0xf5, 0xce, 0xa3, 0xae, 0x7d, 0x32, 0x20, 0x0d, 0xf1,
		0x3f, 0x9d, 0xa4, 0x90, 0x56, 0x72, 0x48, 0x3d, 0x49, 0xa4, 0x9e, 0x2c, 0x52, 0x4f, 0x1a, 0x98,
		0x7a, 0xda, 0xba, 0xe7, 0x3f, 0x93, 0xd0, 0x77, 0xc7, 0xf5, 0x62, 0x4a, 0xcb, 0x35, 0xa6, 0x6f,
		0x93, 0xce, 0xb2, 0x8d, 0x1c, 0xbb, 0x6e, 0xa6, 0x9c, 0x86, 0xd2, 0x4e, 0x47, 0xc6, 0xd2, 0x92,
		0xb1, 0xf4, 0x64, 0x2c, 0x4d, 0xad, 0x37, 0x5d, 0xad, 0x39, 0x6d, 0x25, 0x4f, 0x21, 0xb5, 0x39,
		0xc4, 0xc4, 0xef, 0x7b, 0xc2, 0xef, 0x86, 0xa2, 0x9b, 0x86, 0xd3, 0x4f, 0x58, 0x4d, 0x0a, 0x7b,
		0x66, 0x9c, 0xf3, 0xb1, 0x96, 0xf4, 0xee, 0x5d, 0x3c, 0xbb, 0xe4, 0x4d, 0x27, 0xcc, 0x6d, 0x68,
		0xf6, 0xdc, 0xbf, 0x2d, 0xb8, 0x51, 0xa8, 0x85, 0xdb, 0x0f, 0x7a, 0xb2, 0x7d, 0x9f, 0x62, 0xe3,
		0xe7, 0x97, 0x77, 0x62, 0x13, 0x68, 0xc2, 0x11, 0xe1, 0x88, 0xab, 0x09, 0xd7, 0xf7, 0x8b, 0x7b,
		0xf1, 0x33, 0x4d, 0x7f, 0x35, 0xe1, 0xe4, 0x46, 0x6c, 0x07, 0x6d, 0x3a, 0xb5, 0x99, 0x4d, 0x71,
		0xa6, 0x52, 0x9d, 0xf1, 0x94, 0x67, 0x3c, 0xf5, 0x19, 0x4f, 0x81, 0xe9, 0xa4, 0xc2, 0x94, 0x52,
		0x62, 0xea, 0xa9, 0x31, 0xb9, 0x41, 0x18, 0x0c, 0xb4, 0x30, 0xd8, 0xe7, 0x64, 0x7c, 0x3f, 0x33,
		0x4d, 0x47, 0xf2, 0x6c, 0x3a, 0x02, 0x9e, 0x48, 0x4d, 0x27, 0x54, 0x6b, 0x89, 0xd5, 0x5a, 0x82,
		0xb5, 0x96, 0x68, 0xd3, 0x4d, 0xb8, 0x29, 0x27, 0x5e, 0x63, 0x09, 0x78, 0x3a, 0x11, 0x9b, 0xf3,
		0xff, 0xa9, 0x7c, 0x6c, 0xca, 0xf7, 0xcd, 0xa4, 0x65, 0xe3, 0xe9, 0xd9, 0x46, 0x9a, 0xb6, 0x9b,
		0xae, 0x6d, 0xa5, 0x6d, 0xeb, 0xe9, 0xdb, 0x7a, 0x1a, 0xb7, 0x9e, 0xce, 0xcd, 0xa4, 0x75, 0x43,
		0xe9, 0xdd, 0x78, 0x9a, 0x4f, 0x6e, 0xd8, 0x0e, 0x7a, 0x41, 0x68, 0x3e, 0x6e, 0x9e, 0x8e, 0xaf,
		0x1a, 0xde, 0xfe, 0xed, 0x56, 0x34, 0xba, 0x31, 0x0d, 0x03, 0x36, 0xe1, 0x00, 0x03, 0x16, 0x6c,
		0xc3, 0x03, 0x0c, 0x4c, 0xc0, 0xc0, 0x05, 0x0c, 0x6c, 0x98, 0x85, 0x0f, 0xc3, 0x30, 0x92, 0x3c,
		0x65, 0x63, 0x2d, 0x0b, 0x17, 0xc6, 0x7d, 0x7a, 0x13, 0xb0, 0xbf, 0xcd, 0xf2, 0xcb, 0x16, 0xee,
		0x3d, 0x33, 0x81, 0x1b, 0x03, 0xdd, 0x9b, 0xcd, 0x74, 0x6d, 0x93, 0xad, 0xf1, 0x84, 0xea, 0xf4,
		0x03, 0x39, 0x4a, 0x1c, 0x96, 0x38, 0x4b, 0x62, 0x01, 0x69, 0x0b, 0x69, 0x0b, 0x69, 0x0b, 0x69,
		0x0b, 0x69, 0x0b, 0x69, 0xcb, 0x86, 0xd2, 0x96, 0x04, 0xeb, 0xc8, 0x5c, 0x56, 0x7e, 0xb8, 0x7d,
		0x5f, 0x7f, 0x75, 0x65, 0xc7, 0x1e, 0x71, 0x99, 0x18, 0x40, 0xde, 0x42, 0xde, 0x42, 0xde, 0x42,
		0xde, 0x42, 0xde, 0x42, 0xde, 0xb2, 0xa1, 0xbc, 0x65, 0x02, 0x75, 0xa4, 0x2d, 0x2b, 0x3f, 0xdb,
		0x74, 0xcf, 0xe7, 0xfb, 0xa5, 0x47, 0xa7, 0x79, 0x6e, 0xdf, 0x2f, 0x7d, 0x99, 0x94, 0x85, 0x94,
		0x85, 0x94, 0x85, 0x94, 0x65, 0x73, 0x29, 0x8b, 0xe9, 0x05, 0x07, 0xc9, 0x8d, 0x7d, 0xad, 0x43,
		0x57, 0xaa, 0x8e, 0xb8, 0xb3, 0x17, 0x74, 0xc9, 0x76, 0xe4, 0x27, 0x5b, 0x2c, 0x39, 0xbb, 0x9d,
		0x1a, 0xd9, 0x3a, 0xf0, 0x20, 0x00, 0x10, 0x16, 0x10, 0xa1, 0x00, 0x12, 0x1c, 0x30, 0xc1, 0x01,
		0x14, 0x1c, 0x50, 0xd9, 0x01, 0x2c, 0x4b, 0xc0, 0x65, 0xbf, 0xe6, 0x06, 0xaa, 0xbd, 0x11, 0x6a,
		0xf0, 0x79, 0xb5, 0xf8, 0xdc, 0x7f, 0x23, 0xb0, 0x8d, 0x84, 0x8e, 0x92, 0xab, 0x71, 0xcd, 0x1e,
		0x03, 0xf0, 0x9b, 0xed, 0x08, 0x19, 0x0b, 0xe1, 0x62, 0x69, 0xad, 0xe7, 0x4c, 0x9c, 0xd8, 0x58,
		0xf3, 0x49, 0xa2, 0x45, 0xa2, 0x45, 0xa2, 0x45, 0xa2, 0x45, 0xa2, 0xb5, 0x01, 0x44, 0xcb, 0xd8,
		0xb1, 0xd8, 0xbf, 0x42, 0x11, 0x9b, 0x34, 0xcb, 0xec, 0x31, 0xda, 0x8b, 0x5e, 0x76, 0x73, 0xe6,
		0x8e, 0xad, 0x63, 0xb7, 0x41, 0xe9, 0xc5, 0x8c, 0x39, 0x96, 0x8e, 0xe9, 0x5e, 0x68, 0x8f, 0xc5,
		0xa3, 0x96, 0xc1, 0xd2, 0xe9, 0xb4, 0x0b, 0xfb, 0x77, 0x74, 0xe1, 0x5f, 0xb8, 0xb0, 0xad, 0xe3,
		0xc1, 0x33, 0xe5, 0xcb, 0x6f, 0xb6, 0xf3, 0xee, 0x0d, 0x8a, 0x06, 0x29, 0x8a, 0x06, 0x37, 0x37,
		0x03, 0x25, 0xf5, 0x3d, 0xca, 0x64, 0xcd, 0x4b, 0x83, 0x28, 0x24, 0x50, 0x48, 0xa0, 0x90, 0x40,
		0x21, 0x81, 0x42, 0x02, 0x85, 0x84, 0x25, 0xf3, 0x06, 0x67, 0x6c, 0x76, 0x7e, 0x67, 0xc6, 0x66,
		0x82, 0xb8, 0x52, 0x44, 0xc9, 0xf5, 0x3d, 0x27, 0x6d, 0xcc, 0x0c, 0x8e, 0xb5, 0xfd, 0xae, 0x33,
		0xd1, 0x62, 0x69, 0xdf, 0x2b, 0x19, 0x17, 0x19, 0x17, 0x19, 0x17, 0x19, 0x17, 0x19, 0xd7, 0x06,
		0x30, 0x2e, 0xd9, 0x77, 0xfd, 0x4e, 0x27, 0x14, 0x51, 0x84, 0x40, 0xba, 0x8e, 0x2c, 0xda, 0x30,
		0x1e, 0x93, 0xad, 0x9f, 0xbe, 0x99, 0x3a, 0x86, 0xc1, 0xbe, 0x6f, 0xcc, 0xf8, 0xc8, 0x21, 0x80,
		0x2d, 0xe7, 0xbe, 0xd6, 0x22, 0x54, 0xd6, 0xdd, 0x25, 0x31, 0xe8, 0xdf, 0xdd, 0xdd, 0xab, 0x9c,
		0x7b, 0xd4, 0x78, 0xb8, 0xca, 0xbb, 0x47, 0x8d, 0xf8, 0x32, 0x3f, 0xfa, 0x12, 0x5f, 0xef, 0x5f,
		0xe5, 0xdc, 0xc2, 0xe4, 0xba, 0x78, 0x95, 0x73, 0x8b, 0x8d, 0xbd, 0x2f, 0x5f, 0xde, 0xed, 0xfd,
		0x3c, 0x78, 0x5c, 0xfe, 0x83, 0x7f, 0x38, 0xd6, 0xff, 0xe8, 0x06, 0x82, 0x13, 0xd4, 0x2e, 0xaa,
		0xff, 0xd0, 0x13, 0x6c, 0x7b, 0x82, 0xdd, 0x29, 0x96, 0xb7, 0x84, 0x8b, 0x04, 0x2e, 0x4a, 0x84,
		0x8b, 0x6c, 0xc1, 0x85, 0xef, 0x76, 0x2b, 0xee, 0xc7, 0xc6, 0xcf, 0xfc, 0xdb, 0xc2, 0xe3, 0xfb,
		0xbd, 0x9f, 0xe5, 0xc7, 0x97, 0x6f, 0x3e, 0xcc, 0xfb, 0xb1, 0xfc, 0xdb, 0xf2, 0xe3, 0xfb, 0x05,
		0xdf, 0x29, 0x3d, 0xbe, 0xff, 0xcd, 0xdf, 0x51, 0x7c, 0xdc, 0x9d, 0xf9, 0xd1, 0xe1, 0xfb, 0xfb,
		0x8b, 0x3e, 0x50, 0x58, 0xf0, 0x81, 0x83, 0x45, 0x1f, 0x38, 0x58, 0xf0, 0x81, 0x85, 0x26, 0xed,
		0x2f, 0xf8, 0x40, 0xf1, 0xf1, 0x61, 0xe6, 0xe7, 0x77, 0xe7, 0xff, 0x68, 0xe9, 0x71, 0xef, 0x61,
		0xd1, 0xf7, 0xca, 0x8f, 0x0f, 0xef, 0xf7, 0x08, 0x9e, 0x19, 0x00, 0x4f, 0xc6, 0xc5, 0x76, 0xc6,
		0x05, 0x57, 0x6b, 0x6c, 0xf4, 0xdf, 0x6b, 0x65, 0xb6, 0xe0, 0x4e, 0xbb, 0x70, 0x2b, 0x36, 0xe6,
		0x19, 0xc5, 0x39, 0x04, 0x3b, 0x38, 0xc8, 0x39, 0x84, 0x17, 0xd6, 0x70, 0x0e, 0x61, 0x81, 0x41,
		0x9c, 0x43, 0x80, 0x44, 0x50, 0xce, 0x21, 0x70, 0xd5, 0xc6, 0xce, 0xef, 0xac, 0xda, 0x78, 0x8e,
		0xba, 0x52, 0x44, 0x53, 0xff, 0xe7, 0xea, 0x0d, 0x43, 0x83, 0x24, 0xd5, 0xad, 0xdf, 0x93, 0x1d,
		0x37, 0x14, 0x7e, 0x14, 0x28, 0xfb, 0x54, 0xec, 0x85, 0x3d, 0x64, 0x61, 0x64, 0x61, 0x64, 0x61,
		0x64, 0x61, 0x64, 0x61, 0x64, 0x61, 0xcb, 0x22, 0x49, 0x47, 0x28, 0x2d, 0xf5, 0x3d, 0x08, 0x13,
		0xb3, 0xb8, 0x2b, 0xcc, 0xa9, 0x8e, 0x1f, 0xc5, 0x07, 0x3f, 0x02, 0x48, 0x61, 0x93, 0x01, 0xaa,
		0x9e, 0xfd, 0x5d, 0x39, 0xad, 0x1e, 0x37, 0xeb, 0xb5, 0xcf, 0x97, 0x27, 0xcd, 0xfa, 0x49, 0xe5,
		0xa2, 0x76, 0x66, 0x3b, 0x9b, 0x8d, 0x36, 0xf3, 0x45, 0x10, 0x02, 0x3c, 0xc8, 0x6e, 0xcb, 0x97,
		0xa3, 0xf5, 0xe7, 0xe9, 0xe7, 0x8b, 0xcb, 0x93, 0x7a, 0xf3, 0xb4, 0x56, 0x3b, 0x77, 0xb8, 0x39,
		0x16, 0x76, 0x9c, 0x2a, 0x17, 0x1c, 0x22, 0xf0, 0x21, 0xaa, 0xd5, 0xab, 0x7f, 0x55, 0xcf, 0x2a,
		0x97, 0xb5, 0x3a, 0x47, 0x09, 0x38, 0xe1, 0xd5, 0xce, 0x3e, 0x9e, 0x1c, 0x3b, 0x5b, 0xbe, 0x77,
		0xba, 0xb1, 0x6d, 0xfc, 0x79, 0x2b, 0xd4, 0x9f, 0x9e, 0x1f, 0x69, 0xf7, 0x26, 0xe8, 0xc8, 0xae,
		0x14, 0x1d, 0xfb, 0xe2, 0xcf, 0xb4, 0x39, 0xd4, 0x7e, 0xa8, 0xfd, 0x50, 0xfb, 0xa1, 0xf6, 0x43,
		0xed, 0x87, 0xda, 0xcf, 0x92, 0x79, 0x43, 0xcb, 0x1b, 0xa1, 0x65, 0xfb, 0x7b, 0x54, 0x2a, 0x00,
		0x68, 0x3f, 0x16, 0x97, 0xdc, 0x3a, 0x9f, 0x55, 0xdc, 0xfb, 0xc7, 0x51, 0xbe, 0x0a, 0x22, 0xd1,
		0x0e, 0x54, 0xc7, 0xea, 0xce, 0x26, 0x76, 0x85, 0x1b, 0x3f, 0x08, 0x76, 0x85, 0x5b, 0x6c, 0x0e,
		0xbb, 0xc2, 0x65, 0xa1, 0x5e, 0x67, 0x57, 0xb8, 0xdf, 0x70, 0xe1, 0xfc, 0x61, 0xa1, 0x50, 0x2a,
		0x17, 0x0a, 0xb9, 0xf2, 0x41, 0x39, 0x77, 0x54, 0x2c, 0xe6, 0x4b, 0x79, 0xf6, 0x87, 0x03, 0xd5,
		0x38, 0xb8, 0xe2, 0x78, 0x13, 0x35, 0x0e, 0x5b, 0xa7, 0xda, 0xce, 0x90, 0x52, 0x3b, 0xa7, 0xdb,
		0x26, 0x66, 0x1c, 0x8b, 0xae, 0x3f, 0xe8, 0x8d, 0x4a, 0xa3, 0x1c, 0xb5, 0x15, 0x6a, 0x2b, 0xd4,
		0x56, 0xa8, 0xad, 0x50, 0x5b, 0xa1, 0xb6, 0xb2, 0x6c, 0xde, 0x60, 0x73, 0x7b, 0xca, 0x18, 0x94,
		0x31, 0x28, 0x63, 0x50, 0xc6, 0xd8, 0x22, 0x17, 0x66, 0x73, 0x7b, 0x8a, 0x17, 0x14, 0x2f, 0xcc,
		0x8b, 0x17, 0xe3, 0xcd, 0x30, 0xc1, 0x40, 0x0b, 0xfb, 0x02, 0xc6, 0x73, 0x63, 0x28, 0x20, 0x50,
		0x40, 0xa0, 0x80, 0x40, 0x01, 0x81, 0x02, 0x02, 0x05, 0x84, 0x25, 0xf3, 0x46, 0x2b, 0x08, 0x7a,
		0xc2, 0x57, 0x08, 0x9b, 0x72, 0xf2, 0xdb, 0x42, 0x5d, 0xde, 0x6c, 0xb0, 0x8b, 0x3b, 0x15, 0xa5,
		0x02, 0xed, 0x0f, 0xab, 0x01, 0x2b, 0x0e, 0xee, 0x44, 0xed, 0xaf, 0xe2, 0xc6, 0xef, 0x8f, 0xb7,
		0xbb, 0x7b, 0x41, 0x5f, 0xa8, 0xf6, 0x88, 0x28, 0xb8, 0x4a, 0xe8, 0x1f, 0x41, 0xf8, 0xdd, 0x95,
		0x2a, 0xd2, 0xbe, 0x6a, 0x0b, 0xef, 0xe5, 0x1b, 0xd1, 0xcc, 0x3b, 0x5e, 0x3f, 0x0c, 0x74, 0xd0,
		0x0e, 0x7a, 0x51, 0x72, 0xe5, 0xb5, 0xae, 0xfb, 0x5e, 0x28, 0x5b, 0x9e, 0xdf, 0x95, 0x6e, 0xe4,
		0x77, 0x65, 0x94, 0x5c, 0x79, 0xa3, 0xae, 0xb4, 0x51, 0xa8, 0x85, 0xdb, 0x0f, 0x7a, 0xb2, 0x7d,
		0xef, 0xf5, 0xe2, 0xd4, 0xea, 0x8d, 0x68, 0x5a, 0x14, 0x7f, 0x89, 0x37, 0xd3, 0x9b, 0xcd, 0xb4,
		0xe6, 0x5c, 0xce, 0xa0, 0xbb, 0x39, 0x03, 0xf5, 0x5d, 0x05, 0x3f, 0x94, 0xeb, 0x6b, 0x1d, 0xca,
		0xd6, 0xf0, 0x09, 0x1b, 0x77, 0xb9, 0x27, 0x21, 0x76, 0xd6, 0x16, 0xc3, 0x81, 0x37, 0x49, 0xa3,
		0x86, 0x6f, 0x6b, 0x8b, 0x85, 0xdb, 0x64, 0xdf, 0x18, 0xac, 0xdb, 0x36, 0xdb, 0x86, 0x61, 0xd9,
		0x30, 0xec, 0x1a, 0x86, 0x55, 0x6f, 0x36, 0xc5, 0x38, 0x96, 0xa1, 0x9d, 0xb0, 0x9f, 0x49, 0xf2,
		0xf6, 0x65, 0xa0, 0x59, 0x93, 0xec, 0x8a, 0x41, 0x79, 0x8a, 0x41, 0x14, 0x83, 0x28, 0x06, 0x51,
		0x0c, 0xa2, 0x18, 0x84, 0x0e, 0x67, 0x89, 0x01, 0x43, 0xec, 0x70, 0xb5, 0x6d, 0x49, 0x6a, 0x2a,
		0x83, 0x3d, 0x99, 0x64, 0x39, 0x34, 0x30, 0xa6, 0x80, 0xad, 0xc3, 0x1b, 0x12, 0xcc, 0x61, 0xc2,
		0x1d, 0x1a, 0xec, 0xc1, 0xc2, 0x1f, 0x2c, 0x0c, 0xc2, 0xc2, 0xa1, 0x5d, 0x58, 0xb4, 0x0c, 0x8f,
		0xc9, 0xa8, 0x5c, 0x22, 0x00, 0xd4, 0x0e, 0x56, 0x6b, 0xd9, 0x99, 0xea, 0xab, 0x8c, 0x71, 0xa0,
		0xcc, 0xa4, 0xd5, 0x6c, 0xdc, 0x37, 0xf6, 0x09, 0xcc, 0xb7, 0x74, 0x51, 0x8e, 0xc5, 0xd0, 0x71,
		0xe2, 0xd9, 0x06, 0x18, 0x62, 0x17, 0x9b, 0x83, 0x41, 0xea, 0xf2, 0x24, 0x75, 0x24, 0x75, 0x24,
		0x75, 0x24, 0x75, 0x24, 0x75, 0xb6, 0x46, 0xc5, 0xb6, 0xf6, 0x31, 0xad, 0x81, 0xf4, 0x04, 0xd0,
		0xfe, 0x89, 0x29, 0x29, 0x64, 0x68, 0xd9, 0x5b, 0x2e, 0x8a, 0x07, 0x06, 0x51, 0x44, 0x30, 0xc5,
		0x06, 0x55, 0x54, 0x70, 0x85, 0x07, 0x59, 0x78, 0xb0, 0x85, 0x07, 0x5d, 0x0c, 0xf0, 0x05, 0x01,
		0x61, 0x3c, 0x85, 0x65, 0x26, 0x6f, 0x0d, 0xa4, 0xd2, 0xf9, 0x12, 0x52, 0xce, 0x1a, 0xa3, 0x60,
		0x09, 0xc8, 0x24, 0x8c, 0x6d, 0xb0, 0x2f, 0x5f, 0x58, 0x39, 0x7d, 0x07, 0x6d, 0x9b, 0x2c, 0x38,
		0xbd, 0x9a, 0x31, 0x0f, 0x6c, 0x1b, 0xed, 0x8c, 0x7d, 0x80, 0x5b, 0x11, 0x41, 0xd3, 0xfd, 0x74,
		0x48, 0xf8, 0x77, 0x0c, 0x89, 0x15, 0x43, 0xa2, 0x54, 0x2c, 0x1e, 0x14, 0x19, 0x16, 0xd9, 0xe6,
		0x62, 0x78, 0xd6, 0x34, 0xde, 0xf0, 0x79, 0x80, 0xa4, 0x4d, 0xa0, 0x95, 0x32, 0x33, 0x14, 0x19,
		0x65, 0xc5, 0x0c, 0x68, 0xd6, 0xa6, 0x4e, 0xb4, 0x8c, 0x33, 0x51, 0x27, 0x5a, 0xca, 0xd3, 0xa9,
		0x13, 0xad, 0x68, 0x20, 0x75, 0xa2, 0x0c, 0x15, 0x0e, 0xe0, 0x3a, 0xd1, 0x21, 0xa0, 0x4c, 0x54,
		0xa4, 0x4c, 0xf4, 0x8b, 0x17, 0x65, 0xa2, 0x8d, 0xac, 0x89, 0x29, 0x13, 0x65, 0x3d, 0xdb, 0x4f,
		0x87, 0x04, 0x65, 0xa2, 0x95, 0x43, 0x62, 0xbf, 0x48, 0x91, 0x68, 0x03, 0x64, 0x99, 0x1d, 0x8a,
		0x44, 0x80, 0xcf, 0x03, 0x46, 0x24, 0xba, 0x1d, 0x47, 0x3b, 0xa2, 0x4a, 0x14, 0xdb, 0x46, 0x99,
		0x68, 0x9e, 0x39, 0x94, 0x89, 0x96, 0xf0, 0x26, 0xca, 0x44, 0x4b, 0x79, 0x3a, 0x65, 0xa2, 0x15,
		0x0d, 0xa4, 0x4c, 0x94, 0xa1, 0xc2, 0x01, 0x58, 0x26, 0x6a, 0x49, 0xe5, 0x87, 0xf7, 0x80, 0x3a,
		0xd1, 0x11, 0x90, 0x49, 0xa7, 0x42, 0x5d, 0x8f, 0x36, 0x72, 0x51, 0x28, 0xfa, 0x55, 0x55, 0x4c,
		0xa1, 0x68, 0xe5, 0xaa, 0x38, 0xcf, 0x9a, 0x38, 0xe3, 0xf9, 0x7e, 0x3a, 0x24, 0x28, 0x14, 0xad,
		0x1c, 0x12, 0x5c, 0x4f, 0xb4, 0x21, 0xe2, 0xcc, 0x0e, 0xa5, 0x22, 0xc0, 0xe7, 0x81, 0x20, 0x15,
		0x89, 0x3b, 0x2d, 0x54, 0x47, 0x74, 0xf0, 0x84, 0xa2, 0xc4, 0x32, 0xca, 0x44, 0xf3, 0xcc, 0xa1,
		0x4c, 0xb4, 0x84, 0x2f, 0x51, 0x26, 0x5a, 0xca, 0xd3, 0x29, 0x13, 0xad, 0x68, 0x20, 0x65, 0xa2,
		0x0c, 0x95, 0x0d, 0xc8, 0x32, 0x91, 0xf5, 0xb3, 0x11, 0x16, 0xc1, 0xa0, 0xa5, 0xb3, 0x12, 0x48,
		0xe2, 0xe6, 0x8d, 0x49, 0xd0, 0x1f, 0x56, 0x42, 0x7e, 0x0f, 0x8f, 0xc4, 0x25, 0x96, 0x91, 0xc4,
		0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4,
		0xbd, 0x1c, 0x93, 0xbe, 0x1f, 0x6a, 0x89, 0xc8, 0xe1, 0x26, 0x86, 0x91, 0xc2, 0x91, 0xc2, 0x91,
		0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0xbd, 0x1c, 0x13,
		0x1d, 0xfa, 0x2a, 0x92, 0x5a, 0xde, 0x02, 0xae, 0xbb, 0x7f, 0x66, 0x1b, 0x89, 0x1c, 0x89, 0x1c,
		0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x18, 0x91, 0xdb, 0xea,
		0x76, 0xf4, 0x96, 0x0f, 0xaf, 0x9f, 0xb1, 0x07, 0xff, 0x30, 0xfb, 0xd9, 0x73, 0xcf, 0x67, 0xdf,
		0xb2, 0x71, 0xe2, 0x3d, 0x8e, 0x5f, 0x6f, 0xd7, 0x61, 0x96, 0xff, 0x13, 0xf7, 0x08, 0xdd, 0xe8,
		0x9c, 0x53, 0x19, 0xe9, 0x8a, 0xd6, 0x96, 0x4f, 0xd6, 0xfc, 0x24, 0xd5, 0x49, 0x4f, 0x0c, 0xa9,
		0x53, 0x64, 0xb7, 0xb4, 0x71, 0x3e, 0xf9, 0x77, 0xcf, 0x2c, 0xc9, 0x1f, 0x16, 0x0a, 0xa5, 0x72,
		0xa1, 0x90, 0x2b, 0x1f, 0x94, 0x73, 0x47, 0xc5, 0x62, 0xbe, 0x94, 0xb7, 0xb8, 0xd3, 0xc0, 0xa9,
		0x85, 0x1d, 0x11, 0x8a, 0xce, 0x87, 0xa1, 0xeb, 0xa8, 0x41, 0xaf, 0xb7, 0x55, 0x11, 0x03, 0x82,
		0x39, 0x1b, 0x82, 0x35, 0x8e, 0xd5, 0xa3, 0xd6, 0xc2, 0x41, 0x5b, 0xab, 0x31, 0xd9, 0x3d, 0x8b,
		0x1f, 0x49, 0x75, 0xfc, 0x44, 0x9a, 0xe7, 0xe3, 0xe7, 0xd0, 0xfc, 0x70, 0xdd, 0x6f, 0xd6, 0x65,
		0xab, 0x59, 0xe9, 0xca, 0x0b, 0xbf, 0x2b, 0x9b, 0xd5, 0xfe, 0x6d, 0xe1, 0x22, 0xd4, 0xe2, 0x7c,
		0xf4, 0xa7, 0x37, 0x4f, 0x83, 0xf6, 0xf0, 0xbb, 0xf5, 0xe1, 0x9f, 0xdc, 0xfc, 0x1c, 0xff, 0x7d,
		0x95, 0xe4, 0xcf, 0x7b, 0xb3, 0x1d, 0x10, 0x66, 0xf6, 0x8e, 0x86, 0x43, 0xdf, 0x76, 0xc8, 0x67,
		0x32, 0xd4, 0xcd, 0x7a, 0xbe, 0x39, 0xff, 0x33, 0x73, 0x27, 0x43, 0x1e, 0x3e, 0xa1, 0x7f, 0x43,
		0xd7, 0x72, 0x65, 0x67, 0x47, 0xa8, 0x4e, 0x3f, 0x90, 0x4a, 0xef, 0xb4, 0x83, 0x5e, 0x10, 0x1a,
		0xca, 0xcd, 0x76, 0xb8, 0x9f, 0x3d, 0xae, 0x07, 0xc5, 0xed, 0xec, 0x70, 0x39, 0x53, 0xee, 0x6d,
		0x29, 0x71, 0xe3, 0x27, 0x6c, 0x83, 0xb4, 0x2b, 0x05, 0x9a, 0x65, 0x06, 0x5b, 0xd2, 0xcf, 0xf4,
		0xe9, 0xde, 0x21, 0xe5, 0x20, 0x33, 0x1d, 0x5c, 0xc8, 0x41, 0x95, 0xae, 0x43, 0xa6, 0xe7, 0x26,
		0xe9, 0xfc, 0xe6, 0x94, 0x1c, 0xcf, 0x94, 0xc3, 0x41, 0x3a, 0x5a, 0x8a, 0x09, 0x7b, 0xad, 0x09,
		0x3a, 0x9d, 0x48, 0x58, 0xbf, 0x9f, 0xa6, 0xe0, 0xa3, 0x8e, 0x12, 0xf2, 0xfa, 0x6b, 0x2b, 0x08,
		0xa3, 0xd4, 0xdc, 0x33, 0x99, 0x99, 0x7b, 0xba, 0x55, 0x4a, 0xb1, 0x96, 0xee, 0x91, 0xeb, 0xa9,
		0x2f, 0x1f, 0x31, 0xb1, 0x1c, 0xc4, 0xec, 0xf2, 0x0e, 0x53, 0xcb, 0x35, 0x8c, 0x2f, 0xbf, 0x30,
		0xbe, 0x9c, 0xc2, 0xf8, 0xf2, 0x88, 0x6c, 0xa1, 0x6c, 0xda, 0x47, 0x7c, 0x27, 0xb9, 0x2b, 0x7d,
		0x57, 0x7e, 0x99, 0x2d, 0xd3, 0xf6, 0xe4, 0x74, 0x93, 0xa6, 0xb1, 0xe4, 0x69, 0x32, 0x89, 0xda,
		0x49, 0xa6, 0xa6, 0x93, 0xaa, 0xb5, 0xe4, 0x6a, 0x2d, 0xc9, 0x5a, 0x4b, 0xb6, 0x9b, 0x51, 0x5b,
		0xa7, 0x9d, 0x84, 0x93, 0x1b, 0xf9, 0x9d, 0x6f, 0xa3, 0x31, 0x91, 0xca, 0xed, 0x07, 0x91, 0x36,
		0x17, 0x09, 0x49, 0x87, 0xf3, 0x17, 0x06, 0x98, 0x12, 0xbe, 0x8d, 0xa4, 0x6a, 0xe3, 0x29, 0xdb,
		0x46, 0xea, 0xb6, 0x9b, 0xc2, 0x6d, 0xa5, 0x72, 0xeb, 0x29, 0xdd, 0x7a, 0x6a, 0xb7, 0x9e, 0xe2,
		0xcd, 0xa4, 0x7a, 0x43, 0x29, 0xdf, 0x78, 0xea, 0x4f, 0x6e, 0x38, 0x96, 0x30, 0x8d, 0x07, 0xce,
		0x24, 0x5d, 0x8c, 0xef, 0x6f, 0xd8, 0x69, 0xcd, 0x02, 0x80, 0x35, 0x20, 0xb0, 0x09, 0x08, 0x18,
		0xc0, 0x60, 0x1b, 0x20, 0x60, 0x80, 0x02, 0x06, 0x30, 0x60, 0x80, 0xc3, 0x2c, 0x80, 0x18, 0x06,
		0x12, 0x6b, 0x80, 0x32, 0x0d, 0x2c, 0xf6, 0xe2, 0x6d, 0x0a, 0x5f, 0x6c, 0xc5, 0x9a, 0x1d, 0x98,
		0xb1, 0x0e, 0x37, 0x08, 0xb0, 0x83, 0x05, 0x3f, 0x28, 0x30, 0x04, 0x07, 0x47, 0x70, 0xb0, 0x04,
		0x07, 0x4f, 0x76, 0x60, 0xca, 0x12, 0x5c, 0x59, 0x87, 0xad, 0xc4, 0x80, 0x78, 0x0d, 0xa4, 0xf5,
		0x38, 0x9d, 0x64, 0x2f, 0x93, 0x4b, 0x32, 0x7f, 0x05, 0x67, 0x96, 0x37, 0xfd, 0xc3, 0x74, 0x1f,
		0x40, 0xea, 0x3a, 0x80, 0xd9, 0x6d, 0x00, 0xad, 0xcb, 0x00, 0x6c, 0x77, 0x01, 0xd8, 0xae, 0x02,
		0xb0, 0xdd, 0x04, 0xb6, 0x7b, 0xeb, 0x33, 0x4c, 0xd7, 0x80, 0x24, 0xef, 0xf4, 0x84, 0xdf, 0x0d,
		0x45, 0x17, 0x21, 0xe9, 0x4c, 0xaa, 0xae, 0x32, 0x80, 0x2d, 0xe7, 0xe3, 0x75, 0x84, 0xef, 0xde,
		0xc5, 0xfb, 0xaa, 0xbd, 0x18, 0xc8, 0xb7, 0x75, 0x77, 0xb5, 0xc5, 0xca, 0x6b, 0xb2, 0xbb, 0x05,
		0x87, 0xd3, 0x25, 0x16, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6,
		0x91, 0xd6, 0x65, 0x92, 0xd6, 0x25, 0x58, 0x4e, 0x66, 0x67, 0x7c, 0x30, 0xc6, 0xfb, 0x97, 0x71,
		0x88, 0xdd, 0xc4, 0x20, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a,
		0xf2, 0xba, 0x4c, 0xf2, 0xba, 0x09, 0x94, 0x93, 0xd6, 0x19, 0x1f, 0x8b, 0xb8, 0x0f, 0x25, 0x0c,
		0xa9, 0x8b, 0xcd, 0xc1, 0xa0, 0x74, 0x79, 0x52, 0x3a, 0x52, 0x3a, 0x52, 0x3a, 0x52, 0x3a, 0x52,
		0x3a, 0x5b, 0xa3, 0x62, 0x7b, 0x81, 0x52, 0x62, 0xc8, 0xa8, 0x79, 0xaf, 0x54, 0x1d, 0x71, 0x87,
		0x77, 0x90, 0xca, 0x33, 0xdb, 0x78, 0x90, 0x0a, 0x32, 0x90, 0x22, 0x02, 0x2a, 0x36, 0xb0, 0xa2,
		0x02, 0x2c, 0x3c, 0xd0, 0xc2, 0x03, 0x2e, 0x3c, 0xf0, 0x62, 0x00, 0x30, 0x08, 0x10, 0xe3, 0x69,
		0x2c, 0xc0, 0x5a, 0x0b, 0xa2, 0xe6, 0x32, 0x4f, 0x7b, 0xf9, 0x8f, 0x7f, 0x23, 0x4a, 0x11, 0x09,
		0x1d, 0x25, 0x57, 0x63, 0xa5, 0x26, 0xa6, 0x19, 0x3c, 0x18, 0x06, 0x25, 0x28, 0x9d, 0x96, 0x88,
		0xb4, 0x3b, 0xee, 0xa3, 0x07, 0xc6, 0x4b, 0x9f, 0x4c, 0x23, 0x2d, 0x25, 0x2d, 0x25, 0x2d, 0x25,
		0x2d, 0x25, 0x2d, 0x25, 0x2d, 0xdd, 0x32, 0x5a, 0xca, 0xf3, 0xfd, 0x48, 0xe3, 0x7e, 0x63, 0x4c,
		0x30, 0x36, 0x42, 0xce, 0x78, 0x2f, 0xc2, 0x86, 0x48, 0xd2, 0x37, 0xd2, 0x37, 0xd2, 0x37, 0xd2,
		0x37, 0xd2, 0x37, 0xd2, 0x37, 0xe3, 0x79, 0x6b, 0x20, 0x95, 0x3e, 0xd8, 0x07, 0x64, 0x6f, 0x48,
		0x9a, 0x62, 0xdd, 0x57, 0xd7, 0xc3, 0xa7, 0x75, 0x05, 0x95, 0x03, 0xb0, 0x72, 0xfa, 0xce, 0xf8,
		0x3c, 0x2c, 0x38, 0xb0, 0x01, 0xa5, 0x57, 0x33, 0xe6, 0xfd, 0xed, 0xf7, 0x06, 0x02, 0xd8, 0xbe,
		0x8f, 0xa1, 0xdf, 0xd6, 0x32, 0x50, 0xc7, 0xf2, 0x5a, 0xc6, 0xc7, 0x9d, 0xc1, 0xd9, 0xf9, 0xf8,
		0x16, 0x30, 0x24, 0xfc, 0x3b, 0x86, 0xc4, 0x8a, 0x21, 0x51, 0xd8, 0x3f, 0x2a, 0x1c, 0x95, 0xca,
		0xfb, 0x47, 0x45, 0xc6, 0x46, 0xb6, 0x09, 0x19, 0x9e, 0x35, 0x0d, 0x8a, 0x44, 0x28, 0xb9, 0xd3,
		0x69, 0x07, 0x37, 0x37, 0x03, 0x25, 0xf5, 0x3d, 0xea, 0x4a, 0xb4, 0x97, 0x06, 0x52, 0x38, 0x9a,
		0x67, 0x0e, 0x85, 0xa3, 0x25, 0x5c, 0x8a, 0xc2, 0xd1, 0x52, 0x9e, 0x4e, 0xe1, 0x68, 0x45, 0x03,
		0x29, 0x1c, 0x65, 0xa8, 0x92, 0xe0, 0x72, 0xb4, 0x57, 0xc0, 0x60, 0x06, 0x97, 0xa3, 0x4d, 0x78,
		0x85, 0x14, 0x51, 0x72, 0x7d, 0xcf, 0x15, 0x69, 0x98, 0x2c, 0x15, 0xa6, 0x05, 0xd8, 0x4c, 0x4c,
		0x82, 0xb4, 0x02, 0x23, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x35,
		0x9e, 0xb7, 0x64, 0xdf, 0xf5, 0x3b, 0x9d, 0x50, 0x44, 0x11, 0x22, 0x35, 0x3d, 0x02, 0xb2, 0x69,
		0x3c, 0x86, 0x9c, 0xd4, 0xfc, 0x6d, 0xcf, 0xba, 0x2d, 0x00, 0xfa, 0xd6, 0x8c, 0x8f, 0x1d, 0x02,
		0xda, 0x76, 0xee, 0x6b, 0x2d, 0x42, 0x05, 0xe7, 0x6e, 0x89, 0x81, 0xff, 0xee, 0xee, 0x5e, 0xe5,
		0xdc, 0xa3, 0xc6, 0xc3, 0x55, 0xde, 0x3d, 0x6a, 0xc4, 0x97, 0xf9, 0xd1, 0x97, 0xf8, 0x7a, 0xff,
		0x2a, 0xe7, 0x16, 0x26, 0xd7, 0xc5, 0xab, 0x9c, 0x5b, 0x6c, 0xec, 0x7d, 0xf9, 0xf2, 0x6e, 0xef,
		0xe7, 0xc1, 0xe3, 0xf2, 0x1f, 0xfc, 0xc3, 0x81, 0x7b, 0x08, 0x0d, 0x44, 0xa7, 0xa9, 0x5d, 0x54,
		0xff, 0xa1, 0xe7, 0xa0, 0x7b, 0x0e, 0xd6, 0xc4, 0xe2, 0x5b, 0xc2, 0xd9, 0x6f, 0xc3, 0x59, 0x89,
		0x70, 0xb6, 0xd9, 0x70, 0xe6, 0xbb, 0xdd, 0x8a, 0xfb, 0xb1, 0xf1, 0x33, 0xff, 0xb6, 0xf0, 0xf8,
		0x7e, 0xef, 0x67, 0xf9, 0xf1, 0xe5, 0x9b, 0x0f, 0xf3, 0x7e, 0x2c, 0xff, 0xb6, 0xfc, 0xf8, 0x7e,
		0xc1, 0x77, 0x4a, 0x8f, 0xef, 0x7f, 0xf3, 0x77, 0x14, 0x1f, 0x77, 0x67, 0x7e, 0x74, 0xf8, 0xfe,
		0xfe, 0xa2, 0x0f, 0x14, 0x16, 0x7c, 0xe0, 0x60, 0xd1, 0x07, 0x0e, 0x16, 0x7c, 0x60, 0xa1, 0x49,
		0xfb, 0x0b, 0x3e, 0x50, 0x7c, 0x7c, 0x98, 0xf9, 0xf9, 0xdd, 0xf9, 0x3f, 0x5a, 0x7a, 0xdc, 0x7b,
		0x58, 0xf4, 0xbd, 0xf2, 0xe3, 0xc3, 0xfb, 0x3d, 0x82, 0xfb, 0x06, 0x82, 0x3b, 0xe3, 0x88, 0x71,
		0x84, 0x47, 0x75, 0xb8, 0x86, 0x0a, 0xec, 0x79, 0x40, 0xcc, 0x4e, 0xdd, 0x69, 0x17, 0x7e, 0x1d,
		0xd5, 0x3c, 0x23, 0x39, 0x67, 0x35, 0xcf, 0x1c, 0xce, 0x59, 0x2d, 0xe1, 0x56, 0x9c, 0xb3, 0x5a,
		0xca, 0xd3, 0x39, 0x67, 0xb5, 0xa2, 0x81, 0x9c, 0xb3, 0xca, 0x90, 0x24, 0xc3, 0xb5, 0x54, 0xaf,
		0x51, 0x5f, 0xb2, 0xb7, 0x96, 0xea, 0x39, 0xb7, 0x90, 0x22, 0x9a, 0xfa, 0x3f, 0xd7, 0x54, 0x81,
		0xb2, 0x56, 0xa9, 0x6e, 0xfd, 0x9e, 0xec, 0xb8, 0xa1, 0xf0, 0xa3, 0x40, 0xe1, 0x11, 0xd6, 0x17,
		0xf6, 0x91, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x6e, 0x19, 0x57,
		0x95, 0x1d, 0xa1, 0xb4, 0xd4, 0xf7, 0xa0, 0x7c, 0x15, 0x68, 0x87, 0xb0, 0x53, 0x1d, 0x3f, 0xaa,
		0x0f, 0x7e, 0x04, 0x98, 0x52, 0x27, 0x03, 0x5a, 0x3d, 0xfb, 0xbb, 0x72, 0x5a, 0x3d, 0x6e, 0xd6,
		0x6b, 0x9f, 0x2f, 0x4f, 0x9a, 0xf5, 0x93, 0xca, 0x45, 0xed, 0x0c, 0x2d, 0xbb, 0x8e, 0x36, 0x82,
		0x47, 0x90, 0xd3, 0x44, 0xa0, 0x3b, 0xfb, 0x5f, 0x8e, 0xee, 0x9f, 0xa7, 0x9f, 0x2f, 0x2e, 0x4f,
		0xea, 0xcd, 0xd3, 0x5a, 0xed, 0xdc, 0x61, 0xe3, 0x86, 0x8d, 0x19, 0xd7, 0xca, 0x05, 0x87, 0x74,
		0xc3, 0x86, 0xb4, 0x56, 0xaf, 0xfe, 0x55, 0x3d, 0xab, 0x5c, 0xd6, 0xea, 0x1c, 0xd5, 0x0d, 0x4a,
		0xc0, 0xb5, 0xb3, 0x8f, 0x27, 0xc7, 0x0e, 0xfb, 0x82, 0xfc, 0xe7, 0xab, 0xc1, 0x7a, 0x04, 0xcc,
		0x0a, 0x04, 0x75, 0xb0, 0xe7, 0x47, 0xda, 0xbd, 0x09, 0x3a, 0xb2, 0x2b, 0x45, 0x07, 0x4f, 0x1c,
		0x9c, 0x36, 0x8f, 0xda, 0xe0, 0x3c, 0x73, 0xa8, 0x0d, 0x2e, 0xe1, 0x50, 0xd4, 0x06, 0x97, 0xf2,
		0x74, 0x6a, 0x83, 0x2b, 0x1a, 0x48, 0x6d, 0x30, 0x43, 0xdc, 0x17, 0x58, 0x1b, 0xd4, 0xf2, 0x46,
		0x68, 0xd9, 0xfe, 0x1e, 0x95, 0x0a, 0x80, 0xda, 0x20, 0xd0, 0x46, 0x02, 0xe7, 0xb3, 0x8a, 0xfb,
		0x04, 0x3a, 0xca, 0x57, 0x41, 0x24, 0xda, 0x81, 0xea, 0x40, 0xed, 0x57, 0x65, 0xc7, 0xdb, 0xdf,
		0x7c, 0x50, 0xec, 0x78, 0xfb, 0x7a, 0xf3, 0xd8, 0xf1, 0x76, 0x13, 0xf5, 0x18, 0x76, 0xbc, 0x5d,
		0x43, 0x48, 0xe4, 0x0f, 0x0b, 0x85, 0x52, 0xb9, 0x50, 0xc8, 0x95, 0x0f, 0xca, 0xb9, 0xa3, 0x62,
		0x31, 0x5f, 0xca, 0xb3, 0xf7, 0x6d, 0xc6, 0xf9, 0x23, 0x9e, 0x35, 0xdc, 0xb7, 0x01, 0x93, 0x45,
		0x9d, 0xbe, 0xaf, 0xbf, 0xba, 0x12, 0x50, 0xdd, 0x9a, 0x18, 0x06, 0x52, 0xfd, 0x1c, 0x8b, 0xae,
		0x3f, 0xe8, 0x8d, 0x4a, 0xd5, 0x1c, 0xb5, 0xb6, 0xb9, 0xe6, 0x50, 0x6b, 0x5b, 0xc2, 0xbd, 0xa9,
		0xb5, 0x2d, 0xe5, 0xe9, 0xd4, 0xda, 0x56, 0x34, 0x90, 0x5a, 0x5b, 0x86, 0xea, 0x1a, 0x1e, 0xdc,
		0xb4, 0x3c, 0x0a, 0xf2, 0xe0, 0xa6, 0x5f, 0xbd, 0x28, 0x63, 0x6d, 0x64, 0xcd, 0x4e, 0x19, 0x2b,
		0xeb, 0xe9, 0x7e, 0x3a, 0x24, 0x28, 0x63, 0xad, 0x1c, 0x12, 0x3c, 0xb8, 0x69, 0x53, 0x08, 0x19,
		0x9e, 0x35, 0x14, 0xaf, 0x60, 0x72, 0xa7, 0x33, 0xde, 0x1c, 0x19, 0x0c, 0xb4, 0xc0, 0x13, 0xb0,
		0x9e, 0x1b, 0x47, 0xc1, 0x68, 0x9e, 0x39, 0x14, 0x8c, 0x96, 0x70, 0x27, 0x0a, 0x46, 0x4b, 0x79,
		0x3a, 0x05, 0xa3, 0x15, 0x0d, 0xa4, 0x60, 0x94, 0xa1, 0x0a, 0x02, 0x58, 0x30, 0x6a, 0x05, 0x41,
		0x4f, 0xf8, 0x0a, 0x71, 0xd3, 0x66, 0x9e, 0x54, 0x0e, 0xc0, 0x02, 0xcb, 0x21, 0xe4, 0x54, 0x94,
		0x0a, 0xb4, 0x3f, 0xac, 0xc6, 0x20, 0x02, 0xc8, 0x89, 0xda, 0x5f, 0xc5, 0x8d, 0xdf, 0x1f, 0x37,
		0x9d, 0xf1, 0x82, 0xbe, 0x50, 0xed, 0x11, 0x51, 0x72, 0x95, 0xd0, 0x3f, 0x82, 0xf0, 0xbb, 0x2b,
		0x55, 0xa4, 0x7d, 0xd5, 0x16, 0xde, 0xcb, 0x37, 0xa2, 0x99, 0x77, 0xbc, 0x7e, 0x18, 0xe8, 0xa0,
		0x1d, 0xf4, 0xa2, 0xe4, 0xca, 0x6b, 0x5d, 0xf7, 0xbd, 0x50, 0xb6, 0x3c, 0xbf, 0x2b, 0xdd, 0xc8,
		0xef, 0xca, 0x28, 0xb9, 0xf2, 0x46, 0x67, 0x0d, 0x44, 0xa1, 0x16, 0x6e, 0x3f, 0xe8, 0xc9, 0xf6,
		0xbd, 0xa7, 0x84, 0xbc, 0xfe, 0xda, 0x0a, 0xc2, 0x28, 0xb9, 0xf2, 0xfc, 0xce, 0xb7, 0x11, 0x1a,
		0x48, 0xe5, 0xf6, 0x83, 0x48, 0x7b, 0x23, 0x86, 0x1b, 0xc5, 0x5f, 0xe2, 0x3e, 0x37, 0x76, 0x41,
		0xc2, 0x9e, 0x37, 0x5b, 0xf4, 0x64, 0x67, 0xa0, 0xbe, 0xab, 0xe0, 0x87, 0x72, 0x7d, 0xad, 0x43,
		0xd9, 0x1a, 0x8e, 0x88, 0x75, 0x6f, 0x7e, 0x9a, 0x33, 0x98, 0xb5, 0xcd, 0x72, 0xcc, 0x4f, 0x10,
		0xc0, 0xb2, 0x19, 0x28, 0x05, 0x10, 0x52, 0xe1, 0x83, 0x59, 0xf0, 0xa0, 0x15, 0x3a, 0xb0, 0x05,
		0x0e, 0x6c, 0x61, 0x03, 0x5b, 0xd0, 0x6c, 0x37, 0xfb, 0x3a, 0x96, 0x21, 0x46, 0xda, 0x99, 0x01,
		0x29, 0x3c, 0x45, 0x71, 0xd6, 0x44, 0x2c, 0x5d, 0x31, 0x4f, 0x5d, 0x11, 0x1e, 0x5e, 0xb1, 0x61,
		0x16, 0x15, 0x6e, 0xe1, 0x61, 0x17, 0x1e, 0x7e, 0xe1, 0x61, 0x18, 0x47, 0x8e, 0xd9, 0x01, 0xd2,
		0x15, 0x51, 0xe0, 0x39, 0x31, 0x68, 0x88, 0x7d, 0xae, 0x46, 0x53, 0x3b, 0xa7, 0x32, 0xea, 0x93,
		0x89, 0x60, 0xa1, 0x87, 0xb9, 0x7a, 0x03, 0x0e, 0xae, 0x91, 0x61, 0x3b, 0x1b, 0xf0, 0x8d, 0x0e,
		0xe3, 0x99, 0x81, 0xf3, 0xcc, 0xc0, 0x7a, 0x66, 0xe0, 0x1d, 0x0b, 0xe6, 0xc1, 0xe0, 0x3e, 0x19,
		0xc5, 0x4b, 0x44, 0x80, 0xdd, 0xc1, 0x3e, 0xbb, 0x60, 0xa6, 0x1a, 0x2e, 0x63, 0x9e, 0x20, 0x39,
		0x39, 0xcb, 0x20, 0x3e, 0x92, 0xe0, 0x89, 0xac, 0x70, 0xbd, 0x1f, 0x7a, 0x68, 0x3a, 0xf1, 0xec,
		0x1a, 0x2c, 0xf1, 0x8d, 0xcd, 0xc3, 0x24, 0xbd, 0x79, 0x92, 0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x92,
		0x5e, 0x92, 0x5e, 0x22, 0xeb, 0xfc, 0x51, 0x44, 0xd3, 0xba, 0x12, 0xc3, 0x46, 0x1c, 0xad, 0x27,
		0x80, 0xb7, 0xca, 0x4d, 0x49, 0x5f, 0x43, 0x4b, 0xdf, 0x72, 0xff, 0xd2, 0x06, 0x91, 0x82, 0x2c,
		0x90, 0x83, 0x6c, 0x91, 0x84, 0xac, 0x90, 0x85, 0xcc, 0x91, 0x86, 0xcc, 0x91, 0x87, 0xcc, 0x91,
		0x08, 0x4c, 0x32, 0x01, 0x4a, 0x2a, 0x92, 0xd1, 0x85, 0x55, 0xd4, 0x66, 0xf2, 0xe6, 0x40, 0x2a,
		0x9d, 0x2f, 0x21, 0xe7, 0xcc, 0x31, 0x8a, 0x97, 0x80, 0x4d, 0xc4, 0xec, 0x00, 0xf1, 0xf2, 0x85,
		0x8d, 0x39, 0x3b, 0xe8, 0x1d, 0x22, 0x32, 0x46, 0x2f, 0x67, 0xcc, 0x05, 0xef, 0x20, 0x31, 0x63,
		0x6f, 0x06, 0x76, 0xcd, 0x67, 0x04, 0x8e, 0xa6, 0x43, 0xcc, 0xbf, 0x63, 0x88, 0xa5, 0x1c, 0x62,
		0xa5, 0x62, 0xf1, 0xa0, 0xc8, 0x30, 0xdb, 0x2e, 0x2e, 0x8a, 0x6f, 0x5d, 0xe3, 0x0d, 0x9f, 0x57,
		0x46, 0xd3, 0x38, 0xf0, 0x4a, 0xb8, 0x99, 0x92, 0x02, 0x75, 0x45, 0x5c, 0x46, 0x50, 0x85, 0xba,
		0xe0, 0x3a, 0x9d, 0x91, 0xba, 0xe0, 0x5a, 0x23, 0x87, 0xba, 0x60, 0xca, 0x06, 0x53, 0x17, 0xdc,
		0xe0, 0x42, 0x2c, 0x63, 0xba, 0xe0, 0x61, 0x06, 0x64, 0xc1, 0x22, 0x65, 0xc1, 0x15, 0x5f, 0x94,
		0x05, 0xa9, 0x59, 0x50, 0x16, 0xdc, 0x42, 0x34, 0x9a, 0x0e, 0x31, 0xca, 0x82, 0xa9, 0x87, 0xd8,
		0x7e, 0x91, 0xa2, 0xe0, 0x96, 0x11, 0x51, 0x7c, 0xeb, 0x28, 0x0a, 0x66, 0x36, 0x89, 0xc7, 0x4a,
		0xdb, 0xed, 0x38, 0xbb, 0x64, 0x41, 0x15, 0x8c, 0x6d, 0xa5, 0x2c, 0xf8, 0x1a, 0xf3, 0x28, 0x0b,
		0xae, 0xd1, 0x1b, 0x29, 0x0b, 0xae, 0x35, 0x72, 0x28, 0x0b, 0xa6, 0x6c, 0x30, 0x65, 0xc1, 0x0d,
		0x2e, 0xc4, 0x32, 0x24, 0x0b, 0xb6, 0xa4, 0xf2, 0xc3, 0xfb, 0x0c, 0xe8, 0x82, 0x47, 0xc0, 0x26,
		0x9e, 0x0a, 0x75, 0x3d, 0xda, 0x98, 0x4b, 0x61, 0x70, 0x55, 0xd5, 0x82, 0xc2, 0x60, 0xea, 0xaa,
		0x45, 0x9e, 0x9a, 0xc5, 0x96, 0xe1, 0xd1, 0x74, 0x88, 0x51, 0x18, 0x4c, 0x3d, 0xc4, 0xb8, 0x5e,
		0x70, 0x0b, 0xc9, 0x28, 0xbe, 0x75, 0x94, 0x06, 0x33, 0x9b, 0xc6, 0x1d, 0x71, 0xa7, 0x85, 0xea,
		0x88, 0x0e, 0xbe, 0x30, 0x98, 0x58, 0x4a, 0x59, 0xf0, 0x35, 0xe6, 0x51, 0x16, 0x5c, 0xa3, 0x2f,
		0x52, 0x16, 0x5c, 0x6b, 0xe4, 0x50, 0x16, 0x4c, 0xd9, 0x60, 0xca, 0x82, 0x1b, 0x5c, 0x86, 0x65,
		0x49, 0x16, 0x84, 0x3b, 0xf6, 0x6b, 0x11, 0x8c, 0x83, 0x1c, 0x03, 0x46, 0x52, 0xfb, 0x9a, 0x31,
		0x0c, 0xfa, 0xc3, 0xca, 0xd3, 0xef, 0xe1, 0x93, 0xda, 0xc4, 0x52, 0x92, 0x5a, 0x92, 0x5a, 0x92,
		0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x06, 0xc5, 0xf4,
		0x18, 0xf6, 0xfd, 0x50, 0xcb, 0x2c, 0x70, 0xda, 0x89, 0xa1, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4,
		0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0x0c, 0x8a, 0xe9, 0x31,
		0xd4, 0xa1, 0xaf, 0x22, 0xa9, 0xe5, 0x6d, 0x06, 0xf6, 0x25, 0x3d, 0xb3, 0x95, 0xc4, 0x96, 0xc4,
		0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0x16,
		0x81, 0x86, 0xa8, 0x53, 0x51, 0x2a, 0xd0, 0xbe, 0x96, 0x01, 0xe6, 0x06, 0x28, 0x27, 0x6a, 0x7f,
		0x15, 0x37, 0x7e, 0x7f, 0x7c, 0x00, 0xa5, 0x17, 0xf4, 0x85, 0x6a, 0x8f, 0x88, 0xa2, 0xab, 0x84,
		0xfe, 0x11, 0x84, 0xdf, 0x5d, 0xa9, 0x22, 0xed, 0xab, 0xb6, 0xf0, 0x5e, 0xbe, 0x11, 0xcd, 0xbc,
		0xe3, 0xf5, 0xc3, 0x40, 0x07, 0xed, 0xa0, 0x17, 0x25, 0x57, 0x5e, 0xeb, 0xba, 0xef, 0x85, 0xb2,
		0xe5, 0xf9, 0x5d, 0xe9, 0x46, 0x7e, 0x57, 0x46, 0xc9, 0x95, 0x27, 0xfb, 0xb7, 0x05, 0x37, 0x0a,
		0xb5, 0x70, 0xfb, 0x41, 0x4f, 0xb6, 0xef, 0x3d, 0x25, 0xe4, 0xf5, 0xd7, 0x56, 0x10, 0x46, 0xc9,
		0x95, 0xe7, 0x77, 0xbe, 0x8d, 0xd0, 0x4a, 0x2a, 0xb7, 0x1f, 0x44, 0xda, 0x0b, 0x83, 0x81, 0x16,
		0x51, 0xfc, 0xc5, 0x1b, 0xa8, 0xef, 0x2a, 0xf8, 0xa1, 0x5c, 0x5f, 0xeb, 0x50, 0xb6, 0x46, 0xdf,
		0x98, 0x79, 0x2b, 0x3e, 0x51, 0x93, 0xe7, 0x68, 0x22, 0x5b, 0x82, 0x72, 0xae, 0xfe, 0xff, 0xc4,
		0x3d, 0x62, 0x63, 0x5c, 0xe7, 0x54, 0x46, 0xba, 0xa2, 0x35, 0xd8, 0xa1, 0xff, 0x9f, 0xa4, 0x3a,
		0xe9, 0x89, 0x21, 0xab, 0x8c, 0xb0, 0xaa, 0x4a, 0xe7, 0x93, 0x7f, 0xf7, 0xcc, 0xb2, 0xfc, 0x61,
		0xa1, 0x50, 0x2a, 0x17, 0x0a, 0xb9, 0xf2, 0x41, 0x39, 0x77, 0x54, 0x2c, 0xe6, 0x4b, 0x79, 0xa0,
		0x4d, 0x5c, 0x4e, 0x2d, 0xec, 0x88, 0x50, 0x74, 0x3e, 0x0c, 0x5d, 0x4f, 0x0d, 0x7a, 0x3d, 0x46,
		0x24, 0x3e, 0x7c, 0x6e, 0x3e, 0x6c, 0x3a, 0x50, 0x07, 0x2c, 0x87, 0x83, 0xb6, 0x56, 0xe3, 0x12,
		0xe2, 0x2c, 0x7e, 0x7a, 0xd5, 0xf1, 0xc3, 0x6b, 0x9e, 0x8f, 0x1f, 0x59, 0xf3, 0xc3, 0x75, 0xbf,
		0x59, 0x97, 0xad, 0x66, 0xa5, 0x2b, 0x2f, 0xfc, 0xae, 0x6c, 0x56, 0xfb, 0xb7, 0x85, 0x8b, 0x50,
		0x8b, 0xf3, 0xd1, 0x53, 0x6a, 0x9e, 0x8d, 0x9f, 0x4d, 0xb3, 0xd2, 0xf9, 0x56, 0x97, 0xad, 0xaa,
		0x3a, 0x0f, 0x22, 0xdd, 0xac, 0x0f, 0x9f, 0x48, 0xf3, 0x73, 0xfc, 0xe7, 0x57, 0x92, 0xbf, 0xfe,
		0x0d, 0xc1, 0xd9, 0xbe, 0x05, 0x96, 0x93, 0x10, 0x5a, 0xf2, 0xd9, 0xb4, 0xa4, 0x63, 0x37, 0xc8,
		0xec, 0xb9, 0xb6, 0x9d, 0x3b, 0x5b, 0x0a, 0xa6, 0x09, 0xa7, 0x1e, 0x7a, 0xad, 0x2b, 0x3b, 0x3b,
		0x42, 0x75, 0xfa, 0x81, 0x54, 0x7a, 0xa7, 0x1d, 0xf4, 0x82, 0xd0, 0x12, 0xca, 0x60, 0x10, 0x6a,
		0x1c, 0x02, 0x0d, 0x4d, 0x98, 0x31, 0x08, 0xb2, 0xad, 0xf0, 0x01, 0xc1, 0xa0, 0x4c, 0x63, 0x8f,
		0x45, 0x2e, 0x9b, 0x3e, 0x77, 0xb5, 0x83, 0xa2, 0xe6, 0x31, 0xcc, 0xec, 0x1d, 0x0d, 0x87, 0xbb,
		0xed, 0x30, 0xcf, 0x68, 0x78, 0x9b, 0xf5, 0x7d, 0x73, 0x1e, 0x68, 0xe6, 0x4e, 0x86, 0x7c, 0xdc,
		0x96, 0x6f, 0x67, 0xcd, 0xa7, 0x0d, 0xa2, 0x54, 0x9a, 0xa8, 0x64, 0x26, 0x26, 0xd3, 0x8f, 0x10,
		0x03, 0xd1, 0xe1, 0x3c, 0xf7, 0x80, 0xd0, 0xdc, 0x0c, 0xfe, 0x53, 0xaf, 0xef, 0xe9, 0xfb, 0x1b,
		0xca, 0x07, 0x93, 0x09, 0x76, 0x43, 0xb7, 0x33, 0xbd, 0xee, 0xcd, 0xc6, 0x3a, 0x36, 0xbb, 0xeb,
		0xd2, 0x6c, 0xad, 0x33, 0xb3, 0xbe, 0x6e, 0xcc, 0xfa, 0x3a, 0x30, 0xeb, 0xeb, 0xba, 0x36, 0x8b,
		0xa9, 0x1c, 0x4b, 0xb3, 0x8a, 0x90, 0x33, 0xa6, 0xb1, 0xc6, 0x03, 0x67, 0x92, 0x2e, 0xc6, 0xf7,
		0x37, 0xec, 0xb4, 0x66, 0x01, 0xc0, 0x1a, 0x10, 0xd8, 0x04, 0x04, 0x0c, 0x60, 0xb0, 0x0d, 0x10,
		0x30, 0x40, 0x01, 0x03, 0x18, 0x30, 0xc0, 0xb1, 0x1d, 0xb2, 0x8e, 0x69, 0x40, 0x99, 0x06, 0x16,
		0x7b, 0xf1, 0x36, 0x85, 0x2f, 0xb6, 0x62, 0xcd, 0x0e, 0xcc, 0x58, 0x87, 0x1b, 0x04, 0xd8, 0xc1,
		0x82, 0x1f, 0x14, 0x18, 0x82, 0x83, 0x23, 0x38, 0x58, 0x82, 0x83, 0x27, 0x3b, 0x30, 0x65, 0x09,
		0xae, 0xac, 0xc3, 0x56, 0x62, 0x40, 0xbc, 0x38, 0xc0, 0x7a, 0x9c, 0x4e, 0xb2, 0x97, 0xcd, 0xb5,
		0x0a, 0x2f, 0xe1, 0xcc, 0xf2, 0x3a, 0x5b, 0x98, 0x6d, 0xa4, 0x48, 0xdb, 0x45, 0x31, 0xb7, 0x85,
		0xa2, 0x6d, 0xff, 0x84, 0xdd, 0xe6, 0x09, 0xbb, 0x9d, 0x13, 0x76, 0xdb, 0xe6, 0x76, 0xaf, 0x0b,
		0x85, 0xd9, 0x6e, 0x99, 0xe4, 0x9d, 0x9e, 0xf0, 0xbb, 0xa1, 0xe8, 0x22, 0x24, 0x9d, 0x49, 0xd5,
		0x55, 0x06, 0xb0, 0xe5, 0x7c, 0x3c, 0xf7, 0xfb, 0xee, 0x5d, 0xbc, 0x0b, 0xcc, 0x8b, 0x81, 0x7c,
		0x5b, 0xd7, 0x9d, 0x5a, 0xac, 0xbc, 0x26, 0xcb, 0x3e, 0x71, 0x38, 0x5d, 0x62, 0x11, 0x69, 0x1d,
		0x69, 0x1d, 0x69, 0x1d, 0x69, 0x1d, 0x69, 0x1d, 0x69, 0x1d, 0x69, 0x5d, 0x26, 0x69, 0x5d, 0x82,
		0xe5, 0x64, 0x76, 0xc6, 0x07, 0x63, 0xbc, 0xb1, 0x07, 0x87, 0xd8, 0x4d, 0x0c, 0x22, 0xaf, 0x23,
		0xaf, 0x23, 0xaf, 0x23, 0xaf, 0x23, 0xaf, 0x23, 0xaf, 0x23, 0xaf, 0xcb, 0x24, 0xaf, 0x9b, 0x40,
		0x39, 0x69, 0x9d, 0xf1, 0xb1, 0x88, 0xbb, 0x66, 0xc1, 0x90, 0xba, 0xd8, 0x1c, 0x0c, 0x4a, 0x97,
		0x27, 0xa5, 0x23, 0xa5, 0x23, 0xa5, 0x23, 0xa5, 0x23, 0xa5, 0xb3, 0x35, 0x2a, 0xb6, 0x17, 0x28,
		0x25, 0x86, 0x8c, 0x5a, 0x05, 0x4a, 0xd5, 0x11, 0x38, 0x7d, 0xcb, 0x9f, 0x76, 0xf7, 0x3d, 0xd9,
		0x86, 0xd2, 0x5f, 0x11, 0xaa, 0x43, 0x3e, 0x5c, 0x47, 0x7c, 0xc4, 0x0e, 0xf8, 0xd8, 0x1d, 0xef,
		0x51, 0x3b, 0xdc, 0xc3, 0x77, 0xb4, 0x87, 0xef, 0x60, 0x0f, 0xdf, 0xb1, 0x9e, 0x9d, 0x73, 0x21,
		0x35, 0x16, 0x60, 0xad, 0x05, 0x51, 0x73, 0x99, 0xa7, 0xbd, 0xfc, 0xc7, 0xbf, 0x11, 0xa5, 0x88,
		0x84, 0x8e, 0x92, 0xab, 0xb1, 0x52, 0x13, 0xd3, 0x0c, 0x76, 0xcd, 0x44, 0x09, 0x4a, 0x90, 0x15,
		0xf4, 0x33, 0xd1, 0x88, 0xb0, 0x92, 0x9e, 0x74, 0x94, 0x74, 0x94, 0x74, 0x94, 0x74, 0x94, 0x74,
		0x94, 0x74, 0xd4, 0x78, 0xde, 0x1a, 0x48, 0xa5, 0x0f, 0xf6, 0x01, 0xd9, 0x28, 0x12, 0x19, 0xad,
		0xfb, 0xea, 0x7a, 0xf8, 0xb4, 0xae, 0xa0, 0x72, 0x00, 0xe0, 0xe9, 0x3d, 0x9f, 0xa4, 0xc2, 0x3d,
		0xb9, 0x13, 0xfc, 0x3c, 0xcc, 0xbf, 0xfd, 0xde, 0x40, 0x00, 0xdb, 0xf7, 0x31, 0xf4, 0xdb, 0x5a,
		0x06, 0xea, 0x58, 0x5e, 0xcb, 0xb8, 0x41, 0x34, 0xcf, 0xb4, 0xfd, 0x9d, 0x90, 0xf0, 0xef, 0x18,
		0x12, 0x2b, 0x86, 0x44, 0x61, 0xff, 0xa8, 0x70, 0x54, 0x2a, 0xef, 0x1f, 0x15, 0x19, 0x1b, 0xd9,
		0x26, 0x64, 0x78, 0xd6, 0x34, 0x28, 0x12, 0xa1, 0xe4, 0x4e, 0xa7, 0x1d, 0xdc, 0xdc, 0x0c, 0x94,
		0xd4, 0xf7, 0xa8, 0x53, 0x98, 0x2f, 0x0d, 0xa4, 0x70, 0x34, 0xcf, 0x1c, 0x0a, 0x47, 0x4b, 0xb8,
		0x14, 0x85, 0xa3, 0xa5, 0x3c, 0x9d, 0xc2, 0xd1, 0x8a, 0x06, 0x52, 0x38, 0xca, 0x50, 0x25, 0xc1,
		0x79, 0xcc, 0x57, 0xc0, 0x60, 0x06, 0xe7, 0x31, 0x27, 0xbc, 0x42, 0x8a, 0x28, 0xb9, 0xbe, 0xe7,
		0x54, 0x26, 0x26, 0x4b, 0x85, 0xe9, 0x1d, 0x31, 0x13, 0x93, 0x20, 0x3d, 0x24, 0xc8, 0x4b, 0xc9,
		0x4b, 0xc9, 0x4b, 0xc9, 0x4b, 0xc9, 0x4b, 0xc9, 0x4b, 0x8d, 0xe7, 0x2d, 0xd9, 0x77, 0xfd, 0x4e,
		0x27, 0x14, 0x51, 0x84, 0x48, 0x4d, 0x8f, 0x80, 0x6c, 0x1a, 0x8f, 0x21, 0x27, 0x35, 0x7f, 0xdb,
		0xb3, 0x6e, 0x0b, 0x80, 0xbe, 0x35, 0xe3, 0x63, 0x87, 0x80, 0xb6, 0x9d, 0xfb, 0x5a, 0x8b, 0x50,
		0xc1, 0xb9, 0x5b, 0x62, 0xe0, 0xbf, 0xbb, 0xbb, 0x57, 0x39, 0xf7, 0xa8, 0xf1, 0x70, 0x95, 0x77,
		0x8f, 0x1a, 0xf1, 0x65, 0x7e, 0xf4, 0x25, 0xbe, 0xde, 0xbf, 0xca, 0xb9, 0x85, 0xc9, 0x75, 0xf1,
		0x2a, 0xe7, 0x16, 0x1b, 0x7b, 0x5f, 0xbe, 0xbc, 0xdb, 0xfb, 0x79, 0xf0, 0xb8, 0xfc, 0x07, 0xff,
		0x70, 0xe0, 0x1e, 0x42, 0x03, 0xd1, 0x69, 0x6a, 0x17, 0xd5, 0x7f, 0xe8, 0x39, 0xe8, 0x9e, 0x83,
		0x35, 0xb1, 0xf8, 0x96, 0x70, 0xf6, 0xdb, 0x70, 0x56, 0x22, 0x9c, 0x6d, 0x36, 0x9c, 0xf9, 0x6e,
		0xb7, 0xe2, 0x7e, 0x6c, 0xfc, 0xcc, 0xbf, 0x2d, 0x3c, 0xbe, 0xdf, 0xfb, 0x59, 0x7e, 0x7c, 0xf9,
		0xe6, 0xc3, 0xbc, 0x1f, 0xcb, 0xbf, 0x2d, 0x3f, 0xbe, 0x5f, 0xf0, 0x9d, 0xd2, 0xe3, 0xfb, 0xdf,
		0xfc, 0x1d, 0xc5, 0xc7, 0xdd, 0x99, 0x1f, 0x1d, 0xbe, 0xbf, 0xbf, 0xe8, 0x03, 0x85, 0x05, 0x1f,
		0x38, 0x58, 0xf4, 0x81, 0x83, 0x05, 0x1f, 0x58, 0x68, 0xd2, 0xfe, 0x82, 0x0f, 0x14, 0x1f, 0x1f,
		0x66, 0x7e, 0x7e, 0x77, 0xfe, 0x8f, 0x96, 0x1e, 0xf7, 0x1e, 0x16, 0x7d, 0xaf, 0xfc, 0xf8, 0xf0,
		0x7e, 0x8f, 0xe0, 0xbe, 0x81, 0xe0, 0xce, 0x38, 0x62, 0x1c, 0xe1, 0x51, 0x1d, 0xae, 0xa1, 0x02,
		0x7b, 0x1e, 0x10, 0xb3, 0x53, 0x77, 0xda, 0x85, 0x5f, 0x47, 0x35, 0xcf, 0x48, 0xce, 0x59, 0xcd,
		0x33, 0x87, 0x73, 0x56, 0x4b, 0xb8, 0x15, 0xe7, 0xac, 0x96, 0xf2, 0x74, 0xce, 0x59, 0xad, 0x68,
		0x20, 0xe7, 0xac, 0x32, 0x24, 0xc9, 0x70, 0x2d, 0xd5, 0x6b, 0xd4, 0x97, 0xec, 0xad, 0xa5, 0x7a,
		0xce, 0x2d, 0xa4, 0x88, 0xa6, 0xfe, 0xcf, 0x35, 0x55, 0xa0, 0xac, 0x55, 0xaa, 0x5b, 0xbf, 0x27,
		0x3b, 0x6e, 0x28, 0xfc, 0x28, 0x50, 0x78, 0x84, 0xf5, 0x85, 0x7d, 0xe4, 0xaa, 0xe4, 0xaa, 0xe4,
		0xaa, 0xe4, 0xaa, 0xe4, 0xaa, 0xe4, 0xaa, 0x5b, 0xc6, 0x55, 0x65, 0x47, 0x28, 0x2d, 0xf5, 0x3d,
		0x28, 0x5f, 0x05, 0xda, 0x21, 0xec, 0x54, 0xc7, 0x8f, 0xea, 0x83, 0x1f, 0x01, 0xa6, 0xd4, 0xc9,
		0x80, 0x56, 0xcf, 0xfe, 0xae, 0x9c, 0x56, 0x8f, 0x9b, 0xf5, 0xda, 0xe7, 0xcb, 0x93, 0x66, 0xfd,
		0xa4, 0x72, 0x51, 0x3b, 0x43, 0xcb, 0xae, 0xa3, 0x8d, 0xe0, 0x11, 0xe4, 0x34, 0x11, 0xe8, 0xce,
		0xfe, 0x97, 0xa3, 0xfb, 0xe7, 0xe9, 0xe7, 0x8b, 0xcb, 0x93, 0x7a, 0xf3, 0xb4, 0x56, 0x3b, 0x77,
		0xd8, 0xb8, 0x61, 0x63, 0xc6, 0xb5, 0x72, 0xc1, 0x21, 0xdd, 0xb0, 0x21, 0xad, 0xd5, 0xab, 0x7f,
		0x55, 0xcf, 0x2a, 0x97, 0xb5, 0x3a, 0x47, 0x75, 0x83, 0x12, 0x70, 0xed, 0xec, 0xe3, 0xc9, 0xb1,
		0xc3, 0xbe, 0x20, 0xff, 0xf9, 0x6a, 0xb0, 0x1e, 0x01, 0xb3, 0x02, 0x41, 0x1d, 0xec, 0xf9, 0x91,
		0x76, 0x6f, 0x82, 0x8e, 0xec, 0x4a, 0xd1, 0xc1, 0x13, 0x07, 0xa7, 0xcd, 0xa3, 0x36, 0x38, 0xcf,
		0x1c, 0x6a, 0x83, 0x4b, 0x38, 0x14, 0xb5, 0xc1, 0xa5, 0x3c, 0x9d, 0xda, 0xe0, 0x8a, 0x06, 0x52,
		0x1b, 0xcc, 0x10, 0xf7, 0x05, 0xd6, 0x06, 0xb5, 0xbc, 0x11, 0x5a, 0xb6, 0xbf, 0x47, 0xa5, 0x02,
		0xa0, 0x36, 0x08, 0xb4, 0x91, 0xc0, 0xf9, 0xac, 0xe2, 0x3e, 0x81, 0x8e, 0xf2, 0x55, 0x10, 0x89,
		0x76, 0xa0, 0x3a, 0x50, 0xfb, 0x55, 0xd9, 0xf1, 0xf6, 0x37, 0x1f, 0x14, 0x3b, 0xde, 0xbe, 0xde,
		0x3c, 0x76, 0xbc, 0xdd, 0x44, 0x3d, 0x86, 0x1d, 0x6f, 0xd7, 0x10, 0x12, 0xf9, 0xc3, 0x42, 0xa1,
		0x54, 0x2e, 0x14, 0x72, 0xe5, 0x83, 0x72, 0xee, 0xa8, 0x58, 0xcc, 0x97, 0xf2, 0xec, 0x7d, 0x9b,
		0x71, 0xfe, 0x88, 0x67, 0x0d, 0xf7, 0x6d, 0xc0, 0x64, 0x51, 0x67, 0x72, 0xb6, 0x38, 0x9c, 0xba,
		0x35, 0x31, 0x0c, 0xa4, 0xfa, 0x39, 0x16, 0x5d, 0x7f, 0xd0, 0x1b, 0x95, 0xaa, 0x39, 0x6a, 0x6d,
		0x73, 0xcd, 0xa1, 0xd6, 0xb6, 0x84, 0x7b, 0x53, 0x6b, 0x5b, 0xca, 0xd3, 0xa9, 0xb5, 0xad, 0x68,
		0x20, 0xb5, 0xb6, 0x0c, 0xd5, 0x35, 0x3c, 0xb8, 0x69, 0x79, 0x14, 0xe4, 0xc1, 0x4d, 0xbf, 0x7a,
		0x51, 0xc6, 0xda, 0xc8, 0x9a, 0x9d, 0x32, 0x56, 0xd6, 0xd3, 0xfd, 0x74, 0x48, 0x50, 0xc6, 0x5a,
		0x39, 0x24, 0x78, 0x70, 0xd3, 0xa6, 0x10, 0x32, 0x3c, 0x6b, 0x28, 0x5e, 0xc1, 0xe4, 0x4e, 0x67,
		0xbc, 0x39, 0x32, 0x18, 0x68, 0x81, 0x27, 0x60, 0x3d, 0x37, 0x8e, 0x82, 0xd1, 0x3c, 0x73, 0x28,
		0x18, 0x2d, 0xe1, 0x4e, 0x14, 0x8c, 0x96, 0xf2, 0x74, 0x0a, 0x46, 0x2b, 0x1a, 0x48, 0xc1, 0x28,
		0x43, 0x15, 0x04, 0xb0, 0x60, 0xd4, 0x0a, 0x82, 0x9e, 0xf0, 0x15, 0xe2, 0xa6, 0xcd, 0x3c, 0xa9,
		0x1c, 0x80, 0x05, 0x96, 0x43, 0xc8, 0xa9, 0x28, 0x15, 0x68, 0x7f, 0x58, 0x8d, 0x41, 0x04, 0x90,
		0x13, 0xb5, 0xbf, 0x8a, 0x1b, 0xbf, 0x3f, 0x6e, 0x3a, 0xe3, 0x05, 0x7d, 0xa1, 0xda, 0x23, 0xa2,
		0xe4, 0x2a, 0xa1, 0x7f, 0x04, 0xe1, 0x77, 0x57, 0xaa, 0x48, 0xfb, 0xaa, 0x2d, 0xbc, 0x97, 0x6f,
		0x44, 0x33, 0xef, 0x78, 0xfd, 0x30, 0xd0, 0x41, 0x3b, 0xe8, 0x45, 0xc9, 0x95, 0xd7, 0xba, 0xee,
		0x7b, 0xa1, 0x6c, 0x79, 0x7e, 0x57, 0xba, 0x91, 0xdf, 0x95, 0x51, 0x72, 0xe5, 0x8d, 0xce, 0x1a,
		0x88, 0x42, 0x2d, 0xdc, 0x7e, 0xd0, 0x93, 0xed, 0x7b, 0x4f, 0x09, 0x79, 0xfd, 0xb5, 0x15, 0x84,
		0x51, 0x72, 0xe5, 0xf9, 0x9d, 0x6f, 0x23, 0x34, 0x90, 0xca, 0xed, 0x87, 0xc2, 0x1b, 0x11, 0xdc,
		0x28, 0xfe, 0x12, 0xb7, 0xb9, 0xb1, 0x8b, 0x11, 0xf6, 0x9c, 0xd9, 0xa2, 0x23, 0x3b, 0x03, 0xf5,
		0x5d, 0x05, 0x3f, 0x94, 0xeb, 0x6b, 0x1d, 0xca, 0xd6, 0x70, 0x44, 0xac, 0x3b, 0xf3, 0xd3, 0x94,
		0xc1, 0xac, 0x6d, 0x96, 0x43, 0x7e, 0x02, 0x00, 0x96, 0xcd, 0x40, 0xa9, 0x7f, 0x90, 0xea, 0x1e,
		0xcc, 0x7a, 0x07, 0xad, 0xce, 0x81, 0xad, 0x6f, 0x60, 0xeb, 0x1a, 0xd8, 0x7a, 0x66, 0xbb, 0xc9,
		0xd7, 0xb1, 0x0c, 0x31, 0xd2, 0xce, 0x0c, 0x48, 0xe1, 0x09, 0x8a, 0xb3, 0x26, 0x62, 0xc9, 0x8a,
		0x79, 0xca, 0x8a, 0xf0, 0xf0, 0x8a, 0x0d, 0xb3, 0xa8, 0x70, 0x0b, 0x0f, 0xbb, 0xf0, 0xf0, 0x0b,
		0x0f, 0xc3, 0x38, 0x6a, 0xcc, 0x0e, 0x90, 0xac, 0x88, 0x02, 0xcf, 0x89, 0x41, 0x43, 0xec, 0x73,
		0x35, 0x9a, 0xd8, 0x39, 0x95, 0x51, 0x9f, 0x4c, 0x04, 0x0b, 0x3d, 0xcc, 0xc5, 0x1b, 0x70, 0x70,
		0x8d, 0x0c, 0xdb, 0xd9, 0x80, 0x6f, 0x74, 0x18, 0xcf, 0x0c, 0x9c, 0x67, 0x06, 0xd6, 0x33, 0x03,
		0xef, 0x58, 0x30, 0x0f, 0x06, 0xf7, 0xc9, 0x28, 0x5e, 0x22, 0x02, 0xec, 0x0e, 0xf6, 0xd1, 0x05,
		0x33, 0xd5, 0x70, 0x19, 0xf3, 0x00, 0xc9, 0xc9, 0x51, 0x06, 0xf1, 0x89, 0x04, 0x4f, 0x64, 0x85,
		0xcb, 0xfd, 0xd0, 0x43, 0xd3, 0x89, 0x67, 0xd7, 0x60, 0x89, 0x6f, 0x6c, 0x1e, 0x26, 0xe9, 0xcd,
		0x93, 0xf4, 0x92, 0xf4, 0x92, 0xf4, 0x92, 0xf4, 0x92, 0xf4, 0x12, 0x59, 0xe7, 0x8f, 0x22, 0x9a,
		0xd6, 0x95, 0x18, 0x36, 0xe2, 0x68, 0x3d, 0x01, 0xbc, 0x53, 0x6e, 0x4a, 0xfa, 0x1a, 0x5a, 0xfa,
		0x96, 0xdb, 0x97, 0x36, 0x88, 0x14, 0x64, 0x81, 0x1c, 0x64, 0x8b, 0x24, 0x64, 0x85, 0x2c, 0x64,
		0x8e, 0x34, 0x64, 0x8e, 0x3c, 0x64, 0x8e, 0x44, 0x60, 0x92, 0x09, 0x50, 0x52, 0x91, 0x8c, 0x2e,
		0xac, 0xa2, 0x36, 0x93, 0x37, 0x07, 0x52, 0xe9, 0x7c, 0x09, 0x39, 0x67, 0x8e, 0x51, 0xbc, 0x04,
		0x6c, 0x22, 0x66, 0x03, 0x88, 0x97, 0x2f, 0x6c, 0xcc, 0xd9, 0x41, 0x6f, 0x10, 0x91, 0x31, 0x7a,
		0x39, 0x63, 0x2e, 0x78, 0x03, 0x89, 0x19, 0x7b, 0x33, 0xb0, 0x69, 0x3e, 0x23, 0x70, 0x34, 0x1d,
		0x62, 0xfe, 0x1d, 0x43, 0x2c, 0xe5, 0x10, 0x2b, 0x15, 0x8b, 0x07, 0x45, 0x86, 0xd9, 0x76, 0x71,
		0x51, 0x7c, 0xeb, 0x1a, 0x6f, 0xf8, 0xbc, 0x32, 0x9a, 0xc6, 0x81, 0x57, 0xc2, 0xcd, 0x94, 0x14,
		0xa8, 0x2b, 0xe2, 0x32, 0x82, 0x2a, 0xd4, 0x05, 0xd7, 0xe9, 0x8c, 0xd4, 0x05, 0xd7, 0x1a, 0x39,
		0xd4, 0x05, 0x53, 0x36, 0x98, 0xba, 0xe0, 0x06, 0x17, 0x62, 0x19, 0xd3, 0x05, 0x0f, 0x33, 0x20,
		0x0b, 0x16, 0x29, 0x0b, 0xae, 0xf8, 0xa2, 0x2c, 0x48, 0xcd, 0x82, 0xb2, 0xe0, 0x16, 0xa2, 0xd1,
		0x74, 0x88, 0x51, 0x16, 0x4c, 0x3d, 0xc4, 0xf6, 0x8b, 0x14, 0x05, 0xb7, 0x8c, 0x88, 0xe2, 0x5b,
		0x47, 0x51, 0x30, 0xb3, 0x49, 0x3c, 0x56, 0xda, 0x6e, 0xc7, 0xd9, 0x25, 0x0b, 0xaa, 0x60, 0x6c,
		0x2b, 0x65, 0xc1, 0xd7, 0x98, 0x47, 0x59, 0x70, 0x8d, 0xde, 0x48, 0x59, 0x70, 0xad, 0x91, 0x43,
		0x59, 0x30, 0x65, 0x83, 0x29, 0x0b, 0x6e, 0x70, 0x21, 0x96, 0x21, 0x59, 0xb0, 0x25, 0x95, 0x1f,
		0xde, 0x67, 0x40, 0x17, 0x3c, 0x02, 0x36, 0xf1, 0x54, 0xa8, 0xeb, 0xd1, 0xc6, 0x5c, 0x0a, 0x83,
		0xab, 0xaa, 0x16, 0x14, 0x06, 0x53, 0x57, 0x2d, 0xf2, 0xd4, 0x2c, 0xb6, 0x0c, 0x8f, 0xa6, 0x43,
		0x8c, 0xc2, 0x60, 0xea, 0x21, 0xc6, 0xf5, 0x82, 0x5b, 0x48, 0x46, 0xf1, 0xad, 0xa3, 0x34, 0x98,
		0xd9, 0x34, 0xee, 0x88, 0x3b, 0x2d, 0x54, 0x47, 0x74, 0xf0, 0x85, 0xc1, 0xc4, 0x52, 0xca, 0x82,
		0xaf, 0x31, 0x8f, 0xb2, 0xe0, 0x1a, 0x7d, 0x91, 0xb2, 0xe0, 0x5a, 0x23, 0x87, 0xb2, 0x60, 0xca,
		0x06, 0x53, 0x16, 0xdc, 0xe0, 0x32, 0x2c, 0x4b, 0xb2, 0x20, 0xdc, 0xa9, 0x5f, 0x8b, 0x60, 0x1c,
		0xe4, 0x14, 0x30, 0x92, 0xda, 0xd7, 0x8c, 0x61, 0xd0, 0x1f, 0x56, 0x9e, 0x7e, 0x0f, 0x9f, 0xd4,
		0x26, 0x96, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4,
		0x92, 0xd4, 0x92, 0xd4, 0x32, 0x28, 0xa6, 0xc7, 0xb0, 0xef, 0x87, 0x5a, 0x66, 0x81, 0xd3, 0x4e,
		0x0c, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25,
		0xa5, 0x25, 0xa5, 0x65, 0x50, 0x4c, 0x8f, 0xa1, 0x0e, 0x7d, 0x15, 0x49, 0x2d, 0x6f, 0x33, 0xb0,
		0x2f, 0xe9, 0x99, 0xad, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6,
		0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0xb4, 0x08, 0x34, 0x44, 0x9d, 0x8a, 0x52, 0x81, 0xf6, 0xb5,
		0x0c, 0x30, 0x37, 0x40, 0x39, 0x51, 0xfb, 0xab, 0xb8, 0xf1, 0xfb, 0xe3, 0x03, 0x28, 0xbd, 0xa0,
		0x2f, 0x54, 0x7b, 0x44, 0x14, 0x5d, 0x25, 0xf4, 0x8f, 0x20, 0xfc, 0xee, 0x4a, 0x15, 0x69, 0x5f,
		0xb5, 0x85, 0xf7, 0xf2, 0x8d, 0x68, 0xe6, 0x1d, 0xaf, 0x1f, 0x06, 0x3a, 0x68, 0x07, 0xbd, 0x28,
		0xb9, 0xf2, 0x5a, 0xd7, 0x7d, 0x2f, 0x94, 0x2d, 0xcf, 0xef, 0x4a, 0x37, 0xf2, 0xbb, 0x32, 0x4a,
		0xae, 0x3c, 0xd9, 0xbf, 0x2d, 0xb8, 0x51, 0xa8, 0x85, 0xdb, 0x0f, 0x7a, 0xb2, 0x7d, 0xef, 0x29,
		0x21, 0xaf, 0xbf, 0xb6, 0x82, 0x30, 0x4a, 0xae, 0x3c, 0xbf, 0xf3, 0x6d, 0x84, 0x56, 0x52, 0xb9,
		0xfd, 0x50, 0x78, 0x61, 0x30, 0xd0, 0x22, 0x8a, 0xbf, 0x78, 0x03, 0xf5, 0x5d, 0x05, 0x3f, 0x94,
		0xeb, 0x6b, 0x1d, 0xca, 0xd6, 0xe8, 0x1b, 0x33, 0x6f, 0xc5, 0x07, 0x6a, 0xf2, 0x18, 0x4d, 0x64,
		0x4b, 0x50, 0x8e, 0xd5, 0xff, 0x9f, 0xb8, 0x47, 0xec, 0x8b, 0xeb, 0x9c, 0xca, 0x48, 0x57, 0xb4,
		0x06, 0x3b, 0xf3, 0xff, 0x93, 0x54, 0x27, 0x3d, 0x31, 0x24, 0x95, 0x11, 0x56, 0x51, 0xe9, 0x7c,
		0xf2, 0xef, 0x9e, 0x59, 0x96, 0x3f, 0x2c, 0x14, 0x4a, 0xe5, 0x42, 0x21, 0x57, 0x3e, 0x28, 0xe7,
		0x8e, 0x8a, 0xc5, 0x7c, 0x29, 0x0f, 0xb4, 0x87, 0xcb, 0xa9, 0x85, 0x1d, 0x11, 0x8a, 0xce, 0x87,
		0xa1, 0xeb, 0xa9, 0x41, 0xaf, 0xc7, 0x88, 0xc4, 0x47, 0xcf, 0x8d, 0x47, 0x4d, 0x07, 0xea, 0x78,
		0xe5, 0x70, 0xd0, 0xd6, 0x6a, 0x5c, 0x40, 0x9c, 0xc5, 0x0f, 0xaf, 0x3a, 0x7e, 0x76, 0xcd, 0xf3,
		0xf1, 0x13, 0x6b, 0x7e, 0xb8, 0xee, 0x37, 0xeb, 0xb2, 0xd5, 0xac, 0x74, 0xe5, 0x85, 0xdf, 0x95,
		0xcd, 0x6a, 0xff, 0xb6, 0x70, 0x11, 0x6a, 0x71, 0x3e, 0x7a, 0x48, 0xcd, 0xb3, 0xf1, 0xa3, 0x69,
		0x56, 0x3a, 0xdf, 0xea, 0xb2, 0x55, 0x55, 0xe7, 0xa1, 0x68, 0xd6, 0x87, 0x0f, 0xa4, 0xf9, 0x39,
		0xfe, 0xeb, 0x2b, 0xc9, 0x1f, 0xff, 0x86, 0xd0, 0x6c, 0xdf, 0x02, 0xcb, 0x29, 0x08, 0x2d, 0xf5,
		0x6c, 0x58, 0xca, 0xb1, 0x1b, 0x63, 0xf6, 0x3c, 0xdb, 0xce, 0x9d, 0x2d, 0xc5, 0xd2, 0x84, 0x50,
		0x0f, 0x9d, 0xd6, 0x95, 0x9d, 0x1d, 0xa1, 0x3a, 0xfd, 0x40, 0x2a, 0xbd, 0xd3, 0x0e, 0x7a, 0x41,
		0x68, 0x09, 0x63, 0x30, 0xd8, 0x34, 0x0e, 0x7b, 0x86, 0x66, 0xcb, 0x18, 0xec, 0xd8, 0x56, 0xf8,
		0x80, 0x40, 0x50, 0x96, 0xa1, 0xc7, 0x22, 0x91, 0x4d, 0x9d, 0xb8, 0xda, 0xc1, 0x50, 0xf3, 0x08,
		0x66, 0xf6, 0x8e, 0x86, 0x83, 0xdd, 0x76, 0x90, 0x67, 0x33, 0xb8, 0xcd, 0xba, 0xbe, 0x39, 0x07,
		0x34, 0x73, 0x27, 0x43, 0x2e, 0x6e, 0xcb, 0xb5, 0x33, 0xe6, 0xd2, 0x06, 0x21, 0x2a, 0x45, 0x48,
		0x32, 0x13, 0x91, 0xe9, 0xc7, 0x87, 0x81, 0xd8, 0x70, 0x26, 0xe3, 0x1f, 0x0c, 0xb4, 0xdb, 0x0f,
		0x22, 0x6d, 0x2c, 0x3a, 0x9e, 0x9a, 0x7c, 0xbf, 0xb4, 0xc0, 0x50, 0x46, 0x98, 0xcc, 0xad, 0x1b,
		0xba, 0x9d, 0xe9, 0x25, 0x6f, 0x36, 0x96, 0xb0, 0xd9, 0x5d, 0x92, 0x66, 0x6b, 0x89, 0x99, 0xf5,
		0x25, 0x63, 0xd6, 0x97, 0x80, 0x59, 0x5f, 0xd2, 0xb5, 0x59, 0x5c, 0xe5, 0x58, 0x9a, 0x15, 0x84,
		0x9c, 0x31, 0x91, 0x35, 0x1e, 0x38, 0x93, 0x74, 0x31, 0xbe, 0xbf, 0x61, 0xa7, 0x35, 0x0b, 0x00,
		0xd6, 0x80, 0xc0, 0x26, 0x20, 0x60, 0x00, 0x83, 0x6d, 0x80, 0x80, 0x01, 0x0a, 0x18, 0xc0, 0x80,
		0x01, 0x8e, 0xed, 0xd0, 0x75, 0x4c, 0x03, 0xca, 0x34, 0xb0, 0xd8, 0x8b, 0xb7, 0x29, 0x7c, 0xb1,
		0x15, 0x6b, 0x76, 0x60, 0xc6, 0x3a, 0xdc, 0x20, 0xc0, 0x0e, 0x16, 0xfc, 0xa0, 0xc0, 0x10, 0x1c,
		0x1c, 0xc1, 0xc1, 0x12, 0x1c, 0x3c, 0xd9, 0x81, 0x29, 0x4b, 0x70, 0x65, 0x1d, 0xb6, 0x12, 0x03,
		0xe2, 0xb5, 0x01, 0xd6, 0xe3, 0x74, 0x92, 0xbd, 0x6c, 0x2e, 0x55, 0x78, 0x09, 0x67, 0x96, 0xd7,
		0xd8, 0xc2, 0xec, 0x20, 0x45, 0xda, 0x29, 0x8a, 0xb9, 0x23, 0x14, 0x6d, 0xe7, 0x27, 0xec, 0x0e,
		0x4f, 0xd8, 0x9d, 0x9c, 0xb0, 0x3b, 0x36, 0xb7, 0x7b, 0x55, 0x28, 0xcc, 0x4e, 0xcb, 0x24, 0xef,
		0xf4, 0x84, 0xdf, 0x0d, 0x45, 0x17, 0x21, 0xe9, 0x4c, 0xaa, 0xae, 0x32, 0x80, 0x2d, 0xe7, 0xe3,
		0xd9, 0xdf, 0x77, 0xef, 0xe2, 0x1d, 0x60, 0x5e, 0x0c, 0xe4, 0xdb, 0xba, 0xec, 0xd4, 0x62, 0xe5,
		0x35, 0x59, 0xf5, 0x89, 0xc3, 0xe9, 0x12, 0x8b, 0x48, 0xeb, 0x48, 0xeb, 0x48, 0xeb, 0x48, 0xeb,
		0x48, 0xeb, 0x48, 0xeb, 0x48, 0xeb, 0x32, 0x49, 0xeb, 0x12, 0x2c, 0x27, 0xb3, 0x33, 0x3e, 0x18,
		0xe3, 0x7d, 0x3d, 0x38, 0xc4, 0x6e, 0x62, 0x10, 0x79, 0x1d, 0x79, 0x1d, 0x79, 0x1d, 0x79, 0x1d,
		0x79, 0x1d, 0x79, 0x1d, 0x79, 0x5d, 0x26, 0x79, 0xdd, 0x04, 0xca, 0x49, 0xeb, 0x8c, 0x8f, 0x45,
		0xdc, 0x31, 0x0b, 0x86, 0xd4, 0xc5, 0xe6, 0x60, 0x50, 0xba, 0x3c, 0x29, 0x1d, 0x29, 0x1d, 0x29,
		0x1d, 0x29, 0x1d, 0x29, 0x9d, 0xad, 0x51, 0xb1, 0xbd, 0x40, 0x29, 0x31, 0x64, 0xd4, 0x26, 0x50,
		0xaa, 0x8e, 0xc0, 0x69, 0x59, 0xfe, 0xb4, 0xbf, 0xef, 0xc9, 0x36, 0x94, 0xde, 0x8a, 0x50, 0xcd,
		0xf1, 0xe1, 0x9a, 0xe1, 0x23, 0x36, 0xbf, 0xc7, 0x6e, 0x76, 0x8f, 0xda, 0xdc, 0x1e, 0xbe, 0x99,
		0x3d, 0x7c, 0xf3, 0x7a, 0xf8, 0x66, 0xf5, 0xec, 0x9a, 0x0b, 0xa9, 0xb1, 0x00, 0x6b, 0x2d, 0x88,
		0x9a, 0xcb, 0x3c, 0xed, 0xe5, 0x3f, 0xfe, 0x8d, 0x28, 0x45, 0x24, 0x74, 0x94, 0x5c, 0x8d, 0x95,
		0x9a, 0x98, 0x66, 0xb0, 0x67, 0x26, 0x4a, 0x50, 0x82, 0xac, 0xa0, 0x9f, 0x89, 0x46, 0x84, 0x95,
		0xf4, 0xa4, 0xa3, 0xa4, 0xa3, 0xa4, 0xa3, 0xa4, 0xa3, 0xa4, 0xa3, 0xa4, 0xa3, 0xc6, 0xf3, 0xd6,
		0x40, 0x2a, 0x7d, 0xb0, 0x0f, 0xc8, 0x46, 0x91, 0xc8, 0x68, 0xdd, 0x57, 0xd7, 0xc3, 0xa7, 0x75,
		0x05, 0x95, 0x03, 0x00, 0x0f, 0xee, 0xf9, 0x24, 0x15, 0xee, 0xa1, 0x9d, 0xe0, 0x47, 0x61, 0xfe,
		0xed, 0xf7, 0x06, 0x02, 0xd8, 0xbe, 0x8f, 0xa1, 0xdf, 0xd6, 0x32, 0x50, 0xc7, 0xf2, 0x5a, 0xc6,
		0xfd, 0xa1, 0x79, 0x9c, 0xed, 0xef, 0x84, 0x84, 0x7f, 0xc7, 0x90, 0x58, 0x31, 0x24, 0x0a, 0xfb,
		0x47, 0x85, 0xa3, 0x52, 0x79, 0xff, 0xa8, 0xc8, 0xd8, 0xc8, 0x36, 0x21, 0xc3, 0xb3, 0xa6, 0x41,
		0x91, 0x08, 0x25, 0x77, 0x3a, 0xed, 0xe0, 0xe6, 0x66, 0xa0, 0xa4, 0xbe, 0x47, 0x9d, 0xc2, 0x7c,
		0x69, 0x20, 0x85, 0xa3, 0x79, 0xe6, 0x50, 0x38, 0x5a, 0xc2, 0xa5, 0x28, 0x1c, 0x2d, 0xe5, 0xe9,
		0x14, 0x8e, 0x56, 0x34, 0x90, 0xc2, 0x51, 0x86, 0x2a, 0x09, 0xce, 0x63, 0xbe, 0x02, 0x06, 0x33,
		0x38, 0x8f, 0x39, 0xe1, 0x15, 0x52, 0x44, 0xc9, 0xf5, 0x3d, 0xa7, 0x32, 0x31, 0x59, 0x2a, 0x4c,
		0xef, 0x88, 0x99, 0x98, 0x04, 0xe9, 0x21, 0x41, 0x5e, 0x4a, 0x5e, 0x4a, 0x5e, 0x4a, 0x5e, 0x4a,
		0x5e, 0x4a, 0x5e, 0x6a, 0x3c, 0x6f, 0xc9, 0xbe, 0xeb, 0x77, 0x3a, 0xa1, 0x88, 0x22, 0x44, 0x6a,
		0x7a, 0x04, 0x64, 0xd3, 0x78, 0x0c, 0x39, 0xa9, 0xf9, 0xdb, 0x9e, 0x75, 0x5b, 0x00, 0xf4, 0xad,
		0x19, 0x1f, 0x3b, 0x04, 0xb4, 0xed, 0xdc, 0xd7, 0x5a, 0x84, 0x0a, 0xce, 0xdd, 0x12, 0x03, 0xff,
		0xdd, 0xdd, 0xbd, 0xca, 0xb9, 0x47, 0x8d, 0x87, 0xab, 0xbc, 0x7b, 0xd4, 0x88, 0x2f, 0xf3, 0xa3,
		0x2f, 0xf1, 0xf5, 0xfe, 0x55, 0xce, 0x2d, 0x4c, 0xae, 0x8b, 0x57, 0x39, 0xb7, 0xd8, 0xd8, 0xfb,
		0xf2, 0xe5, 0xdd, 0xde, 0xcf, 0x83, 0xc7, 0xe5, 0x3f, 0xf8, 0x87, 0x03, 0xf7, 0x10, 0x1a, 0x88,
		0x4e, 0x53, 0xbb, 0xa8, 0xfe, 0x43, 0xcf, 0x41, 0xf7, 0x1c, 0xac, 0x89, 0xc5, 0xb7, 0x84, 0xb3,
		0xdf, 0x86, 0xb3, 0x12, 0xe1, 0x6c, 0xb3, 0xe1, 0xcc, 0x77, 0xbb, 0x15, 0xf7, 0x63, 0xe3, 0x67,
		0xfe, 0x6d, 0xe1, 0xf1, 0xfd, 0xde, 0xcf, 0xf2, 0xe3, 0xcb, 0x37, 0x1f, 0xe6, 0xfd, 0x58, 0xfe,
		0x6d, 0xf9, 0xf1, 0xfd, 0x82, 0xef, 0x94, 0x1e, 0xdf, 0xff, 0xe6, 0xef, 0x28, 0x3e, 0xee, 0xce,
		0xfc, 0xe8, 0xf0, 0xfd, 0xfd, 0x45, 0x1f, 0x28, 0x2c, 0xf8, 0xc0, 0xc1, 0xa2, 0x0f, 0x1c, 0x2c,
		0xf8, 0xc0, 0x42, 0x93, 0xf6, 0x17, 0x7c, 0xa0, 0xf8, 0xf8, 0x30, 0xf3, 0xf3, 0xbb, 0xf3, 0x7f,
		0xb4, 0xf4, 0xb8, 0xf7, 0xb0, 0xe8, 0x7b, 0xe5, 0xc7, 0x87, 0xf7, 0x7b, 0x04, 0xf7, 0x0d, 0x04,
		0x77, 0xc6, 0x11, 0xe3, 0x08, 0x8f, 0xea, 0x70, 0x0d, 0x15, 0xd8, 0xf3, 0x80, 0x98, 0x9d, 0xba,
		0xd3, 0x2e, 0xfc, 0x3a, 0xaa, 0x79, 0x46, 0x72, 0xce, 0x6a, 0x9e, 0x39, 0x9c, 0xb3, 0x5a, 0xc2,
		0xad, 0x38, 0x67, 0xb5, 0x94, 0xa7, 0x73, 0xce, 0x6a, 0x45, 0x03, 0x39, 0x67, 0x95, 0x21, 0x49,
		0x86, 0x6b, 0xa9, 0x5e, 0xa3, 0xbe, 0x64, 0x6f, 0x2d, 0xd5, 0x73, 0x6e, 0x21, 0x45, 0x34, 0xf5,
		0x7f, 0xae, 0xa9, 0x02, 0x65, 0xad, 0x52, 0xdd, 0xfa, 0x3d, 0xd9, 0x71, 0x43, 0xe1, 0x47, 0x81,
		0xc2, 0x23, 0xac, 0x2f, 0xec, 0x23, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25,
		0x57, 0xdd, 0x32, 0xae, 0x2a, 0x3b, 0x42, 0x69, 0xa9, 0xef, 0x41, 0xf9, 0x2a, 0xd0, 0x0e, 0x61,
		0xa7, 0x3a, 0x7e, 0x54, 0x1f, 0xfc, 0x08, 0x30, 0xa5, 0x4e, 0x06, 0xb4, 0x7a, 0xf6, 0x77, 0xe5,
		0xb4, 0x7a, 0xdc, 0xac, 0xd7, 0x3e, 0x5f, 0x9e, 0x34, 0xeb, 0x27, 0x95, 0x8b, 0xda, 0x19, 0x5a,
		0x76, 0x1d, 0x6d, 0x04, 0x8f, 0x20, 0xa7, 0x89, 0x40, 0x77, 0xf6, 0xbf, 0x1c, 0xdd, 0x3f, 0x4f,
		0x3f, 0x5f, 0x5c, 0x9e, 0xd4, 0x9b, 0xa7, 0xb5, 0xda, 0xb9, 0xc3, 0xc6, 0x0d, 0x1b, 0x33, 0xae,
		0x95, 0x0b, 0x0e, 0xe9, 0x86, 0x0d, 0x69, 0xad, 0x5e, 0xfd, 0xab, 0x7a, 0x56, 0xb9, 0xac, 0xd5,
		0x39, 0xaa, 0x1b, 0x94, 0x80, 0x6b, 0x67, 0x1f, 0x4f, 0x8e, 0x1d, 0xf6, 0x05, 0xf9, 0xcf, 0x57,
		0x83, 0xf5, 0x08, 0x98, 0x15, 0x08, 0xea, 0x60, 0xcf, 0x8f, 0xb4, 0x7b, 0x13, 0x74, 0x64, 0x57,
		0x8a, 0x0e, 0x9e, 0x38, 0x38, 0x6d, 0x1e, 0xb5, 0xc1, 0x79, 0xe6, 0x50, 0x1b, 0x5c, 0xc2, 0xa1,
		0xa8, 0x0d, 0x2e, 0xe5, 0xe9, 0xd4, 0x06, 0x57, 0x34, 0x90, 0xda, 0x60, 0x86, 0xb8, 0x2f, 0xb0,
		0x36, 0xa8, 0xe5, 0x8d, 0xd0, 0xb2, 0xfd, 0x3d, 0x2a, 0x15, 0x00, 0xb5, 0x41, 0xa0, 0x8d, 0x04,
		0xce, 0x67, 0x15, 0xf7, 0x09, 0x74, 0x94, 0xaf, 0x82, 0x48, 0xb4, 0x03, 0xd5, 0x81, 0xda, 0xaf,
		0xca, 0x8e, 0xb7, 0xbf, 0xf9, 0xa0, 0xd8, 0xf1, 0xf6, 0xf5, 0xe6, 0xb1, 0xe3, 0xed, 0x26, 0xea,
		0x31, 0xec, 0x78, 0xbb, 0x86, 0x90, 0xc8, 0x1f, 0x16, 0x0a, 0xa5, 0x72, 0xa1, 0x90, 0x2b, 0x1f,
		0x94, 0x73, 0x47, 0xc5, 0x62, 0xbe, 0x94, 0x67, 0xef, 0xdb, 0x8c, 0xf3, 0x47, 0x3c, 0x6b, 0xb8,
		0x6f, 0x03, 0x26, 0x8b, 0x3a, 0x93, 0xb3, 0xc5, 0xe1, 0xd4, 0xad, 0x89, 0x61, 0x20, 0xd5, 0xcf,
		0xb1, 0xe8, 0xfa, 0x83, 0xde, 0xa8, 0x54, 0xcd, 0x51, 0x6b, 0x9b, 0x6b, 0x0e, 0xb5, 0xb6, 0x25,
		0xdc, 0x9b, 0x5a, 0xdb, 0x52, 0x9e, 0x4e, 0xad, 0x6d, 0x45, 0x03, 0xa9, 0xb5, 0x65, 0xa8, 0xae,
		0xe1, 0xc1, 0x4d, 0xcb, 0xa3, 0x20, 0x0f, 0x6e, 0xfa, 0xd5, 0x8b, 0x32, 0xd6, 0x46, 0xd6, 0xec,
		0x94, 0xb1, 0xb2, 0x9e, 0xee, 0xa7, 0x43, 0x82, 0x32, 0xd6, 0xca, 0x21, 0xc1, 0x83, 0x9b, 0x36,
		0x85, 0x90, 0xe1, 0x59, 0x43, 0xf1, 0x0a, 0x26, 0x77, 0x3a, 0xe3, 0xcd, 0x91, 0xc1, 0x40, 0x0b,
		0x3c, 0x01, 0xeb, 0xb9, 0x71, 0x14, 0x8c, 0xe6, 0x99, 0x43, 0xc1, 0x68, 0x09, 0x77, 0xa2, 0x60,
		0xb4, 0x94, 0xa7, 0x53, 0x30, 0x5a, 0xd1, 0x40, 0x0a, 0x46, 0x19, 0xaa, 0x20, 0x80, 0x05, 0xa3,
		0x56, 0x10, 0xf4, 0x84, 0xaf, 0x10, 0x37, 0x6d, 0xe6, 0x49, 0xe5, 0x00, 0x2c, 0xb0, 0x1c, 0x42,
		0x4e, 0x45, 0xa9, 0x40, 0xfb, 0xc3, 0x6a, 0x0c, 0x22, 0x80, 0x9c, 0xa8, 0xfd, 0x55, 0xdc, 0xf8,
		0xfd, 0x71, 0xd3, 0x19, 0x2f, 0xe8, 0x0b, 0xd5, 0x1e, 0x11, 0x25, 0x57, 0x09, 0xfd, 0x23, 0x08,
		0xbf, 0xbb, 0x52, 0x45, 0xda, 0x57, 0x6d, 0xe1, 0xbd, 0x7c, 0x23, 0x9a, 0x79, 0xc7, 0xeb, 0x87,
		0x81, 0x0e, 0xda, 0x41, 0x2f, 0x4a, 0xae, 0xbc, 0xd6, 0x75, 0xdf, 0x0b, 0x65, 0xcb, 0xf3, 0xbb,
		0xd2, 0x8d, 0xfc, 0xae, 0x8c, 0x92, 0x2b, 0x6f, 0x74, 0xd6, 0x40, 0x14, 0x6a, 0xe1, 0xf6, 0x83,
		0x9e, 0x6c, 0xdf, 0x7b, 0x4a, 0xc8, 0xeb, 0xaf, 0xad, 0x20, 0x8c, 0x92, 0x2b, 0xcf, 0xef, 0x7c,
		0x1b, 0xa1, 0x41, 0x30, 0xd0, 0x6e, 0x3f, 0x88, 0xb4, 0x37, 0xa2, 0xb8, 0x51, 0xfc, 0x25, 0x6e,
		0x74, 0x63, 0x17, 0x25, 0xec, 0xb9, 0xb3, 0x45, 0x57, 0x76, 0x06, 0xea, 0xbb, 0x0a, 0x7e, 0x28,
		0xd7, 0xd7, 0x3a, 0x94, 0xad, 0xe1, 0x88, 0x58, 0x77, 0xe7, 0xa7, 0x49, 0x83, 0x59, 0xdb, 0x2c,
		0x07, 0xfd, 0x04, 0x02, 0x2c, 0x9b, 0x81, 0x52, 0x01, 0x21, 0x55, 0x3e, 0x98, 0x15, 0x0f, 0x5a,
		0xa5, 0x03, 0x5b, 0xe1, 0xc0, 0x56, 0x36, 0xb0, 0x15, 0xcd, 0x76, 0xd3, 0xaf, 0x63, 0x19, 0x62,
		0xa4, 0x9d, 0x19, 0x90, 0xc2, 0x93, 0x14, 0x67, 0x4d, 0xc4, 0x12, 0x16, 0xf3, 0x14, 0x16, 0xe1,
		0xe1, 0x15, 0x1b, 0x66, 0x51, 0xe1, 0x16, 0x1e, 0x76, 0xe1, 0xe1, 0x17, 0x1e, 0x86, 0x71, 0xf4,
		0x98, 0x1d, 0x20, 0x61, 0x11, 0x05, 0x9e, 0x13, 0x83, 0x86, 0xd8, 0xe7, 0x6a, 0x34, 0xb9, 0x73,
		0x2a, 0xa3, 0x3e, 0x99, 0x08, 0x16, 0x7a, 0x98, 0xcb, 0x37, 0xe0, 0xe0, 0x1a, 0x19, 0xb6, 0xb3,
		0x01, 0xdf, 0xe8, 0x30, 0x9e, 0x19, 0x38, 0xcf, 0x0c, 0xac, 0x67, 0x06, 0xde, 0xb1, 0x60, 0x1e,
		0x0c, 0xee, 0x93, 0x51, 0xbc, 0x44, 0x04, 0xd8, 0x1d, 0xec, 0xc3, 0x0b, 0x66, 0xaa, 0xe1, 0x32,
		0xe6, 0x11, 0x92, 0x93, 0xc3, 0x0c, 0xe2, 0x33, 0x09, 0x9e, 0xc8, 0x0a, 0x17, 0xfc, 0xa1, 0x87,
		0xa6, 0x13, 0xcf, 0xae, 0xc1, 0x12, 0xdf, 0xd8, 0x3c, 0x4c, 0xd2, 0x9b, 0x27, 0xe9, 0x25, 0xe9,
		0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xb2, 0xce, 0x1f, 0x45, 0x34, 0xad, 0x2b, 0x31, 0x6c,
		0xc4, 0xd1, 0x7a, 0x02, 0x78, 0xaf, 0xdc, 0x94, 0xf4, 0x35, 0xb4, 0xf4, 0x2d, 0x37, 0x30, 0x6d,
		0x10, 0x29, 0xc8, 0x02, 0x39, 0xc8, 0x16, 0x49, 0xc8, 0x0a, 0x59, 0xc8, 0x1c, 0x69, 0xc8, 0x1c,
		0x79, 0xc8, 0x1c, 0x89, 0xc0, 0x24, 0x13, 0xa0, 0xa4, 0x22, 0x19, 0x5d, 0x58, 0x45, 0x6d, 0x26,
		0x6f, 0x0e, 0xa4, 0xd2, 0xf9, 0x12, 0x72, 0xce, 0x1c, 0xa3, 0x78, 0x09, 0xd8, 0x44, 0xcc, 0x16,
		0x10, 0x2f, 0x5f, 0xd8, 0x98, 0xb3, 0x83, 0xde, 0x22, 0x22, 0x63, 0xf4, 0x72, 0xc6, 0x5c, 0xf0,
		0x16, 0x12, 0x33, 0xf6, 0x66, 0x60, 0xdb, 0x7c, 0x46, 0xe0, 0x68, 0x3a, 0xc4, 0xfc, 0x3b, 0x86,
		0x58, 0xca, 0x21, 0x56, 0x2a, 0x16, 0x0f, 0x8a, 0x0c, 0xb3, 0xed, 0xe2, 0xa2, 0xf8, 0xd6, 0x35,
		0xde, 0xf0, 0x79, 0x65, 0x34, 0x8d, 0x03, 0xaf, 0x84, 0x9b, 0x29, 0x29, 0x50, 0x57, 0xc4, 0x65,
		0x04, 0x55, 0xa8, 0x0b, 0xae, 0xd3, 0x19, 0xa9, 0x0b, 0xae, 0x35, 0x72, 0xa8, 0x0b, 0xa6, 0x6c,
		0x30, 0x75, 0xc1, 0x0d, 0x2e, 0xc4, 0x32, 0xa6, 0x0b, 0x1e, 0x66, 0x40, 0x16, 0x2c, 0x52, 0x16,
		0x5c, 0xf1, 0x45, 0x59, 0x90, 0x9a, 0x05, 0x65, 0xc1, 0x2d, 0x44, 0xa3, 0xe9, 0x10, 0xa3, 0x2c,
		0x98, 0x7a, 0x88, 0xed, 0x17, 0x29, 0x0a, 0x6e, 0x19, 0x11, 0xc5, 0xb7, 0x8e, 0xa2, 0x60, 0x66,
		0x93, 0x78, 0xac, 0xb4, 0xdd, 0x8e, 0xb3, 0x4b, 0x16, 0x54, 0xc1, 0xd8, 0x56, 0xca, 0x82, 0xaf,
		0x31, 0x8f, 0xb2, 0xe0, 0x1a, 0xbd, 0x91, 0xb2, 0xe0, 0x5a, 0x23, 0x87, 0xb2, 0x60, 0xca, 0x06,
		0x53, 0x16, 0xdc, 0xe0, 0x42, 0x2c, 0x43, 0xb2, 0x60, 0x4b, 0x2a, 0x3f, 0xbc, 0xcf, 0x80, 0x2e,
		0x78, 0x04, 0x6c, 0xe2, 0xa9, 0x50, 0xd7, 0xa3, 0x8d, 0xb9, 0x14, 0x06, 0x57, 0x55, 0x2d, 0x28,
		0x0c, 0xa6, 0xae, 0x5a, 0xe4, 0xa9, 0x59, 0x6c, 0x19, 0x1e, 0x4d, 0x87, 0x18, 0x85, 0xc1, 0xd4,
		0x43, 0x8c, 0xeb, 0x05, 0xb7, 0x90, 0x8c, 0xe2, 0x5b, 0x47, 0x69, 0x30, 0xb3, 0x69, 0xdc, 0x11,
		0x77, 0x5a, 0xa8, 0x8e, 0xe8, 0xe0, 0x0b, 0x83, 0x89, 0xa5, 0x94, 0x05, 0x5f, 0x63, 0x1e, 0x65,
		0xc1, 0x35, 0xfa, 0x22, 0x65, 0xc1, 0xb5, 0x46, 0x0e, 0x65, 0xc1, 0x94, 0x0d, 0xa6, 0x2c, 0xb8,
		0xc1, 0x65, 0x58, 0x96, 0x64, 0x41, 0xb8, 0x73, 0xbf, 0x16, 0xc1, 0x38, 0xc8, 0x39, 0x60, 0x24,
		0xb5, 0xaf, 0x19, 0xc3, 0xa0, 0x3f, 0xac, 0x3c, 0xfd, 0x1e, 0x3e, 0xa9, 0x4d, 0x2c, 0x25, 0xa9,
		0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9,
		0x65, 0x50, 0x4c, 0x8f, 0x61, 0xdf, 0x0f, 0xb5, 0xcc, 0x02, 0xa7, 0x9d, 0x18, 0x4a, 0x4a, 0x4b,
		0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0xcb,
		0xa0, 0x98, 0x1e, 0x43, 0x1d, 0xfa, 0x2a, 0x92, 0x5a, 0xde, 0x66, 0x60, 0x5f, 0xd2, 0x33, 0x5b,
		0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c,
		0x49, 0x6c, 0x69, 0x11, 0x68, 0x88, 0x3a, 0x15, 0xa5, 0x02, 0xed, 0x6b, 0x19, 0x60, 0x6e, 0x80,
		0x72, 0xa2, 0xf6, 0x57, 0x71, 0xe3, 0xf7, 0xc7, 0x07, 0x50, 0x7a, 0x41, 0x5f, 0xa8, 0xf6, 0x88,
		0x28, 0xba, 0x4a, 0xe8, 0x1f, 0x41, 0xf8, 0xdd, 0x95, 0x2a, 0xd2, 0xbe, 0x6a, 0x0b, 0xef, 0xe5,
		0x1b, 0xd1, 0xcc, 0x3b, 0x5e, 0x3f, 0x0c, 0x74, 0xd0, 0x0e, 0x7a, 0x51, 0x72, 0xe5, 0xb5, 0xae,
		0xfb, 0x5e, 0x28, 0x5b, 0x9e, 0xdf, 0x95, 0x6e, 0xe4, 0x77, 0x65, 0x94, 0x5c, 0x79, 0xb2, 0x7f,
		0x5b, 0x70, 0xa3, 0x50, 0x0b, 0xb7, 0x1f, 0xf4, 0x64, 0xfb, 0xde, 0x53, 0x42, 0x5e, 0x7f, 0x6d,
		0x05, 0x61, 0x94, 0x5c, 0x79, 0x7e, 0xe7, 0xdb, 0x08, 0xad, 0x82, 0x81, 0x76, 0xfb, 0x41, 0xa4,
		0xbd, 0x30, 0x18, 0x68, 0x11, 0xc5, 0x5f, 0xbc, 0x81, 0xfa, 0xae, 0x82, 0x1f, 0xca, 0xf5, 0xb5,
		0x0e, 0x65, 0x6b, 0xf4, 0x8d, 0x99, 0xb7, 0xe2, 0x23, 0x35, 0x79, 0x90, 0x26, 0xb2, 0x25, 0x28,
		0x07, 0xeb, 0xff, 0x4f, 0xdc, 0x23, 0x76, 0xc6, 0x75, 0x4e, 0x65, 0xa4, 0x2b, 0x5a, 0x83, 0x9d,
		0xfa, 0xff, 0x49, 0xaa, 0x93, 0x9e, 0x18, 0xd2, 0xca, 0x08, 0xab, 0xac, 0x74, 0x3e, 0xf9, 0x77,
		0xcf, 0x2c, 0xcb, 0x1f, 0x16, 0x0a, 0xa5, 0x72, 0xa1, 0x90, 0x2b, 0x1f, 0x94, 0x73, 0x47, 0xc5,
		0x62, 0xbe, 0x94, 0x07, 0xda, 0xc5, 0xe5, 0xd4, 0xc2, 0x8e, 0x08, 0x45, 0xe7, 0xc3, 0xd0, 0xf5,
		0xd4, 0xa0, 0xd7, 0x63, 0x44, 0xe2, 0xe3, 0xe7, 0x16, 0xe0, 0xa6, 0x03, 0x75, 0xc4, 0x72, 0x38,
		0x68, 0x6b, 0x35, 0x2e, 0x22, 0xce, 0xe2, 0xc7, 0x57, 0x1d, 0x3f, 0xbd, 0xe6, 0xf9, 0xf8, 0x99,
		0x35, 0x3f, 0x5c, 0xf7, 0x9b, 0x75, 0xd9, 0x6a, 0x56, 0xba, 0xf2, 0xc2, 0xef, 0xca, 0x66, 0xb5,
		0x7f, 0x5b, 0xb8, 0x08, 0xb5, 0x38, 0x1f, 0x3d, 0xa6, 0xe6, 0xd9, 0xf8, 0xe1, 0x34, 0x2b, 0x9d,
		0x6f, 0x75, 0xd9, 0xaa, 0x0d, 0xf4, 0x79, 0x10, 0xe9, 0x66, 0x7d, 0xf8, 0x48, 0x9a, 0x9f, 0xe3,
		0xbf, 0xbf, 0x92, 0xfc, 0xf9, 0x6f, 0x08, 0xcf, 0xf6, 0x2d, 0xb0, 0x9c, 0x86, 0xd0, 0xd2, 0xcf,
		0xc6, 0xa5, 0x1d, 0xbb, 0x51, 0x66, 0xcf, 0xb7, 0xed, 0xdc, 0xd9, 0x52, 0x34, 0x4d, 0x68, 0xf5,
		0xd0, 0x6d, 0x5d, 0xd9, 0xd9, 0x11, 0xaa, 0xd3, 0x0f, 0xa4, 0xd2, 0x3b, 0xed, 0xa0, 0x17, 0x84,
		0x96, 0x70, 0x06, 0x83, 0x53, 0xe3, 0x70, 0x68, 0x68, 0xce, 0x8c, 0xc1, 0x91, 0x6d, 0x85, 0x0f,
		0x08, 0x08, 0x65, 0x1b, 0x7c, 0x2c, 0xd2, 0x59, 0x03, 0xf4, 0xd5, 0x0e, 0x8e, 0x9a, 0x47, 0x31,
		0xb3, 0x77, 0x34, 0x1c, 0xf0, 0xb6, 0x03, 0x3d, 0xab, 0x01, 0x6e, 0xd6, 0xf9, 0xcd, 0xb9, 0xa0,
		0x99, 0x3b, 0x19, 0x72, 0x72, 0x5b, 0xce, 0x9d, 0x39, 0xa7, 0x36, 0x08, 0x54, 0xa9, 0x02, 0x93,
		0x99, 0xa8, 0x4c, 0x3f, 0x46, 0x0c, 0xc4, 0x87, 0x33, 0xe5, 0x03, 0xa1, 0xb9, 0xb9, 0xfc, 0xa7,
		0xae, 0xdf, 0x2f, 0x0c, 0x30, 0x94, 0x13, 0x26, 0x73, 0xed, 0x86, 0x6e, 0x67, 0x7a, 0x09, 0x9c,
		0x8d, 0x25, 0x6d, 0x76, 0x97, 0xa8, 0xd9, 0x5a, 0x72, 0x66, 0x7d, 0x09, 0x99, 0xf5, 0x25, 0x61,
		0xd6, 0x97, 0x78, 0x6d, 0x16, 0x5b, 0x39, 0x96, 0x66, 0x85, 0x21, 0x67, 0x4c, 0x65, 0x8d, 0x07,
		0xce, 0x24, 0x5d, 0x8c, 0xef, 0x6f, 0xd8, 0x69, 0xcd, 0x02, 0x80, 0x35, 0x20, 0xb0, 0x09, 0x08,
		0x18, 0xc0, 0x60, 0x1b, 0x20, 0x60, 0x80, 0x02, 0x06, 0x30, 0x60, 0x80, 0x63, 0x3b, 0xb4, 0x1d,
		0xd3, 0x80, 0x32, 0x0d, 0x2c, 0xf6, 0xe2, 0x6d, 0x0a, 0x5f, 0x6c, 0xc5, 0x9a, 0x1d, 0x98, 0xb1,
		0x0e, 0x37, 0x08, 0xb0, 0x83, 0x05, 0x3f, 0x28, 0x30, 0x04, 0x07, 0x47, 0x70, 0xb0, 0x04, 0x07,
		0x4f, 0x76, 0x60, 0xca, 0x12, 0x5c, 0x59, 0x87, 0xad, 0xc4, 0x80, 0x78, 0x8d, 0x80, 0xf5, 0x38,
		0x9d, 0x64, 0x2f, 0x9b, 0x4b, 0x16, 0x5e, 0xc2, 0x99, 0xe5, 0x15, 0xb7, 0x30, 0x3b, 0x4a, 0x91,
		0x76, 0x8e, 0x62, 0xee, 0x10, 0x45, 0xdb, 0x09, 0x0a, 0xbb, 0xe3, 0x13, 0x76, 0x67, 0x27, 0xec,
		0x0e, 0xce, 0xed, 0x5e, 0x1f, 0x0a, 0xb3, 0xf3, 0x32, 0xc9, 0x3b, 0x3d, 0xe1, 0x77, 0x43, 0xd1,
		0x45, 0x48, 0x3a, 0x93, 0xaa, 0xab, 0x0c, 0x60, 0xcb, 0xf9, 0x78, 0xfe, 0xf7, 0xdd, 0xbb, 0x78,
		0x3f, 0x98, 0x17, 0x03, 0xf9, 0xb6, 0x2e, 0x3f, 0xb5, 0x58, 0x79, 0x4d, 0x56, 0x7f, 0xe2, 0x70,
		0xba, 0xc4, 0x22, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2,
		0xba, 0x4c, 0xd2, 0xba, 0x04, 0xcb, 0xc9, 0xec, 0x8c, 0x0f, 0xc6, 0x78, 0x7f, 0x0f, 0x0e, 0xb1,
		0x9b, 0x18, 0x44, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e,
		0x97, 0x49, 0x5e, 0x37, 0x81, 0x72, 0xd2, 0x3a, 0xe3, 0x63, 0x11, 0xf7, 0xcf, 0x82, 0x21, 0x75,
		0xb1, 0x39, 0x18, 0x94, 0x2e, 0x4f, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x67,
		0x6b, 0x54, 0x6c, 0x2f, 0x50, 0x4a, 0x0c, 0x19, 0x35, 0x0d, 0x94, 0xaa, 0x23, 0x70, 0x5a, 0x98,
		0x3f, 0x6d, 0xef, 0x7b, 0xb2, 0x0d, 0xa5, 0xd3, 0x22, 0x54, 0xb3, 0x7c, 0xb8, 0xe6, 0xf8, 0x88,
		0xcd, 0xf0, 0xb1, 0x9b, 0xdf, 0xa3, 0x36, 0xbb, 0x87, 0x6f, 0x6e, 0x0f, 0xdf, 0xcc, 0x1e, 0xbe,
		0x79, 0x3d, 0x7b, 0xe8, 0x42, 0x6a, 0x2c, 0xc0, 0x5a, 0x0b, 0xa2, 0xe6, 0x32, 0x4f, 0x7b, 0xf9,
		0x8f, 0x7f, 0x23, 0x4a, 0x11, 0x09, 0x1d, 0x25, 0x57, 0x63, 0xa5, 0x26, 0xa6, 0x19, 0xec, 0x9e,
		0x89, 0x12, 0x94, 0x20, 0x2b, 0xe8, 0x67, 0xa2, 0x11, 0x61, 0x25, 0x3d, 0xe9, 0x28, 0xe9, 0x28,
		0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0xa8, 0xf1, 0xbc, 0x35, 0x90, 0x4a, 0x1f, 0xec, 0x03,
		0xb2, 0x51, 0x24, 0x32, 0x5a, 0xf7, 0xd5, 0xf5, 0xf0, 0x69, 0x5d, 0x41, 0xe5, 0x00, 0xc0, 0x83,
		0x7c, 0x3e, 0x49, 0x85, 0x7b, 0x88, 0x27, 0xf8, 0xd1, 0x98, 0x7f, 0xfb, 0xbd, 0x81, 0x00, 0xb6,
		0xef, 0x63, 0xe8, 0xb7, 0xb5, 0x0c, 0xd4, 0xb1, 0xbc, 0x96, 0x71, 0x9f, 0x68, 0x1e, 0x6f, 0xfb,
		0x3b, 0x21, 0xe1, 0xdf, 0x31, 0x24, 0x56, 0x0c, 0x89, 0xc2, 0xfe, 0x51, 0xe1, 0xa8, 0x54, 0xde,
		0x3f, 0x2a, 0x32, 0x36, 0xb2, 0x4d, 0xc8, 0xf0, 0xac, 0x69, 0x50, 0x24, 0x42, 0xc9, 0x9d, 0x4e,
		0x3b, 0xb8, 0xb9, 0x19, 0x28, 0xa9, 0xef, 0x51, 0xa7, 0x30, 0x5f, 0x1a, 0x48, 0xe1, 0x68, 0x9e,
		0x39, 0x14, 0x8e, 0x96, 0x70, 0x29, 0x0a, 0x47, 0x4b, 0x79, 0x3a, 0x85, 0xa3, 0x15, 0x0d, 0xa4,
		0x70, 0x94, 0xa1, 0x4a, 0x82, 0xf3, 0x98, 0xaf, 0x80, 0xc1, 0x0c, 0xce, 0x63, 0x4e, 0x78, 0x85,
		0x14, 0x51, 0x72, 0x7d, 0xcf, 0xa9, 0x4c, 0x4c, 0x96, 0x0a, 0xd3, 0x3b, 0x62, 0x26, 0x26, 0x41,
		0x7a, 0x48, 0x90, 0x97, 0x92, 0x97, 0x92, 0x97, 0x92, 0x97, 0x92, 0x97, 0x92, 0x97, 0x1a, 0xcf,
		0x5b, 0xb2, 0xef, 0xfa, 0x9d, 0x4e, 0x28, 0xa2, 0x08, 0x91, 0x9a, 0x1e, 0x01, 0xd9, 0x34, 0x1e,
		0x43, 0x4e, 0x6a, 0xfe, 0xb6, 0x67, 0xdd, 0x16, 0x00, 0x7d, 0x6b, 0xc6, 0xc7, 0x0e, 0x01, 0x6d,
		0x3b, 0xf7, 0xb5, 0x16, 0xa1, 0x82, 0x73, 0xb7, 0xc4, 0xc0, 0x7f, 0x77, 0x77, 0xaf, 0x72, 0xee,
		0x51, 0xe3, 0xe1, 0x2a, 0xef, 0x1e, 0x35, 0xe2, 0xcb, 0xfc, 0xe8, 0x4b, 0x7c, 0xbd, 0x7f, 0x95,
		0x73, 0x0b, 0x93, 0xeb, 0xe2, 0x55, 0xce, 0x2d, 0x36, 0xf6, 0xbe, 0x7c, 0x79, 0xb7, 0xf7, 0xf3,
		0xe0, 0x71, 0xf9, 0x0f, 0xfe, 0xe1, 0xc0, 0x3d, 0x84, 0x06, 0xa2, 0xd3, 0xd4, 0x2e, 0xaa, 0xff,
		0xd0, 0x73, 0xd0, 0x3d, 0x07, 0x6b, 0x62, 0xf1, 0x2d, 0xe1, 0xec, 0xb7, 0xe1, 0xac, 0x44, 0x38,
		0xdb, 0x6c, 0x38, 0xf3, 0xdd, 0x6e, 0xc5, 0xfd, 0xd8, 0xf8, 0x99, 0x7f, 0x5b, 0x78, 0x7c, 0xbf,
		0xf7, 0xb3, 0xfc, 0xf8, 0xf2, 0xcd, 0x87, 0x79, 0x3f, 0x96, 0x7f, 0x5b, 0x7e, 0x7c, 0xbf, 0xe0,
		0x3b, 0xa5, 0xc7, 0xf7, 0xbf, 0xf9, 0x3b, 0x8a, 0x8f, 0xbb, 0x33, 0x3f, 0x3a, 0x7c, 0x7f, 0x7f,
		0xd1, 0x07, 0x0a, 0x0b, 0x3e, 0x70, 0xb0, 0xe8, 0x03, 0x07, 0x0b, 0x3e, 0xb0, 0xd0, 0xa4, 0xfd,
		0x05, 0x1f, 0x28, 0x3e, 0x3e, 0xcc, 0xfc, 0xfc, 0xee, 0xfc, 0x1f, 0x2d, 0x3d, 0xee, 0x3d, 0x2c,
		0xfa, 0x5e, 0xf9, 0xf1, 0xe1, 0xfd, 0x1e, 0xc1, 0x7d, 0x03, 0xc1, 0x9d, 0x71, 0xc4, 0x38, 0xc2,
		0xa3, 0x3a, 0x5c, 0x43, 0x05, 0xf6, 0x3c, 0x20, 0x66, 0xa7, 0xee, 0xb4, 0x0b, 0xbf, 0x8e, 0x6a,
		0x9e, 0x91, 0x9c, 0xb3, 0x9a, 0x67, 0x0e, 0xe7, 0xac, 0x96, 0x70, 0x2b, 0xce, 0x59, 0x2d, 0xe5,
		0xe9, 0x9c, 0xb3, 0x5a, 0xd1, 0x40, 0xce, 0x59, 0x65, 0x48, 0x92, 0xe1, 0x5a, 0xaa, 0xd7, 0xa8,
		0x2f, 0xd9, 0x5b, 0x4b, 0xf5, 0x9c, 0x5b, 0x48, 0x11, 0x4d, 0xfd, 0x9f, 0x6b, 0xaa, 0x40, 0x59,
		0xab, 0x54, 0xb7, 0x7e, 0x4f, 0x76, 0xdc, 0x50, 0xf8, 0x51, 0xa0, 0xf0, 0x08, 0xeb, 0x0b, 0xfb,
		0xc8, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xb7, 0x8c, 0xab, 0xca,
		0x8e, 0x50, 0x5a, 0xea, 0x7b, 0x50, 0xbe, 0x0a, 0xb4, 0x43, 0xd8, 0xa9, 0x8e, 0x1f, 0xd5, 0x07,
		0x3f, 0x02, 0x4c, 0xa9, 0x93, 0x01, 0xad, 0x9e, 0xfd, 0x5d, 0x39, 0xad, 0x1e, 0x37, 0xeb, 0xb5,
		0xcf, 0x97, 0x27, 0xcd, 0xfa, 0x49, 0xe5, 0xa2, 0x76, 0x86, 0x96, 0x5d, 0x47, 0x1b, 0xc1, 0x23,
		0xc8, 0x69, 0x22, 0xd0, 0x9d, 0xfd, 0x2f, 0x47, 0xf7, 0xcf, 0xd3, 0xcf, 0x17, 0x97, 0x27, 0xf5,
		0xe6, 0x69, 0xad, 0x76, 0xee, 0xb0, 0x71, 0xc3, 0xc6, 0x8c, 0x6b, 0xe5, 0x82, 0x43, 0xba, 0x61,
		0x43, 0x5a, 0xab, 0x57, 0xff, 0xaa, 0x9e, 0x55, 0x2e, 0x6b, 0x75, 0x8e, 0xea, 0x06, 0x25, 0xe0,
		0xda, 0xd9, 0xc7, 0x93, 0x63, 0x87, 0x7d, 0x41, 0xfe, 0xf3, 0xd5, 0x60, 0x3d, 0x02, 0x66, 0x05,
		0x82, 0x3a, 0xd8, 0xf3, 0x23, 0xed, 0xde, 0x04, 0x1d, 0xd9, 0x95, 0xa2, 0x83, 0x27, 0x0e, 0x4e,
		0x9b, 0x47, 0x6d, 0x70, 0x9e, 0x39, 0xd4, 0x06, 0x97, 0x70, 0x28, 0x6a, 0x83, 0x4b, 0x79, 0x3a,
		0xb5, 0xc1, 0x15, 0x0d, 0xa4, 0x36, 0x98, 0x21, 0xee, 0x0b, 0xac, 0x0d, 0x6a, 0x79, 0x23, 0xb4,
		0x6c, 0x7f, 0x8f, 0x4a, 0x05, 0x40, 0x6d, 0x10, 0x68, 0x23, 0x81, 0xf3, 0x59, 0xc5, 0x7d, 0x02,
		0x1d, 0xe5, 0xab, 0x20, 0x12, 0xed, 0x40, 0x75, 0xa0, 0xf6, 0xab, 0xb2, 0xe3, 0xed, 0x6f, 0x3e,
		0x28, 0x76, 0xbc, 0x7d, 0xbd, 0x79, 0xec, 0x78, 0xbb, 0x89, 0x7a, 0x0c, 0x3b, 0xde, 0xae, 0x21,
		0x24, 0xf2, 0x87, 0x85, 0x42, 0xa9, 0x5c, 0x28, 0xe4, 0xca, 0x07, 0xe5, 0xdc, 0x51, 0xb1, 0x98,
		0x2f, 0xe5, 0xd9, 0xfb, 0x36, 0xe3, 0xfc, 0x11, 0xcf, 0x1a, 0xee, 0xdb, 0x80, 0xc9, 0xa2, 0xce,
		0xe4, 0x6c, 0x71, 0x38, 0x75, 0x6b, 0x62, 0x18, 0x48, 0xf5, 0x73, 0x2c, 0xba, 0xfe, 0xa0, 0x37,
		0x2a, 0x55, 0x73, 0xd4, 0xda, 0xe6, 0x9a, 0x43, 0xad, 0x6d, 0x09, 0xf7, 0xa6, 0xd6, 0xb6, 0x94,
		0xa7, 0x53, 0x6b, 0x5b, 0xd1, 0x40, 0x6a, 0x6d, 0x19, 0xaa, 0x6b, 0x78, 0x70, 0xd3, 0xf2, 0x28,
		0xc8, 0x83, 0x9b, 0x7e, 0xf5, 0xa2, 0x8c, 0xb5, 0x91, 0x35, 0x3b, 0x65, 0xac, 0xac, 0xa7, 0xfb,
		0xe9, 0x90, 0xa0, 0x8c, 0xb5, 0x72, 0x48, 0xf0, 0xe0, 0xa6, 0x4d, 0x21, 0x64, 0x78, 0xd6, 0x50,
		0xbc, 0x82, 0xc9, 0x9d, 0xce, 0x78, 0x73, 0x64, 0x30, 0xd0, 0x02, 0x4f, 0xc0, 0x7a, 0x6e, 0x1c,
		0x05, 0xa3, 0x79, 0xe6, 0x50, 0x30, 0x5a, 0xc2, 0x9d, 0x28, 0x18, 0x2d, 0xe5, 0xe9, 0x14, 0x8c,
		0x56, 0x34, 0x90, 0x82, 0x51, 0x86, 0x2a, 0x08, 0x60, 0xc1, 0xa8, 0x15, 0x04, 0x3d, 0xe1, 0x2b,
		0xc4, 0x4d, 0x9b, 0x79, 0x52, 0x39, 0x00, 0x0b, 0x2c, 0x87, 0x90, 0x53, 0x51, 0x2a, 0xd0, 0xfe,
		0xb0, 0x1a, 0x83, 0x08, 0x20, 0x27, 0x6a, 0x7f, 0x15, 0x37, 0x7e, 0x7f, 0xdc, 0x74, 0xc6, 0x0b,
		0xfa, 0x42, 0xb5, 0x47, 0x44, 0xc9, 0x55, 0x42, 0xff, 0x08, 0xc2, 0xef, 0xae, 0x54, 0x91, 0xf6,
		0x55, 0x5b, 0x78, 0x2f, 0xdf, 0x88, 0x66, 0xde, 0xf1, 0xfa, 0x61, 0xa0, 0x83, 0x76, 0xd0, 0x8b,
		0x92, 0x2b, 0xaf, 0x75, 0xdd, 0xf7, 0x42, 0xd9, 0xf2, 0xfc, 0xae, 0x74, 0x23, 0xbf, 0x2b, 0xa3,
		0xe4, 0xca, 0x1b, 0x9d, 0x35, 0x10, 0x85, 0x5a, 0xb8, 0xfd, 0xa0, 0x27, 0xdb, 0xf7, 0x9e, 0x12,
		0xf2, 0xfa, 0x6b, 0x2b, 0x08, 0xa3, 0xe4, 0xca, 0xf3, 0x3b, 0xdf, 0x46, 0x68, 0x10, 0x0c, 0xb4,
		0xdb, 0x0f, 0x85, 0x37, 0x62, 0xb8, 0x51, 0xfc, 0x25, 0xee, 0x73, 0x63, 0x17, 0x24, 0xec, 0x79,
		0xb3, 0x45, 0x4f, 0x76, 0x06, 0xea, 0xbb, 0x0a, 0x7e, 0x28, 0xd7, 0xd7, 0x3a, 0x94, 0xad, 0xe1,
		0x88, 0x58, 0xf7, 0xe6, 0xa7, 0x39, 0x83, 0x59, 0xdb, 0x2c, 0xc7, 0xfc, 0x04, 0x01, 0x2c, 0x9b,
		0x81, 0x52, 0x00, 0x21, 0x15, 0x3e, 0x98, 0x05, 0x0f, 0x5a, 0xa1, 0x03, 0x5b, 0xe0, 0xc0, 0x16,
		0x36, 0xb0, 0x05, 0xcd, 0x76, 0xb3, 0xaf, 0x63, 0x19, 0x62, 0xa4, 0x9d, 0x19, 0x90, 0xc2, 0x53,
		0x14, 0x67, 0x4d, 0xc4, 0xd2, 0x15, 0xf3, 0xd4, 0x15, 0xe1, 0xe1, 0x15, 0x1b, 0x66, 0x51, 0xe1,
		0x16, 0x1e, 0x76, 0xe1, 0xe1, 0x17, 0x1e, 0x86, 0x71, 0xe4, 0x98, 0x1d, 0x20, 0x5d, 0x11, 0x05,
		0x9e, 0x13, 0x83, 0x86, 0xd8, 0xe7, 0x6a, 0x34, 0xb5, 0x73, 0x2a, 0xa3, 0x3e, 0x99, 0x08, 0x16,
		0x7a, 0x98, 0xab, 0x37, 0xe0, 0xe0, 0x1a, 0x19, 0xb6, 0xb3, 0x01, 0xdf, 0xe8, 0x30, 0x9e, 0x19,
		0x38, 0xcf, 0x0c, 0xac, 0x67, 0x06, 0xde, 0xb1, 0x60, 0x1e, 0x0c, 0xee, 0x93, 0x51, 0xbc, 0x44,
		0x04, 0xd8, 0x1d, 0xec, 0xb3, 0x0b, 0x66, 0xaa, 0xe1, 0x32, 0xe6, 0x09, 0x92, 0x93, 0xb3, 0x0c,
		0xe2, 0x23, 0x09, 0x9e, 0xc8, 0x0a, 0xd7, 0xfb, 0xa1, 0x87, 0xa6, 0x13, 0xcf, 0xae, 0xc1, 0x12,
		0xdf, 0xd8, 0x3c, 0x4c, 0xd2, 0x9b, 0x27, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9,
		0x25, 0xb2, 0xce, 0x1f, 0x45, 0x34, 0xad, 0x2b, 0x31, 0x6c, 0xc4, 0xd1, 0x7a, 0x02, 0x78, 0xab,
		0xdc, 0x94, 0xf4, 0x35, 0xb4, 0xf4, 0x2d, 0xf7, 0x2f, 0x6d, 0x10, 0x29, 0xc8, 0x02, 0x39, 0xc8,
		0x16, 0x49, 0xc8, 0x0a, 0x59, 0xc8, 0x1c, 0x69, 0xc8, 0x1c, 0x79, 0xc8, 0x1c, 0x89, 0xc0, 0x24,
		0x13, 0xa0, 0xa4, 0x22, 0x19, 0x5d, 0x58, 0x45, 0x6d, 0x26, 0x6f, 0x0e, 0xa4, 0xd2, 0xf9, 0x12,
		0x72, 0xce, 0x1c, 0xa3, 0x78, 0x09, 0xd8, 0x44, 0xcc, 0x0e, 0x10, 0x2f, 0x5f, 0xd8, 0x98, 0xb3,
		0x83, 0xde, 0x21, 0x22, 0x63, 0xf4, 0x72, 0xc6, 0x5c, 0xf0, 0x0e, 0x12, 0x33, 0xf6, 0x66, 0x60,
		0xd7, 0x7c, 0x46, 0xe0, 0x68, 0x3a, 0xc4, 0xfc, 0x3b, 0x86, 0x58, 0xca, 0x21, 0x56, 0x2a, 0x16,
		0x0f, 0x8a, 0x0c, 0xb3, 0xed, 0xe2, 0xa2, 0xf8, 0xd6, 0x35, 0xde, 0xf0, 0x79, 0x65, 0x34, 0x8d,
		0x03, 0xaf, 0x84, 0x9b, 0x29, 0x29, 0x50, 0x57, 0xc4, 0x65, 0x04, 0x55, 0xa8, 0x0b, 0xae, 0xd3,
		0x19, 0xa9, 0x0b, 0xae, 0x35, 0x72, 0xa8, 0x0b, 0xa6, 0x6c, 0x30, 0x75, 0xc1, 0x0d, 0x2e, 0xc4,
		0x32, 0xa6, 0x0b, 0x1e, 0x66, 0x40, 0x16, 0x2c, 0x52, 0x16, 0x5c, 0xf1, 0x45, 0x59, 0x90, 0x9a,
		0x05, 0x65, 0xc1, 0x2d, 0x44, 0xa3, 0xe9, 0x10, 0xa3, 0x2c, 0x98, 0x7a, 0x88, 0xed, 0x17, 0x29,
		0x0a, 0x6e, 0x19, 0x11, 0xc5, 0xb7, 0x8e, 0xa2, 0x60, 0x66, 0x93, 0x78, 0xac, 0xb4, 0xdd, 0x8e,
		0xb3, 0x4b, 0x16, 0x54, 0xc1, 0xd8, 0x56, 0xca, 0x82, 0xaf, 0x31, 0x8f, 0xb2, 0xe0, 0x1a, 0xbd,
		0x91, 0xb2, 0xe0, 0x5a, 0x23, 0x87, 0xb2, 0x60, 0xca, 0x06, 0x53, 0x16, 0xdc, 0xe0, 0x42, 0x2c,
		0x43, 0xb2, 0x60, 0x4b, 0x2a, 0x3f, 0xbc, 0xcf, 0x80, 0x2e, 0x78, 0x04, 0x6c, 0xe2, 0xa9, 0x50,
		0xd7, 0xa3, 0x8d, 0xb9, 0x14, 0x06, 0x57, 0x55, 0x2d, 0x28, 0x0c, 0xa6, 0xae, 0x5a, 0xe4, 0xa9,
		0x59, 0x6c, 0x19, 0x1e, 0x4d, 0x87, 0x18, 0x85, 0xc1, 0xd4, 0x43, 0x8c, 0xeb, 0x05, 0xb7, 0x90,
		0x8c, 0xe2, 0x5b, 0x47, 0x69, 0x30, 0xb3, 0x69, 0xdc, 0x11, 0x77, 0x5a, 0xa8, 0x8e, 0xe8, 0xe0,
		0x0b, 0x83, 0x89, 0xa5, 0x94, 0x05, 0x5f, 0x63, 0x1e, 0x65, 0xc1, 0x35, 0xfa, 0x22, 0x65, 0xc1,
		0xb5, 0x46, 0x0e, 0x65, 0xc1, 0x94, 0x0d, 0xa6, 0x2c, 0xb8, 0xc1, 0x65, 0x58, 0x96, 0x64, 0x41,
		0xb8, 0x63, 0xbf, 0x16, 0xc1, 0x38, 0xc8, 0x31, 0x60, 0x24, 0xb5, 0xaf, 0x19, 0xc3, 0xa0, 0x3f,
		0xac, 0x3c, 0xfd, 0x1e, 0x3e, 0xa9, 0x4d, 0x2c, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9,
		0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x65, 0x50, 0x4c, 0x8f, 0x61, 0xdf,
		0x0f, 0xb5, 0xcc, 0x02, 0xa7, 0x9d, 0x18, 0x4a, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b,
		0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0xcb, 0xa0, 0x98, 0x1e, 0x43, 0x1d, 0xfa,
		0x2a, 0x92, 0x5a, 0xde, 0x66, 0x60, 0x5f, 0xd2, 0x33, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c,
		0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0x68, 0x88,
		0x3a, 0x15, 0xa5, 0x02, 0xed, 0x6b, 0x19, 0x60, 0x6e, 0x80, 0x72, 0xa2, 0xf6, 0x57, 0x71, 0xe3,
		0xf7, 0xc7, 0x07, 0x50, 0x7a, 0x41, 0x5f, 0xa8, 0xf6, 0x88, 0x28, 0xba, 0x4a, 0xe8, 0x1f, 0x41,
		0xf8, 0xdd, 0x95, 0x2a, 0xd2, 0xbe, 0x6a, 0x0b, 0xef, 0xe5, 0x1b, 0xd1, 0xcc, 0x3b, 0x5e, 0x3f,
		0x0c, 0x74, 0xd0, 0x0e, 0x7a, 0x51, 0x72, 0xe5, 0xb5, 0xae, 0xfb, 0x5e, 0x28, 0x5b, 0x9e, 0xdf,
		0x95, 0x6e, 0xe4, 0x77, 0x65, 0x94, 0x5c, 0x79, 0xb2, 0x7f, 0x5b, 0x70, 0xa3, 0x50, 0x0b, 0xb7,
		0x1f, 0xf4, 0x64, 0xfb, 0xde, 0x53, 0x42, 0x5e, 0x7f, 0x6d, 0x05, 0x61, 0x94, 0x5c, 0x79, 0x7e,
		0xe7, 0xdb, 0x08, 0xad, 0x82, 0x81, 0x76, 0xfb, 0xa1, 0xf0, 0xc2, 0x60, 0xa0, 0x45, 0x14, 0x7f,
		0xf1, 0x06, 0xea, 0xbb, 0x0a, 0x7e, 0x28, 0xd7, 0xd7, 0x3a, 0x94, 0xad, 0xd1, 0x37, 0x66, 0xde,
		0x8a, 0x4f, 0xd4, 0xe4, 0x39, 0x9a, 0xc8, 0x96, 0xa0, 0x9c, 0xab, 0xff, 0x3f, 0x71, 0x8f, 0xd8,
		0x18, 0xd7, 0x39, 0x95, 0x91, 0xae, 0x68, 0x0d, 0x76, 0xe8, 0xff, 0x27, 0xa9, 0x4e, 0x7a, 0x62,
		0xc8, 0x2a, 0x23, 0xac, 0xaa, 0xd2, 0xf9, 0xe4, 0xdf, 0x3d, 0xb3, 0x2c, 0x7f, 0x58, 0x28, 0x94,
		0xca, 0x85, 0x42, 0xae, 0x7c, 0x50, 0xce, 0x1d, 0x15, 0x8b, 0xf9, 0x52, 0x1e, 0x68, 0x13, 0x97,
		0x53, 0x0b, 0x3b, 0x22, 0x14, 0x9d, 0x0f, 0x43, 0xd7, 0x53, 0x83, 0x5e, 0x8f, 0x11, 0x89, 0x0f,
		0x9f, 0x9b, 0x0f, 0x9b, 0x0e, 0xd4, 0x01, 0xcb, 0xe1, 0xa0, 0xad, 0xd5, 0xb8, 0x84, 0x38, 0x8b,
		0x9f, 0x5e, 0x75, 0xfc, 0xf0, 0x9a, 0xe7, 0xe3, 0x47, 0xd6, 0xfc, 0x70, 0xdd, 0x6f, 0xd6, 0x65,
		0xab, 0x59, 0xe9, 0xca, 0x0b, 0xbf, 0x2b, 0x9b, 0xd5, 0xfe, 0x6d, 0xe1, 0x22, 0xd4, 0xe2, 0x7c,
		0xf4, 0x94, 0x9a, 0x67, 0xe3, 0x67, 0xd3, 0xac, 0x74, 0xbe, 0xd5, 0x65, 0xab, 0x36, 0xd0, 0xe7,
		0xa1, 0x68, 0xd6, 0x87, 0x4f, 0xa4, 0xf9, 0x39, 0xfe, 0xf3, 0x2b, 0xc9, 0x5f, 0xff, 0x86, 0xe0,
		0x6c, 0xdf, 0x02, 0xcb, 0x49, 0x08, 0x2d, 0xf9, 0x6c, 0x5a, 0xd2, 0xb1, 0x1b, 0x64, 0xf6, 0x5c,
		0xdb, 0xce, 0x9d, 0x2d, 0x05, 0xd3, 0x84, 0x53, 0x0f, 0xbd, 0xd6, 0x95, 0x9d, 0x1d, 0xa1, 0x3a,
		0xfd, 0x40, 0x2a, 0xbd, 0xd3, 0x0e, 0x7a, 0x41, 0x68, 0x09, 0x65, 0x30, 0x08, 0x35, 0x0e, 0x81,
		0x86, 0x26, 0xcc, 0x18, 0x04, 0xd9, 0x56, 0xf8, 0x80, 0x60, 0x50, 0xa6, 0xb1, 0xc7, 0x22, 0x97,
		0x4d, 0x9f, 0xbb, 0xda, 0x41, 0x51, 0xf3, 0x18, 0x66, 0xf6, 0x8e, 0x86, 0xc3, 0xdd, 0x76, 0x98,
		0x67, 0x34, 0xbc, 0xcd, 0xfa, 0xbe, 0x39, 0x0f, 0x34, 0x73, 0x27, 0x43, 0x3e, 0x6e, 0xcb, 0xb7,
		0xb3, 0xe6, 0xd3, 0x06, 0x51, 0x2a, 0x4d, 0x54, 0x32, 0x13, 0x93, 0xe9, 0x47, 0x88, 0x81, 0xe8,
		0x70, 0x26, 0xae, 0xe0, 0xfa, 0x9d, 0x4e, 0x28, 0xa2, 0xc8, 0x58, 0x7c, 0x24, 0xf3, 0xf1, 0x33,
		0x16, 0x18, 0xca, 0x09, 0x66, 0xd7, 0xca, 0x19, 0x5f, 0xfb, 0x66, 0x63, 0x2d, 0x9b, 0xdd, 0xb5,
		0x69, 0xb6, 0xd6, 0x9a, 0x59, 0x5f, 0x3b, 0x66, 0x7d, 0x2d, 0x98, 0xf5, 0xb5, 0x5d, 0x9b, 0xc5,
		0x56, 0x8c, 0xaf, 0xa5, 0x4a, 0xe2, 0xb6, 0x27, 0xfc, 0x6e, 0x28, 0xba, 0x26, 0x83, 0x76, 0xb2,
		0xd6, 0xa9, 0x6c, 0xf0, 0x9e, 0xe7, 0x63, 0x42, 0xf6, 0xee, 0x5d, 0xbc, 0x34, 0xc3, 0x9b, 0xc1,
		0x20, 0x32, 0x88, 0x25, 0x88, 0x9c, 0xaf, 0x85, 0x79, 0xda, 0x10, 0xdf, 0xd6, 0x2c, 0x57, 0xc8,
		0x93, 0x2b, 0x90, 0x2b, 0x90, 0x2b, 0x90, 0x2b, 0xe0, 0x70, 0x85, 0x63, 0x69, 0x76, 0x06, 0xc9,
		0x5e, 0xc1, 0x88, 0x52, 0x38, 0x5a, 0x2a, 0x20, 0xad, 0x81, 0x83, 0x4d, 0x90, 0xc0, 0x00, 0x0b,
		0xdb, 0xa0, 0x01, 0x03, 0x1e, 0x30, 0x20, 0x02, 0x03, 0x26, 0x66, 0x41, 0xc5, 0x30, 0xb8, 0xd8,
		0x2b, 0x48, 0x67, 0xe2, 0x5e, 0xf6, 0x2d, 0x65, 0xf9, 0x29, 0xfa, 0x6f, 0xe1, 0xa4, 0xa0, 0xc9,
		0xb3, 0xb7, 0x73, 0xfe, 0x8f, 0xc5, 0xd9, 0xfe, 0xa7, 0x91, 0xbf, 0x2d, 0x58, 0x1c, 0xfb, 0x19,
		0x1f, 0x38, 0xb4, 0x68, 0xc3, 0xb9, 0xaf, 0xb5, 0x08, 0x95, 0xf5, 0xe3, 0xa0, 0x9c, 0x7f, 0x77,
		0x77, 0xaf, 0x72, 0xee, 0x51, 0xe3, 0xe1, 0x2a, 0xef, 0x1e, 0x35, 0xe2, 0xcb, 0xfc, 0xe8, 0x4b,
		0x7c, 0xbd, 0x7f, 0x95, 0x73, 0x0b, 0x93, 0xeb, 0xe2, 0x55, 0xce, 0x2d, 0x36, 0xf6, 0xbe, 0x7c,
		0x79, 0xb7, 0xf7, 0xf3, 0xe0, 0x71, 0xf9, 0x0f, 0xfe, 0x61, 0x6f, 0x95, 0x5e, 0xc3, 0xe6, 0x60,
		0xd7, 0x2e, 0xaa, 0xff, 0x70, 0xc4, 0x4d, 0x8f, 0xf8, 0x36, 0x2d, 0xed, 0xc2, 0x48, 0xef, 0x25,
		0xa6, 0x77, 0xcc, 0xf4, 0xee, 0xbb, 0xdd, 0x8a, 0xfb, 0xb1, 0xf1, 0x33, 0xff, 0xb6, 0xf0, 0xf8,
		0x7e, 0xef, 0x67, 0xf9, 0xf1, 0xe5, 0x9b, 0x0f, 0xf3, 0x7e, 0x2c, 0xff, 0xb6, 0xfc, 0xf8, 0x7e,
		0xc1, 0x77, 0x4a, 0x8f, 0xef, 0x7f, 0xf3, 0x77, 0x14, 0x1f, 0x77, 0x67, 0x7e, 0x74, 0xf8, 0xfe,
		0xfe, 0xa2, 0x0f, 0x14, 0x16, 0x7c, 0xe0, 0x60, 0xd1, 0x07, 0x0e, 0x16, 0x7c, 0x60, 0xa1, 0x49,
		0xfb, 0x0b, 0x3e, 0x50, 0x7c, 0x7c, 0x98, 0xf9, 0xf9, 0xdd, 0xf9, 0x3f, 0x5a, 0x7a, 0xdc, 0x7b,
		0x58, 0xf4, 0xbd, 0xf2, 0xe3, 0xc3, 0xfb, 0x3d, 0x82, 0x1d, 0xfd, 0x9f, 0xfe, 0xbf, 0x55, 0xd0,
		0xff, 0x66, 0xb3, 0xff, 0x4e, 0x2e, 0x59, 0x7c, 0xa5, 0xb2, 0xc5, 0x25, 0x8b, 0x73, 0x97, 0x2c,
		0x1a, 0xec, 0xa5, 0x60, 0x60, 0x7e, 0xfe, 0x4d, 0x86, 0x5d, 0x75, 0xb2, 0xaf, 0xca, 0xf0, 0x3c,
		0x8c, 0xd9, 0x9d, 0x53, 0xe6, 0x77, 0x48, 0x41, 0xec, 0x84, 0x32, 0xbb, 0xe3, 0x29, 0x6d, 0x47,
		0x35, 0x9c, 0x4b, 0xd1, 0x73, 0xa8, 0x63, 0x64, 0x55, 0xd0, 0x3a, 0x97, 0x77, 0xa7, 0x9b, 0xef,
		0xd3, 0xcb, 0xc2, 0xe9, 0xfc, 0xe6, 0x94, 0xc2, 0xc5, 0x54, 0x98, 0x80, 0x86, 0x47, 0x3a, 0x3e,
		0xb6, 0x7e, 0x0f, 0x58, 0xef, 0x6f, 0x5c, 0xb3, 0x2f, 0xa5, 0xed, 0x43, 0x50, 0xbe, 0x93, 0x42,
		0x1e, 0x5d, 0x4f, 0xde, 0x5c, 0xaf, 0x2b, 0xaf, 0xcf, 0xe1, 0xd6, 0xe8, 0x6c, 0xf1, 0xbc, 0xe0,
		0x40, 0xc9, 0xb6, 0x1f, 0xe9, 0xb5, 0xbb, 0xda, 0xf4, 0xec, 0xe3, 0xe4, 0x2e, 0x6b, 0x0e, 0x95,
		0x74, 0x16, 0x95, 0xa6, 0xb6, 0x3e, 0x28, 0xcd, 0xf5, 0x3f, 0x66, 0xd6, 0xf7, 0xa4, 0xbd, 0x7e,
		0xc7, 0xd8, 0xfa, 0x1c, 0x63, 0xeb, 0x6f, 0x8c, 0xad, 0xaf, 0xc1, 0x06, 0xb5, 0xb4, 0x16, 0x59,
		0x3a, 0xbd, 0xf8, 0x99, 0xa6, 0xe7, 0x91, 0xc9, 0xc6, 0x8e, 0xf1, 0x8d, 0x52, 0x72, 0x93, 0x74,
		0xd7, 0xc7, 0x3f, 0xa5, 0xb4, 0xfd, 0x94, 0x6e, 0x60, 0x60, 0x69, 0xa3, 0xd9, 0x25, 0x8c, 0xa6,
		0x96, 0x2a, 0x1a, 0x5f, 0x92, 0x68, 0x7c, 0xe9, 0xa1, 0xf1, 0x25, 0x86, 0xd9, 0xaa, 0x19, 0xd3,
		0x5e, 0x7f, 0xee, 0x8c, 0xdb, 0x2c, 0xa4, 0xee, 0xc8, 0x93, 0xf0, 0x1c, 0xdf, 0x2f, 0x6d, 0xe9,
		0xd4, 0xc8, 0x86, 0x22, 0x63, 0x6b, 0xc5, 0x4d, 0xae, 0x0d, 0xb7, 0xb3, 0x16, 0xdc, 0xf4, 0xda,
		0x6f, 0x6b, 0x6b, 0xbd, 0xad, 0xad, 0xed, 0xb6, 0xb6, 0x96, 0x3b, 0xdb, 0x93, 0x30, 0xa6, 0x36,
		0x00, 0xc5, 0x89, 0xd1, 0xfc, 0x3e, 0x4f, 0x93, 0xed, 0xb3, 0xb8, 0xcf, 0x73, 0x53, 0xd2, 0xb5,
		0xad, 0xb4, 0x6d, 0x3d, 0x7d, 0x5b, 0x4f, 0xe3, 0xd6, 0xd3, 0xb9, 0x99, 0xb4, 0x6e, 0x28, 0xbd,
		0x1b, 0x4f, 0xf3, 0xc9, 0x0d, 0x83, 0x50, 0x5e, 0x4b, 0x65, 0x6f, 0x77, 0xe7, 0xf8, 0xfe, 0xdc,
		0xd3, 0xb9, 0x69, 0x80, 0x80, 0x01, 0x0c, 0xb6, 0x01, 0x02, 0x06, 0x28, 0x60, 0x00, 0x03, 0x06,
		0x38, 0xcc, 0x02, 0x88, 0x61, 0x20, 0x49, 0x9e, 0xb2, 0xfd, 0x3d, 0x9d, 0xe6, 0x9b, 0x0d, 0xcd,
		0xf0, 0xfc, 0xb2, 0x85, 0x7b, 0xcf, 0x34, 0x1f, 0x1a, 0x23, 0xdd, 0xa6, 0xae, 0xca, 0x35, 0x48,
		0xf6, 0xc7, 0x1d, 0xde, 0xed, 0x91, 0x96, 0x89, 0x01, 0x64, 0x2d, 0x64, 0x2d, 0x64, 0x2d, 0x64,
		0x2d, 0x64, 0x2d, 0x64, 0x2d, 0x1b, 0xca, 0x5a, 0x26, 0x50, 0x47, 0xda, 0xb2, 0x3a, 0x6d, 0xb1,
		0x03, 0x67, 0x4f, 0xac, 0xc5, 0x8a, 0x40, 0x49, 0xd2, 0x42, 0xd2, 0x42, 0xd2, 0x42, 0xd2, 0x42,
		0xd2, 0x42, 0xd2, 0x62, 0x8c, 0xb4, 0xc4, 0x61, 0x4f, 0xce, 0xb2, 0xf2, 0xa3, 0x35, 0xdb, 0xf5,
		0x79, 0xc6, 0xa1, 0x4d, 0x76, 0x7f, 0x9e, 0x71, 0x65, 0x32, 0x16, 0x32, 0x16, 0x32, 0x16, 0x32,
		0x96, 0xcd, 0x65, 0x2c, 0xa6, 0x57, 0x1b, 0x24, 0x37, 0xf6, 0xb5, 0x0e, 0x5d, 0xa9, 0x3a, 0xe2,
		0xce, 0x5e, 0xd0, 0x4d, 0x52, 0xcf, 0x33, 0x5b, 0x6c, 0x1d, 0x5c, 0x6b, 0xa5, 0x44, 0xb6, 0x0e,
		0x3c, 0x08, 0x00, 0x84, 0x05, 0x44, 0x28, 0x80, 0x04, 0x07, 0x4c, 0x70, 0x00, 0x05, 0x07, 0x54,
		0x76, 0x00, 0xcb, 0x12, 0x70, 0xd9, 0x2f, 0xb9, 0x81, 0x4a, 0x6f, 0x84, 0x12, 0x7c, 0x5e, 0x29,
		0x3e, 0xf7, 0xdf, 0x08, 0x6c, 0x23, 0xa1, 0xa3, 0xe4, 0x6a, 0x5c, 0xb2, 0xc7, 0x00, 0xbc, 0x2d,
		0x27, 0x0c, 0x5b, 0xa8, 0x71, 0xda, 0xc1, 0xcd, 0xcd, 0x40, 0x49, 0x7d, 0x8f, 0xc2, 0xbb, 0x5e,
		0x1a, 0x44, 0xf2, 0x45, 0xf2, 0x45, 0xf2, 0x45, 0xf2, 0x45, 0xf2, 0x45, 0xf2, 0x45, 0xf2, 0x95,
		0x06, 0xf9, 0x9a, 0x20, 0xae, 0x14, 0x51, 0x72, 0x7d, 0x4f, 0xfe, 0x65, 0x66, 0x70, 0xc4, 0x9d,
		0x76, 0xe1, 0x38, 0xd8, 0x3c, 0xa3, 0xc8, 0xc3, 0xc8, 0xc3, 0xc8, 0xc3, 0xc8, 0xc3, 0xc8, 0xc3,
		0xc8, 0xc3, 0xc8, 0xc3, 0xd2, 0xe0, 0x61, 0xcf, 0x51, 0x77, 0xc8, 0xc5, 0xa6, 0x50, 0x98, 0x7c,
		0xcc, 0xcc, 0x20, 0x49, 0x75, 0xeb, 0xf7, 0x64, 0xc7, 0x0d, 0x85, 0x1f, 0x05, 0xca, 0x3e, 0x15,
		0x7b, 0x61, 0x0f, 0x59, 0x18, 0x59, 0x18, 0x59, 0x18, 0x59, 0x18, 0x59, 0x18, 0x59, 0xd8, 0xb2,
		0x48, 0xd2, 0x11, 0x4a, 0x4b, 0x7d, 0x0f, 0xc2, 0xc4, 0x8a, 0x16, 0x6d, 0xa8, 0x8e, 0x1f, 0xc5,
		0x07, 0x3f, 0x02, 0x48, 0x61, 0x93, 0x01, 0xaa, 0x9e, 0xfd, 0x5d, 0x39, 0xad, 0x1e, 0x37, 0xeb,
		0xb5, 0xcf, 0x97, 0x27, 0xcd, 0xfa, 0x49, 0xe5, 0xa2, 0x76, 0x66, 0x3b, 0x9b, 0xfd, 0xed, 0xf7,
		0x06, 0xa3, 0xfe, 0x8b, 0x76, 0xcf, 0x64, 0xdb, 0xb1, 0x7a, 0x5c, 0xe5, 0x7f, 0x8e, 0xd6, 0x9f,
		0xa7, 0x9f, 0x2f, 0x2e, 0x4f, 0xea, 0xcd, 0xd3, 0x5a, 0xed, 0xdc, 0xb1, 0x6e, 0xe2, 0xe3, 0x5b,
		0x8e, 0xd3, 0xfc, 0x71, 0xaa, 0x5c, 0x70, 0x88, 0xc0, 0x87, 0xa8, 0x56, 0xaf, 0xfe, 0x55, 0x3d,
		0xab, 0x5c, 0xd6, 0xea, 0x1c, 0x25, 0xe0, 0x84, 0x57, 0x3b, 0xfb, 0x78, 0x72, 0x0c, 0x30, 0x42,
		0x56, 0x2d, 0x68, 0x6c, 0x1b, 0x7f, 0xde, 0x0a, 0xf5, 0xa7, 0xe7, 0x47, 0xda, 0xbd, 0x09, 0x3a,
		0xb2, 0x2b, 0x45, 0xc7, 0xbe, 0xf8, 0x33, 0x6d, 0x0e, 0xb5, 0x1f, 0x6a, 0x3f, 0xd4, 0x7e, 0xa8,
		0xfd, 0x50, 0xfb, 0xa1, 0xf6, 0xb3, 0x64, 0xde, 0xd0, 0xf2, 0x46, 0x68, 0xd9, 0xfe, 0x1e, 0x95,
		0x0a, 0x00, 0xda, 0xcf, 0xa1, 0x45, 0x13, 0x3e, 0x2b, 0x39, 0x3a, 0x58, 0xd5, 0x51, 0xbe, 0x0a,
		0x22, 0xd1, 0x0e, 0x54, 0x27, 0xb2, 0xf9, 0x48, 0xea, 0xbe, 0xba, 0x16, 0xd6, 0xf5, 0x15, 0xfb,
		0xa5, 0x86, 0xf3, 0x49, 0x2a, 0xeb, 0x88, 0x02, 0xc2, 0x79, 0x66, 0xcc, 0x19, 0xa9, 0x70, 0x40,
		0xf6, 0x7c, 0x0c, 0xfd, 0xb6, 0x96, 0x81, 0x3a, 0x96, 0xd7, 0x71, 0x34, 0xe5, 0x58, 0xaf, 0xc7,
		0x47, 0x37, 0xd3, 0x85, 0x7f, 0xe1, 0xc2, 0x76, 0x0e, 0xb4, 0xce, 0xac, 0x57, 0xbf, 0xd9, 0xce,
		0xbb, 0x37, 0xa8, 0x71, 0xa4, 0xe6, 0xe6, 0x96, 0x5a, 0xfb, 0xcf, 0xd6, 0xb2, 0x36, 0x5a, 0xfc,
		0x53, 0xd5, 0xa0, 0xaa, 0x41, 0x55, 0x83, 0xaa, 0x06, 0x55, 0x8d, 0x0d, 0x50, 0x35, 0x06, 0x4a,
		0x5a, 0x5b, 0x12, 0xf9, 0x1c, 0x44, 0xf2, 0x47, 0x16, 0x6d, 0x18, 0x0f, 0xc7, 0xd6, 0xeb, 0x07,
		0x4f, 0x67, 0xb6, 0xbb, 0x7e, 0xa7, 0x13, 0x8a, 0x28, 0x72, 0x00, 0x4a, 0x42, 0x00, 0x0f, 0xc1,
		0xf2, 0x14, 0x1c, 0x8f, 0x99, 0xe3, 0x39, 0xb7, 0x05, 0x20, 0xdf, 0x99, 0xf1, 0xa1, 0x43, 0x20,
		0x9b, 0xce, 0x7d, 0xad, 0x45, 0xa8, 0x60, 0xdc, 0x29, 0x31, 0xec, 0xdf, 0xdd, 0xdd, 0xab, 0x9c,
		0x7b, 0xd4, 0x78, 0xb8, 0xca, 0xbb, 0x47, 0x8d, 0xf8, 0x32, 0x3f, 0xfa, 0x12, 0x5f, 0xef, 0x5f,
		0xe5, 0xdc, 0xc2, 0xe4, 0xba, 0x78, 0x95, 0x73, 0x8b, 0x8d, 0xbd, 0x2f, 0x5f, 0xde, 0xed, 0xfd,
		0x3c, 0x78, 0x5c, 0xfe, 0x83, 0x7f, 0x38, 0x30, 0x7f, 0x7c, 0x03, 0xc9, 0x39, 0x6a, 0x17, 0xd5,
		0x7f, 0xe8, 0x21, 0x68, 0x1e, 0x02, 0x61, 0xc9, 0xe3, 0x5b, 0xc2, 0xcf, 0x42, 0xf8, 0x29, 0x11,
		0x7e, 0x36, 0x03, 0x7e, 0x7c, 0xb7, 0x5b, 0x71, 0x3f, 0x36, 0x7e, 0xe6, 0xdf, 0x16, 0x1e, 0xdf,
		0xef, 0xfd, 0x2c, 0x3f, 0xbe, 0x7c, 0xf3, 0x61, 0xde, 0x8f, 0xe5, 0xdf, 0x96, 0x1f, 0xdf, 0x2f,
		0xf8, 0x4e, 0xe9, 0xf1, 0xfd, 0x6f, 0xfe, 0x8e, 0xe2, 0xe3, 0xee, 0xcc, 0x8f, 0x0e, 0xdf, 0xdf,
		0x5f, 0xf4, 0x81, 0xc2, 0x82, 0x0f, 0x1c, 0x2c, 0xfa, 0xc0, 0xc1, 0x82, 0x0f, 0x2c, 0x34, 0x69,
		0x7f, 0xc1, 0x07, 0x8a, 0x8f, 0x0f, 0x33, 0x3f, 0xbf, 0x3b, 0xff, 0x47, 0x4b, 0x8f, 0x7b, 0x0f,
		0x8b, 0xbe, 0x57, 0x7e, 0x7c, 0x78, 0xbf, 0x47, 0x30, 0xce, 0x30, 0x18, 0x33, 0x5e, 0xb6, 0x3b,
		0x5e, 0x30, 0xa8, 0xc9, 0x9b, 0xed, 0x7e, 0x0e, 0x96, 0xa9, 0x19, 0x92, 0x86, 0x04, 0xb1, 0x55,
		0x6e, 0x86, 0x81, 0x01, 0x4c, 0x94, 0x63, 0x6d, 0x9d, 0x9b, 0x19, 0xb8, 0xea, 0xd9, 0xc5, 0x65,
		0xe5, 0xf4, 0xb4, 0x79, 0x5e, 0xaf, 0x5d, 0xd6, 0xfe, 0xac, 0x9d, 0x36, 0x2f, 0xff, 0xef, 0xfc,
		0xc4, 0x41, 0x5a, 0x02, 0x11, 0x41, 0x61, 0xf0, 0x4f, 0x2c, 0x36, 0x30, 0x19, 0xc6, 0xf3, 0xea,
		0x27, 0x1c, 0x70, 0x7a, 0x7c, 0xcb, 0xe1, 0xfa, 0x45, 0xd4, 0xfd, 0xf5, 0xe9, 0x9c, 0xe3, 0x95,
		0x9d, 0xf1, 0x3a, 0xae, 0xd6, 0x4f, 0xfe, 0xbc, 0x3c, 0xfd, 0xbf, 0xe6, 0x9f, 0xb5, 0xb3, 0xb3,
		0x93, 0x3f, 0x2f, 0x11, 0x76, 0x73, 0x71, 0xf4, 0x7e, 0x77, 0xf4, 0x6a, 0x17, 0xe7, 0x1f, 0x0f,
		0x38, 0x60, 0xd9, 0x19, 0xb0, 0x8b, 0xcb, 0xca, 0x65, 0xf5, 0x4f, 0x8e, 0x58, 0x86, 0x00, 0xed,
		0xa2, 0x7a, 0xc1, 0xf1, 0xca, 0xce, 0x78, 0x7d, 0xf8, 0x8b, 0xfc, 0x23, 0x63, 0x08, 0xc6, 0xf1,
		0xca, 0xce, 0x78, 0x9d, 0xd6, 0xfe, 0xac, 0x9c, 0x36, 0x2b, 0x7f, 0xfd, 0x55, 0x3f, 0xf9, 0xab,
		0x72, 0x79, 0x02, 0x34, 0x74, 0x10, 0x96, 0x34, 0xb8, 0x4d, 0x60, 0xab, 0x9e, 0xfc, 0x76, 0x6c,
		0x13, 0x98, 0x9c, 0xf0, 0x6f, 0x7d, 0x9f, 0xc0, 0xc4, 0x10, 0x4b, 0xcb, 0x5d, 0x8f, 0x45, 0xd7,
		0x1f, 0xf4, 0x46, 0x6b, 0x8d, 0x73, 0xdc, 0xac, 0xc0, 0xcd, 0x0a, 0xdc, 0xac, 0x30, 0xe5, 0x99,
		0xdc, 0xac, 0xf0, 0x0b, 0x83, 0xb8, 0x59, 0x61, 0x87, 0x9b, 0x15, 0xde, 0xef, 0x38, 0x03, 0xa9,
		0xf4, 0xc1, 0x3e, 0xc0, 0x6e, 0x85, 0x32, 0xbb, 0x1d, 0xb0, 0xdb, 0x01, 0x10, 0xbd, 0x98, 0x31,
		0x87, 0xdd, 0x0e, 0xb2, 0xa0, 0x59, 0xb0, 0xdb, 0xc1, 0x6f, 0xb8, 0x70, 0x61, 0xff, 0xa8, 0x70,
		0x54, 0x2a, 0xef, 0x1f, 0xb1, 0xc7, 0x01, 0xc5, 0x0b, 0x8a, 0x17, 0xe6, 0xc4, 0x0b, 0xbb, 0x05,
		0xe3, 0x93, 0x76, 0x61, 0xb3, 0x26, 0xa2, 0x6c, 0x40, 0xd9, 0x80, 0xb2, 0x01, 0x65, 0x03, 0xca,
		0x06, 0x19, 0x96, 0x0d, 0x46, 0x9b, 0x92, 0xad, 0xc7, 0x08, 0xc2, 0x26, 0x30, 0x98, 0x4d, 0x5f,
		0x66, 0x77, 0x90, 0x7a, 0xe3, 0x9b, 0xed, 0x3d, 0xec, 0x5e, 0xe5, 0xdd, 0xfd, 0xc6, 0xe4, 0x3f,
		0x07, 0x57, 0x39, 0x77, 0xbf, 0x61, 0x75, 0x1b, 0x47, 0xc3, 0xa6, 0x33, 0x20, 0x6d, 0x6b, 0xa2,
		0x47, 0xb0, 0xa6, 0x49, 0xdd, 0xc7, 0xc6, 0xe7, 0x00, 0x06, 0x03, 0x2d, 0xec, 0x17, 0x36, 0xcf,
		0x8d, 0x61, 0x75, 0xc3, 0xea, 0x86, 0xd5, 0x0d, 0xab, 0x1b, 0x56, 0x37, 0xac, 0x6e, 0x96, 0xcc,
		0x1b, 0xad, 0x20, 0xe8, 0x09, 0x1f, 0xa2, 0x87, 0x5b, 0x7e, 0x5b, 0xa8, 0xcb, 0x9b, 0x0d, 0x76,
		0x71, 0xa7, 0xa2, 0x54, 0xa0, 0x7d, 0x2d, 0x2d, 0x1d, 0xdd, 0xec, 0x44, 0xed, 0xaf, 0xe2, 0xc6,
		0xef, 0x8f, 0x4f, 0xfa, 0xf6, 0x82, 0xbe, 0x50, 0xed, 0x11, 0x51, 0x70, 0x95, 0xd0, 0x3f, 0x82,
		0xf0, 0xbb, 0x2b, 0x55, 0xa4, 0x7d, 0xd5, 0x16, 0xde, 0xcb, 0x37, 0xa2, 0x99, 0x77, 0xbc, 0x7e,
		0x18, 0xe8, 0xa0, 0x1d, 0xf4, 0xa2, 0xe4, 0xca, 0x6b, 0x5d, 0xf7, 0xbd, 0x50, 0xb6, 0x3c, 0xbf,
		0x2b, 0xdd, 0xc8, 0xef, 0xca, 0x28, 0xb9, 0xf2, 0x46, 0x52, 0xc1, 0x40, 0xc9, 0xb6, 0x1f, 0x69,
		0xaf, 0x17, 0xa7, 0x55, 0x6f, 0x44, 0xd1, 0xa2, 0xf8, 0x4b, 0x7c, 0x86, 0xb8, 0xd9, 0x2c, 0x6b,
		0xce, 0xdd, 0x0c, 0xba, 0x9a, 0x33, 0x50, 0xdf, 0x55, 0xf0, 0x43, 0xb9, 0xbe, 0xd6, 0xa1, 0x6c,
		0x0d, 0x9f, 0xb0, 0x71, 0x77, 0x7b, 0xd6, 0x05, 0x73, 0xc6, 0x16, 0xc3, 0x41, 0x37, 0x49, 0xa1,
		0x86, 0x6f, 0x6b, 0x8b, 0x81, 0xdb, 0x64, 0xde, 0x18, 0x8c, 0xdb, 0x36, 0xd3, 0x86, 0x61, 0xd8,
		0x30, 0xcc, 0x1a, 0x86, 0x51, 0x6f, 0x36, 0xbd, 0x38, 0x96, 0xa1, 0x9d, 0xb0, 0x9f, 0x49, 0xf2,
		0xf6, 0x25, 0xa0, 0x59, 0x93, 0xec, 0x0a, 0x41, 0x79, 0x0a, 0x41, 0x14, 0x82, 0x28, 0x04, 0x51,
		0x08, 0xa2, 0x10, 0x84, 0x0e, 0x67, 0x89, 0x01, 0x43, 0xec, 0x70, 0xb5, 0x6d, 0x39, 0x6a, 0x2a,
		0x83, 0x3d, 0x99, 0x64, 0x39, 0x34, 0x30, 0x96, 0xb4, 0x5a, 0x87, 0x37, 0x24, 0x98, 0xc3, 0x84,
		0x3b, 0x34, 0xd8, 0x83, 0x85, 0x3f, 0x58, 0x18, 0x84, 0x85, 0x43, 0xbb, 0xb0, 0x68, 0x19, 0x1e,
		0x93, 0x51, 0xb9, 0x44, 0x00, 0xa8, 0xa9, 0xbc, 0xd3, 0x13, 0x7e, 0x17, 0xac, 0x39, 0x65, 0x19,
		0xc0, 0x96, 0xf3, 0xb1, 0xee, 0xfe, 0xee, 0x5d, 0x2c, 0x75, 0x7b, 0x4f, 0x60, 0xbe, 0xa5, 0x9b,
		0x0c, 0x2c, 0x86, 0x8e, 0x13, 0xcf, 0x36, 0xc0, 0x10, 0xbb, 0xd8, 0x1c, 0x0c, 0x52, 0x97, 0x27,
		0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0xb3, 0x35, 0x2a, 0xb6, 0xb5, 0x8f, 0x69,
		0x0d, 0xa4, 0x27, 0x14, 0x5e, 0x37, 0xed, 0xc4, 0xb2, 0xb7, 0xdc, 0xe4, 0x0b, 0x0c, 0xa2, 0x88,
		0x60, 0x8a, 0x0d, 0xaa, 0xa8, 0xe0, 0x0a, 0x0f, 0xb2, 0xf0, 0x60, 0x0b, 0x0f, 0xba, 0x18, 0xe0,
		0x0b, 0x02, 0xc2, 0x78, 0x0a, 0xcb, 0x4c, 0xde, 0x1a, 0x48, 0xa5, 0xf3, 0x25, 0xc0, 0xf3, 0xd8,
		0x4a, 0x40, 0x26, 0x61, 0xb4, 0xf5, 0x79, 0xf9, 0xc2, 0xca, 0xe9, 0x3b, 0x68, 0x6d, 0x7f, 0xc0,
		0xe9, 0xd5, 0x8c, 0x79, 0x60, 0x6d, 0x81, 0x66, 0xec, 0x03, 0x6c, 0xad, 0x02, 0x9a, 0xee, 0xa7,
		0x43, 0xc2, 0xbf, 0x63, 0x48, 0xac, 0x18, 0x12, 0xa5, 0x62, 0xf1, 0xa0, 0xc8, 0xb0, 0xc8, 0x36,
		0x17, 0xc3, 0xb3, 0x86, 0xc7, 0xf2, 0xc1, 0xa4, 0x4d, 0xa0, 0x95, 0x32, 0x33, 0x14, 0x19, 0x65,
		0xc5, 0x0c, 0x68, 0xd6, 0xa6, 0x4e, 0xb4, 0x8c, 0x33, 0x51, 0x27, 0x5a, 0xca, 0xd3, 0xa9, 0x13,
		0xad, 0x68, 0x20, 0x75, 0xa2, 0x0c, 0x15, 0x0e, 0xe0, 0x3a, 0xd1, 0x21, 0xa0, 0x4c, 0x54, 0xa4,
		0x4c, 0xf4, 0x8b, 0x17, 0x65, 0xa2, 0x8d, 0xac, 0x89, 0x29, 0x13, 0x65, 0x3d, 0xdb, 0x4f, 0x87,
		0x04, 0x65, 0xa2, 0x95, 0x43, 0x62, 0xbf, 0x48, 0x91, 0x68, 0x03, 0x64, 0x99, 0x1d, 0x8a, 0x44,
		0x80, 0xcf, 0x03, 0x46, 0x24, 0xba, 0x1d, 0x47, 0x3b, 0xa2, 0x4a, 0x14, 0xdb, 0x46, 0x99, 0x68,
		0x9e, 0x39, 0x94, 0x89, 0x96, 0xf0, 0x26, 0xca, 0x44, 0x4b, 0x79, 0x3a, 0x65, 0xa2, 0x15, 0x0d,
		0xa4, 0x4c, 0x94, 0xa1, 0xc2, 0x01, 0x58, 0x26, 0x6a, 0x49, 0xe5, 0x87, 0xf7, 0x80, 0x3a, 0xd1,
		0x11, 0x90, 0x49, 0xa7, 0x42, 0x5d, 0x8f, 0x36, 0x72, 0x51, 0x28, 0xfa, 0x55, 0x55, 0x4c, 0xa1,
		0x68, 0xe5, 0xaa, 0x38, 0xcf, 0x9a, 0x38, 0xe3, 0xf9, 0x7e, 0x3a, 0x24, 0x28, 0x14, 0xad, 0x1c,
		0x12, 0x5c, 0x4f, 0xb4, 0x21, 0xe2, 0xcc, 0x0e, 0xa5, 0x22, 0xc0, 0xe7, 0x81, 0x20, 0x15, 0x89,
		0x3b, 0x2d, 0x54, 0x47, 0x74, 0xf0, 0x84, 0xa2, 0xc4, 0x32, 0xca, 0x44, 0xf3, 0xcc, 0xa1, 0x4c,
		0xb4, 0x84, 0x2f, 0x51, 0x26, 0x5a, 0xca, 0xd3, 0x29, 0x13, 0xad, 0x68, 0x20, 0x65, 0xa2, 0x0c,
		0x95, 0x0d, 0xc8, 0x32, 0x91, 0xf5, 0x73, 0x11, 0x16, 0xc1, 0xa0, 0xa5, 0x73, 0x12, 0x48, 0xe2,
		0xe6, 0x8d, 0x49, 0xd0, 0x1f, 0x56, 0x42, 0x7e, 0x0f, 0x8f, 0xc4, 0x25, 0x96, 0x91, 0xc4, 0x91,
		0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0x91, 0xc4, 0xbd,
		0x1c, 0x93, 0xbe, 0x1f, 0x6a, 0x89, 0xc8, 0xe1, 0x26, 0x86, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2,
		0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0xbd, 0x1c, 0x13, 0x1d,
		0xfa, 0x2a, 0x92, 0x5a, 0xde, 0x02, 0xae, 0xbb, 0x7f, 0x66, 0x1b, 0x89, 0x1c, 0x89, 0x1c, 0x89,
		0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x18, 0x91, 0xdb, 0xea, 0x76,
		0xf4, 0x96, 0x0f, 0xae, 0x9f, 0xb1, 0x07, 0xfb, 0x20, 0xfb, 0xd9, 0x33, 0xcf, 0x67, 0xdf, 0xb2,
		0x71, 0xda, 0x3d, 0x8e, 0x4f, 0x6f, 0xd7, 0x41, 0x96, 0xff, 0x13, 0xf7, 0x08, 0x9d, 0xe8, 0x9c,
		0x53, 0x19, 0xe9, 0x8a, 0xd6, 0x96, 0x4f, 0xd5, 0xfc, 0x24, 0xd5, 0x49, 0x4f, 0x0c, 0x69, 0x53,
		0x64, 0xb7, 0xac, 0x71, 0x3e, 0xf9, 0x77, 0xcf, 0x2c, 0xc9, 0x1f, 0x16, 0x0a, 0xa5, 0x72, 0xa1,
		0x90, 0x2b, 0x1f, 0x94, 0x73, 0x47, 0xc5, 0x62, 0xbe, 0x94, 0xb7, 0xb8, 0xcb, 0xc0, 0xa9, 0x85,
		0x1d, 0x11, 0x8a, 0xce, 0x87, 0xa1, 0xeb, 0xa8, 0x41, 0xaf, 0xb7, 0x55, 0x11, 0x03, 0x82, 0x37,
		0x1b, 0x80, 0x33, 0x8e, 0xd5, 0x23, 0xd6, 0xc2, 0x41, 0x5b, 0xab, 0x31, 0xc9, 0x3d, 0x8b, 0x1f,
		0x47, 0x75, 0xfc, 0x34, 0x9a, 0xe7, 0xe3, 0x67, 0xd0, 0xfc, 0x70, 0xdd, 0x6f, 0xd6, 0x65, 0xab,
		0x59, 0xe9, 0xca, 0x0b, 0xbf, 0x2b, 0x9b, 0xd5, 0xfe, 0x6d, 0xe1, 0x73, 0xfc, 0x77, 0x37, 0x4f,
		0x83, 0xf6, 0xf0, 0x5b, 0xf5, 0xe1, 0xdf, 0xdb, 0xfc, 0x1c, 0xff, 0x71, 0x95, 0xe4, 0x6f, 0x7b,
		0xb3, 0x1d, 0xd8, 0x65, 0xf6, 0x8e, 0x86, 0x63, 0xde, 0x76, 0xac, 0x67, 0x2e, 0xc6, 0xcd, 0x7a,
		0xbd, 0x39, 0xdf, 0x33, 0x73, 0x27, 0x43, 0xde, 0x3d, 0xe1, 0x7c, 0xb1, 0xb0, 0xb6, 0x13, 0x84,
		0xf2, 0x5a, 0xaa, 0x9d, 0xa1, 0x93, 0xb9, 0xd2, 0xd4, 0xde, 0x21, 0x3b, 0x7c, 0xcf, 0x1e, 0xbf,
		0x83, 0xe2, 0x73, 0x76, 0xf8, 0x9b, 0x29, 0xef, 0xb6, 0x94, 0xb3, 0xb1, 0x73, 0xb5, 0x41, 0xaa,
		0xb5, 0x6e, 0x6a, 0x65, 0x06, 0x53, 0xd2, 0xcf, 0xf0, 0xe9, 0xde, 0x21, 0xe5, 0xe8, 0x32, 0x1d,
		0x55, 0xa8, 0xd1, 0x94, 0xae, 0x33, 0xa6, 0xe7, 0x22, 0x29, 0xba, 0x87, 0xa1, 0xd3, 0xaa, 0x8d,
		0x9e, 0x46, 0x6d, 0xe8, 0xb4, 0xe9, 0xa7, 0x19, 0xf4, 0xfd, 0x94, 0x6f, 0x64, 0x70, 0x66, 0xdc,
		0xce, 0x8c, 0xb7, 0xe9, 0x99, 0x6c, 0x6b, 0x33, 0xd4, 0xd6, 0x66, 0x9e, 0xad, 0xcd, 0x28, 0x13,
		0x38, 0x33, 0x0d, 0x9c, 0x06, 0x26, 0x93, 0x52, 0xc4, 0xcd, 0x37, 0x19, 0xf2, 0x39, 0x53, 0xbe,
		0x06, 0xe7, 0x63, 0x4e, 0xaa, 0xec, 0x66, 0x4d, 0xd5, 0x4c, 0x3a, 0x21, 0xb0, 0x7e, 0x07, 0x4d,
		0xc1, 0x39, 0x1d, 0x25, 0xe4, 0xf5, 0xd7, 0x56, 0x10, 0x46, 0xa9, 0xf9, 0x65, 0xc2, 0x3a, 0x9e,
		0x6e, 0x95, 0x52, 0x90, 0xa5, 0x4b, 0x0d, 0x53, 0xa7, 0x84, 0x26, 0xa8, 0xa0, 0x59, 0x0a, 0x68,
		0x8a, 0xfa, 0x19, 0xa7, 0x7c, 0xc6, 0xa9, 0x9e, 0x71, 0x8a, 0x97, 0x2d, 0x78, 0x3d, 0x96, 0xe9,
		0xca, 0xd5, 0x49, 0xee, 0x32, 0x57, 0x4c, 0x27, 0x77, 0xdc, 0xb0, 0x7a, 0x3a, 0xc7, 0x7a, 0x9a,
		0xf5, 0x34, 0xeb, 0xe9, 0x0d, 0xac, 0xa7, 0xd3, 0x4e, 0xc2, 0xc9, 0x8d, 0xfc, 0xce, 0xb7, 0xd1,
		0x98, 0x48, 0xe5, 0xf6, 0x83, 0x48, 0x9b, 0x8b, 0x84, 0xe4, 0xdc, 0x8f, 0x17, 0x06, 0x98, 0x9a,
		0x1d, 0x36, 0x92, 0xaa, 0x8d, 0xa7, 0x6c, 0x1b, 0xa9, 0xdb, 0x6e, 0x0a, 0xb7, 0x95, 0xca, 0xad,
		0xa7, 0x74, 0xeb, 0xa9, 0xdd, 0x7a, 0x8a, 0x37, 0x93, 0xea, 0x0d, 0xa5, 0x7c, 0xe3, 0xa9, 0x3f,
		0xb9, 0xe1, 0x78, 0xce, 0xcf, 0x78, 0xe0, 0x4c, 0xd2, 0xc5, 0xf8, 0xfe, 0x86, 0x9d, 0xd6, 0x2c,
		0x00, 0x18, 0x13, 0x3e, 0x90, 0x00, 0x01, 0x03, 0x18, 0x6c, 0x03, 0x04, 0x0c, 0x50, 0xc0, 0x00,
		0x06, 0x0c, 0x70, 0x98, 0x05, 0x10, 0xc3, 0x40, 0x62, 0x0d, 0x50, 0xa6, 0x81, 0xc5, 0x5e, 0xbc,
		0x4d, 0xe1, 0x8b, 0xad, 0x58, 0xb3, 0x03, 0x33, 0xd6, 0xea, 0x0e, 0x24, 0xd8, 0xc1, 0x82, 0x1f,
		0x14, 0x18, 0x82, 0x83, 0x23, 0x38, 0x58, 0x82, 0x83, 0x27, 0x3b, 0x30, 0x65, 0x09, 0xae, 0xac,
		0xc3, 0x56, 0x62, 0xc0, 0x64, 0xaf, 0x80, 0xf5, 0x48, 0x7d, 0x6a, 0xb8, 0x68, 0x72, 0xf3, 0xc2,
		0xaf, 0x20, 0xcd, 0x72, 0x3b, 0x1c, 0x98, 0xbe, 0x3c, 0x48, 0xfd, 0x78, 0x30, 0xfb, 0xf0, 0xa0,
		0xf5, 0xdf, 0x81, 0xed, 0xbb, 0x03, 0xdb, 0x6f, 0x07, 0xb6, 0xcf, 0xce, 0x76, 0x37, 0x05, 0x81,
		0xe9, 0xa7, 0x93, 0xe4, 0x9d, 0x9e, 0xf0, 0xbb, 0xa1, 0xe8, 0x22, 0x24, 0x9d, 0x49, 0xe5, 0x55,
		0x06, 0xb0, 0xe5, 0x7c, 0xbc, 0x88, 0xf0, 0xdd, 0xbb, 0x78, 0xa1, 0xa8, 0x37, 0x81, 0xf2, 0x6d,
		0xed, 0x3e, 0x62, 0xb1, 0xfe, 0xea, 0x63, 0xc0, 0xf5, 0x13, 0xab, 0x83, 0x28, 0xbe, 0x48, 0xea,
		0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x5e, 0x49, 0xea, 0xe2,
		0xb4, 0x43, 0x4e, 0x67, 0x7c, 0x28, 0xcc, 0x6c, 0xce, 0xfd, 0xed, 0x80, 0x31, 0xb1, 0x79, 0xf7,
		0xb7, 0x43, 0x85, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0xce, 0xd6, 0xa8, 0xd8,
		0x9e, 0xc9, 0x4a, 0x0c, 0x19, 0xf5, 0x3f, 0x95, 0xaa, 0x23, 0xee, 0xf0, 0xce, 0xa1, 0x78, 0x66,
		0x1b, 0xcf, 0xa1, 0x40, 0x06, 0x52, 0x44, 0x40, 0xc5, 0x06, 0x56, 0x54, 0x80, 0x85, 0x07, 0x5a,
		0x78, 0xc0, 0x85, 0x07, 0x5e, 0x0c, 0x00, 0x06, 0x01, 0x62, 0x3c, 0x89, 0x05, 0x58, 0x6a, 0x41,
		0x94, 0x5c, 0xe6, 0x49, 0x2f, 0xff, 0xf1, 0x6f, 0x44, 0x29, 0x22, 0xa1, 0xa3, 0xe4, 0x6a, 0x2c,
		0xd4, 0xc4, 0x34, 0x83, 0xe7, 0x6a, 0xa0, 0x04, 0xa5, 0xd3, 0x12, 0x91, 0x76, 0xc7, 0x9d, 0x56,
		0xc0, 0x78, 0xe9, 0x93, 0x69, 0xa4, 0xa5, 0xa4, 0xa5, 0xa4, 0xa5, 0xa4, 0xa5, 0xa4, 0xa5, 0xa4,
		0xa5, 0x5b, 0x46, 0x4b, 0x79, 0x3c, 0x1a, 0x69, 0xdc, 0x6f, 0x8c, 0x49, 0x3b, 0xb8, 0xb9, 0x19,
		0x28, 0xa9, 0xef, 0x51, 0x45, 0xc6, 0x97, 0x06, 0x92, 0xd2, 0x91, 0xd2, 0x91, 0xd2, 0x91, 0xd2,
		0x91, 0xd2, 0x91, 0xd2, 0x6d, 0x19, 0xa5, 0xa3, 0xd2, 0xf8, 0x7b, 0xd0, 0xf3, 0x5b, 0x4a, 0xe3,
		0x84, 0x57, 0x48, 0x11, 0x25, 0xd7, 0xf7, 0x14, 0x1b, 0x31, 0x59, 0xaa, 0xb8, 0xd3, 0x2e, 0x3c,
		0x53, 0x9d, 0x67, 0x24, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a,
		0xd9, 0x2a, 0xd9, 0xea, 0x6b, 0xd9, 0xea, 0x73, 0x6e, 0x31, 0x64, 0xac, 0x53, 0x5c, 0x83, 0xac,
		0x15, 0x93, 0xb5, 0x4a, 0x75, 0xeb, 0xf7, 0x64, 0xc7, 0x0d, 0x85, 0x1f, 0x59, 0x3e, 0x94, 0x7b,
		0x6e, 0x84, 0xbe, 0xb0, 0x8f, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c,
		0x75, 0xcb, 0xb8, 0xaa, 0xec, 0x08, 0xa5, 0xa5, 0xbe, 0x07, 0xe5, 0xab, 0x45, 0x20, 0x9b, 0xaa,
		0xe3, 0x47, 0xf5, 0xc1, 0x8f, 0x00, 0x53, 0xea, 0x64, 0x40, 0xab, 0x67, 0x7f, 0x57, 0x4e, 0xab,
		0xc7, 0xcd, 0x7a, 0xed, 0xf3, 0xe5, 0x49, 0xb3, 0x7e, 0x52, 0xb9, 0xa8, 0x9d, 0xa1, 0x65, 0xd7,
		0xbf, 0xfd, 0xde, 0x60, 0xd4, 0xc4, 0xfb, 0x0a, 0xca, 0xae, 0xe1, 0xeb, 0x27, 0x9c, 0x45, 0x73,
		0x47, 0xf7, 0xcf, 0xd3, 0xcf, 0x17, 0x97, 0x27, 0xf5, 0xe6, 0x69, 0xad, 0x76, 0xee, 0xc0, 0x99,
		0xfc, 0xf8, 0x96, 0xe3, 0xfa, 0xba, 0x71, 0xad, 0x5c, 0x70, 0x48, 0x37, 0x6c, 0x48, 0x6b, 0xf5,
		0xea, 0x5f, 0xd5, 0xb3, 0xca, 0x65, 0xad, 0xce, 0x51, 0xdd, 0xa0, 0x04, 0x5c, 0x3b, 0xfb, 0x78,
		0x72, 0x0c, 0x38, 0xa2, 0x50, 0x16, 0x35, 0x58, 0x8f, 0x80, 0x59, 0x81, 0xa0, 0x0e, 0xf6, 0xfc,
		0x48, 0xbb, 0x37, 0x41, 0x47, 0x76, 0xa5, 0xe8, 0xe0, 0x89, 0x83, 0xd3, 0xe6, 0x51, 0x1b, 0x9c,
		0x67, 0x0e, 0xb5, 0xc1, 0x25, 0x1c, 0x8a, 0xda, 0xe0, 0x52, 0x9e, 0x4e, 0x6d, 0x70, 0x45, 0x03,
		0xa9, 0x0d, 0x66, 0x88, 0xfb, 0x02, 0x6b, 0x83, 0x5a, 0xde, 0x08, 0x2d, 0xdb, 0xdf, 0xa3, 0x52,
		0x01, 0x50, 0x1b, 0x3c, 0x04, 0x32, 0xe9, 0xb3, 0x92, 0x3a, 0x1a, 0x1d, 0xde, 0xec, 0xab, 0x20,
		0x12, 0xed, 0x40, 0x75, 0x22, 0xa4, 0x47, 0x56, 0xf7, 0xd5, 0xb5, 0x80, 0xd3, 0xdb, 0xf0, 0x4a,
		0x3d, 0xe7, 0x93, 0x54, 0x70, 0x88, 0x08, 0xca, 0x01, 0x67, 0xcc, 0x1b, 0xa9, 0xba, 0xc0, 0xf6,
		0x7d, 0x0c, 0xfd, 0xb6, 0x96, 0x81, 0x3a, 0x96, 0xd7, 0x71, 0xb4, 0xe6, 0xa8, 0xc7, 0xfc, 0x4e,
		0x48, 0xf8, 0x77, 0x0c, 0x89, 0x15, 0x43, 0x22, 0x7f, 0x58, 0x28, 0x94, 0xca, 0x85, 0x42, 0xae,
		0x7c, 0x50, 0xce, 0x1d, 0x15, 0x8b, 0xf9, 0x12, 0xd2, 0xcc, 0x56, 0xe6, 0xa2, 0xe4, 0x0d, 0xad,
		0x99, 0xf7, 0x6a, 0x50, 0xe3, 0x42, 0xc9, 0xa2, 0x30, 0xe7, 0x71, 0xcd, 0x90, 0x7a, 0x8c, 0x73,
		0xb9, 0x40, 0x13, 0x38, 0x75, 0xad, 0x65, 0x5c, 0x89, 0xba, 0xd6, 0x52, 0x9e, 0x4e, 0x5d, 0x6b,
		0x45, 0x03, 0xa9, 0x6b, 0x65, 0xa8, 0x86, 0x00, 0xd6, 0xb5, 0x06, 0x52, 0xe9, 0x83, 0x7d, 0x40,
		0x49, 0xab, 0x4c, 0xc9, 0xe8, 0x17, 0x2f, 0x4a, 0x46, 0x1b, 0x59, 0x1f, 0x53, 0x32, 0xca, 0x7a,
		0xba, 0x9f, 0x0e, 0x09, 0x4a, 0x46, 0x2b, 0x87, 0x44, 0x61, 0xff, 0xa8, 0x70, 0x54, 0x2a, 0xef,
		0x1f, 0x51, 0x28, 0xda, 0x00, 0x69, 0x66, 0x87, 0x42, 0x11, 0xe0, 0xf3, 0x80, 0x10, 0x8a, 0xb0,
		0x0a, 0x7c, 0xac, 0x93, 0x3e, 0x41, 0x93, 0x36, 0x65, 0xa2, 0x65, 0x3c, 0x89, 0x32, 0xd1, 0x52,
		0x9e, 0x4e, 0x99, 0x68, 0x45, 0x03, 0x29, 0x13, 0x65, 0xa8, 0x6e, 0x40, 0xde, 0x1a, 0xd9, 0xbf,
		0x2d, 0xb8, 0x70, 0x31, 0x98, 0x6c, 0x8d, 0x3c, 0xc4, 0x6a, 0xe5, 0xa1, 0x45, 0xa8, 0xe0, 0xe4,
		0x22, 0xe7, 0xdf, 0xdd, 0xdd, 0xab, 0x9c, 0x7b, 0xd4, 0x78, 0xb8, 0xca, 0xbb, 0x47, 0x8d, 0xf8,
		0x32, 0x3f, 0xfa, 0x12, 0x5f, 0xef, 0x5f, 0xe5, 0xdc, 0xc2, 0xe4, 0xba, 0x78, 0x95, 0x73, 0x8b,
		0x8d, 0xbd, 0x2f, 0x5f, 0xde, 0xed, 0xfd, 0x3c, 0x78, 0x5c, 0xfe, 0x83, 0xde, 0xf8, 0x66, 0x7b,
		0x0f, 0xbb, 0x57, 0x79, 0x77, 0xbf, 0x31, 0xf9, 0xcf, 0xc1, 0x55, 0xce, 0xdd, 0x6f, 0xec, 0xed,
		0xfd, 0x81, 0x93, 0x83, 0x1a, 0x48, 0xce, 0x53, 0xbb, 0xa8, 0xfe, 0x43, 0x0f, 0xca, 0x9a, 0x07,
		0xb1, 0x86, 0x84, 0xa9, 0x21, 0xc7, 0xcd, 0x6c, 0x82, 0x81, 0x16, 0x78, 0x85, 0xe4, 0x73, 0xe3,
		0x58, 0x4d, 0xb2, 0x9a, 0x64, 0x35, 0xc9, 0x6a, 0x92, 0xd5, 0x24, 0xab, 0xc9, 0x2d, 0xab, 0x26,
		0x79, 0x2a, 0x0d, 0x3e, 0x95, 0xdb, 0xea, 0x83, 0xbf, 0x2b, 0x4a, 0x05, 0xda, 0xd7, 0x12, 0xa4,
		0x5f, 0xa3, 0x13, 0xb5, 0xbf, 0x8a, 0x1b, 0x7f, 0x7c, 0xce, 0xa2, 0xe3, 0x05, 0x7d, 0xa1, 0xda,
		0x23, 0xa2, 0xe4, 0x2a, 0xa1, 0x7f, 0x04, 0xe1, 0x77, 0x57, 0xaa, 0x48, 0xfb, 0xaa, 0x2d, 0xbc,
		0x97, 0x6f, 0x44, 0x33, 0xef, 0x78, 0xfd, 0x30, 0xd0, 0x41, 0x3b, 0xe8, 0x45, 0xc9, 0x95, 0xd7,
		0xba, 0xee, 0x7b, 0xa1, 0x6c, 0x79, 0x7e, 0x57, 0xba, 0x91, 0xdf, 0x95, 0x51, 0x72, 0xe5, 0x8d,
		0xa4, 0x9f, 0x81, 0x92, 0x6d, 0x3f, 0xd2, 0x9e, 0x12, 0xf2, 0xfa, 0x6b, 0x2b, 0x08, 0xa3, 0xe4,
		0xca, 0xf3, 0x3b, 0xdf, 0x46, 0x48, 0x20, 0x95, 0xdb, 0x0f, 0x22, 0xed, 0x8d, 0xd8, 0x6d, 0x14,
		0x7f, 0x89, 0x7b, 0x92, 0xda, 0x05, 0x08, 0x7b, 0x9e, 0x6c, 0xd1, 0x8b, 0x9d, 0x81, 0xfa, 0xae,
		0x82, 0x1f, 0xca, 0xf5, 0xb5, 0x0e, 0x65, 0x6b, 0x38, 0x22, 0xd6, 0x3d, 0xf9, 0x69, 0xcd, 0xd9,
		0xac, 0x6d, 0x96, 0xe3, 0x7d, 0x92, 0xfd, 0x2d, 0x9b, 0x81, 0x52, 0xfc, 0x20, 0x15, 0x3d, 0x98,
		0xc5, 0x0e, 0x5a, 0x91, 0x03, 0x5b, 0xdc, 0xc0, 0x16, 0x35, 0xb0, 0xc5, 0xcc, 0x76, 0x33, 0xaf,
		0x63, 0x19, 0x62, 0xa4, 0x9d, 0x19, 0x90, 0xc2, 0x53, 0x13, 0x67, 0x4d, 0xc4, 0xd2, 0x14, 0xf3,
		0xd4, 0x14, 0xe1, 0xe1, 0x15, 0x1b, 0x66, 0x51, 0xe1, 0x16, 0x1e, 0x76, 0xe1, 0xe1, 0x17, 0x1e,
		0x86, 0x71, 0xa4, 0x98, 0x1d, 0x20, 0x4d, 0x11, 0x05, 0x9e, 0x13, 0x83, 0x86, 0xd8, 0xe7, 0x6a,
		0x34, 0xa5, 0x73, 0x2a, 0xa3, 0x3e, 0x99, 0x08, 0x16, 0x7a, 0x98, 0xab, 0xff, 0xe1, 0xe0, 0x1a,
		0x19, 0xb6, 0xb3, 0x01, 0xdf, 0xe8, 0x30, 0x9e, 0x19, 0x38, 0xcf, 0x0c, 0xac, 0x67, 0x06, 0xde,
		0xb1, 0x60, 0x1e, 0x0c, 0xee, 0x93, 0x51, 0xbc, 0x44, 0x04, 0xd8, 0x1d, 0xec, 0x73, 0xe6, 0x66,
		0xaa, 0xe1, 0x32, 0xa0, 0x6d, 0xcf, 0xce, 0x9d, 0x8b, 0x8f, 0x8f, 0x7b, 0x22, 0x2b, 0xdc, 0x2f,
		0x86, 0x1e, 0x9a, 0x4e, 0x3c, 0xbb, 0x06, 0x4b, 0x7c, 0x63, 0xf3, 0x30, 0x49, 0x6f, 0x9e, 0xa4,
		0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xc8, 0x3a, 0x7f, 0x14, 0xd1, 0xb4, 0xae,
		0xc4, 0xb0, 0x11, 0x47, 0xeb, 0x09, 0xe0, 0x56, 0x2b, 0x53, 0xd2, 0xd7, 0xd0, 0xd2, 0xb7, 0xec,
		0x7f, 0xb1, 0x41, 0xa4, 0x20, 0x0b, 0xe4, 0x20, 0x5b, 0x24, 0x21, 0x2b, 0x64, 0x21, 0x73, 0xa4,
		0x21, 0x73, 0xe4, 0x21, 0x73, 0x24, 0x02, 0x93, 0x4c, 0x80, 0x92, 0x8a, 0x64, 0x74, 0x61, 0x15,
		0xb5, 0x99, 0xbc, 0x39, 0x90, 0x4a, 0xe7, 0x4b, 0xc8, 0x39, 0x73, 0x8c, 0xe2, 0x25, 0x60, 0x13,
		0x31, 0x3b, 0x08, 0xbe, 0x7c, 0x61, 0x63, 0xce, 0x0e, 0x7a, 0x87, 0xc1, 0x8c, 0xd1, 0xcb, 0x19,
		0x73, 0xc1, 0x3b, 0x10, 0xce, 0xd8, 0x9b, 0x81, 0xae, 0x6b, 0x19, 0x81, 0xa3, 0xe9, 0x10, 0xf3,
		0xef, 0x18, 0x62, 0x29, 0x87, 0x58, 0xa9, 0x58, 0x3c, 0x28, 0x32, 0xcc, 0xb6, 0x8b, 0x8b, 0xe2,
		0x5b, 0xd7, 0x78, 0xc3, 0xe7, 0x95, 0xd1, 0x34, 0x0e, 0xbc, 0x12, 0x6e, 0xa6, 0xa4, 0x40, 0x5d,
		0x11, 0x97, 0x11, 0x54, 0xa1, 0x2e, 0xb8, 0x4e, 0x67, 0xa4, 0x2e, 0xb8, 0xd6, 0xc8, 0xa1, 0x2e,
		0x98, 0xb2, 0xc1, 0xd4, 0x05, 0x37, 0xb8, 0x10, 0xcb, 0x98, 0x2e, 0x78, 0x98, 0x01, 0x59, 0xb0,
		0x48, 0x59, 0x70, 0xc5, 0x17, 0x65, 0x41, 0x6a, 0x16, 0x94, 0x05, 0xb7, 0x10, 0x8d, 0xa6, 0x43,
		0x8c, 0xb2, 0x60, 0xea, 0x21, 0xb6, 0x5f, 0xa4, 0x28, 0xb8, 0x65, 0x44, 0x14, 0xdf, 0x3a, 0x8a,
		0x82, 0x99, 0x4d, 0xe2, 0xb1, 0xd2, 0x76, 0x3b, 0xce, 0x2e, 0x59, 0x50, 0x05, 0x63, 0x5b, 0x29,
		0x0b, 0xbe, 0xc6, 0x3c, 0xca, 0x82, 0x6b, 0xf4, 0x46, 0xca, 0x82, 0x6b, 0x8d, 0x1c, 0xca, 0x82,
		0x29, 0x1b, 0x4c, 0x59, 0x70, 0x83, 0x0b, 0xb1, 0x0c, 0xc9, 0x82, 0x2d, 0xa9, 0xfc, 0xf0, 0x3e,
		0x03, 0xba, 0xe0, 0x11, 0xb0, 0x89, 0xa7, 0x42, 0x5d, 0x8f, 0x36, 0xe6, 0x52, 0x18, 0x5c, 0x55,
		0xb5, 0xa0, 0x30, 0x98, 0xba, 0x6a, 0x91, 0xa7, 0x66, 0xb1, 0x65, 0x78, 0x34, 0x1d, 0x62, 0x14,
		0x06, 0x53, 0x0f, 0x31, 0xae, 0x17, 0xdc, 0x42, 0x32, 0x8a, 0x6f, 0x1d, 0xa5, 0xc1, 0xcc, 0xa6,
		0x71, 0x47, 0xdc, 0x69, 0xa1, 0x3a, 0xa2, 0x83, 0x2f, 0x0c, 0x26, 0x96, 0x52, 0x16, 0x7c, 0x8d,
		0x79, 0x94, 0x05, 0xd7, 0xe8, 0x8b, 0x94, 0x05, 0xd7, 0x1a, 0x39, 0x94, 0x05, 0x53, 0x36, 0x98,
		0xb2, 0xe0, 0x06, 0x97, 0x61, 0x59, 0x92, 0x05, 0xe1, 0x8e, 0xfc, 0x5a, 0x04, 0xe3, 0x20, 0x47,
		0x80, 0x91, 0xd4, 0xbe, 0x66, 0x0c, 0x83, 0xfe, 0xb0, 0xf2, 0xf4, 0x7b, 0xf8, 0xa4, 0x36, 0xb1,
		0x94, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4,
		0x96, 0xa4, 0x96, 0x41, 0x31, 0x3d, 0x86, 0x7d, 0x3f, 0xd4, 0x32, 0x0b, 0x9c, 0x76, 0x62, 0x28,
		0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d,
		0x29, 0x2d, 0x83, 0x62, 0x7a, 0x0c, 0x75, 0xe8, 0xab, 0x48, 0x6a, 0x79, 0x9b, 0x81, 0x7d, 0x49,
		0xcf, 0x6c, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1,
		0x25, 0xb1, 0x25, 0xb1, 0xa5, 0x45, 0xa0, 0x21, 0xea, 0x54, 0x94, 0x0a, 0xb4, 0xaf, 0x65, 0x80,
		0xb9, 0x01, 0xca, 0x89, 0xda, 0x5f, 0xc5, 0x8d, 0xdf, 0x1f, 0x1f, 0x40, 0xe9, 0x05, 0x7d, 0xa1,
		0xda, 0x23, 0xa2, 0xe8, 0x2a, 0xa1, 0x7f, 0x04, 0xe1, 0x77, 0x57, 0xaa, 0x48, 0xfb, 0xaa, 0x2d,
		0xbc, 0x97, 0x6f, 0x44, 0x33, 0xef, 0x78, 0xfd, 0x30, 0xd0, 0x41, 0x3b, 0xe8, 0x45, 0xc9, 0x95,
		0xd7, 0xba, 0xee, 0x7b, 0xa1, 0x6c, 0x79, 0x7e, 0x57, 0xba, 0x91, 0xdf, 0x95, 0x51, 0x72, 0xe5,
		0xc9, 0xfe, 0x6d, 0xc1, 0x1d, 0x28, 0xd9, 0xf6, 0x23, 0xed, 0x29, 0x21, 0xaf, 0xbf, 0xb6, 0x82,
		0x30, 0x4a, 0xae, 0x3c, 0xbf, 0xf3, 0x6d, 0x84, 0x54, 0x52, 0xb9, 0xfd, 0x20, 0xd2, 0x5e, 0x18,
		0x0c, 0xb4, 0x88, 0xe2, 0x2f, 0xde, 0x40, 0x7d, 0x57, 0xc1, 0x0f, 0xe5, 0xfa, 0x5a, 0x87, 0xb2,
		0x35, 0xfa, 0xc6, 0xcc, 0x5b, 0xf1, 0x69, 0x9a, 0x3c, 0x43, 0x13, 0xd9, 0x12, 0x94, 0x33, 0xf5,
		0xff, 0x27, 0xee, 0x11, 0x9b, 0xe2, 0x3a, 0xa7, 0x32, 0xd2, 0x15, 0xad, 0xc1, 0x0e, 0xfc, 0xff,
		0x24, 0xd5, 0x49, 0x4f, 0x0c, 0x19, 0x65, 0x84, 0x55, 0x51, 0x3a, 0x9f, 0xfc, 0xbb, 0x67, 0x96,
		0xe5, 0x0f, 0x0b, 0x85, 0x52, 0xb9, 0x50, 0xc8, 0x95, 0x0f, 0xca, 0xb9, 0xa3, 0x62, 0x31, 0x5f,
		0xca, 0x03, 0x6d, 0xe0, 0x72, 0x6a, 0x61, 0x47, 0x84, 0xa2, 0xf3, 0x61, 0xe8, 0x7a, 0x6a, 0xd0,
		0xeb, 0x31, 0x22, 0xf1, 0xa1, 0x73, 0xb3, 0x21, 0xd3, 0x81, 0x3a, 0x58, 0x39, 0x1c, 0xb4, 0xb5,
		0x1a, 0x97, 0x0e, 0x67, 0xf1, 0x93, 0xab, 0x8e, 0x1f, 0x5c, 0xf3, 0x7c, 0xfc, 0xb8, 0x9a, 0x1f,
		0xae, 0xfb, 0xcd, 0xba, 0x6c, 0x35, 0x2b, 0x5d, 0x79, 0xe1, 0x77, 0x65, 0xb3, 0xda, 0xbf, 0x2d,
		0x7c, 0x8e, 0x1f, 0x51, 0xf3, 0x6c, 0xfc, 0x60, 0x9a, 0x95, 0xce, 0xb7, 0xba, 0x6c, 0x55, 0xd5,
		0x79, 0x10, 0xe9, 0x66, 0x7d, 0xf8, 0x38, 0x9a, 0x9f, 0xe3, 0xbf, 0xbd, 0x92, 0xfc, 0xe9, 0x6f,
		0x88, 0xca, 0xf6, 0x2d, 0xb0, 0x9c, 0x7d, 0xd0, 0xb2, 0xce, 0x26, 0x65, 0x1b, 0xbb, 0x01, 0x66,
		0xcf, 0xad, 0xed, 0xdc, 0xd9, 0x52, 0x20, 0x4d, 0x88, 0x74, 0x2c, 0xe4, 0xee, 0x0c, 0x1d, 0xd7,
		0x95, 0xb6, 0x36, 0x8d, 0x62, 0xb0, 0x67, 0x1c, 0xb6, 0x0c, 0xcd, 0x8e, 0x31, 0xd8, 0xb0, 0xad,
		0xb0, 0x01, 0xc1, 0x9d, 0xcc, 0xe2, 0x8d, 0x45, 0xe2, 0x9a, 0x32, 0x51, 0xb5, 0x03, 0x9b, 0xe6,
		0x41, 0xcb, 0xec, 0x1d, 0x0d, 0xc7, 0xb9, 0xed, 0xf8, 0xce, 0x60, 0x5c, 0x9b, 0xf5, 0x7b, 0x73,
		0xde, 0x67, 0xd0, 0xf3, 0x9c, 0x58, 0x00, 0x37, 0xed, 0x70, 0xc9, 0x74, 0x5f, 0x7c, 0x7b, 0xc3,
		0x91, 0x36, 0x99, 0xc0, 0x33, 0x7c, 0xdb, 0x64, 0x7d, 0xcd, 0xbe, 0xe1, 0x1b, 0x5b, 0x5c, 0x37,
		0x83, 0xb1, 0x1e, 0xc6, 0xf6, 0x3a, 0x17, 0x98, 0xf5, 0x2b, 0x30, 0xeb, 0x52, 0x60, 0xd6, 0x9b,
		0x90, 0x53, 0x90, 0x53, 0xc4, 0x9c, 0xc2, 0xc2, 0x54, 0xb0, 0x41, 0x4a, 0xf1, 0x66, 0x83, 0xdc,
		0xdb, 0x96, 0x5b, 0x67, 0xc9, 0x9d, 0x1d, 0xa3, 0x1c, 0x32, 0x9d, 0xea, 0xd6, 0x4c, 0x30, 0xa6,
		0x1f, 0x1a, 0x06, 0xc2, 0xc2, 0x79, 0x3e, 0xfc, 0xa1, 0x39, 0xa6, 0xf3, 0x74, 0x2a, 0xc8, 0xf4,
		0xfd, 0x0d, 0x25, 0x02, 0xb3, 0x4c, 0xde, 0xf8, 0x0a, 0x79, 0x1b, 0xcc, 0xdd, 0x2e, 0x63, 0xb7,
		0xc5, 0xd4, 0xad, 0x33, 0x74, 0xeb, 0xcc, 0xdc, 0x3a, 0x23, 0xdf, 0x2c, 0x8a, 0x72, 0x2c, 0xcd,
		0x4e, 0x29, 0x39, 0x63, 0x49, 0xcc, 0x9a, 0x92, 0x33, 0xbe, 0x3f, 0xa5, 0x1c, 0x4a, 0x39, 0x94,
		0x72, 0x28, 0xe5, 0x50, 0xca, 0xc9, 0x38, 0xa0, 0x4c, 0x03, 0x8b, 0xbd, 0x78, 0x9b, 0xc2, 0x17,
		0x5b, 0xb1, 0x66, 0x07, 0x66, 0xac, 0xd5, 0x1d, 0x48, 0xb0, 0x83, 0x05, 0x3f, 0x28, 0x30, 0x04,
		0x07, 0x47, 0x70, 0xb0, 0x04, 0x07, 0x4f, 0x76, 0x60, 0xca, 0x12, 0x5c, 0x59, 0x87, 0xad, 0xc4,
		0x80, 0xc9, 0xfa, 0x42, 0xeb, 0x91, 0xfa, 0xd4, 0x7d, 0xcd, 0xe6, 0x82, 0xc7, 0x97, 0x90, 0x66,
		0x79, 0x67, 0x0e, 0x4c, 0xd3, 0x09, 0xa4, 0xe6, 0x12, 0x98, 0x4d, 0x24, 0xd0, 0x9a, 0x45, 0xc0,
		0x36, 0x85, 0x80, 0x6d, 0xfe, 0x00, 0xdb, 0xe4, 0x61, 0xbb, 0x37, 0x94, 0xc0, 0x34, 0x67, 0x48,
		0xf2, 0x4e, 0x4f, 0xf8, 0xdd, 0x50, 0x74, 0x11, 0x92, 0xce, 0xa4, 0xf2, 0x2a, 0x03, 0xd8, 0x72,
		0x3e, 0x9e, 0xf8, 0x7d, 0xf7, 0x2e, 0x5e, 0x2c, 0xe0, 0x4d, 0xa0, 0x7c, 0x5b, 0xb7, 0xad, 0x58,
		0xac, 0xbf, 0xfa, 0x18, 0x70, 0xfd, 0xc4, 0xea, 0x20, 0x8a, 0x2f, 0x92, 0x3a, 0x92, 0x3a, 0x92,
		0x3a, 0x92, 0x3a, 0x92, 0x3a, 0x92, 0x3a, 0x92, 0xba, 0x57, 0x92, 0xba, 0x38, 0xed, 0x90, 0xd3,
		0x19, 0x1f, 0x0a, 0x3b, 0x7b, 0x51, 0x16, 0x06, 0x8c, 0x8d, 0xbd, 0x29, 0x0b, 0x43, 0x85, 0x8c,
		0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0xce, 0xd6, 0xa8, 0xd8, 0x9e, 0xc9, 0x4a, 0x0c,
		0x19, 0x75, 0xa0, 0x93, 0xaa, 0x23, 0x70, 0x5a, 0x61, 0x3f, 0x2d, 0x03, 0x7f, 0xb2, 0x0d, 0xa5,
		0x6d, 0x1f, 0x54, 0xd3, 0x75, 0xb8, 0x26, 0xeb, 0x88, 0x4d, 0xd5, 0xb1, 0x9b, 0xa8, 0xa3, 0x36,
		0x4d, 0x87, 0x6f, 0x92, 0x0e, 0xdf, 0x14, 0x1d, 0xbe, 0x09, 0x3a, 0x1b, 0xb2, 0x42, 0x4a, 0x2c,
		0xc0, 0x52, 0x0b, 0xa2, 0xe4, 0x32, 0x4f, 0x7a, 0xf9, 0x8f, 0x7f, 0x23, 0x4a, 0x11, 0x09, 0x1d,
		0x25, 0x57, 0x63, 0xa1, 0x26, 0xa6, 0x19, 0xec, 0xc9, 0x88, 0x12, 0x94, 0x4e, 0x3b, 0xb8, 0xb9,
		0x19, 0x28, 0xa9, 0xef, 0x51, 0xd9, 0xe9, 0x4b, 0x03, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49,
		0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x5f, 0x4b, 0x51, 0x27, 0xbc, 0x42, 0x8a,
		0x28, 0xb9, 0xbe, 0x27, 0x4b, 0xc5, 0x64, 0xa9, 0xe2, 0x4e, 0xbb, 0xf0, 0x4c, 0x75, 0x9e, 0x91,
		0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab,
		0xaf, 0x65, 0xab, 0xcf, 0xb9, 0xc5, 0x90, 0xb1, 0x4e, 0x71, 0x0d, 0xb2, 0x56, 0x4c, 0xd6, 0x2a,
		0xd5, 0xad, 0xdf, 0x93, 0x1d, 0x37, 0x14, 0x7e, 0x04, 0x74, 0xde, 0x55, 0x12, 0xa1, 0x2f, 0xec,
		0x23, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0xdd, 0x32, 0xae, 0x2a,
		0x3b, 0x42, 0x69, 0xa9, 0xef, 0x41, 0xf9, 0x2a, 0xd2, 0xe9, 0xa6, 0xd5, 0xf1, 0xa3, 0xfa, 0xe0,
		0x47, 0x80, 0x29, 0x75, 0x32, 0xa0, 0xd5, 0xb3, 0xbf, 0x2b, 0xa7, 0xd5, 0xe3, 0x66, 0xbd, 0xf6,
		0xf9, 0xf2, 0xa4, 0x59, 0x3f, 0xa9, 0x5c, 0xd4, 0xce, 0xd0, 0xb2, 0xeb, 0xdf, 0x7e, 0x6f, 0x30,
		0xea, 0xfe, 0x78, 0x05, 0x77, 0x82, 0xf8, 0x4f, 0xc8, 0x63, 0xf2, 0x67, 0x46, 0xf7, 0xcf, 0xd3,
		0xcf, 0x17, 0x97, 0x27, 0xf5, 0xe6, 0x69, 0xad, 0x76, 0xee, 0xe0, 0x9d, 0xa1, 0xff, 0x96, 0xe3,
		0xfa, 0xba, 0x71, 0xad, 0x5c, 0x70, 0x48, 0x37, 0x6c, 0x48, 0x6b, 0xf5, 0xea, 0x5f, 0xd5, 0xb3,
		0xca, 0x65, 0xad, 0xce, 0x51, 0xdd, 0xa0, 0x04, 0x5c, 0x3b, 0xfb, 0x78, 0x72, 0x0c, 0x38, 0xa2,
		0x50, 0x16, 0x35, 0x58, 0x8f, 0x80, 0x59, 0x81, 0xa0, 0x0e, 0xf6, 0xfc, 0x48, 0xbb, 0x37, 0x41,
		0x47, 0x76, 0xa5, 0xe8, 0xe0, 0x89, 0x83, 0xd3, 0xe6, 0x51, 0x1b, 0x9c, 0x67, 0x0e, 0xb5, 0xc1,
		0x25, 0x1c, 0x8a, 0xda, 0xe0, 0x52, 0x9e, 0x4e, 0x6d, 0x70, 0x45, 0x03, 0xa9, 0x0d, 0x66, 0x88,
		0xfb, 0x02, 0x6b, 0x83, 0x5a, 0xde, 0x08, 0x2d, 0xdb, 0xdf, 0xa3, 0x52, 0x01, 0x50, 0x1b, 0x3c,
		0x04, 0x32, 0xe9, 0xb3, 0x92, 0xa3, 0x13, 0xe8, 0x1d, 0xe5, 0xab, 0x20, 0x12, 0xed, 0x40, 0x75,
		0x22, 0xa4, 0x47, 0x56, 0xf7, 0xd5, 0xb5, 0x80, 0xd3, 0xdb, 0xf0, 0x4a, 0x3d, 0xe7, 0x93, 0x54,
		0x70, 0x88, 0x08, 0xca, 0x01, 0x67, 0xcc, 0x1b, 0xa9, 0xba, 0xc0, 0xf6, 0x7d, 0x0c, 0xfd, 0xb6,
		0x96, 0x81, 0x3a, 0x96, 0xd7, 0x71, 0xb4, 0xe6, 0xa8, 0xc7, 0xfc, 0x4e, 0x48, 0xf8, 0x77, 0x0c,
		0x89, 0x15, 0x43, 0x22, 0x7f, 0x58, 0x28, 0x94, 0xca, 0x85, 0x42, 0xae, 0x7c, 0x50, 0xce, 0x1d,
		0x15, 0x8b, 0xf9, 0x12, 0xd2, 0xcc, 0x56, 0xe6, 0xa2, 0xe4, 0x0d, 0xad, 0x99, 0xf7, 0x6a, 0x50,
		0xe3, 0x42, 0xc9, 0xa2, 0x30, 0x07, 0x39, 0xcc, 0x90, 0x7a, 0x8c, 0x03, 0x1d, 0x40, 0x13, 0x38,
		0x75, 0xad, 0x65, 0x5c, 0x89, 0xba, 0xd6, 0x52, 0x9e, 0x4e, 0x5d, 0x6b, 0x45, 0x03, 0xa9, 0x6b,
		0x65, 0xa8, 0x86, 0x00, 0xd6, 0xb5, 0x06, 0x52, 0xe9, 0x83, 0x7d, 0x40, 0x49, 0xab, 0x4c, 0xc9,
		0xe8, 0x17, 0x2f, 0x4a, 0x46, 0x1b, 0x59, 0x1f, 0x53, 0x32, 0xca, 0x7a, 0xba, 0x9f, 0x0e, 0x09,
		0x4a, 0x46, 0x2b, 0x87, 0x44, 0x61, 0xff, 0xa8, 0x70, 0x54, 0x2a, 0xef, 0x1f, 0x51, 0x28, 0xda,
		0x00, 0x69, 0x66, 0x87, 0x42, 0x11, 0xe0, 0xf3, 0x80, 0x10, 0x8a, 0xb0, 0x0a, 0x7c, 0xac, 0x23,
		0xa2, 0x40, 0x93, 0x36, 0x65, 0xa2, 0x65, 0x3c, 0x89, 0x32, 0xd1, 0x52, 0x9e, 0x4e, 0x99, 0x68,
		0x45, 0x03, 0x29, 0x13, 0x65, 0xa8, 0x6e, 0x40, 0xde, 0x1a, 0xd9, 0xbf, 0x2d, 0xb8, 0x70, 0x31,
		0x98, 0x6c, 0x8d, 0x3c, 0xc4, 0x6a, 0xe5, 0xa1, 0x45, 0xa8, 0xe0, 0xe4, 0x22, 0xe7, 0xdf, 0xdd,
		0xdd, 0xab, 0x9c, 0x7b, 0xd4, 0x78, 0xb8, 0xca, 0xbb, 0x47, 0x8d, 0xf8, 0x32, 0x3f, 0xfa, 0x12,
		0x5f, 0xef, 0x5f, 0xe5, 0xdc, 0xc2, 0xe4, 0xba, 0x78, 0x95, 0x73, 0x8b, 0x8d, 0xbd, 0x2f, 0x5f,
		0xde, 0xed, 0xfd, 0x3c, 0x78, 0x5c, 0xfe, 0x83, 0xde, 0xf8, 0x66, 0x7b, 0x0f, 0xbb, 0x57, 0x79,
		0x77, 0xbf, 0x31, 0xf9, 0xcf, 0xc1, 0x55, 0xce, 0xdd, 0x6f, 0xec, 0xed, 0xfd, 0x81, 0x93, 0x83,
		0x1a, 0x48, 0xce, 0x53, 0xbb, 0xa8, 0xfe, 0x43, 0x0f, 0xca, 0x9a, 0x07, 0xb1, 0x86, 0x84, 0xa9,
		0x21, 0xc7, 0xcd, 0x6c, 0x82, 0x81, 0x16, 0x78, 0x85, 0xe4, 0x73, 0xe3, 0x58, 0x4d, 0xb2, 0x9a,
		0x64, 0x35, 0xc9, 0x6a, 0x92, 0xd5, 0x24, 0xab, 0xc9, 0x2d, 0xab, 0x26, 0x5b, 0x41, 0xd0, 0x13,
		0xbe, 0x42, 0xac, 0x24, 0xf3, 0xa4, 0x72, 0x00, 0x16, 0xd8, 0x3e, 0x31, 0xb2, 0xa2, 0x54, 0xa0,
		0x7d, 0x2d, 0x41, 0xfa, 0x35, 0x3a, 0x51, 0xfb, 0xab, 0xb8, 0xf1, 0xfb, 0xe3, 0x26, 0xa1, 0x5e,
		0xd0, 0x17, 0xaa, 0x3d, 0x22, 0x4a, 0xae, 0x12, 0xfa, 0x47, 0x10, 0x7e, 0x77, 0xa5, 0x8a, 0xb4,
		0xaf, 0xda, 0xc2, 0x7b, 0xf9, 0x46, 0x34, 0xf3, 0x8e, 0xd7, 0x0f, 0x03, 0x1d, 0xb4, 0x83, 0x5e,
		0x94, 0x5c, 0x79, 0xad, 0xeb, 0xbe, 0x17, 0xca, 0x96, 0xe7, 0x77, 0xa5, 0x1b, 0xf9, 0x5d, 0x19,
		0x25, 0x57, 0xde, 0x48, 0xfa, 0x19, 0x28, 0xd9, 0xf6, 0x23, 0xed, 0x29, 0x21, 0xaf, 0xbf, 0xb6,
		0x82, 0x30, 0x4a, 0xae, 0x3c, 0xbf, 0xf3, 0x6d, 0x84, 0x04, 0x52, 0xb9, 0xfd, 0x50, 0x78, 0x23,
		0x72, 0x1b, 0xc5, 0x5f, 0xe2, 0x96, 0xa4, 0x3c, 0x90, 0xdb, 0xbc, 0xc3, 0x0c, 0xd4, 0x77, 0x15,
		0xfc, 0x50, 0xae, 0xaf, 0x75, 0x28, 0x5b, 0xc3, 0x11, 0xc1, 0x39, 0x9d, 0x7b, 0x8e, 0x6d, 0x3c,
		0xaa, 0x9b, 0x47, 0x75, 0x67, 0xa9, 0xd6, 0xe1, 0x51, 0xdd, 0x59, 0xaf, 0x69, 0x78, 0x54, 0x37,
		0x24, 0xf1, 0x82, 0x39, 0xaa, 0x7b, 0x06, 0xa4, 0xf0, 0xc4, 0xc4, 0x59, 0x13, 0xb1, 0x24, 0xc5,
		0x3c, 0x25, 0x45, 0x78, 0x78, 0xc5, 0x86, 0x59, 0x54, 0xb8, 0x85, 0x87, 0x5d, 0x78, 0xf8, 0x85,
		0x87, 0x61, 0x1c, 0x25, 0x66, 0x07, 0x48, 0x52, 0x44, 0x81, 0xe7, 0xc4, 0xa0, 0xd1, 0xc1, 0xd2,
		0x1a, 0x4d, 0xe8, 0x9c, 0xca, 0xa8, 0x4f, 0x26, 0x82, 0x85, 0x1e, 0xe6, 0xe2, 0x7f, 0x38, 0xb8,
		0x46, 0x86, 0xed, 0x6c, 0xc0, 0x37, 0x3a, 0x8c, 0x67, 0x06, 0xce, 0x33, 0x03, 0xeb, 0x99, 0x81,
		0x77, 0x2c, 0x98, 0x07, 0x83, 0xfb, 0x64, 0x14, 0x2f, 0x11, 0x01, 0x76, 0x07, 0xfb, 0x98, 0xb9,
		0x99, 0x6a, 0xb8, 0x0c, 0x68, 0xdb, 0xb3, 0x63, 0xe7, 0xe2, 0xd3, 0xe3, 0x9e, 0xc8, 0x0a, 0xb7,
		0x8b, 0xa1, 0x87, 0xa6, 0x13, 0xcf, 0xae, 0xc1, 0x12, 0xdf, 0xd8, 0x3c, 0x4c, 0xd2, 0x9b, 0x27,
		0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xb2, 0xce, 0x1f, 0x45, 0x34, 0xad,
		0x2b, 0x31, 0x6c, 0xc4, 0xd1, 0x7a, 0x02, 0xb8, 0xd3, 0xca, 0x94, 0xf4, 0x35, 0xb4, 0xf4, 0x2d,
		0xdb, 0x5f, 0x6c, 0x10, 0x29, 0xc8, 0x02, 0x39, 0xc8, 0x16, 0x49, 0xc8, 0x0a, 0x59, 0xc8, 0x1c,
		0x69, 0xc8, 0x1c, 0x79, 0xc8, 0x1c, 0x89, 0xc0, 0x24, 0x13, 0xa0, 0xa4, 0x22, 0x19, 0x5d, 0x58,
		0x45, 0x6d, 0x26, 0x6f, 0x0e, 0xa4, 0xd2, 0xf9, 0x12, 0x72, 0xce, 0x1c, 0xa3, 0x78, 0x09, 0xd8,
		0x44, 0xcc, 0x06, 0x82, 0x2f, 0x5f, 0xd8, 0x98, 0xb3, 0x83, 0xde, 0x60, 0x30, 0x63, 0xf4, 0x72,
		0xc6, 0x5c, 0xf0, 0x06, 0x84, 0x33, 0xf6, 0x66, 0xa0, 0xe9, 0x5a, 0x46, 0xe0, 0x68, 0x3a, 0xc4,
		0xfc, 0x3b, 0x86, 0x58, 0xca, 0x21, 0x56, 0x2a, 0x16, 0x0f, 0x8a, 0x0c, 0xb3, 0xed, 0xe2, 0xa2,
		0xf8, 0xd6, 0x35, 0xde, 0xf0, 0x79, 0x65, 0x34, 0x8d, 0x03, 0xaf, 0x84, 0x9b, 0x29, 0x29, 0x50,
		0x57, 0xc4, 0x65, 0x04, 0x55, 0xa8, 0x0b, 0xae, 0xd3, 0x19, 0xa9, 0x0b, 0xae, 0x35, 0x72, 0xa8,
		0x0b, 0xa6, 0x6c, 0x30, 0x75, 0xc1, 0x0d, 0x2e, 0xc4, 0x32, 0xa6, 0x0b, 0x1e, 0x66, 0x40, 0x16,
		0x2c, 0x52, 0x16, 0x5c, 0xf1, 0x45, 0x59, 0x90, 0x9a, 0x05, 0x65, 0xc1, 0x2d, 0x44, 0xa3, 0xe9,
		0x10, 0xa3, 0x2c, 0x98, 0x7a, 0x88, 0xed, 0x17, 0x29, 0x0a, 0x6e, 0x19, 0x11, 0xc5, 0xb7, 0x8e,
		0xa2, 0x60, 0x66, 0x93, 0x78, 0xac, 0xb4, 0xdd, 0x8e, 0xb3, 0x4b, 0x16, 0x54, 0xc1, 0xd8, 0x56,
		0xca, 0x82, 0xaf, 0x31, 0x8f, 0xb2, 0xe0, 0x1a, 0xbd, 0x91, 0xb2, 0xe0, 0x5a, 0x23, 0x87, 0xb2,
		0x60, 0xca, 0x06, 0x53, 0x16, 0xdc, 0xe0, 0x42, 0x2c, 0x43, 0xb2, 0x60, 0x4b, 0x2a, 0x3f, 0xbc,
		0xcf, 0x80, 0x2e, 0x78, 0x04, 0x6c, 0xe2, 0xa9, 0x50, 0xd7, 0xa3, 0x8d, 0xb9, 0x14, 0x06, 0x57,
		0x55, 0x2d, 0x28, 0x0c, 0xa6, 0xae, 0x5a, 0xe4, 0xa9, 0x59, 0x6c, 0x19, 0x1e, 0x4d, 0x87, 0x18,
		0x85, 0xc1, 0xd4, 0x43, 0x8c, 0xeb, 0x05, 0xb7, 0x90, 0x8c, 0xe2, 0x5b, 0x47, 0x69, 0x30, 0xb3,
		0x69, 0xdc, 0x11, 0x77, 0x5a, 0xa8, 0x8e, 0xe8, 0xe0, 0x0b, 0x83, 0x89, 0xa5, 0x94, 0x05, 0x5f,
		0x63, 0x1e, 0x65, 0xc1, 0x35, 0xfa, 0x22, 0x65, 0xc1, 0xb5, 0x46, 0x0e, 0x65, 0xc1, 0x94, 0x0d,
		0xa6, 0x2c, 0xb8, 0xc1, 0x65, 0x58, 0x96, 0x64, 0x41, 0xb8, 0x13, 0xbf, 0x16, 0xc1, 0x38, 0xc8,
		0x09, 0x60, 0x24, 0xb5, 0xaf, 0x19, 0xc3, 0xa0, 0x3f, 0xac, 0x3c, 0xfd, 0x1e, 0x3e, 0xa9, 0x4d,
		0x2c, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25,
		0xa9, 0x25, 0xa9, 0x65, 0x50, 0x4c, 0x8f, 0x61, 0xdf, 0x0f, 0xb5, 0xcc, 0x02, 0xa7, 0x9d, 0x18,
		0x4a, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a,
		0x4b, 0x4a, 0xcb, 0xa0, 0x98, 0x1e, 0x43, 0x1d, 0xfa, 0x2a, 0x92, 0x5a, 0xde, 0x66, 0x60, 0x5f,
		0xd2, 0x33, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49,
		0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0x68, 0x88, 0x3a, 0x15, 0xa5, 0x02, 0xed, 0x6b, 0x19,
		0x60, 0x6e, 0x80, 0x72, 0xa2, 0xf6, 0x57, 0x71, 0xe3, 0xf7, 0xc7, 0x07, 0x50, 0x7a, 0x41, 0x5f,
		0xa8, 0xf6, 0x88, 0x28, 0xba, 0x4a, 0xe8, 0x1f, 0x41, 0xf8, 0xdd, 0x95, 0x2a, 0xd2, 0xbe, 0x6a,
		0x0b, 0xef, 0xe5, 0x1b, 0xd1, 0xcc, 0x3b, 0x5e, 0x3f, 0x0c, 0x74, 0xd0, 0x0e, 0x7a, 0x51, 0x72,
		0xe5, 0xb5, 0xae, 0xfb, 0x5e, 0x28, 0x5b, 0x9e, 0xdf, 0x95, 0x6e, 0xe4, 0x77, 0x65, 0x94, 0x5c,
		0x79, 0xb2, 0x7f, 0x5b, 0x70, 0x07, 0x4a, 0xb6, 0xfd, 0x48, 0x7b, 0x4a, 0xc8, 0xeb, 0xaf, 0xad,
		0x20, 0x8c, 0x92, 0x2b, 0xcf, 0xef, 0x7c, 0x1b, 0x21, 0x95, 0x54, 0x6e, 0x3f, 0x14, 0x5e, 0x18,
		0x0c, 0xb4, 0x88, 0xe2, 0x2f, 0xde, 0x40, 0x7d, 0x57, 0xc1, 0x0f, 0xe5, 0xfa, 0x5a, 0x87, 0xb2,
		0x35, 0xfa, 0xc6, 0xcc, 0x5b, 0xf1, 0x61, 0x9a, 0x3c, 0x42, 0x13, 0xd9, 0x12, 0x94, 0x23, 0xf5,
		0xff, 0x27, 0xee, 0x11, 0x7b, 0xe2, 0x3a, 0xa7, 0x32, 0xd2, 0x15, 0xad, 0xc1, 0xce, 0xfb, 0xff,
		0x24, 0xd5, 0x49, 0x4f, 0x0c, 0x09, 0x65, 0x84, 0x55, 0x50, 0x3a, 0x9f, 0xfc, 0xbb, 0x67, 0x96,
		0xe5, 0x0f, 0x0b, 0x85, 0x52, 0xb9, 0x50, 0xc8, 0x95, 0x0f, 0xca, 0xb9, 0xa3, 0x62, 0x31, 0x5f,
		0xca, 0x03, 0xed, 0xdf, 0x72, 0x6a, 0x61, 0x47, 0x84, 0xa2, 0xf3, 0x61, 0xe8, 0x7a, 0x6a, 0xd0,
		0xeb, 0x31, 0x22, 0xf1, 0x91, 0x73, 0xa3, 0x11, 0xd3, 0x81, 0x3a, 0x56, 0x39, 0x1c, 0xb4, 0xb5,
		0x1a, 0x17, 0x0e, 0x67, 0xf1, 0x83, 0xab, 0x8e, 0x9f, 0x5b, 0xf3, 0x7c, 0xfc, 0xb4, 0x9a, 0x1f,
		0xae, 0xfb, 0xcd, 0xba, 0x6c, 0x35, 0x2b, 0x5d, 0x79, 0xe1, 0x77, 0x65, 0xb3, 0xda, 0xbf, 0x2d,
		0x7c, 0x8e, 0x9f, 0x50, 0xf3, 0x6c, 0xfc, 0x5c, 0x9a, 0x95, 0xce, 0xb7, 0xba, 0x6c, 0x55, 0xd5,
		0x79, 0x28, 0x9a, 0xf5, 0xe1, 0xd3, 0x68, 0x7e, 0x8e, 0xff, 0xf4, 0x4a, 0xf2, 0x97, 0xbf, 0x21,
		0x26, 0xdb, 0xb7, 0xc0, 0x72, 0xee, 0x41, 0xcb, 0x39, 0x1b, 0x94, 0x6b, 0xec, 0xc6, 0x97, 0x3d,
		0xaf, 0xb6, 0x73, 0x67, 0x4b, 0x71, 0x34, 0x61, 0xd1, 0xb1, 0x88, 0xbb, 0x33, 0xf4, 0x5b, 0x57,
		0xda, 0xda, 0x30, 0x8a, 0x41, 0x9d, 0x71, 0xa8, 0x32, 0x34, 0x35, 0xc6, 0xa0, 0xc2, 0xb6, 0xc2,
		0x06, 0x04, 0x76, 0xb2, 0x0a, 0x37, 0x16, 0x59, 0x6b, 0xba, 0x2c, 0xd5, 0x0e, 0x68, 0x9a, 0x87,
		0x2c, 0xb3, 0x77, 0x34, 0x1c, 0xe5, 0xb6, 0xa3, 0x3b, 0x7b, 0x51, 0x6d, 0xd6, 0xed, 0xcd, 0x39,
		0x9f, 0x41, 0xc7, 0x73, 0x62, 0xe9, 0xdb, 0xb4, 0xbf, 0x25, 0xf3, 0x7c, 0xf1, 0xed, 0x0d, 0x07,
		0xda, 0x64, 0xe6, 0xce, 0xf0, 0x6d, 0x93, 0x85, 0x35, 0xfb, 0x86, 0x6f, 0x6c, 0x71, 0xc1, 0x0c,
		0xc6, 0x42, 0x18, 0xdb, 0x0b, 0x5c, 0x60, 0x16, 0xae, 0xc0, 0x2c, 0x48, 0x81, 0x59, 0x68, 0x42,
		0x4a, 0x41, 0x4a, 0x31, 0xa2, 0x14, 0x16, 0xe6, 0x80, 0x0d, 0x32, 0x8a, 0x37, 0x1b, 0xe4, 0xdd,
		0xb6, 0xbc, 0x3a, 0x43, 0xde, 0xec, 0x18, 0x65, 0x90, 0xa9, 0x54, 0xb6, 0x66, 0x42, 0x31, 0xfd,
		0xc0, 0x30, 0x10, 0x14, 0xce, 0x64, 0xf0, 0x83, 0x81, 0x76, 0xfb, 0x41, 0xa4, 0x8d, 0x85, 0xc5,
		0xd3, 0x69, 0x20, 0x2f, 0x2d, 0x30, 0x94, 0x0a, 0xcc, 0x52, 0x79, 0xe3, 0x6b, 0xe3, 0x6d, 0x50,
		0x77, 0xbb, 0x94, 0xdd, 0x16, 0x55, 0xb7, 0x4e, 0xd1, 0xad, 0x53, 0x73, 0xeb, 0x94, 0x7c, 0xb3,
		0x48, 0xca, 0xb1, 0x34, 0x3b, 0xa1, 0xe4, 0x8c, 0x35, 0x31, 0x6b, 0x52, 0xce, 0xf8, 0xfe, 0xd4,
		0x72, 0xa8, 0xe5, 0x50, 0xcb, 0xa1, 0x96, 0x43, 0x2d, 0x27, 0xe3, 0x80, 0x32, 0x0d, 0x2c, 0xf6,
		0xe2, 0x6d, 0x0a, 0x5f, 0x6c, 0xc5, 0x9a, 0x1d, 0x98, 0xb1, 0x56, 0x77, 0x20, 0xc1, 0x0e, 0x16,
		0xfc, 0xa0, 0xc0, 0x10, 0x1c, 0x1c, 0xc1, 0xc1, 0x12, 0x1c, 0x3c, 0xd9, 0x81, 0x29, 0x4b, 0x70,
		0x65, 0x1d, 0xb6, 0x12, 0x03, 0x26, 0xab, 0x0b, 0xad, 0x47, 0xea, 0x53, 0xdf, 0x35, 0x9b, 0xcb,
		0x1d, 0x5f, 0x42, 0x9a, 0xe5, 0x4d, 0x39, 0x30, 0xed, 0x26, 0x90, 0xda, 0x4a, 0x60, 0xb6, 0x8f,
		0x40, 0x6b, 0x13, 0x01, 0xdb, 0x0e, 0x02, 0xb6, 0xed, 0x03, 0x6c, 0x7b, 0x87, 0xed, 0xde, 0x4d,
		0x02, 0xd3, 0x96, 0x21, 0xc9, 0x3b, 0x3d, 0xe1, 0x77, 0x43, 0xd1, 0x45, 0x48, 0x3a, 0x93, 0xca,
		0xab, 0x0c, 0x60, 0xcb, 0xf9, 0x78, 0xea, 0xf7, 0xdd, 0xbb, 0x78, 0xb9, 0x80, 0x37, 0x81, 0xf2,
		0x6d, 0xdd, 0xb4, 0x62, 0xb1, 0xfe, 0xea, 0x63, 0xc0, 0xf5, 0x13, 0xab, 0x83, 0x28, 0xbe, 0x48,
		0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x5e, 0x49, 0xea,
		0xe2, 0xb4, 0x43, 0x4e, 0x67, 0x7c, 0x28, 0xec, 0x6c, 0x46, 0x59, 0x18, 0x30, 0x36, 0x36, 0xa7,
		0x2c, 0x0c, 0x15, 0x32, 0x3a, 0x32, 0x3a, 0x32, 0x3a, 0x32, 0x3a, 0x32, 0x3a, 0x5b, 0xa3, 0x62,
		0x7b, 0x26, 0x2b, 0x31, 0x64, 0xd4, 0x7c, 0x4e, 0xaa, 0x8e, 0xc0, 0x69, 0x82, 0xfd, 0xb4, 0x10,
		0xfc, 0xc9, 0x36, 0x94, 0x8e, 0x7d, 0x50, 0xed, 0xd6, 0xe1, 0xda, 0xab, 0x23, 0xb6, 0x53, 0xc7,
		0x6e, 0x9f, 0x8e, 0xda, 0x2e, 0x1d, 0xbe, 0x3d, 0x3a, 0x7c, 0x3b, 0x74, 0xf8, 0xf6, 0xe7, 0xec,
		0xc5, 0x0a, 0x29, 0xb1, 0x00, 0x4b, 0x2d, 0x88, 0x92, 0xcb, 0x3c, 0xe9, 0xe5, 0x3f, 0xfe, 0x8d,
		0x28, 0x45, 0x24, 0x74, 0x94, 0x5c, 0x8d, 0x85, 0x9a, 0x98, 0x66, 0xb0, 0x21, 0x23, 0x4a, 0x50,
		0x3a, 0xed, 0xe0, 0xe6, 0x66, 0xa0, 0xa4, 0xbe, 0x47, 0x65, 0xa7, 0x2f, 0x0d, 0x24, 0x45, 0x25,
		0x45, 0x25, 0x45, 0x25, 0x45, 0x25, 0x45, 0x25, 0x45, 0x25, 0x45, 0x25, 0x45, 0x7d, 0x2d, 0x45,
		0x9d, 0xf0, 0x0a, 0x29, 0xa2, 0xe4, 0xfa, 0x9e, 0x2c, 0x15, 0x93, 0xa5, 0x8a, 0x3b, 0xed, 0xc2,
		0x33, 0xd5, 0x79, 0x46, 0x92, 0xad, 0x92, 0xad, 0x92, 0xad, 0x92, 0xad, 0x92, 0xad, 0x92, 0xad,
		0x92, 0xad, 0x92, 0xad, 0xbe, 0x96, 0xad, 0x3e, 0xe7, 0x16, 0x43, 0xc6, 0x3a, 0xc5, 0x35, 0xc8,
		0x5a, 0x31, 0x59, 0xab, 0x54, 0xb7, 0x7e, 0x4f, 0x76, 0xdc, 0x50, 0xf8, 0x11, 0xd0, 0x51, 0x57,
		0x49, 0x84, 0xbe, 0xb0, 0x8f, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c,
		0x75, 0xcb, 0xb8, 0xaa, 0xec, 0x08, 0xa5, 0xa5, 0xbe, 0x07, 0xe5, 0xab, 0x48, 0x07, 0x9b, 0x56,
		0xc7, 0x8f, 0xea, 0x83, 0x1f, 0x01, 0xa6, 0xd4, 0xc9, 0x80, 0x56, 0xcf, 0xfe, 0xae, 0x9c, 0x56,
		0x8f, 0x9b, 0xf5, 0xda, 0xe7, 0xcb, 0x93, 0x66, 0xfd, 0xa4, 0x72, 0x51, 0x3b, 0x43, 0xcb, 0xae,
		0x7f, 0xfb, 0xbd, 0xc1, 0xa8, 0xfb, 0xe3, 0x15, 0xdc, 0xd9, 0xe1, 0x3f, 0x21, 0x0f, 0xc8, 0x9f,
		0x19, 0xdd, 0x3f, 0x4f, 0x3f, 0x5f, 0x5c, 0x9e, 0xd4, 0x9b, 0xa7, 0xb5, 0xda, 0xb9, 0x83, 0x77,
		0x7a, 0xfe, 0x5b, 0x8e, 0xeb, 0xeb, 0xc6, 0xb5, 0x72, 0xc1, 0x21, 0xdd, 0xb0, 0x21, 0xad, 0xd5,
		0xab, 0x7f, 0x55, 0xcf, 0x2a, 0x97, 0xb5, 0x3a, 0x47, 0x75, 0x83, 0x12, 0x70, 0xed, 0xec, 0xe3,
		0xc9, 0x31, 0xe0, 0x88, 0x42, 0x59, 0xd4, 0x60, 0x3d, 0x02, 0x66, 0x05, 0x82, 0x3a, 0xd8, 0xf3,
		0x23, 0xed, 0xde, 0x04, 0x1d, 0xd9, 0x95, 0xa2, 0x83, 0x27, 0x0e, 0x4e, 0x9b, 0x47, 0x6d, 0x70,
		0x9e, 0x39, 0xd4, 0x06, 0x97, 0x70, 0x28, 0x6a, 0x83, 0x4b, 0x79, 0x3a, 0xb5, 0xc1, 0x15, 0x0d,
		0xa4, 0x36, 0x98, 0x21, 0xee, 0x0b, 0xac, 0x0d, 0x6a, 0x79, 0x23, 0xb4, 0x6c, 0x7f, 0x8f, 0x4a,
		0x05, 0x40, 0x6d, 0xf0, 0x10, 0xc8, 0xa4, 0xcf, 0x4a, 0x8e, 0xce, 0x9f, 0x77, 0x94, 0xaf, 0x82,
		0x48, 0xb4, 0x03, 0xd5, 0x89, 0x90, 0x1e, 0x59, 0xdd, 0x57, 0xd7, 0x02, 0x4e, 0x6f, 0xc3, 0x2b,
		0xf5, 0x9c, 0x4f, 0x52, 0xc1, 0x21, 0x22, 0x28, 0x07, 0x9c, 0x31, 0x6f, 0xa4, 0xea, 0x02, 0xdb,
		0xf7, 0x31, 0xf4, 0xdb, 0x5a, 0x06, 0xea, 0x58, 0x5e, 0xc7, 0xd1, 0x9a, 0xa3, 0x1e, 0xf3, 0x3b,
		0x21, 0xe1, 0xdf, 0x31, 0x24, 0x56, 0x0c, 0x89, 0xfc, 0x61, 0xa1, 0x50, 0x2a, 0x17, 0x0a, 0xb9,
		0xf2, 0x41, 0x39, 0x77, 0x54, 0x2c, 0xe6, 0x4b, 0x48, 0x33, 0x5b, 0x99, 0x8b, 0x92, 0x37, 0xb4,
		0x66, 0xde, 0xab, 0x41, 0x8d, 0x0b, 0x25, 0x8b, 0xc2, 0x1c, 0xe4, 0x30, 0x43, 0xea, 0x31, 0x0e,
		0x74, 0x00, 0x4d, 0xe0, 0xd4, 0xb5, 0x96, 0x71, 0x25, 0xea, 0x5a, 0x4b, 0x79, 0x3a, 0x75, 0xad,
		0x15, 0x0d, 0xa4, 0xae, 0x95, 0xa1, 0x1a, 0x02, 0x58, 0xd7, 0x1a, 0x48, 0xa5, 0x0f, 0xf6, 0x01,
		0x25, 0xad, 0x32, 0x25, 0xa3, 0x5f, 0xbc, 0x28, 0x19, 0x6d, 0x64, 0x7d, 0x4c, 0xc9, 0x28, 0xeb,
		0xe9, 0x7e, 0x3a, 0x24, 0x28, 0x19, 0xad, 0x1c, 0x12, 0x85, 0xfd, 0xa3, 0xc2, 0x51, 0xa9, 0xbc,
		0x7f, 0x44, 0xa1, 0x68, 0x03, 0xa4, 0x99, 0x1d, 0x0a, 0x45, 0x80, 0xcf, 0x03, 0x42, 0x28, 0xc2,
		0x2a, 0xf0, 0xb1, 0x8e, 0x88, 0x02, 0x4d, 0xda, 0x94, 0x89, 0x96, 0xf1, 0x24, 0xca, 0x44, 0x4b,
		0x79, 0x3a, 0x65, 0xa2, 0x15, 0x0d, 0xa4, 0x4c, 0x94, 0xa1, 0xba, 0x01, 0x79, 0x6b, 0x64, 0xff,
		0xb6, 0xe0, 0xc2, 0xc5, 0x60, 0xb2, 0x35, 0xf2, 0x10, 0xab, 0x95, 0x87, 0x16, 0xa1, 0x82, 0x93,
		0x8b, 0x9c, 0x7f, 0x77, 0x77, 0xaf, 0x72, 0xee, 0x51, 0xe3, 0xe1, 0x2a, 0xef, 0x1e, 0x35, 0xe2,
		0xcb, 0xfc, 0xe8, 0x4b, 0x7c, 0xbd, 0x7f, 0x95, 0x73, 0x0b, 0x93, 0xeb, 0xe2, 0x55, 0xce, 0x2d,
		0x36, 0xf6, 0xbe, 0x7c, 0x79, 0xb7, 0xf7, 0xf3, 0xe0, 0x71, 0xf9, 0x0f, 0x7a, 0xe3, 0x9b, 0xed,
		0x3d, 0xec, 0x5e, 0xe5, 0xdd, 0xfd, 0xc6, 0xe4, 0x3f, 0x07, 0x57, 0x39, 0x77, 0xbf, 0xb1, 0xb7,
		0xf7, 0x07, 0x4e, 0x0e, 0x6a, 0x20, 0x39, 0x4f, 0xed, 0xa2, 0xfa, 0x0f, 0x3d, 0x28, 0x6b, 0x1e,
		0xc4, 0x1a, 0x12, 0xa6, 0x86, 0x1c, 0x37, 0xb3, 0x09, 0x06, 0x5a, 0xe0, 0x15, 0x92, 0xcf, 0x8d,
		0x63, 0x35, 0xc9, 0x6a, 0x92, 0xd5, 0x24, 0xab, 0x49, 0x56, 0x93, 0xac, 0x26, 0xb7, 0xac, 0x9a,
		0x6c, 0x05, 0x41, 0x4f, 0xf8, 0x0a, 0xb1, 0x92, 0xcc, 0x93, 0xca, 0x01, 0x58, 0x60, 0xfb, 0xc4,
		0xc8, 0x8a, 0x52, 0x81, 0xf6, 0xb5, 0x04, 0xe9, 0xd7, 0xe8, 0x44, 0xed, 0xaf, 0xe2, 0xc6, 0xef,
		0x8f, 0x9b, 0x84, 0x7a, 0x41, 0x5f, 0xa8, 0xf6, 0x88, 0x28, 0xb9, 0x4a, 0xe8, 0x1f, 0x41, 0xf8,
		0xdd, 0x95, 0x2a, 0xd2, 0xbe, 0x6a, 0x0b, 0xef, 0xe5, 0x1b, 0xd1, 0xcc, 0x3b, 0x5e, 0x3f, 0x0c,
		0x74, 0xd0, 0x0e, 0x7a, 0x51, 0x72, 0xe5, 0xb5, 0xae, 0xfb, 0x5e, 0x28, 0x5b, 0x9e, 0xdf, 0x95,
		0x6e, 0xe4, 0x77, 0x65, 0x94, 0x5c, 0x79, 0x23, 0xe9, 0x67, 0xa0, 0x64, 0xdb, 0x8f, 0xb4, 0xa7,
		0x84, 0xbc, 0xfe, 0xda, 0x0a, 0xc2, 0x28, 0xb9, 0xf2, 0xfc, 0xce, 0xb7, 0x11, 0x12, 0x04, 0x03,
		0xed, 0xf6, 0x83, 0x48, 0x7b, 0x23, 0x7a, 0x1b, 0xc5, 0x5f, 0xe2, 0xa6, 0xa4, 0x3c, 0x92, 0xdb,
		0xbc, 0xcb, 0x0c, 0xd4, 0x77, 0x15, 0xfc, 0x50, 0xae, 0xaf, 0x75, 0x28, 0x5b, 0xc3, 0x11, 0xc1,
		0x39, 0x9f, 0x7b, 0x8e, 0x6d, 0x3c, 0xac, 0x9b, 0x87, 0x75, 0x67, 0xa9, 0xda, 0xe1, 0x61, 0xdd,
		0x59, 0xaf, 0x6a, 0x78, 0x58, 0x37, 0x24, 0xf5, 0x82, 0x39, 0xac, 0x7b, 0x06, 0xa4, 0xf0, 0xe4,
		0xc4, 0x59, 0x13, 0xb1, 0x44, 0xc5, 0x3c, 0x45, 0x45, 0x78, 0x78, 0xc5, 0x86, 0x59, 0x54, 0xb8,
		0x85, 0x87, 0x5d, 0x78, 0xf8, 0x85, 0x87, 0x61, 0x1c, 0x2d, 0x66, 0x07, 0x48, 0x54, 0x44, 0x81,
		0xe7, 0xc4, 0xa0, 0xd1, 0xd1, 0xd2, 0x1a, 0x4d, 0xea, 0x9c, 0xca, 0xa8, 0x4f, 0x26, 0x82, 0x85,
		0x1e, 0xe6, 0xf2, 0x7f, 0x38, 0xb8, 0x46, 0x86, 0xed, 0x6c, 0xc0, 0x37, 0x3a, 0x8c, 0x67, 0x06,
		0xce, 0x33, 0x03, 0xeb, 0x99, 0x81, 0x77, 0x2c, 0x98, 0x07, 0x83, 0xfb, 0x64, 0x14, 0x2f, 0x11,
		0x01, 0x76, 0x07, 0xfb, 0xa0, 0xb9, 0x99, 0x6a, 0xb8, 0x0c, 0x68, 0xdb, 0xb3, 0x83, 0xe7, 0xe2,
		0xf3, 0xe3, 0x9e, 0xc8, 0x0a, 0x37, 0x8c, 0xa1, 0x87, 0xa6, 0x13, 0xcf, 0xae, 0xc1, 0x12, 0xdf,
		0xd8, 0x3c, 0x4c, 0xd2, 0x9b, 0x27, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25,
		0xb2, 0xce, 0x1f, 0x45, 0x34, 0xad, 0x2b, 0x31, 0x6c, 0xc4, 0xd1, 0x7a, 0x02, 0xb8, 0xd7, 0xca,
		0x94, 0xf4, 0x35, 0xb4, 0xf4, 0x2d, 0x1b, 0x60, 0x6c, 0x10, 0x29, 0xc8, 0x02, 0x39, 0xc8, 0x16,
		0x49, 0xc8, 0x0a, 0x59, 0xc8, 0x1c, 0x69, 0xc8, 0x1c, 0x79, 0xc8, 0x1c, 0x89, 0xc0, 0x24, 0x13,
		0xa0, 0xa4, 0x22, 0x19, 0x5d, 0x58, 0x45, 0x6d, 0x26, 0x6f, 0x0e, 0xa4, 0xd2, 0xf9, 0x12, 0x72,
		0xce, 0x1c, 0xa3, 0x78, 0x09, 0xd8, 0x44, 0xcc, 0x16, 0x82, 0x2f, 0x5f, 0xd8, 0x98, 0xb3, 0x83,
		0xde, 0x62, 0x30, 0x63, 0xf4, 0x72, 0xc6, 0x5c, 0xf0, 0x16, 0x84, 0x33, 0xf6, 0x66, 0xa0, 0xed,
		0x5a, 0x46, 0xe0, 0x68, 0x3a, 0xc4, 0xfc, 0x3b, 0x86, 0x58, 0xca, 0x21, 0x56, 0x2a, 0x16, 0x0f,
		0x8a, 0x0c, 0xb3, 0xed, 0xe2, 0xa2, 0xf8, 0xd6, 0x35, 0xde, 0xf0, 0x79, 0x65, 0x34, 0x8d, 0x03,
		0xaf, 0x84, 0x9b, 0x29, 0x29, 0x50, 0x57, 0xc4, 0x65, 0x04, 0x55, 0xa8, 0x0b, 0xae, 0xd3, 0x19,
		0xa9, 0x0b, 0xae, 0x35, 0x72, 0xa8, 0x0b, 0xa6, 0x6c, 0x30, 0x75, 0xc1, 0x0d, 0x2e, 0xc4, 0x32,
		0xa6, 0x0b, 0x1e, 0x66, 0x40, 0x16, 0x2c, 0x52, 0x16, 0x5c, 0xf1, 0x45, 0x59, 0x90, 0x9a, 0x05,
		0x65, 0xc1, 0x2d, 0x44, 0xa3, 0xe9, 0x10, 0xa3, 0x2c, 0x98, 0x7a, 0x88, 0xed, 0x17, 0x29, 0x0a,
		0x6e, 0x19, 0x11, 0xc5, 0xb7, 0x8e, 0xa2, 0x60, 0x66, 0x93, 0x78, 0xac, 0xb4, 0xdd, 0x8e, 0xb3,
		0x4b, 0x16, 0x54, 0xc1, 0xd8, 0x56, 0xca, 0x82, 0xaf, 0x31, 0x8f, 0xb2, 0xe0, 0x1a, 0xbd, 0x91,
		0xb2, 0xe0, 0x5a, 0x23, 0x87, 0xb2, 0x60, 0xca, 0x06, 0x53, 0x16, 0xdc, 0xe0, 0x42, 0x2c, 0x43,
		0xb2, 0x60, 0x4b, 0x2a, 0x3f, 0xbc, 0xcf, 0x80, 0x2e, 0x78, 0x04, 0x6c, 0xe2, 0xa9, 0x50, 0xd7,
		0xa3, 0x8d, 0xb9, 0x14, 0x06, 0x57, 0x55, 0x2d, 0x28, 0x0c, 0xa6, 0xae, 0x5a, 0xe4, 0xa9, 0x59,
		0x6c, 0x19, 0x1e, 0x4d, 0x87, 0x18, 0x85, 0xc1, 0xd4, 0x43, 0x8c, 0xeb, 0x05, 0xb7, 0x90, 0x8c,
		0xe2, 0x5b, 0x47, 0x69, 0x30, 0xb3, 0x69, 0xdc, 0x11, 0x77, 0x5a, 0xa8, 0x8e, 0xe8, 0xe0, 0x0b,
		0x83, 0x89, 0xa5, 0x94, 0x05, 0x5f, 0x63, 0x1e, 0x65, 0xc1, 0x35, 0xfa, 0x22, 0x65, 0xc1, 0xb5,
		0x46, 0x0e, 0x65, 0xc1, 0x94, 0x0d, 0xa6, 0x2c, 0xb8, 0xc1, 0x65, 0x58, 0x96, 0x64, 0x41, 0xb8,
		0x33, 0xbf, 0x16, 0xc1, 0x38, 0xc8, 0x19, 0x60, 0x24, 0xb5, 0xaf, 0x19, 0xc3, 0xa0, 0x3f, 0xac,
		0x3c, 0xfd, 0x1e, 0x3e, 0xa9, 0x4d, 0x2c, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25,
		0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x65, 0x50, 0x4c, 0x8f, 0x61, 0xdf, 0x0f,
		0xb5, 0xcc, 0x02, 0xa7, 0x9d, 0x18, 0x4a, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a,
		0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0xcb, 0xa0, 0x98, 0x1e, 0x43, 0x1d, 0xfa, 0x2a,
		0x92, 0x5a, 0xde, 0x66, 0x60, 0x5f, 0xd2, 0x33, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49,
		0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0x68, 0x88, 0x3a,
		0x15, 0xa5, 0x02, 0xed, 0x6b, 0x19, 0x60, 0x6e, 0x80, 0x72, 0xa2, 0xf6, 0x57, 0x71, 0xe3, 0xf7,
		0xc7, 0x07, 0x50, 0x7a, 0x41, 0x5f, 0xa8, 0xf6, 0x88, 0x28, 0xba, 0x4a, 0xe8, 0x1f, 0x41, 0xf8,
		0xdd, 0x95, 0x2a, 0xd2, 0xbe, 0x6a, 0x0b, 0xef, 0xe5, 0x1b, 0xd1, 0xcc, 0x3b, 0x5e, 0x3f, 0x0c,
		0x74, 0xd0, 0x0e, 0x7a, 0x51, 0x72, 0xe5, 0xb5, 0xae, 0xfb, 0x5e, 0x28, 0x5b, 0x9e, 0xdf, 0x95,
		0x6e, 0xe4, 0x77, 0x65, 0x94, 0x5c, 0x79, 0xb2, 0x7f, 0x5b, 0x70, 0x07, 0x4a, 0xb6, 0xfd, 0x48,
		0x7b, 0x4a, 0xc8, 0xeb, 0xaf, 0xad, 0x20, 0x8c, 0x92, 0x2b, 0xcf, 0xef, 0x7c, 0x1b, 0x21, 0x55,
		0x30, 0xd0, 0x6e, 0x3f, 0x88, 0xb4, 0x17, 0x06, 0x03, 0x2d, 0xa2, 0xf8, 0x8b, 0x37, 0x50, 0xdf,
		0x55, 0xf0, 0x43, 0xb9, 0xbe, 0xd6, 0xa1, 0x6c, 0x8d, 0xbe, 0x31, 0xf3, 0x56, 0x7c, 0x9c, 0x26,
		0x0f, 0xd1, 0x44, 0xb6, 0x04, 0xe5, 0x50, 0xfd, 0xff, 0x89, 0x7b, 0xc4, 0xae, 0xb8, 0xce, 0xa9,
		0x8c, 0x74, 0x45, 0x6b, 0xb0, 0x13, 0xff, 0x3f, 0x49, 0x75, 0xd2, 0x13, 0x43, 0x4a, 0x19, 0x61,
		0x95, 0x94, 0xce, 0x27, 0xff, 0xee, 0x99, 0x65, 0xf9, 0xc3, 0x42, 0xa1, 0x54, 0x2e, 0x14, 0x72,
		0xe5, 0x83, 0x72, 0xee, 0xa8, 0x58, 0xcc, 0x97, 0xf2, 0x40, 0x3b, 0xb8, 0x9c, 0x5a, 0xd8, 0x11,
		0xa1, 0xe8, 0x7c, 0x18, 0xba, 0x9e, 0x1a, 0xf4, 0x7a, 0x8c, 0x48, 0x7c, 0xec, 0xdc, 0x70, 0xcc,
		0x74, 0xa0, 0x8e, 0x56, 0x0e, 0x07, 0x6d, 0xad, 0xc6, 0xc5, 0xc3, 0x59, 0xfc, 0xe8, 0xaa, 0xe3,
		0x27, 0xd7, 0x3c, 0x1f, 0x3f, 0xaf, 0xe6, 0x87, 0xeb, 0x7e, 0xb3, 0x2e, 0x5b, 0xcd, 0x4a, 0x57,
		0x5e, 0xf8, 0x5d, 0xd9, 0xac, 0xf6, 0x6f, 0x0b, 0x9f, 0xe3, 0x67, 0xd4, 0x3c, 0x1b, 0x3f, 0x99,
		0x66, 0xa5, 0xf3, 0xad, 0x2e, 0x5b, 0xb5, 0x81, 0x3e, 0x0f, 0x22, 0xdd, 0xac, 0x0f, 0x9f, 0x47,
		0xf3, 0x73, 0xfc, 0xc7, 0x57, 0x92, 0xbf, 0xfd, 0x0d, 0x71, 0xd9, 0xbe, 0x05, 0x96, 0xf3, 0x0f,
		0x5a, 0xde, 0xd9, 0xa8, 0x7c, 0x63, 0x37, 0xc2, 0xec, 0xf9, 0xb5, 0x9d, 0x3b, 0x5b, 0x8a, 0xa4,
		0x09, 0x97, 0x8e, 0xc5, 0xdc, 0x9d, 0xa1, 0xe7, 0xba, 0xd2, 0xd6, 0xc6, 0x51, 0x0c, 0x02, 0x8d,
		0x43, 0x98, 0xa1, 0x09, 0x32, 0x06, 0x21, 0xb6, 0x15, 0x36, 0x20, 0xc0, 0x93, 0x5d, 0xc0, 0xb1,
		0xc8, 0x5d, 0xd3, 0xe6, 0xaa, 0x76, 0x80, 0xd3, 0x3c, 0x6c, 0x99, 0xbd, 0xa3, 0xe1, 0x48, 0xb7,
		0x1d, 0xe1, 0x59, 0x8c, 0x6c, 0xb3, 0x8e, 0x6f, 0xce, 0xfd, 0x0c, 0xba, 0x9e, 0x13, 0xcb, 0xe0,
		0xa6, 0x3d, 0x2e, 0x99, 0xf5, 0x8b, 0x6f, 0x6f, 0x38, 0xd4, 0x26, 0xf3, 0x78, 0x86, 0x6f, 0x9b,
		0x2c, 0xb3, 0xd9, 0x37, 0x7c, 0x63, 0x8b, 0xcb, 0x67, 0x30, 0x96, 0xc5, 0xd8, 0x5e, 0xee, 0x02,
		0xb3, 0x8c, 0x05, 0x66, 0x79, 0x0a, 0xcc, 0xb2, 0x13, 0x92, 0x0a, 0x92, 0x8a, 0x31, 0xa9, 0xb0,
		0x30, 0x23, 0x6c, 0x90, 0x53, 0xbc, 0xd9, 0x20, 0xff, 0xb6, 0xe5, 0xd7, 0x99, 0xf2, 0x67, 0xc7,
		0x28, 0x8b, 0x4c, 0xa9, 0xc2, 0x35, 0x13, 0x8e, 0xe9, 0x07, 0x87, 0x81, 0xc0, 0x70, 0xa6, 0x1c,
		0x20, 0x34, 0xc7, 0x76, 0x9e, 0x0e, 0x08, 0x79, 0x61, 0x80, 0xa1, 0x64, 0x60, 0x96, 0xce, 0x1b,
		0x5f, 0x2d, 0x6f, 0x83, 0xbe, 0xdb, 0xa5, 0xed, 0xb6, 0xe8, 0xba, 0x75, 0x9a, 0x6e, 0x9d, 0x9e,
		0x5b, 0xa7, 0xe5, 0x9b, 0x45, 0x53, 0x8e, 0xa5, 0xd9, 0xa9, 0x25, 0x67, 0xac, 0x8b, 0x59, 0x93,
		0x73, 0xc6, 0xf7, 0xa7, 0x9e, 0x43, 0x3d, 0x87, 0x7a, 0x0e, 0xf5, 0x1c, 0xea, 0x39, 0x19, 0x07,
		0x94, 0x69, 0x60, 0xb1, 0x17, 0x6f, 0x53, 0xf8, 0x62, 0x2b, 0xd6, 0xec, 0xc0, 0x8c, 0xb5, 0xba,
		0x03, 0x09, 0x76, 0xb0, 0xe0, 0x07, 0x05, 0x86, 0xe0, 0xe0, 0x08, 0x0e, 0x96, 0xe0, 0xe0, 0xc9,
		0x0e, 0x4c, 0x59, 0x82, 0x2b, 0xeb, 0xb0, 0x95, 0x18, 0x30, 0x59, 0x67, 0x68, 0x3d, 0x52, 0x9f,
		0x3a, 0xb1, 0xd9, 0x5c, 0xf8, 0xf8, 0x12, 0xd2, 0x2c, 0x6f, 0xd2, 0x81, 0x69, 0x40, 0x81, 0xd4,
		0x68, 0x02, 0xb3, 0xa1, 0x04, 0x5a, 0xe3, 0x08, 0xd8, 0x06, 0x11, 0xb0, 0x8d, 0x20, 0x60, 0x1b,
		0x3e, 0x6c, 0xf7, 0xce, 0x12, 0x98, 0x46, 0x0d, 0x49, 0xde, 0xe9, 0x09, 0xbf, 0x1b, 0x8a, 0x2e,
		0x42, 0xd2, 0x99, 0x54, 0x5e, 0x65, 0x00, 0x5b, 0xce, 0xc7, 0x93, 0xbf, 0xef, 0xde, 0xc5, 0x0b,
		0x06, 0xbc, 0x09, 0x94, 0x6f, 0xeb, 0xf6, 0x15, 0x8b, 0xf5, 0x57, 0x1f, 0x03, 0xae, 0x9f, 0x58,
		0x1d, 0x44, 0xf1, 0x45, 0x52, 0x47, 0x52, 0x47, 0x52, 0x47, 0x52, 0x47, 0x52, 0x47, 0x52, 0x47,
		0x52, 0xf7, 0x4a, 0x52, 0x17, 0xa7, 0x1d, 0x72, 0x3a, 0xe3, 0x43, 0x61, 0x67, 0x43, 0xca, 0xc2,
		0x80, 0xb1, 0xb1, 0x41, 0x65, 0x61, 0xa8, 0x90, 0xd1, 0x91, 0xd1, 0x91, 0xd1, 0x91, 0xd1, 0x91,
		0xd1, 0xd9, 0x1a, 0x15, 0xdb, 0x33, 0x59, 0x89, 0x21, 0xa3, 0x66, 0x74, 0x52, 0x75, 0x04, 0x4e,
		0x5b, 0xec, 0xa7, 0x75, 0xe0, 0x4f, 0xb6, 0xa1, 0x74, 0xf0, 0x83, 0x6a, 0xc0, 0x0e, 0xd7, 0x70,
		0x1d, 0xb1, 0xc1, 0x3a, 0x76, 0x43, 0x75, 0xd4, 0x06, 0xea, 0xf0, 0x0d, 0xd3, 0xe1, 0x1b, 0xa4,
		0xc3, 0x37, 0x44, 0x67, 0x6f, 0x56, 0x48, 0x89, 0x05, 0x58, 0x6a, 0x41, 0x94, 0x5c, 0xe6, 0x49,
		0x2f, 0xff, 0xf1, 0x6f, 0x44, 0x29, 0x22, 0xa1, 0xa3, 0xe4, 0x6a, 0x2c, 0xd4, 0xc4, 0x34, 0x83,
		0xcd, 0x19, 0x51, 0x82, 0xd2, 0x69, 0x07, 0x37, 0x37, 0x03, 0x25, 0xf5, 0x3d, 0x2a, 0x3b, 0x7d,
		0x69, 0x20, 0x29, 0x2a, 0x29, 0x2a, 0x29, 0x2a, 0x29, 0x2a, 0x29, 0x2a, 0x29, 0x2a, 0x29, 0x2a,
		0x29, 0xea, 0x6b, 0x29, 0xea, 0x84, 0x57, 0x48, 0x11, 0x25, 0xd7, 0xf7, 0x64, 0xa9, 0x98, 0x2c,
		0x55, 0xdc, 0x69, 0x17, 0x9e, 0xa9, 0xce, 0x33, 0x92, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c,
		0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0xf5, 0xb5, 0x6c, 0xf5, 0x39, 0xb7, 0x18, 0x32,
		0xd6, 0x29, 0xae, 0x41, 0xd6, 0x8a, 0xc9, 0x5a, 0xa5, 0xba, 0xf5, 0x7b, 0xb2, 0xe3, 0x86, 0xc2,
		0x8f, 0x80, 0x8e, 0xbe, 0x4a, 0x22, 0xf4, 0x85, 0x7d, 0xe4, 0xaa, 0xe4, 0xaa, 0xe4, 0xaa, 0xe4,
		0xaa, 0xe4, 0xaa, 0xe4, 0xaa, 0x5b, 0xc6, 0x55, 0x65, 0x47, 0x28, 0x2d, 0xf5, 0x3d, 0x28, 0x5f,
		0x45, 0x3a, 0xe8, 0xb4, 0x3a, 0x7e, 0x54, 0x1f, 0xfc, 0x08, 0x30, 0xa5, 0x4e, 0x06, 0xb4, 0x7a,
		0xf6, 0x77, 0xe5, 0xb4, 0x7a, 0xdc, 0xac, 0xd7, 0x3e, 0x5f, 0x9e, 0x34, 0xeb, 0x27, 0x95, 0x8b,
		0xda, 0x19, 0x5a, 0x76, 0xfd, 0xdb, 0xef, 0x0d, 0x46, 0xdd, 0x1f, 0xaf, 0xe0, 0x4e, 0x13, 0xff,
		0x09, 0x79, 0x64, 0xfe, 0xcc, 0xe8, 0xfe, 0x79, 0xfa, 0xf9, 0xe2, 0xf2, 0xa4, 0xde, 0x3c, 0xad,
		0xd5, 0xce, 0x1d, 0xbc, 0xf3, 0xf4, 0xdf, 0x72, 0x5c, 0x5f, 0x37, 0xae, 0x95, 0x0b, 0x0e, 0xe9,
		0x86, 0x0d, 0x69, 0xad, 0x5e, 0xfd, 0xab, 0x7a, 0x56, 0xb9, 0xac, 0xd5, 0x39, 0xaa, 0x1b, 0x94,
		0x80, 0x6b, 0x67, 0x1f, 0x4f, 0x8e, 0x01, 0x47, 0x14, 0xca, 0xa2, 0x06, 0xeb, 0x11, 0x30, 0x2b,
		0x10, 0xd4, 0xc1, 0x9e, 0x1f, 0x69, 0xf7, 0x26, 0xe8, 0xc8, 0xae, 0x14, 0x1d, 0x3c, 0x71, 0x70,
		0xda, 0x3c, 0x6a, 0x83, 0xf3, 0xcc, 0xa1, 0x36, 0xb8, 0x84, 0x43, 0x51, 0x1b, 0x5c, 0xca, 0xd3,
		0xa9, 0x0d, 0xae, 0x68, 0x20, 0xb5, 0xc1, 0x0c, 0x71, 0x5f, 0x60, 0x6d, 0x50, 0xcb, 0x1b, 0xa1,
		0x65, 0xfb, 0x7b, 0x54, 0x2a, 0x00, 0x6a, 0x83, 0x87, 0x40, 0x26, 0x7d, 0x56, 0x72, 0x74, 0x12,
		0xbd, 0xa3, 0x7c, 0x15, 0x44, 0xa2, 0x1d, 0xa8, 0x4e, 0x84, 0xf4, 0xc8, 0xea, 0xbe, 0xba, 0x16,
		0x70, 0x7a, 0x1b, 0x5e, 0xa9, 0xe7, 0x7c, 0x92, 0x0a, 0x0e, 0x11, 0x41, 0x39, 0xe0, 0x8c, 0x79,
		0x23, 0x55, 0x17, 0xd8, 0xbe, 0x8f, 0xa1, 0xdf, 0xd6, 0x32, 0x50, 0xc7, 0xf2, 0x3a, 0x8e, 0xd6,
		0x1c, 0xf5, 0x98, 0xdf, 0x09, 0x09, 0xff, 0x8e, 0x21, 0xb1, 0x62, 0x48, 0xe4, 0x0f, 0x0b, 0x85,
		0x52, 0xb9, 0x50, 0xc8, 0x95, 0x0f, 0xca, 0xb9, 0xa3, 0x62, 0x31, 0x5f, 0x42, 0x9a, 0xd9, 0xca,
		0x5c, 0x94, 0xbc, 0xa1, 0x35, 0xf3, 0x5e, 0x0d, 0x6a, 0x5c, 0x28, 0x59, 0x14, 0xe6, 0x20, 0x87,
		0x19, 0x52, 0x8f, 0x71, 0xa0, 0x03, 0x68, 0x02, 0xa7, 0xae, 0xb5, 0x8c, 0x2b, 0x51, 0xd7, 0x5a,
		0xca, 0xd3, 0xa9, 0x6b, 0xad, 0x68, 0x20, 0x75, 0xad, 0x0c, 0xd5, 0x10, 0xc0, 0xba, 0xd6, 0x40,
		0x2a, 0x7d, 0xb0, 0x0f, 0x28, 0x69, 0x95, 0x29, 0x19, 0xfd, 0xe2, 0x45, 0xc9, 0x68, 0x23, 0xeb,
		0x63, 0x4a, 0x46, 0x59, 0x4f, 0xf7, 0xd3, 0x21, 0x41, 0xc9, 0x68, 0xe5, 0x90, 0x28, 0xec, 0x1f,
		0x15, 0x8e, 0x4a, 0xe5, 0xfd, 0x23, 0x0a, 0x45, 0x1b, 0x20, 0xcd, 0xec, 0x50, 0x28, 0x02, 0x7c,
		0x1e, 0x10, 0x42, 0x11, 0x56, 0x81, 0x8f, 0x75, 0x44, 0x14, 0x68, 0xd2, 0xa6, 0x4c, 0xb4, 0x8c,
		0x27, 0x51, 0x26, 0x5a, 0xca, 0xd3, 0x29, 0x13, 0xad, 0x68, 0x20, 0x65, 0xa2, 0x0c, 0xd5, 0x0d,
		0xc8, 0x5b, 0x23, 0xfb, 0xb7, 0x05, 0x17, 0x2e, 0x06, 0x93, 0xad, 0x91, 0x87, 0x58, 0xad, 0x3c,
		0xb4, 0x08, 0x15, 0x9c, 0x5c, 0xe4, 0xfc, 0xbb, 0xbb, 0x7b, 0x95, 0x73, 0x8f, 0x1a, 0x0f, 0x57,
		0x79, 0xf7, 0xa8, 0x11, 0x5f, 0xe6, 0x47, 0x5f, 0xe2, 0xeb, 0xfd, 0xab, 0x9c, 0x5b, 0x98, 0x5c,
		0x17, 0xaf, 0x72, 0x6e, 0xb1, 0xb1, 0xf7, 0xe5, 0xcb, 0xbb, 0xbd, 0x9f, 0x07, 0x8f, 0xcb, 0x7f,
		0xd0, 0x1b, 0xdf, 0x6c, 0xef, 0x61, 0xf7, 0x2a, 0xef, 0xee, 0x37, 0x26, 0xff, 0x39, 0xb8, 0xca,
		0xb9, 0xfb, 0x8d, 0xbd, 0xbd, 0x3f, 0x70, 0x72, 0x50, 0x03, 0xc9, 0x79, 0x6a, 0x17, 0xd5, 0x7f,
		0xe8, 0x41, 0x59, 0xf3, 0x20, 0xd6, 0x90, 0x30, 0x35, 0xe4, 0xb8, 0x99, 0x4d, 0x30, 0xd0, 0x02,
		0xaf, 0x90, 0x7c, 0x6e, 0x1c, 0xab, 0x49, 0x56, 0x93, 0xac, 0x26, 0x59, 0x4d, 0xb2, 0x9a, 0x64,
		0x35, 0xb9, 0x65, 0xd5, 0x64, 0x2b, 0x08, 0x7a, 0xc2, 0x57, 0x88, 0x95, 0x64, 0x9e, 0x54, 0x0e,
		0xc0, 0x02, 0xdb, 0x27, 0x46, 0x56, 0x94, 0x0a, 0xb4, 0xaf, 0x25, 0x48, 0xbf, 0x46, 0x27, 0x6a,
		0x7f, 0x15, 0x37, 0x7e, 0x7f, 0xdc, 0x24, 0xd4, 0x0b, 0xfa, 0x42, 0xb5, 0x47, 0x44, 0xc9, 0x55,
		0x42, 0xff, 0x08, 0xc2, 0xef, 0xae, 0x54, 0x91, 0xf6, 0x55, 0x5b, 0x78, 0x2f, 0xdf, 0x88, 0x66,
		0xde, 0xf1, 0xfa, 0x61, 0xa0, 0x83, 0x76, 0xd0, 0x8b, 0x92, 0x2b, 0xaf, 0x75, 0xdd, 0xf7, 0x42,
		0xd9, 0xf2, 0xfc, 0xae, 0x74, 0x23, 0xbf, 0x2b, 0xa3, 0xe4, 0xca, 0x1b, 0x49, 0x3f, 0x03, 0x25,
		0xdb, 0x7e, 0xa4, 0x3d, 0x25, 0xe4, 0xf5, 0xd7, 0x56, 0x10, 0x46, 0xc9, 0x95, 0xe7, 0x77, 0xbe,
		0x8d, 0x90, 0x20, 0x18, 0x68, 0xb7, 0x1f, 0x0a, 0x6f, 0xc4, 0x6e, 0xa3, 0xf8, 0x4b, 0xdc, 0x93,
		0x94, 0x27, 0x72, 0x9b, 0xf7, 0x98, 0x81, 0xfa, 0xae, 0x82, 0x1f, 0xca, 0xf5, 0xb5, 0x0e, 0x65,
		0x6b, 0x38, 0x22, 0x38, 0xc7, 0x73, 0xcf, 0xb1, 0x8d, 0x67, 0x75, 0xf3, 0xac, 0xee, 0x2c, 0x15,
		0x3b, 0x3c, 0xab, 0x3b, 0xeb, 0x45, 0x0d, 0xcf, 0xea, 0x86, 0x64, 0x5e, 0x30, 0x67, 0x75, 0xcf,
		0x80, 0x14, 0x9e, 0x9a, 0x38, 0x6b, 0x22, 0x96, 0xa6, 0x98, 0xa7, 0xa6, 0x08, 0x0f, 0xaf, 0xd8,
		0x30, 0x8b, 0x0a, 0xb7, 0xf0, 0xb0, 0x0b, 0x0f, 0xbf, 0xf0, 0x30, 0x8c, 0x23, 0xc5, 0xec, 0x00,
		0x69, 0x8a, 0x28, 0xf0, 0x9c, 0x18, 0x34, 0x3a, 0x59, 0x5a, 0xa3, 0x29, 0x9d, 0x53, 0x19, 0xf5,
		0xc9, 0x44, 0xb0, 0xd0, 0xc3, 0x5c, 0xfd, 0x0f, 0x07, 0xd7, 0xc8, 0xb0, 0x9d, 0x0d, 0xf8, 0x46,
		0x87, 0xf1, 0xcc, 0xc0, 0x79, 0x66, 0x60, 0x3d, 0x33, 0xf0, 0x8e, 0x05, 0xf3, 0x60, 0x70, 0x9f,
		0x8c, 0xe2, 0x25, 0x22, 0xc0, 0xee, 0x60, 0x9f, 0x33, 0x37, 0x53, 0x0d, 0x97, 0x01, 0x6d, 0x7b,
		0x76, 0xee, 0x5c, 0x7c, 0x7c, 0xdc, 0x13, 0x59, 0xe1, 0x7e, 0x31, 0xf4, 0xd0, 0x74, 0xe2, 0xd9,
		0x35, 0x58, 0xe2, 0x1b, 0x9b, 0x87, 0x49, 0x7a, 0xf3, 0x24, 0xbd, 0x24, 0xbd, 0x24, 0xbd, 0x24,
		0xbd, 0x24, 0xbd, 0x44, 0xd6, 0xf9, 0xa3, 0x88, 0xa6, 0x75, 0x25, 0x86, 0x8d, 0x38, 0x5a, 0x4f,
		0x00, 0xb7, 0x5a, 0x99, 0x92, 0xbe, 0x86, 0x96, 0xbe, 0x65, 0xff, 0x8b, 0x0d, 0x22, 0x05, 0x59,
		0x20, 0x07, 0xd9, 0x22, 0x09, 0x59, 0x21, 0x0b, 0x99, 0x23, 0x0d, 0x99, 0x23, 0x0f, 0x99, 0x23,
		0x11, 0x98, 0x64, 0x02, 0x94, 0x54, 0x24, 0xa3, 0x0b, 0xab, 0xa8, 0xcd, 0xe4, 0xcd, 0x81, 0x54,
		0x3a, 0x5f, 0x42, 0xce, 0x99, 0x63, 0x14, 0x2f, 0x01, 0x9b, 0x88, 0xd9, 0x41, 0xf0, 0xe5, 0x0b,
		0x1b, 0x73, 0x76, 0xd0, 0x3b, 0x0c, 0x66, 0x8c, 0x5e, 0xce, 0x98, 0x0b, 0xde, 0x81, 0x70, 0xc6,
		0xde, 0x0c, 0x74, 0x5d, 0xcb, 0x08, 0x1c, 0x4d, 0x87, 0x98, 0x7f, 0xc7, 0x10, 0x4b, 0x39, 0xc4,
		0x4a, 0xc5, 0xe2, 0x41, 0x91, 0x61, 0xb6, 0x5d, 0x5c, 0x14, 0xdf, 0xba, 0xc6, 0x1b, 0x3e, 0xaf,
		0x8c, 0xa6, 0x71, 0xe0, 0x95, 0x70, 0x33, 0x25, 0x05, 0xea, 0x8a, 0xb8, 0x8c, 0xa0, 0x0a, 0x75,
		0xc1, 0x75, 0x3a, 0x23, 0x75, 0xc1, 0xb5, 0x46, 0x0e, 0x75, 0xc1, 0x94, 0x0d, 0xa6, 0x2e, 0xb8,
		0xc1, 0x85, 0x58, 0xc6, 0x74, 0xc1, 0xc3, 0x0c, 0xc8, 0x82, 0x45, 0xca, 0x82, 0x2b, 0xbe, 0x28,
		0x0b, 0x52, 0xb3, 0xa0, 0x2c, 0xb8, 0x85, 0x68, 0x34, 0x1d, 0x62, 0x94, 0x05, 0x53, 0x0f, 0xb1,
		0xfd, 0x22, 0x45, 0xc1, 0x2d, 0x23, 0xa2, 0xf8, 0xd6, 0x51, 0x14, 0xcc, 0x6c, 0x12, 0x8f, 0x95,
		0xb6, 0xdb, 0x71, 0x76, 0xc9, 0x82, 0x2a, 0x18, 0xdb, 0x4a, 0x59, 0xf0, 0x35, 0xe6, 0x51, 0x16,
		0x5c, 0xa3, 0x37, 0x52, 0x16, 0x5c, 0x6b, 0xe4, 0x50, 0x16, 0x4c, 0xd9, 0x60, 0xca, 0x82, 0x1b,
		0x5c, 0x88, 0x65, 0x48, 0x16, 0x6c, 0x49, 0xe5, 0x87, 0xf7, 0x19, 0xd0, 0x05, 0x8f, 0x80, 0x4d,
		0x3c, 0x15, 0xea, 0x7a, 0xb4, 0x31, 0x97, 0xc2, 0xe0, 0xaa, 0xaa, 0x05, 0x85, 0xc1, 0xd4, 0x55,
		0x8b, 0x3c, 0x35, 0x8b, 0x2d, 0xc3, 0xa3, 0xe9, 0x10, 0xa3, 0x30, 0x98, 0x7a, 0x88, 0x71, 0xbd,
		0xe0, 0x16, 0x92, 0x51, 0x7c, 0xeb, 0x28, 0x0d, 0x66, 0x36, 0x8d, 0x3b, 0xe2, 0x4e, 0x0b, 0xd5,
		0x11, 0x1d, 0x7c, 0x61, 0x30, 0xb1, 0x94, 0xb2, 0xe0, 0x6b, 0xcc, 0xa3, 0x2c, 0xb8, 0x46, 0x5f,
		0xa4, 0x2c, 0xb8, 0xd6, 0xc8, 0xa1, 0x2c, 0x98, 0xb2, 0xc1, 0x94, 0x05, 0x37, 0xb8, 0x0c, 0xcb,
		0x92, 0x2c, 0x08, 0x77, 0xe4, 0xd7, 0x22, 0x18, 0x07, 0x39, 0x02, 0x8c, 0xa4, 0xf6, 0x35, 0x63,
		0x18, 0xf4, 0x87, 0x95, 0xa7, 0xdf, 0xc3, 0x27, 0xb5, 0x89, 0xa5, 0x24, 0xb5, 0x24, 0xb5, 0x24,
		0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x0c, 0x8a, 0xe9,
		0x31, 0xec, 0xfb, 0xa1, 0x96, 0x59, 0xe0, 0xb4, 0x13, 0x43, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69,
		0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x19, 0x14, 0xd3, 0x63,
		0xa8, 0x43, 0x5f, 0x45, 0x52, 0xcb, 0xdb, 0x0c, 0xec, 0x4b, 0x7a, 0x66, 0x2b, 0x89, 0x2d, 0x89,
		0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x2d,
		0x02, 0x0d, 0x51, 0xa7, 0xa2, 0x54, 0xa0, 0x7d, 0x2d, 0x03, 0xcc, 0x0d, 0x50, 0x4e, 0xd4, 0xfe,
		0x2a, 0x6e, 0xfc, 0xfe, 0xf8, 0x00, 0x4a, 0x2f, 0xe8, 0x0b, 0xd5, 0x1e, 0x11, 0x45, 0x57, 0x09,
		0xfd, 0x23, 0x08, 0xbf, 0xbb, 0x52, 0x45, 0xda, 0x57, 0x6d, 0xe1, 0xbd, 0x7c, 0x23, 0x9a, 0x79,
		0xc7, 0xeb, 0x87, 0x81, 0x0e, 0xda, 0x41, 0x2f, 0x4a, 0xae, 0xbc, 0xd6, 0x75, 0xdf, 0x0b, 0x65,
		0xcb, 0xf3, 0xbb, 0xd2, 0x8d, 0xfc, 0xae, 0x8c, 0x92, 0x2b, 0x4f, 0xf6, 0x6f, 0x0b, 0xee, 0x40,
		0xc9, 0xb6, 0x1f, 0x69, 0x4f, 0x09, 0x79, 0xfd, 0xb5, 0x15, 0x84, 0x51, 0x72, 0xe5, 0xf9, 0x9d,
		0x6f, 0x23, 0xa4, 0x0a, 0x06, 0xda, 0xed, 0x87, 0xc2, 0x0b, 0x83, 0x81, 0x16, 0x51, 0xfc, 0xc5,
		0x1b, 0xa8, 0xef, 0x2a, 0xf8, 0xa1, 0x5c, 0x5f, 0xeb, 0x50, 0xb6, 0x46, 0xdf, 0x98, 0x79, 0x2b,
		0x3e, 0x4d, 0x93, 0x67, 0x68, 0x22, 0x5b, 0x82, 0x72, 0xa6, 0xfe, 0xff, 0xc4, 0x3d, 0x62, 0x53,
		0x5c, 0xe7, 0x54, 0x46, 0xba, 0xa2, 0x35, 0xd8, 0x81, 0xff, 0x9f, 0xa4, 0x3a, 0xe9, 0x89, 0x21,
		0xa3, 0x8c, 0xb0, 0x2a, 0x4a, 0xe7, 0x93, 0x7f, 0xf7, 0xcc, 0xb2, 0xfc, 0x61, 0xa1, 0x50, 0x2a,
		0x17, 0x0a, 0xb9, 0xf2, 0x41, 0x39, 0x77, 0x54, 0x2c, 0xe6, 0x4b, 0x79, 0xa0, 0x0d, 0x5c, 0x4e,
		0x2d, 0xec, 0x88, 0x50, 0x74, 0x3e, 0x0c, 0x5d, 0x4f, 0x0d, 0x7a, 0x3d, 0x46, 0x24, 0x3e, 0x74,
		0x6e, 0x36, 0x64, 0x3a, 0x50, 0x07, 0x2b, 0x87, 0x83, 0xb6, 0x56, 0xe3, 0xd2, 0xe1, 0x2c, 0x7e,
		0x72, 0xd5, 0xf1, 0x83, 0x6b, 0x9e, 0x8f, 0x1f, 0x57, 0xf3, 0xc3, 0x75, 0xbf, 0x59, 0x97, 0xad,
		0x66, 0xa5, 0x2b, 0x2f, 0xfc, 0xae, 0x6c, 0x56, 0xfb, 0xb7, 0x85, 0xcf, 0xf1, 0x23, 0x6a, 0x9e,
		0x8d, 0x1f, 0x4c, 0xb3, 0xd2, 0xf9, 0x56, 0x97, 0xad, 0xda, 0x40, 0x9f, 0x87, 0xa2, 0x59, 0x1f,
		0x3e, 0x8e, 0xe6, 0xe7, 0xf8, 0x6f, 0xaf, 0x24, 0x7f, 0xfa, 0x1b, 0xa2, 0xb2, 0x7d, 0x0b, 0x2c,
		0x67, 0x1f, 0xb4, 0xac, 0xb3, 0x49, 0xd9, 0xc6, 0x6e, 0x80, 0xd9, 0x73, 0x6b, 0x3b, 0x77, 0xb6,
		0x14, 0x48, 0x13, 0x22, 0x1d, 0x0b, 0xb9, 0x3b, 0x43, 0xc7, 0x75, 0xa5, 0xad, 0x4d, 0xa3, 0x18,
		0xec, 0x19, 0x87, 0x2d, 0x43, 0xb3, 0x63, 0x0c, 0x36, 0x6c, 0x2b, 0x6c, 0x40, 0x70, 0x27, 0xb3,
		0x78, 0x63, 0x91, 0xb8, 0xa6, 0x4c, 0x54, 0xed, 0xc0, 0xa6, 0x79, 0xd0, 0x32, 0x7b, 0x47, 0xc3,
		0x71, 0x6e, 0x3b, 0xbe, 0x33, 0x18, 0xd7, 0x66, 0xfd, 0xde, 0x9c, 0xf7, 0x19, 0xf4, 0x3c, 0x27,
		0x16, 0xc0, 0x4d, 0x3b, 0x5c, 0x32, 0xdd, 0x17, 0xdf, 0xde, 0x70, 0xa4, 0x4d, 0x26, 0xf0, 0x0c,
		0xdf, 0x36, 0x59, 0x5f, 0xb3, 0x6f, 0xf8, 0xc6, 0x16, 0xd7, 0xcd, 0x60, 0xac, 0x87, 0xb1, 0xbd,
		0xce, 0x05, 0x66, 0xfd, 0x0a, 0xcc, 0xba, 0x14, 0x98, 0xf5, 0x26, 0xe4, 0x14, 0xe4, 0x14, 0x31,
		0xa7, 0xb0, 0x30, 0x15, 0x6c, 0x90, 0x52, 0xbc, 0xd9, 0x20, 0xf7, 0xb6, 0xe5, 0xd6, 0x59, 0x72,
		0x67, 0xc7, 0x28, 0x87, 0x4c, 0xa7, 0xba, 0x35, 0x13, 0x8c, 0xe9, 0x87, 0x86, 0x81, 0xb0, 0x70,
		0x26, 0x7e, 0xe0, 0xfa, 0x9d, 0x4e, 0x28, 0xa2, 0xc8, 0x58, 0x60, 0x24, 0x0c, 0x6f, 0xc6, 0x02,
		0x43, 0xc9, 0xc0, 0xec, 0xaa, 0x7a, 0xe3, 0xab, 0xe4, 0x6d, 0xb0, 0x77, 0xbb, 0xac, 0xdd, 0x16,
		0x5b, 0xb7, 0xce, 0xd2, 0xad, 0xb3, 0x73, 0xeb, 0xac, 0x7c, 0xb3, 0x68, 0x8a, 0xf1, 0x55, 0xd7,
		0x49, 0xdc, 0xf6, 0x84, 0xdf, 0x0d, 0x45, 0xd7, 0x64, 0xd0, 0x4e, 0x44, 0x95, 0xb2, 0xc1, 0x7b,
		0x9e, 0x8f, 0x99, 0xd8, 0xbb, 0x77, 0x31, 0x7b, 0xf7, 0x66, 0x30, 0x88, 0x0c, 0x02, 0x54, 0x09,
		0xb4, 0xa2, 0x00, 0x1a, 0x56, 0xfe, 0xc8, 0x15, 0xc8, 0x15, 0xc8, 0x15, 0xc8, 0x15, 0x7e, 0xe7,
		0x69, 0x1e, 0x4b, 0xb3, 0x4b, 0x50, 0xec, 0x15, 0x8c, 0x28, 0x85, 0xa3, 0xa5, 0x02, 0xd2, 0x1a,
		0x38, 0xd8, 0x04, 0x09, 0x0c, 0xb0, 0xb0, 0x0d, 0x1a, 0x30, 0xe0, 0x01, 0x03, 0x22, 0x30, 0x60,
		0x62, 0x16, 0x54, 0x0c, 0x83, 0x8b, 0xbd, 0x82, 0x74, 0x26, 0xee, 0x65, 0xdf, 0x52, 0x96, 0x9f,
		0xa2, 0xff, 0x16, 0xce, 0x14, 0x9c, 0x3c, 0x7b, 0x3b, 0x27, 0x05, 0x5a, 0x5c, 0x2e, 0xf8, 0x34,
		0xf2, 0xb7, 0x05, 0x8b, 0x63, 0x3f, 0xe3, 0x03, 0x87, 0x16, 0x6d, 0x38, 0xf7, 0xb5, 0x16, 0xa1,
		0xb2, 0x7e, 0x70, 0xa4, 0xf3, 0xef, 0xee, 0xee, 0x55, 0xce, 0x3d, 0x6a, 0x3c, 0x5c, 0xe5, 0xdd,
		0xa3, 0x46, 0x7c, 0x99, 0x1f, 0x7d, 0x89, 0xaf, 0xf7, 0xaf, 0x72, 0x6e, 0x61, 0x72, 0x5d, 0xbc,
		0xca, 0xb9, 0xc5, 0xc6, 0xde, 0x97, 0x2f, 0xef, 0xf6, 0x7e, 0x1e, 0x3c, 0x2e, 0xff, 0xc1, 0x3f,
		0xec, 0x2d, 0xef, 0x6f, 0xd8, 0x1c, 0xec, 0xda, 0x45, 0xf5, 0x1f, 0x8e, 0xb8, 0xe9, 0x11, 0xdf,
		0xa6, 0xb5, 0xe1, 0x18, 0xe9, 0xbd, 0xc4, 0xf4, 0x8e, 0x99, 0xde, 0x7d, 0xb7, 0x5b, 0x71, 0x3f,
		0x36, 0x7e, 0xe6, 0xdf, 0x16, 0x1e, 0xdf, 0xef, 0xfd, 0x2c, 0x3f, 0xbe, 0x7c, 0xf3, 0x61, 0xde,
		0x8f, 0xe5, 0xdf, 0x96, 0x1f, 0xdf, 0x2f, 0xf8, 0x4e, 0xe9, 0xf1, 0xfd, 0x6f, 0xfe, 0x8e, 0xe2,
		0xe3, 0xee, 0xcc, 0x8f, 0x0e, 0xdf, 0xdf, 0x5f, 0xf4, 0x81, 0xc2, 0x82, 0x0f, 0x1c, 0x2c, 0xfa,
		0xc0, 0xc1, 0x82, 0x0f, 0x2c, 0x34, 0x69, 0x7f, 0xc1, 0x07, 0x8a, 0x8f, 0x0f, 0x33, 0x3f, 0xbf,
		0x3b, 0xff, 0x47, 0x4b, 0x8f, 0x7b, 0x0f, 0x8b, 0xbe, 0x57, 0x7e, 0x7c, 0x78, 0xbf, 0x47, 0xb0,
		0xa3, 0xff, 0xd3, 0xff, 0xb7, 0x0a, 0xfa, 0xdf, 0x6c, 0xf6, 0xdf, 0xc9, 0xb5, 0x8a, 0xaf, 0x54,
		0xb6, 0xb8, 0x56, 0x71, 0x66, 0xad, 0xa2, 0xc1, 0xa5, 0xb6, 0x06, 0xe6, 0xe6, 0xdf, 0x64, 0xd8,
		0x4d, 0x27, 0x9b, 0xb1, 0x0d, 0xcf, 0xc1, 0x98, 0xdd, 0x76, 0x6d, 0x7e, 0x7b, 0x35, 0xc4, 0x36,
		0x6a, 0xb3, 0xdb, 0xa5, 0xd3, 0x76, 0x54, 0xc3, 0x79, 0x14, 0x39, 0x7f, 0x3a, 0x46, 0x56, 0x03,
		0xad, 0x6d, 0x4d, 0x77, 0xba, 0x89, 0x3e, 0xbd, 0xf4, 0x9b, 0xce, 0x6f, 0x4e, 0x29, 0x4e, 0x4c,
		0xc5, 0x07, 0x60, 0x5c, 0xa4, 0xe3, 0x5f, 0xeb, 0x1f, 0xfd, 0xf5, 0xfe, 0xc6, 0x35, 0xfb, 0x51,
		0xda, 0xfe, 0x03, 0xe3, 0x37, 0x29, 0x24, 0xcf, 0x35, 0x24, 0xcb, 0xf5, 0xfa, 0xf0, 0xfa, 0x3c,
		0x6d, 0x8d, 0x5e, 0x16, 0x4b, 0xc4, 0x51, 0xa8, 0x85, 0xdb, 0x0f, 0x7a, 0xb2, 0x7d, 0xbf, 0x76,
		0x3f, 0x9b, 0x16, 0xa3, 0x9f, 0xdf, 0x69, 0xcd, 0xb1, 0x92, 0xce, 0x32, 0xd2, 0xd4, 0x56, 0x04,
		0xa5, 0xb9, 0xe2, 0xc7, 0xcc, 0x8a, 0x9e, 0xb4, 0x57, 0xec, 0x18, 0x5b, 0x91, 0x63, 0x6c, 0xc5,
		0x8d, 0xb1, 0x15, 0x35, 0xd8, 0xa8, 0x96, 0xd6, 0xb2, 0x4a, 0xa7, 0x17, 0x3f, 0xd3, 0xf4, 0x3c,
		0x32, 0xd9, 0xca, 0x31, 0xbe, 0x51, 0x4a, 0x6e, 0x92, 0xee, 0x8a, 0xf8, 0xd4, 0x17, 0x39, 0x9a,
		0x58, 0xcc, 0x68, 0x76, 0xd1, 0xa2, 0xa9, 0xc5, 0x89, 0xc6, 0x17, 0x21, 0x1a, 0x5f, 0x6c, 0x68,
		0x7c, 0x51, 0x61, 0xb6, 0x0a, 0xc6, 0xb4, 0x57, 0x9c, 0x3b, 0xe3, 0x26, 0x4d, 0xa9, 0x3b, 0xf2,
		0x24, 0x3c, 0xc7, 0xf7, 0x4b, 0x5b, 0x30, 0x35, 0xb2, 0x85, 0xc8, 0xd8, 0xea, 0x70, 0x93, 0xab,
		0xc1, 0xed, 0xac, 0xfe, 0x36, 0xbd, 0xda, 0xdb, 0xda, 0xea, 0x6e, 0x6b, 0xab, 0xb9, 0xad, 0xad,
		0xde, 0xfe, 0x7f, 0xf6, 0xbe, 0xf7, 0x29, 0x71, 0xa4, 0xfb, 0xfe, 0xfd, 0xfc, 0x15, 0x56, 0xea,
		0x79, 0xa1, 0x55, 0x93, 0x89, 0x28, 0x3f, 0xd4, 0x77, 0xcc, 0xea, 0x6c, 0x51, 0x8f, 0x23, 0x96,
		0x3a, 0xf3, 0x7d, 0x3e, 0xe5, 0xba, 0x54, 0x80, 0xc6, 0xe9, 0x19, 0xec, 0x50, 0x49, 0xe3, 0x68,
		0x8d, 0xfc, 0xef, 0xdf, 0x82, 0x40, 0x14, 0x03, 0xbb, 0x83, 0x90, 0xee, 0x13, 0x38, 0xd4, 0xd4,
		0x9a, 0x0d, 0x60, 0xae, 0xe9, 0x7b, 0xef, 0x39, 0x7d, 0x72, 0xfb, 0x76, 0xbe, 0x1f, 0xbd, 0x98,
		0x5a, 0xf2, 0x13, 0x27, 0x46, 0xf3, 0x2b, 0x3b, 0x4d, 0x76, 0xdd, 0xe4, 0xca, 0xce, 0x75, 0x49,
		0xd7, 0xb6, 0xd2, 0xb6, 0xf5, 0xf4, 0x6d, 0x3d, 0x8d, 0x5b, 0x4f, 0xe7, 0x66, 0xd2, 0xba, 0xa1,
		0xf4, 0x6e, 0x3c, 0xcd, 0x27, 0x17, 0x6c, 0x05, 0xdd, 0x20, 0xb4, 0xb7, 0x9c, 0x33, 0xbe, 0x3c,
		0xd7, 0x70, 0xae, 0x1b, 0x1c, 0x60, 0xc0, 0x82, 0x6d, 0x78, 0x80, 0x81, 0x09, 0x18, 0xb8, 0x80,
		0x81, 0x0d, 0xb3, 0xf0, 0x61, 0x18, 0x46, 0x92, 0xbb, 0x6c, 0x7f, 0x0d, 0xa7, 0xf9, 0xe6, 0x42,
		0x29, 0x96, 0x5f, 0xb1, 0x70, 0xed, 0x54, 0xb3, 0xa1, 0x18, 0xe8, 0xd8, 0x83, 0x7c, 0xe9, 0x3b,
		0x2b, 0x54, 0xbb, 0x17, 0xc8, 0x51, 0xe2, 0xb0, 0xc4, 0x59, 0x12, 0x0b, 0x48, 0x5b, 0x48, 0x5b,
		0x48, 0x5b, 0x48, 0x5b, 0x48, 0x5b, 0x48, 0x5b, 0xd6, 0x94, 0xb6, 0x24, 0x58, 0x47, 0xe6, 0xb2,
		0xf4, 0xcd, 0x9d, 0x6c, 0x5e, 0x67, 0x8d, 0xb8, 0xd8, 0xd9, 0x3d, 0x8f, 0xbc, 0x85, 0xbc, 0x85,
		0xbc, 0x85, 0xbc, 0x85, 0xbc, 0x85, 0xbc, 0xc5, 0x18, 0x6f, 0x99, 0x40, 0x1d, 0x69, 0xcb, 0xd2,
		0xf7, 0x96, 0x9b, 0xbe, 0x91, 0xb2, 0x90, 0xb2, 0x90, 0xb2, 0x90, 0xb2, 0xac, 0x23, 0x65, 0x31,
		0x5d, 0x70, 0x90, 0x5c, 0xd8, 0xd7, 0x3a, 0x74, 0xa5, 0x6a, 0x8b, 0x07, 0x7b, 0x41, 0x37, 0x49,
		0x3d, 0x2f, 0x6c, 0xb1, 0xb5, 0xcd, 0xbd, 0x95, 0x39, 0xb2, 0x75, 0xe0, 0x41, 0x00, 0x20, 0x2c,
		0x20, 0x42, 0x01, 0x24, 0x38, 0x60, 0x82, 0x03, 0x28, 0x38, 0xa0, 0xb2, 0x03, 0x58, 0x96, 0x80,
		0xcb, 0xfe, 0x9c, 0x1b, 0x68, 0xee, 0x8d, 0x30, 0x07, 0x9f, 0x35, 0x17, 0x9f, 0xf9, 0x6f, 0x04,
		0xb6, 0x91, 0xd0, 0x51, 0x72, 0x34, 0x9e, 0xb3, 0xc7, 0x00, 0xbc, 0x21, 0xfd, 0xd8, 0x2c, 0x84,
		0x8b, 0xa5, 0x5a, 0xcf, 0x54, 0x9c, 0xd8, 0xa8, 0xf9, 0x24, 0xd1, 0x22, 0xd1, 0x22, 0xd1, 0x22,
		0xd1, 0x22, 0xd1, 0x5a, 0x03, 0xa2, 0xd5, 0x97, 0x4a, 0xef, 0xef, 0x01, 0xf0, 0x2c, 0x9b, 0x34,
		0xeb, 0xc2, 0x57, 0xb7, 0xc2, 0x7a, 0xd7, 0x64, 0xbb, 0x39, 0x73, 0x6b, 0xdc, 0xaf, 0xd1, 0x7a,
		0xf2, 0x06, 0xa1, 0x17, 0x29, 0x73, 0xbe, 0xfa, 0xdd, 0xbe, 0x00, 0xb2, 0xe7, 0x53, 0xe8, 0xb7,
		0xb4, 0x0c, 0xd4, 0xb1, 0xbc, 0x95, 0x71, 0x7b, 0x4d, 0xeb, 0x76, 0x0d, 0xde, 0x03, 0xb8, 0xb0,
		0xff, 0x40, 0x17, 0xfe, 0x17, 0x17, 0x2e, 0xee, 0x1d, 0x16, 0x0f, 0xcb, 0x95, 0xbd, 0xc3, 0x12,
		0x7d, 0x19, 0x8b, 0x90, 0xd8, 0xbf, 0xfa, 0x0d, 0x45, 0x83, 0x0c, 0x45, 0x83, 0xbb, 0xbb, 0xbe,
		0x92, 0xfa, 0x11, 0xe5, 0x61, 0xcd, 0x6b, 0x83, 0x28, 0x24, 0x50, 0x48, 0xa0, 0x90, 0x40, 0x21,
		0x81, 0x42, 0x02, 0x85, 0x84, 0x05, 0xf3, 0x06, 0x9f, 0xd8, 0x6c, 0xfd, 0xce, 0x13, 0x9b, 0x09,
		0xe2, 0x4a, 0x11, 0x25, 0xc7, 0x8f, 0x7c, 0x68, 0x63, 0x66, 0x70, 0xac, 0xad, 0x77, 0x4d, 0x45,
		0x8b, 0xa5, 0x75, 0xaf, 0x64, 0x5c, 0x64, 0x5c, 0x64, 0x5c, 0x64, 0x5c, 0x64, 0x5c, 0x6b, 0xc0,
		0xb8, 0xac, 0x6e, 0xe9, 0x9e, 0x22, 0x5d, 0x87, 0x16, 0x6d, 0xb0, 0xba, 0xc5, 0xfb, 0xe4, 0x05,
		0xf0, 0xf8, 0x06, 0x6c, 0xcb, 0xf7, 0x94, 0x8f, 0x1c, 0x00, 0xd8, 0x82, 0xb2, 0x47, 0x6a, 0x62,
		0xd0, 0xa6, 0x6c, 0x0c, 0x3e, 0x79, 0xdd, 0x20, 0x38, 0x01, 0xd2, 0x6e, 0xb9, 0x9b, 0xeb, 0x09,
		0x76, 0x1f, 0xb1, 0xbc, 0x27, 0x5c, 0x40, 0x6d, 0x21, 0x4f, 0xb8, 0x58, 0x20, 0x49, 0x70, 0x6b,
		0xed, 0x8d, 0xda, 0x5a, 0x9b, 0xe0, 0xc9, 0xb8, 0x60, 0x5c, 0xc0, 0x52, 0x09, 0x56, 0x6b, 0xac,
		0x1f, 0x59, 0x73, 0xc4, 0x83, 0x76, 0xe1, 0x2a, 0x36, 0x66, 0x19, 0xc5, 0x67, 0x08, 0x76, 0x70,
		0x90, 0xcf, 0x10, 0x5e, 0x59, 0xc3, 0x67, 0x08, 0x73, 0x0c, 0xe2, 0x33, 0x04, 0x48, 0x04, 0xe5,
		0x33, 0x04, 0x56, 0x6d, 0x6c, 0xfd, 0x4e, 0xd5, 0xc6, 0x4b, 0xd4, 0x95, 0x22, 0x9a, 0xfa, 0x7f,
		0x56, 0x6f, 0x18, 0x1a, 0x24, 0xa9, 0xee, 0xfd, 0xae, 0x6c, 0xbb, 0xa1, 0xf0, 0xa3, 0x40, 0xd9,
		0xa7, 0x62, 0xaf, 0xec, 0x21, 0x0b, 0x23, 0x0b, 0x23, 0x0b, 0x23, 0x0b, 0x23, 0x0b, 0x23, 0x0b,
		0x5b, 0x14, 0x49, 0xda, 0x42, 0x69, 0xa9, 0x1f, 0x41, 0x98, 0x98, 0xc5, 0x55, 0x61, 0x4e, 0x6d,
		0x7c, 0x2b, 0x3e, 0xfa, 0x11, 0x40, 0x0a, 0x9b, 0x0c, 0x50, 0xed, 0xec, 0x6b, 0xf5, 0xb4, 0x76,
		0xdc, 0xb8, 0xa8, 0x7f, 0xb9, 0x3a, 0x69, 0x5c, 0x9c, 0x54, 0x2f, 0xeb, 0x67, 0xb6, 0xb3, 0xd9,
		0x68, 0x31, 0x5f, 0x04, 0x21, 0xc0, 0x83, 0xac, 0xb6, 0x7c, 0x3d, 0x5a, 0x7f, 0x9c, 0x7e, 0xb9,
		0xbc, 0x3a, 0xb9, 0x68, 0x9c, 0xd6, 0xeb, 0xe7, 0x0e, 0x17, 0xc7, 0xc2, 0x8e, 0x53, 0xf5, 0x92,
		0x43, 0x04, 0x3e, 0x44, 0xf5, 0x8b, 0xda, 0x9f, 0xb5, 0xb3, 0xea, 0x55, 0xfd, 0x82, 0xa3, 0x04,
		0x9c, 0xf0, 0xea, 0x67, 0x9f, 0x4e, 0x8e, 0x9d, 0x0d, 0x5f, 0x3b, 0x7d, 0xb3, 0x69, 0xfc, 0x79,
		0x23, 0xd4, 0x9f, 0xae, 0x1f, 0x69, 0xf7, 0x2e, 0x68, 0xcb, 0x8e, 0x14, 0x6d, 0xfb, 0xe2, 0xcf,
		0xb4, 0x39, 0xd4, 0x7e, 0xa8, 0xfd, 0x50, 0xfb, 0xa1, 0xf6, 0x43, 0xed, 0x87, 0xda, 0xcf, 0x82,
		0x79, 0x43, 0xcb, 0x3b, 0xa1, 0x65, 0xeb, 0x47, 0x54, 0x2e, 0x02, 0x68, 0x3f, 0x16, 0x4b, 0x6e,
		0x9d, 0x2f, 0x2a, 0xee, 0xfd, 0xe3, 0x28, 0x5f, 0x05, 0x91, 0x68, 0x05, 0xaa, 0x6d, 0x75, 0x65,
		0x13, 0xbb, 0xc2, 0x8d, 0x6f, 0x04, 0xbb, 0xc2, 0xcd, 0x37, 0x87, 0x5d, 0xe1, 0xf2, 0x30, 0x5f,
		0x67, 0x57, 0xb8, 0xdf, 0x70, 0xe1, 0xc2, 0x41, 0xb1, 0x58, 0xae, 0x14, 0x8b, 0xbb, 0x95, 0xfd,
		0xca, 0xee, 0x61, 0xa9, 0x54, 0x28, 0x17, 0xd8, 0x1f, 0x0e, 0x54, 0xe3, 0x60, 0xc5, 0xf1, 0x3a,
		0x6a, 0x1c, 0xb6, 0x76, 0xb5, 0x4d, 0x91, 0x52, 0x3b, 0xbb, 0xdb, 0x26, 0x66, 0x1c, 0x8b, 0x8e,
		0xdf, 0xef, 0x8e, 0xa6, 0x46, 0xbb, 0xd4, 0x56, 0xa8, 0xad, 0x50, 0x5b, 0xa1, 0xb6, 0x42, 0x6d,
		0x85, 0xda, 0xca, 0xa2, 0x79, 0x83, 0xcd, 0xed, 0x29, 0x63, 0x50, 0xc6, 0xa0, 0x8c, 0x41, 0x19,
		0x63, 0x83, 0x5c, 0x98, 0xcd, 0xed, 0x29, 0x5e, 0x50, 0xbc, 0x30, 0x2f, 0x5e, 0x8c, 0x17, 0xc3,
		0x04, 0x7d, 0x2d, 0xec, 0x0b, 0x18, 0x2f, 0x8d, 0xa1, 0x80, 0x40, 0x01, 0x81, 0x02, 0x02, 0x05,
		0x04, 0x0a, 0x08, 0x14, 0x10, 0x16, 0xcc, 0x1b, 0xcd, 0x20, 0xe8, 0x0a, 0x5f, 0x21, 0x2c, 0xca,
		0x29, 0x6c, 0x0a, 0x75, 0x79, 0xb7, 0xc6, 0x2e, 0xee, 0x54, 0x95, 0x0a, 0xb4, 0x3f, 0x9c, 0x0d,
		0x58, 0x71, 0x70, 0x27, 0x6a, 0x7d, 0x13, 0x77, 0x7e, 0x6f, 0xbc, 0xdc, 0xdd, 0x0b, 0x7a, 0x42,
		0xb5, 0x46, 0x44, 0xc1, 0x55, 0x42, 0xff, 0x0c, 0xc2, 0x1f, 0xae, 0x54, 0x91, 0xf6, 0x55, 0x4b,
		0x78, 0xaf, 0x4f, 0x44, 0xa9, 0x33, 0x5e, 0x2f, 0x0c, 0x74, 0xd0, 0x0a, 0xba, 0x51, 0x72, 0xe4,
		0x35, 0x6f, 0x7b, 0x5e, 0x28, 0x9b, 0x9e, 0xdf, 0x91, 0x6e, 0xe4, 0x77, 0x64, 0x94, 0x1c, 0x79,
		0xa3, 0x36, 0x83, 0x51, 0xa8, 0x85, 0xdb, 0x0b, 0xba, 0xb2, 0xf5, 0xe8, 0x75, 0xe3, 0xd4, 0xea,
		0x8d, 0x68, 0x5a, 0x14, 0xff, 0x88, 0x17, 0xd3, 0x9b, 0xcd, 0xb4, 0xe6, 0x5c, 0xce, 0xa0, 0xbb,
		0x39, 0x7d, 0xf5, 0x43, 0x05, 0x3f, 0x95, 0xeb, 0x6b, 0x1d, 0xca, 0xe6, 0xf0, 0x0e, 0x1b, 0x77,
		0xb9, 0x67, 0x21, 0x36, 0x6d, 0x8b, 0xe1, 0xc0, 0x9b, 0xa4, 0x51, 0xc3, 0x97, 0xb5, 0xc5, 0xc2,
		0x6d, 0xb2, 0x6f, 0x0c, 0xd6, 0x6d, 0x9b, 0x6d, 0xc3, 0xb0, 0x6c, 0x18, 0x76, 0x0d, 0xc3, 0xaa,
		0xd7, 0x9b, 0x62, 0x1c, 0xcb, 0xd0, 0x4e, 0xd8, 0xa7, 0x92, 0xbc, 0x7d, 0x19, 0x28, 0x6d, 0x92,
		0x5d, 0x31, 0xa8, 0x40, 0x31, 0x88, 0x62, 0x10, 0xc5, 0x20, 0x8a, 0x41, 0x14, 0x83, 0xd0, 0xe1,
		0x2c, 0x31, 0x60, 0x88, 0x1d, 0xae, 0xb6, 0x2d, 0x49, 0x4d, 0x65, 0xb0, 0x67, 0x93, 0x2c, 0x87,
		0x06, 0xc6, 0x23, 0x60, 0xeb, 0xf0, 0x86, 0x04, 0x73, 0x98, 0x70, 0x87, 0x06, 0x7b, 0xb0, 0xf0,
		0x07, 0x0b, 0x83, 0xb0, 0x70, 0x68, 0x17, 0x16, 0x2d, 0xc3, 0x63, 0x32, 0x2a, 0x57, 0x08, 0x00,
		0xb5, 0x85, 0xd5, 0x5a, 0x36, 0x35, 0xfb, 0xaa, 0x60, 0x6c, 0x28, 0x33, 0x69, 0x35, 0x1b, 0xf7,
		0x8d, 0x7d, 0x06, 0xf3, 0x0d, 0x2d, 0xca, 0xb1, 0x18, 0x3a, 0x4e, 0xfc, 0xb4, 0x01, 0x86, 0xd8,
		0xc5, 0xe6, 0x60, 0x90, 0xba, 0x02, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x9d,
		0xad, 0x51, 0xb1, 0xad, 0x7d, 0x4c, 0x6b, 0x20, 0x5d, 0x01, 0xb4, 0x7e, 0x62, 0x4a, 0x0a, 0x19,
		0x5a, 0xf6, 0x9e, 0x45, 0xf1, 0xc0, 0x20, 0x8a, 0x08, 0xa6, 0xd8, 0xa0, 0x8a, 0x0a, 0xae, 0xf0,
		0x20, 0x0b, 0x0f, 0xb6, 0xf0, 0xa0, 0x8b, 0x01, 0xbe, 0x20, 0x20, 0x8c, 0xa7, 0xb0, 0xa4, 0xf2,
		0x56, 0x5f, 0x2a, 0x5d, 0x28, 0x23, 0xe5, 0xac, 0x31, 0x0a, 0x96, 0x81, 0x4c, 0xc2, 0x58, 0x06,
		0xfb, 0xfa, 0x85, 0x95, 0xd3, 0xb7, 0xd0, 0x96, 0xc9, 0x82, 0xd3, 0xab, 0x94, 0x79, 0x60, 0xcb,
		0x68, 0x53, 0xf6, 0x01, 0x2e, 0x45, 0x04, 0x4d, 0xf7, 0xd3, 0x21, 0xe1, 0x3f, 0x30, 0x24, 0x96,
		0x0c, 0x89, 0x72, 0xa9, 0xb4, 0x5f, 0x62, 0x58, 0xe4, 0x9b, 0x8b, 0xe1, 0x59, 0x73, 0xf3, 0x8e,
		0xf7, 0x03, 0x24, 0x6d, 0x02, 0x55, 0xca, 0xa4, 0x28, 0x32, 0x4a, 0xc5, 0x0c, 0x68, 0xd6, 0xa6,
		0x4e, 0xb4, 0x88, 0x33, 0x51, 0x27, 0x5a, 0xc8, 0xd3, 0xa9, 0x13, 0x2d, 0x69, 0x20, 0x75, 0xa2,
		0x1c, 0x4d, 0x1c, 0xc0, 0x75, 0xa2, 0x03, 0x40, 0x99, 0xa8, 0x44, 0x99, 0xe8, 0x5f, 0x5e, 0x94,
		0x89, 0xd6, 0x72, 0x4e, 0x4c, 0x99, 0x28, 0xef, 0xd9, 0x7e, 0x3a, 0x24, 0x28, 0x13, 0x2d, 0x1d,
		0x12, 0x7b, 0x25, 0x8a, 0x44, 0x6b, 0x20, 0xcb, 0x6c, 0x51, 0x24, 0x02, 0xbc, 0x1f, 0x30, 0x22,
		0xd1, 0xfd, 0x38, 0xda, 0x11, 0x55, 0xa2, 0xd8, 0x36, 0xca, 0x44, 0xb3, 0xcc, 0xa1, 0x4c, 0xb4,
		0x80, 0x37, 0x51, 0x26, 0x5a, 0xc8, 0xd3, 0x29, 0x13, 0x2d, 0x69, 0x20, 0x65, 0xa2, 0x1c, 0x4d,
		0x1c, 0x80, 0x65, 0xa2, 0xa6, 0x54, 0x7e, 0xf8, 0x08, 0xa8, 0x13, 0x1d, 0x02, 0x99, 0x74, 0x2a,
		0xd4, 0xed, 0x68, 0x21, 0x17, 0x85, 0xa2, 0x7f, 0x9b, 0x15, 0x53, 0x28, 0x5a, 0x7a, 0x56, 0x5c,
		0xe0, 0x9c, 0x38, 0xe7, 0xf9, 0x7e, 0x3a, 0x24, 0x28, 0x14, 0x2d, 0x1d, 0x12, 0xac, 0x27, 0x5a,
		0x13, 0x71, 0x66, 0x8b, 0x52, 0x11, 0xe0, 0xfd, 0x40, 0x90, 0x8a, 0xc4, 0x83, 0x16, 0xaa, 0x2d,
		0xda, 0x78, 0x42, 0x51, 0x62, 0x19, 0x65, 0xa2, 0x59, 0xe6, 0x50, 0x26, 0x5a, 0xc0, 0x97, 0x28,
		0x13, 0x2d, 0xe4, 0xe9, 0x94, 0x89, 0x96, 0x34, 0x90, 0x32, 0x51, 0x8e, 0xa6, 0x0d, 0xc8, 0x32,
		0x91, 0xf5, 0xbd, 0x11, 0xe6, 0xc1, 0xa0, 0xa5, 0xbd, 0x12, 0x48, 0xe2, 0x66, 0x8d, 0x49, 0xd0,
		0x1b, 0xce, 0x84, 0xfc, 0x2e, 0x1e, 0x89, 0x4b, 0x2c, 0x23, 0x89, 0x23, 0x89, 0x23, 0x89, 0x23,
		0x89, 0x23, 0x89, 0x23, 0x89, 0x23, 0x89, 0x23, 0x89, 0x23, 0x89, 0x7b, 0x3d, 0x26, 0x3d, 0x3f,
		0xd4, 0x12, 0x91, 0xc3, 0x4d, 0x0c, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85,
		0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x7b, 0x3d, 0x26, 0x3a, 0xf4, 0x55, 0x24, 0xb5,
		0xbc, 0x07, 0xac, 0xbb, 0x7f, 0x61, 0x1b, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89,
		0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x18, 0x91, 0xdb, 0xe8, 0x76, 0xf4, 0x96, 0x37, 0xaf,
		0x4f, 0xd9, 0x83, 0xbf, 0x99, 0x7d, 0x7a, 0xdf, 0xf3, 0xf4, 0x29, 0x1b, 0x3b, 0xde, 0xe3, 0xf8,
		0xf5, 0x66, 0x6d, 0x66, 0xf9, 0x5f, 0xf1, 0x88, 0xd0, 0x8d, 0xce, 0x39, 0x95, 0x91, 0xae, 0x6a,
		0x6d, 0x79, 0x67, 0xcd, 0xcf, 0x52, 0x9d, 0x74, 0xc5, 0x90, 0x3a, 0x45, 0x76, 0xa7, 0x36, 0xce,
		0x67, 0xff, 0xe1, 0x85, 0x25, 0x85, 0x83, 0x62, 0xb1, 0x5c, 0x29, 0x16, 0x77, 0x2b, 0xfb, 0x95,
		0xdd, 0xc3, 0x52, 0xa9, 0x50, 0x2e, 0x58, 0x5c, 0x69, 0xe0, 0xd4, 0xc3, 0xb6, 0x08, 0x45, 0xfb,
		0xe3, 0xd0, 0x75, 0x54, 0xbf, 0xdb, 0xdd, 0xa8, 0x88, 0x01, 0xc1, 0x9c, 0x35, 0xc1, 0x1a, 0xc7,
		0xea, 0x56, 0x6b, 0x61, 0xbf, 0xa5, 0xd5, 0x98, 0xec, 0x9e, 0xc5, 0xb7, 0xa4, 0x36, 0xbe, 0x23,
		0x8d, 0xf3, 0xf1, 0x7d, 0x68, 0x7c, 0xbc, 0xed, 0x35, 0x2e, 0x64, 0xb3, 0x51, 0xed, 0xc8, 0x4b,
		0xbf, 0x23, 0x1b, 0xb5, 0xde, 0x7d, 0xf9, 0x32, 0xd4, 0xe2, 0x7c, 0xf4, 0xa7, 0x37, 0x4e, 0x83,
		0xd6, 0xf0, 0xdd, 0x8b, 0xe1, 0x9f, 0xdc, 0xf8, 0x12, 0xff, 0x7d, 0xd5, 0xe4, 0xcf, 0x7b, 0xb7,
		0x19, 0x10, 0x66, 0xf6, 0x8a, 0x86, 0x43, 0xdf, 0x76, 0xc8, 0xe7, 0x32, 0xd4, 0xcd, 0x7a, 0xbe,
		0x39, 0xff, 0x33, 0x73, 0x25, 0x43, 0x1e, 0x3e, 0xa1, 0x7f, 0x43, 0xd7, 0x72, 0x65, 0x7b, 0x4b,
		0xa8, 0x76, 0x2f, 0x90, 0x4a, 0x6f, 0xb5, 0x82, 0x6e, 0x10, 0x1a, 0xca, 0xcd, 0x76, 0xb8, 0x9f,
		0x3d, 0xae, 0x07, 0xc5, 0xed, 0xec, 0x70, 0x39, 0x53, 0xee, 0x6d, 0x29, 0x71, 0xe3, 0x27, 0x6c,
		0x83, 0xb4, 0x2b, 0x03, 0x9a, 0x65, 0x06, 0x5b, 0xb2, 0xcf, 0xf4, 0xd9, 0x5e, 0x21, 0xe3, 0x20,
		0x33, 0x1d, 0x5c, 0xc8, 0x41, 0x95, 0xad, 0x43, 0x66, 0xe7, 0x26, 0xd9, 0xfc, 0xe6, 0x8c, 0x1c,
		0xcf, 0x94, 0xc3, 0x41, 0x3a, 0x5a, 0x86, 0x09, 0x7b, 0xa5, 0x09, 0x3a, 0x9b, 0x48, 0x58, 0xbd,
		0x9f, 0x66, 0xe0, 0xa3, 0x8e, 0x12, 0xf2, 0xf6, 0x5b, 0x33, 0x08, 0xa3, 0xcc, 0xdc, 0x33, 0x79,
		0x32, 0xf7, 0x7c, 0xa9, 0x8c, 0x62, 0x2d, 0xdb, 0x2d, 0xd7, 0x33, 0x2f, 0x1f, 0x31, 0x51, 0x0e,
		0x62, 0xb6, 0xbc, 0xc3, 0x54, 0xb9, 0x86, 0xf1, 0xf2, 0x0b, 0xe3, 0xe5, 0x14, 0xc6, 0xcb, 0x23,
		0xf2, 0x85, 0xb2, 0x59, 0x6f, 0xf1, 0x9d, 0xe4, 0xae, 0xec, 0x5d, 0xf9, 0x75, 0xb6, 0xcc, 0xda,
		0x93, 0xb3, 0x4d, 0x9a, 0xc6, 0x92, 0xa7, 0xc9, 0x24, 0x6a, 0x27, 0x99, 0x9a, 0x4e, 0xaa, 0xd6,
		0x92, 0xab, 0xb5, 0x24, 0x6b, 0x2d, 0xd9, 0xae, 0xc7, 0xdc, 0x3a, 0xeb, 0x24, 0x9c, 0x5c, 0xc8,
		0x6f, 0x7f, 0x1f, 0x8d, 0x89, 0x54, 0x6e, 0x2f, 0x88, 0xb4, 0xb9, 0x48, 0x48, 0x3a, 0x9c, 0xbf,
		0x32, 0xc0, 0x94, 0xf0, 0x6d, 0x24, 0x55, 0x1b, 0x4f, 0xd9, 0x36, 0x52, 0xb7, 0xdd, 0x14, 0x6e,
		0x2b, 0x95, 0x5b, 0x4f, 0xe9, 0xd6, 0x53, 0xbb, 0xf5, 0x14, 0x6f, 0x26, 0xd5, 0x1b, 0x4a, 0xf9,
		0xc6, 0x53, 0x7f, 0x72, 0xc1, 0xb1, 0x84, 0x69, 0x3c, 0x70, 0x26, 0xe9, 0x62, 0x7c, 0x7d, 0xc3,
		0x4e, 0x6b, 0x16, 0x00, 0xac, 0x01, 0x81, 0x4d, 0x40, 0xc0, 0x00, 0x06, 0xdb, 0x00, 0x01, 0x03,
		0x14, 0x30, 0x80, 0x01, 0x03, 0x1c, 0x66, 0x01, 0xc4, 0x30, 0x90, 0x58, 0x03, 0x94, 0x69, 0x60,
		0xb1, 0x17, 0x6f, 0x53, 0xf8, 0x62, 0x2b, 0xd6, 0xec, 0xc0, 0x8c, 0x75, 0xb8, 0x41, 0x80, 0x1d,
		0x2c, 0xf8, 0x41, 0x81, 0x21, 0x38, 0x38, 0x82, 0x83, 0x25, 0x38, 0x78, 0xb2, 0x03, 0x53, 0x96,
		0xe0, 0xca, 0x3a, 0x6c, 0x25, 0x06, 0xc4, 0x35, 0x90, 0xd6, 0xe3, 0x74, 0x92, 0xbd, 0x4c, 0x96,
		0x64, 0xfe, 0x1b, 0x9c, 0x59, 0x5e, 0xf4, 0x0f, 0xd3, 0x7d, 0x00, 0xa9, 0xeb, 0x00, 0x66, 0xb7,
		0x01, 0xb4, 0x2e, 0x03, 0xb0, 0xdd, 0x05, 0x60, 0xbb, 0x0a, 0xc0, 0x76, 0x13, 0xd8, 0xec, 0xa5,
		0xcf, 0x30, 0x5d, 0x03, 0x92, 0xbc, 0xd3, 0x15, 0x7e, 0x27, 0x14, 0x1d, 0x84, 0xa4, 0x33, 0x99,
		0x75, 0x55, 0x00, 0x6c, 0x39, 0x1f, 0xd7, 0x11, 0x7e, 0xf8, 0x10, 0xaf, 0xab, 0xf6, 0x62, 0x20,
		0xdf, 0xd4, 0xd5, 0xd5, 0x16, 0x67, 0x5e, 0x93, 0xd5, 0x2d, 0x38, 0x9c, 0x2e, 0xb1, 0x88, 0xb4,
		0x8e, 0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0x2e, 0x97, 0xb4, 0x2e,
		0xc1, 0x72, 0x32, 0x3b, 0xe3, 0x83, 0x31, 0x5e, 0xbf, 0x8c, 0x43, 0xec, 0x26, 0x06, 0x91, 0xd7,
		0x91, 0xd7, 0x91, 0xd7, 0x91, 0xd7, 0x91, 0xd7, 0x91, 0xd7, 0x91, 0xd7, 0xe5, 0x92, 0xd7, 0x4d,
		0xa0, 0x9c, 0xb4, 0xce, 0xf8, 0x58, 0xc4, 0x7d, 0x28, 0x61, 0x48, 0x5d, 0x6c, 0x0e, 0x06, 0xa5,
		0x2b, 0x90, 0xd2, 0x91, 0xd2, 0x91, 0xd2, 0x91, 0xd2, 0x91, 0xd2, 0xd9, 0x1a, 0x15, 0xdb, 0x05,
		0x4a, 0x89, 0x21, 0xa3, 0xe6, 0xbd, 0x52, 0xb5, 0xc5, 0x03, 0xde, 0x46, 0x2a, 0x2f, 0x6c, 0xe3,
		0x46, 0x2a, 0xc8, 0x40, 0x8a, 0x08, 0xa8, 0xd8, 0xc0, 0x8a, 0x0a, 0xb0, 0xf0, 0x40, 0x0b, 0x0f,
		0xb8, 0xf0, 0xc0, 0x8b, 0x01, 0xc0, 0x20, 0x40, 0x8c, 0xa7, 0xb1, 0x00, 0x6b, 0x2d, 0x88, 0x9a,
		0xcb, 0x2c, 0xed, 0xe5, 0x1f, 0xfe, 0x8d, 0x28, 0x45, 0x24, 0x74, 0x94, 0x1c, 0x8d, 0x95, 0x9a,
		0x98, 0x66, 0x70, 0x63, 0x18, 0x94, 0xa0, 0x74, 0x9a, 0x22, 0xd2, 0xee, 0xb8, 0x8f, 0x1e, 0x18,
		0x2f, 0x7d, 0x36, 0x8d, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x74,
		0xc3, 0x68, 0x29, 0xf7, 0xf7, 0x23, 0x8d, 0xfb, 0x8d, 0x31, 0xc1, 0x58, 0x08, 0x99, 0xf2, 0x5e,
		0x84, 0x05, 0x91, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xc6,
		0xf3, 0x56, 0x5f, 0x2a, 0xbd, 0xbf, 0x07, 0xc8, 0xde, 0x90, 0x34, 0xc5, 0x0b, 0x5f, 0xdd, 0x0e,
		0xef, 0xd6, 0x35, 0x54, 0x0e, 0xc0, 0xca, 0xe9, 0x5b, 0xe3, 0xfd, 0xb0, 0xe0, 0xc0, 0x06, 0x94,
		0x5e, 0xa5, 0xcc, 0xfb, 0xea, 0x77, 0xfb, 0x02, 0xd8, 0xbe, 0x4f, 0xa1, 0xdf, 0xd2, 0x32, 0x50,
		0xc7, 0xf2, 0x56, 0xc6, 0xdb, 0x9d, 0xc1, 0xd9, 0x39, 0x78, 0x0f, 0x18, 0x12, 0xfe, 0x03, 0x43,
		0x62, 0xc9, 0x90, 0x28, 0xee, 0x1d, 0x16, 0x0f, 0xcb, 0x95, 0xbd, 0xc3, 0x12, 0x63, 0x23, 0xdf,
		0x84, 0x0c, 0xcf, 0x9a, 0x1b, 0x8a, 0x44, 0x28, 0xb9, 0xd3, 0x69, 0x05, 0x77, 0x77, 0x7d, 0x25,
		0xf5, 0x23, 0x6a, 0x25, 0xda, 0x6b, 0x03, 0x29, 0x1c, 0xcd, 0x32, 0x87, 0xc2, 0xd1, 0x02, 0x2e,
		0x45, 0xe1, 0x68, 0x21, 0x4f, 0xa7, 0x70, 0xb4, 0xa4, 0x81, 0x14, 0x8e, 0x72, 0x34, 0x93, 0x60,
		0x39, 0xda, 0x1b, 0x60, 0x30, 0x87, 0xe5, 0x68, 0x13, 0x5e, 0x21, 0x45, 0x94, 0x1c, 0x3f, 0xb2,
		0x22, 0x0d, 0x93, 0xa5, 0xc2, 0xb4, 0x00, 0x4b, 0xc5, 0x24, 0x48, 0x2b, 0x30, 0xf2, 0x52, 0xf2,
		0x52, 0xf2, 0x52, 0xf2, 0x52, 0xf2, 0x52, 0xf2, 0x52, 0xe3, 0x79, 0x4b, 0xf6, 0x5c, 0xbf, 0xdd,
		0x0e, 0x45, 0x14, 0x21, 0x52, 0xd3, 0x43, 0x20, 0x9b, 0xc6, 0x63, 0xc8, 0x87, 0x9a, 0xbf, 0xed,
		0x59, 0xf7, 0x45, 0x40, 0xdf, 0x4a, 0xf9, 0xd8, 0x01, 0xa0, 0x6d, 0xe7, 0xbe, 0xd6, 0x22, 0x54,
		0x70, 0xee, 0x96, 0x18, 0xf8, 0xf7, 0xf6, 0xf6, 0xf5, 0xae, 0x7b, 0x78, 0xf3, 0x74, 0x5d, 0x70,
		0x0f, 0x6f, 0xe2, 0xc3, 0xc2, 0xe8, 0x47, 0x7c, 0xbc, 0x77, 0xbd, 0xeb, 0x16, 0x27, 0xc7, 0xa5,
		0xeb, 0x5d, 0xb7, 0x74, 0xb3, 0xf3, 0xd7, 0x5f, 0x1f, 0x76, 0x7e, 0xed, 0x0f, 0x16, 0xff, 0xe2,
		0x7f, 0x1c, 0xb8, 0x9b, 0x70, 0x83, 0xe8, 0x34, 0xf5, 0xcb, 0xda, 0xff, 0xe8, 0x39, 0xe8, 0x9e,
		0x83, 0xf5, 0x60, 0xf1, 0x3d, 0xe1, 0xec, 0xb7, 0xe1, 0xac, 0x4c, 0x38, 0x5b, 0x6f, 0x38, 0xf3,
		0xdd, 0x4e, 0xd5, 0xfd, 0x74, 0xf3, 0xab, 0xf0, 0xbe, 0x38, 0x38, 0xda, 0xf9, 0x55, 0x19, 0xbc,
		0x3e, 0xf9, 0x34, 0xeb, 0x63, 0x85, 0xf7, 0x95, 0xc1, 0xd1, 0x9c, 0x77, 0xca, 0x83, 0xa3, 0xdf,
		0xfc, 0x1d, 0xa5, 0xc1, 0x76, 0xea, 0xa3, 0xc3, 0xf3, 0x7b, 0xf3, 0xbe, 0x50, 0x9c, 0xf3, 0x85,
		0xfd, 0x79, 0x5f, 0xd8, 0x9f, 0xf3, 0x85, 0xb9, 0x26, 0xed, 0xcd, 0xf9, 0x42, 0x69, 0xf0, 0x94,
		0xfa, 0xfc, 0xf6, 0xec, 0x8f, 0x96, 0x07, 0x3b, 0x4f, 0xf3, 0xde, 0xab, 0x0c, 0x9e, 0x8e, 0x76,
		0x08, 0xee, 0x6b, 0x08, 0xee, 0x8c, 0x23, 0xc6, 0x11, 0x1e, 0xd5, 0x61, 0x0d, 0x15, 0xd8, 0xfd,
		0x80, 0x78, 0x3a, 0xf5, 0xa0, 0x5d, 0xf8, 0x3a, 0xaa, 0x59, 0x46, 0xf2, 0x99, 0xd5, 0x2c, 0x73,
		0xf8, 0xcc, 0x6a, 0x01, 0xb7, 0xe2, 0x33, 0xab, 0x85, 0x3c, 0x9d, 0xcf, 0xac, 0x96, 0x34, 0x90,
		0xcf, 0xac, 0x72, 0x24, 0xc9, 0xb0, 0x96, 0xea, 0x2d, 0xea, 0x4b, 0xfe, 0x6a, 0xa9, 0x5e, 0x72,
		0x0b, 0x29, 0xa2, 0xa9, 0xff, 0x67, 0x4d, 0x15, 0x28, 0x6b, 0x95, 0xea, 0xde, 0xef, 0xca, 0xb6,
		0x1b, 0x0a, 0x3f, 0x0a, 0x14, 0x1e, 0x61, 0x7d, 0x65, 0x1f, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a,
		0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0xea, 0x86, 0x71, 0x55, 0xd9, 0x16, 0x4a, 0x4b, 0xfd, 0x08, 0xca,
		0x57, 0x81, 0x56, 0x08, 0x3b, 0xb5, 0xf1, 0xad, 0xfa, 0xe8, 0x47, 0x80, 0x29, 0x75, 0x32, 0xa0,
		0xb5, 0xb3, 0xaf, 0xd5, 0xd3, 0xda, 0x71, 0xe3, 0xa2, 0xfe, 0xe5, 0xea, 0xa4, 0x71, 0x71, 0x52,
		0xbd, 0xac, 0x9f, 0xa1, 0x65, 0xd7, 0xd1, 0x42, 0xf0, 0x08, 0xf2, 0x31, 0x11, 0xe8, 0xca, 0xfe,
		0xd7, 0xa3, 0xfb, 0xc7, 0xe9, 0x97, 0xcb, 0xab, 0x93, 0x8b, 0xc6, 0x69, 0xbd, 0x7e, 0xee, 0xb0,
		0x71, 0xc3, 0xda, 0x8c, 0x6b, 0xf5, 0x92, 0x43, 0xba, 0x66, 0x43, 0x5a, 0xbf, 0xa8, 0xfd, 0x59,
		0x3b, 0xab, 0x5e, 0xd5, 0x2f, 0x38, 0xaa, 0x6b, 0x94, 0x80, 0xeb, 0x67, 0x9f, 0x4e, 0x8e, 0x1d,
		0xf6, 0x05, 0xf9, 0xc7, 0xd7, 0x0d, 0xe7, 0x23, 0x60, 0x56, 0x20, 0xa8, 0x83, 0x5d, 0x3f, 0xd2,
		0xee, 0x5d, 0xd0, 0x96, 0x1d, 0x29, 0xda, 0x78, 0xe2, 0xe0, 0xb4, 0x79, 0xd4, 0x06, 0x67, 0x99,
		0x43, 0x6d, 0x70, 0x01, 0x87, 0xa2, 0x36, 0xb8, 0x90, 0xa7, 0x53, 0x1b, 0x5c, 0xd2, 0x40, 0x6a,
		0x83, 0x39, 0xe2, 0xbe, 0xc0, 0xda, 0xa0, 0x96, 0x77, 0x42, 0xcb, 0xd6, 0x8f, 0xa8, 0x5c, 0x04,
		0xd4, 0x06, 0x81, 0x16, 0x12, 0x38, 0x5f, 0x54, 0xdc, 0x27, 0xd0, 0x51, 0xbe, 0x0a, 0x22, 0xd1,
		0x0a, 0x54, 0x1b, 0x6a, 0xbd, 0x2a, 0x3b, 0xde, 0xfe, 0xe6, 0x8d, 0x62, 0xc7, 0xdb, 0xb7, 0x9b,
		0xc7, 0x8e, 0xb7, 0xeb, 0xa8, 0xc7, 0xb0, 0xe3, 0xed, 0x0a, 0x42, 0xa2, 0x70, 0x50, 0x2c, 0x96,
		0x2b, 0xc5, 0xe2, 0x6e, 0x65, 0xbf, 0xb2, 0x7b, 0x58, 0x2a, 0x15, 0xca, 0x05, 0xf6, 0xbe, 0xcd,
		0x39, 0x7f, 0xc4, 0xb3, 0x86, 0xeb, 0x36, 0x60, 0xb2, 0xa8, 0xd3, 0xf3, 0xf5, 0x37, 0x57, 0x02,
		0xaa, 0x5b, 0x13, 0xc3, 0x40, 0x66, 0x3f, 0xc7, 0xa2, 0xe3, 0xf7, 0xbb, 0xa3, 0xa9, 0xea, 0x2e,
		0xb5, 0xb6, 0x99, 0xe6, 0x50, 0x6b, 0x5b, 0xc0, 0xbd, 0xa9, 0xb5, 0x2d, 0xe4, 0xe9, 0xd4, 0xda,
		0x96, 0x34, 0x90, 0x5a, 0x5b, 0x8e, 0xe6, 0x35, 0xdc, 0xb8, 0x69, 0x71, 0x14, 0xe4, 0xc6, 0x4d,
		0xff, 0xf6, 0xa2, 0x8c, 0xb5, 0x96, 0x73, 0x76, 0xca, 0x58, 0x79, 0x4f, 0xf7, 0xd3, 0x21, 0x41,
		0x19, 0x6b, 0xe9, 0x90, 0xe0, 0xc6, 0x4d, 0xeb, 0x42, 0xc8, 0xf0, 0xac, 0xa1, 0x78, 0x05, 0x93,
		0x3b, 0x9d, 0xf1, 0xe2, 0xc8, 0xa0, 0xaf, 0x05, 0x9e, 0x80, 0xf5, 0xd2, 0x38, 0x0a, 0x46, 0xb3,
		0xcc, 0xa1, 0x60, 0xb4, 0x80, 0x3b, 0x51, 0x30, 0x5a, 0xc8, 0xd3, 0x29, 0x18, 0x2d, 0x69, 0x20,
		0x05, 0xa3, 0x1c, 0xcd, 0x20, 0x80, 0x05, 0xa3, 0x66, 0x10, 0x74, 0x85, 0xaf, 0x10, 0x17, 0x6d,
		0x16, 0x48, 0xe5, 0x00, 0x2c, 0xb0, 0x1c, 0x42, 0x4e, 0x55, 0xa9, 0x40, 0xfb, 0xc3, 0xd9, 0x18,
		0x44, 0x00, 0x39, 0x51, 0xeb, 0x9b, 0xb8, 0xf3, 0x7b, 0xe3, 0xa6, 0x33, 0x5e, 0xd0, 0x13, 0xaa,
		0x35, 0x22, 0x4a, 0xae, 0x12, 0xfa, 0x67, 0x10, 0xfe, 0x70, 0xa5, 0x8a, 0xb4, 0xaf, 0x5a, 0xc2,
		0x7b, 0x7d, 0x22, 0x4a, 0x9d, 0xf1, 0x7a, 0x61, 0xa0, 0x83, 0x56, 0xd0, 0x8d, 0x92, 0x23, 0xaf,
		0x79, 0xdb, 0xf3, 0x42, 0xd9, 0xf4, 0xfc, 0x8e, 0x74, 0x23, 0xbf, 0x23, 0xa3, 0xe4, 0xc8, 0x1b,
		0x35, 0x67, 0x8e, 0x42, 0x2d, 0xdc, 0x5e, 0xd0, 0x95, 0xad, 0x47, 0x4f, 0x09, 0x79, 0xfb, 0xad,
		0x19, 0x84, 0x51, 0x72, 0xe4, 0xf9, 0xed, 0xef, 0x23, 0x34, 0x90, 0xca, 0xed, 0x05, 0x91, 0xf6,
		0x46, 0x0c, 0x37, 0x8a, 0x7f, 0xc4, 0x7d, 0x6e, 0xec, 0x82, 0x84, 0x3d, 0x6f, 0xb6, 0xe8, 0xc9,
		0x4e, 0x5f, 0xfd, 0x50, 0xc1, 0x4f, 0xe5, 0xfa, 0x5a, 0x87, 0xb2, 0x39, 0x1c, 0x11, 0xeb, 0xde,
		0xfc, 0xfc, 0xcc, 0x20, 0x6d, 0x9b, 0xe5, 0x98, 0x9f, 0x20, 0x80, 0x65, 0x33, 0x50, 0x26, 0x40,
		0x48, 0x13, 0x1f, 0xcc, 0x09, 0x0f, 0xda, 0x44, 0x07, 0x76, 0x82, 0x03, 0x3b, 0xb1, 0x81, 0x9d,
		0xd0, 0x6c, 0x36, 0xfb, 0x3a, 0x96, 0x21, 0x46, 0xda, 0x49, 0x81, 0x14, 0x9e, 0xa2, 0x98, 0x36,
		0x11, 0x4b, 0x57, 0x2c, 0x50, 0x57, 0x84, 0x87, 0x57, 0x6c, 0x98, 0x45, 0x85, 0x5b, 0x78, 0xd8,
		0x85, 0x87, 0x5f, 0x78, 0x18, 0xc6, 0x91, 0x63, 0xb6, 0x80, 0x74, 0x45, 0x14, 0x78, 0x4e, 0x0c,
		0x1a, 0x62, 0x9f, 0xab, 0xd1, 0xd4, 0xce, 0xa9, 0x8c, 0xfa, 0x6c, 0x22, 0x58, 0xe8, 0x61, 0x56,
		0x6f, 0xc0, 0xc1, 0x35, 0x32, 0x6c, 0xe7, 0x03, 0xbe, 0xd1, 0x61, 0x3c, 0x37, 0x70, 0x9e, 0x1b,
		0x58, 0xcf, 0x0d, 0xbc, 0x63, 0xc1, 0x3c, 0x18, 0xdc, 0x27, 0xa3, 0x78, 0x85, 0x08, 0xb0, 0x5b,
		0xd8, 0x7b, 0x17, 0xa4, 0x66, 0xc3, 0x15, 0xcc, 0x1d, 0x24, 0x27, 0x7b, 0x19, 0xc4, 0x5b, 0x12,
		0x3c, 0x93, 0x15, 0xd6, 0xfb, 0xa1, 0x87, 0xa6, 0x13, 0x3f, 0x5d, 0x83, 0x25, 0xbe, 0xb1, 0x79,
		0x98, 0xa4, 0xb7, 0x40, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0x64, 0x9d,
		0x3d, 0x8a, 0x68, 0x5a, 0x57, 0x62, 0xd8, 0x88, 0xa3, 0x75, 0x05, 0xf0, 0x52, 0xb9, 0x29, 0xe9,
		0x6b, 0x68, 0xe9, 0x7b, 0xae, 0x5f, 0x5a, 0x23, 0x52, 0x90, 0x07, 0x72, 0x90, 0x2f, 0x92, 0x90,
		0x17, 0xb2, 0x90, 0x3b, 0xd2, 0x90, 0x3b, 0xf2, 0x90, 0x3b, 0x12, 0x81, 0x49, 0x26, 0x40, 0x49,
		0x45, 0x32, 0xba, 0xb0, 0x8a, 0x5a, 0x2a, 0x6f, 0xf6, 0xa5, 0xd2, 0x85, 0x32, 0x72, 0xce, 0x1c,
		0xa3, 0x78, 0x19, 0xd8, 0x44, 0xcc, 0x0e, 0x10, 0xaf, 0x5f, 0xd8, 0x98, 0xb3, 0x85, 0xde, 0x21,
		0x22, 0x67, 0xf4, 0x32, 0x65, 0x2e, 0x78, 0x07, 0x89, 0x94, 0xbd, 0x39, 0x58, 0x35, 0x9f, 0x13,
		0x38, 0x9a, 0x0e, 0x31, 0xff, 0x81, 0x21, 0x96, 0x71, 0x88, 0x95, 0x4b, 0xa5, 0xfd, 0x12, 0xc3,
		0x6c, 0xb3, 0xb8, 0x28, 0xbe, 0x75, 0x37, 0xef, 0x78, 0xbf, 0x72, 0x9a, 0xc6, 0x81, 0x2b, 0xe1,
		0x52, 0x53, 0x0a, 0xd4, 0x8a, 0xb8, 0x9c, 0xa0, 0x0a, 0x75, 0xc1, 0x55, 0x3a, 0x23, 0x75, 0xc1,
		0x95, 0x46, 0x0e, 0x75, 0xc1, 0x8c, 0x0d, 0xa6, 0x2e, 0xb8, 0xc6, 0x13, 0xb1, 0x9c, 0xe9, 0x82,
		0x07, 0x39, 0x90, 0x05, 0x4b, 0x94, 0x05, 0x97, 0x7c, 0x51, 0x16, 0xa4, 0x66, 0x41, 0x59, 0x70,
		0x03, 0xd1, 0x68, 0x3a, 0xc4, 0x28, 0x0b, 0x66, 0x1e, 0x62, 0x7b, 0x25, 0x8a, 0x82, 0x1b, 0x46,
		0x44, 0xf1, 0xad, 0xa3, 0x28, 0x98, 0xdb, 0x24, 0x1e, 0x2b, 0x6d, 0xf7, 0xe3, 0xec, 0x92, 0x07,
		0x55, 0x30, 0xb6, 0x95, 0xb2, 0xe0, 0x5b, 0xcc, 0xa3, 0x2c, 0xb8, 0x42, 0x6f, 0xa4, 0x2c, 0xb8,
		0xd2, 0xc8, 0xa1, 0x2c, 0x98, 0xb1, 0xc1, 0x94, 0x05, 0xd7, 0x78, 0x22, 0x96, 0x23, 0x59, 0xb0,
		0x29, 0x95, 0x1f, 0x3e, 0xe6, 0x40, 0x17, 0x3c, 0x04, 0x36, 0xf1, 0x54, 0xa8, 0xdb, 0xd1, 0xc2,
		0x5c, 0x0a, 0x83, 0xcb, 0xaa, 0x16, 0x14, 0x06, 0x33, 0x57, 0x2d, 0x0a, 0xd4, 0x2c, 0x36, 0x0c,
		0x8f, 0xa6, 0x43, 0x8c, 0xc2, 0x60, 0xe6, 0x21, 0xc6, 0x7a, 0xc1, 0x0d, 0x24, 0xa3, 0xf8, 0xd6,
		0x51, 0x1a, 0xcc, 0x6d, 0x1a, 0x77, 0xc4, 0x83, 0x16, 0xaa, 0x2d, 0xda, 0xf8, 0xc2, 0x60, 0x62,
		0x29, 0x65, 0xc1, 0xb7, 0x98, 0x47, 0x59, 0x70, 0x85, 0xbe, 0x48, 0x59, 0x70, 0xa5, 0x91, 0x43,
		0x59, 0x30, 0x63, 0x83, 0x29, 0x0b, 0xae, 0xf1, 0x34, 0x2c, 0x4f, 0xb2, 0x20, 0xdc, 0xb6, 0x5f,
		0xf3, 0x60, 0x1c, 0x64, 0x1b, 0x30, 0x92, 0xda, 0xb7, 0x8c, 0x61, 0xd0, 0x1b, 0xce, 0x3c, 0xfd,
		0x2e, 0x3e, 0xa9, 0x4d, 0x2c, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25,
		0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x65, 0x50, 0x4c, 0x8f, 0x61, 0xcf, 0x0f, 0xb5, 0xcc,
		0x03, 0xa7, 0x9d, 0x18, 0x4a, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a,
		0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0xcb, 0xa0, 0x98, 0x1e, 0x43, 0x1d, 0xfa, 0x2a, 0x92, 0x5a,
		0xde, 0xe7, 0x60, 0x5d, 0xd2, 0x0b, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49,
		0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0x68, 0x88, 0x3a, 0x55, 0xa5,
		0x02, 0xed, 0x6b, 0x19, 0x60, 0x2e, 0x80, 0x72, 0xa2, 0xd6, 0x37, 0x71, 0xe7, 0xf7, 0xc6, 0x1b,
		0x50, 0x7a, 0x41, 0x4f, 0xa8, 0xd6, 0x88, 0x28, 0xba, 0x4a, 0xe8, 0x9f, 0x41, 0xf8, 0xc3, 0x95,
		0x2a, 0xd2, 0xbe, 0x6a, 0x09, 0xef, 0xf5, 0x89, 0x28, 0x75, 0xc6, 0xeb, 0x85, 0x81, 0x0e, 0x5a,
		0x41, 0x37, 0x4a, 0x8e, 0xbc, 0xe6, 0x6d, 0xcf, 0x0b, 0x65, 0xd3, 0xf3, 0x3b, 0xd2, 0x8d, 0xfc,
		0x8e, 0x8c, 0x92, 0x23, 0x4f, 0xf6, 0xee, 0xcb, 0x6e, 0x14, 0x6a, 0xe1, 0xf6, 0x82, 0xae, 0x6c,
		0x3d, 0x7a, 0x4a, 0xc8, 0xdb, 0x6f, 0xcd, 0x20, 0x8c, 0x92, 0x23, 0xcf, 0x6f, 0x7f, 0x1f, 0xa1,
		0x95, 0x54, 0x6e, 0x2f, 0x88, 0xb4, 0x17, 0x06, 0x7d, 0x2d, 0xa2, 0xf8, 0x87, 0xd7, 0x57, 0x3f,
		0x54, 0xf0, 0x53, 0xb9, 0xbe, 0xd6, 0xa1, 0x6c, 0x8e, 0xde, 0x48, 0x9d, 0x8a, 0x77, 0xd4, 0xe4,
		0x3e, 0x9a, 0xc8, 0x96, 0xa0, 0xec, 0xab, 0xff, 0x5f, 0xf1, 0x88, 0xd8, 0x18, 0xd7, 0x39, 0x95,
		0x91, 0xae, 0x6a, 0x0d, 0xb6, 0xe9, 0xff, 0x67, 0xa9, 0x4e, 0xba, 0x62, 0xc8, 0x2a, 0x23, 0xac,
		0x59, 0xa5, 0xf3, 0xd9, 0x7f, 0x78, 0x61, 0x59, 0xe1, 0xa0, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xdd,
		0xca, 0x7e, 0x65, 0xf7, 0xb0, 0x54, 0x2a, 0x94, 0x0b, 0x40, 0x8b, 0xb8, 0x9c, 0x7a, 0xd8, 0x16,
		0xa1, 0x68, 0x7f, 0x1c, 0xba, 0x9e, 0xea, 0x77, 0xbb, 0x8c, 0x48, 0x7c, 0xf8, 0x5c, 0x7f, 0xd8,
		0x74, 0xa0, 0x36, 0x58, 0x0e, 0xfb, 0x2d, 0xad, 0xc6, 0x53, 0x88, 0xb3, 0xf8, 0xee, 0xd5, 0xc6,
		0x37, 0xaf, 0x71, 0x3e, 0xbe, 0x65, 0x8d, 0x8f, 0xb7, 0xbd, 0xc6, 0x85, 0x6c, 0x36, 0xaa, 0x1d,
		0x79, 0xe9, 0x77, 0x64, 0xa3, 0xd6, 0xbb, 0x2f, 0x5f, 0x86, 0x5a, 0x9c, 0x8f, 0xee, 0x52, 0xe3,
		0x6c, 0x7c, 0x6f, 0x1a, 0xd5, 0xf6, 0xf7, 0x0b, 0xd9, 0xac, 0xa9, 0xf3, 0x20, 0xd2, 0x8d, 0x8b,
		0xe1, 0x1d, 0x69, 0x7c, 0x89, 0xff, 0xfc, 0x6a, 0xf2, 0xd7, 0xbf, 0x23, 0x38, 0xdb, 0xb7, 0xc0,
		0x72, 0x12, 0x42, 0x4b, 0x3e, 0xeb, 0x96, 0x74, 0xec, 0x06, 0x99, 0x3d, 0xd7, 0xb6, 0x73, 0x65,
		0x4b, 0xc1, 0x34, 0xe1, 0xd4, 0x43, 0xaf, 0x75, 0x65, 0x7b, 0x4b, 0xa8, 0x76, 0x2f, 0x90, 0x4a,
		0x6f, 0xb5, 0x82, 0x6e, 0x10, 0x5a, 0x42, 0x19, 0x0c, 0x42, 0x8d, 0x43, 0xa0, 0xa1, 0x09, 0x33,
		0x06, 0x41, 0xb6, 0x15, 0x3e, 0x20, 0x18, 0x94, 0x6b, 0xec, 0xb1, 0xc8, 0x65, 0xb3, 0xe7, 0xae,
		0x76, 0x50, 0xd4, 0x3c, 0x86, 0x99, 0xbd, 0xa2, 0xe1, 0x70, 0xb7, 0x1d, 0xe6, 0x39, 0x0d, 0x6f,
		0xb3, 0xbe, 0x6f, 0xce, 0x03, 0xcd, 0x5c, 0xc9, 0x90, 0x8f, 0xdb, 0xf2, 0xed, 0xbc, 0xf9, 0xb4,
		0x41, 0x94, 0xca, 0x12, 0x95, 0xcc, 0xc4, 0x64, 0xf6, 0x11, 0x62, 0x20, 0x3a, 0x9c, 0x97, 0x1e,
		0x10, 0x9a, 0x7b, 0x82, 0xff, 0xdc, 0xeb, 0x7b, 0xfa, 0xfa, 0x86, 0xf2, 0xc1, 0xe4, 0x01, 0xbb,
		0xa1, 0xcb, 0x99, 0xae, 0x7b, 0xb3, 0x51, 0xc7, 0x66, 0xb7, 0x2e, 0xcd, 0x56, 0x9d, 0x99, 0xf5,
		0xba, 0x31, 0xeb, 0x75, 0x60, 0xd6, 0xeb, 0xba, 0xd6, 0x8b, 0xa9, 0x1c, 0x4b, 0xb3, 0x8a, 0x90,
		0x33, 0xa6, 0xb1, 0xc6, 0x03, 0x67, 0x92, 0x2e, 0xc6, 0xd7, 0x37, 0xec, 0xb4, 0x66, 0x01, 0xc0,
		0x1a, 0x10, 0xd8, 0x04, 0x04, 0x0c, 0x60, 0xb0, 0x0d, 0x10, 0x30, 0x40, 0x01, 0x03, 0x18, 0x30,
		0xc0, 0xb1, 0x19, 0xb2, 0x8e, 0x69, 0x40, 0x99, 0x06, 0x16, 0x7b, 0xf1, 0x36, 0x85, 0x2f, 0xb6,
		0x62, 0xcd, 0x0e, 0xcc, 0x58, 0x87, 0x1b, 0x04, 0xd8, 0xc1, 0x82, 0x1f, 0x14, 0x18, 0x82, 0x83,
		0x23, 0x38, 0x58, 0x82, 0x83, 0x27, 0x3b, 0x30, 0x65, 0x09, 0xae, 0xac, 0xc3, 0x56, 0x62, 0x40,
		0x5c, 0x1c, 0x60, 0x3d, 0x4e, 0x27, 0xd9, 0xcb, 0x66, 0xad, 0xc2, 0x6b, 0x38, 0xb3, 0x5c, 0x67,
		0x0b, 0xb3, 0x8c, 0x14, 0x69, 0xb9, 0x28, 0xe6, 0xb2, 0x50, 0xb4, 0xe5, 0x9f, 0xb0, 0xcb, 0x3c,
		0x61, 0x97, 0x73, 0xc2, 0x2e, 0xdb, 0xdc, 0xec, 0xba, 0x50, 0x98, 0xe5, 0x96, 0x49, 0xde, 0xe9,
		0x0a, 0xbf, 0x13, 0x8a, 0x0e, 0x42, 0xd2, 0x99, 0xcc, 0xba, 0x2a, 0x00, 0xb6, 0x9c, 0x8f, 0x9f,
		0xfd, 0x7e, 0xf8, 0x10, 0xaf, 0x02, 0xf3, 0x62, 0x20, 0xdf, 0xd4, 0xba, 0x53, 0x8b, 0x33, 0xaf,
		0x49, 0xd9, 0x27, 0x0e, 0xa7, 0x4b, 0x2c, 0x22, 0xad, 0x23, 0xad, 0x23, 0xad, 0x23, 0xad, 0x23,
		0xad, 0x23, 0xad, 0x23, 0xad, 0xcb, 0x25, 0xad, 0x4b, 0xb0, 0x9c, 0xcc, 0xce, 0xf8, 0x60, 0x8c,
		0x17, 0xf6, 0xe0, 0x10, 0xbb, 0x89, 0x41, 0xe4, 0x75, 0xe4, 0x75, 0xe4, 0x75, 0xe4, 0x75, 0xe4,
		0x75, 0xe4, 0x75, 0xe4, 0x75, 0xb9, 0xe4, 0x75, 0x13, 0x28, 0x27, 0xad, 0x33, 0x3e, 0x16, 0x71,
		0xd7, 0x2c, 0x18, 0x52, 0x17, 0x9b, 0x83, 0x41, 0xe9, 0x0a, 0xa4, 0x74, 0xa4, 0x74, 0xa4, 0x74,
		0xa4, 0x74, 0xa4, 0x74, 0xb6, 0x46, 0xc5, 0x76, 0x81, 0x52, 0x62, 0xc8, 0xa8, 0x55, 0xa0, 0x54,
		0x6d, 0x81, 0xd3, 0xb7, 0xfc, 0x79, 0x75, 0xdf, 0xb3, 0x6d, 0x28, 0xfd, 0x15, 0xa1, 0x3a, 0xe4,
		0xc3, 0x75, 0xc4, 0x47, 0xec, 0x80, 0x8f, 0xdd, 0xf1, 0x1e, 0xb5, 0xc3, 0x3d, 0x7c, 0x47, 0x7b,
		0xf8, 0x0e, 0xf6, 0xf0, 0x1d, 0xeb, 0xd9, 0x39, 0x17, 0x52, 0x63, 0x01, 0xd6, 0x5a, 0x10, 0x35,
		0x97, 0x59, 0xda, 0xcb, 0x3f, 0xfc, 0x1b, 0x51, 0x8a, 0x48, 0xe8, 0x28, 0x39, 0x1a, 0x2b, 0x35,
		0x31, 0xcd, 0x60, 0xd7, 0x4c, 0x94, 0xa0, 0x04, 0xa9, 0xa0, 0x4f, 0x45, 0x23, 0x42, 0x25, 0x3d,
		0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0xa8, 0xf1, 0xbc, 0xd5, 0x97,
		0x4a, 0xef, 0xef, 0x01, 0xb2, 0x51, 0x24, 0x32, 0x7a, 0xe1, 0xab, 0xdb, 0xe1, 0xdd, 0xba, 0x86,
		0xca, 0x01, 0x80, 0xbb, 0xf7, 0x7c, 0x96, 0x0a, 0x77, 0xe7, 0x4e, 0xf0, 0xfd, 0x30, 0xbf, 0xfa,
		0xdd, 0xbe, 0x00, 0xb6, 0xef, 0x53, 0xe8, 0xb7, 0xb4, 0x0c, 0xd4, 0xb1, 0xbc, 0x95, 0x71, 0x83,
		0x68, 0xee, 0x69, 0xfb, 0x3b, 0x21, 0xe1, 0x3f, 0x30, 0x24, 0x96, 0x0c, 0x89, 0xe2, 0xde, 0x61,
		0xf1, 0xb0, 0x5c, 0xd9, 0x3b, 0x2c, 0x31, 0x36, 0xf2, 0x4d, 0xc8, 0xf0, 0xac, 0xb9, 0xa1, 0x48,
		0x84, 0x92, 0x3b, 0x9d, 0x56, 0x70, 0x77, 0xd7, 0x57, 0x52, 0x3f, 0xa2, 0x3e, 0xc2, 0x7c, 0x6d,
		0x20, 0x85, 0xa3, 0x59, 0xe6, 0x50, 0x38, 0x5a, 0xc0, 0xa5, 0x28, 0x1c, 0x2d, 0xe4, 0xe9, 0x14,
		0x8e, 0x96, 0x34, 0x90, 0xc2, 0x51, 0x8e, 0x66, 0x12, 0x7c, 0x8e, 0xf9, 0x06, 0x18, 0xcc, 0xe1,
		0x73, 0xcc, 0x09, 0xaf, 0x90, 0x22, 0x4a, 0x8e, 0x1f, 0xf9, 0x28, 0x13, 0x93, 0xa5, 0xc2, 0xf4,
		0x8e, 0x48, 0xc5, 0x24, 0x48, 0x0f, 0x09, 0xf2, 0x52, 0xf2, 0x52, 0xf2, 0x52, 0xf2, 0x52, 0xf2,
		0x52, 0xf2, 0x52, 0xe3, 0x79, 0x4b, 0xf6, 0x5c, 0xbf, 0xdd, 0x0e, 0x45, 0x14, 0x21, 0x52, 0xd3,
		0x43, 0x20, 0x9b, 0xc6, 0x63, 0xc8, 0x87, 0x9a, 0xbf, 0xed, 0x59, 0xf7, 0x45, 0x40, 0xdf, 0x4a,
		0xf9, 0xd8, 0x01, 0xa0, 0x6d, 0xe7, 0xbe, 0xd6, 0x22, 0x54, 0x70, 0xee, 0x96, 0x18, 0xf8, 0xf7,
		0xf6, 0xf6, 0xf5, 0xae, 0x7b, 0x78, 0xf3, 0x74, 0x5d, 0x70, 0x0f, 0x6f, 0xe2, 0xc3, 0xc2, 0xe8,
		0x47, 0x7c, 0xbc, 0x77, 0xbd, 0xeb, 0x16, 0x27, 0xc7, 0xa5, 0xeb, 0x5d, 0xb7, 0x74, 0xb3, 0xf3,
		0xd7, 0x5f, 0x1f, 0x76, 0x7e, 0xed, 0x0f, 0x16, 0xff, 0xe2, 0x7f, 0x1c, 0xb8, 0x9b, 0x70, 0x83,
		0xe8, 0x34, 0xf5, 0xcb, 0xda, 0xff, 0xe8, 0x39, 0xe8, 0x9e, 0x83, 0xf5, 0x60, 0xf1, 0x3d, 0xe1,
		0xec, 0xb7, 0xe1, 0xac, 0x4c, 0x38, 0x5b, 0x6f, 0x38, 0xf3, 0xdd, 0x4e, 0xd5, 0xfd, 0x74, 0xf3,
		0xab, 0xf0, 0xbe, 0x38, 0x38, 0xda, 0xf9, 0x55, 0x19, 0xbc, 0x3e, 0xf9, 0x34, 0xeb, 0x63, 0x85,
		0xf7, 0x95, 0xc1, 0xd1, 0x9c, 0x77, 0xca, 0x83, 0xa3, 0xdf, 0xfc, 0x1d, 0xa5, 0xc1, 0x76, 0xea,
		0xa3, 0xc3, 0xf3, 0x7b, 0xf3, 0xbe, 0x50, 0x9c, 0xf3, 0x85, 0xfd, 0x79, 0x5f, 0xd8, 0x9f, 0xf3,
		0x85, 0xb9, 0x26, 0xed, 0xcd, 0xf9, 0x42, 0x69, 0xf0, 0x94, 0xfa, 0xfc, 0xf6, 0xec, 0x8f, 0x96,
		0x07, 0x3b, 0x4f, 0xf3, 0xde, 0xab, 0x0c, 0x9e, 0x8e, 0x76, 0x08, 0xee, 0x6b, 0x08, 0xee, 0x8c,
		0x23, 0xc6, 0x11, 0x1e, 0xd5, 0x61, 0x0d, 0x15, 0xd8, 0xfd, 0x80, 0x78, 0x3a, 0xf5, 0xa0, 0x5d,
		0xf8, 0x3a, 0xaa, 0x59, 0x46, 0xf2, 0x99, 0xd5, 0x2c, 0x73, 0xf8, 0xcc, 0x6a, 0x01, 0xb7, 0xe2,
		0x33, 0xab, 0x85, 0x3c, 0x9d, 0xcf, 0xac, 0x96, 0x34, 0x90, 0xcf, 0xac, 0x72, 0x24, 0xc9, 0xb0,
		0x96, 0xea, 0x2d, 0xea, 0x4b, 0xfe, 0x6a, 0xa9, 0x5e, 0x72, 0x0b, 0x29, 0xa2, 0xa9, 0xff, 0x67,
		0x4d, 0x15, 0x28, 0x6b, 0x95, 0xea, 0xde, 0xef, 0xca, 0xb6, 0x1b, 0x0a, 0x3f, 0x0a, 0x14, 0x1e,
		0x61, 0x7d, 0x65, 0x1f, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0xea,
		0x86, 0x71, 0x55, 0xd9, 0x16, 0x4a, 0x4b, 0xfd, 0x08, 0xca, 0x57, 0x81, 0x56, 0x08, 0x3b, 0xb5,
		0xf1, 0xad, 0xfa, 0xe8, 0x47, 0x80, 0x29, 0x75, 0x32, 0xa0, 0xb5, 0xb3, 0xaf, 0xd5, 0xd3, 0xda,
		0x71, 0xe3, 0xa2, 0xfe, 0xe5, 0xea, 0xa4, 0x71, 0x71, 0x52, 0xbd, 0xac, 0x9f, 0xa1, 0x65, 0xd7,
		0xd1, 0x42, 0xf0, 0x08, 0xf2, 0x31, 0x11, 0xe8, 0xca, 0xfe, 0xd7, 0xa3, 0xfb, 0xc7, 0xe9, 0x97,
		0xcb, 0xab, 0x93, 0x8b, 0xc6, 0x69, 0xbd, 0x7e, 0xee, 0xb0, 0x71, 0xc3, 0xda, 0x8c, 0x6b, 0xf5,
		0x92, 0x43, 0xba, 0x66, 0x43, 0x5a, 0xbf, 0xa8, 0xfd, 0x59, 0x3b, 0xab, 0x5e, 0xd5, 0x2f, 0x38,
		0xaa, 0x6b, 0x94, 0x80, 0xeb, 0x67, 0x9f, 0x4e, 0x8e, 0x1d, 0xf6, 0x05, 0xf9, 0xc7, 0xd7, 0x0d,
		0xe7, 0x23, 0x60, 0x56, 0x20, 0xa8, 0x83, 0x5d, 0x3f, 0xd2, 0xee, 0x5d, 0xd0, 0x96, 0x1d, 0x29,
		0xda, 0x78, 0xe2, 0xe0, 0xb4, 0x79, 0xd4, 0x06, 0x67, 0x99, 0x43, 0x6d, 0x70, 0x01, 0x87, 0xa2,
		0x36, 0xb8, 0x90, 0xa7, 0x53, 0x1b, 0x5c, 0xd2, 0x40, 0x6a, 0x83, 0x39, 0xe2, 0xbe, 0xc0, 0xda,
		0xa0, 0x96, 0x77, 0x42, 0xcb, 0xd6, 0x8f, 0xa8, 0x5c, 0x04, 0xd4, 0x06, 0x81, 0x16, 0x12, 0x38,
		0x5f, 0x54, 0xdc, 0x27, 0xd0, 0x51, 0xbe, 0x0a, 0x22, 0xd1, 0x0a, 0x54, 0x1b, 0x6a, 0xbd, 0x2a,
		0x3b, 0xde, 0xfe, 0xe6, 0x8d, 0x62, 0xc7, 0xdb, 0xb7, 0x9b, 0xc7, 0x8e, 0xb7, 0xeb, 0xa8, 0xc7,
		0xb0, 0xe3, 0xed, 0x0a, 0x42, 0xa2, 0x70, 0x50, 0x2c, 0x96, 0x2b, 0xc5, 0xe2, 0x6e, 0x65, 0xbf,
		0xb2, 0x7b, 0x58, 0x2a, 0x15, 0xca, 0x05, 0xf6, 0xbe, 0xcd, 0x39, 0x7f, 0xc4, 0xb3, 0x86, 0xeb,
		0x36, 0x60, 0xb2, 0xa8, 0x33, 0xd9, 0x5b, 0x1c, 0x4e, 0xdd, 0x9a, 0x18, 0x06, 0x32, 0xfb, 0x39,
		0x16, 0x1d, 0xbf, 0xdf, 0x1d, 0x4d, 0x55, 0x77, 0xa9, 0xb5, 0xcd, 0x34, 0x87, 0x5a, 0xdb, 0x02,
		0xee, 0x4d, 0xad, 0x6d, 0x21, 0x4f, 0xa7, 0xd6, 0xb6, 0xa4, 0x81, 0xd4, 0xda, 0x72, 0x34, 0xaf,
		0xe1, 0xc6, 0x4d, 0x8b, 0xa3, 0x20, 0x37, 0x6e, 0xfa, 0xb7, 0x17, 0x65, 0xac, 0xb5, 0x9c, 0xb3,
		0x53, 0xc6, 0xca, 0x7b, 0xba, 0x9f, 0x0e, 0x09, 0xca, 0x58, 0x4b, 0x87, 0x04, 0x37, 0x6e, 0x5a,
		0x17, 0x42, 0x86, 0x67, 0x0d, 0xc5, 0x2b, 0x98, 0xdc, 0xe9, 0x8c, 0x17, 0x47, 0x06, 0x7d, 0x2d,
		0xf0, 0x04, 0xac, 0x97, 0xc6, 0x51, 0x30, 0x9a, 0x65, 0x0e, 0x05, 0xa3, 0x05, 0xdc, 0x89, 0x82,
		0xd1, 0x42, 0x9e, 0x4e, 0xc1, 0x68, 0x49, 0x03, 0x29, 0x18, 0xe5, 0x68, 0x06, 0x01, 0x2c, 0x18,
		0x35, 0x83, 0xa0, 0x2b, 0x7c, 0x85, 0xb8, 0x68, 0xb3, 0x40, 0x2a, 0x07, 0x60, 0x81, 0xe5, 0x10,
		0x72, 0xaa, 0x4a, 0x05, 0xda, 0x1f, 0xce, 0xc6, 0x20, 0x02, 0xc8, 0x89, 0x5a, 0xdf, 0xc4, 0x9d,
		0xdf, 0x1b, 0x37, 0x9d, 0xf1, 0x82, 0x9e, 0x50, 0xad, 0x11, 0x51, 0x72, 0x95, 0xd0, 0x3f, 0x83,
		0xf0, 0x87, 0x2b, 0x55, 0xa4, 0x7d, 0xd5, 0x12, 0xde, 0xeb, 0x13, 0x51, 0xea, 0x8c, 0xd7, 0x0b,
		0x03, 0x1d, 0xb4, 0x82, 0x6e, 0x94, 0x1c, 0x79, 0xcd, 0xdb, 0x9e, 0x17, 0xca, 0xa6, 0xe7, 0x77,
		0xa4, 0x1b, 0xf9, 0x1d, 0x19, 0x25, 0x47, 0xde, 0xa8, 0x39, 0x73, 0x14, 0x6a, 0xe1, 0xf6, 0x82,
		0xae, 0x6c, 0x3d, 0x7a, 0x4a, 0xc8, 0xdb, 0x6f, 0xcd, 0x20, 0x8c, 0x92, 0x23, 0xcf, 0x6f, 0x7f,
		0x1f, 0xa1, 0x81, 0x54, 0x6e, 0x2f, 0x14, 0xde, 0x88, 0xe0, 0x46, 0xf1, 0x8f, 0xb8, 0xcd, 0x8d,
		0x5d, 0x8c, 0xb0, 0xe7, 0xcc, 0x16, 0x1d, 0xd9, 0xe9, 0xab, 0x1f, 0x2a, 0xf8, 0xa9, 0x5c, 0x5f,
		0xeb, 0x50, 0x36, 0x87, 0x23, 0x62, 0xdd, 0x99, 0x9f, 0x1f, 0x19, 0xa4, 0x6d, 0xb3, 0x1c, 0xf2,
		0x13, 0x00, 0xb0, 0x6c, 0x06, 0xca, 0xfc, 0x07, 0x69, 0xde, 0x83, 0x39, 0xdf, 0x41, 0x9b, 0xe7,
		0xc0, 0xce, 0x6f, 0x60, 0xe7, 0x35, 0xb0, 0xf3, 0x99, 0xcd, 0x26, 0x5f, 0xc7, 0x32, 0xc4, 0x48,
		0x3b, 0x29, 0x90, 0xc2, 0x13, 0x14, 0xd3, 0x26, 0x62, 0xc9, 0x8a, 0x05, 0xca, 0x8a, 0xf0, 0xf0,
		0x8a, 0x0d, 0xb3, 0xa8, 0x70, 0x0b, 0x0f, 0xbb, 0xf0, 0xf0, 0x0b, 0x0f, 0xc3, 0x38, 0x6a, 0xcc,
		0x16, 0x90, 0xac, 0x88, 0x02, 0xcf, 0x89, 0x41, 0x43, 0xec, 0x73, 0x35, 0x9a, 0xd8, 0x39, 0x95,
		0x51, 0x9f, 0x4d, 0x04, 0x0b, 0x3d, 0xcc, 0xe2, 0x0d, 0x38, 0xb8, 0x46, 0x86, 0xed, 0x7c, 0xc0,
		0x37, 0x3a, 0x8c, 0xe7, 0x06, 0xce, 0x73, 0x03, 0xeb, 0xb9, 0x81, 0x77, 0x2c, 0x98, 0x07, 0x83,
		0xfb, 0x64, 0x14, 0xaf, 0x10, 0x01, 0x76, 0x0b, 0x7b, 0xeb, 0x82, 0xd4, 0x6c, 0xb8, 0x82, 0xb9,
		0x81, 0xe4, 0x64, 0x2b, 0x83, 0x78, 0x47, 0x82, 0x67, 0xb2, 0xc2, 0x72, 0x3f, 0xf4, 0xd0, 0x74,
		0xe2, 0xa7, 0x6b, 0xb0, 0xc4, 0x37, 0x36, 0x0f, 0x93, 0xf4, 0x16, 0x48, 0x7a, 0x49, 0x7a, 0x49,
		0x7a, 0x49, 0x7a, 0x49, 0x7a, 0x89, 0xac, 0xb3, 0x47, 0x11, 0x4d, 0xeb, 0x4a, 0x0c, 0x1b, 0x71,
		0xb4, 0xae, 0x00, 0x5e, 0x29, 0x37, 0x25, 0x7d, 0x0d, 0x2d, 0x7d, 0xcf, 0xe5, 0x4b, 0x6b, 0x44,
		0x0a, 0xf2, 0x40, 0x0e, 0xf2, 0x45, 0x12, 0xf2, 0x42, 0x16, 0x72, 0x47, 0x1a, 0x72, 0x47, 0x1e,
		0x72, 0x47, 0x22, 0x30, 0xc9, 0x04, 0x28, 0xa9, 0x48, 0x46, 0x17, 0x56, 0x51, 0x4b, 0xe5, 0xcd,
		0xbe, 0x54, 0xba, 0x50, 0x46, 0xce, 0x99, 0x63, 0x14, 0x2f, 0x03, 0x9b, 0x88, 0xd9, 0x00, 0xe2,
		0xf5, 0x0b, 0x1b, 0x73, 0xb6, 0xd0, 0x1b, 0x44, 0xe4, 0x8c, 0x5e, 0xa6, 0xcc, 0x05, 0x6f, 0x20,
		0x91, 0xb2, 0x37, 0x07, 0x8b, 0xe6, 0x73, 0x02, 0x47, 0xd3, 0x21, 0xe6, 0x3f, 0x30, 0xc4, 0x32,
		0x0e, 0xb1, 0x72, 0xa9, 0xb4, 0x5f, 0x62, 0x98, 0x6d, 0x16, 0x17, 0xc5, 0xb7, 0xee, 0xe6, 0x1d,
		0xef, 0x57, 0x4e, 0xd3, 0x38, 0x70, 0x25, 0x5c, 0x6a, 0x4a, 0x81, 0x5a, 0x11, 0x97, 0x13, 0x54,
		0xa1, 0x2e, 0xb8, 0x4a, 0x67, 0xa4, 0x2e, 0xb8, 0xd2, 0xc8, 0xa1, 0x2e, 0x98, 0xb1, 0xc1, 0xd4,
		0x05, 0xd7, 0x78, 0x22, 0x96, 0x33, 0x5d, 0xf0, 0x20, 0x07, 0xb2, 0x60, 0x89, 0xb2, 0xe0, 0x92,
		0x2f, 0xca, 0x82, 0xd4, 0x2c, 0x28, 0x0b, 0x6e, 0x20, 0x1a, 0x4d, 0x87, 0x18, 0x65, 0xc1, 0xcc,
		0x43, 0x6c, 0xaf, 0x44, 0x51, 0x70, 0xc3, 0x88, 0x28, 0xbe, 0x75, 0x14, 0x05, 0x73, 0x9b, 0xc4,
		0x63, 0xa5, 0xed, 0x7e, 0x9c, 0x5d, 0xf2, 0xa0, 0x0a, 0xc6, 0xb6, 0x52, 0x16, 0x7c, 0x8b, 0x79,
		0x94, 0x05, 0x57, 0xe8, 0x8d, 0x94, 0x05, 0x57, 0x1a, 0x39, 0x94, 0x05, 0x33, 0x36, 0x98, 0xb2,
		0xe0, 0x1a, 0x4f, 0xc4, 0x72, 0x24, 0x0b, 0x36, 0xa5, 0xf2, 0xc3, 0xc7, 0x1c, 0xe8, 0x82, 0x87,
		0xc0, 0x26, 0x9e, 0x0a, 0x75, 0x3b, 0x5a, 0x98, 0x4b, 0x61, 0x70, 0x59, 0xd5, 0x82, 0xc2, 0x60,
		0xe6, 0xaa, 0x45, 0x81, 0x9a, 0xc5, 0x86, 0xe1, 0xd1, 0x74, 0x88, 0x51, 0x18, 0xcc, 0x3c, 0xc4,
		0x58, 0x2f, 0xb8, 0x81, 0x64, 0x14, 0xdf, 0x3a, 0x4a, 0x83, 0xb9, 0x4d, 0xe3, 0x8e, 0x78, 0xd0,
		0x42, 0xb5, 0x45, 0x1b, 0x5f, 0x18, 0x4c, 0x2c, 0xa5, 0x2c, 0xf8, 0x16, 0xf3, 0x28, 0x0b, 0xae,
		0xd0, 0x17, 0x29, 0x0b, 0xae, 0x34, 0x72, 0x28, 0x0b, 0x66, 0x6c, 0x30, 0x65, 0xc1, 0x35, 0x9e,
		0x86, 0xe5, 0x49, 0x16, 0x84, 0xdb, 0xf5, 0x6b, 0x1e, 0x8c, 0x83, 0xec, 0x02, 0x46, 0x52, 0xfb,
		0x96, 0x31, 0x0c, 0x7a, 0xc3, 0x99, 0xa7, 0xdf, 0xc5, 0x27, 0xb5, 0x89, 0xa5, 0x24, 0xb5, 0x24,
		0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x24, 0xb5, 0x0c,
		0x8a, 0xe9, 0x31, 0xec, 0xf9, 0xa1, 0x96, 0x79, 0xe0, 0xb4, 0x13, 0x43, 0x49, 0x69, 0x49, 0x69,
		0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x19, 0x14,
		0xd3, 0x63, 0xa8, 0x43, 0x5f, 0x45, 0x52, 0xcb, 0xfb, 0x1c, 0xac, 0x4b, 0x7a, 0x61, 0x2b, 0x89,
		0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89,
		0x2d, 0x2d, 0x02, 0x0d, 0x51, 0xa7, 0xaa, 0x54, 0xa0, 0x7d, 0x2d, 0x03, 0xcc, 0x05, 0x50, 0x4e,
		0xd4, 0xfa, 0x26, 0xee, 0xfc, 0xde, 0x78, 0x03, 0x4a, 0x2f, 0xe8, 0x09, 0xd5, 0x1a, 0x11, 0x45,
		0x57, 0x09, 0xfd, 0x33, 0x08, 0x7f, 0xb8, 0x52, 0x45, 0xda, 0x57, 0x2d, 0xe1, 0xbd, 0x3e, 0x11,
		0xa5, 0xce, 0x78, 0xbd, 0x30, 0xd0, 0x41, 0x2b, 0xe8, 0x46, 0xc9, 0x91, 0xd7, 0xbc, 0xed, 0x79,
		0xa1, 0x6c, 0x7a, 0x7e, 0x47, 0xba, 0x91, 0xdf, 0x91, 0x51, 0x72, 0xe4, 0xc9, 0xde, 0x7d, 0xd9,
		0x8d, 0x42, 0x2d, 0xdc, 0x5e, 0xd0, 0x95, 0xad, 0x47, 0x4f, 0x09, 0x79, 0xfb, 0xad, 0x19, 0x84,
		0x51, 0x72, 0xe4, 0xf9, 0xed, 0xef, 0x23, 0xb4, 0x92, 0xca, 0xed, 0x85, 0xc2, 0x0b, 0x83, 0xbe,
		0x16, 0x51, 0xfc, 0xc3, 0xeb, 0xab, 0x1f, 0x2a, 0xf8, 0xa9, 0x5c, 0x5f, 0xeb, 0x50, 0x36, 0x47,
		0x6f, 0xa4, 0x4e, 0xc5, 0x1b, 0x6a, 0x72, 0x1b, 0x4d, 0x64, 0x4b, 0x50, 0xb6, 0xd5, 0xff, 0xaf,
		0x78, 0x44, 0xec, 0x8b, 0xeb, 0x9c, 0xca, 0x48, 0x57, 0xb5, 0x06, 0xdb, 0xf3, 0xff, 0xb3, 0x54,
		0x27, 0x5d, 0x31, 0x24, 0x95, 0x11, 0xd6, 0xa4, 0xd2, 0xf9, 0xec, 0x3f, 0xbc, 0xb0, 0xac, 0x70,
		0x50, 0x2c, 0x96, 0x2b, 0xc5, 0xe2, 0x6e, 0x65, 0xbf, 0xb2, 0x7b, 0x58, 0x2a, 0x15, 0xca, 0x05,
		0xa0, 0x35, 0x5c, 0x4e, 0x3d, 0x6c, 0x8b, 0x50, 0xb4, 0x3f, 0x0e, 0x5d, 0x4f, 0xf5, 0xbb, 0x5d,
		0x46, 0x24, 0x3e, 0x7a, 0xae, 0x3d, 0x6a, 0x3a, 0x50, 0xdb, 0x2b, 0x87, 0xfd, 0x96, 0x56, 0xe3,
		0x09, 0xc4, 0x59, 0x7c, 0xf3, 0x6a, 0xe3, 0x7b, 0xd7, 0x38, 0x1f, 0xdf, 0xb1, 0xc6, 0xc7, 0xdb,
		0x5e, 0xe3, 0x42, 0x36, 0x1b, 0xd5, 0x8e, 0xbc, 0xf4, 0x3b, 0xb2, 0x51, 0xeb, 0xdd, 0x97, 0x2f,
		0x43, 0x2d, 0xce, 0x47, 0x37, 0xa9, 0x71, 0x36, 0xbe, 0x35, 0x8d, 0x6a, 0xfb, 0xfb, 0x85, 0x6c,
		0xd6, 0xd4, 0x79, 0x28, 0x1a, 0x17, 0xc3, 0x1b, 0xd2, 0xf8, 0x12, 0xff, 0xf5, 0xd5, 0xe4, 0x8f,
		0x7f, 0x47, 0x68, 0xb6, 0x6f, 0x81, 0xe5, 0x14, 0x84, 0x96, 0x7a, 0xd6, 0x2c, 0xe5, 0xd8, 0x8d,
		0x31, 0x7b, 0x9e, 0x6d, 0xe7, 0xca, 0x96, 0x62, 0x69, 0x42, 0xa8, 0x87, 0x4e, 0xeb, 0xca, 0xf6,
		0x96, 0x50, 0xed, 0x5e, 0x20, 0x95, 0xde, 0x6a, 0x05, 0xdd, 0x20, 0xb4, 0x84, 0x31, 0x18, 0x6c,
		0x1a, 0x87, 0x3d, 0x43, 0xb3, 0x65, 0x0c, 0x76, 0x6c, 0x2b, 0x7c, 0x40, 0x20, 0x28, 0xcf, 0xd0,
		0x63, 0x91, 0xc8, 0x66, 0x4e, 0x5c, 0xed, 0x60, 0xa8, 0x79, 0x04, 0x33, 0x7b, 0x45, 0xc3, 0xc1,
		0x6e, 0x3b, 0xc8, 0xf3, 0x19, 0xdc, 0x66, 0x5d, 0xdf, 0x9c, 0x03, 0x9a, 0xb9, 0x92, 0x21, 0x17,
		0xb7, 0xe5, 0xda, 0x39, 0x73, 0x69, 0x83, 0x10, 0x95, 0x21, 0x24, 0x99, 0x89, 0xc8, 0xec, 0xe3,
		0xc3, 0x40, 0x6c, 0x38, 0x93, 0xf1, 0x0f, 0xfa, 0xda, 0xed, 0x05, 0x91, 0x36, 0x16, 0x1d, 0xcf,
		0x4d, 0xbe, 0x5f, 0x5b, 0x60, 0x28, 0x23, 0x4c, 0x9e, 0xad, 0x1b, 0xba, 0x9c, 0xe9, 0x92, 0x37,
		0x1b, 0x25, 0x6c, 0x76, 0x4b, 0xd2, 0x6c, 0x95, 0x98, 0x59, 0x2f, 0x19, 0xb3, 0x5e, 0x02, 0x66,
		0xbd, 0xa4, 0x6b, 0xbd, 0xb8, 0xca, 0xb1, 0x34, 0x2b, 0x08, 0x39, 0x63, 0x22, 0x6b, 0x3c, 0x70,
		0x26, 0xe9, 0x62, 0x7c, 0x7d, 0xc3, 0x4e, 0x6b, 0x16, 0x00, 0xac, 0x01, 0x81, 0x4d, 0x40, 0xc0,
		0x00, 0x06, 0xdb, 0x00, 0x01, 0x03, 0x14, 0x30, 0x80, 0x01, 0x03, 0x1c, 0x9b, 0xa1, 0xeb, 0x98,
		0x06, 0x94, 0x69, 0x60, 0xb1, 0x17, 0x6f, 0x53, 0xf8, 0x62, 0x2b, 0xd6, 0xec, 0xc0, 0x8c, 0x75,
		0xb8, 0x41, 0x80, 0x1d, 0x2c, 0xf8, 0x41, 0x81, 0x21, 0x38, 0x38, 0x82, 0x83, 0x25, 0x38, 0x78,
		0xb2, 0x03, 0x53, 0x96, 0xe0, 0xca, 0x3a, 0x6c, 0x25, 0x06, 0xc4, 0xb5, 0x01, 0xd6, 0xe3, 0x74,
		0x92, 0xbd, 0x6c, 0x96, 0x2a, 0xbc, 0x86, 0x33, 0xcb, 0x35, 0xb6, 0x30, 0x2b, 0x48, 0x91, 0x56,
		0x8a, 0x62, 0xae, 0x08, 0x45, 0x5b, 0xf9, 0x09, 0xbb, 0xc2, 0x13, 0x76, 0x25, 0x27, 0xec, 0x8a,
		0xcd, 0xcd, 0xae, 0x0a, 0x85, 0x59, 0x69, 0x99, 0xe4, 0x9d, 0xae, 0xf0, 0x3b, 0xa1, 0xe8, 0x20,
		0x24, 0x9d, 0xc9, 0xac, 0xab, 0x02, 0x60, 0xcb, 0xf9, 0xf8, 0xe9, 0xef, 0x87, 0x0f, 0xf1, 0x0a,
		0x30, 0x2f, 0x06, 0xf2, 0x4d, 0x2d, 0x3b, 0xb5, 0x38, 0xf3, 0x9a, 0x54, 0x7d, 0xe2, 0x70, 0xba,
		0xc4, 0x22, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0xba,
		0x5c, 0xd2, 0xba, 0x04, 0xcb, 0xc9, 0xec, 0x8c, 0x0f, 0xc6, 0x78, 0x5d, 0x0f, 0x0e, 0xb1, 0x9b,
		0x18, 0x44, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x97,
		0x4b, 0x5e, 0x37, 0x81, 0x72, 0xd2, 0x3a, 0xe3, 0x63, 0x11, 0x77, 0xcc, 0x82, 0x21, 0x75, 0xb1,
		0x39, 0x18, 0x94, 0xae, 0x40, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x67, 0x6b,
		0x54, 0x6c, 0x17, 0x28, 0x25, 0x86, 0x8c, 0xda, 0x04, 0x4a, 0xd5, 0x16, 0x38, 0x2d, 0xcb, 0x9f,
		0xd7, 0xf7, 0x3d, 0xdb, 0x86, 0xd2, 0x5b, 0x11, 0xaa, 0x39, 0x3e, 0x5c, 0x33, 0x7c, 0xc4, 0xe6,
		0xf7, 0xd8, 0xcd, 0xee, 0x51, 0x9b, 0xdb, 0xc3, 0x37, 0xb3, 0x87, 0x6f, 0x5e, 0x0f, 0xdf, 0xac,
		0x9e, 0x5d, 0x73, 0x21, 0x35, 0x16, 0x60, 0xad, 0x05, 0x51, 0x73, 0x99, 0xa5, 0xbd, 0xfc, 0xc3,
		0xbf, 0x11, 0xa5, 0x88, 0x84, 0x8e, 0x92, 0xa3, 0xb1, 0x52, 0x13, 0xd3, 0x0c, 0xf6, 0xcc, 0x44,
		0x09, 0x4a, 0x90, 0x0a, 0xfa, 0x54, 0x34, 0x22, 0x54, 0xd2, 0x93, 0x8e, 0x92, 0x8e, 0x92, 0x8e,
		0x92, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x1a, 0xcf, 0x5b, 0x7d, 0xa9, 0xf4, 0xfe, 0x1e, 0x20, 0x1b,
		0x45, 0x22, 0xa3, 0x17, 0xbe, 0xba, 0x1d, 0xde, 0xad, 0x6b, 0xa8, 0x1c, 0x00, 0xb8, 0x71, 0xcf,
		0x67, 0xa9, 0x70, 0x37, 0xed, 0x04, 0xdf, 0x0a, 0xf3, 0xab, 0xdf, 0xed, 0x0b, 0x60, 0xfb, 0x3e,
		0x85, 0x7e, 0x4b, 0xcb, 0x40, 0x1d, 0xcb, 0x5b, 0x19, 0xf7, 0x87, 0xe6, 0x76, 0xb6, 0xbf, 0x13,
		0x12, 0xfe, 0x03, 0x43, 0x62, 0xc9, 0x90, 0x28, 0xee, 0x1d, 0x16, 0x0f, 0xcb, 0x95, 0xbd, 0xc3,
		0x12, 0x63, 0x23, 0xdf, 0x84, 0x0c, 0xcf, 0x9a, 0x1b, 0x8a, 0x44, 0x28, 0xb9, 0xd3, 0x69, 0x05,
		0x77, 0x77, 0x7d, 0x25, 0xf5, 0x23, 0xea, 0x23, 0xcc, 0xd7, 0x06, 0x52, 0x38, 0x9a, 0x65, 0x0e,
		0x85, 0xa3, 0x05, 0x5c, 0x8a, 0xc2, 0xd1, 0x42, 0x9e, 0x4e, 0xe1, 0x68, 0x49, 0x03, 0x29, 0x1c,
		0xe5, 0x68, 0x26, 0xc1, 0xe7, 0x98, 0x6f, 0x80, 0xc1, 0x1c, 0x3e, 0xc7, 0x9c, 0xf0, 0x0a, 0x29,
		0xa2, 0xe4, 0xf8, 0x91, 0x8f, 0x32, 0x31, 0x59, 0x2a, 0x4c, 0xef, 0x88, 0x54, 0x4c, 0x82, 0xf4,
		0x90, 0x20, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x35, 0x9e, 0xb7,
		0x64, 0xcf, 0xf5, 0xdb, 0xed, 0x50, 0x44, 0x11, 0x22, 0x35, 0x3d, 0x04, 0xb2, 0x69, 0x3c, 0x86,
		0x7c, 0xa8, 0xf9, 0xdb, 0x9e, 0x75, 0x5f, 0x04, 0xf4, 0xad, 0x94, 0x8f, 0x1d, 0x00, 0xda, 0x76,
		0xee, 0x6b, 0x2d, 0x42, 0x05, 0xe7, 0x6e, 0x89, 0x81, 0x7f, 0x6f, 0x6f, 0x5f, 0xef, 0xba, 0x87,
		0x37, 0x4f, 0xd7, 0x05, 0xf7, 0xf0, 0x26, 0x3e, 0x2c, 0x8c, 0x7e, 0xc4, 0xc7, 0x7b, 0xd7, 0xbb,
		0x6e, 0x71, 0x72, 0x5c, 0xba, 0xde, 0x75, 0x4b, 0x37, 0x3b, 0x7f, 0xfd, 0xf5, 0x61, 0xe7, 0xd7,
		0xfe, 0x60, 0xf1, 0x2f, 0xfe, 0xc7, 0x81, 0xbb, 0x09, 0x37, 0x88, 0x4e, 0x53, 0xbf, 0xac, 0xfd,
		0x8f, 0x9e, 0x83, 0xee, 0x39, 0x58, 0x0f, 0x16, 0xdf, 0x13, 0xce, 0x7e, 0x1b, 0xce, 0xca, 0x84,
		0xb3, 0xf5, 0x86, 0x33, 0xdf, 0xed, 0x54, 0xdd, 0x4f, 0x37, 0xbf, 0x0a, 0xef, 0x8b, 0x83, 0xa3,
		0x9d, 0x5f, 0x95, 0xc1, 0xeb, 0x93, 0x4f, 0xb3, 0x3e, 0x56, 0x78, 0x5f, 0x19, 0x1c, 0xcd, 0x79,
		0xa7, 0x3c, 0x38, 0xfa, 0xcd, 0xdf, 0x51, 0x1a, 0x6c, 0xa7, 0x3e, 0x3a, 0x3c, 0xbf, 0x37, 0xef,
		0x0b, 0xc5, 0x39, 0x5f, 0xd8, 0x9f, 0xf7, 0x85, 0xfd, 0x39, 0x5f, 0x98, 0x6b, 0xd2, 0xde, 0x9c,
		0x2f, 0x94, 0x06, 0x4f, 0xa9, 0xcf, 0x6f, 0xcf, 0xfe, 0x68, 0x79, 0xb0, 0xf3, 0x34, 0xef, 0xbd,
		0xca, 0xe0, 0xe9, 0x68, 0x87, 0xe0, 0xbe, 0x86, 0xe0, 0xce, 0x38, 0x62, 0x1c, 0xe1, 0x51, 0x1d,
		0xd6, 0x50, 0x81, 0xdd, 0x0f, 0x88, 0xa7, 0x53, 0x0f, 0xda, 0x85, 0xaf, 0xa3, 0x9a, 0x65, 0x24,
		0x9f, 0x59, 0xcd, 0x32, 0x87, 0xcf, 0xac, 0x16, 0x70, 0x2b, 0x3e, 0xb3, 0x5a, 0xc8, 0xd3, 0xf9,
		0xcc, 0x6a, 0x49, 0x03, 0xf9, 0xcc, 0x2a, 0x47, 0x92, 0x0c, 0x6b, 0xa9, 0xde, 0xa2, 0xbe, 0xe4,
		0xaf, 0x96, 0xea, 0x25, 0xb7, 0x90, 0x22, 0x9a, 0xfa, 0x7f, 0xd6, 0x54, 0x81, 0xb2, 0x56, 0xa9,
		0xee, 0xfd, 0xae, 0x6c, 0xbb, 0xa1, 0xf0, 0xa3, 0x40, 0xe1, 0x11, 0xd6, 0x57, 0xf6, 0x91, 0xab,
		0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x6e, 0x18, 0x57, 0x95, 0x6d, 0xa1,
		0xb4, 0xd4, 0x8f, 0xa0, 0x7c, 0x15, 0x68, 0x85, 0xb0, 0x53, 0x1b, 0xdf, 0xaa, 0x8f, 0x7e, 0x04,
		0x98, 0x52, 0x27, 0x03, 0x5a, 0x3b, 0xfb, 0x5a, 0x3d, 0xad, 0x1d, 0x37, 0x2e, 0xea, 0x5f, 0xae,
		0x4e, 0x1a, 0x17, 0x27, 0xd5, 0xcb, 0xfa, 0x19, 0x5a, 0x76, 0x1d, 0x2d, 0x04, 0x8f, 0x20, 0x1f,
		0x13, 0x81, 0xae, 0xec, 0x7f, 0x3d, 0xba, 0x7f, 0x9c, 0x7e, 0xb9, 0xbc, 0x3a, 0xb9, 0x68, 0x9c,
		0xd6, 0xeb, 0xe7, 0x0e, 0x1b, 0x37, 0xac, 0xcd, 0xb8, 0x56, 0x2f, 0x39, 0xa4, 0x6b, 0x36, 0xa4,
		0xf5, 0x8b, 0xda, 0x9f, 0xb5, 0xb3, 0xea, 0x55, 0xfd, 0x82, 0xa3, 0xba, 0x46, 0x09, 0xb8, 0x7e,
		0xf6, 0xe9, 0xe4, 0xd8, 0x61, 0x5f, 0x90, 0x7f, 0x7c, 0xdd, 0x70, 0x3e, 0x02, 0x66, 0x05, 0x82,
		0x3a, 0xd8, 0xf5, 0x23, 0xed, 0xde, 0x05, 0x6d, 0xd9, 0x91, 0xa2, 0x8d, 0x27, 0x0e, 0x4e, 0x9b,
		0x47, 0x6d, 0x70, 0x96, 0x39, 0xd4, 0x06, 0x17, 0x70, 0x28, 0x6a, 0x83, 0x0b, 0x79, 0x3a, 0xb5,
		0xc1, 0x25, 0x0d, 0xa4, 0x36, 0x98, 0x23, 0xee, 0x0b, 0xac, 0x0d, 0x6a, 0x79, 0x27, 0xb4, 0x6c,
		0xfd, 0x88, 0xca, 0x45, 0x40, 0x6d, 0x10, 0x68, 0x21, 0x81, 0xf3, 0x45, 0xc5, 0x7d, 0x02, 0x1d,
		0xe5, 0xab, 0x20, 0x12, 0xad, 0x40, 0xb5, 0xa1, 0xd6, 0xab, 0xb2, 0xe3, 0xed, 0x6f, 0xde, 0x28,
		0x76, 0xbc, 0x7d, 0xbb, 0x79, 0xec, 0x78, 0xbb, 0x8e, 0x7a, 0x0c, 0x3b, 0xde, 0xae, 0x20, 0x24,
		0x0a, 0x07, 0xc5, 0x62, 0xb9, 0x52, 0x2c, 0xee, 0x56, 0xf6, 0x2b, 0xbb, 0x87, 0xa5, 0x52, 0xa1,
		0x5c, 0x60, 0xef, 0xdb, 0x9c, 0xf3, 0x47, 0x3c, 0x6b, 0xb8, 0x6e, 0x03, 0x26, 0x8b, 0x3a, 0x93,
		0xbd, 0xc5, 0xe1, 0xd4, 0xad, 0x89, 0x61, 0x20, 0xb3, 0x9f, 0x63, 0xd1, 0xf1, 0xfb, 0xdd, 0xd1,
		0x54, 0x75, 0x97, 0x5a, 0xdb, 0x4c, 0x73, 0xa8, 0xb5, 0x2d, 0xe0, 0xde, 0xd4, 0xda, 0x16, 0xf2,
		0x74, 0x6a, 0x6d, 0x4b, 0x1a, 0x48, 0xad, 0x2d, 0x47, 0xf3, 0x1a, 0x6e, 0xdc, 0xb4, 0x38, 0x0a,
		0x72, 0xe3, 0xa6, 0x7f, 0x7b, 0x51, 0xc6, 0x5a, 0xcb, 0x39, 0x3b, 0x65, 0xac, 0xbc, 0xa7, 0xfb,
		0xe9, 0x90, 0xa0, 0x8c, 0xb5, 0x74, 0x48, 0x70, 0xe3, 0xa6, 0x75, 0x21, 0x64, 0x78, 0xd6, 0x50,
		0xbc, 0x82, 0xc9, 0x9d, 0xce, 0x78, 0x71, 0x64, 0xd0, 0xd7, 0x02, 0x4f, 0xc0, 0x7a, 0x69, 0x1c,
		0x05, 0xa3, 0x59, 0xe6, 0x50, 0x30, 0x5a, 0xc0, 0x9d, 0x28, 0x18, 0x2d, 0xe4, 0xe9, 0x14, 0x8c,
		0x96, 0x34, 0x90, 0x82, 0x51, 0x8e, 0x66, 0x10, 0xc0, 0x82, 0x51, 0x33, 0x08, 0xba, 0xc2, 0x57,
		0x88, 0x8b, 0x36, 0x0b, 0xa4, 0x72, 0x00, 0x16, 0x58, 0x0e, 0x21, 0xa7, 0xaa, 0x54, 0xa0, 0xfd,
		0xe1, 0x6c, 0x0c, 0x22, 0x80, 0x9c, 0xa8, 0xf5, 0x4d, 0xdc, 0xf9, 0xbd, 0x71, 0xd3, 0x19, 0x2f,
		0xe8, 0x09, 0xd5, 0x1a, 0x11, 0x25, 0x57, 0x09, 0xfd, 0x33, 0x08, 0x7f, 0xb8, 0x52, 0x45, 0xda,
		0x57, 0x2d, 0xe1, 0xbd, 0x3e, 0x11, 0xa5, 0xce, 0x78, 0xbd, 0x30, 0xd0, 0x41, 0x2b, 0xe8, 0x46,
		0xc9, 0x91, 0xd7, 0xbc, 0xed, 0x79, 0xa1, 0x6c, 0x7a, 0x7e, 0x47, 0xba, 0x91, 0xdf, 0x91, 0x51,
		0x72, 0xe4, 0x8d, 0x9a, 0x33, 0x47, 0xa1, 0x16, 0x6e, 0x2f, 0xe8, 0xca, 0xd6, 0xa3, 0xa7, 0x84,
		0xbc, 0xfd, 0xd6, 0x0c, 0xc2, 0x28, 0x39, 0xf2, 0xfc, 0xf6, 0xf7, 0x11, 0x1a, 0x04, 0x7d, 0xed,
		0xf6, 0x82, 0x48, 0x7b, 0x23, 0x8a, 0x1b, 0xc5, 0x3f, 0xe2, 0x46, 0x37, 0x76, 0x51, 0xc2, 0x9e,
		0x3b, 0x5b, 0x74, 0x65, 0xa7, 0xaf, 0x7e, 0xa8, 0xe0, 0xa7, 0x72, 0x7d, 0xad, 0x43, 0xd9, 0x1c,
		0x8e, 0x88, 0x75, 0x77, 0x7e, 0x7e, 0x68, 0x90, 0xb6, 0xcd, 0x72, 0xd0, 0x4f, 0x20, 0xc0, 0xb2,
		0x19, 0x28, 0x33, 0x20, 0xa4, 0x99, 0x0f, 0xe6, 0x8c, 0x07, 0x6d, 0xa6, 0x03, 0x3b, 0xc3, 0x81,
		0x9d, 0xd9, 0xc0, 0xce, 0x68, 0x36, 0x9b, 0x7e, 0x1d, 0xcb, 0x10, 0x23, 0xed, 0xa4, 0x40, 0x0a,
		0x4f, 0x52, 0x4c, 0x9b, 0x88, 0x25, 0x2c, 0x16, 0x28, 0x2c, 0xc2, 0xc3, 0x2b, 0x36, 0xcc, 0xa2,
		0xc2, 0x2d, 0x3c, 0xec, 0xc2, 0xc3, 0x2f, 0x3c, 0x0c, 0xe3, 0xe8, 0x31, 0x5b, 0x40, 0xc2, 0x22,
		0x0a, 0x3c, 0x27, 0x06, 0x0d, 0xb1, 0xcf, 0xd5, 0x68, 0x72, 0xe7, 0x54, 0x46, 0x7d, 0x36, 0x11,
		0x2c, 0xf4, 0x30, 0xcb, 0x37, 0xe0, 0xe0, 0x1a, 0x19, 0xb6, 0xf3, 0x01, 0xdf, 0xe8, 0x30, 0x9e,
		0x1b, 0x38, 0xcf, 0x0d, 0xac, 0xe7, 0x06, 0xde, 0xb1, 0x60, 0x1e, 0x0c, 0xee, 0x93, 0x51, 0xbc,
		0x42, 0x04, 0xd8, 0x2d, 0xec, 0xcd, 0x0b, 0x52, 0xb3, 0xe1, 0x0a, 0xe6, 0x16, 0x92, 0x93, 0xcd,
		0x0c, 0xe2, 0x3d, 0x09, 0x9e, 0xc9, 0x0a, 0x0b, 0xfe, 0xd0, 0x43, 0xd3, 0x89, 0x9f, 0xae, 0xc1,
		0x12, 0xdf, 0xd8, 0x3c, 0x4c, 0xd2, 0x5b, 0x20, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25,
		0xe9, 0x25, 0xb2, 0xce, 0x1e, 0x45, 0x34, 0xad, 0x2b, 0x31, 0x6c, 0xc4, 0xd1, 0xba, 0x02, 0x78,
		0xad, 0xdc, 0x94, 0xf4, 0x35, 0xb4, 0xf4, 0x3d, 0x17, 0x30, 0xad, 0x11, 0x29, 0xc8, 0x03, 0x39,
		0xc8, 0x17, 0x49, 0xc8, 0x0b, 0x59, 0xc8, 0x1d, 0x69, 0xc8, 0x1d, 0x79, 0xc8, 0x1d, 0x89, 0xc0,
		0x24, 0x13, 0xa0, 0xa4, 0x22, 0x19, 0x5d, 0x58, 0x45, 0x2d, 0x95, 0x37, 0xfb, 0x52, 0xe9, 0x42,
		0x19, 0x39, 0x67, 0x8e, 0x51, 0xbc, 0x0c, 0x6c, 0x22, 0x66, 0x0b, 0x88, 0xd7, 0x2f, 0x6c, 0xcc,
		0xd9, 0x42, 0x6f, 0x11, 0x91, 0x33, 0x7a, 0x99, 0x32, 0x17, 0xbc, 0x85, 0x44, 0xca, 0xde, 0x1c,
		0x2c, 0x9b, 0xcf, 0x09, 0x1c, 0x4d, 0x87, 0x98, 0xff, 0xc0, 0x10, 0xcb, 0x38, 0xc4, 0xca, 0xa5,
		0xd2, 0x7e, 0x89, 0x61, 0xb6, 0x59, 0x5c, 0x14, 0xdf, 0xba, 0x9b, 0x77, 0xbc, 0x5f, 0x39, 0x4d,
		0xe3, 0xc0, 0x95, 0x70, 0xa9, 0x29, 0x05, 0x6a, 0x45, 0x5c, 0x4e, 0x50, 0x85, 0xba, 0xe0, 0x2a,
		0x9d, 0x91, 0xba, 0xe0, 0x4a, 0x23, 0x87, 0xba, 0x60, 0xc6, 0x06, 0x53, 0x17, 0x5c, 0xe3, 0x89,
		0x58, 0xce, 0x74, 0xc1, 0x83, 0x1c, 0xc8, 0x82, 0x25, 0xca, 0x82, 0x4b, 0xbe, 0x28, 0x0b, 0x52,
		0xb3, 0xa0, 0x2c, 0xb8, 0x81, 0x68, 0x34, 0x1d, 0x62, 0x94, 0x05, 0x33, 0x0f, 0xb1, 0xbd, 0x12,
		0x45, 0xc1, 0x0d, 0x23, 0xa2, 0xf8, 0xd6, 0x51, 0x14, 0xcc, 0x6d, 0x12, 0x8f, 0x95, 0xb6, 0xfb,
		0x71, 0x76, 0xc9, 0x83, 0x2a, 0x18, 0xdb, 0x4a, 0x59, 0xf0, 0x2d, 0xe6, 0x51, 0x16, 0x5c, 0xa1,
		0x37, 0x52, 0x16, 0x5c, 0x69, 0xe4, 0x50, 0x16, 0xcc, 0xd8, 0x60, 0xca, 0x82, 0x6b, 0x3c, 0x11,
		0xcb, 0x91, 0x2c, 0xd8, 0x94, 0xca, 0x0f, 0x1f, 0x73, 0xa0, 0x0b, 0x1e, 0x02, 0x9b, 0x78, 0x2a,
		0xd4, 0xed, 0x68, 0x61, 0x2e, 0x85, 0xc1, 0x65, 0x55, 0x0b, 0x0a, 0x83, 0x99, 0xab, 0x16, 0x05,
		0x6a, 0x16, 0x1b, 0x86, 0x47, 0xd3, 0x21, 0x46, 0x61, 0x30, 0xf3, 0x10, 0x63, 0xbd, 0xe0, 0x06,
		0x92, 0x51, 0x7c, 0xeb, 0x28, 0x0d, 0xe6, 0x36, 0x8d, 0x3b, 0xe2, 0x41, 0x0b, 0xd5, 0x16, 0x6d,
		0x7c, 0x61, 0x30, 0xb1, 0x94, 0xb2, 0xe0, 0x5b, 0xcc, 0xa3, 0x2c, 0xb8, 0x42, 0x5f, 0xa4, 0x2c,
		0xb8, 0xd2, 0xc8, 0xa1, 0x2c, 0x98, 0xb1, 0xc1, 0x94, 0x05, 0xd7, 0x78, 0x1a, 0x96, 0x27, 0x59,
		0x10, 0x6e, 0xdf, 0xaf, 0x79, 0x30, 0x0e, 0xb2, 0x0f, 0x18, 0x49, 0xed, 0x5b, 0xc6, 0x30, 0xe8,
		0x0d, 0x67, 0x9e, 0x7e, 0x17, 0x9f, 0xd4, 0x26, 0x96, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92,
		0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x32, 0x28, 0xa6, 0xc7, 0xb0,
		0xe7, 0x87, 0x5a, 0xe6, 0x81, 0xd3, 0x4e, 0x0c, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5,
		0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x65, 0x50, 0x4c, 0x8f, 0xa1, 0x0e,
		0x7d, 0x15, 0x49, 0x2d, 0xef, 0x73, 0xb0, 0x2e, 0xe9, 0x85, 0xad, 0x24, 0xb6, 0x24, 0xb6, 0x24,
		0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0xb4, 0x08, 0x34,
		0x44, 0x9d, 0xaa, 0x52, 0x81, 0xf6, 0xb5, 0x0c, 0x30, 0x17, 0x40, 0x39, 0x51, 0xeb, 0x9b, 0xb8,
		0xf3, 0x7b, 0xe3, 0x0d, 0x28, 0xbd, 0xa0, 0x27, 0x54, 0x6b, 0x44, 0x14, 0x5d, 0x25, 0xf4, 0xcf,
		0x20, 0xfc, 0xe1, 0x4a, 0x15, 0x69, 0x5f, 0xb5, 0x84, 0xf7, 0xfa, 0x44, 0x94, 0x3a, 0xe3, 0xf5,
		0xc2, 0x40, 0x07, 0xad, 0xa0, 0x1b, 0x25, 0x47, 0x5e, 0xf3, 0xb6, 0xe7, 0x85, 0xb2, 0xe9, 0xf9,
		0x1d, 0xe9, 0x46, 0x7e, 0x47, 0x46, 0xc9, 0x91, 0x27, 0x7b, 0xf7, 0x65, 0x37, 0x0a, 0xb5, 0x70,
		0x7b, 0x41, 0x57, 0xb6, 0x1e, 0x3d, 0x25, 0xe4, 0xed, 0xb7, 0x66, 0x10, 0x46, 0xc9, 0x91, 0xe7,
		0xb7, 0xbf, 0x8f, 0xd0, 0x2a, 0xe8, 0x6b, 0xb7, 0x17, 0x44, 0xda, 0x0b, 0x83, 0xbe, 0x16, 0x51,
		0xfc, 0xc3, 0xeb, 0xab, 0x1f, 0x2a, 0xf8, 0xa9, 0x5c, 0x5f, 0xeb, 0x50, 0x36, 0x47, 0x6f, 0xa4,
		0x4e, 0xc5, 0x5b, 0x6a, 0x72, 0x23, 0x4d, 0x64, 0x4b, 0x50, 0x36, 0xd6, 0xff, 0xaf, 0x78, 0x44,
		0xec, 0x8c, 0xeb, 0x9c, 0xca, 0x48, 0x57, 0xb5, 0x06, 0xdb, 0xf5, 0xff, 0xb3, 0x54, 0x27, 0x5d,
		0x31, 0xa4, 0x95, 0x11, 0xd6, 0xb4, 0xd2, 0xf9, 0xec, 0x3f, 0xbc, 0xb0, 0xac, 0x70, 0x50, 0x2c,
		0x96, 0x2b, 0xc5, 0xe2, 0x6e, 0x65, 0xbf, 0xb2, 0x7b, 0x58, 0x2a, 0x15, 0xca, 0x05, 0xa0, 0x55,
		0x5c, 0x4e, 0x3d, 0x6c, 0x8b, 0x50, 0xb4, 0x3f, 0x0e, 0x5d, 0x4f, 0xf5, 0xbb, 0x5d, 0x46, 0x24,
		0x3e, 0x7e, 0x6e, 0x00, 0x6e, 0x3a, 0x50, 0x5b, 0x2c, 0x87, 0xfd, 0x96, 0x56, 0xe3, 0x49, 0xc4,
		0x59, 0x7c, 0xfb, 0x6a, 0xe3, 0xbb, 0xd7, 0x38, 0x1f, 0xdf, 0xb3, 0xc6, 0xc7, 0xdb, 0x5e, 0xe3,
		0x42, 0x36, 0x1b, 0xd5, 0x8e, 0xbc, 0xf4, 0x3b, 0xb2, 0x51, 0xeb, 0xdd, 0x97, 0x2f, 0x43, 0x2d,
		0xce, 0x47, 0xb7, 0xa9, 0x71, 0x36, 0xbe, 0x39, 0x8d, 0x6a, 0xfb, 0xfb, 0x85, 0x6c, 0xd6, 0xfb,
		0xfa, 0x3c, 0x88, 0x74, 0xe3, 0x62, 0x78, 0x4b, 0x1a, 0x5f, 0xe2, 0xbf, 0xbf, 0x9a, 0xfc, 0xf9,
		0xef, 0x08, 0xcf, 0xf6, 0x2d, 0xb0, 0x9c, 0x86, 0xd0, 0xd2, 0xcf, 0xda, 0xa5, 0x1d, 0xbb, 0x51,
		0x66, 0xcf, 0xb7, 0xed, 0x5c, 0xd9, 0x52, 0x34, 0x4d, 0x68, 0xf5, 0xd0, 0x6d, 0x5d, 0xd9, 0xde,
		0x12, 0xaa, 0xdd, 0x0b, 0xa4, 0xd2, 0x5b, 0xad, 0xa0, 0x1b, 0x84, 0x96, 0x70, 0x06, 0x83, 0x53,
		0xe3, 0x70, 0x68, 0x68, 0xce, 0x8c, 0xc1, 0x91, 0x6d, 0x85, 0x0f, 0x08, 0x08, 0xe5, 0x1b, 0x7c,
		0x2c, 0xd2, 0x59, 0x03, 0xf4, 0xd5, 0x0e, 0x8e, 0x9a, 0x47, 0x31, 0xb3, 0x57, 0x34, 0x1c, 0xf0,
		0xb6, 0x03, 0x3d, 0xaf, 0x01, 0x6e, 0xd6, 0xf9, 0xcd, 0xb9, 0xa0, 0x99, 0x2b, 0x19, 0x72, 0x72,
		0x5b, 0xce, 0x9d, 0x3b, 0xa7, 0x36, 0x08, 0x54, 0x99, 0x02, 0x93, 0x99, 0xa8, 0xcc, 0x3e, 0x46,
		0x0c, 0xc4, 0x87, 0x33, 0xe5, 0x03, 0xa1, 0xb9, 0x67, 0xf9, 0xcf, 0x5d, 0xbf, 0x5f, 0x19, 0x60,
		0x28, 0x27, 0x4c, 0x9e, 0xb5, 0x1b, 0xba, 0x9c, 0xe9, 0x12, 0x38, 0x1b, 0x25, 0x6d, 0x76, 0x4b,
		0xd4, 0x6c, 0x95, 0x9c, 0x59, 0x2f, 0x21, 0xb3, 0x5e, 0x12, 0x66, 0xbd, 0xc4, 0x6b, 0xbd, 0xd8,
		0xca, 0xb1, 0x34, 0x2b, 0x0c, 0x39, 0x63, 0x2a, 0x6b, 0x3c, 0x70, 0x26, 0xe9, 0x62, 0x7c, 0x7d,
		0xc3, 0x4e, 0x6b, 0x16, 0x00, 0xac, 0x01, 0x81, 0x4d, 0x40, 0xc0, 0x00, 0x06, 0xdb, 0x00, 0x01,
		0x03, 0x14, 0x30, 0x80, 0x01, 0x03, 0x1c, 0x9b, 0xa1, 0xed, 0x98, 0x06, 0x94, 0x69, 0x60, 0xb1,
		0x17, 0x6f, 0x53, 0xf8, 0x62, 0x2b, 0xd6, 0xec, 0xc0, 0x8c, 0x75, 0xb8, 0x41, 0x80, 0x1d, 0x2c,
		0xf8, 0x41, 0x81, 0x21, 0x38, 0x38, 0x82, 0x83, 0x25, 0x38, 0x78, 0xb2, 0x03, 0x53, 0x96, 0xe0,
		0xca, 0x3a, 0x6c, 0x25, 0x06, 0xc4, 0x35, 0x02, 0xd6, 0xe3, 0x74, 0x92, 0xbd, 0x6c, 0x96, 0x2c,
		0xbc, 0x86, 0x33, 0xcb, 0x15, 0xb7, 0x30, 0x2b, 0x4a, 0x91, 0x56, 0x8e, 0x62, 0xae, 0x10, 0x45,
		0x5b, 0x09, 0x0a, 0xbb, 0xe2, 0x13, 0x76, 0x65, 0x27, 0xec, 0x0a, 0xce, 0xcd, 0xae, 0x0f, 0x85,
		0x59, 0x79, 0x99, 0xe4, 0x9d, 0xae, 0xf0, 0x3b, 0xa1, 0xe8, 0x20, 0x24, 0x9d, 0xc9, 0xac, 0xab,
		0x02, 0x60, 0xcb, 0xf9, 0xf8, 0xf9, 0xef, 0x87, 0x0f, 0xf1, 0x7a, 0x30, 0x2f, 0x06, 0xf2, 0x4d,
		0x2d, 0x3f, 0xb5, 0x38, 0xf3, 0x9a, 0x54, 0x7f, 0xe2, 0x70, 0xba, 0xc4, 0x22, 0xd2, 0x3a, 0xd2,
		0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0x3a, 0xd2, 0xba, 0x5c, 0xd2, 0xba, 0x04, 0xcb,
		0xc9, 0xec, 0x8c, 0x0f, 0xc6, 0x78, 0x7d, 0x0f, 0x0e, 0xb1, 0x9b, 0x18, 0x44, 0x5e, 0x47, 0x5e,
		0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x47, 0x5e, 0x97, 0x4b, 0x5e, 0x37, 0x81, 0x72,
		0xd2, 0x3a, 0xe3, 0x63, 0x11, 0xf7, 0xcf, 0x82, 0x21, 0x75, 0xb1, 0x39, 0x18, 0x94, 0xae, 0x40,
		0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x47, 0x4a, 0x67, 0x6b, 0x54, 0x6c, 0x17, 0x28, 0x25,
		0x86, 0x8c, 0x9a, 0x06, 0x4a, 0xd5, 0x16, 0x38, 0x2d, 0xcc, 0x9f, 0x97, 0xf7, 0x3d, 0xdb, 0x86,
		0xd2, 0x69, 0x11, 0xaa, 0x59, 0x3e, 0x5c, 0x73, 0x7c, 0xc4, 0x66, 0xf8, 0xd8, 0xcd, 0xef, 0x51,
		0x9b, 0xdd, 0xc3, 0x37, 0xb7, 0x87, 0x6f, 0x66, 0x0f, 0xdf, 0xbc, 0x9e, 0x3d, 0x74, 0x21, 0x35,
		0x16, 0x60, 0xad, 0x05, 0x51, 0x73, 0x99, 0xa5, 0xbd, 0xfc, 0xc3, 0xbf, 0x11, 0xa5, 0x88, 0x84,
		0x8e, 0x92, 0xa3, 0xb1, 0x52, 0x13, 0xd3, 0x0c, 0x76, 0xcf, 0x44, 0x09, 0x4a, 0x90, 0x0a, 0xfa,
		0x54, 0x34, 0x22, 0x54, 0xd2, 0x93, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x92,
		0x8e, 0x1a, 0xcf, 0x5b, 0x7d, 0xa9, 0xf4, 0xfe, 0x1e, 0x20, 0x1b, 0x45, 0x22, 0xa3, 0x17, 0xbe,
		0xba, 0x1d, 0xde, 0xad, 0x6b, 0xa8, 0x1c, 0x00, 0xb8, 0x91, 0xcf, 0x67, 0xa9, 0x70, 0x37, 0xf1,
		0x04, 0xdf, 0x1a, 0xf3, 0xab, 0xdf, 0xed, 0x0b, 0x60, 0xfb, 0x3e, 0x85, 0x7e, 0x4b, 0xcb, 0x40,
		0x1d, 0xcb, 0x5b, 0x19, 0xf7, 0x89, 0xe6, 0xf6, 0xb6, 0xbf, 0x13, 0x12, 0xfe, 0x03, 0x43, 0x62,
		0xc9, 0x90, 0x28, 0xee, 0x1d, 0x16, 0x0f, 0xcb, 0x95, 0xbd, 0xc3, 0x12, 0x63, 0x23, 0xdf, 0x84,
		0x0c, 0xcf, 0x9a, 0x1b, 0x8a, 0x44, 0x28, 0xb9, 0xd3, 0x69, 0x05, 0x77, 0x77, 0x7d, 0x25, 0xf5,
		0x23, 0xea, 0x23, 0xcc, 0xd7, 0x06, 0x52, 0x38, 0x9a, 0x65, 0x0e, 0x85, 0xa3, 0x05, 0x5c, 0x8a,
		0xc2, 0xd1, 0x42, 0x9e, 0x4e, 0xe1, 0x68, 0x49, 0x03, 0x29, 0x1c, 0xe5, 0x68, 0x26, 0xc1, 0xe7,
		0x98, 0x6f, 0x80, 0xc1, 0x1c, 0x3e, 0xc7, 0x9c, 0xf0, 0x0a, 0x29, 0xa2, 0xe4, 0xf8, 0x91, 0x8f,
		0x32, 0x31, 0x59, 0x2a, 0x4c, 0xef, 0x88, 0x54, 0x4c, 0x82, 0xf4, 0x90, 0x20, 0x2f, 0x25, 0x2f,
		0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x25, 0x2f, 0x35, 0x9e, 0xb7, 0x64, 0xcf, 0xf5, 0xdb, 0xed,
		0x50, 0x44, 0x11, 0x22, 0x35, 0x3d, 0x04, 0xb2, 0x69, 0x3c, 0x86, 0x7c, 0xa8, 0xf9, 0xdb, 0x9e,
		0x75, 0x5f, 0x04, 0xf4, 0xad, 0x94, 0x8f, 0x1d, 0x00, 0xda, 0x76, 0xee, 0x6b, 0x2d, 0x42, 0x05,
		0xe7, 0x6e, 0x89, 0x81, 0x7f, 0x6f, 0x6f, 0x5f, 0xef, 0xba, 0x87, 0x37, 0x4f, 0xd7, 0x05, 0xf7,
		0xf0, 0x26, 0x3e, 0x2c, 0x8c, 0x7e, 0xc4, 0xc7, 0x7b, 0xd7, 0xbb, 0x6e, 0x71, 0x72, 0x5c, 0xba,
		0xde, 0x75, 0x4b, 0x37, 0x3b, 0x7f, 0xfd, 0xf5, 0x61, 0xe7, 0xd7, 0xfe, 0x60, 0xf1, 0x2f, 0xfe,
		0xc7, 0x81, 0xbb, 0x09, 0x37, 0x88, 0x4e, 0x53, 0xbf, 0xac, 0xfd, 0x8f, 0x9e, 0x83, 0xee, 0x39,
		0x58, 0x0f, 0x16, 0xdf, 0x13, 0xce, 0x7e, 0x1b, 0xce, 0xca, 0x84, 0xb3, 0xf5, 0x86, 0x33, 0xdf,
		0xed, 0x54, 0xdd, 0x4f, 0x37, 0xbf, 0x0a, 0xef, 0x8b, 0x83, 0xa3, 0x9d, 0x5f, 0x95, 0xc1, 0xeb,
		0x93, 0x4f, 0xb3, 0x3e, 0x56, 0x78, 0x5f, 0x19, 0x1c, 0xcd, 0x79, 0xa7, 0x3c, 0x38, 0xfa, 0xcd,
		0xdf, 0x51, 0x1a, 0x6c, 0xa7, 0x3e, 0x3a, 0x3c, 0xbf, 0x37, 0xef, 0x0b, 0xc5, 0x39, 0x5f, 0xd8,
		0x9f, 0xf7, 0x85, 0xfd, 0x39, 0x5f, 0x98, 0x6b, 0xd2, 0xde, 0x9c, 0x2f, 0x94, 0x06, 0x4f, 0xa9,
		0xcf, 0x6f, 0xcf, 0xfe, 0x68, 0x79, 0xb0, 0xf3, 0x34, 0xef, 0xbd, 0xca, 0xe0, 0xe9, 0x68, 0x87,
		0xe0, 0xbe, 0x86, 0xe0, 0xce, 0x38, 0x62, 0x1c, 0xe1, 0x51, 0x1d, 0xd6, 0x50, 0x81, 0xdd, 0x0f,
		0x88, 0xa7, 0x53, 0x0f, 0xda, 0x85, 0xaf, 0xa3, 0x9a, 0x65, 0x24, 0x9f, 0x59, 0xcd, 0x32, 0x87,
		0xcf, 0xac, 0x16, 0x70, 0x2b, 0x3e, 0xb3, 0x5a, 0xc8, 0xd3, 0xf9, 0xcc, 0x6a, 0x49, 0x03, 0xf9,
		0xcc, 0x2a, 0x47, 0x92, 0x0c, 0x6b, 0xa9, 0xde, 0xa2, 0xbe, 0xe4, 0xaf, 0x96, 0xea, 0x25, 0xb7,
		0x90, 0x22, 0x9a, 0xfa, 0x7f, 0xd6, 0x54, 0x81, 0xb2, 0x56, 0xa9, 0xee, 0xfd, 0xae, 0x6c, 0xbb,
		0xa1, 0xf0, 0xa3, 0x40, 0xe1, 0x11, 0xd6, 0x57, 0xf6, 0x91, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92,
		0xab, 0x92, 0xab, 0x92, 0xab, 0x6e, 0x18, 0x57, 0x95, 0x6d, 0xa1, 0xb4, 0xd4, 0x8f, 0xa0, 0x7c,
		0x15, 0x68, 0x85, 0xb0, 0x53, 0x1b, 0xdf, 0xaa, 0x8f, 0x7e, 0x04, 0x98, 0x52, 0x27, 0x03, 0x5a,
		0x3b, 0xfb, 0x5a, 0x3d, 0xad, 0x1d, 0x37, 0x2e, 0xea, 0x5f, 0xae, 0x4e, 0x1a, 0x17, 0x27, 0xd5,
		0xcb, 0xfa, 0x19, 0x5a, 0x76, 0x1d, 0x2d, 0x04, 0x8f, 0x20, 0x1f, 0x13, 0x81, 0xae, 0xec, 0x7f,
		0x3d, 0xba, 0x7f, 0x9c, 0x7e, 0xb9, 0xbc, 0x3a, 0xb9, 0x68, 0x9c, 0xd6, 0xeb, 0xe7, 0x0e, 0x1b,
		0x37, 0xac, 0xcd, 0xb8, 0x56, 0x2f, 0x39, 0xa4, 0x6b, 0x36, 0xa4, 0xf5, 0x8b, 0xda, 0x9f, 0xb5,
		0xb3, 0xea, 0x55, 0xfd, 0x82, 0xa3, 0xba, 0x46, 0x09, 0xb8, 0x7e, 0xf6, 0xe9, 0xe4, 0xd8, 0x61,
		0x5f, 0x90, 0x7f, 0x7c, 0xdd, 0x70, 0x3e, 0x02, 0x66, 0x05, 0x82, 0x3a, 0xd8, 0xf5, 0x23, 0xed,
		0xde, 0x05, 0x6d, 0xd9, 0x91, 0xa2, 0x8d, 0x27, 0x0e, 0x4e, 0x9b, 0x47, 0x6d, 0x70, 0x96, 0x39,
		0xd4, 0x06, 0x17, 0x70, 0x28, 0x6a, 0x83, 0x0b, 0x79, 0x3a, 0xb5, 0xc1, 0x25, 0x0d, 0xa4, 0x36,
		0x98, 0x23, 0xee, 0x0b, 0xac, 0x0d, 0x6a, 0x79, 0x27, 0xb4, 0x6c, 0xfd, 0x88, 0xca, 0x45, 0x40,
		0x6d, 0x10, 0x68, 0x21, 0x81, 0xf3, 0x45, 0xc5, 0x7d, 0x02, 0x1d, 0xe5, 0xab, 0x20, 0x12, 0xad,
		0x40, 0xb5, 0xa1, 0xd6, 0xab, 0xb2, 0xe3, 0xed, 0x6f, 0xde, 0x28, 0x76, 0xbc, 0x7d, 0xbb, 0x79,
		0xec, 0x78, 0xbb, 0x8e, 0x7a, 0x0c, 0x3b, 0xde, 0xae, 0x20, 0x24, 0x0a, 0x07, 0xc5, 0x62, 0xb9,
		0x52, 0x2c, 0xee, 0x56, 0xf6, 0x2b, 0xbb, 0x87, 0xa5, 0x52, 0xa1, 0x5c, 0x60, 0xef, 0xdb, 0x9c,
		0xf3, 0x47, 0x3c, 0x6b, 0xb8, 0x6e, 0x03, 0x26, 0x8b, 0x3a, 0x93, 0xbd, 0xc5, 0xe1, 0xd4, 0xad,
		0x89, 0x61, 0x20, 0xb3, 0x9f, 0x63, 0xd1, 0xf1, 0xfb, 0xdd, 0xd1, 0x54, 0x75, 0x97, 0x5a, 0xdb,
		0x4c, 0x73, 0xa8, 0xb5, 0x2d, 0xe0, 0xde, 0xd4, 0xda, 0x16, 0xf2, 0x74, 0x6a, 0x6d, 0x4b, 0x1a,
		0x48, 0xad, 0x2d, 0x47, 0xf3, 0x1a, 0x6e, 0xdc, 0xb4, 0x38, 0x0a, 0x72, 0xe3, 0xa6, 0x7f, 0x7b,
		0x51, 0xc6, 0x5a, 0xcb, 0x39, 0x3b, 0x65, 0xac, 0xbc, 0xa7, 0xfb, 0xe9, 0x90, 0xa0, 0x8c, 0xb5,
		0x74, 0x48, 0x70, 0xe3, 0xa6, 0x75, 0x21, 0x64, 0x78, 0xd6, 0x50, 0xbc, 0x82, 0xc9, 0x9d, 0xce,
		0x78, 0x71, 0x64, 0xd0, 0xd7, 0x02, 0x4f, 0xc0, 0x7a, 0x69, 0x1c, 0x05, 0xa3, 0x59, 0xe6, 0x50,
		0x30, 0x5a, 0xc0, 0x9d, 0x28, 0x18, 0x2d, 0xe4, 0xe9, 0x14, 0x8c, 0x96, 0x34, 0x90, 0x82, 0x51,
		0x8e, 0x66, 0x10, 0xc0, 0x82, 0x51, 0x33, 0x08, 0xba, 0xc2, 0x57, 0x88, 0x8b, 0x36, 0x0b, 0xa4,
		0x72, 0x00, 0x16, 0x58, 0x0e, 0x21, 0xa7, 0xaa, 0x54, 0xa0, 0xfd, 0xe1, 0x6c, 0x0c, 0x22, 0x80,
		0x9c, 0xa8, 0xf5, 0x4d, 0xdc, 0xf9, 0xbd, 0x71, 0xd3, 0x19, 0x2f, 0xe8, 0x09, 0xd5, 0x1a, 0x11,
		0x25, 0x57, 0x09, 0xfd, 0x33, 0x08, 0x7f, 0xb8, 0x52, 0x45, 0xda, 0x57, 0x2d, 0xe1, 0xbd, 0x3e,
		0x11, 0xa5, 0xce, 0x78, 0xbd, 0x30, 0xd0, 0x41, 0x2b, 0xe8, 0x46, 0xc9, 0x91, 0xd7, 0xbc, 0xed,
		0x79, 0xa1, 0x6c, 0x7a, 0x7e, 0x47, 0xba, 0x91, 0xdf, 0x91, 0x51, 0x72, 0xe4, 0x8d, 0x9a, 0x33,
		0x47, 0xa1, 0x16, 0x6e, 0x2f, 0xe8, 0xca, 0xd6, 0xa3, 0xa7, 0x84, 0xbc, 0xfd, 0xd6, 0x0c, 0xc2,
		0x28, 0x39, 0xf2, 0xfc, 0xf6, 0xf7, 0x11, 0x1a, 0x04, 0x7d, 0xed, 0xf6, 0x42, 0xe1, 0x8d, 0x18,
		0x6e, 0x14, 0xff, 0x88, 0xfb, 0xdc, 0xd8, 0x05, 0x09, 0x7b, 0xde, 0x6c, 0xd1, 0x93, 0x9d, 0xbe,
		0xfa, 0xa1, 0x82, 0x9f, 0xca, 0xf5, 0xb5, 0x0e, 0x65, 0x73, 0x38, 0x22, 0xd6, 0xbd, 0xf9, 0xf9,
		0x99, 0x41, 0xda, 0x36, 0xcb, 0x31, 0x3f, 0x41, 0x00, 0xcb, 0x66, 0xa0, 0x4c, 0x80, 0x90, 0x26,
		0x3e, 0x98, 0x13, 0x1e, 0xb4, 0x89, 0x0e, 0xec, 0x04, 0x07, 0x76, 0x62, 0x03, 0x3b, 0xa1, 0xd9,
		0x6c, 0xf6, 0x75, 0x2c, 0x43, 0x8c, 0xb4, 0x93, 0x02, 0x29, 0x3c, 0x45, 0x31, 0x6d, 0x22, 0x96,
		0xae, 0x58, 0xa0, 0xae, 0x08, 0x0f, 0xaf, 0xd8, 0x30, 0x8b, 0x0a, 0xb7, 0xf0, 0xb0, 0x0b, 0x0f,
		0xbf, 0xf0, 0x30, 0x8c, 0x23, 0xc7, 0x6c, 0x01, 0xe9, 0x8a, 0x28, 0xf0, 0x9c, 0x18, 0x34, 0xc4,
		0x3e, 0x57, 0xa3, 0xa9, 0x9d, 0x53, 0x19, 0xf5, 0xd9, 0x44, 0xb0, 0xd0, 0xc3, 0xac, 0xde, 0x80,
		0x83, 0x6b, 0x64, 0xd8, 0xce, 0x07, 0x7c, 0xa3, 0xc3, 0x78, 0x6e, 0xe0, 0x3c, 0x37, 0xb0, 0x9e,
		0x1b, 0x78, 0xc7, 0x82, 0x79, 0x30, 0xb8, 0x4f, 0x46, 0xf1, 0x0a, 0x11, 0x60, 0xb7, 0xb0, 0xf7,
		0x2e, 0x48, 0xcd, 0x86, 0x2b, 0x98, 0x3b, 0x48, 0x4e, 0xf6, 0x32, 0x88, 0xb7, 0x24, 0x78, 0x26,
		0x2b, 0xac, 0xf7, 0x43, 0x0f, 0x4d, 0x27, 0x7e, 0xba, 0x06, 0x4b, 0x7c, 0x63, 0xf3, 0x30, 0x49,
		0x6f, 0x81, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xc8, 0x3a, 0x7b, 0x14,
		0xd1, 0xb4, 0xae, 0xc4, 0xb0, 0x11, 0x47, 0xeb, 0x0a, 0xe0, 0xa5, 0x72, 0x53, 0xd2, 0xd7, 0xd0,
		0xd2, 0xf7, 0x5c, 0xbf, 0xb4, 0x46, 0xa4, 0x20, 0x0f, 0xe4, 0x20, 0x5f, 0x24, 0x21, 0x2f, 0x64,
		0x21, 0x77, 0xa4, 0x21, 0x77, 0xe4, 0x21, 0x77, 0x24, 0x02, 0x93, 0x4c, 0x80, 0x92, 0x8a, 0x64,
		0x74, 0x61, 0x15, 0xb5, 0x54, 0xde, 0xec, 0x4b, 0xa5, 0x0b, 0x65, 0xe4, 0x9c, 0x39, 0x46, 0xf1,
		0x32, 0xb0, 0x89, 0x98, 0x1d, 0x20, 0x5e, 0xbf, 0xb0, 0x31, 0x67, 0x0b, 0xbd, 0x43, 0x44, 0xce,
		0xe8, 0x65, 0xca, 0x5c, 0xf0, 0x0e, 0x12, 0x29, 0x7b, 0x73, 0xb0, 0x6a, 0x3e, 0x27, 0x70, 0x34,
		0x1d, 0x62, 0xfe, 0x03, 0x43, 0x2c, 0xe3, 0x10, 0x2b, 0x97, 0x4a, 0xfb, 0x25, 0x86, 0xd9, 0x66,
		0x71, 0x51, 0x7c, 0xeb, 0x6e, 0xde, 0xf1, 0x7e, 0xe5, 0x34, 0x8d, 0x03, 0x57, 0xc2, 0xa5, 0xa6,
		0x14, 0xa8, 0x15, 0x71, 0x39, 0x41, 0x15, 0xea, 0x82, 0xab, 0x74, 0x46, 0xea, 0x82, 0x2b, 0x8d,
		0x1c, 0xea, 0x82, 0x19, 0x1b, 0x4c, 0x5d, 0x70, 0x8d, 0x27, 0x62, 0x39, 0xd3, 0x05, 0x0f, 0x72,
		0x20, 0x0b, 0x96, 0x28, 0x0b, 0x2e, 0xf9, 0xa2, 0x2c, 0x48, 0xcd, 0x82, 0xb2, 0xe0, 0x06, 0xa2,
		0xd1, 0x74, 0x88, 0x51, 0x16, 0xcc, 0x3c, 0xc4, 0xf6, 0x4a, 0x14, 0x05, 0x37, 0x8c, 0x88, 0xe2,
		0x5b, 0x47, 0x51, 0x30, 0xb7, 0x49, 0x3c, 0x56, 0xda, 0xee, 0xc7, 0xd9, 0x25, 0x0f, 0xaa, 0x60,
		0x6c, 0x2b, 0x65, 0xc1, 0xb7, 0x98, 0x47, 0x59, 0x70, 0x85, 0xde, 0x48, 0x59, 0x70, 0xa5, 0x91,
		0x43, 0x59, 0x30, 0x63, 0x83, 0x29, 0x0b, 0xae, 0xf1, 0x44, 0x2c, 0x47, 0xb2, 0x60, 0x53, 0x2a,
		0x3f, 0x7c, 0xcc, 0x81, 0x2e, 0x78, 0x08, 0x6c, 0xe2, 0xa9, 0x50, 0xb7, 0xa3, 0x85, 0xb9, 0x14,
		0x06, 0x97, 0x55, 0x2d, 0x28, 0x0c, 0x66, 0xae, 0x5a, 0x14, 0xa8, 0x59, 0x6c, 0x18, 0x1e, 0x4d,
		0x87, 0x18, 0x85, 0xc1, 0xcc, 0x43, 0x8c, 0xf5, 0x82, 0x1b, 0x48, 0x46, 0xf1, 0xad, 0xa3, 0x34,
		0x98, 0xdb, 0x34, 0xee, 0x88, 0x07, 0x2d, 0x54, 0x5b, 0xb4, 0xf1, 0x85, 0xc1, 0xc4, 0x52, 0xca,
		0x82, 0x6f, 0x31, 0x8f, 0xb2, 0xe0, 0x0a, 0x7d, 0x91, 0xb2, 0xe0, 0x4a, 0x23, 0x87, 0xb2, 0x60,
		0xc6, 0x06, 0x53, 0x16, 0x5c, 0xe3, 0x69, 0x58, 0x9e, 0x64, 0x41, 0xb8, 0x6d, 0xbf, 0xe6, 0xc1,
		0x38, 0xc8, 0x36, 0x60, 0x24, 0xb5, 0x6f, 0x19, 0xc3, 0xa0, 0x37, 0x9c, 0x79, 0xfa, 0x5d, 0x7c,
		0x52, 0x9b, 0x58, 0x4a, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b,
		0x52, 0x4b, 0x52, 0x4b, 0x52, 0xcb, 0xa0, 0x98, 0x1e, 0xc3, 0x9e, 0x1f, 0x6a, 0x99, 0x07, 0x4e,
		0x3b, 0x31, 0x94, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94,
		0x96, 0x94, 0x96, 0x94, 0x96, 0x41, 0x31, 0x3d, 0x86, 0x3a, 0xf4, 0x55, 0x24, 0xb5, 0xbc, 0xcf,
		0xc1, 0xba, 0xa4, 0x17, 0xb6, 0x92, 0xd8, 0x92, 0xd8, 0x92, 0xd8, 0x92, 0xd8, 0x92, 0xd8, 0x92,
		0xd8, 0x92, 0xd8, 0x92, 0xd8, 0x92, 0xd8, 0xd2, 0x22, 0xd0, 0x10, 0x75, 0xaa, 0x4a, 0x05, 0xda,
		0xd7, 0x32, 0xc0, 0x5c, 0x00, 0xe5, 0x44, 0xad, 0x6f, 0xe2, 0xce, 0xef, 0x8d, 0x37, 0xa0, 0xf4,
		0x82, 0x9e, 0x50, 0xad, 0x11, 0x51, 0x74, 0x95, 0xd0, 0x3f, 0x83, 0xf0, 0x87, 0x2b, 0x55, 0xa4,
		0x7d, 0xd5, 0x12, 0xde, 0xeb, 0x13, 0x51, 0xea, 0x8c, 0xd7, 0x0b, 0x03, 0x1d, 0xb4, 0x82, 0x6e,
		0x94, 0x1c, 0x79, 0xcd, 0xdb, 0x9e, 0x17, 0xca, 0xa6, 0xe7, 0x77, 0xa4, 0x1b, 0xf9, 0x1d, 0x19,
		0x25, 0x47, 0x9e, 0xec, 0xdd, 0x97, 0xdd, 0x28, 0xd4, 0xc2, 0xed, 0x05, 0x5d, 0xd9, 0x7a, 0xf4,
		0x94, 0x90, 0xb7, 0xdf, 0x9a, 0x41, 0x18, 0x25, 0x47, 0x9e, 0xdf, 0xfe, 0x3e, 0x42, 0xab, 0xa0,
		0xaf, 0xdd, 0x5e, 0x28, 0xbc, 0x30, 0xe8, 0x6b, 0x11, 0xc5, 0x3f, 0xbc, 0xbe, 0xfa, 0xa1, 0x82,
		0x9f, 0xca, 0xf5, 0xb5, 0x0e, 0x65, 0x73, 0xf4, 0x46, 0xea, 0x54, 0xbc, 0xa3, 0x26, 0xf7, 0xd1,
		0x44, 0xb6, 0x04, 0x65, 0x5f, 0xfd, 0xff, 0x8a, 0x47, 0xc4, 0xc6, 0xb8, 0xce, 0xa9, 0x8c, 0x74,
		0x55, 0x6b, 0xb0, 0x4d, 0xff, 0x3f, 0x4b, 0x75, 0xd2, 0x15, 0x43, 0x56, 0x19, 0x61, 0xcd, 0x2a,
		0x9d, 0xcf, 0xfe, 0xc3, 0x0b, 0xcb, 0x0a, 0x07, 0xc5, 0x62, 0xb9, 0x52, 0x2c, 0xee, 0x56, 0xf6,
		0x2b, 0xbb, 0x87, 0xa5, 0x52, 0xa1, 0x5c, 0x00, 0x5a, 0xc4, 0xe5, 0xd4, 0xc3, 0xb6, 0x08, 0x45,
		0xfb, 0xe3, 0xd0, 0xf5, 0x54, 0xbf, 0xdb, 0x65, 0x44, 0xe2, 0xc3, 0xe7, 0xfa, 0xc3, 0xa6, 0x03,
		0xb5, 0xc1, 0x72, 0xd8, 0x6f, 0x69, 0x35, 0x9e, 0x42, 0x9c, 0xc5, 0x77, 0xaf, 0x36, 0xbe, 0x79,
		0x8d, 0xf3, 0xf1, 0x2d, 0x6b, 0x7c, 0xbc, 0xed, 0x35, 0x2e, 0x64, 0xb3, 0x51, 0xed, 0xc8, 0x4b,
		0xbf, 0x23, 0x1b, 0xb5, 0xde, 0x7d, 0xf9, 0x32, 0xd4, 0xe2, 0x7c, 0x74, 0x97, 0x1a, 0x67, 0xe3,
		0x7b, 0xd3, 0xa8, 0xb6, 0xbf, 0x5f, 0xc8, 0x66, 0xbd, 0xaf, 0xcf, 0x43, 0xd1, 0xb8, 0x18, 0xde,
		0x91, 0xc6, 0x97, 0xf8, 0xcf, 0xaf, 0x26, 0x7f, 0xfd, 0x3b, 0x82, 0xb3, 0x7d, 0x0b, 0x2c, 0x27,
		0x21, 0xb4, 0xe4, 0xb3, 0x6e, 0x49, 0xc7, 0x6e, 0x90, 0xd9, 0x73, 0x6d, 0x3b, 0x57, 0xb6, 0x14,
		0x4c, 0x13, 0x4e, 0x3d, 0xf4, 0x5a, 0x57, 0xb6, 0xb7, 0x84, 0x6a, 0xf7, 0x02, 0xa9, 0xf4, 0x56,
		0x2b, 0xe8, 0x06, 0xa1, 0x25, 0x94, 0xc1, 0x20, 0xd4, 0x38, 0x04, 0x1a, 0x9a, 0x30, 0x63, 0x10,
		0x64, 0x5b, 0xe1, 0x03, 0x82, 0x41, 0xb9, 0xc6, 0x1e, 0x8b, 0x5c, 0x36, 0x7b, 0xee, 0x6a, 0x07,
		0x45, 0xcd, 0x63, 0x98, 0xd9, 0x2b, 0x1a, 0x0e, 0x77, 0xdb, 0x61, 0x9e, 0xd3, 0xf0, 0x36, 0xeb,
		0xfb, 0xe6, 0x3c, 0xd0, 0xcc, 0x95, 0x0c, 0xf9, 0xb8, 0x2d, 0xdf, 0xce, 0x9b, 0x4f, 0x1b, 0x44,
		0xa9, 0x2c, 0x51, 0xc9, 0x4c, 0x4c, 0x66, 0x1f, 0x21, 0x06, 0xa2, 0xc3, 0x99, 0xb8, 0x82, 0xeb,
		0xb7, 0xdb, 0xa1, 0x88, 0x22, 0x63, 0xf1, 0x91, 0x3c, 0x8f, 0x4f, 0x59, 0x60, 0x28, 0x27, 0x98,
		0xad, 0x95, 0x33, 0x5e, 0xfb, 0x66, 0xa3, 0x96, 0xcd, 0x6e, 0x6d, 0x9a, 0xad, 0x5a, 0x33, 0xeb,
		0xb5, 0x63, 0xd6, 0x6b, 0xc1, 0xac, 0xd7, 0x76, 0xad, 0x17, 0x5b, 0x31, 0x5e, 0x4b, 0x95, 0xc4,
		0x6d, 0x57, 0xf8, 0x9d, 0x50, 0x74, 0x4c, 0x06, 0xed, 0xa4, 0xd6, 0xa9, 0x62, 0xf0, 0x9a, 0xe7,
		0x63, 0x42, 0xf6, 0xe1, 0x43, 0x5c, 0x9a, 0xe1, 0xa5, 0x30, 0x88, 0x0c, 0x62, 0x01, 0x22, 0xe7,
		0x6b, 0x61, 0x9e, 0x36, 0xc4, 0x97, 0x35, 0xcb, 0x15, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a,
		0xe4, 0x0a, 0x38, 0x5c, 0xe1, 0x58, 0x9a, 0x7d, 0x82, 0x64, 0x6f, 0xc2, 0x88, 0x32, 0x71, 0xb4,
		0x34, 0x81, 0xb4, 0x06, 0x0e, 0x36, 0x41, 0x02, 0x03, 0x2c, 0x6c, 0x83, 0x06, 0x0c, 0x78, 0xc0,
		0x80, 0x08, 0x0c, 0x98, 0x98, 0x05, 0x15, 0xc3, 0xe0, 0x62, 0x6f, 0x42, 0x9a, 0x8a, 0x7b, 0xd9,
		0xb3, 0x94, 0xe5, 0xa7, 0xe8, 0xbf, 0x85, 0x9d, 0x82, 0x26, 0xf7, 0xde, 0xce, 0xfe, 0x3f, 0x16,
		0x9f, 0xf6, 0x3f, 0x8f, 0xfc, 0x7d, 0xd1, 0xe2, 0xd8, 0xa7, 0x7c, 0xe0, 0xc0, 0xa2, 0x0d, 0xe7,
		0xbe, 0xd6, 0x22, 0x54, 0xd6, 0xb7, 0x83, 0x72, 0xfe, 0xde, 0xde, 0xbe, 0xde, 0x75, 0x0f, 0x6f,
		0x9e, 0xae, 0x0b, 0xee, 0xe1, 0x4d, 0x7c, 0x58, 0x18, 0xfd, 0x88, 0x8f, 0xf7, 0xae, 0x77, 0xdd,
		0xe2, 0xe4, 0xb8, 0x74, 0xbd, 0xeb, 0x96, 0x6e, 0x76, 0xfe, 0xfa, 0xeb, 0xc3, 0xce, 0xaf, 0xfd,
		0xc1, 0xe2, 0x5f, 0xfc, 0x8f, 0xbd, 0x2a, 0xbd, 0x1b, 0x9b, 0x83, 0x5d, 0xbf, 0xac, 0xfd, 0x8f,
		0x23, 0x6e, 0x7a, 0xc4, 0x37, 0xa9, 0xb4, 0x0b, 0x23, 0xbd, 0x97, 0x99, 0xde, 0x31, 0xd3, 0xbb,
		0xef, 0x76, 0xaa, 0xee, 0xa7, 0x9b, 0x5f, 0x85, 0xf7, 0xc5, 0xc1, 0xd1, 0xce, 0xaf, 0xca, 0xe0,
		0xf5, 0xc9, 0xa7, 0x59, 0x1f, 0x2b, 0xbc, 0xaf, 0x0c, 0x8e, 0xe6, 0xbc, 0x53, 0x1e, 0x1c, 0xfd,
		0xe6, 0xef, 0x28, 0x0d, 0xb6, 0x53, 0x1f, 0x1d, 0x9e, 0xdf, 0x9b, 0xf7, 0x85, 0xe2, 0x9c, 0x2f,
		0xec, 0xcf, 0xfb, 0xc2, 0xfe, 0x9c, 0x2f, 0xcc, 0x35, 0x69, 0x6f, 0xce, 0x17, 0x4a, 0x83, 0xa7,
		0xd4, 0xe7, 0xb7, 0x67, 0x7f, 0xb4, 0x3c, 0xd8, 0x79, 0x9a, 0xf7, 0x5e, 0x65, 0xf0, 0x74, 0xb4,
		0x43, 0xb0, 0xa3, 0xff, 0xd3, 0xff, 0x37, 0x0a, 0xfa, 0xdf, 0xad, 0xf7, 0xdf, 0xc9, 0x92, 0xc5,
		0x37, 0x2a, 0x5b, 0x2c, 0x59, 0x9c, 0x59, 0xb2, 0x68, 0xb0, 0x97, 0x82, 0x81, 0xe7, 0xf3, 0xef,
		0x72, 0xec, 0xaa, 0x93, 0x75, 0x55, 0x86, 0x9f, 0xc3, 0x98, 0x5d, 0x39, 0x65, 0x7e, 0x85, 0x14,
		0xc4, 0x4a, 0x28, 0xb3, 0x2b, 0x9e, 0xb2, 0x76, 0x54, 0xc3, 0xb9, 0x14, 0x3d, 0x87, 0x3a, 0x46,
		0xaa, 0x82, 0x56, 0x59, 0xde, 0x9d, 0x6d, 0xbe, 0xcf, 0x2e, 0x0b, 0x67, 0xf3, 0x9b, 0x33, 0x0a,
		0x17, 0x53, 0x61, 0x02, 0x1a, 0x1e, 0xd9, 0xf8, 0xd8, 0xea, 0x3d, 0x60, 0xb5, 0xbf, 0x71, 0xc5,
		0xbe, 0x94, 0xb5, 0x0f, 0x41, 0xf9, 0x4e, 0x06, 0x79, 0x74, 0x35, 0x79, 0x73, 0xb5, 0xae, 0xbc,
		0x3a, 0x87, 0x5b, 0xa1, 0xb3, 0xc5, 0xc2, 0x71, 0x5f, 0xc9, 0x96, 0x1f, 0xe9, 0x95, 0xbb, 0xda,
		0xb4, 0x3c, 0x3d, 0xb9, 0xca, 0x8a, 0x43, 0x25, 0x9b, 0xa2, 0xd2, 0xcc, 0xea, 0x83, 0xb2, 0xac,
		0xff, 0x31, 0x53, 0xdf, 0x93, 0x75, 0xfd, 0x8e, 0xb1, 0xfa, 0x1c, 0x63, 0xf5, 0x37, 0xc6, 0xea,
		0x6b, 0xb0, 0x41, 0x2d, 0xab, 0x22, 0x4b, 0xa7, 0x1b, 0xdf, 0xd3, 0xec, 0x3c, 0x32, 0x59, 0xd8,
		0x31, 0xbe, 0x50, 0x46, 0x6e, 0x92, 0x6d, 0x7d, 0xfc, 0x73, 0x4a, 0xdb, 0xcb, 0xe8, 0x02, 0x06,
		0x4a, 0x1b, 0xcd, 0x96, 0x30, 0x9a, 0x2a, 0x55, 0x34, 0x5e, 0x92, 0x68, 0xbc, 0xf4, 0xd0, 0x78,
		0x89, 0x61, 0xbe, 0xe6, 0x8c, 0x59, 0xd7, 0x9f, 0x3b, 0xe3, 0x36, 0x0b, 0x99, 0x3b, 0xf2, 0x24,
		0x3c, 0xc7, 0xd7, 0xcb, 0x5a, 0x3a, 0x35, 0xb2, 0xa0, 0xc8, 0x58, 0xad, 0xb8, 0xc9, 0xda, 0x70,
		0x3b, 0xb5, 0xe0, 0xa6, 0x6b, 0xbf, 0xad, 0xd5, 0x7a, 0x5b, 0xab, 0xed, 0xb6, 0x56, 0xcb, 0x9d,
		0xef, 0x87, 0x30, 0xa6, 0x16, 0x00, 0xc5, 0x89, 0xd1, 0xfc, 0x3a, 0x4f, 0x93, 0xed, 0xb3, 0xb8,
		0xce, 0x73, 0x5d, 0xd2, 0xb5, 0xad, 0xb4, 0x6d, 0x3d, 0x7d, 0x5b, 0x4f, 0xe3, 0xd6, 0xd3, 0xb9,
		0x99, 0xb4, 0x6e, 0x28, 0xbd, 0x1b, 0x4f, 0xf3, 0xc9, 0x05, 0x83, 0x50, 0xde, 0x4a, 0x65, 0x6f,
		0x75, 0xe7, 0xf8, 0xfa, 0x5c, 0xd3, 0xb9, 0x6e, 0x80, 0x80, 0x01, 0x0c, 0xb6, 0x01, 0x02, 0x06,
		0x28, 0x60, 0x00, 0x03, 0x06, 0x38, 0xcc, 0x02, 0x88, 0x61, 0x20, 0x49, 0xee, 0xb2, 0xfd, 0x35,
		0x9d, 0xe6, 0x9b, 0x0d, 0xa5, 0x78, 0x7e, 0xc5, 0xc2, 0xb5, 0x53, 0xcd, 0x87, 0xc6, 0x48, 0xb7,
		0xae, 0x55, 0xb9, 0x06, 0xc9, 0xfe, 0xb8, 0xc3, 0xbb, 0x3d, 0xd2, 0x32, 0x31, 0x80, 0xac, 0x85,
		0xac, 0x85, 0xac, 0x85, 0xac, 0x85, 0xac, 0x85, 0xac, 0x65, 0x4d, 0x59, 0xcb, 0x04, 0xea, 0x48,
		0x5b, 0x96, 0xa7, 0x2d, 0x76, 0xe0, 0xec, 0x99, 0xb5, 0x58, 0x11, 0x28, 0x49, 0x5a, 0x48, 0x5a,
		0x48, 0x5a, 0x48, 0x5a, 0x48, 0x5a, 0x48, 0x5a, 0x8c, 0x91, 0x96, 0x38, 0xec, 0xc9, 0x59, 0x96,
		0xbe, 0xb5, 0x66, 0xbb, 0x3e, 0xa7, 0x1c, 0xda, 0x64, 0xf7, 0xe7, 0x94, 0x2b, 0x93, 0xb1, 0x90,
		0xb1, 0x90, 0xb1, 0x90, 0xb1, 0xac, 0x2f, 0x63, 0x31, 0x5d, 0x6d, 0x90, 0x5c, 0xd8, 0xd7, 0x3a,
		0x74, 0xa5, 0x6a, 0x8b, 0x07, 0x7b, 0x41, 0x37, 0x49, 0x3d, 0x2f, 0x6c, 0xb1, 0xb5, 0x71, 0xad,
		0x95, 0x29, 0xb2, 0x75, 0xe0, 0x41, 0x00, 0x20, 0x2c, 0x20, 0x42, 0x01, 0x24, 0x38, 0x60, 0x82,
		0x03, 0x28, 0x38, 0xa0, 0xb2, 0x03, 0x58, 0x96, 0x80, 0xcb, 0xfe, 0x94, 0x1b, 0x68, 0xea, 0x8d,
		0x30, 0x05, 0x9f, 0x35, 0x15, 0x9f, 0xf9, 0x6f, 0x04, 0xb6, 0x91, 0xd0, 0x51, 0x72, 0x34, 0x9e,
		0xb2, 0xc7, 0x00, 0xbc, 0x29, 0x3b, 0x0c, 0x5b, 0x98, 0xe3, 0xb4, 0x82, 0xbb, 0xbb, 0xbe, 0x92,
		0xfa, 0x11, 0x85, 0x77, 0xbd, 0x36, 0x88, 0xe4, 0x8b, 0xe4, 0x8b, 0xe4, 0x8b, 0xe4, 0x8b, 0xe4,
		0x8b, 0xe4, 0x8b, 0xe4, 0x2b, 0x0b, 0xf2, 0x35, 0x41, 0x5c, 0x29, 0xa2, 0xe4, 0xf8, 0x91, 0xfc,
		0xcb, 0xcc, 0xe0, 0x88, 0x07, 0xed, 0xc2, 0x71, 0xb0, 0x59, 0x46, 0x91, 0x87, 0x91, 0x87, 0x91,
		0x87, 0x91, 0x87, 0x91, 0x87, 0x91, 0x87, 0x91, 0x87, 0x65, 0xc1, 0xc3, 0x5e, 0xa2, 0xee, 0x90,
		0x8b, 0x4d, 0xa1, 0x30, 0xf9, 0x98, 0x99, 0x41, 0x92, 0xea, 0xde, 0xef, 0xca, 0xb6, 0x1b, 0x0a,
		0x3f, 0x0a, 0x94, 0x7d, 0x2a, 0xf6, 0xca, 0x1e, 0xb2, 0x30, 0xb2, 0x30, 0xb2, 0x30, 0xb2, 0x30,
		0xb2, 0x30, 0xb2, 0xb0, 0x45, 0x91, 0xa4, 0x2d, 0x94, 0x96, 0xfa, 0x11, 0x84, 0x89, 0x95, 0x2c,
		0xda, 0x50, 0x1b, 0xdf, 0x8a, 0x8f, 0x7e, 0x04, 0x90, 0xc2, 0x26, 0x03, 0x54, 0x3b, 0xfb, 0x5a,
		0x3d, 0xad, 0x1d, 0x37, 0x2e, 0xea, 0x5f, 0xae, 0x4e, 0x1a, 0x17, 0x27, 0xd5, 0xcb, 0xfa, 0x99,
		0xed, 0x6c, 0xf6, 0xd5, 0xef, 0xf6, 0x47, 0xfd, 0x17, 0xed, 0xee, 0xc9, 0xb6, 0x65, 0x75, 0xbb,
		0xca, 0x7f, 0x1c, 0xad, 0x3f, 0x4e, 0xbf, 0x5c, 0x5e, 0x9d, 0x5c, 0x34, 0x4e, 0xeb, 0xf5, 0x73,
		0xc7, 0xba, 0x89, 0x83, 0xf7, 0x1c, 0xa7, 0xd9, 0xe3, 0x54, 0xbd, 0xe4, 0x10, 0x81, 0x0f, 0x51,
		0xfd, 0xa2, 0xf6, 0x67, 0xed, 0xac, 0x7a, 0x55, 0xbf, 0xe0, 0x28, 0x01, 0x27, 0xbc, 0xfa, 0xd9,
		0xa7, 0x93, 0x63, 0x80, 0x11, 0xb2, 0x6a, 0xc1, 0xcd, 0xa6, 0xf1, 0xe7, 0x8d, 0x50, 0x7f, 0xba,
		0x7e, 0xa4, 0xdd, 0xbb, 0xa0, 0x2d, 0x3b, 0x52, 0xb4, 0xed, 0x8b, 0x3f, 0xd3, 0xe6, 0x50, 0xfb,
		0xa1, 0xf6, 0x43, 0xed, 0x87, 0xda, 0x0f, 0xb5, 0x1f, 0x6a, 0x3f, 0x0b, 0xe6, 0x0d, 0x2d, 0xef,
		0x84, 0x96, 0xad, 0x1f, 0x51, 0xb9, 0x08, 0xa0, 0xfd, 0x1c, 0x58, 0x34, 0xe1, 0x8b, 0x92, 0xa3,
		0x8d, 0x55, 0x1d, 0xe5, 0xab, 0x20, 0x12, 0xad, 0x40, 0xb5, 0x23, 0x9b, 0xb7, 0xe4, 0xc2, 0x57,
		0xb7, 0xc2, 0xba, 0xbe, 0x62, 0x7f, 0xaa, 0xe1, 0x7c, 0x96, 0xca, 0x3a, 0xa2, 0x80, 0x70, 0x9e,
		0x94, 0x39, 0x23, 0x15, 0x0e, 0xc8, 0x9e, 0x4f, 0xa1, 0xdf, 0xd2, 0x32, 0x50, 0xc7, 0xf2, 0x36,
		0x8e, 0xa6, 0x5d, 0xce, 0xd7, 0xe3, 0xad, 0x9b, 0xe9, 0xc2, 0xff, 0xe2, 0xc2, 0x76, 0x36, 0xb4,
		0xce, 0xad, 0x57, 0xbf, 0xdb, 0xcc, 0xab, 0xdf, 0x50, 0xe3, 0xc8, 0xcc, 0xcd, 0x2d, 0xb5, 0xf6,
		0x4f, 0xcf, 0x65, 0x6d, 0xb4, 0xf8, 0xa7, 0xaa, 0x41, 0x55, 0x83, 0xaa, 0x06, 0x55, 0x0d, 0xaa,
		0x1a, 0x6b, 0xa0, 0x6a, 0xf4, 0x95, 0xb4, 0x56, 0x12, 0xf9, 0x12, 0x44, 0x0a, 0x87, 0x16, 0x6d,
		0x18, 0x0f, 0xc7, 0xc6, 0xeb, 0x07, 0xcf, 0x7b, 0xb6, 0xbb, 0x7e, 0xbb, 0x1d, 0x8a, 0x28, 0x72,
		0x00, 0xa6, 0x84, 0x00, 0x1e, 0x82, 0xe5, 0x29, 0x38, 0x1e, 0x33, 0xc3, 0x73, 0xee, 0x8b, 0x40,
		0xbe, 0x93, 0xf2, 0xa1, 0x03, 0x20, 0x9b, 0xce, 0x7d, 0xad, 0x45, 0xa8, 0x60, 0xdc, 0x29, 0x31,
		0xec, 0xef, 0xed, 0xed, 0xeb, 0x5d, 0xf7, 0xf0, 0xe6, 0xe9, 0xba, 0xe0, 0x1e, 0xde, 0xc4, 0x87,
		0x85, 0xd1, 0x8f, 0xf8, 0x78, 0xef, 0x7a, 0xd7, 0x2d, 0x4e, 0x8e, 0x4b, 0xd7, 0xbb, 0x6e, 0xe9,
		0x66, 0xe7, 0xaf, 0xbf, 0x3e, 0xec, 0xfc, 0xda, 0x1f, 0x2c, 0xfe, 0xc5, 0xff, 0x38, 0x30, 0x7f,
		0xfc, 0x0d, 0x92, 0x73, 0xd4, 0x2f, 0x6b, 0xff, 0xa3, 0x87, 0xa0, 0x79, 0x08, 0x84, 0x25, 0x83,
		0xf7, 0x84, 0x9f, 0xb9, 0xf0, 0x53, 0x26, 0xfc, 0xac, 0x07, 0xfc, 0xf8, 0x6e, 0xa7, 0xea, 0x7e,
		0xba, 0xf9, 0x55, 0x78, 0x5f, 0x1c, 0x1c, 0xed, 0xfc, 0xaa, 0x0c, 0x5e, 0x9f, 0x7c, 0x9a, 0xf5,
		0xb1, 0xc2, 0xfb, 0xca, 0xe0, 0x68, 0xce, 0x3b, 0xe5, 0xc1, 0xd1, 0x6f, 0xfe, 0x8e, 0xd2, 0x60,
		0x3b, 0xf5, 0xd1, 0xe1, 0xf9, 0xbd, 0x79, 0x5f, 0x28, 0xce, 0xf9, 0xc2, 0xfe, 0xbc, 0x2f, 0xec,
		0xcf, 0xf9, 0xc2, 0x5c, 0x93, 0xf6, 0xe6, 0x7c, 0xa1, 0x34, 0x78, 0x4a, 0x7d, 0x7e, 0x7b, 0xf6,
		0x47, 0xcb, 0x83, 0x9d, 0xa7, 0x79, 0xef, 0x55, 0x06, 0x4f, 0x47, 0x3b, 0x04, 0xe3, 0x1c, 0x83,
		0x31, 0xe3, 0x65, 0xb3, 0xe3, 0x05, 0x83, 0x9a, 0xbc, 0xdb, 0xec, 0xfb, 0x60, 0x99, 0x9a, 0x21,
		0x69, 0x48, 0x10, 0x4b, 0xe5, 0x52, 0x0c, 0x0c, 0xe0, 0x41, 0x39, 0xd6, 0xd2, 0xb9, 0xd4, 0xc0,
		0xd5, 0xce, 0x2e, 0xaf, 0xaa, 0xa7, 0xa7, 0x8d, 0xf3, 0x8b, 0xfa, 0x55, 0xfd, 0x8f, 0xfa, 0x69,
		0xe3, 0xea, 0xff, 0xce, 0x4f, 0x1c, 0xa4, 0x12, 0x88, 0x08, 0x0a, 0x83, 0x7f, 0x61, 0xb1, 0x81,
		0xc9, 0x30, 0x9e, 0xd7, 0x3e, 0xe3, 0x80, 0xd3, 0xe0, 0x3d, 0x87, 0xeb, 0x5f, 0xa2, 0xee, 0xcf,
		0xcf, 0xe7, 0x1c, 0xaf, 0xfc, 0x8c, 0xd7, 0x71, 0xed, 0xe2, 0xe4, 0x8f, 0xab, 0xd3, 0xff, 0x6b,
		0xfc, 0x51, 0x3f, 0x3b, 0x3b, 0xf9, 0xe3, 0x0a, 0x61, 0x35, 0x17, 0x47, 0xef, 0x77, 0x47, 0xaf,
		0x7e, 0x79, 0xfe, 0x69, 0x9f, 0x03, 0x96, 0x9f, 0x01, 0xbb, 0xbc, 0xaa, 0x5e, 0xd5, 0xfe, 0xe0,
		0x88, 0xe5, 0x08, 0xd0, 0x2e, 0x6b, 0x97, 0x1c, 0xaf, 0xfc, 0x8c, 0xd7, 0xc7, 0x3f, 0xc9, 0x3f,
		0x72, 0x86, 0x60, 0x1c, 0xaf, 0xfc, 0x8c, 0xd7, 0x69, 0xfd, 0x8f, 0xea, 0x69, 0xa3, 0xfa, 0xe7,
		0x9f, 0x17, 0x27, 0x7f, 0x56, 0xaf, 0x4e, 0x80, 0x86, 0x0e, 0xc2, 0x92, 0x1b, 0x2e, 0x13, 0xd8,
		0xa8, 0x3b, 0xbf, 0x19, 0xcb, 0x04, 0x26, 0x3b, 0xfc, 0x5b, 0x5f, 0x27, 0x30, 0x31, 0xc4, 0x52,
		0xb9, 0xeb, 0xb1, 0xe8, 0xf8, 0xfd, 0xee, 0xa8, 0xd6, 0x78, 0x97, 0x8b, 0x15, 0xb8, 0x58, 0x81,
		0x8b, 0x15, 0xa6, 0x3c, 0x93, 0x8b, 0x15, 0xfe, 0xc5, 0x20, 0x2e, 0x56, 0xd8, 0xe2, 0x62, 0x85,
		0xa3, 0x2d, 0xa7, 0x2f, 0x95, 0xde, 0xdf, 0x03, 0x58, 0xad, 0x50, 0x61, 0xb7, 0x03, 0x76, 0x3b,
		0x00, 0xa2, 0x17, 0x29, 0x73, 0xd8, 0xed, 0x20, 0x0f, 0x9a, 0x05, 0xbb, 0x1d, 0xfc, 0x86, 0x0b,
		0x17, 0xf7, 0x0e, 0x8b, 0x87, 0xe5, 0xca, 0xde, 0x21, 0x7b, 0x1c, 0x50, 0xbc, 0xa0, 0x78, 0x61,
		0x4e, 0xbc, 0xb0, 0x3b, 0x61, 0x7c, 0xd6, 0x2e, 0x6c, 0xce, 0x89, 0x28, 0x1b, 0x50, 0x36, 0xa0,
		0x6c, 0x40, 0xd9, 0x80, 0xb2, 0x41, 0x8e, 0x65, 0x83, 0xd1, 0xaa, 0x30, 0xeb, 0x31, 0x82, 0xb0,
		0x08, 0x0c, 0x66, 0xd1, 0x17, 0x17, 0xad, 0xd8, 0x5b, 0xb4, 0xe2, 0x6d, 0x17, 0xf6, 0xae, 0x77,
		0xdd, 0x83, 0x78, 0xe5, 0x6d, 0xe1, 0x26, 0xb5, 0x20, 0x77, 0xf4, 0x5f, 0x9b, 0x6b, 0x5b, 0x6e,
		0x6c, 0x46, 0x08, 0xd2, 0x5a, 0x2f, 0x86, 0x09, 0xc3, 0x84, 0xb3, 0x5f, 0x1b, 0xb3, 0xdf, 0xf1,
		0x8e, 0x91, 0x41, 0x5f, 0x0b, 0xfb, 0x53, 0xe0, 0x97, 0xc6, 0x70, 0x1e, 0xcc, 0x79, 0x30, 0xe7,
		0xc1, 0x9c, 0x07, 0x73, 0x1e, 0xcc, 0x79, 0xf0, 0x82, 0x79, 0xa3, 0x19, 0x04, 0x5d, 0xe1, 0x43,
		0x74, 0xfb, 0x2b, 0x6c, 0x0a, 0x75, 0x79, 0xb7, 0xc6, 0x2e, 0xee, 0x54, 0x95, 0x0a, 0xb4, 0xaf,
		0xa5, 0xa5, 0x4d, 0xbe, 0x9d, 0xa8, 0xf5, 0x4d, 0xdc, 0xf9, 0xbd, 0xf1, 0x9e, 0xf0, 0x5e, 0xd0,
		0x13, 0xaa, 0x35, 0x22, 0x0a, 0xae, 0x12, 0xfa, 0x67, 0x10, 0xfe, 0x70, 0xa5, 0x8a, 0xb4, 0xaf,
		0x5a, 0xc2, 0x7b, 0x7d, 0x22, 0x4a, 0x9d, 0xf1, 0x7a, 0x61, 0xa0, 0x83, 0x56, 0xd0, 0x8d, 0x92,
		0x23, 0xaf, 0x79, 0xdb, 0xf3, 0x42, 0xd9, 0xf4, 0xfc, 0x8e, 0x74, 0x23, 0xbf, 0x23, 0xa3, 0xe4,
		0xc8, 0x1b, 0x89, 0x4a, 0x7d, 0x25, 0x5b, 0x7e, 0xa4, 0xbd, 0x6e, 0x9c, 0x56, 0xbd, 0x11, 0x45,
		0x8b, 0xe2, 0x1f, 0xf1, 0x6e, 0xf3, 0x66, 0xb3, 0xac, 0x39, 0x77, 0x33, 0xe8, 0x6a, 0x4e, 0x5f,
		0xfd, 0x50, 0xc1, 0x4f, 0xe5, 0xfa, 0x5a, 0x87, 0xb2, 0x39, 0xbc, 0xc3, 0xc6, 0xdd, 0xed, 0x45,
		0xbf, 0xd4, 0x94, 0x2d, 0x86, 0x83, 0x6e, 0x92, 0x42, 0x0d, 0x5f, 0xd6, 0x16, 0x03, 0xb7, 0xc9,
		0xbc, 0x31, 0x18, 0xb7, 0x6d, 0xa6, 0x0d, 0xc3, 0xb0, 0x61, 0x98, 0x35, 0x0c, 0xa3, 0x5e, 0x6f,
		0x7a, 0x71, 0x2c, 0x43, 0x3b, 0x61, 0x9f, 0x4a, 0xf2, 0xf6, 0x25, 0xa0, 0xb4, 0x49, 0x76, 0x85,
		0xa0, 0x02, 0x85, 0x20, 0x0a, 0x41, 0x14, 0x82, 0x28, 0x04, 0x51, 0x08, 0x42, 0x87, 0xb3, 0xc4,
		0x80, 0x21, 0x76, 0xb8, 0xda, 0xb6, 0x1c, 0x35, 0x95, 0xc1, 0x9e, 0x4d, 0xb2, 0x1c, 0x1a, 0x18,
		0xc5, 0xcf, 0xd6, 0xe1, 0x0d, 0x09, 0xe6, 0x30, 0xe1, 0x0e, 0x0d, 0xf6, 0x60, 0xe1, 0x0f, 0x16,
		0x06, 0x61, 0xe1, 0xd0, 0x2e, 0x2c, 0x5a, 0x86, 0xc7, 0x64, 0x54, 0xae, 0x10, 0x00, 0x6a, 0x2a,
		0xef, 0x74, 0x85, 0xdf, 0x01, 0x6b, 0x63, 0x5a, 0x01, 0xb0, 0xe5, 0x7c, 0xac, 0xbb, 0x7f, 0xf8,
		0x10, 0x4b, 0xdd, 0xde, 0x33, 0x98, 0x6f, 0xe8, 0x72, 0x14, 0x8b, 0xa1, 0xe3, 0xc4, 0x4f, 0x1b,
		0x60, 0x88, 0x5d, 0x6c, 0x0e, 0x06, 0xa9, 0x2b, 0x90, 0xd4, 0x91, 0xd4, 0x91, 0xd4, 0x91, 0xd4,
		0x91, 0xd4, 0xd9, 0x1a, 0x15, 0xdb, 0xda, 0xc7, 0xb4, 0x06, 0xd2, 0x15, 0x0a, 0xaf, 0xef, 0x7a,
		0x62, 0xd9, 0x7b, 0x2e, 0x07, 0x07, 0x06, 0x51, 0x44, 0x30, 0xc5, 0x06, 0x55, 0x54, 0x70, 0x85,
		0x07, 0x59, 0x78, 0xb0, 0x85, 0x07, 0x5d, 0x0c, 0xf0, 0x05, 0x01, 0x61, 0x3c, 0x85, 0x25, 0x95,
		0xb7, 0xfa, 0x52, 0xe9, 0x42, 0x19, 0x70, 0xe7, 0xbe, 0x32, 0x90, 0x49, 0x18, 0x0d, 0xa0, 0x5e,
		0xbf, 0xb0, 0x72, 0xfa, 0x16, 0x5a, 0x83, 0x28, 0x70, 0x7a, 0x95, 0x32, 0x0f, 0xac, 0x81, 0x54,
		0xca, 0x3e, 0xc0, 0x26, 0x3c, 0xa0, 0xe9, 0x7e, 0x3a, 0x24, 0xfc, 0x07, 0x86, 0xc4, 0x92, 0x21,
		0x51, 0x2e, 0x95, 0xf6, 0x4b, 0x0c, 0x8b, 0x7c, 0x73, 0x31, 0x3c, 0x6b, 0xb8, 0x81, 0x23, 0x4c,
		0xda, 0x04, 0xaa, 0x94, 0x49, 0x51, 0x64, 0x94, 0x8a, 0x19, 0xd0, 0xac, 0x4d, 0x9d, 0x68, 0x11,
		0x67, 0xa2, 0x4e, 0xb4, 0x90, 0xa7, 0x53, 0x27, 0x5a, 0xd2, 0x40, 0xea, 0x44, 0x39, 0x9a, 0x38,
		0x80, 0xeb, 0x44, 0x07, 0x80, 0x32, 0x51, 0x89, 0x32, 0xd1, 0xbf, 0xbc, 0x28, 0x13, 0xad, 0xe5,
		0x9c, 0x98, 0x32, 0x51, 0xde, 0xb3, 0xfd, 0x74, 0x48, 0x50, 0x26, 0x5a, 0x3a, 0x24, 0xf6, 0x4a,
		0x14, 0x89, 0xd6, 0x40, 0x96, 0xd9, 0xa2, 0x48, 0x04, 0x78, 0x3f, 0x60, 0x44, 0xa2, 0xfb, 0x71,
		0xb4, 0x23, 0xaa, 0x44, 0xb1, 0x6d, 0x94, 0x89, 0x66, 0x99, 0x43, 0x99, 0x68, 0x01, 0x6f, 0xa2,
		0x4c, 0xb4, 0x90, 0xa7, 0x53, 0x26, 0x5a, 0xd2, 0x40, 0xca, 0x44, 0x39, 0x9a, 0x38, 0x00, 0xcb,
		0x44, 0x4d, 0xa9, 0xfc, 0xf0, 0x11, 0x50, 0x27, 0x3a, 0x04, 0x32, 0xe9, 0x54, 0xa8, 0xdb, 0xd1,
		0x42, 0x2e, 0x0a, 0x45, 0xff, 0x36, 0x2b, 0xa6, 0x50, 0xb4, 0xf4, 0xac, 0xb8, 0xc0, 0x39, 0x71,
		0xce, 0xf3, 0xfd, 0x74, 0x48, 0x50, 0x28, 0x5a, 0x3a, 0x24, 0x58, 0x4f, 0xb4, 0x26, 0xe2, 0xcc,
		0x16, 0xa5, 0x22, 0xc0, 0xfb, 0x81, 0x20, 0x15, 0x89, 0x07, 0x2d, 0x54, 0x5b, 0xb4, 0xf1, 0x84,
		0xa2, 0xc4, 0x32, 0xca, 0x44, 0xb3, 0xcc, 0xa1, 0x4c, 0xb4, 0x80, 0x2f, 0x51, 0x26, 0x5a, 0xc8,
		0xd3, 0x29, 0x13, 0x2d, 0x69, 0x20, 0x65, 0xa2, 0x1c, 0x4d, 0x1b, 0x90, 0x65, 0x22, 0xeb, 0xfb,
		0x22, 0xcc, 0x83, 0x41, 0x4b, 0xfb, 0x24, 0x90, 0xc4, 0xcd, 0x1a, 0x93, 0xa0, 0x37, 0x9c, 0x09,
		0xf9, 0x5d, 0x3c, 0x12, 0x97, 0x58, 0x46, 0x12, 0x47, 0x12, 0x47, 0x12, 0x47, 0x12, 0x47, 0x12,
		0x47, 0x12, 0x47, 0x12, 0x47, 0x12, 0x47, 0x12, 0xf7, 0x7a, 0x4c, 0x7a, 0x7e, 0xa8, 0x25, 0x22,
		0x87, 0x9b, 0x18, 0x46, 0x0a, 0x47, 0x0a, 0x47, 0x0a, 0x47, 0x0a, 0x47, 0x0a, 0x47, 0x0a, 0x47,
		0x0a, 0x47, 0x0a, 0x47, 0x0a, 0xf7, 0x7a, 0x4c, 0x74, 0xe8, 0xab, 0x48, 0x6a, 0x79, 0x0f, 0x58,
		0x77, 0xff, 0xc2, 0x36, 0x12, 0x39, 0x12, 0x39, 0x12, 0x39, 0x12, 0x39, 0x12, 0x39, 0x12, 0x39,
		0x12, 0x39, 0x12, 0x39, 0x30, 0x22, 0xb7, 0xd1, 0xed, 0xe8, 0x2d, 0x6f, 0x5c, 0x9f, 0xb2, 0x07,
		0x7b, 0x23, 0xfb, 0xf4, 0x9e, 0xe7, 0xe9, 0x53, 0x36, 0x76, 0xbb, 0xc7, 0xf1, 0xe9, 0xcd, 0xda,
		0xc8, 0xf2, 0xbf, 0xe2, 0x11, 0xa1, 0x13, 0x9d, 0x73, 0x2a, 0x23, 0x5d, 0xd5, 0xda, 0xf2, 0xae,
		0x9a, 0x9f, 0xa5, 0x3a, 0xe9, 0x8a, 0x21, 0x6d, 0x8a, 0xec, 0x4e, 0x6b, 0x9c, 0xcf, 0xfe, 0xc3,
		0x0b, 0x4b, 0x0a, 0x07, 0xc5, 0x62, 0xb9, 0x52, 0x2c, 0xee, 0x56, 0xf6, 0x2b, 0xbb, 0x87, 0xa5,
		0x52, 0xa1, 0x5c, 0xb0, 0xb8, 0xca, 0xc0, 0xa9, 0x87, 0x6d, 0x11, 0x8a, 0xf6, 0xc7, 0xa1, 0xeb,
		0xa8, 0x7e, 0xb7, 0xbb, 0x51, 0x11, 0x03, 0x82, 0x37, 0x6b, 0x80, 0x33, 0x8e, 0xd5, 0x2d, 0xd6,
		0xc2, 0x7e, 0x4b, 0xab, 0x31, 0xc9, 0x3d, 0x8b, 0x6f, 0x47, 0x6d, 0x7c, 0x37, 0x1a, 0xe7, 0xe3,
		0x7b, 0xd0, 0xf8, 0x78, 0xdb, 0x6b, 0x5c, 0xc8, 0x66, 0xa3, 0xda, 0x91, 0x97, 0x7e, 0x47, 0x36,
		0x6a, 0xbd, 0xfb, 0xf2, 0x97, 0xf8, 0xef, 0x6e, 0x9c, 0x06, 0xad, 0xe1, 0x5b, 0x17, 0xc3, 0xbf,
		0xb7, 0xf1, 0x25, 0xfe, 0xe3, 0xaa, 0xc9, 0xdf, 0xf6, 0x6e, 0x33, 0xb0, 0xcb, 0xec, 0x15, 0x0d,
		0xc7, 0xbc, 0xed, 0x58, 0xcf, 0x5d, 0x8c, 0x9b, 0xf5, 0x7a, 0x73, 0xbe, 0x67, 0xe6, 0x4a, 0x86,
		0xbc, 0x7b, 0xc2, 0xf9, 0x62, 0x61, 0x6d, 0x2b, 0x08, 0xe5, 0xad, 0x54, 0x5b, 0x43, 0x27, 0x73,
		0xa5, 0xa9, 0xb5, 0x43, 0x76, 0xf8, 0x9e, 0x3d, 0x7e, 0x07, 0xc5, 0xe7, 0xec, 0xf0, 0x37, 0x53,
		0xde, 0x6d, 0x29, 0x67, 0x63, 0xe7, 0x6a, 0x83, 0x54, 0x6b, 0xd5, 0xd4, 0xca, 0x0c, 0xa6, 0x64,
		0x9f, 0xe1, 0xb3, 0xbd, 0x42, 0xc6, 0xd1, 0x65, 0x3a, 0xaa, 0x50, 0xa3, 0x29, 0x5b, 0x67, 0xcc,
		0xce, 0x45, 0x32, 0x74, 0x0f, 0x43, 0xbb, 0x55, 0x1b, 0xdd, 0x8d, 0xda, 0xd0, 0x6e, 0xd3, 0xcf,
		0x4f, 0xd0, 0xf7, 0x32, 0xbe, 0x90, 0xc1, 0x27, 0xe3, 0x76, 0x9e, 0x78, 0x9b, 0x7e, 0x92, 0x6d,
		0xed, 0x09, 0xb5, 0xb5, 0x27, 0xcf, 0xd6, 0x9e, 0x28, 0x13, 0x38, 0x73, 0x0d, 0x9c, 0x06, 0x1e,
		0x26, 0x65, 0x88, 0x9b, 0xef, 0x72, 0xe4, 0x73, 0xa6, 0x7c, 0x0d, 0xce, 0xc7, 0x9c, 0x4c, 0xd9,
		0xcd, 0x8a, 0x66, 0x33, 0xd9, 0x84, 0xc0, 0xea, 0x1d, 0x34, 0x03, 0xe7, 0x74, 0x94, 0x90, 0xb7,
		0xdf, 0x9a, 0x41, 0x18, 0x65, 0xe6, 0x97, 0x09, 0xeb, 0x78, 0xbe, 0x54, 0x46, 0x41, 0x96, 0x2d,
		0x35, 0xcc, 0x9c, 0x12, 0x9a, 0xa0, 0x82, 0x66, 0x29, 0xa0, 0x29, 0xea, 0x67, 0x9c, 0xf2, 0x19,
		0xa7, 0x7a, 0xc6, 0x29, 0x5e, 0xbe, 0xe0, 0xf5, 0x58, 0x66, 0x2b, 0x57, 0x27, 0xb9, 0xcb, 0xdc,
		0x64, 0x3a, 0xb9, 0xe2, 0x9a, 0xcd, 0xa7, 0x77, 0x39, 0x9f, 0xe6, 0x7c, 0x9a, 0xf3, 0xe9, 0x35,
		0x9c, 0x4f, 0x67, 0x9d, 0x84, 0x93, 0x0b, 0xf9, 0xed, 0xef, 0xa3, 0x31, 0x91, 0xca, 0xed, 0x05,
		0x91, 0x36, 0x17, 0x09, 0xc9, 0xbe, 0x1f, 0xaf, 0x0c, 0x30, 0xf5, 0x74, 0xd8, 0x48, 0xaa, 0x36,
		0x9e, 0xb2, 0x6d, 0xa4, 0x6e, 0xbb, 0x29, 0xdc, 0x56, 0x2a, 0xb7, 0x9e, 0xd2, 0xad, 0xa7, 0x76,
		0xeb, 0x29, 0xde, 0x4c, 0xaa, 0x37, 0x94, 0xf2, 0x8d, 0xa7, 0xfe, 0xe4, 0x82, 0xe3, 0x67, 0x7e,
		0xc6, 0x03, 0x67, 0x92, 0x2e, 0xc6, 0xd7, 0x37, 0xec, 0xb4, 0x66, 0x01, 0xc0, 0x98, 0xf0, 0x81,
		0x04, 0x08, 0x18, 0xc0, 0x60, 0x1b, 0x20, 0x60, 0x80, 0x02, 0x06, 0x30, 0x60, 0x80, 0xc3, 0x2c,
		0x80, 0x18, 0x06, 0x12, 0x6b, 0x80, 0x32, 0x0d, 0x2c, 0xf6, 0xe2, 0x6d, 0x0a, 0x5f, 0x6c, 0xc5,
		0x9a, 0x1d, 0x98, 0xb1, 0x36, 0xef, 0x40, 0x82, 0x1d, 0x2c, 0xf8, 0x41, 0x81, 0x21, 0x38, 0x38,
		0x82, 0x83, 0x25, 0x38, 0x78, 0xb2, 0x03, 0x53, 0x96, 0xe0, 0xca, 0x3a, 0x6c, 0x25, 0x06, 0x4c,
		0xd6, 0x0a, 0x58, 0x8f, 0xd4, 0xe7, 0x86, 0x8b, 0x26, 0x17, 0x2f, 0xfc, 0x1b, 0xa4, 0x59, 0x6e,
		0x87, 0x03, 0xd3, 0x97, 0x07, 0xa9, 0x1f, 0x0f, 0x66, 0x1f, 0x1e, 0xb4, 0xfe, 0x3b, 0xb0, 0x7d,
		0x77, 0x60, 0xfb, 0xed, 0xc0, 0xf6, 0xd9, 0xd9, 0xec, 0xa6, 0x20, 0x30, 0xfd, 0x74, 0x92, 0xbc,
		0xd3, 0x15, 0x7e, 0x27, 0x14, 0x1d, 0x84, 0xa4, 0x33, 0x99, 0x79, 0x55, 0x00, 0x6c, 0x39, 0x1f,
		0x17, 0x11, 0x7e, 0xf8, 0x10, 0x17, 0x8a, 0x7a, 0x13, 0x28, 0xdf, 0xd4, 0xee, 0x23, 0x16, 0xe7,
		0x5f, 0x3d, 0x0c, 0xb8, 0x7e, 0x66, 0x75, 0x10, 0x93, 0x2f, 0x92, 0x3a, 0x92, 0x3a, 0x92, 0x3a,
		0x92, 0x3a, 0x92, 0x3a, 0x92, 0x3a, 0x92, 0xba, 0x37, 0x92, 0xba, 0x38, 0xed, 0x90, 0xd3, 0x19,
		0x1f, 0x0a, 0x33, 0x8b, 0x73, 0x7f, 0x3b, 0x60, 0x4c, 0x2c, 0xde, 0xfd, 0xed, 0x50, 0x21, 0xa3,
		0x23, 0xa3, 0x23, 0xa3, 0x23, 0xa3, 0x23, 0xa3, 0xb3, 0x35, 0x2a, 0xb6, 0x9f, 0x64, 0x25, 0x86,
		0x8c, 0xfa, 0x9f, 0x4a, 0xd5, 0x16, 0x0f, 0x78, 0xfb, 0x50, 0xbc, 0xb0, 0x8d, 0xfb, 0x50, 0x20,
		0x03, 0x29, 0x22, 0xa0, 0x62, 0x03, 0x2b, 0x2a, 0xc0, 0xc2, 0x03, 0x2d, 0x3c, 0xe0, 0xc2, 0x03,
		0x2f, 0x06, 0x00, 0x83, 0x00, 0x31, 0x9e, 0xc4, 0x02, 0x2c, 0xb5, 0x20, 0x4a, 0x2e, 0xb3, 0xa4,
		0x97, 0x7f, 0xf8, 0x37, 0xa2, 0x14, 0x91, 0xd0, 0x51, 0x72, 0x34, 0x16, 0x6a, 0x62, 0x9a, 0xc1,
		0x7d, 0x35, 0x50, 0x82, 0xd2, 0x69, 0x8a, 0x48, 0xbb, 0xe3, 0x4e, 0x2b, 0x60, 0xbc, 0xf4, 0xd9,
		0x34, 0xd2, 0x52, 0xd2, 0x52, 0xd2, 0x52, 0xd2, 0x52, 0xd2, 0x52, 0xd2, 0xd2, 0x0d, 0xa3, 0xa5,
		0xdc, 0x1e, 0x8d, 0x34, 0xee, 0x37, 0xc6, 0xa4, 0x15, 0xdc, 0xdd, 0xf5, 0x95, 0xd4, 0x8f, 0xa8,
		0x22, 0xe3, 0x6b, 0x03, 0x49, 0xe9, 0x48, 0xe9, 0x48, 0xe9, 0x48, 0xe9, 0x48, 0xe9, 0x48, 0xe9,
		0x36, 0x8c, 0xd2, 0x51, 0x69, 0xfc, 0x3d, 0xe8, 0xf9, 0x2d, 0xa5, 0x71, 0xc2, 0x2b, 0xa4, 0x88,
		0x92, 0xe3, 0x47, 0x8a, 0x8d, 0x98, 0x2c, 0x55, 0x3c, 0x68, 0x17, 0x9e, 0xa9, 0xce, 0x32, 0x92,
		0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0xf5,
		0xad, 0x6c, 0xf5, 0x25, 0xb7, 0x18, 0x32, 0xd6, 0x29, 0xae, 0x41, 0xd6, 0x8a, 0xc9, 0x5a, 0xa5,
		0xba, 0xf7, 0xbb, 0xb2, 0xed, 0x86, 0xc2, 0x8f, 0x2c, 0x6f, 0xca, 0x3d, 0x33, 0x42, 0x5f, 0xd9,
		0x47, 0xae, 0x4a, 0xae, 0x4a, 0xae, 0x4a, 0xae, 0x4a, 0xae, 0x4a, 0xae, 0xba, 0x61, 0x5c, 0x55,
		0xb6, 0x85, 0xd2, 0x52, 0x3f, 0x82, 0xf2, 0xd5, 0x12, 0x90, 0x4d, 0xb5, 0xf1, 0xad, 0xfa, 0xe8,
		0x47, 0x80, 0x29, 0x75, 0x32, 0xa0, 0xb5, 0xb3, 0xaf, 0xd5, 0xd3, 0xda, 0x71, 0xe3, 0xa2, 0xfe,
		0xe5, 0xea, 0xa4, 0x71, 0x71, 0x52, 0xbd, 0xac, 0x9f, 0xa1, 0x65, 0xd7, 0xaf, 0x7e, 0xb7, 0x3f,
		0x6a, 0xe2, 0x7d, 0x0d, 0x65, 0xd7, 0xf0, 0xf5, 0x0b, 0xce, 0xa2, 0x99, 0xa3, 0xfb, 0xc7, 0xe9,
		0x97, 0xcb, 0xab, 0x93, 0x8b, 0xc6, 0x69, 0xbd, 0x7e, 0xee, 0xc0, 0x99, 0x3c, 0x78, 0xcf, 0x71,
		0x7d, 0xdb, 0xb8, 0x56, 0x2f, 0x39, 0xa4, 0x6b, 0x36, 0xa4, 0xf5, 0x8b, 0xda, 0x9f, 0xb5, 0xb3,
		0xea, 0x55, 0xfd, 0x82, 0xa3, 0xba, 0x46, 0x09, 0xb8, 0x7e, 0xf6, 0xe9, 0xe4, 0x18, 0x70, 0x44,
		0xa1, 0x2c, 0xba, 0xe1, 0x7c, 0x04, 0xcc, 0x0a, 0x04, 0x75, 0xb0, 0xeb, 0x47, 0xda, 0xbd, 0x0b,
		0xda, 0xb2, 0x23, 0x45, 0x1b, 0x4f, 0x1c, 0x9c, 0x36, 0x8f, 0xda, 0xe0, 0x2c, 0x73, 0xa8, 0x0d,
		0x2e, 0xe0, 0x50, 0xd4, 0x06, 0x17, 0xf2, 0x74, 0x6a, 0x83, 0x4b, 0x1a, 0x48, 0x6d, 0x30, 0x47,
		0xdc, 0x17, 0x58, 0x1b, 0xd4, 0xf2, 0x4e, 0x68, 0xd9, 0xfa, 0x11, 0x95, 0x8b, 0x80, 0xda, 0xe0,
		0x01, 0x90, 0x49, 0x5f, 0x94, 0xd4, 0xd1, 0x68, 0xf3, 0x66, 0x5f, 0x05, 0x91, 0x68, 0x05, 0xaa,
		0x1d, 0x21, 0xdd, 0xb2, 0x0b, 0x5f, 0xdd, 0x0a, 0x38, 0xbd, 0x0d, 0x6f, 0xaa, 0xe7, 0x7c, 0x96,
		0x0a, 0x0e, 0x11, 0x41, 0x39, 0x60, 0xca, 0xbc, 0x91, 0xaa, 0x0b, 0x6c, 0xdf, 0xa7, 0xd0, 0x6f,
		0x69, 0x19, 0xa8, 0x63, 0x79, 0x1b, 0x47, 0xeb, 0x2e, 0xf5, 0x98, 0xdf, 0x09, 0x09, 0xff, 0x81,
		0x21, 0xb1, 0x64, 0x48, 0x14, 0x0e, 0x8a, 0xc5, 0x72, 0xa5, 0x58, 0xdc, 0xad, 0xec, 0x57, 0x76,
		0x0f, 0x4b, 0xa5, 0x42, 0x19, 0xe9, 0xc9, 0x56, 0xee, 0xa2, 0xe4, 0x1d, 0xad, 0x99, 0xf5, 0xba,
		0xa1, 0xc6, 0x85, 0x92, 0x45, 0x61, 0xf6, 0xe3, 0x4a, 0x91, 0x7a, 0x8c, 0x7d, 0xb9, 0x40, 0x13,
		0x38, 0x75, 0xad, 0x45, 0x5c, 0x89, 0xba, 0xd6, 0x42, 0x9e, 0x4e, 0x5d, 0x6b, 0x49, 0x03, 0xa9,
		0x6b, 0xe5, 0x68, 0x0e, 0x01, 0xac, 0x6b, 0xf5, 0xa5, 0xd2, 0xfb, 0x7b, 0x80, 0x92, 0x56, 0x85,
		0x92, 0xd1, 0xbf, 0xbc, 0x28, 0x19, 0xad, 0xe5, 0xfc, 0x98, 0x92, 0x51, 0xde, 0xd3, 0xfd, 0x74,
		0x48, 0x50, 0x32, 0x5a, 0x3a, 0x24, 0x8a, 0x7b, 0x87, 0xc5, 0xc3, 0x72, 0x65, 0xef, 0x90, 0x42,
		0xd1, 0x1a, 0x48, 0x33, 0x5b, 0x14, 0x8a, 0x00, 0xef, 0x07, 0x84, 0x50, 0x84, 0x35, 0xc1, 0xc7,
		0xda, 0xe9, 0x13, 0x34, 0x69, 0x53, 0x26, 0x5a, 0xc4, 0x93, 0x28, 0x13, 0x2d, 0xe4, 0xe9, 0x94,
		0x89, 0x96, 0x34, 0x90, 0x32, 0x51, 0x8e, 0xe6, 0x0d, 0xc8, 0x4b, 0x23, 0x7b, 0xf7, 0x65, 0x17,
		0x2e, 0x06, 0x93, 0xa5, 0x91, 0x07, 0x58, 0xad, 0x3c, 0xb4, 0x08, 0x15, 0x9c, 0x5c, 0xe4, 0xfc,
		0xbd, 0xbd, 0x7d, 0xbd, 0xeb, 0x1e, 0xfa, 0x6e, 0xa7, 0xea, 0x7e, 0xba, 0xf9, 0x55, 0x78, 0x5f,
		0x1c, 0x1c, 0xed, 0xfc, 0xaa, 0x0c, 0x5e, 0x9f, 0x7c, 0x9a, 0xf5, 0xb1, 0xc2, 0xfb, 0xca, 0xe0,
		0x68, 0xce, 0x3b, 0xe5, 0xc1, 0xd1, 0x6f, 0xfe, 0x8e, 0xd2, 0x60, 0x3b, 0xf5, 0xd1, 0xe1, 0xf9,
		0xbd, 0x79, 0x5f, 0x28, 0xce, 0xf9, 0xc2, 0xfe, 0xbc, 0x2f, 0xec, 0xcf, 0xf9, 0xc2, 0x5c, 0x93,
		0xf6, 0xe6, 0x7c, 0xa1, 0x34, 0x78, 0x4a, 0x7d, 0x7e, 0x7b, 0xf6, 0x47, 0xcb, 0x83, 0x9d, 0xa7,
		0x79, 0xef, 0x55, 0x06, 0x4f, 0x47, 0x3b, 0x3b, 0xde, 0x76, 0x61, 0xef, 0x7a, 0xd7, 0x3d, 0xb8,
		0x79, 0x2a, 0x5c, 0xef, 0xba, 0x85, 0x9b, 0xe1, 0x27, 0x6f, 0x9e, 0xae, 0x0b, 0xee, 0xe1, 0xe4,
		0x70, 0xf8, 0xdf, 0x9d, 0xff, 0xe0, 0x24, 0xe6, 0x1b, 0xa4, 0x88, 0xaa, 0x5f, 0xd6, 0xfe, 0xc7,
		0xb0, 0x62, 0x58, 0xad, 0x41, 0x58, 0x51, 0x6d, 0x80, 0x51, 0x1b, 0xc6, 0x6d, 0x8f, 0x82, 0xbe,
		0x16, 0x78, 0x92, 0xc3, 0x4b, 0xe3, 0xa8, 0x3b, 0x50, 0x77, 0xa0, 0xee, 0x40, 0xdd, 0x81, 0xba,
		0x03, 0x75, 0x87, 0x0d, 0xd3, 0x1d, 0xb8, 0x7f, 0x11, 0x3e, 0x95, 0xdb, 0xe8, 0x2d, 0xe2, 0xab,
		0x4a, 0x05, 0xda, 0xd7, 0x12, 0xa4, 0xb3, 0xa7, 0x13, 0xb5, 0xbe, 0x89, 0x3b, 0x7f, 0xbc, 0x23,
		0xa7, 0xe3, 0x05, 0x3d, 0xa1, 0x5a, 0x23, 0xa2, 0xe4, 0x2a, 0xa1, 0x7f, 0x06, 0xe1, 0x0f, 0x57,
		0xaa, 0x48, 0xfb, 0xaa, 0x25, 0xbc, 0xd7, 0x27, 0xa2, 0xd4, 0x19, 0xaf, 0x17, 0x06, 0x3a, 0x68,
		0x05, 0xdd, 0x28, 0x39, 0xf2, 0x9a, 0xb7, 0x3d, 0x2f, 0x94, 0x4d, 0xcf, 0xef, 0x48, 0x37, 0xf2,
		0x3b, 0x32, 0x4a, 0x8e, 0xbc, 0x91, 0x48, 0xd8, 0x57, 0xb2, 0xe5, 0x47, 0xda, 0x53, 0x42, 0xde,
		0x7e, 0x6b, 0x06, 0x61, 0x94, 0x1c, 0x79, 0x7e, 0xfb, 0xfb, 0x08, 0x09, 0xa4, 0x72, 0x7b, 0x41,
		0xa4, 0xbd, 0x11, 0xbb, 0x8d, 0xe2, 0x1f, 0x71, 0xf7, 0x5a, 0xbb, 0x00, 0x61, 0xcf, 0x93, 0x2d,
		0x7a, 0xb1, 0xd3, 0x57, 0x3f, 0x54, 0xf0, 0x53, 0xb9, 0xbe, 0xd6, 0xa1, 0x6c, 0x0e, 0x47, 0xc4,
		0xba, 0x27, 0x3f, 0x57, 0x27, 0xa6, 0x6d, 0xb3, 0x1c, 0xef, 0x93, 0xec, 0x6f, 0xd9, 0x0c, 0x94,
		0xc9, 0x0f, 0xd2, 0xa4, 0x07, 0x73, 0xb2, 0x83, 0x36, 0xc9, 0x81, 0x9d, 0xdc, 0xc0, 0x4e, 0x6a,
		0x60, 0x27, 0x33, 0x9b, 0xcd, 0xbc, 0x8e, 0x65, 0x88, 0x91, 0x76, 0x52, 0x20, 0x85, 0xa7, 0x26,
		0xa6, 0x4d, 0xc4, 0xd2, 0x14, 0x0b, 0xd4, 0x14, 0xe1, 0xe1, 0x15, 0x1b, 0x66, 0x51, 0xe1, 0x16,
		0x1e, 0x76, 0xe1, 0xe1, 0x17, 0x1e, 0x86, 0x71, 0xa4, 0x98, 0x2d, 0x20, 0x4d, 0x11, 0x05, 0x9e,
		0x13, 0x83, 0x86, 0xd8, 0xe7, 0x6a, 0x34, 0xa5, 0x73, 0x2a, 0xa3, 0x3e, 0x9b, 0x08, 0x16, 0x7a,
		0x98, 0xeb, 0x44, 0xe0, 0xe0, 0x1a, 0x19, 0xb6, 0xf3, 0x01, 0xdf, 0xe8, 0x30, 0x9e, 0x1b, 0x38,
		0xcf, 0x0d, 0xac, 0xe7, 0x06, 0xde, 0xb1, 0x60, 0x1e, 0x0c, 0xee, 0x93, 0x51, 0xbc, 0x42, 0x04,
		0xd8, 0x2d, 0xec, 0x1d, 0x09, 0x53, 0xb3, 0xe1, 0x0a, 0xa0, 0x6d, 0x2f, 0x76, 0x28, 0x8c, 0x37,
		0x1a, 0x7c, 0x26, 0x2b, 0x5c, 0x59, 0x88, 0x1e, 0x9a, 0x4e, 0xfc, 0x74, 0x0d, 0x96, 0xf8, 0xc6,
		0xe6, 0x61, 0x92, 0xde, 0x02, 0x49, 0x2f, 0x49, 0x2f, 0x49, 0x2f, 0x49, 0x2f, 0x49, 0x2f, 0x91,
		0x75, 0xf6, 0x28, 0xa2, 0x69, 0x5d, 0x89, 0x61, 0x23, 0x8e, 0xd6, 0x15, 0xc0, 0x4d, 0x79, 0xa6,
		0xa4, 0xaf, 0xa1, 0xa5, 0xef, 0xd9, 0x29, 0x65, 0x8d, 0x48, 0x41, 0x1e, 0xc8, 0x41, 0xbe, 0x48,
		0x42, 0x5e, 0xc8, 0x42, 0xee, 0x48, 0x43, 0xee, 0xc8, 0x43, 0xee, 0x48, 0x04, 0x26, 0x99, 0x00,
		0x25, 0x15, 0xc9, 0xe8, 0xc2, 0x2a, 0x6a, 0xa9, 0xbc, 0xd9, 0x97, 0x4a, 0x17, 0xca, 0xc8, 0x39,
		0x73, 0x8c, 0xe2, 0x65, 0x60, 0x13, 0x31, 0x7b, 0x4d, 0xbe, 0x7e, 0x61, 0x63, 0xce, 0x16, 0x7a,
		0x2f, 0xca, 0x9c, 0xd1, 0xcb, 0x94, 0xb9, 0xe0, 0xbd, 0x2a, 0x53, 0xf6, 0xe6, 0xa0, 0x3f, 0x5f,
		0x4e, 0xe0, 0x68, 0x3a, 0xc4, 0xfc, 0x07, 0x86, 0x58, 0xc6, 0x21, 0x56, 0x2e, 0x95, 0xf6, 0x4b,
		0x0c, 0xb3, 0xcd, 0xe2, 0xa2, 0xf8, 0xd6, 0xdd, 0xbc, 0xe3, 0xfd, 0xca, 0x69, 0x1a, 0x07, 0xae,
		0x84, 0x4b, 0x4d, 0x29, 0x50, 0x2b, 0xe2, 0x72, 0x82, 0x2a, 0xd4, 0x05, 0x57, 0xe9, 0x8c, 0xd4,
		0x05, 0x57, 0x1a, 0x39, 0xd4, 0x05, 0x33, 0x36, 0x98, 0xba, 0xe0, 0x1a, 0x4f, 0xc4, 0x72, 0xa6,
		0x0b, 0x1e, 0xe4, 0x40, 0x16, 0x2c, 0x51, 0x16, 0x5c, 0xf2, 0x45, 0x59, 0x90, 0x9a, 0x05, 0x65,
		0xc1, 0x0d, 0x44, 0xa3, 0xe9, 0x10, 0xa3, 0x2c, 0x98, 0x79, 0x88, 0xed, 0x95, 0x28, 0x0a, 0x6e,
		0x18, 0x11, 0xc5, 0xb7, 0x8e, 0xa2, 0x60, 0x6e, 0x93, 0x78, 0xac, 0xb4, 0xdd, 0x8f, 0xb3, 0x4b,
		0x1e, 0x54, 0xc1, 0xd8, 0x56, 0xca, 0x82, 0x6f, 0x31, 0x8f, 0xb2, 0xe0, 0x0a, 0xbd, 0x91, 0xb2,
		0xe0, 0x4a, 0x23, 0x87, 0xb2, 0x60, 0xc6, 0x06, 0x53, 0x16, 0x5c, 0xe3, 0x89, 0x58, 0x8e, 0x64,
		0xc1, 0xa6, 0x54, 0x7e, 0xf8, 0x98, 0x03, 0x5d, 0xf0, 0x10, 0xd8, 0xc4, 0x53, 0xa1, 0x6e, 0x47,
		0x0b, 0x73, 0x29, 0x0c, 0x2e, 0xab, 0x5a, 0x50, 0x18, 0xcc, 0x5c, 0xb5, 0x28, 0x50, 0xb3, 0xd8,
		0x30, 0x3c, 0x9a, 0x0e, 0x31, 0x0a, 0x83, 0x99, 0x87, 0x18, 0xeb, 0x05, 0x37, 0x90, 0x8c, 0xe2,
		0x5b, 0x47, 0x69, 0x30, 0xb7, 0x69, 0xdc, 0x11, 0x0f, 0x5a, 0xa8, 0xb6, 0x68, 0xe3, 0x0b, 0x83,
		0x89, 0xa5, 0x94, 0x05, 0xdf, 0x62, 0x1e, 0x65, 0xc1, 0x15, 0xfa, 0x22, 0x65, 0xc1, 0x95, 0x46,
		0x0e, 0x65, 0xc1, 0x8c, 0x0d, 0xa6, 0x2c, 0xb8, 0xc6, 0xd3, 0xb0, 0x3c, 0xc9, 0x82, 0x70, 0x5b,
		0x7e, 0xcd, 0x83, 0x71, 0x90, 0x2d, 0xc0, 0x48, 0x6a, 0xdf, 0x32, 0x86, 0x41, 0x6f, 0x38, 0xf3,
		0xf4, 0xbb, 0xf8, 0xa4, 0x36, 0xb1, 0x94, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4,
		0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0x41, 0x31, 0x3d, 0x86, 0x3d, 0x3f, 0xd4,
		0x32, 0x0f, 0x9c, 0x76, 0x62, 0x28, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d,
		0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x29, 0x2d, 0x83, 0x62, 0x7a, 0x0c, 0x75, 0xe8, 0xab, 0x48,
		0x6a, 0x79, 0x9f, 0x83, 0x75, 0x49, 0x2f, 0x6c, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1,
		0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0xa5, 0x45, 0xa0, 0x21, 0xea, 0x54,
		0x95, 0x0a, 0xb4, 0xaf, 0x65, 0x80, 0xb9, 0x00, 0xca, 0x89, 0x5a, 0xdf, 0xc4, 0x9d, 0xdf, 0x1b,
		0x6f, 0x40, 0xe9, 0x05, 0x3d, 0xa1, 0x5a, 0x23, 0xa2, 0xe8, 0x2a, 0xa1, 0x7f, 0x06, 0xe1, 0x0f,
		0x57, 0xaa, 0x48, 0xfb, 0xaa, 0x25, 0xbc, 0xd7, 0x27, 0xa2, 0xd4, 0x19, 0xaf, 0x17, 0x06, 0x3a,
		0x68, 0x05, 0xdd, 0x28, 0x39, 0xf2, 0x9a, 0xb7, 0x3d, 0x2f, 0x94, 0x4d, 0xcf, 0xef, 0x48, 0x37,
		0xf2, 0x3b, 0x32, 0x4a, 0x8e, 0x3c, 0xd9, 0xbb, 0x2f, 0xbb, 0x7d, 0x25, 0x5b, 0x7e, 0xa4, 0x3d,
		0x25, 0xe4, 0xed, 0xb7, 0x66, 0x10, 0x46, 0xc9, 0x91, 0xe7, 0xb7, 0xbf, 0x8f, 0x90, 0x4a, 0x2a,
		0xb7, 0x17, 0x44, 0xda, 0x0b, 0x83, 0xbe, 0x16, 0x51, 0xfc, 0xc3, 0xeb, 0xab, 0x1f, 0x2a, 0xf8,
		0xa9, 0x5c, 0x5f, 0xeb, 0x50, 0x36, 0x47, 0x6f, 0xa4, 0x4e, 0xc5, 0xbb, 0x69, 0x72, 0x0f, 0x4d,
		0x64, 0x4b, 0x50, 0xf6, 0xd4, 0xff, 0xaf, 0x78, 0x44, 0x6c, 0x8a, 0xeb, 0x9c, 0xca, 0x48, 0x57,
		0xb5, 0x06, 0xdb, 0xf0, 0xff, 0xb3, 0x54, 0x27, 0x5d, 0x31, 0x64, 0x94, 0x11, 0xd6, 0x8c, 0xd2,
		0xf9, 0xec, 0x3f, 0xbc, 0xb0, 0xac, 0x70, 0x50, 0x2c, 0x96, 0x2b, 0xc5, 0xe2, 0x6e, 0x65, 0xbf,
		0xb2, 0x7b, 0x58, 0x2a, 0x15, 0xca, 0x05, 0xa0, 0x05, 0x5c, 0x4e, 0x3d, 0x6c, 0x8b, 0x50, 0xb4,
		0x3f, 0x0e, 0x5d, 0x4f, 0xf5, 0xbb, 0x5d, 0x46, 0x24, 0x3e, 0x74, 0xae, 0x37, 0x64, 0x3a, 0x50,
		0x1b, 0x2b, 0x87, 0xfd, 0x96, 0x56, 0xe3, 0xa9, 0xc3, 0x59, 0x7c, 0xe7, 0x6a, 0xe3, 0x1b, 0xd7,
		0x38, 0x1f, 0xdf, 0xae, 0xc6, 0xc7, 0xdb, 0x5e, 0xe3, 0x42, 0x36, 0x1b, 0xd5, 0x8e, 0xbc, 0xf4,
		0x3b, 0xb2, 0x51, 0xeb, 0xdd, 0x97, 0xbf, 0xc4, 0xb7, 0xa8, 0x71, 0x36, 0xbe, 0x31, 0x8d, 0x6a,
		0xfb, 0xfb, 0x85, 0x6c, 0xd6, 0xd4, 0x79, 0x10, 0xe9, 0xc6, 0xc5, 0xf0, 0x76, 0x34, 0xbe, 0xc4,
		0x7f, 0x7b, 0x35, 0xf9, 0xd3, 0xdf, 0x11, 0x95, 0xed, 0x5b, 0x60, 0x39, 0xfb, 0xa0, 0x65, 0x9d,
		0x75, 0xca, 0x36, 0x76, 0x03, 0xcc, 0x9e, 0x5b, 0xdb, 0xb9, 0xb2, 0xa5, 0x40, 0x9a, 0x10, 0xe9,
		0x58, 0xc8, 0xdd, 0x1a, 0x3a, 0xae, 0x2b, 0x6d, 0x2d, 0x1a, 0xc5, 0x60, 0xcf, 0x38, 0x6c, 0x19,
		0x9a, 0x1d, 0x63, 0xb0, 0x61, 0x5b, 0x61, 0x03, 0x82, 0x3b, 0xb9, 0xc5, 0x1b, 0x8b, 0xc4, 0x35,
		0x63, 0xa2, 0x6a, 0x07, 0x36, 0xcd, 0x83, 0x96, 0xd9, 0x2b, 0x1a, 0x8e, 0x73, 0xdb, 0xf1, 0x9d,
		0xc3, 0xb8, 0x36, 0xeb, 0xf7, 0xe6, 0xbc, 0xcf, 0xcc, 0x95, 0x0c, 0xf9, 0xb7, 0x2d, 0xbf, 0xce,
		0x93, 0x3f, 0x1b, 0x84, 0xa6, 0xcc, 0xa0, 0xc8, 0x4c, 0x30, 0x66, 0x1f, 0x1a, 0x06, 0xc2, 0xc2,
		0x79, 0x39, 0xfc, 0xa1, 0xb9, 0x07, 0xf3, 0xcf, 0x2d, 0xbc, 0xa7, 0xaf, 0x6f, 0x28, 0x11, 0x4c,
		0x9e, 0x9b, 0x1b, 0xba, 0x9c, 0xe9, 0x72, 0x36, 0x1b, 0xe5, 0x69, 0x76, 0xcb, 0xcd, 0x6c, 0x95,
		0x8f, 0x59, 0x2f, 0x07, 0xb3, 0x5e, 0xde, 0x65, 0xbd, 0x5c, 0x6b, 0xbd, 0x28, 0xca, 0xb1, 0x34,
		0xab, 0xff, 0x38, 0x63, 0xfe, 0x6a, 0x3c, 0x70, 0x26, 0xe9, 0x62, 0x7c, 0x7d, 0xc3, 0x4e, 0x6b,
		0x16, 0x00, 0xd2, 0x40, 0xb0, 0x67, 0xf8, 0xc2, 0x16, 0xeb, 0x95, 0x31, 0xea, 0x90, 0x6d, 0xd7,
		0x17, 0xc3, 0xd4, 0x0d, 0xc3, 0xd4, 0x03, 0xc3, 0xd4, 0xf9, 0xae, 0xb7, 0x96, 0x63, 0x1a, 0x50,
		0xa6, 0x81, 0xc5, 0x5e, 0xbc, 0x4d, 0xe1, 0x8b, 0xad, 0x58, 0xb3, 0x03, 0x33, 0xd6, 0xe6, 0x1d,
		0x48, 0xb0, 0x83, 0x05, 0x3f, 0x28, 0x30, 0x04, 0x07, 0x47, 0x70, 0xb0, 0x04, 0x07, 0x4f, 0x76,
		0x60, 0xca, 0x12, 0x5c, 0x59, 0x87, 0xad, 0xc4, 0x80, 0x49, 0x31, 0x80, 0xf5, 0x48, 0x7d, 0x6e,
		0x95, 0x62, 0xb3, 0x3a, 0xe1, 0x35, 0xa4, 0x59, 0x2e, 0xa3, 0x85, 0x59, 0x21, 0x8a, 0xb4, 0x12,
		0x14, 0x73, 0xc5, 0x27, 0xda, 0xca, 0x4e, 0xd8, 0x15, 0x9c, 0xb0, 0x2b, 0x35, 0x61, 0x57, 0x64,
		0x6e, 0x76, 0xf5, 0x27, 0xcc, 0x4a, 0xca, 0x24, 0xef, 0x74, 0x85, 0xdf, 0x09, 0x45, 0x07, 0x21,
		0xe9, 0x4c, 0x66, 0x5e, 0x15, 0x00, 0x5b, 0xce, 0xc7, 0x0f, 0x7e, 0x3f, 0x7c, 0x88, 0x17, 0x79,
		0x79, 0x13, 0x28, 0xdf, 0xd4, 0x1a, 0x53, 0x8b, 0xf3, 0xaf, 0x1e, 0x06, 0x5c, 0x3f, 0xb3, 0x3a,
		0x88, 0xc9, 0x17, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x1d, 0x49, 0x1d, 0x49,
		0xdd, 0x1b, 0x49, 0x5d, 0x9c, 0x76, 0xc8, 0xe9, 0x8c, 0x0f, 0x45, 0xdc, 0x39, 0x01, 0x86, 0xd2,
		0xc5, 0xe6, 0x60, 0x30, 0xba, 0x02, 0x19, 0x1d, 0x19, 0x1d, 0x19, 0x1d, 0x19, 0x1d, 0x19, 0x9d,
		0xad, 0x51, 0xb1, 0xfd, 0x24, 0x2b, 0x31, 0x64, 0xd4, 0x2e, 0x46, 0xaa, 0xb6, 0xc0, 0xe9, 0x5b,
		0xf9, 0x5c, 0x06, 0xfe, 0x6c, 0x1b, 0x4a, 0x8f, 0x1d, 0xa8, 0x0e, 0xa9, 0x70, 0x1d, 0x51, 0x11,
		0x3b, 0xa0, 0x62, 0x77, 0x3c, 0x45, 0xed, 0x70, 0x0a, 0xdf, 0xd1, 0x14, 0xbe, 0x83, 0x29, 0x7c,
		0xc7, 0x52, 0x76, 0x4f, 0x83, 0x94, 0x58, 0x80, 0xa5, 0x16, 0x44, 0xc9, 0x65, 0x96, 0xf4, 0xf2,
		0x0f, 0xff, 0x46, 0x94, 0x22, 0x12, 0x3a, 0x4a, 0x8e, 0xc6, 0x42, 0x4d, 0x4c, 0x33, 0xd8, 0x40,
		0x09, 0x25, 0x28, 0x9d, 0x56, 0x70, 0x77, 0xd7, 0x57, 0x52, 0x3f, 0xa2, 0xb2, 0xd3, 0xd7, 0x06,
		0x92, 0xa2, 0x92, 0xa2, 0x92, 0xa2, 0x92, 0xa2, 0x92, 0xa2, 0x92, 0xa2, 0x92, 0xa2, 0x92, 0xa2,
		0xbe, 0x95, 0xa2, 0x4e, 0x78, 0x85, 0x14, 0x51, 0x72, 0xfc, 0x48, 0x96, 0x8a, 0xc9, 0x52, 0xc5,
		0x83, 0x76, 0xe1, 0x99, 0xea, 0x2c, 0x23, 0xc9, 0x56, 0xc9, 0x56, 0xc9, 0x56, 0xc9, 0x56, 0xc9,
		0x56, 0xc9, 0x56, 0xc9, 0x56, 0xc9, 0x56, 0xdf, 0xca, 0x56, 0x5f, 0x72, 0x8b, 0x21, 0x63, 0x9d,
		0xe2, 0x1a, 0x64, 0xad, 0x98, 0xac, 0x55, 0xaa, 0x7b, 0xbf, 0x2b, 0xdb, 0x6e, 0x28, 0xfc, 0x08,
		0x68, 0x73, 0x8a, 0x24, 0x42, 0x5f, 0xd9, 0x47, 0xae, 0x4a, 0xae, 0x4a, 0xae, 0x4a, 0xae, 0x4a,
		0xae, 0x4a, 0xae, 0xba, 0x61, 0x5c, 0x55, 0xb6, 0x85, 0xd2, 0x52, 0x3f, 0x82, 0xf2, 0x55, 0xa4,
		0xad, 0xc8, 0x6a, 0xe3, 0x5b, 0xf5, 0xd1, 0x8f, 0x00, 0x53, 0xea, 0x64, 0x40, 0x6b, 0x67, 0x5f,
		0xab, 0xa7, 0xb5, 0xe3, 0xc6, 0x45, 0xfd, 0xcb, 0xd5, 0x49, 0xe3, 0xe2, 0xa4, 0x7a, 0x59, 0x3f,
		0x43, 0xcb, 0xae, 0x5f, 0xfd, 0x6e, 0x7f, 0xd4, 0xfd, 0xf1, 0x1a, 0x6e, 0xbb, 0x4f, 0xf0, 0x3d,
		0xfe, 0x27, 0xa3, 0xfb, 0xc7, 0xe9, 0x97, 0xcb, 0xab, 0x93, 0x8b, 0xc6, 0x69, 0xbd, 0x7e, 0x8e,
		0xb7, 0x47, 0x35, 0xe0, 0x2e, 0xd0, 0x39, 0x19, 0xd7, 0xea, 0x25, 0x87, 0x74, 0xcd, 0x86, 0xb4,
		0x7e, 0x51, 0xfb, 0xb3, 0x76, 0x56, 0xbd, 0xaa, 0x5f, 0x70, 0x54, 0xd7, 0x28, 0x01, 0xd7, 0xcf,
		0x3e, 0x9d, 0x1c, 0x3b, 0xdc, 0x6b, 0xfc, 0x1f, 0x5f, 0x37, 0x9c, 0x8f, 0x80, 0x59, 0x81, 0xa0,
		0x0e, 0x76, 0xfd, 0x48, 0xbb, 0x77, 0x41, 0x5b, 0x76, 0xa4, 0x68, 0xe3, 0x89, 0x83, 0xd3, 0xe6,
		0x51, 0x1b, 0x9c, 0x65, 0x0e, 0xb5, 0xc1, 0x05, 0x1c, 0x8a, 0xda, 0xe0, 0x42, 0x9e, 0x4e, 0x6d,
		0x70, 0x49, 0x03, 0xa9, 0x0d, 0xe6, 0x88, 0xfb, 0x02, 0x6b, 0x83, 0x5a, 0xde, 0x09, 0x2d, 0x5b,
		0x3f, 0xa2, 0x72, 0x11, 0x50, 0x1b, 0x3c, 0x00, 0x32, 0xe9, 0x8b, 0x92, 0xa3, 0xed, 0x62, 0x1d,
		0xe5, 0xab, 0x20, 0x12, 0xad, 0x40, 0xb5, 0x23, 0xa4, 0x5b, 0x76, 0xe1, 0xab, 0x5b, 0x01, 0xa7,
		0xb7, 0xe1, 0x4d, 0xf5, 0x9c, 0xcf, 0x52, 0xc1, 0x21, 0x22, 0x28, 0x07, 0x4c, 0x99, 0x37, 0x52,
		0x75, 0x81, 0xed, 0xfb, 0x14, 0xfa, 0x2d, 0x2d, 0x03, 0x75, 0x2c, 0x6f, 0xe3, 0x68, 0xdd, 0xa5,
		0x1e, 0xf3, 0x3b, 0x21, 0xe1, 0x3f, 0x30, 0x24, 0x96, 0x0c, 0x09, 0xac, 0x6d, 0xc4, 0x73, 0x1f,
		0x25, 0xef, 0x68, 0xcd, 0xac, 0xd7, 0x0d, 0x35, 0x2e, 0x94, 0x2c, 0x0a, 0xb3, 0x91, 0x43, 0x8a,
		0xd4, 0x63, 0x6c, 0xe8, 0x00, 0x9a, 0xc0, 0xa9, 0x6b, 0x2d, 0xe2, 0x4a, 0xd4, 0xb5, 0x16, 0xf2,
		0x74, 0xea, 0x5a, 0x4b, 0x1a, 0x48, 0x5d, 0x2b, 0x47, 0x73, 0x08, 0x60, 0x5d, 0xab, 0x2f, 0x95,
		0xde, 0xdf, 0x03, 0x94, 0xb4, 0x2a, 0x94, 0x8c, 0xfe, 0xe5, 0x45, 0xc9, 0x68, 0x2d, 0xe7, 0xc7,
		0x94, 0x8c, 0xf2, 0x9e, 0xee, 0xa7, 0x43, 0x82, 0x92, 0xd1, 0xd2, 0x21, 0x51, 0xdc, 0x3b, 0x2c,
		0x1e, 0x96, 0x2b, 0x7b, 0x87, 0x14, 0x8a, 0xd6, 0x40, 0x9a, 0xd9, 0xa2, 0x50, 0x04, 0x78, 0x3f,
		0x20, 0x84, 0x22, 0xac, 0x09, 0x3e, 0xd6, 0x16, 0x51, 0xa0, 0x49, 0x9b, 0x32, 0xd1, 0x22, 0x9e,
		0x44, 0x99, 0x68, 0x21, 0x4f, 0xa7, 0x4c, 0xb4, 0xa4, 0x81, 0x94, 0x89, 0x72, 0x34, 0x6f, 0x40,
		0x5e, 0x1a, 0xd9, 0xbb, 0x2f, 0xbb, 0x70, 0x31, 0x98, 0x2c, 0x8d, 0x3c, 0xc0, 0x6a, 0xe5, 0xa1,
		0x45, 0xa8, 0xe0, 0xe4, 0x22, 0xe7, 0xef, 0xed, 0xed, 0xeb, 0x5d, 0xf7, 0xd0, 0x77, 0x3b, 0x55,
		0xf7, 0xd3, 0xcd, 0xaf, 0xc2, 0xfb, 0xe2, 0xe0, 0x68, 0xe7, 0x57, 0x65, 0xf0, 0xfa, 0xe4, 0xd3,
		0xac, 0x8f, 0x15, 0xde, 0x57, 0x06, 0x47, 0x73, 0xde, 0x29, 0x0f, 0x8e, 0x7e, 0xf3, 0x77, 0x94,
		0x06, 0xdb, 0xa9, 0x8f, 0x0e, 0xcf, 0xef, 0xcd, 0xfb, 0x42, 0x71, 0xce, 0x17, 0xf6, 0xe7, 0x7d,
		0x61, 0x7f, 0xce, 0x17, 0xe6, 0x9a, 0xb4, 0x37, 0xe7, 0x0b, 0xa5, 0xc1, 0x53, 0xea, 0xf3, 0xdb,
		0xb3, 0x3f, 0x5a, 0x1e, 0xec, 0x3c, 0xcd, 0x7b, 0xaf, 0x32, 0x78, 0x3a, 0xda, 0xd9, 0xf1, 0xb6,
		0x0b, 0x7b, 0xd7, 0xbb, 0xee, 0xc1, 0xcd, 0x53, 0xe1, 0x7a, 0xd7, 0x2d, 0xdc, 0x0c, 0x3f, 0x79,
		0xf3, 0x74, 0x5d, 0x70, 0x0f, 0x27, 0x87, 0xc3, 0xff, 0xee, 0xfc, 0x07, 0x27, 0x31, 0xdf, 0x20,
		0x45, 0x54, 0xfd, 0xb2, 0xf6, 0x3f, 0x86, 0x15, 0xc3, 0x6a, 0x0d, 0xc2, 0x8a, 0x6a, 0x03, 0x8c,
		0xda, 0x30, 0x6e, 0x7b, 0x14, 0xf4, 0xb5, 0xc0, 0x93, 0x1c, 0x5e, 0x1a, 0x47, 0xdd, 0x81, 0xba,
		0x03, 0x75, 0x07, 0xea, 0x0e, 0xd4, 0x1d, 0xa8, 0x3b, 0x6c, 0x98, 0xee, 0xd0, 0x0c, 0x82, 0xae,
		0xf0, 0x15, 0xa2, 0xe6, 0x50, 0x20, 0x95, 0x03, 0xb0, 0xc0, 0xf6, 0xde, 0xa2, 0x55, 0xa5, 0x02,
		0xed, 0x6b, 0x09, 0xd2, 0xd9, 0xd3, 0x89, 0x5a, 0xdf, 0xc4, 0x9d, 0xdf, 0x1b, 0xb7, 0x93, 0xf5,
		0x82, 0x9e, 0x50, 0xad, 0x11, 0x51, 0x72, 0x95, 0xd0, 0x3f, 0x83, 0xf0, 0x87, 0x2b, 0x55, 0xa4,
		0x7d, 0xd5, 0x12, 0xde, 0xeb, 0x13, 0x51, 0xea, 0x8c, 0xd7, 0x0b, 0x03, 0x1d, 0xb4, 0x82, 0x6e,
		0x94, 0x1c, 0x79, 0xcd, 0xdb, 0x9e, 0x17, 0xca, 0xa6, 0xe7, 0x77, 0xa4, 0x1b, 0xf9, 0x1d, 0x19,
		0x25, 0x47, 0xde, 0x48, 0x24, 0xec, 0x2b, 0xd9, 0xf2, 0x23, 0xed, 0x29, 0x21, 0x6f, 0xbf, 0x35,
		0x83, 0x30, 0x4a, 0x8e, 0x3c, 0xbf, 0xfd, 0x7d, 0x84, 0x04, 0x52, 0xb9, 0xbd, 0x50, 0x78, 0x23,
		0x72, 0x1b, 0xc5, 0x3f, 0xe2, 0xe6, 0xb5, 0xdc, 0xba, 0xdd, 0xbc, 0xc3, 0xf4, 0xd5, 0x0f, 0x15,
		0xfc, 0x54, 0xae, 0xaf, 0x75, 0x28, 0x9b, 0xc3, 0x11, 0xc1, 0xd9, 0xc7, 0x7d, 0x86, 0x6d, 0xdc,
		0xd4, 0x9d, 0x9b, 0xba, 0xe7, 0x69, 0xae, 0xc3, 0x4d, 0xdd, 0xf3, 0x3e, 0xa7, 0xe1, 0xa6, 0xee,
		0x90, 0xc4, 0x0b, 0x66, 0x53, 0xf7, 0x14, 0x48, 0xe1, 0x89, 0x89, 0x69, 0x13, 0xb1, 0x24, 0xc5,
		0x02, 0x25, 0x45, 0x78, 0x78, 0xc5, 0x86, 0x59, 0x54, 0xb8, 0x85, 0x87, 0x5d, 0x78, 0xf8, 0x85,
		0x87, 0x61, 0x1c, 0x25, 0x66, 0x0b, 0x48, 0x52, 0x44, 0x81, 0xe7, 0xc4, 0xa0, 0xd1, 0x16, 0xe4,
		0x1a, 0x4d, 0xe8, 0x9c, 0xca, 0xa8, 0xcf, 0x26, 0x82, 0x85, 0x1e, 0xe6, 0x32, 0x11, 0x38, 0xb8,
		0x46, 0x86, 0xed, 0x7c, 0xc0, 0x37, 0x3a, 0x8c, 0xe7, 0x06, 0xce, 0x73, 0x03, 0xeb, 0xb9, 0x81,
		0x77, 0x2c, 0x98, 0x07, 0x83, 0xfb, 0x64, 0x14, 0xaf, 0x10, 0x01, 0x76, 0x0b, 0x7b, 0x43, 0xc2,
		0xd4, 0x6c, 0xb8, 0x02, 0x68, 0xdb, 0x8b, 0x0d, 0x0a, 0xe3, 0x7d, 0x06, 0x9f, 0xc9, 0x0a, 0x17,
		0x16, 0xa2, 0x87, 0xa6, 0x13, 0x3f, 0x5d, 0x83, 0x25, 0xbe, 0xb1, 0x79, 0x98, 0xa4, 0xb7, 0x40,
		0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0x64, 0x9d, 0x3d, 0x8a, 0x68, 0x5a,
		0x57, 0x62, 0xd8, 0x88, 0xa3, 0x75, 0x05, 0x70, 0x4f, 0x9e, 0x29, 0xe9, 0x6b, 0x68, 0xe9, 0x7b,
		0x36, 0x4a, 0x59, 0x23, 0x52, 0x90, 0x07, 0x72, 0x90, 0x2f, 0x92, 0x90, 0x17, 0xb2, 0x90, 0x3b,
		0xd2, 0x90, 0x3b, 0xf2, 0x90, 0x3b, 0x12, 0x81, 0x49, 0x26, 0x40, 0x49, 0x45, 0x32, 0xba, 0xb0,
		0x8a, 0x5a, 0x2a, 0x6f, 0xf6, 0xa5, 0xd2, 0x85, 0x32, 0x72, 0xce, 0x1c, 0xa3, 0x78, 0x19, 0xd8,
		0x44, 0xcc, 0x56, 0x93, 0xaf, 0x5f, 0xd8, 0x98, 0xb3, 0x85, 0xde, 0x8a, 0x32, 0x67, 0xf4, 0x32,
		0x65, 0x2e, 0x78, 0xab, 0xca, 0x94, 0xbd, 0x39, 0x68, 0xcf, 0x97, 0x13, 0x38, 0x9a, 0x0e, 0x31,
		0xff, 0x81, 0x21, 0x96, 0x71, 0x88, 0x95, 0x4b, 0xa5, 0xfd, 0x12, 0xc3, 0x6c, 0xb3, 0xb8, 0x28,
		0xbe, 0x75, 0x37, 0xef, 0x78, 0xbf, 0x72, 0x9a, 0xc6, 0x81, 0x2b, 0xe1, 0x52, 0x53, 0x0a, 0xd4,
		0x8a, 0xb8, 0x9c, 0xa0, 0x0a, 0x75, 0xc1, 0x55, 0x3a, 0x23, 0x75, 0xc1, 0x95, 0x46, 0x0e, 0x75,
		0xc1, 0x8c, 0x0d, 0xa6, 0x2e, 0xb8, 0xc6, 0x13, 0xb1, 0x9c, 0xe9, 0x82, 0x07, 0x39, 0x90, 0x05,
		0x4b, 0x94, 0x05, 0x97, 0x7c, 0x51, 0x16, 0xa4, 0x66, 0x41, 0x59, 0x70, 0x03, 0xd1, 0x68, 0x3a,
		0xc4, 0x28, 0x0b, 0x66, 0x1e, 0x62, 0x7b, 0x25, 0x8a, 0x82, 0x1b, 0x46, 0x44, 0xf1, 0xad, 0xa3,
		0x28, 0x98, 0xdb, 0x24, 0x1e, 0x2b, 0x6d, 0xf7, 0xe3, 0xec, 0x92, 0x07, 0x55, 0x30, 0xb6, 0x95,
		0xb2, 0xe0, 0x5b, 0xcc, 0xa3, 0x2c, 0xb8, 0x42, 0x6f, 0xa4, 0x2c, 0xb8, 0xd2, 0xc8, 0xa1, 0x2c,
		0x98, 0xb1, 0xc1, 0x94, 0x05, 0xd7, 0x78, 0x22, 0x96, 0x23, 0x59, 0xb0, 0x29, 0x95, 0x1f, 0x3e,
		0xe6, 0x40, 0x17, 0x3c, 0x04, 0x36, 0xf1, 0x54, 0xa8, 0xdb, 0xd1, 0xc2, 0x5c, 0x0a, 0x83, 0xcb,
		0xaa, 0x16, 0x14, 0x06, 0x33, 0x57, 0x2d, 0x0a, 0xd4, 0x2c, 0x36, 0x0c, 0x8f, 0xa6, 0x43, 0x8c,
		0xc2, 0x60, 0xe6, 0x21, 0xc6, 0x7a, 0xc1, 0x0d, 0x24, 0xa3, 0xf8, 0xd6, 0x51, 0x1a, 0xcc, 0x6d,
		0x1a, 0x77, 0xc4, 0x83, 0x16, 0xaa, 0x2d, 0xda, 0xf8, 0xc2, 0x60, 0x62, 0x29, 0x65, 0xc1, 0xb7,
		0x98, 0x47, 0x59, 0x70, 0x85, 0xbe, 0x48, 0x59, 0x70, 0xa5, 0x91, 0x43, 0x59, 0x30, 0x63, 0x83,
		0x29, 0x0b, 0xae, 0xf1, 0x34, 0x2c, 0x4f, 0xb2, 0x20, 0xdc, 0x8e, 0x5f, 0xf3, 0x60, 0x1c, 0x64,
		0x07, 0x30, 0x92, 0xda, 0xb7, 0x8c, 0x61, 0xd0, 0x1b, 0xce, 0x3c, 0xfd, 0x2e, 0x3e, 0xa9, 0x4d,
		0x2c, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25,
		0xa9, 0x25, 0xa9, 0x65, 0x50, 0x4c, 0x8f, 0x61, 0xcf, 0x0f, 0xb5, 0xcc, 0x03, 0xa7, 0x9d, 0x18,
		0x4a, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a,
		0x4b, 0x4a, 0xcb, 0xa0, 0x98, 0x1e, 0x43, 0x1d, 0xfa, 0x2a, 0x92, 0x5a, 0xde, 0xe7, 0x60, 0x5d,
		0xd2, 0x0b, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49,
		0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0x68, 0x88, 0x3a, 0x55, 0xa5, 0x02, 0xed, 0x6b, 0x19,
		0x60, 0x2e, 0x80, 0x72, 0xa2, 0xd6, 0x37, 0x71, 0xe7, 0xf7, 0xc6, 0x1b, 0x50, 0x7a, 0x41, 0x4f,
		0xa8, 0xd6, 0x88, 0x28, 0xba, 0x4a, 0xe8, 0x9f, 0x41, 0xf8, 0xc3, 0x95, 0x2a, 0xd2, 0xbe, 0x6a,
		0x09, 0xef, 0xf5, 0x89, 0x28, 0x75, 0xc6, 0xeb, 0x85, 0x81, 0x0e, 0x5a, 0x41, 0x37, 0x4a, 0x8e,
		0xbc, 0xe6, 0x6d, 0xcf, 0x0b, 0x65, 0xd3, 0xf3, 0x3b, 0xd2, 0x8d, 0xfc, 0x8e, 0x8c, 0x92, 0x23,
		0x4f, 0xf6, 0xee, 0xcb, 0x6e, 0x5f, 0xc9, 0x96, 0x1f, 0x69, 0x4f, 0x09, 0x79, 0xfb, 0xad, 0x19,
		0x84, 0x51, 0x72, 0xe4, 0xf9, 0xed, 0xef, 0x23, 0xa4, 0x92, 0xca, 0xed, 0x85, 0xc2, 0x0b, 0x83,
		0xbe, 0x16, 0x51, 0xfc, 0xc3, 0xeb, 0xab, 0x1f, 0x2a, 0xf8, 0xa9, 0x5c, 0x5f, 0xeb, 0x50, 0x36,
		0x47, 0x6f, 0xa4, 0x4e, 0xc5, 0x9b, 0x69, 0x72, 0x0b, 0x4d, 0x64, 0x4b, 0x50, 0xb6, 0xd4, 0xff,
		0xaf, 0x78, 0x44, 0xec, 0x89, 0xeb, 0x9c, 0xca, 0x48, 0x57, 0xb5, 0x06, 0xdb, 0xef, 0xff, 0xb3,
		0x54, 0x27, 0x5d, 0x31, 0x24, 0x94, 0x11, 0xd6, 0x84, 0xd2, 0xf9, 0xec, 0x3f, 0xbc, 0xb0, 0xac,
		0x70, 0x50, 0x2c, 0x96, 0x2b, 0xc5, 0xe2, 0x6e, 0x65, 0xbf, 0xb2, 0x7b, 0x58, 0x2a, 0x15, 0xca,
		0x05, 0xa0, 0xf5, 0x5b, 0x4e, 0x3d, 0x6c, 0x8b, 0x50, 0xb4, 0x3f, 0x0e, 0x5d, 0x4f, 0xf5, 0xbb,
		0x5d, 0x46, 0x24, 0x3e, 0x72, 0xae, 0x35, 0x62, 0x3a, 0x50, 0xdb, 0x2a, 0x87, 0xfd, 0x96, 0x56,
		0xe3, 0x89, 0xc3, 0x59, 0x7c, 0xe3, 0x6a, 0xe3, 0xfb, 0xd6, 0x38, 0x1f, 0xdf, 0xad, 0xc6, 0xc7,
		0xdb, 0x5e, 0xe3, 0x42, 0x36, 0x1b, 0xd5, 0x8e, 0xbc, 0xf4, 0x3b, 0xb2, 0x51, 0xeb, 0xdd, 0x97,
		0xbf, 0xc4, 0x77, 0xa8, 0x71, 0x36, 0xbe, 0x2f, 0x8d, 0x6a, 0xfb, 0xfb, 0x85, 0x6c, 0xd6, 0xd4,
		0x79, 0x28, 0x1a, 0x17, 0xc3, 0xbb, 0xd1, 0xf8, 0x12, 0xff, 0xe9, 0xd5, 0xe4, 0x2f, 0x7f, 0x47,
		0x4c, 0xb6, 0x6f, 0x81, 0xe5, 0xdc, 0x83, 0x96, 0x73, 0xd6, 0x28, 0xd7, 0xd8, 0x8d, 0x2f, 0x7b,
		0x5e, 0x6d, 0xe7, 0xca, 0x96, 0xe2, 0x68, 0xc2, 0xa2, 0x63, 0x11, 0x77, 0x6b, 0xe8, 0xb7, 0xae,
		0xb4, 0xb5, 0x60, 0x14, 0x83, 0x3a, 0xe3, 0x50, 0x65, 0x68, 0x6a, 0x8c, 0x41, 0x85, 0x6d, 0x85,
		0x0d, 0x08, 0xec, 0xe4, 0x15, 0x6e, 0x2c, 0xb2, 0xd6, 0x6c, 0x59, 0xaa, 0x1d, 0xd0, 0x34, 0x0f,
		0x59, 0x66, 0xaf, 0x68, 0x38, 0xca, 0x6d, 0x47, 0x77, 0xfe, 0xa2, 0xda, 0xac, 0xdb, 0x9b, 0x73,
		0x3e, 0x33, 0x57, 0x32, 0xe4, 0xde, 0xb6, 0xdc, 0x3a, 0x47, 0xee, 0x6c, 0x10, 0x97, 0xb2, 0xc2,
		0x21, 0x33, 0xa1, 0x98, 0x7d, 0x60, 0x18, 0x08, 0x0a, 0x67, 0x32, 0xf8, 0x41, 0x5f, 0xbb, 0xbd,
		0x20, 0xd2, 0xc6, 0xc2, 0xe2, 0xb9, 0x77, 0xf7, 0x6b, 0x0b, 0x0c, 0xa5, 0x82, 0xc9, 0x23, 0x73,
		0x43, 0x97, 0x33, 0x5d, 0xc9, 0x66, 0xa3, 0x32, 0xcd, 0x6e, 0xa5, 0x99, 0xad, 0xca, 0x31, 0xeb,
		0x95, 0x60, 0xd6, 0x2b, 0xbb, 0xac, 0x57, 0x6a, 0xad, 0x17, 0x49, 0x39, 0x96, 0x66, 0xe5, 0x1f,
		0x67, 0xcc, 0x60, 0x8d, 0x07, 0xce, 0x24, 0x5d, 0x8c, 0xaf, 0x6f, 0xd8, 0x69, 0xcd, 0x02, 0x40,
		0x1a, 0x08, 0xf6, 0x0c, 0x5f, 0xd8, 0x62, 0xa9, 0x32, 0x46, 0x09, 0xb2, 0xed, 0xd2, 0x62, 0x98,
		0x92, 0x61, 0x98, 0x52, 0x60, 0x98, 0x12, 0xdf, 0xf5, 0x16, 0x73, 0x4c, 0x03, 0xca, 0x34, 0xb0,
		0xd8, 0x8b, 0xb7, 0x29, 0x7c, 0xb1, 0x15, 0x6b, 0x76, 0x60, 0xc6, 0xda, 0xbc, 0x03, 0x09, 0x76,
		0xb0, 0xe0, 0x07, 0x05, 0x86, 0xe0, 0xe0, 0x08, 0x0e, 0x96, 0xe0, 0xe0, 0xc9, 0x0e, 0x4c, 0x59,
		0x82, 0x2b, 0xeb, 0xb0, 0x95, 0x18, 0x30, 0xa9, 0x05, 0xb0, 0x1e, 0xa9, 0xcf, 0x5d, 0x52, 0x6c,
		0x16, 0x27, 0xbc, 0x86, 0x34, 0xcb, 0x25, 0xb4, 0x30, 0x8b, 0x43, 0x91, 0x16, 0x81, 0x62, 0x2e,
		0xf6, 0x44, 0x5b, 0xd4, 0x09, 0xbb, 0x78, 0x13, 0x76, 0x91, 0x26, 0xec, 0x62, 0xcc, 0xcd, 0xae,
		0xfd, 0x84, 0x59, 0x44, 0x99, 0xe4, 0x9d, 0xae, 0xf0, 0x3b, 0xa1, 0xe8, 0x20, 0x24, 0x9d, 0xc9,
		0xcc, 0xab, 0x02, 0x60, 0xcb, 0xf9, 0xf8, 0xd1, 0xef, 0x87, 0x0f, 0xf1, 0x02, 0x2f, 0x6f, 0x02,
		0xe5, 0x9b, 0x5a, 0x62, 0x6a, 0x71, 0xfe, 0xd5, 0xc3, 0x80, 0xeb, 0x67, 0x56, 0x07, 0x31, 0xf9,
		0x22, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x23, 0xa9, 0x7b, 0x23,
		0xa9, 0x8b, 0xd3, 0x0e, 0x39, 0x9d, 0xf1, 0xa1, 0x88, 0xbb, 0x26, 0xc0, 0x50, 0xba, 0xd8, 0x1c,
		0x0c, 0x46, 0x57, 0x20, 0xa3, 0x23, 0xa3, 0x23, 0xa3, 0x23, 0xa3, 0x23, 0xa3, 0xb3, 0x35, 0x2a,
		0xb6, 0x9f, 0x64, 0x25, 0x86, 0x8c, 0x5a, 0xc5, 0x48, 0xd5, 0x16, 0x38, 0x2d, 0x2b, 0x9f, 0x0b,
		0xc1, 0x9f, 0x6d, 0x43, 0xe9, 0xaf, 0x03, 0xd5, 0x1c, 0x15, 0xae, 0x19, 0x2a, 0x62, 0xf3, 0x53,
		0xec, 0x66, 0xa7, 0xa8, 0xcd, 0x4d, 0xe1, 0x9b, 0x99, 0xc2, 0x37, 0x2f, 0x85, 0x6f, 0x56, 0xca,
		0xce, 0x69, 0x90, 0x12, 0x0b, 0xb0, 0xd4, 0x82, 0x28, 0xb9, 0xcc, 0x92, 0x5e, 0xfe, 0xe1, 0xdf,
		0x88, 0x52, 0x44, 0x42, 0x47, 0xc9, 0xd1, 0x58, 0xa8, 0x89, 0x69, 0x06, 0xdb, 0x27, 0xa1, 0x04,
		0xa5, 0xd3, 0x0a, 0xee, 0xee, 0xfa, 0x4a, 0xea, 0x47, 0x54, 0x76, 0xfa, 0xda, 0x40, 0x52, 0x54,
		0x52, 0x54, 0x52, 0x54, 0x52, 0x54, 0x52, 0x54, 0x52, 0x54, 0x52, 0x54, 0x52, 0xd4, 0xb7, 0x52,
		0xd4, 0x09, 0xaf, 0x90, 0x22, 0x4a, 0x8e, 0x1f, 0xc9, 0x52, 0x31, 0x59, 0xaa, 0x78, 0xd0, 0x2e,
		0x3c, 0x53, 0x9d, 0x65, 0x24, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9,
		0x2a, 0xd9, 0x2a, 0xd9, 0xea, 0x5b, 0xd9, 0xea, 0x4b, 0x6e, 0x31, 0x64, 0xac, 0x53, 0x5c, 0x83,
		0xac, 0x15, 0x93, 0xb5, 0x4a, 0x75, 0xef, 0x77, 0x65, 0xdb, 0x0d, 0x85, 0x1f, 0x01, 0x6d, 0x4c,
		0x91, 0x44, 0xe8, 0x2b, 0xfb, 0xc8, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9,
		0x55, 0x37, 0x8c, 0xab, 0xca, 0xb6, 0x50, 0x5a, 0xea, 0x47, 0x50, 0xbe, 0x8a, 0xb4, 0x0d, 0x59,
		0x6d, 0x7c, 0xab, 0x3e, 0xfa, 0x11, 0x60, 0x4a, 0x9d, 0x0c, 0x68, 0xed, 0xec, 0x6b, 0xf5, 0xb4,
		0x76, 0xdc, 0xb8, 0xa8, 0x7f, 0xb9, 0x3a, 0x69, 0x5c, 0x9c, 0x54, 0x2f, 0xeb, 0x67, 0x68, 0xd9,
		0xf5, 0xab, 0xdf, 0xed, 0x8f, 0xba, 0x3f, 0x5e, 0xc3, 0xed, 0xf4, 0x09, 0xbe, 0xbd, 0xff, 0x64,
		0x74, 0xff, 0x38, 0xfd, 0x72, 0x79, 0x75, 0x72, 0xd1, 0x38, 0xad, 0xd7, 0xcf, 0xf1, 0xb6, 0xa7,
		0x06, 0xdc, 0x00, 0x3a, 0x27, 0xe3, 0x5a, 0xbd, 0xe4, 0x90, 0xae, 0xd9, 0x90, 0xd6, 0x2f, 0x6a,
		0x7f, 0xd6, 0xce, 0xaa, 0x57, 0xf5, 0x0b, 0x8e, 0xea, 0x1a, 0x25, 0xe0, 0xfa, 0xd9, 0xa7, 0x93,
		0x63, 0x87, 0xdb, 0x8c, 0xff, 0xe3, 0xeb, 0x86, 0xf3, 0x11, 0x30, 0x2b, 0x10, 0xd4, 0xc1, 0xae,
		0x1f, 0x69, 0xf7, 0x2e, 0x68, 0xcb, 0x8e, 0x14, 0x6d, 0x3c, 0x71, 0x70, 0xda, 0x3c, 0x6a, 0x83,
		0xb3, 0xcc, 0xa1, 0x36, 0xb8, 0x80, 0x43, 0x51, 0x1b, 0x5c, 0xc8, 0xd3, 0xa9, 0x0d, 0x2e, 0x69,
		0x20, 0xb5, 0xc1, 0x1c, 0x71, 0x5f, 0x60, 0x6d, 0x50, 0xcb, 0x3b, 0xa1, 0x65, 0xeb, 0x47, 0x54,
		0x2e, 0x02, 0x6a, 0x83, 0x07, 0x40, 0x26, 0x7d, 0x51, 0x72, 0xb4, 0x5b, 0xac, 0xa3, 0x7c, 0x15,
		0x44, 0xa2, 0x15, 0xa8, 0x76, 0x84, 0x74, 0xcb, 0x2e, 0x7c, 0x75, 0x2b, 0xe0, 0xf4, 0x36, 0xbc,
		0xa9, 0x9e, 0xf3, 0x59, 0x2a, 0x38, 0x44, 0x04, 0xe5, 0x80, 0x29, 0xf3, 0x46, 0xaa, 0x2e, 0xb0,
		0x7d, 0x9f, 0x42, 0xbf, 0xa5, 0x65, 0xa0, 0x8e, 0xe5, 0x6d, 0x1c, 0xad, 0xbb, 0xd4, 0x63, 0x7e,
		0x27, 0x24, 0xfc, 0x07, 0x86, 0xc4, 0x92, 0x21, 0x81, 0xb5, 0x8b, 0x78, 0xee, 0xa3, 0xe4, 0x1d,
		0xad, 0x99, 0xf5, 0xba, 0xa1, 0xc6, 0x85, 0x92, 0x45, 0x61, 0x36, 0x72, 0x48, 0x91, 0x7a, 0x8c,
		0x0d, 0x1d, 0x40, 0x13, 0x38, 0x75, 0xad, 0x45, 0x5c, 0x89, 0xba, 0xd6, 0x42, 0x9e, 0x4e, 0x5d,
		0x6b, 0x49, 0x03, 0xa9, 0x6b, 0xe5, 0x68, 0x0e, 0x01, 0xac, 0x6b, 0xf5, 0xa5, 0xd2, 0xfb, 0x7b,
		0x80, 0x92, 0x56, 0x85, 0x92, 0xd1, 0xbf, 0xbc, 0x28, 0x19, 0xad, 0xe5, 0xfc, 0x98, 0x92, 0x51,
		0xde, 0xd3, 0xfd, 0x74, 0x48, 0x50, 0x32, 0x5a, 0x3a, 0x24, 0x8a, 0x7b, 0x87, 0xc5, 0xc3, 0x72,
		0x65, 0xef, 0x90, 0x42, 0xd1, 0x1a, 0x48, 0x33, 0x5b, 0x14, 0x8a, 0x00, 0xef, 0x07, 0x84, 0x50,
		0x84, 0x35, 0xc1, 0xc7, 0xda, 0x22, 0x0a, 0x34, 0x69, 0x53, 0x26, 0x5a, 0xc4, 0x93, 0x28, 0x13,
		0x2d, 0xe4, 0xe9, 0x94, 0x89, 0x96, 0x34, 0x90, 0x32, 0x51, 0x8e, 0xe6, 0x0d, 0xc8, 0x4b, 0x23,
		0x7b, 0xf7, 0x65, 0x17, 0x2e, 0x06, 0x93, 0xa5, 0x91, 0x07, 0x58, 0xad, 0x3c, 0xb4, 0x08, 0x15,
		0x9c, 0x5c, 0xe4, 0xfc, 0xbd, 0xbd, 0x7d, 0xbd, 0xeb, 0x1e, 0xfa, 0x6e, 0xa7, 0xea, 0x7e, 0xba,
		0xf9, 0x55, 0x78, 0x5f, 0x1c, 0x1c, 0xed, 0xfc, 0xaa, 0x0c, 0x5e, 0x9f, 0x7c, 0x9a, 0xf5, 0xb1,
		0xc2, 0xfb, 0xca, 0xe0, 0x68, 0xce, 0x3b, 0xe5, 0xc1, 0xd1, 0x6f, 0xfe, 0x8e, 0xd2, 0x60, 0x3b,
		0xf5, 0xd1, 0xe1, 0xf9, 0xbd, 0x79, 0x5f, 0x28, 0xce, 0xf9, 0xc2, 0xfe, 0xbc, 0x2f, 0xec, 0xcf,
		0xf9, 0xc2, 0x5c, 0x93, 0xf6, 0xe6, 0x7c, 0xa1, 0x34, 0x78, 0x4a, 0x7d, 0x7e, 0x7b, 0xf6, 0x47,
		0xcb, 0x83, 0x9d, 0xa7, 0x79, 0xef, 0x55, 0x06, 0x4f, 0x47, 0x3b, 0x3b, 0xde, 0x76, 0x61, 0xef,
		0x7a, 0xd7, 0x3d, 0xb8, 0x79, 0x2a, 0x5c, 0xef, 0xba, 0x85, 0x9b, 0xe1, 0x27, 0x6f, 0x9e, 0xae,
		0x0b, 0xee, 0xe1, 0xe4, 0x70, 0xf8, 0xdf, 0x9d, 0xff, 0xe0, 0x24, 0xe6, 0x1b, 0xa4, 0x88, 0xaa,
		0x5f, 0xd6, 0xfe, 0xc7, 0xb0, 0x62, 0x58, 0xad, 0x41, 0x58, 0x51, 0x6d, 0x80, 0x51, 0x1b, 0xc6,
		0x6d, 0x8f, 0x82, 0xbe, 0x16, 0x78, 0x92, 0xc3, 0x4b, 0xe3, 0xa8, 0x3b, 0x50, 0x77, 0xa0, 0xee,
		0x40, 0xdd, 0x81, 0xba, 0x03, 0x75, 0x87, 0x0d, 0xd3, 0x1d, 0x9a, 0x41, 0xd0, 0x15, 0xbe, 0x42,
		0xd4, 0x1c, 0x0a, 0xa4, 0x72, 0x00, 0x16, 0xd8, 0xde, 0x5b, 0xb4, 0xaa, 0x54, 0xa0, 0x7d, 0x2d,
		0x41, 0x3a, 0x7b, 0x3a, 0x51, 0xeb, 0x9b, 0xb8, 0xf3, 0x7b, 0xe3, 0x76, 0xb2, 0x5e, 0xd0, 0x13,
		0xaa, 0x35, 0x22, 0x4a, 0xae, 0x12, 0xfa, 0x67, 0x10, 0xfe, 0x70, 0xa5, 0x8a, 0xb4, 0xaf, 0x5a,
		0xc2, 0x7b, 0x7d, 0x22, 0x4a, 0x9d, 0xf1, 0x7a, 0x61, 0xa0, 0x83, 0x56, 0xd0, 0x8d, 0x92, 0x23,
		0xaf, 0x79, 0xdb, 0xf3, 0x42, 0xd9, 0xf4, 0xfc, 0x8e, 0x74, 0x23, 0xbf, 0x23, 0xa3, 0xe4, 0xc8,
		0x1b, 0x89, 0x84, 0x7d, 0x25, 0x5b, 0x7e, 0xa4, 0x3d, 0x25, 0xe4, 0xed, 0xb7, 0x66, 0x10, 0x46,
		0xc9, 0x91, 0xe7, 0xb7, 0xbf, 0x8f, 0x90, 0x20, 0xe8, 0x6b, 0xb7, 0x17, 0x44, 0xda, 0x1b, 0xd1,
		0xdb, 0x28, 0xfe, 0x11, 0xb7, 0xaf, 0xe5, 0xe6, 0xed, 0xe6, 0x5d, 0xa6, 0xaf, 0x7e, 0xa8, 0xe0,
		0xa7, 0x72, 0x7d, 0xad, 0x43, 0xd9, 0x1c, 0x8e, 0x08, 0xce, 0x4e, 0xee, 0x33, 0x6c, 0xe3, 0xb6,
		0xee, 0xdc, 0xd6, 0x3d, 0x4f, 0xb3, 0x1d, 0x6e, 0xeb, 0x9e, 0xf7, 0x59, 0x0d, 0xb7, 0x75, 0x87,
		0xa4, 0x5e, 0x30, 0xdb, 0xba, 0xa7, 0x40, 0x0a, 0x4f, 0x4e, 0x4c, 0x9b, 0x88, 0x25, 0x2a, 0x16,
		0x28, 0x2a, 0xc2, 0xc3, 0x2b, 0x36, 0xcc, 0xa2, 0xc2, 0x2d, 0x3c, 0xec, 0xc2, 0xc3, 0x2f, 0x3c,
		0x0c, 0xe3, 0x68, 0x31, 0x5b, 0x40, 0xa2, 0x22, 0x0a, 0x3c, 0x27, 0x06, 0x8d, 0x36, 0x21, 0xd7,
		0x68, 0x52, 0xe7, 0x54, 0x46, 0x7d, 0x36, 0x11, 0x2c, 0xf4, 0x30, 0x17, 0x8a, 0xc0, 0xc1, 0x35,
		0x32, 0x6c, 0xe7, 0x03, 0xbe, 0xd1, 0x61, 0x3c, 0x37, 0x70, 0x9e, 0x1b, 0x58, 0xcf, 0x0d, 0xbc,
		0x63, 0xc1, 0x3c, 0x18, 0xdc, 0x27, 0xa3, 0x78, 0x85, 0x08, 0xb0, 0x5b, 0xd8, 0x5b, 0x12, 0xa6,
		0x66, 0xc3, 0x15, 0x40, 0xdb, 0x5e, 0x6c, 0x51, 0x18, 0xef, 0x34, 0xf8, 0x4c, 0x56, 0xb8, 0xb4,
		0x10, 0x3d, 0x34, 0x9d, 0xf8, 0xe9, 0x1a, 0x2c, 0xf1, 0x8d, 0xcd, 0xc3, 0x24, 0xbd, 0x05, 0x92,
		0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x22, 0xeb, 0xec, 0x51, 0x44, 0xd3, 0xba,
		0x12, 0xc3, 0x46, 0x1c, 0xad, 0x2b, 0x80, 0xbb, 0xf2, 0x4c, 0x49, 0x5f, 0x43, 0x4b, 0xdf, 0xb3,
		0x55, 0xca, 0x1a, 0x91, 0x82, 0x3c, 0x90, 0x83, 0x7c, 0x91, 0x84, 0xbc, 0x90, 0x85, 0xdc, 0x91,
		0x86, 0xdc, 0x91, 0x87, 0xdc, 0x91, 0x08, 0x4c, 0x32, 0x01, 0x4a, 0x2a, 0x92, 0xd1, 0x85, 0x55,
		0xd4, 0x52, 0x79, 0xb3, 0x2f, 0x95, 0x2e, 0x94, 0x91, 0x73, 0xe6, 0x18, 0xc5, 0xcb, 0xc0, 0x26,
		0x62, 0x36, 0x9b, 0x7c, 0xfd, 0xc2, 0xc6, 0x9c, 0x2d, 0xf4, 0x66, 0x94, 0x39, 0xa3, 0x97, 0x29,
		0x73, 0xc1, 0x9b, 0x55, 0xa6, 0xec, 0xcd, 0x41, 0x83, 0xbe, 0x9c, 0xc0, 0xd1, 0x74, 0x88, 0xf9,
		0x0f, 0x0c, 0xb1, 0x8c, 0x43, 0xac, 0x5c, 0x2a, 0xed, 0x97, 0x18, 0x66, 0x9b, 0xc5, 0x45, 0xf1,
		0xad, 0xbb, 0x79, 0xc7, 0xfb, 0x95, 0xd3, 0x34, 0x0e, 0x5c, 0x09, 0x97, 0x9a, 0x52, 0xa0, 0x56,
		0xc4, 0xe5, 0x04, 0x55, 0xa8, 0x0b, 0xae, 0xd2, 0x19, 0xa9, 0x0b, 0xae, 0x34, 0x72, 0xa8, 0x0b,
		0x66, 0x6c, 0x30, 0x75, 0xc1, 0x35, 0x9e, 0x88, 0xe5, 0x4c, 0x17, 0x3c, 0xc8, 0x81, 0x2c, 0x58,
		0xa2, 0x2c, 0xb8, 0xe4, 0x8b, 0xb2, 0x20, 0x35, 0x0b, 0xca, 0x82, 0x1b, 0x88, 0x46, 0xd3, 0x21,
		0x46, 0x59, 0x30, 0xf3, 0x10, 0xdb, 0x2b, 0x51, 0x14, 0xdc, 0x30, 0x22, 0x8a, 0x6f, 0x1d, 0x45,
		0xc1, 0xdc, 0x26, 0xf1, 0x58, 0x69, 0xbb, 0x1f, 0x67, 0x97, 0x3c, 0xa8, 0x82, 0xb1, 0xad, 0x94,
		0x05, 0xdf, 0x62, 0x1e, 0x65, 0xc1, 0x15, 0x7a, 0x23, 0x65, 0xc1, 0x95, 0x46, 0x0e, 0x65, 0xc1,
		0x8c, 0x0d, 0xa6, 0x2c, 0xb8, 0xc6, 0x13, 0xb1, 0x1c, 0xc9, 0x82, 0x4d, 0xa9, 0xfc, 0xf0, 0x31,
		0x07, 0xba, 0xe0, 0x21, 0xb0, 0x89, 0xa7, 0x42, 0xdd, 0x8e, 0x16, 0xe6, 0x52, 0x18, 0x5c, 0x56,
		0xb5, 0xa0, 0x30, 0x98, 0xb9, 0x6a, 0x51, 0xa0, 0x66, 0xb1, 0x61, 0x78, 0x34, 0x1d, 0x62, 0x14,
		0x06, 0x33, 0x0f, 0x31, 0xd6, 0x0b, 0x6e, 0x20, 0x19, 0xc5, 0xb7, 0x8e, 0xd2, 0x60, 0x6e, 0xd3,
		0xb8, 0x23, 0x1e, 0xb4, 0x50, 0x6d, 0xd1, 0xc6, 0x17, 0x06, 0x13, 0x4b, 0x29, 0x0b, 0xbe, 0xc5,
		0x3c, 0xca, 0x82, 0x2b, 0xf4, 0x45, 0xca, 0x82, 0x2b, 0x8d, 0x1c, 0xca, 0x82, 0x19, 0x1b, 0x4c,
		0x59, 0x70, 0x8d, 0xa7, 0x61, 0x79, 0x92, 0x05, 0xe1, 0xf6, 0xfc, 0x9a, 0x07, 0xe3, 0x20, 0x7b,
		0x80, 0x91, 0xd4, 0xbe, 0x65, 0x0c, 0x83, 0xde, 0x70, 0xe6, 0xe9, 0x77, 0xf1, 0x49, 0x6d, 0x62,
		0x29, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49,
		0x2d, 0x49, 0x2d, 0x83, 0x62, 0x7a, 0x0c, 0x7b, 0x7e, 0xa8, 0x65, 0x1e, 0x38, 0xed, 0xc4, 0x50,
		0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a,
		0x52, 0x5a, 0x06, 0xc5, 0xf4, 0x18, 0xea, 0xd0, 0x57, 0x91, 0xd4, 0xf2, 0x3e, 0x07, 0xeb, 0x92,
		0x5e, 0xd8, 0x4a, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62,
		0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x8b, 0x40, 0x43, 0xd4, 0xa9, 0x2a, 0x15, 0x68, 0x5f, 0xcb, 0x00,
		0x73, 0x01, 0x94, 0x13, 0xb5, 0xbe, 0x89, 0x3b, 0xbf, 0x37, 0xde, 0x80, 0xd2, 0x0b, 0x7a, 0x42,
		0xb5, 0x46, 0x44, 0xd1, 0x55, 0x42, 0xff, 0x0c, 0xc2, 0x1f, 0xae, 0x54, 0x91, 0xf6, 0x55, 0x4b,
		0x78, 0xaf, 0x4f, 0x44, 0xa9, 0x33, 0x5e, 0x2f, 0x0c, 0x74, 0xd0, 0x0a, 0xba, 0x51, 0x72, 0xe4,
		0x35, 0x6f, 0x7b, 0x5e, 0x28, 0x9b, 0x9e, 0xdf, 0x91, 0x6e, 0xe4, 0x77, 0x64, 0x94, 0x1c, 0x79,
		0xb2, 0x77, 0x5f, 0x76, 0xfb, 0x4a, 0xb6, 0xfc, 0x48, 0x7b, 0x4a, 0xc8, 0xdb, 0x6f, 0xcd, 0x20,
		0x8c, 0x92, 0x23, 0xcf, 0x6f, 0x7f, 0x1f, 0x21, 0x55, 0xd0, 0xd7, 0x6e, 0x2f, 0x88, 0xb4, 0x17,
		0x06, 0x7d, 0x2d, 0xa2, 0xf8, 0x87, 0xd7, 0x57, 0x3f, 0x54, 0xf0, 0x53, 0xb9, 0xbe, 0xd6, 0xa1,
		0x6c, 0x8e, 0xde, 0x48, 0x9d, 0x8a, 0xb7, 0xd3, 0xe4, 0x26, 0x9a, 0xc8, 0x96, 0xa0, 0x6c, 0xaa,
		0xff, 0x5f, 0xf1, 0x88, 0xd8, 0x15, 0xd7, 0x39, 0x95, 0x91, 0xae, 0x6a, 0x0d, 0xb6, 0xe3, 0xff,
		0x67, 0xa9, 0x4e, 0xba, 0x62, 0x48, 0x29, 0x23, 0xac, 0x29, 0xa5, 0xf3, 0xd9, 0x7f, 0x78, 0x61,
		0x59, 0xe1, 0xa0, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xdd, 0xca, 0x7e, 0x65, 0xf7, 0xb0, 0x54, 0x2a,
		0x94, 0x0b, 0x40, 0x2b, 0xb8, 0x9c, 0x7a, 0xd8, 0x16, 0xa1, 0x68, 0x7f, 0x1c, 0xba, 0x9e, 0xea,
		0x77, 0xbb, 0x8c, 0x48, 0x7c, 0xec, 0x5c, 0x73, 0xcc, 0x74, 0xa0, 0xb6, 0x56, 0x0e, 0xfb, 0x2d,
		0xad, 0xc6, 0x93, 0x87, 0xb3, 0xf8, 0xd6, 0xd5, 0xc6, 0x77, 0xae, 0x71, 0x3e, 0xbe, 0x5f, 0x8d,
		0x8f, 0xb7, 0xbd, 0xc6, 0x85, 0x6c, 0x36, 0xaa, 0x1d, 0x79, 0xe9, 0x77, 0x64, 0xa3, 0xd6, 0xbb,
		0x2f, 0x7f, 0x89, 0xef, 0x51, 0xe3, 0x6c, 0x7c, 0x67, 0x1a, 0xd5, 0xf6, 0xf7, 0x0b, 0xd9, 0xac,
		0xf7, 0xf5, 0x79, 0x10, 0xe9, 0xc6, 0xc5, 0xf0, 0x7e, 0x34, 0xbe, 0xc4, 0x7f, 0x7c, 0x35, 0xf9,
		0xdb, 0xdf, 0x11, 0x97, 0xed, 0x5b, 0x60, 0x39, 0xff, 0xa0, 0xe5, 0x9d, 0xb5, 0xca, 0x37, 0x76,
		0x23, 0xcc, 0x9e, 0x5f, 0xdb, 0xb9, 0xb2, 0xa5, 0x48, 0x9a, 0x70, 0xe9, 0x58, 0xcc, 0xdd, 0x1a,
		0x7a, 0xae, 0x2b, 0x6d, 0x2d, 0x1c, 0xc5, 0x20, 0xd0, 0x38, 0x84, 0x19, 0x9a, 0x20, 0x63, 0x10,
		0x62, 0x5b, 0x61, 0x03, 0x02, 0x3c, 0xf9, 0x05, 0x1c, 0x8b, 0xdc, 0x35, 0x6b, 0xae, 0x6a, 0x07,
		0x38, 0xcd, 0xc3, 0x96, 0xd9, 0x2b, 0x1a, 0x8e, 0x74, 0xdb, 0x11, 0x9e, 0xc7, 0xc8, 0x36, 0xeb,
		0xf8, 0xe6, 0xdc, 0xcf, 0xcc, 0x95, 0x0c, 0x39, 0xb8, 0x2d, 0xc7, 0xce, 0x95, 0x43, 0x1b, 0x44,
		0xa7, 0xec, 0xd0, 0xc8, 0x4c, 0x38, 0x66, 0x1f, 0x1c, 0x06, 0x02, 0xc3, 0x99, 0x72, 0x80, 0xd0,
		0xdc, 0x23, 0xfa, 0xe7, 0x66, 0xde, 0xaf, 0x0c, 0x30, 0x94, 0x0c, 0x26, 0x8f, 0xd0, 0x0d, 0x5d,
		0xce, 0x74, 0x65, 0x9b, 0x8d, 0x4a, 0x35, 0xbb, 0x95, 0x67, 0xb6, 0x2a, 0xc9, 0xac, 0x57, 0x86,
		0x59, 0xaf, 0xf4, 0xb2, 0x5e, 0xb9, 0xb5, 0x5e, 0x34, 0xe5, 0x58, 0x9a, 0x95, 0x81, 0x9c, 0x31,
		0x87, 0x35, 0x1e, 0x38, 0x93, 0x74, 0x31, 0xbe, 0xbe, 0x61, 0xa7, 0x35, 0x0b, 0x00, 0x69, 0x20,
		0xd8, 0x33, 0x7c, 0x61, 0x8b, 0xa5, 0xcb, 0x18, 0x25, 0xc9, 0xb6, 0x4b, 0x8d, 0x61, 0x4a, 0x88,
		0x61, 0x4a, 0x83, 0x61, 0x4a, 0x7e, 0xd7, 0x5b, 0xd0, 0x31, 0x0d, 0x28, 0xd3, 0xc0, 0x62, 0x2f,
		0xde, 0xa6, 0xf0, 0xc5, 0x56, 0xac, 0xd9, 0x81, 0x19, 0x6b, 0xf3, 0x0e, 0x24, 0xd8, 0xc1, 0x82,
		0x1f, 0x14, 0x18, 0x82, 0x83, 0x23, 0x38, 0x58, 0x82, 0x83, 0x27, 0x3b, 0x30, 0x65, 0x09, 0xae,
		0xac, 0xc3, 0x56, 0x62, 0xc0, 0xa4, 0x26, 0xc0, 0x7a, 0xa4, 0x3e, 0x77, 0x4d, 0xb1, 0x59, 0xa4,
		0xf0, 0x1a, 0xd2, 0x2c, 0x17, 0xd4, 0xc2, 0x2c, 0x16, 0x45, 0x5a, 0x14, 0x8a, 0xb9, 0xf8, 0x13,
		0x6d, 0x91, 0x27, 0xec, 0x62, 0x4e, 0xd8, 0x45, 0x9b, 0xb0, 0x8b, 0x33, 0x37, 0xbb, 0x0a, 0x14,
		0x66, 0x51, 0x65, 0x92, 0x77, 0xba, 0xc2, 0xef, 0x84, 0xa2, 0x83, 0x90, 0x74, 0x26, 0x33, 0xaf,
		0x0a, 0x80, 0x2d, 0xe7, 0xe3, 0x87, 0xbf, 0x1f, 0x3e, 0xc4, 0xcb, 0xbd, 0xbc, 0x09, 0x94, 0x6f,
		0x6a, 0xa9, 0xa9, 0xc5, 0xf9, 0x57, 0x0f, 0x03, 0xae, 0x9f, 0x59, 0x1d, 0xc4, 0xe4, 0x8b, 0xa4,
		0x8e, 0xa4, 0x8e, 0xa4, 0x8e, 0xa4, 0x8e, 0xa4, 0x8e, 0xa4, 0x8e, 0xa4, 0xee, 0x8d, 0xa4, 0x2e,
		0x4e, 0x3b, 0xe4, 0x74, 0xc6, 0x87, 0x22, 0xee, 0xa1, 0x00, 0x43, 0xe9, 0x62, 0x73, 0x30, 0x18,
		0x5d, 0x81, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0xce, 0xd6, 0xa8, 0xd8, 0x7e,
		0x92, 0x95, 0x18, 0x32, 0x6a, 0x1c, 0x23, 0x55, 0x5b, 0xe0, 0xb4, 0xb0, 0x7c, 0xae, 0x03, 0x7f,
		0xb6, 0x0d, 0xa5, 0xdb, 0x0e, 0x54, 0xb3, 0x54, 0xb8, 0xe6, 0xa8, 0x88, 0xcd, 0x50, 0xb1, 0x9b,
		0x9f, 0xa2, 0x36, 0x3b, 0x85, 0x6f, 0x6e, 0x0a, 0xdf, 0xcc, 0x14, 0xbe, 0x79, 0x29, 0xfb, 0xa8,
		0x41, 0x4a, 0x2c, 0xc0, 0x52, 0x0b, 0xa2, 0xe4, 0x32, 0x4b, 0x7a, 0xf9, 0x87, 0x7f, 0x23, 0x4a,
		0x11, 0x09, 0x1d, 0x25, 0x47, 0x63, 0xa1, 0x26, 0xa6, 0x19, 0x6c, 0xa4, 0x84, 0x12, 0x94, 0x4e,
		0x2b, 0xb8, 0xbb, 0xeb, 0x2b, 0xa9, 0x1f, 0x51, 0xd9, 0xe9, 0x6b, 0x03, 0x49, 0x51, 0x49, 0x51,
		0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0xdf, 0x4a, 0x51, 0x27,
		0xbc, 0x42, 0x8a, 0x28, 0x39, 0x7e, 0x24, 0x4b, 0xc5, 0x64, 0xa9, 0xe2, 0x41, 0xbb, 0xf0, 0x4c,
		0x75, 0x96, 0x91, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64,
		0xab, 0x64, 0xab, 0x6f, 0x65, 0xab, 0x2f, 0xb9, 0xc5, 0x90, 0xb1, 0x4e, 0x71, 0x0d, 0xb2, 0x56,
		0x4c, 0xd6, 0x2a, 0xd5, 0xbd, 0xdf, 0x95, 0x6d, 0x37, 0x14, 0x7e, 0x04, 0xb4, 0x4d, 0x45, 0x12,
		0xa1, 0xaf, 0xec, 0x23, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0x25, 0x57, 0xdd,
		0x30, 0xae, 0x2a, 0xdb, 0x42, 0x69, 0xa9, 0x1f, 0x41, 0xf9, 0x2a, 0xd2, 0xa6, 0x64, 0xb5, 0xf1,
		0xad, 0xfa, 0xe8, 0x47, 0x80, 0x29, 0x75, 0x32, 0xa0, 0xb5, 0xb3, 0xaf, 0xd5, 0xd3, 0xda, 0x71,
		0xe3, 0xa2, 0xfe, 0xe5, 0xea, 0xa4, 0x71, 0x71, 0x52, 0xbd, 0xac, 0x9f, 0xa1, 0x65, 0xd7, 0xaf,
		0x7e, 0xb7, 0x3f, 0xea, 0xfe, 0x78, 0x0d, 0xb7, 0xf3, 0x27, 0xf8, 0x76, 0xff, 0x93, 0xd1, 0xfd,
		0xe3, 0xf4, 0xcb, 0xe5, 0xd5, 0xc9, 0x45, 0xe3, 0xb4, 0x5e, 0x3f, 0xc7, 0xdb, 0xae, 0x1a, 0x70,
		0x43, 0xe8, 0x9c, 0x8c, 0x6b, 0xf5, 0x92, 0x43, 0xba, 0x66, 0x43, 0x5a, 0xbf, 0xa8, 0xfd, 0x59,
		0x3b, 0xab, 0x5e, 0xd5, 0x2f, 0x38, 0xaa, 0x6b, 0x94, 0x80, 0xeb, 0x67, 0x9f, 0x4e, 0x8e, 0x1d,
		0x6e, 0x3b, 0xfe, 0x8f, 0xaf, 0x1b, 0xce, 0x47, 0xc0, 0xac, 0x40, 0x50, 0x07, 0xbb, 0x7e, 0xa4,
		0xdd, 0xbb, 0xa0, 0x2d, 0x3b, 0x52, 0xb4, 0xf1, 0xc4, 0xc1, 0x69, 0xf3, 0xa8, 0x0d, 0xce, 0x32,
		0x87, 0xda, 0xe0, 0x02, 0x0e, 0x45, 0x6d, 0x70, 0x21, 0x4f, 0xa7, 0x36, 0xb8, 0xa4, 0x81, 0xd4,
		0x06, 0x73, 0xc4, 0x7d, 0x81, 0xb5, 0x41, 0x2d, 0xef, 0x84, 0x96, 0xad, 0x1f, 0x51, 0xb9, 0x08,
		0xa8, 0x0d, 0x1e, 0x00, 0x99, 0xf4, 0x45, 0xc9, 0xd1, 0xae, 0xb1, 0x8e, 0xf2, 0x55, 0x10, 0x89,
		0x56, 0xa0, 0xda, 0x11, 0xd2, 0x2d, 0xbb, 0xf0, 0xd5, 0xad, 0x80, 0xd3, 0xdb, 0xf0, 0xa6, 0x7a,
		0xce, 0x67, 0xa9, 0xe0, 0x10, 0x11, 0x94, 0x03, 0xa6, 0xcc, 0x1b, 0xa9, 0xba, 0xc0, 0xf6, 0x7d,
		0x0a, 0xfd, 0x96, 0x96, 0x81, 0x3a, 0x96, 0xb7, 0x71, 0xb4, 0xee, 0x52, 0x8f, 0xf9, 0x9d, 0x90,
		0xf0, 0x1f, 0x18, 0x12, 0x4b, 0x86, 0x04, 0xd6, 0x6e, 0xe2, 0xb9, 0x8f, 0x92, 0x77, 0xb4, 0x66,
		0xd6, 0xeb, 0x86, 0x1a, 0x17, 0x4a, 0x16, 0x85, 0xd9, 0xc8, 0x21, 0x45, 0xea, 0x31, 0x36, 0x74,
		0x00, 0x4d, 0xe0, 0xd4, 0xb5, 0x16, 0x71, 0x25, 0xea, 0x5a, 0x0b, 0x79, 0x3a, 0x75, 0xad, 0x25,
		0x0d, 0xa4, 0xae, 0x95, 0xa3, 0x39, 0x04, 0xb0, 0xae, 0xd5, 0x97, 0x4a, 0xef, 0xef, 0x01, 0x4a,
		0x5a, 0x15, 0x4a, 0x46, 0xff, 0xf2, 0xa2, 0x64, 0xb4, 0x96, 0xf3, 0x63, 0x4a, 0x46, 0x79, 0x4f,
		0xf7, 0xd3, 0x21, 0x41, 0xc9, 0x68, 0xe9, 0x90, 0x28, 0xee, 0x1d, 0x16, 0x0f, 0xcb, 0x95, 0xbd,
		0x43, 0x0a, 0x45, 0x6b, 0x20, 0xcd, 0x6c, 0x51, 0x28, 0x02, 0xbc, 0x1f, 0x10, 0x42, 0x11, 0xd6,
		0x04, 0x1f, 0x6b, 0x8b, 0x28, 0xd0, 0xa4, 0x4d, 0x99, 0x68, 0x11, 0x4f, 0xa2, 0x4c, 0xb4, 0x90,
		0xa7, 0x53, 0x26, 0x5a, 0xd2, 0x40, 0xca, 0x44, 0x39, 0x9a, 0x37, 0x20, 0x2f, 0x8d, 0xec, 0xdd,
		0x97, 0x5d, 0xb8, 0x18, 0x4c, 0x96, 0x46, 0x1e, 0x60, 0xb5, 0xf2, 0xd0, 0x22, 0x54, 0x70, 0x72,
		0x91, 0xf3, 0xf7, 0xf6, 0xf6, 0xf5, 0xae, 0x7b, 0xe8, 0xbb, 0x9d, 0xaa, 0xfb, 0xe9, 0xe6, 0x57,
		0xe1, 0x7d, 0x71, 0x70, 0xb4, 0xf3, 0xab, 0x32, 0x78, 0x7d, 0xf2, 0x69, 0xd6, 0xc7, 0x0a, 0xef,
		0x2b, 0x83, 0xa3, 0x39, 0xef, 0x94, 0x07, 0x47, 0xbf, 0xf9, 0x3b, 0x4a, 0x83, 0xed, 0xd4, 0x47,
		0x87, 0xe7, 0xf7, 0xe6, 0x7d, 0xa1, 0x38, 0xe7, 0x0b, 0xfb, 0xf3, 0xbe, 0xb0, 0x3f, 0xe7, 0x0b,
		0x73, 0x4d, 0xda, 0x9b, 0xf3, 0x85, 0xd2, 0xe0, 0x29, 0xf5, 0xf9, 0xed, 0xd9, 0x1f, 0x2d, 0x0f,
		0x76, 0x9e, 0xe6, 0xbd, 0x57, 0x19, 0x3c, 0x1d, 0xed, 0xec, 0x78, 0xdb, 0x85, 0xbd, 0xeb, 0x5d,
		0xf7, 0xe0, 0xe6, 0xa9, 0x70, 0xbd, 0xeb, 0x16, 0x6e, 0x86, 0x9f, 0xbc, 0x79, 0xba, 0x2e, 0xb8,
		0x87, 0x93, 0xc3, 0xe1, 0x7f, 0x77, 0xfe, 0x83, 0x93, 0x98, 0x6f, 0x90, 0x22, 0xaa, 0x7e, 0x59,
		0xfb, 0x1f, 0xc3, 0x8a, 0x61, 0xb5, 0x06, 0x61, 0x45, 0xb5, 0x01, 0x46, 0x6d, 0x18, 0xb7, 0x3d,
		0x0a, 0xfa, 0x5a, 0xe0, 0x49, 0x0e, 0x2f, 0x8d, 0xa3, 0xee, 0x40, 0xdd, 0x81, 0xba, 0x03, 0x75,
		0x07, 0xea, 0x0e, 0xd4, 0x1d, 0x36, 0x4c, 0x77, 0x68, 0x06, 0x41, 0x57, 0xf8, 0x0a, 0x51, 0x73,
		0x28, 0x90, 0xca, 0x01, 0x58, 0x60, 0x7b, 0x6f, 0xd1, 0xaa, 0x52, 0x81, 0xf6, 0xb5, 0x04, 0xe9,
		0xec, 0xe9, 0x44, 0xad, 0x6f, 0xe2, 0xce, 0xef, 0x8d, 0xdb, 0xc9, 0x7a, 0x41, 0x4f, 0xa8, 0xd6,
		0x88, 0x28, 0xb9, 0x4a, 0xe8, 0x9f, 0x41, 0xf8, 0xc3, 0x95, 0x2a, 0xd2, 0xbe, 0x6a, 0x09, 0xef,
		0xf5, 0x89, 0x28, 0x75, 0xc6, 0xeb, 0x85, 0x81, 0x0e, 0x5a, 0x41, 0x37, 0x4a, 0x8e, 0xbc, 0xe6,
		0x6d, 0xcf, 0x0b, 0x65, 0xd3, 0xf3, 0x3b, 0xd2, 0x8d, 0xfc, 0x8e, 0x8c, 0x92, 0x23, 0x6f, 0x24,
		0x12, 0xf6, 0x95, 0x6c, 0xf9, 0x91, 0xf6, 0x94, 0x90, 0xb7, 0xdf, 0x9a, 0x41, 0x18, 0x25, 0x47,
		0x9e, 0xdf, 0xfe, 0x3e, 0x42, 0x82, 0xa0, 0xaf, 0xdd, 0x5e, 0x28, 0xbc, 0x11, 0xbb, 0x8d, 0xe2,
		0x1f, 0x71, 0xf7, 0x5a, 0xee, 0xdd, 0x6e, 0xde, 0x63, 0xfa, 0xea, 0x87, 0x0a, 0x7e, 0x2a, 0xd7,
		0xd7, 0x3a, 0x94, 0xcd, 0xe1, 0x88, 0xe0, 0x6c, 0xe4, 0x3e, 0xc3, 0x36, 0xee, 0xea, 0xce, 0x5d,
		0xdd, 0xf3, 0x34, 0xd9, 0xe1, 0xae, 0xee, 0x79, 0x9f, 0xd4, 0x70, 0x57, 0x77, 0x48, 0xe6, 0x05,
		0xb3, 0xab, 0x7b, 0x0a, 0xa4, 0xf0, 0xd4, 0xc4, 0xb4, 0x89, 0x58, 0x9a, 0x62, 0x81, 0x9a, 0x22,
		0x3c, 0xbc, 0x62, 0xc3, 0x2c, 0x2a, 0xdc, 0xc2, 0xc3, 0x2e, 0x3c, 0xfc, 0xc2, 0xc3, 0x30, 0x8e,
		0x14, 0xb3, 0x05, 0xa4, 0x29, 0xa2, 0xc0, 0x73, 0x62, 0xd0, 0x68, 0x0f, 0x72, 0x8d, 0xa6, 0x74,
		0x4e, 0x65, 0xd4, 0x67, 0x13, 0xc1, 0x42, 0x0f, 0x73, 0x9d, 0x08, 0x1c, 0x5c, 0x23, 0xc3, 0x76,
		0x3e, 0xe0, 0x1b, 0x1d, 0xc6, 0x73, 0x03, 0xe7, 0xb9, 0x81, 0xf5, 0xdc, 0xc0, 0x3b, 0x16, 0xcc,
		0x83, 0xc1, 0x7d, 0x32, 0x8a, 0x57, 0x88, 0x00, 0xbb, 0x85, 0xbd, 0x23, 0x61, 0x6a, 0x36, 0x5c,
		0x01, 0xb4, 0xed, 0xc5, 0x0e, 0x85, 0xf1, 0x46, 0x83, 0xcf, 0x64, 0x85, 0x2b, 0x0b, 0xd1, 0x43,
		0xd3, 0x89, 0x9f, 0xae, 0xc1, 0x12, 0xdf, 0xd8, 0x3c, 0x4c, 0xd2, 0x5b, 0x20, 0xe9, 0x25, 0xe9,
		0x25, 0xe9, 0x25, 0xe9, 0x25, 0xe9, 0x25, 0xb2, 0xce, 0x1e, 0x45, 0x34, 0xad, 0x2b, 0x31, 0x6c,
		0xc4, 0xd1, 0xba, 0x02, 0xb8, 0x29, 0xcf, 0x94, 0xf4, 0x35, 0xb4, 0xf4, 0x3d, 0x3b, 0xa5, 0xac,
		0x11, 0x29, 0xc8, 0x03, 0x39, 0xc8, 0x17, 0x49, 0xc8, 0x0b, 0x59, 0xc8, 0x1d, 0x69, 0xc8, 0x1d,
		0x79, 0xc8, 0x1d, 0x89, 0xc0, 0x24, 0x13, 0xa0, 0xa4, 0x22, 0x19, 0x5d, 0x58, 0x45, 0x2d, 0x95,
		0x37, 0xfb, 0x52, 0xe9, 0x42, 0x19, 0x39, 0x67, 0x8e, 0x51, 0xbc, 0x0c, 0x6c, 0x22, 0x66, 0xaf,
		0xc9, 0xd7, 0x2f, 0x6c, 0xcc, 0xd9, 0x42, 0xef, 0x45, 0x99, 0x33, 0x7a, 0x99, 0x32, 0x17, 0xbc,
		0x57, 0x65, 0xca, 0xde, 0x1c, 0xf4, 0xe7, 0xcb, 0x09, 0x1c, 0x4d, 0x87, 0x98, 0xff, 0xc0, 0x10,
		0xcb, 0x38, 0xc4, 0xca, 0xa5, 0xd2, 0x7e, 0x89, 0x61, 0xb6, 0x59, 0x5c, 0x14, 0xdf, 0xba, 0x9b,
		0x77, 0xbc, 0x5f, 0x39, 0x4d, 0xe3, 0xc0, 0x95, 0x70, 0xa9, 0x29, 0x05, 0x6a, 0x45, 0x5c, 0x4e,
		0x50, 0x85, 0xba, 0xe0, 0x2a, 0x9d, 0x91, 0xba, 0xe0, 0x4a, 0x23, 0x87, 0xba, 0x60, 0xc6, 0x06,
		0x53, 0x17, 0x5c, 0xe3, 0x89, 0x58, 0xce, 0x74, 0xc1, 0x83, 0x1c, 0xc8, 0x82, 0x25, 0xca, 0x82,
		0x4b, 0xbe, 0x28, 0x0b, 0x52, 0xb3, 0xa0, 0x2c, 0xb8, 0x81, 0x68, 0x34, 0x1d, 0x62, 0x94, 0x05,
		0x33, 0x0f, 0xb1, 0xbd, 0x12, 0x45, 0xc1, 0x0d, 0x23, 0xa2, 0xf8, 0xd6, 0x51, 0x14, 0xcc, 0x6d,
		0x12, 0x8f, 0x95, 0xb6, 0xfb, 0x71, 0x76, 0xc9, 0x83, 0x2a, 0x18, 0xdb, 0x4a, 0x59, 0xf0, 0x2d,
		0xe6, 0x51, 0x16, 0x5c, 0xa1, 0x37, 0x52, 0x16, 0x5c, 0x69, 0xe4, 0x50, 0x16, 0xcc, 0xd8, 0x60,
		0xca, 0x82, 0x6b, 0x3c, 0x11, 0xcb, 0x91, 0x2c, 0xd8, 0x94, 0xca, 0x0f, 0x1f, 0x73, 0xa0, 0x0b,
		0x1e, 0x02, 0x9b, 0x78, 0x2a, 0xd4, 0xed, 0x68, 0x61, 0x2e, 0x85, 0xc1, 0x65, 0x55, 0x0b, 0x0a,
		0x83, 0x99, 0xab, 0x16, 0x05, 0x6a, 0x16, 0x1b, 0x86, 0x47, 0xd3, 0x21, 0x46, 0x61, 0x30, 0xf3,
		0x10, 0x63, 0xbd, 0xe0, 0x06, 0x92, 0x51, 0x7c, 0xeb, 0x28, 0x0d, 0xe6, 0x36, 0x8d, 0x3b, 0xe2,
		0x41, 0x0b, 0xd5, 0x16, 0x6d, 0x7c, 0x61, 0x30, 0xb1, 0x94, 0xb2, 0xe0, 0x5b, 0xcc, 0xa3, 0x2c,
		0xb8, 0x42, 0x5f, 0xa4, 0x2c, 0xb8, 0xd2, 0xc8, 0xa1, 0x2c, 0x98, 0xb1, 0xc1, 0x94, 0x05, 0xd7,
		0x78, 0x1a, 0x96, 0x27, 0x59, 0x10, 0x6e, 0xcb, 0xaf, 0x79, 0x30, 0x0e, 0xb2, 0x05, 0x18, 0x49,
		0xed, 0x5b, 0xc6, 0x30, 0xe8, 0x0d, 0x67, 0x9e, 0x7e, 0x17, 0x9f, 0xd4, 0x26, 0x96, 0x92, 0xd4,
		0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4,
		0x32, 0x28, 0xa6, 0xc7, 0xb0, 0xe7, 0x87, 0x5a, 0xe6, 0x81, 0xd3, 0x4e, 0x0c, 0x25, 0xa5, 0x25,
		0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x65,
		0x50, 0x4c, 0x8f, 0xa1, 0x0e, 0x7d, 0x15, 0x49, 0x2d, 0xef, 0x73, 0xb0, 0x2e, 0xe9, 0x85, 0xad,
		0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6,
		0x24, 0xb6, 0xb4, 0x08, 0x34, 0x44, 0x9d, 0xaa, 0x52, 0x81, 0xf6, 0xb5, 0x0c, 0x30, 0x17, 0x40,
		0x39, 0x51, 0xeb, 0x9b, 0xb8, 0xf3, 0x7b, 0xe3, 0x0d, 0x28, 0xbd, 0xa0, 0x27, 0x54, 0x6b, 0x44,
		0x14, 0x5d, 0x25, 0xf4, 0xcf, 0x20, 0xfc, 0xe1, 0x4a, 0x15, 0x69, 0x5f, 0xb5, 0x84, 0xf7, 0xfa,
		0x44, 0x94, 0x3a, 0xe3, 0xf5, 0xc2, 0x40, 0x07, 0xad, 0xa0, 0x1b, 0x25, 0x47, 0x5e, 0xf3, 0xb6,
		0xe7, 0x85, 0xb2, 0xe9, 0xf9, 0x1d, 0xe9, 0x46, 0x7e, 0x47, 0x46, 0xc9, 0x91, 0x27, 0x7b, 0xf7,
		0x65, 0xb7, 0xaf, 0x64, 0xcb, 0x8f, 0xb4, 0xa7, 0x84, 0xbc, 0xfd, 0xd6, 0x0c, 0xc2, 0x28, 0x39,
		0xf2, 0xfc, 0xf6, 0xf7, 0x11, 0x52, 0x05, 0x7d, 0xed, 0xf6, 0x42, 0xe1, 0x85, 0x41, 0x5f, 0x8b,
		0x28, 0xfe, 0xe1, 0xf5, 0xd5, 0x0f, 0x15, 0xfc, 0x54, 0xae, 0xaf, 0x75, 0x28, 0x9b, 0xa3, 0x37,
		0x52, 0xa7, 0xe2, 0xdd, 0x34, 0xb9, 0x87, 0x26, 0xb2, 0x25, 0x28, 0x7b, 0xea, 0xff, 0x57, 0x3c,
		0x22, 0x36, 0xc5, 0x75, 0x4e, 0x65, 0xa4, 0xab, 0x5a, 0x83, 0x6d, 0xf8, 0xff, 0x59, 0xaa, 0x93,
		0xae, 0x18, 0x32, 0xca, 0x08, 0x6b, 0x46, 0xe9, 0x7c, 0xf6, 0x1f, 0x5e, 0x58, 0x56, 0x38, 0x28,
		0x16, 0xcb, 0x95, 0x62, 0x71, 0xb7, 0xb2, 0x5f, 0xd9, 0x3d, 0x2c, 0x95, 0x0a, 0xe5, 0x02, 0xd0,
		0x02, 0x2e, 0xa7, 0x1e, 0xb6, 0x45, 0x28, 0xda, 0x1f, 0x87, 0xae, 0xa7, 0xfa, 0xdd, 0x2e, 0x23,
		0x12, 0x1f, 0x3a, 0xd7, 0x1b, 0x32, 0x1d, 0xa8, 0x8d, 0x95, 0xc3, 0x7e, 0x4b, 0xab, 0xf1, 0xd4,
		0xe1, 0x2c, 0xbe, 0x73, 0xb5, 0xf1, 0x8d, 0x6b, 0x9c, 0x8f, 0x6f, 0x57, 0xe3, 0xe3, 0x6d, 0xaf,
		0x71, 0x21, 0x9b, 0x8d, 0x6a, 0x47, 0x5e, 0xfa, 0x1d, 0xd9, 0xa8, 0xf5, 0xee, 0xcb, 0x5f, 0xe2,
		0x5b, 0xd4, 0x38, 0x1b, 0xdf, 0x98, 0x46, 0xb5, 0xfd, 0xfd, 0x42, 0x36, 0xeb, 0x7d, 0x7d, 0x1e,
		0x8a, 0xc6, 0xc5, 0xf0, 0x76, 0x34, 0xbe, 0xc4, 0x7f, 0x7b, 0x35, 0xf9, 0xd3, 0xdf, 0x11, 0x95,
		0xed, 0x5b, 0x60, 0x39, 0xfb, 0xa0, 0x65, 0x9d, 0x75, 0xca, 0x36, 0x76, 0x03, 0xcc, 0x9e, 0x5b,
		0xdb, 0xb9, 0xb2, 0xa5, 0x40, 0x9a, 0x10, 0xe9, 0x58, 0xc8, 0xdd, 0x1a, 0x3a, 0xae, 0x2b, 0x6d,
		0x2d, 0x1a, 0xc5, 0x60, 0xcf, 0x38, 0x6c, 0x19, 0x9a, 0x1d, 0x63, 0xb0, 0x61, 0x5b, 0x61, 0x03,
		0x82, 0x3b, 0xb9, 0xc5, 0x1b, 0x8b, 0xc4, 0x35, 0x63, 0xa2, 0x6a, 0x07, 0x36, 0xcd, 0x83, 0x96,
		0xd9, 0x2b, 0x1a, 0x8e, 0x73, 0xdb, 0xf1, 0x9d, 0xc3, 0xb8, 0x36, 0xeb, 0xf7, 0xe6, 0xbc, 0xcf,
		0xcc, 0x95, 0x0c, 0xf9, 0xb7, 0x2d, 0xbf, 0xce, 0x93, 0x3f, 0x1b, 0x84, 0xa6, 0xcc, 0xa0, 0xc8,
		0x4c, 0x30, 0x66, 0x1f, 0x1a, 0x06, 0xc2, 0xc2, 0x99, 0xf8, 0x81, 0xeb, 0xb7, 0xdb, 0xa1, 0x88,
		0x22, 0x63, 0x81, 0x91, 0x3c, 0x66, 0x4f, 0x59, 0x60, 0x28, 0x19, 0x98, 0x2d, 0x81, 0x33, 0x5e,
		0xd2, 0x66, 0xa3, 0x44, 0xcd, 0x6e, 0xc9, 0x99, 0xad, 0x12, 0x32, 0xeb, 0x25, 0x61, 0xd6, 0x4b,
		0xbc, 0xac, 0x97, 0x6c, 0xad, 0x17, 0x4d, 0x31, 0x5e, 0x22, 0x95, 0xc4, 0x6d, 0x57, 0xf8, 0x9d,
		0x50, 0x74, 0x4c, 0x06, 0xed, 0xa4, 0x84, 0xa9, 0x62, 0xf0, 0x9a, 0xe7, 0x63, 0x26, 0xf6, 0xe1,
		0x43, 0x5c, 0x75, 0xe1, 0xa5, 0x30, 0x88, 0x0c, 0x62, 0x01, 0x16, 0xe7, 0x6b, 0x61, 0x9e, 0x36,
		0xc4, 0x97, 0x35, 0xcb, 0x15, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a, 0x38, 0x5c,
		0xe1, 0x58, 0x9a, 0x7d, 0x5e, 0x64, 0x6f, 0xc2, 0x88, 0x32, 0x71, 0xb4, 0x34, 0x81, 0xb4, 0x06,
		0x0e, 0x36, 0x41, 0x02, 0x03, 0x2c, 0x6c, 0x83, 0x06, 0x0c, 0x78, 0xc0, 0x80, 0x08, 0x0c, 0x98,
		0x98, 0x05, 0x15, 0xc3, 0xe0, 0x62, 0x6f, 0x42, 0x9a, 0x8a, 0x7b, 0xd9, 0xb3, 0x94, 0xe5, 0xa7,
		0xe8, 0xbf, 0x85, 0x0d, 0x80, 0x26, 0xf7, 0xde, 0xce, 0xb6, 0x3e, 0x16, 0x9f, 0xed, 0x3f, 0x8f,
		0xfc, 0x7d, 0xd1, 0xe2, 0xd8, 0xa7, 0x7c, 0xe0, 0xc0, 0xa2, 0x0d, 0xe7, 0xbe, 0xd6, 0x22, 0x54,
		0xd6, 0x77, 0x79, 0x72, 0xfe, 0xde, 0xde, 0xbe, 0xde, 0x75, 0x0f, 0x6f, 0x9e, 0xae, 0x0b, 0xee,
		0xe1, 0x4d, 0x7c, 0x58, 0x18, 0xfd, 0x88, 0x8f, 0xf7, 0xae, 0x77, 0xdd, 0xe2, 0xe4, 0xb8, 0x74,
		0xbd, 0xeb, 0x96, 0x6e, 0x76, 0xfe, 0xfa, 0xeb, 0xc3, 0xce, 0xaf, 0xfd, 0xc1, 0xe2, 0x5f, 0xfc,
		0x8f, 0xbd, 0x5a, 0xbc, 0x1b, 0x9b, 0x83, 0x5d, 0xbf, 0xac, 0xfd, 0x8f, 0x23, 0x6e, 0x7a, 0xc4,
		0x37, 0xa9, 0x90, 0x0b, 0x23, 0xbd, 0x97, 0x99, 0xde, 0x31, 0xd3, 0xbb, 0xef, 0x76, 0xaa, 0xee,
		0xa7, 0x9b, 0x5f, 0x85, 0xf7, 0xc5, 0xc1, 0xd1, 0xce, 0xaf, 0xca, 0xe0, 0xf5, 0xc9, 0xa7, 0x59,
		0x1f, 0x2b, 0xbc, 0xaf, 0x0c, 0x8e, 0xe6, 0xbc, 0x53, 0x1e, 0x1c, 0xfd, 0xe6, 0xef, 0x28, 0x0d,
		0xb6, 0x53, 0x1f, 0x1d, 0x9e, 0xdf, 0x9b, 0xf7, 0x85, 0xe2, 0x9c, 0x2f, 0xec, 0xcf, 0xfb, 0xc2,
		0xfe, 0x9c, 0x2f, 0xcc, 0x35, 0x69, 0x6f, 0xce, 0x17, 0x4a, 0x83, 0xa7, 0xd4, 0xe7, 0xb7, 0x67,
		0x7f, 0xb4, 0x3c, 0xd8, 0x79, 0x9a, 0xf7, 0x5e, 0x65, 0xf0, 0x74, 0xb4, 0x43, 0xb0, 0xa3, 0xff,
		0xd3, 0xff, 0x37, 0x0a, 0xfa, 0xdf, 0xad, 0xf7, 0xdf, 0xc9, 0x5a, 0xc5, 0x37, 0x2a, 0x5b, 0xac,
		0x55, 0x4c, 0xd5, 0x2a, 0x1a, 0x6c, 0x91, 0x60, 0xe0, 0xd9, 0xfc, 0xbb, 0x1c, 0xbb, 0xe9, 0x64,
		0xe5, 0x94, 0xe1, 0x67, 0x30, 0x66, 0xd7, 0x48, 0x99, 0x5f, 0x0b, 0x05, 0xb1, 0xe6, 0xc9, 0xec,
		0xda, 0xa6, 0xac, 0x1d, 0xd5, 0x70, 0x1e, 0x45, 0xce, 0x9f, 0x8e, 0x91, 0x6a, 0xa0, 0x95, 0xd5,
		0x74, 0x67, 0x9b, 0xe8, 0xb3, 0x4b, 0xbf, 0xd9, 0xfc, 0xe6, 0x8c, 0xe2, 0xc4, 0x54, 0x7c, 0x00,
		0xc6, 0x45, 0x36, 0xfe, 0xb5, 0xfa, 0xd1, 0x5f, 0xed, 0x6f, 0x5c, 0xb1, 0x1f, 0x65, 0xed, 0x3f,
		0x30, 0x7e, 0x93, 0x41, 0xf2, 0x5c, 0x41, 0xb2, 0x5c, 0xad, 0x0f, 0xaf, 0xce, 0xd3, 0x56, 0xe8,
		0x65, 0x19, 0x15, 0x98, 0x66, 0x5a, 0x48, 0x9a, 0x51, 0xc1, 0xe8, 0x73, 0xed, 0xcf, 0xde, 0x8a,
		0x7f, 0x71, 0x86, 0xb5, 0x3d, 0x66, 0x6a, 0x77, 0xb2, 0xae, 0xcd, 0x31, 0x56, 0x7b, 0x63, 0xac,
		0xb6, 0xc6, 0x58, 0xed, 0x0c, 0x36, 0x7e, 0x65, 0x55, 0x40, 0xe9, 0x4c, 0x50, 0xc4, 0x1d, 0xe7,
		0xf7, 0x8c, 0xfc, 0x72, 0x12, 0x5d, 0xd3, 0x97, 0xcb, 0xc8, 0x65, 0xb2, 0x2d, 0x79, 0xcc, 0xbc,
		0xb4, 0xd1, 0x44, 0x09, 0xa3, 0xd9, 0x52, 0x45, 0x53, 0x25, 0x89, 0xc6, 0x4b, 0x0f, 0x8d, 0x97,
		0x18, 0x1a, 0x2f, 0x25, 0xcc, 0xd7, 0x34, 0x31, 0xf3, 0x12, 0xc0, 0xe7, 0x8a, 0x80, 0xb6, 0x50,
		0x5a, 0xea, 0xc7, 0x6c, 0xd7, 0xa1, 0x25, 0x0c, 0x2d, 0x43, 0x41, 0xcd, 0xa9, 0x8d, 0xff, 0x94,
		0x8f, 0x7e, 0x64, 0x20, 0x44, 0x27, 0x37, 0xb0, 0xfa, 0xa9, 0xd6, 0xb8, 0x1c, 0xfe, 0xe7, 0xea,
		0xff, 0xce, 0x4f, 0xb2, 0x0e, 0xd3, 0xaf, 0x7e, 0xb7, 0x2f, 0x22, 0x23, 0x8f, 0x6c, 0x0d, 0x2f,
		0x30, 0x3b, 0xdd, 0xff, 0x7a, 0x7e, 0xd6, 0xa8, 0x9d, 0x7f, 0x2d, 0x36, 0xbe, 0x9c, 0xd5, 0xfe,
		0xa8, 0x5e, 0x5e, 0x39, 0xeb, 0xb0, 0x5e, 0xcf, 0xf4, 0x5d, 0xac, 0x9d, 0xfd, 0xf7, 0xf2, 0xaa,
		0x7a, 0x75, 0xc2, 0x9b, 0xb7, 0xf8, 0xcd, 0x1b, 0x39, 0xdf, 0x69, 0xf5, 0xe3, 0xc9, 0xe9, 0xc9,
		0x31, 0x9d, 0x70, 0x09, 0x27, 0xdc, 0x1b, 0x86, 0xf2, 0xd7, 0xf3, 0xd3, 0x4b, 0xde, 0xbd, 0x25,
		0x42, 0xb8, 0x71, 0x79, 0xfe, 0x89, 0x37, 0x70, 0x09, 0x24, 0x29, 0x33, 0x88, 0x97, 0x4a, 0x86,
		0x65, 0x26, 0xc3, 0x55, 0x25, 0xc3, 0x93, 0xaf, 0xe7, 0x67, 0xbc, 0x7b, 0x6f, 0xf4, 0x42, 0x7a,
		0xdf, 0x9b, 0xef, 0xdf, 0xe5, 0xc5, 0xd5, 0x49, 0xe3, 0xbc, 0x7e, 0x5a, 0xfb, 0xe3, 0xff, 0x46,
		0xdc, 0x9a, 0xf7, 0x70, 0xa9, 0x99, 0xc9, 0xe7, 0x2f, 0xa7, 0x57, 0xf4, 0xc5, 0x65, 0xe8, 0xf5,
		0xa7, 0xd3, 0xfa, 0xff, 0xbb, 0x3c, 0x3f, 0xf9, 0x83, 0x37, 0x70, 0x19, 0x66, 0x48, 0x34, 0x79,
		0xd3, 0x0d, 0xfc, 0x7a, 0x7e, 0x46, 0x17, 0x5c, 0x25, 0x9e, 0x94, 0x79, 0x0f, 0xdf, 0x98, 0x07,
		0xc9, 0x69, 0x56, 0x31, 0xbf, 0x33, 0x89, 0xc7, 0x99, 0x5e, 0xe1, 0x26, 0x6f, 0xcf, 0x3d, 0x58,
		0x76, 0xb5, 0xd2, 0xdf, 0x6f, 0xb3, 0xec, 0x2a, 0x83, 0x32, 0xff, 0x15, 0x56, 0x36, 0xbd, 0x03,
		0x72, 0x87, 0x64, 0x27, 0xc0, 0x0c, 0x1e, 0xfe, 0x67, 0x53, 0x6b, 0x9f, 0x5d, 0x4d, 0xbd, 0xd1,
		0xda, 0xf9, 0x6c, 0x6a, 0xe4, 0x57, 0xe5, 0x15, 0x19, 0x25, 0x07, 0x9b, 0x49, 0xc1, 0x59, 0x69,
		0x41, 0xe1, 0x5b, 0xca, 0x2e, 0x57, 0x93, 0x90, 0x96, 0x4f, 0x1f, 0xcb, 0xfd, 0x86, 0x25, 0x5d,
		0x6c, 0xd5, 0xae, 0x65, 0xc1, 0xa5, 0x96, 0x1b, 0xc7, 0xb7, 0xdf, 0xfd, 0x25, 0xee, 0x7c, 0xbc,
		0xd3, 0x6b, 0x24, 0xf4, 0xf2, 0xdd, 0xf6, 0x9e, 0xeb, 0xc5, 0x92, 0x5f, 0xb9, 0xa4, 0x47, 0xac,
		0xa6, 0xd4, 0x75, 0x65, 0xb5, 0x5f, 0xab, 0xac, 0xf1, 0xca, 0xa6, 0x96, 0x6b, 0xd5, 0x35, 0x5b,
		0x99, 0xd5, 0x66, 0x65, 0x56, 0x83, 0x95, 0x59, 0xad, 0x95, 0xdd, 0xdc, 0xb8, 0xaa, 0x52, 0xd2,
		0x24, 0x36, 0x57, 0xe7, 0x22, 0xaf, 0xa3, 0x7e, 0x55, 0x1e, 0xb2, 0xda, 0x3a, 0xf7, 0x95, 0x17,
		0x80, 0x66, 0x51, 0xf0, 0x99, 0x6d, 0x81, 0x67, 0x56, 0x05, 0x9d, 0x99, 0x17, 0x70, 0x66, 0x5e,
		0xb0, 0x99, 0x79, 0x81, 0x26, 0xd6, 0xcc, 0x6e, 0xd5, 0x75, 0xe9, 0x8e, 0x7f, 0x7b, 0x1b, 0x8a,
		0x5b, 0x5f, 0x07, 0x61, 0x76, 0x6b, 0x69, 0x5e, 0x5c, 0x23, 0x67, 0x0b, 0x6a, 0x76, 0xb9, 0xa0,
		0xc6, 0x4c, 0x22, 0x32, 0x96, 0x90, 0x8c, 0x25, 0x26, 0x63, 0x09, 0x2a, 0x1f, 0xca, 0x64, 0x66,
		0x0b, 0x6a, 0xb2, 0xdd, 0x68, 0xc2, 0xc8, 0xc6, 0x12, 0x19, 0x6f, 0x24, 0x91, 0xd9, 0xfa, 0x40,
		0x13, 0x69, 0xcd, 0x6c, 0x7a, 0x33, 0x95, 0xe6, 0x8c, 0xa7, 0x3b, 0xe3, 0x69, 0xcf, 0x78, 0xfa,
		0xcb, 0x26, 0x0d, 0x66, 0x94, 0x0e, 0x33, 0x4f, 0x8b, 0xcf, 0xfc, 0xce, 0xd0, 0x7e, 0x0c, 0xcf,
		0x64, 0xcf, 0x4c, 0xcb, 0x1f, 0x33, 0xdb, 0x2c, 0x18, 0xdb, 0x56, 0xc1, 0xe4, 0x36, 0x0a, 0x76,
		0xb6, 0x4d, 0x30, 0xbd, 0x4d, 0x82, 0xb5, 0x6d, 0x11, 0xac, 0x6d, 0x83, 0x60, 0x6d, 0xdb, 0x83,
		0x7c, 0xf7, 0x2c, 0x33, 0xb6, 0x8d, 0x81, 0xad, 0xe6, 0xf5, 0x26, 0xbb, 0x18, 0x1b, 0xef, 0x56,
		0xbc, 0x76, 0x2d, 0xc8, 0x6f, 0x4c, 0x0c, 0x92, 0x8d, 0xbe, 0xba, 0xeb, 0x37, 0x52, 0x79, 0xed,
		0x44, 0x96, 0xe1, 0xbc, 0xc9, 0x37, 0xc9, 0x34, 0x49, 0x32, 0x49, 0x32, 0x49, 0x32, 0x49, 0x32,
		0x49, 0x32, 0x67, 0x66, 0x47, 0x57, 0xf5, 0xef, 0x9a, 0x22, 0x34, 0xc8, 0x30, 0x0d, 0xec, 0xd6,
		0xec, 0x5c, 0xf8, 0xea, 0xd6, 0xdc, 0xd6, 0x57, 0x06, 0x5b, 0x6c, 0x7f, 0x96, 0xca, 0xc2, 0xc6,
		0xb3, 0x76, 0x76, 0xab, 0x1c, 0xf5, 0x07, 0xb1, 0x70, 0xdd, 0x4f, 0xa1, 0xdf, 0xd2, 0x32, 0x50,
		0xc7, 0xf2, 0x56, 0xc6, 0x95, 0xa6, 0xe6, 0xfa, 0xd0, 0x1b, 0xdc, 0xc6, 0xf8, 0xb3, 0xff, 0xb0,
		0x71, 0xae, 0x54, 0xdc, 0x3b, 0x2c, 0x1e, 0x96, 0x2b, 0x7b, 0x87, 0xa5, 0x0d, 0xf2, 0xa9, 0x35,
		0x69, 0x7a, 0xcf, 0x99, 0xd4, 0xac, 0x99, 0x54, 0xd1, 0xe4, 0x54, 0xaa, 0xc8, 0xb9, 0x14, 0xe7,
		0x52, 0x9c, 0x4b, 0x71, 0x2e, 0xc5, 0xb9, 0x14, 0xe7, 0x52, 0x9c, 0x4b, 0x71, 0x2e, 0xc5, 0xb9,
		0x14, 0xe7, 0x52, 0x9c, 0x4b, 0x71, 0x2e, 0x65, 0x6c, 0x2e, 0xc5, 0xfd, 0x71, 0x66, 0x5c, 0xc7,
		0xdc, 0x42, 0xc8, 0xc9, 0xc2, 0xbf, 0xe4, 0xc8, 0x7b, 0x2e, 0xdb, 0xcf, 0x72, 0x8b, 0x3d, 0xb6,
		0x68, 0x58, 0x47, 0x8f, 0x41, 0xd8, 0x17, 0x47, 0xeb, 0xf0, 0x52, 0xe8, 0x46, 0xf5, 0xd9, 0xa8,
		0x0d, 0xd8, 0x16, 0xc7, 0x8f, 0xdc, 0xf1, 0xd8, 0x67, 0xb5, 0x98, 0x67, 0x7c, 0x01, 0xae, 0xe4,
		0xe1, 0x4a, 0x1e, 0x08, 0x39, 0x87, 0x2b, 0x79, 0xcc, 0x02, 0x58, 0x76, 0x5b, 0xe3, 0x44, 0x6e,
		0x24, 0x6e, 0xc7, 0x37, 0x38, 0xeb, 0x7d, 0x71, 0x9e, 0xaf, 0x95, 0xf3, 0x35, 0x3d, 0xdc, 0x14,
		0x07, 0x24, 0xe1, 0x19, 0x4f, 0x7c, 0xc6, 0x13, 0xa0, 0xf1, 0x44, 0x98, 0xcf, 0xb9, 0x61, 0xe6,
		0x6b, 0x7a, 0xb2, 0x5d, 0xf2, 0x98, 0x8a, 0xce, 0x2c, 0x97, 0x3e, 0x1a, 0x4a, 0x97, 0xe9, 0xb4,
		0xb9, 0xc7, 0xc7, 0x83, 0xf9, 0x48, 0xa7, 0xd6, 0xd2, 0xaa, 0xb5, 0xf4, 0x6a, 0x2d, 0xcd, 0x66,
		0x2f, 0xf2, 0x6d, 0x19, 0x78, 0x3c, 0x98, 0x75, 0xfa, 0x4d, 0x2e, 0x74, 0x27, 0x46, 0x8f, 0x04,
		0x8f, 0x4c, 0x37, 0x96, 0x1d, 0x5f, 0xd7, 0x90, 0x13, 0x9a, 0x7d, 0x14, 0x61, 0xac, 0x7e, 0xc3,
		0x46, 0xa2, 0xb6, 0x9b, 0xb0, 0x6d, 0x25, 0x6e, 0xeb, 0x09, 0xdc, 0x7a, 0x22, 0xb7, 0x9e, 0xd0,
		0xcd, 0x24, 0x76, 0x43, 0x09, 0x3e, 0xb9, 0x9b, 0xc6, 0xea, 0x40, 0x66, 0xa9, 0x07, 0xc6, 0xea,
		0x41, 0x5e, 0x27, 0xe2, 0x8a, 0xc1, 0x4b, 0x9a, 0xad, 0x0f, 0x99, 0xbc, 0xcc, 0xa6, 0xa5, 0x2d,
		0x5b, 0xf5, 0x22, 0x96, 0x10, 0x36, 0x75, 0x79, 0x4b, 0xf5, 0x23, 0xc9, 0xf5, 0x2d, 0x3e, 0xf3,
		0x37, 0x9c, 0xb1, 0xa6, 0x5d, 0xce, 0x42, 0x5d, 0x09, 0x9a, 0xcb, 0xd9, 0xaa, 0x33, 0x81, 0xf2,
		0xbd, 0x77, 0xeb, 0x79, 0xb5, 0x9b, 0xb5, 0xe2, 0x1a, 0x99, 0x74, 0xbd, 0xff, 0x1d, 0x58, 0xca,
		0xa6, 0x2b, 0xfe, 0xef, 0x64, 0x27, 0x63, 0x5d, 0xf3, 0xff, 0xd5, 0x98, 0x4c, 0xba, 0xea, 0xdb,
		0x8f, 0x14, 0x03, 0xbe, 0xeb, 0x68, 0x93, 0x1c, 0x39, 0xe1, 0xc7, 0xa3, 0xab, 0x52, 0x9f, 0xa0,
		0x3e, 0x41, 0x7d, 0x82, 0xfa, 0x04, 0xf5, 0x09, 0x1b, 0xfa, 0x44, 0xcf, 0xd7, 0xdf, 0x26, 0x25,
		0x0e, 0xae, 0xc1, 0x7c, 0xfc, 0x32, 0x27, 0x17, 0x8a, 0x06, 0xaf, 0x79, 0xa2, 0xfa, 0x77, 0xc3,
		0xbb, 0xbd, 0x2e, 0x75, 0xdc, 0xf9, 0x7e, 0x08, 0x63, 0xa8, 0x3e, 0x3a, 0xb9, 0x9e, 0xd5, 0xaa,
		0xd7, 0x38, 0xda, 0xbc, 0xe7, 0x9a, 0xa2, 0x2c, 0xeb, 0xa5, 0xb3, 0xf7, 0x8f, 0x7c, 0x55, 0x5b,
		0x18, 0x99, 0x99, 0x99, 0x9b, 0x89, 0x59, 0x9d, 0x79, 0x99, 0x99, 0x69, 0x71, 0x4d, 0xc6, 0x2a,
		0x73, 0x4d, 0x96, 0x15, 0x73, 0x6f, 0xad, 0xb8, 0x8f, 0x2e, 0xc7, 0xb6, 0x71, 0xc5, 0x08, 0xbe,
		0x5f, 0x23, 0xf8, 0xf3, 0x66, 0xac, 0xcc, 0x28, 0x66, 0xbe, 0x34, 0xa3, 0xc8, 0xb5, 0x19, 0x5c,
		0x9b, 0x01, 0x24, 0x75, 0x70, 0x6d, 0x86, 0x59, 0xa8, 0xc8, 0x70, 0x6d, 0x46, 0xd1, 0xe4, 0xe2,
		0x8c, 0x22, 0x57, 0x67, 0x58, 0x4b, 0x71, 0x66, 0x53, 0x9d, 0xa9, 0x94, 0x67, 0x3c, 0xf5, 0x19,
		0x4f, 0x81, 0xc6, 0x53, 0x61, 0x3e, 0xf5, 0x02, 0xae, 0xce, 0x80, 0x4b, 0x97, 0xe9, 0xb4, 0xc9,
		0xd5, 0x19, 0x39, 0x49, 0xa7, 0xd6, 0xd2, 0xaa, 0xb5, 0xf4, 0x6a, 0x2d, 0xcd, 0x66, 0x9b, 0x6e,
		0x33, 0x4e, 0xbb, 0xc6, 0xd2, 0x6f, 0x72, 0x21, 0xae, 0xce, 0xc8, 0x21, 0xaf, 0xb5, 0x99, 0xa8,
		0xed, 0x26, 0x6c, 0x5b, 0x89, 0xdb, 0x7a, 0x02, 0xb7, 0x9e, 0xc8, 0xad, 0x27, 0x74, 0x33, 0x89,
		0xdd, 0x50, 0x82, 0x4f, 0xee, 0x26, 0x57, 0x67, 0x64, 0x7d, 0x49, 0xae, 0xce, 0x58, 0x3f, 0x84,
		0x4d, 0x5d, 0x9e, 0xab, 0x33, 0xb8, 0x3a, 0xc3, 0x92, 0xcb, 0x71, 0x75, 0x06, 0x57, 0x67, 0xe4,
		0x83, 0x6b, 0x70, 0x75, 0x06, 0x57, 0x67, 0xe4, 0xd0, 0x77, 0xb9, 0x3a, 0x83, 0xfa, 0x04, 0xf5,
		0x09, 0xea, 0x13, 0xd4, 0x27, 0x36, 0x4d, 0x9f, 0xe0, 0xea, 0x8c, 0xbc, 0xb3, 0x03, 0xae, 0xce,
		0x58, 0xe0, 0x7a, 0x76, 0x2b, 0x4c, 0x8b, 0x93, 0x92, 0xe9, 0x22, 0xd7, 0x67, 0x18, 0xf7, 0x39,
		0xae, 0xcf, 0xc8, 0xdd, 0x5c, 0x8b, 0xeb, 0x33, 0x56, 0x9b, 0x6d, 0x20, 0x57, 0x68, 0x14, 0xb9,
		0x44, 0x23, 0x3f, 0xae, 0x0d, 0xe1, 0xd2, 0x9b, 0xb0, 0x46, 0x43, 0xaa, 0xb6, 0x78, 0xc8, 0x6e,
		0x81, 0x46, 0xfc, 0xeb, 0xb3, 0x59, 0x9d, 0xb1, 0xcb, 0xd5, 0x19, 0x5c, 0x9d, 0x01, 0x2a, 0x69,
		0x70, 0x75, 0x46, 0xb6, 0x92, 0x43, 0xe2, 0xf7, 0x5d, 0xe1, 0x77, 0x42, 0xd1, 0xc9, 0xc2, 0xe9,
		0x27, 0xaa, 0x41, 0x06, 0x15, 0x0e, 0xce, 0xf9, 0x18, 0xd8, 0x3e, 0x7c, 0x88, 0x67, 0x66, 0x5e,
		0x9c, 0x28, 0x37, 0x00, 0x70, 0xb2, 0x29, 0x16, 0xcf, 0xb4, 0x38, 0x3c, 0xf3, 0xe5, 0x80, 0x7b,
		0x04, 0x1c, 0x02, 0x0e, 0x01, 0x67, 0x05, 0x77, 0x21, 0xbb, 0xe5, 0x80, 0xf2, 0xb6, 0x67, 0x60,
		0x1d, 0xa0, 0xcc, 0xec, 0xd1, 0x56, 0xc6, 0x0f, 0x26, 0xb9, 0x00, 0x10, 0x2e, 0xc9, 0x19, 0x4f,
		0x76, 0xc6, 0x93, 0x9e, 0xf1, 0xe4, 0x97, 0x9d, 0xda, 0xb3, 0x95, 0xa1, 0x0c, 0x99, 0xf9, 0x83,
		0xbf, 0x24, 0x6e, 0xfa, 0x52, 0xe9, 0x72, 0x31, 0xcb, 0x98, 0x19, 0x67, 0xb1, 0x83, 0x0c, 0x2f,
		0x61, 0xa6, 0xca, 0xd8, 0xc0, 0x43, 0x28, 0x93, 0x55, 0xc4, 0xa6, 0xeb, 0x5e, 0x0c, 0x57, 0x09,
		0xdb, 0xa8, 0xcc, 0x34, 0x51, 0x8f, 0x65, 0xb2, 0xea, 0xd7, 0x96, 0x8b, 0xd8, 0xab, 0x16, 0xb4,
		0xe2, 0x35, 0x39, 0x7d, 0xc6, 0x7b, 0x93, 0x97, 0xc7, 0x32, 0x19, 0xcc, 0x76, 0x7d, 0x1d, 0xdc,
		0xc9, 0x96, 0x3b, 0xd9, 0x4c, 0x5c, 0x18, 0x98, 0x68, 0xbc, 0xbe, 0x22, 0x27, 0x1d, 0x9c, 0x74,
		0x70, 0xd2, 0xc1, 0x49, 0x47, 0x0e, 0x27, 0x1d, 0xcd, 0x20, 0xe8, 0x0a, 0x5f, 0x19, 0x98, 0x75,
		0x14, 0x0a, 0x1b, 0x0c, 0x52, 0xad, 0x6e, 0x3f, 0xd2, 0x22, 0x74, 0xbb, 0x32, 0x32, 0xd0, 0x11,
		0x6b, 0xea, 0x6a, 0x04, 0x27, 0x82, 0x13, 0xc1, 0x89, 0xe0, 0x94, 0x43, 0x70, 0x92, 0xbd, 0xfb,
		0xa2, 0xeb, 0xb7, 0xdb, 0xa1, 0x88, 0x22, 0x13, 0x08, 0x95, 0xa5, 0x30, 0x76, 0xee, 0x6b, 0x2d,
		0x42, 0x95, 0xb9, 0x34, 0xe6, 0xfc, 0xbd, 0xbd, 0x7d, 0xbd, 0xeb, 0x1e, 0xde, 0x3c, 0x5d, 0x17,
		0xdc, 0xc3, 0x9b, 0xf8, 0xb0, 0x30, 0xfa, 0x11, 0x1f, 0xef, 0x5d, 0xef, 0xba, 0xc5, 0xc9, 0x71,
		0xe9, 0x7a, 0xd7, 0x2d, 0xdd, 0xec, 0xfc, 0xf5, 0xd7, 0x87, 0x9d, 0x5f, 0xfb, 0x83, 0xc5, 0xbf,
		0xf8, 0x9f, 0xec, 0x82, 0xe2, 0x26, 0xcb, 0xc1, 0xa8, 0x5f, 0xd6, 0xfe, 0xc7, 0x11, 0xc1, 0x50,
		0x19, 0x58, 0x49, 0xfe, 0x7b, 0x57, 0x5a, 0xff, 0x4a, 0xf2, 0x5c, 0x50, 0xf9, 0x6c, 0x8a, 0x3e,
		0xd3, 0xd8, 0x97, 0x41, 0xf1, 0x27, 0xc9, 0x3b, 0xc9, 0x3b, 0xc9, 0x3b, 0xc9, 0x3b, 0x1f, 0x67,
		0xff, 0xee, 0x25, 0xf8, 0x38, 0x1b, 0x0f, 0x5e, 0x52, 0x97, 0xe3, 0xe3, 0xec, 0x55, 0x11, 0x4c,
		0x3e, 0xce, 0x5e, 0x2f, 0xaf, 0xe1, 0xe3, 0xec, 0xdc, 0x4d, 0x2f, 0xba, 0x41, 0xcb, 0xef, 0xba,
		0x43, 0x6e, 0x96, 0xfd, 0x1c, 0xe3, 0xc5, 0xb5, 0x38, 0xd1, 0xe0, 0x44, 0x83, 0x13, 0x0d, 0x4e,
		0x34, 0x72, 0x3a, 0xd1, 0xd8, 0xdf, 0x33, 0x30, 0xd1, 0xa8, 0x70, 0xa2, 0xc1, 0x89, 0x06, 0x27,
		0x1a, 0x9c, 0x68, 0xfc, 0x86, 0x8b, 0x98, 0xee, 0x86, 0xcb, 0xe9, 0x05, 0xa7, 0x17, 0xbf, 0xe3,
		0x26, 0x77, 0xa2, 0x9d, 0xfd, 0xbc, 0x62, 0x78, 0x11, 0x4e, 0x28, 0x38, 0xa1, 0xe0, 0x84, 0x82,
		0x13, 0x0a, 0x4e, 0x28, 0x38, 0xa1, 0xe0, 0x84, 0x82, 0x13, 0x0a, 0x4e, 0x28, 0x38, 0xa1, 0xe0,
		0x84, 0x62, 0xfd, 0x26, 0x14, 0x4a, 0x3c, 0x68, 0xf7, 0x5b, 0x60, 0xa0, 0xbf, 0x47, 0x72, 0x25,
		0x4e, 0x2d, 0x38, 0xb5, 0xe0, 0xd4, 0x82, 0x53, 0x8b, 0x1c, 0x4e, 0x2d, 0x64, 0xcf, 0xe4, 0x7a,
		0x86, 0xc3, 0x0c, 0xaf, 0x31, 0xbe, 0x67, 0xb9, 0x9f, 0x5e, 0x18, 0x5e, 0x6b, 0x92, 0x1a, 0xa3,
		0x03, 0x03, 0xd7, 0x32, 0xb5, 0xd2, 0x21, 0xb9, 0xe0, 0xba, 0xac, 0x78, 0x48, 0x08, 0x9e, 0x89,
		0x41, 0x32, 0xb9, 0x26, 0x65, 0x7d, 0x47, 0x2a, 0xcf, 0x3b, 0x6d, 0x98, 0x4d, 0x77, 0x65, 0xa6,
		0xbb, 0xd5, 0x06, 0x91, 0xef, 0x76, 0xaa, 0xee, 0xa7, 0x9b, 0x5f, 0x85, 0xf7, 0xc5, 0xc1, 0xd1,
		0xce, 0xaf, 0xca, 0xe0, 0xf5, 0xc9, 0xa7, 0x59, 0x1f, 0x2b, 0xbc, 0xaf, 0x0c, 0x8e, 0xe6, 0xbc,
		0x53, 0x1e, 0x1c, 0xfd, 0xe6, 0xef, 0x28, 0x0d, 0xb6, 0x53, 0x1f, 0x1d, 0x9e, 0xdf, 0x9b, 0xf7,
		0x85, 0xe2, 0x9c, 0x2f, 0xec, 0xcf, 0xfb, 0xc2, 0xfe, 0x9c, 0x2f, 0xcc, 0x35, 0x69, 0x6f, 0xce,
		0x17, 0x4a, 0x83, 0xa7, 0xd4, 0xe7, 0xb7, 0x67, 0x7f, 0xb4, 0x3c, 0xd8, 0x79, 0x9a, 0xf7, 0x5e,
		0x65, 0xf0, 0x74, 0xb4, 0xc3, 0xe4, 0x4f, 0xbf, 0xa5, 0xdf, 0x5a, 0x81, 0x42, 0xaa, 0x69, 0x19,
		0xa8, 0x69, 0x41, 0x28, 0x6f, 0x33, 0x7c, 0xde, 0xf1, 0xac, 0xdf, 0xc4, 0xd7, 0xa1, 0x92, 0x46,
		0x25, 0x8d, 0x4a, 0x1a, 0x95, 0xb4, 0x1c, 0x2a, 0x69, 0xcd, 0xdb, 0x9e, 0x1b, 0x67, 0x31, 0x77,
		0xb4, 0xf7, 0x50, 0xc6, 0xdb, 0x62, 0x9a, 0xd8, 0x06, 0x33, 0xe3, 0x6d, 0x2f, 0xf3, 0x84, 0x80,
		0xbe, 0x0e, 0x42, 0x57, 0xb6, 0x4d, 0x01, 0xe1, 0xe4, 0x72, 0xc4, 0x43, 0xe2, 0x21, 0xf1, 0x90,
		0x78, 0x98, 0x43, 0x3c, 0x64, 0xaf, 0xac, 0xb7, 0x0b, 0x20, 0xec, 0x95, 0x85, 0x22, 0x4d, 0xb1,
		0x57, 0x96, 0x69, 0x0a, 0xc7, 0x8d, 0x52, 0x2d, 0x6d, 0x94, 0x9a, 0xc1, 0xa6, 0xe2, 0x98, 0x9b,
		0xd6, 0xe9, 0xbe, 0x52, 0xa2, 0xeb, 0x0a, 0xd5, 0xf2, 0x7b, 0x51, 0xbf, 0x9b, 0xcd, 0x70, 0x26,
		0x38, 0x38, 0xf3, 0x6a, 0xdc, 0xd2, 0x8e, 0x5b, 0xda, 0x41, 0xf0, 0x74, 0x6e, 0x69, 0x67, 0x16,
		0x40, 0x32, 0xdb, 0xd2, 0x2e, 0x4e, 0x33, 0x51, 0xf6, 0x02, 0xc5, 0xe4, 0x42, 0xd9, 0x4a, 0x13,
		0x05, 0x4a, 0x13, 0x94, 0x26, 0x28, 0x4d, 0x6c, 0x92, 0x34, 0x91, 0x55, 0x6a, 0x7c, 0x95, 0x22,
		0xb3, 0x77, 0xe4, 0xe9, 0x4c, 0x99, 0xb5, 0x17, 0x67, 0x9b, 0x30, 0x8d, 0x25, 0x4e, 0x93, 0x09,
		0xd4, 0x4e, 0x22, 0x35, 0x9d, 0x50, 0xad, 0x25, 0x56, 0x6b, 0x09, 0xd6, 0x5a, 0xa2, 0xcd, 0x36,
		0xe1, 0x66, 0x9c, 0x78, 0x8d, 0x25, 0xe0, 0x67, 0x95, 0x43, 0x67, 0xb9, 0x2d, 0xda, 0xdc, 0x28,
		0xcf, 0x62, 0x37, 0x79, 0xcb, 0x69, 0x39, 0xf3, 0xa9, 0x3a, 0x42, 0x9a, 0xb6, 0x9b, 0xae, 0x6d,
		0xa5, 0x6d, 0xeb, 0xe9, 0xdb, 0x7a, 0x1a, 0xb7, 0x9e, 0xce, 0xcd, 0xa4, 0x75, 0x43, 0xe9, 0xdd,
		0x78, 0x9a, 0x7f, 0xe6, 0xdd, 0x59, 0x3f, 0x73, 0xfc, 0x67, 0x16, 0x9e, 0x6d, 0x1d, 0xce, 0x3f,
		0x25, 0xff, 0x5d, 0xc3, 0x97, 0x35, 0xc5, 0xd1, 0x11, 0xc0, 0x00, 0x03, 0x14, 0x6c, 0x83, 0x03,
		0x0c, 0x48, 0xc0, 0x80, 0x05, 0x0c, 0x68, 0x98, 0x05, 0x0f, 0xc3, 0x20, 0x92, 0xdc, 0xe5, 0x2b,
		0x1b, 0xb9, 0x7d, 0x2a, 0xee, 0x65, 0x5b, 0x28, 0x2d, 0xf5, 0x63, 0x76, 0x4d, 0xa3, 0x7f, 0x8b,
		0xe7, 0x97, 0x2c, 0x5c, 0xbb, 0x36, 0xfe, 0xd3, 0x3f, 0xfa, 0x91, 0xc5, 0xd4, 0x33, 0x19, 0x88,
		0xab, 0x2f, 0x67, 0x67, 0x27, 0xa7, 0x8d, 0x93, 0xb3, 0x3f, 0xaa, 0xe7, 0x97, 0x5f, 0x4e, 0xab,
		0x57, 0xb5, 0xfa, 0x59, 0xe3, 0xea, 0xff, 0xce, 0x4f, 0x6c, 0xa5, 0xa2, 0x51, 0xa7, 0x9a, 0xc8,
		0xd8, 0xea, 0xa5, 0x59, 0xaf, 0x5f, 0xd6, 0xae, 0x3c, 0x35, 0x34, 0x97, 0x17, 0x57, 0x27, 0x8d,
		0xf3, 0xfa, 0x69, 0xed, 0x8f, 0xff, 0x6b, 0xc4, 0xc3, 0xe4, 0x58, 0x33, 0x6c, 0x60, 0xe5, 0xca,
		0x37, 0xeb, 0x9e, 0xf7, 0x39, 0x19, 0x7a, 0x1b, 0x4b, 0xc8, 0xb6, 0xa0, 0x67, 0xee, 0x75, 0x6d,
		0x16, 0xfa, 0xcc, 0xaa, 0x48, 0x19, 0x9f, 0x8c, 0xc6, 0x3f, 0xb3, 0x28, 0x06, 0xb2, 0xe7, 0x50,
		0x26, 0x5a, 0xbe, 0x45, 0xfd, 0xa6, 0xee, 0xde, 0x47, 0x16, 0x54, 0xcd, 0xf1, 0x85, 0xd7, 0x5c,
		0xd7, 0xdc, 0xa5, 0xae, 0xb9, 0x5e, 0x53, 0x57, 0xea, 0x9a, 0xd4, 0x35, 0x57, 0x7a, 0x37, 0x8d,
		0xeb, 0x9a, 0x71, 0xe6, 0xb5, 0xa7, 0x6c, 0x8e, 0xaf, 0x6f, 0x47, 0xdb, 0x2c, 0x50, 0xdb, 0x5c,
		0x73, 0x60, 0xb0, 0x0d, 0x10, 0x30, 0x40, 0x01, 0x03, 0x18, 0x30, 0xc0, 0x61, 0x69, 0x8e, 0x6b,
		0x38, 0xf2, 0x4d, 0x03, 0x4a, 0x72, 0xe1, 0x50, 0xdc, 0x05, 0x5a, 0xb8, 0x42, 0xb5, 0x7b, 0x81,
		0x8c, 0xb7, 0x57, 0xb7, 0xac, 0xed, 0xa5, 0x2c, 0xb2, 0xe4, 0xf8, 0x76, 0xc0, 0xc7, 0x3a, 0x08,
		0x21, 0x80, 0x11, 0x16, 0x28, 0xa1, 0x80, 0x13, 0x1c, 0x48, 0xc1, 0x81, 0x15, 0x1c, 0x68, 0xd9,
		0x01, 0x2f, 0x4b, 0x20, 0x66, 0x1d, 0xcc, 0xe6, 0x81, 0x9a, 0xfd, 0x88, 0x9d, 0x83, 0x6d, 0xb6,
		0xe3, 0xd6, 0x2e, 0xc4, 0xc1, 0x40, 0x1d, 0x12, 0xe4, 0x61, 0x42, 0x1f, 0x1a, 0x04, 0xc2, 0x42,
		0x21, 0x2c, 0x24, 0xc2, 0x42, 0xa3, 0x5d, 0x88, 0xb4, 0x0c, 0x95, 0x30, 0x90, 0x99, 0x18, 0x02,
		0x83, 0x99, 0xa9, 0x44, 0x08, 0x02, 0x9a, 0xaf, 0xc1, 0x73, 0x17, 0xc4, 0x1c, 0x14, 0x10, 0x45,
		0x04, 0x53, 0x6c, 0x50, 0x45, 0x05, 0x57, 0x78, 0x90, 0x85, 0x07, 0x5b, 0x78, 0xd0, 0xc5, 0x00,
		0x5f, 0x10, 0x10, 0x4e, 0x46, 0xcb, 0x5a, 0xa1, 0xe9, 0xbf, 0xe6, 0xad, 0xae, 0xf0, 0x3b, 0x76,
		0x8a, 0x4f, 0xff, 0x75, 0x0e, 0x59, 0x01, 0xb2, 0xe9, 0x7c, 0x5c, 0xeb, 0xf4, 0xe1, 0x43, 0x5c,
		0x5c, 0xe4, 0x25, 0xdc, 0xe1, 0x1d, 0xa3, 0x0d, 0x24, 0xd2, 0x0c, 0xaf, 0xcc, 0xfc, 0xed, 0x10,
		0x33, 0xb9, 0x72, 0x33, 0x27, 0x02, 0x4d, 0x9a, 0x63, 0xee, 0x91, 0x63, 0x92, 0x63, 0x92, 0x63,
		0x92, 0x63, 0x92, 0x63, 0xe6, 0x5c, 0xf0, 0x49, 0x0c, 0xf2, 0x23, 0xbc, 0xa4, 0x30, 0x49, 0xa5,
		0x7e, 0x84, 0x96, 0x0d, 0xb0, 0xc4, 0x9f, 0x34, 0x40, 0xa3, 0x19, 0x06, 0x08, 0xd4, 0xf9, 0x00,
		0x6c, 0x74, 0xe0, 0xce, 0x0d, 0x80, 0xe7, 0x06, 0xc8, 0x73, 0x03, 0xe8, 0x58, 0xc0, 0x0e, 0x06,
		0xf0, 0xc9, 0x28, 0xc2, 0x89, 0x49, 0x33, 0xd0, 0xd5, 0x55, 0xfd, 0xbb, 0xa6, 0x08, 0x11, 0xd3,
		0xde, 0x18, 0x68, 0x2b, 0x80, 0xa6, 0x5d, 0xf8, 0xea, 0x56, 0x58, 0x5d, 0xf2, 0xfb, 0x4f, 0x2f,
		0x4c, 0x98, 0x18, 0xdd, 0xb8, 0xcf, 0x52, 0xc1, 0xe2, 0x18, 0x38, 0xc3, 0x4b, 0x99, 0x39, 0x5a,
		0x78, 0x9e, 0x03, 0x3b, 0x3f, 0x85, 0x7e, 0x4b, 0xcb, 0x40, 0x1d, 0xcb, 0x5b, 0x39, 0xaa, 0x32,
		0xde, 0x85, 0xb5, 0x77, 0xf0, 0x1e, 0x38, 0x74, 0xfc, 0x07, 0x86, 0xce, 0x8a, 0x43, 0xa7, 0xb8,
		0x77, 0x58, 0x3c, 0x2c, 0x57, 0xf6, 0x0e, 0x4b, 0x8c, 0xa1, 0xf5, 0xe4, 0x84, 0xb8, 0x56, 0xdd,
		0xbc, 0xe3, 0xfd, 0x01, 0xcf, 0xc1, 0x78, 0x25, 0x51, 0x29, 0x06, 0x0f, 0x56, 0x1a, 0x05, 0x0e,
		0x04, 0x54, 0xc9, 0x96, 0xf1, 0x35, 0xaa, 0x64, 0x4b, 0x45, 0x04, 0x55, 0xb2, 0x15, 0x1b, 0x4a,
		0x95, 0x6c, 0x0d, 0xe6, 0x38, 0x39, 0x50, 0xc9, 0x64, 0xcf, 0xc0, 0x0e, 0x93, 0xcb, 0x22, 0x6d,
		0xe1, 0x10, 0xd0, 0xb6, 0xf1, 0xd8, 0x52, 0x26, 0x7b, 0xb3, 0xe7, 0x19, 0xd9, 0xdd, 0x74, 0x65,
		0x3e, 0x78, 0x00, 0x6c, 0xa3, 0xa9, 0xbd, 0x3c, 0x97, 0x36, 0x74, 0x5d, 0xf6, 0x02, 0x5d, 0x7a,
		0x82, 0x8c, 0xec, 0x4c, 0x26, 0x77, 0x87, 0xa5, 0x47, 0xad, 0xa5, 0xe4, 0x02, 0x4a, 0xc8, 0xf2,
		0x05, 0x8f, 0x65, 0xc2, 0xe3, 0x66, 0xc2, 0xa3, 0xef, 0x76, 0xaa, 0xee, 0xa7, 0x9b, 0x5f, 0x85,
		0xf7, 0xc5, 0xc1, 0xd1, 0xce, 0xaf, 0xca, 0xe0, 0xf5, 0xc9, 0xa7, 0x59, 0x1f, 0x2b, 0xbc, 0xaf,
		0x0c, 0x8e, 0xe6, 0xbc, 0x53, 0x1e, 0x1c, 0xfd, 0xe6, 0xef, 0x28, 0x0d, 0xb6, 0x53, 0x1f, 0x1d,
		0x9e, 0xdf, 0x9b, 0xf7, 0x85, 0xe2, 0x9c, 0x2f, 0xec, 0xcf, 0xfb, 0xc2, 0xfe, 0x9c, 0x2f, 0xcc,
		0x35, 0x69, 0x6f, 0xce, 0x17, 0x4a, 0x83, 0xa7, 0xd4, 0xe7, 0xb7, 0x67, 0x7f, 0xb4, 0x3c, 0xd8,
		0x79, 0x9a, 0xf7, 0x5e, 0x65, 0xf0, 0x74, 0xb4, 0x43, 0xb2, 0xb0, 0x41, 0x64, 0x81, 0xf1, 0xc5,
		0xf8, 0xc2, 0xa7, 0x4e, 0x7c, 0xaa, 0x97, 0x93, 0xfb, 0xc3, 0x25, 0x00, 0x2f, 0x73, 0xac, 0xa5,
		0x7e, 0xf0, 0xff, 0x6a, 0x17, 0x7c, 0xbf, 0xf8, 0xb8, 0x0b, 0xf9, 0xf8, 0xa7, 0xf7, 0xba, 0x5f,
		0xe0, 0xeb, 0x13, 0x26, 0xfb, 0xcb, 0xe3, 0x07, 0xc0, 0x66, 0xb7, 0x59, 0xf9, 0xaf, 0x78, 0x04,
		0x7a, 0x5e, 0xee, 0x9c, 0xca, 0x48, 0x57, 0xb5, 0x06, 0x69, 0xfd, 0xf2, 0x59, 0xaa, 0x93, 0xae,
		0xb8, 0x13, 0x71, 0x17, 0x50, 0x80, 0x67, 0xe3, 0xce, 0x67, 0xff, 0xe1, 0x85, 0x45, 0x85, 0x83,
		0x62, 0xb1, 0x5c, 0x29, 0x16, 0x77, 0x2b, 0xfb, 0x95, 0xdd, 0xc3, 0x52, 0xa9, 0x50, 0x2e, 0x00,
		0x54, 0x6c, 0x39, 0xf5, 0xb0, 0x2d, 0x42, 0xd1, 0xfe, 0x38, 0xf4, 0x2c, 0xd5, 0xef, 0x76, 0x37,
		0x3a, 0xc0, 0xc0, 0x30, 0x6d, 0xdd, 0xb0, 0xcc, 0x81, 0x58, 0xb7, 0x1f, 0xf6, 0x5b, 0x5a, 0x8d,
		0xd5, 0xb7, 0xb3, 0xf8, 0x1e, 0xd5, 0xc6, 0xb7, 0xa8, 0x71, 0x3e, 0xbe, 0x31, 0x8d, 0x8f, 0xb7,
		0xbd, 0xc6, 0x85, 0x6c, 0x36, 0x86, 0xf9, 0xed, 0x52, 0xe8, 0xc6, 0xd5, 0xe8, 0x0f, 0x3e, 0x79,
		0x79, 0x33, 0xc6, 0xe7, 0x1a, 0x97, 0xa3, 0x3f, 0xbe, 0x71, 0x31, 0xfa, 0x5b, 0x4f, 0x20, 0x5a,
		0x35, 0x0c, 0xd8, 0x2a, 0x74, 0x93, 0xf2, 0x45, 0xde, 0xf3, 0x84, 0x9d, 0x60, 0x31, 0xef, 0xaa,
		0x16, 0xdc, 0xd4, 0x89, 0xc4, 0xed, 0x90, 0x81, 0xb8, 0x5d, 0x19, 0x21, 0xb4, 0x47, 0x9f, 0x36,
		0x87, 0xbd, 0xd1, 0xad, 0x18, 0xc0, 0xde, 0xe8, 0xaf, 0xad, 0x61, 0x6f, 0xf4, 0x39, 0x06, 0xb1,
		0x37, 0x3a, 0x09, 0xcf, 0x8b, 0xbb, 0x6f, 0xbd, 0x37, 0xfa, 0x4b, 0xfc, 0xc0, 0x69, 0x8c, 0x3e,
		0x65, 0x15, 0xbb, 0xa2, 0xb3, 0x2b, 0x7a, 0x1e, 0x40, 0x0f, 0x0d, 0xfc, 0x60, 0x41, 0x10, 0x16,
		0x0c, 0x61, 0x41, 0xd1, 0xbe, 0x0e, 0xb1, 0xc5, 0xae, 0xe8, 0xcf, 0x86, 0x4c, 0x66, 0xf6, 0xae,
		0x6c, 0xe3, 0x75, 0xac, 0x7c, 0x69, 0x1c, 0x7b, 0xa3, 0x23, 0x43, 0x29, 0x22, 0xa4, 0x62, 0x43,
		0x2b, 0x2a, 0xc4, 0xc2, 0x43, 0x2d, 0x3c, 0xe4, 0xc2, 0x43, 0x2f, 0x06, 0x04, 0x83, 0x40, 0x71,
		0x32, 0x5a, 0xec, 0x8d, 0xfe, 0x86, 0x99, 0x24, 0x74, 0x6f, 0xf4, 0x97, 0xf4, 0x81, 0x45, 0x32,
		0x28, 0xc1, 0x36, 0x51, 0x44, 0x22, 0xc0, 0x0e, 0xe9, 0x13, 0xcb, 0xd8, 0x24, 0x9d, 0x64, 0x93,
		0x64, 0x93, 0x64, 0x93, 0x64, 0x93, 0x64, 0x73, 0xad, 0xf5, 0x9f, 0xd7, 0xa0, 0x8c, 0xdb, 0x09,
		0x6a, 0x62, 0x20, 0x66, 0x23, 0xa8, 0x02, 0x1b, 0x41, 0xe5, 0x16, 0xb2, 0xf3, 0x01, 0xdd, 0xe8,
		0x10, 0x9e, 0x1b, 0x28, 0xcf, 0x0d, 0xa4, 0xe7, 0x06, 0xda, 0xb1, 0x20, 0x1e, 0x0c, 0xea, 0x61,
		0x21, 0x3f, 0x31, 0x4c, 0xfe, 0x7f, 0xf6, 0xfe, 0xbf, 0xa9, 0x8d, 0x24, 0x69, 0xf7, 0x87, 0xff,
		0xf7, 0xab, 0x20, 0x14, 0xbb, 0x11, 0xb0, 0xeb, 0x06, 0x49, 0x48, 0x60, 0x1c, 0x71, 0x62, 0x02,
		0x8f, 0xf1, 0x1c, 0x9e, 0xc5, 0x36, 0x8f, 0xed, 0x99, 0x7b, 0x37, 0x6c, 0x96, 0x68, 0xa4, 0x12,
		0xee, 0x9d, 0xa6, 0xa5, 0xbb, 0xbb, 0xe5, 0x35, 0xc7, 0xe6, 0xbd, 0x7f, 0x43, 0x3f, 0x91, 0x10,
		0xd8, 0x80, 0x2a, 0xb3, 0xaa, 0x5b, 0x1f, 0x62, 0x63, 0x16, 0x63, 0xd3, 0x55, 0xaa, 0xce, 0xba,
		0x32, 0xaf, 0xab, 0xb2, 0x32, 0x93, 0xb6, 0xf1, 0xb7, 0xf6, 0xee, 0xcc, 0x61, 0xd0, 0x60, 0x9a,
		0x9e, 0x6e, 0x51, 0xbf, 0x0b, 0x03, 0x7b, 0x1b, 0x0e, 0x14, 0x21, 0x2c, 0x28, 0x56, 0x78, 0x50,
		0x94, 0x30, 0xa1, 0x70, 0xe1, 0x42, 0xe1, 0xc2, 0x86, 0xc2, 0x85, 0x0f, 0x7e, 0x86, 0x11, 0x9e,
		0x86, 0x13, 0xd3, 0xb7, 0xeb, 0x6d, 0x7d, 0xc9, 0x05, 0xdc, 0xf4, 0xef, 0x18, 0xeb, 0x4e, 0x36,
		0xbf, 0xeb, 0x77, 0x25, 0xa3, 0x9b, 0xc7, 0x5c, 0x83, 0xc0, 0x88, 0x02, 0x16, 0x45, 0xdd, 0xc6,
		0x9e, 0xf5, 0x0b, 0xbe, 0x73, 0xff, 0xfa, 0xd4, 0x3f, 0xf8, 0xce, 0x9d, 0xeb, 0x7b, 0x00, 0x5e,
		0x27, 0x00, 0x27, 0x00, 0x27, 0x00, 0x27, 0x00, 0x27, 0x00, 0x2f, 0x49, 0x00, 0xee, 0xab, 0xae,
		0x37, 0x9d, 0xa0, 0xdf, 0xfa, 0xde, 0x02, 0xba, 0xfb, 0xac, 0xf3, 0xdd, 0x0c, 0x37, 0x7c, 0x6f,
		0x04, 0xe6, 0xbb, 0xee, 0x57, 0xa4, 0xf0, 0xa3, 0x98, 0x61, 0x48, 0xd1, 0xc2, 0x91, 0xc2, 0x86,
		0x25, 0x85, 0x0d, 0x4f, 0x0a, 0x1b, 0xa6, 0xf8, 0x1d, 0xae, 0x78, 0x1e, 0xb6, 0x4c, 0xdf, 0xba,
		0xf7, 0xfa, 0xe1, 0x02, 0xee, 0xf6, 0xa3, 0x24, 0xdf, 0x69, 0x14, 0x01, 0x73, 0xc7, 0x51, 0xc2,
		0xb3, 0x02, 0x4c, 0xd5, 0xef, 0x96, 0xcf, 0x37, 0xbf, 0x8a, 0xe1, 0xc3, 0xd6, 0x8a, 0xd2, 0x12,
		0xba, 0xa0, 0xe1, 0xed, 0xc2, 0xb4, 0x0b, 0xd2, 0x32, 0x7a, 0x61, 0xde, 0x05, 0x6a, 0x7f, 0x5b,
		0x30, 0xf7, 0x36, 0xbf, 0x15, 0xc3, 0xaf, 0x6c, 0x45, 0xe5, 0xad, 0xe8, 0x67, 0x69, 0xd3, 0x95,
		0xd9, 0x9d, 0x4f, 0x98, 0xa5, 0x8d, 0xaf, 0x93, 0x27, 0xac, 0x5f, 0xc9, 0xbc, 0x43, 0x25, 0xee,
		0xb6, 0xc2, 0x38, 0x88, 0x92, 0xdc, 0xa4, 0x9d, 0xd0, 0xaf, 0x02, 0x18, 0x3f, 0xa5, 0x40, 0xb7,
		0xcc, 0x1d, 0xc1, 0xd4, 0xc6, 0x34, 0x11, 0x4c, 0x05, 0xad, 0x16, 0xc1, 0x54, 0x74, 0x87, 0x21,
		0x98, 0x2a, 0x4f, 0x1c, 0xc1, 0x74, 0x05, 0x19, 0x65, 0x41, 0x05, 0xd3, 0xed, 0x7a, 0x81, 0x04,
		0xd3, 0x5d, 0x04, 0x53, 0xcb, 0x5f, 0x08, 0xa6, 0x84, 0xb7, 0xb7, 0x4c, 0x1b, 0xc1, 0x14, 0xf7,
		0xf6, 0xa3, 0xad, 0x88, 0x60, 0xaa, 0xbe, 0x15, 0x1b, 0xf5, 0xbd, 0xc6, 0xde, 0xce, 0x6e, 0x7d,
		0x0f, 0x99, 0x94, 0x80, 0xb8, 0x60, 0xb3, 0x44, 0x26, 0x2d, 0x9d, 0x4f, 0x98, 0x48, 0x8d, 0xbd,
		0x2f, 0x8d, 0x69, 0x2b, 0xfa, 0xa2, 0xc9, 0xa4, 0xb3, 0x73, 0x47, 0x26, 0xb5, 0x31, 0x4d, 0x64,
		0x52, 0x41, 0xab, 0x45, 0x26, 0x15, 0xdd, 0x61, 0xc8, 0xa4, 0xca, 0x13, 0x47, 0x26, 0x5d, 0x41,
		0x1e, 0x59, 0x40, 0x99, 0xb4, 0x40, 0x71, 0xc2, 0x6c, 0xac, 0x50, 0x2b, 0x42, 0x7a, 0xe9, 0x71,
		0x98, 0xe7, 0x26, 0x4d, 0x0a, 0xa3, 0x97, 0x56, 0xfe, 0xbd, 0xbe, 0xfe, 0xb1, 0x1a, 0xec, 0x9d,
		0x7c, 0xff, 0x58, 0x0b, 0xf6, 0x4e, 0x46, 0xdf, 0xd6, 0x86, 0xff, 0x37, 0xfa, 0xbe, 0xfe, 0xb1,
		0x1a, 0x34, 0x26, 0xdf, 0x37, 0x3f, 0x56, 0x83, 0xe6, 0xc9, 0xc6, 0xa7, 0x4f, 0x9b, 0x1b, 0xdf,
		0xb6, 0xaf, 0x1e, 0xfe, 0x8b, 0x7f, 0xf1, 0x1f, 0x0c, 0x4f, 0x8a, 0x60, 0x64, 0x6f, 0xdf, 0x1f,
		0xfe, 0x13, 0x4b, 0x2b, 0xba, 0xa5, 0x21, 0x22, 0x94, 0x57, 0x44, 0xd8, 0x29, 0xb0, 0x88, 0xb0,
		0x83, 0x88, 0x80, 0x88, 0x80, 0x88, 0x80, 0x88, 0x80, 0x88, 0x80, 0x88, 0x80, 0x88, 0x80, 0x88,
		0x70, 0x87, 0x88, 0xb0, 0x83, 0x88, 0x80, 0x88, 0x30, 0x4b, 0xed, 0xc2, 0xa0, 0xb3, 0x1f, 0xbc,
		0x3a, 0xf9, 0x56, 0x7b, 0xda, 0xb8, 0x7a, 0xbe, 0xf1, 0x6d, 0xf7, 0xea, 0xe6, 0x0f, 0xbf, 0xdf,
		0xf6, 0xcf, 0x6a, 0x4f, 0x77, 0xaf, 0x9e, 0xdf, 0xf1, 0x37, 0x3b, 0x57, 0xcf, 0xef, 0xf9, 0x8c,
		0xe6, 0xd5, 0xfa, 0xc2, 0x3f, 0x1d, 0xfc, 0xbc, 0x7e, 0xd7, 0x2f, 0x34, 0xee, 0xf8, 0x85, 0xed,
		0xbb, 0x7e, 0x61, 0xfb, 0x8e, 0x5f, 0xb8, 0x73, 0x4a, 0xf5, 0x3b, 0x7e, 0xa1, 0x79, 0xf5, 0x7d,
		0xe1, 0xdf, 0xaf, 0xdf, 0xfe, 0x4f, 0x77, 0xae, 0x36, 0xbe, 0xdf, 0xf5, 0x77, 0xbb, 0x57, 0xdf,
		0x9f, 0x6f, 0x20, 0xa9, 0x20, 0xa9, 0xb0, 0xef, 0xd8, 0x77, 0x08, 0x4c, 0xab, 0x21, 0x30, 0x5d,
		0xf4, 0xe2, 0x2c, 0x38, 0xeb, 0x16, 0x48, 0x56, 0x9a, 0xce, 0x18, 0x31, 0x09, 0x31, 0x09, 0x31,
		0x09, 0x31, 0x09, 0x31, 0x09, 0x31, 0x09, 0x31, 0x09, 0x31, 0x69, 0x06, 0x77, 0xcf, 0xba, 0xdd,
		0xd8, 0x84, 0x49, 0x91, 0x74, 0xa4, 0x1a, 0xc1, 0x75, 0x39, 0x83, 0xeb, 0xbc, 0x55, 0xb0, 0xd8,
		0x3a, 0x6f, 0x11, 0x5a, 0x13, 0x5a, 0x13, 0x5a, 0x13, 0x5a, 0x13, 0x5a, 0x13, 0x5a, 0x13, 0x5a,
		0x13, 0x5a, 0xdf, 0xac, 0x89, 0xf1, 0xac, 0x40, 0x81, 0x75, 0x93, 0x92, 0x18, 0x96, 0xbf, 0x28,
		0x89, 0x41, 0x74, 0x7b, 0xcb, 0xb4, 0x29, 0x89, 0x81, 0x77, 0xfb, 0xd1, 0x56, 0xa4, 0x24, 0x86,
		0xfa, 0x56, 0xdc, 0x65, 0x2b, 0x12, 0x06, 0x17, 0x6b, 0x96, 0xe4, 0x18, 0x94, 0xce, 0x15, 0x8c,
		0x55, 0xc5, 0x3c, 0x2e, 0x9a, 0x0e, 0x9a, 0xc7, 0x08, 0xa1, 0x56, 0xa6, 0x89, 0x10, 0x2a, 0x68,
		0xab, 0x08, 0xa1, 0xa2, 0x3b, 0x0c, 0x21, 0x54, 0x79, 0xe2, 0x08, 0xa1, 0x2b, 0x48, 0x15, 0x11,
		0x42, 0xc5, 0x83, 0x04, 0x84, 0x50, 0xdb, 0x5f, 0x08, 0xa1, 0x44, 0xb7, 0xb7, 0x4c, 0x1b, 0x21,
		0x14, 0xef, 0xf6, 0xa3, 0xad, 0x88, 0x10, 0xaa, 0xbe, 0x15, 0xeb, 0x4d, 0x8a, 0x02, 0x13, 0x08,
		0x17, 0x6c, 0x96, 0x48, 0xa1, 0xa5, 0x73, 0x06, 0x95, 0xd4, 0x5c, 0x74, 0x73, 0x53, 0xd0, 0xaa,
		0xc0, 0xb7, 0x4d, 0x1e, 0x81, 0xd4, 0xc6, 0x34, 0x11, 0x48, 0x05, 0xcd, 0x16, 0x81, 0x54, 0x74,
		0x87, 0x21, 0x90, 0x2a, 0x4f, 0x1c, 0x81, 0x74, 0x05, 0x29, 0x24, 0x65, 0x81, 0xb5, 0x62, 0x05,
		0x2a, 0xfa, 0x48, 0x4c, 0x98, 0x62, 0xad, 0x37, 0xc8, 0x1d, 0x35, 0x6c, 0xb0, 0x34, 0x64, 0x04,
		0x64, 0x84, 0x25, 0x65, 0x84, 0x9d, 0x22, 0xcb, 0x08, 0x14, 0x06, 0x46, 0x46, 0x40, 0x46, 0x40,
		0x46, 0x40, 0x46, 0x40, 0x46, 0x40, 0x46, 0x40, 0x46, 0xb8, 0x4b, 0x46, 0xa0, 0x30, 0x30, 0x32,
		0xc2, 0x1c, 0xb9, 0xa3, 0x40, 0x29, 0x05, 0x4a, 0x11, 0x55, 0xd8, 0x77, 0xec, 0x3b, 0x24, 0x26,
		0x24, 0x26, 0x91, 0x1d, 0x9f, 0x45, 0xed, 0xe2, 0x48, 0x4a, 0x83, 0xc9, 0x22, 0x21, 0x21, 0x21,
		0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0xcd, 0x86, 0x07, 0x69,
		0x90, 0x45, 0xed, 0x20, 0x1f, 0x4c, 0xbc, 0x40, 0x0a, 0xd2, 0x5e, 0x01, 0xe6, 0x3a, 0x36, 0x06,
		0x2e, 0xec, 0x09, 0x99, 0xee, 0xb0, 0x12, 0x45, 0x1c, 0x9e, 0x99, 0xb8, 0x52, 0xa0, 0x3b, 0x4e,
		0x05, 0xb2, 0xe0, 0x62, 0x5a, 0x72, 0xf1, 0x2c, 0x7a, 0xc1, 0xb2, 0xfb, 0x51, 0x92, 0x6f, 0xd7,
		0x2b, 0x4f, 0x8b, 0xf7, 0x09, 0xc6, 0xd6, 0xbd, 0x5b, 0xc0, 0xa9, 0x17, 0xeb, 0x82, 0x75, 0xf1,
		0xad, 0x7d, 0xba, 0xf0, 0x45, 0xbc, 0x80, 0x5d, 0x50, 0x0d, 0xe3, 0xa7, 0x1f, 0x63, 0x72, 0x2b,
		0xb4, 0xb6, 0x53, 0xf0, 0x0f, 0x52, 0xe0, 0x4b, 0xa2, 0x05, 0x23, 0x3d, 0x3f, 0xde, 0xdb, 0x05,
		0xbc, 0xd1, 0x5d, 0xfa, 0xbd, 0x5d, 0x6d, 0x3c, 0x6b, 0xee, 0x36, 0xd9, 0xe0, 0xde, 0x6c, 0xf0,
		0x27, 0xcc, 0x5a, 0xe3, 0xeb, 0xe4, 0x09, 0xb0, 0x4f, 0x00, 0xba, 0x48, 0xb7, 0x4c, 0xd2, 0xbf,
		0x30, 0x69, 0x38, 0x40, 0x93, 0x02, 0x73, 0xae, 0x5a, 0xa3, 0x80, 0x73, 0x3f, 0x48, 0xfa, 0x17,
		0x83, 0x00, 0xa1, 0x58, 0x60, 0x52, 0x9c, 0xd9, 0x16, 0x03, 0xf2, 0x0a, 0x02, 0x75, 0x05, 0xd4,
		0x48, 0x0b, 0x96, 0x21, 0xba, 0x80, 0x69, 0xcf, 0x0a, 0x34, 0xe7, 0xa2, 0x65, 0xae, 0x4d, 0x27,
		0x4e, 0x06, 0x1b, 0x19, 0x6c, 0xf7, 0x70, 0x25, 0x45, 0xda, 0x8a, 0x45, 0xcc, 0x24, 0x65, 0x3f,
		0xb2, 0x1f, 0xcb, 0x17, 0xda, 0x91, 0xa1, 0x5b, 0xd2, 0xf5, 0xf3, 0x39, 0x43, 0x37, 0x2f, 0x42,
		0x1e, 0xce, 0x34, 0x48, 0x2f, 0x40, 0xf2, 0x0d, 0x39, 0xba, 0xb6, 0x23, 0x14, 0x72, 0x74, 0x85,
		0x67, 0x4d, 0x8e, 0xae, 0xd2, 0xc4, 0xc9, 0xd1, 0x25, 0x26, 0x28, 0x8e, 0x98, 0x57, 0xc0, 0x1c,
		0xdd, 0x62, 0x9d, 0x4f, 0x14, 0xe9, 0x3c, 0xa2, 0x20, 0xe7, 0x0f, 0x1e, 0x93, 0x80, 0x27, 0x40,
		0xd0, 0x03, 0x1c, 0x4e, 0x92, 0x74, 0xf3, 0xd1, 0x3e, 0xf6, 0x19, 0x80, 0x2a, 0x59, 0xeb, 0xb3,
		0xb9, 0x08, 0x7b, 0x61, 0xfe, 0x79, 0x00, 0x3f, 0x5b, 0xdd, 0x9e, 0x49, 0x5a, 0xc3, 0xc0, 0x3a,
		0x48, 0x4c, 0xfe, 0xdf, 0x6e, 0xfa, 0x67, 0x10, 0x25, 0x59, 0x1e, 0x26, 0x2d, 0xb3, 0x75, 0xf3,
		0x07, 0xd9, 0xc2, 0x4f, 0xb6, 0x7a, 0x69, 0x37, 0xef, 0xb6, 0xba, 0x71, 0x36, 0xfd, 0x6e, 0xeb,
		0xec, 0xbc, 0xb7, 0x95, 0x46, 0x67, 0x5b, 0x61, 0x9e, 0xa7, 0x41, 0x66, 0xf2, 0x6c, 0xfa, 0xdd,
		0x56, 0xde, 0x4f, 0x12, 0x13, 0x07, 0x26, 0x69, 0x85, 0xbd, 0xac, 0x1f, 0x0f, 0x57, 0x6b, 0xfc,
		0xc3, 0x6c, 0xfc, 0xff, 0x5b, 0x59, 0xff, 0x2c, 0x8f, 0xbf, 0x64, 0xe3, 0xff, 0xdf, 0xca, 0xcc,
		0xf9, 0xc0, 0x8d, 0x07, 0x71, 0x94, 0xe5, 0xd9, 0xdc, 0x9f, 0x26, 0x7f, 0x98, 0xfe, 0x74, 0x2b,
		0xcb, 0xc3, 0xdc, 0xf8, 0xe9, 0xe2, 0xfd, 0xdb, 0x4b, 0x7e, 0xcd, 0xc8, 0xb3, 0x5d, 0x3d, 0x08,
		0xd8, 0x87, 0x47, 0x6c, 0x49, 0xdb, 0xf8, 0x16, 0xab, 0x57, 0x8e, 0xa2, 0x2c, 0xdf, 0xcf, 0xf3,
		0xd4, 0x4b, 0x9c, 0xa9, 0xbc, 0x8e, 0x92, 0x83, 0xd8, 0x0c, 0x37, 0xa6, 0x9f, 0x54, 0xbd, 0xf2,
		0x3a, 0xfc, 0x3a, 0x33, 0xc3, 0xda, 0xb3, 0x46, 0x63, 0x67, 0xb7, 0xd1, 0xa8, 0xee, 0x6e, 0xef,
		0x56, 0xf7, 0x9a, 0xcd, 0xda, 0x4e, 0xcd, 0xc3, 0xf4, 0xb9, 0xca, 0xdb, 0xb4, 0x6d, 0x52, 0xd3,
		0x7e, 0x31, 0x30, 0xcb, 0xa4, 0x1f, 0xc7, 0xec, 0xde, 0xe2, 0xfa, 0xe2, 0x12, 0xfb, 0x60, 0x0f,
		0x39, 0x4c, 0x25, 0xcb, 0xd3, 0x7e, 0x2b, 0x4f, 0xc6, 0x84, 0xeb, 0xcd, 0x68, 0xf9, 0x0e, 0xc7,
		0xab, 0x77, 0x7a, 0x3c, 0x5e, 0xb3, 0xd3, 0x17, 0xe7, 0xbd, 0xd3, 0x77, 0xd1, 0xd9, 0xe9, 0x00,
		0x5a, 0xdf, 0x9b, 0xfc, 0xf4, 0xc3, 0x70, 0x2d, 0x0e, 0x66, 0xd7, 0x69, 0xfc, 0xb3, 0xd3, 0xf7,
		0xc3, 0x75, 0x39, 0x7d, 0x3f, 0xfa, 0xcc, 0x03, 0x3c, 0x9e, 0x7c, 0xef, 0x57, 0xf4, 0xe1, 0x8f,
		0x8f, 0xf7, 0x63, 0x26, 0x9e, 0xe0, 0x94, 0xaf, 0xf8, 0x54, 0x42, 0x5c, 0xf2, 0x63, 0x3f, 0xba,
		0xb7, 0x7e, 0x0f, 0x2c, 0xbf, 0x32, 0xa2, 0x67, 0xbe, 0x18, 0xfc, 0xf5, 0x2d, 0xf9, 0xe1, 0xb4,
		0x3c, 0x41, 0x86, 0x89, 0xbe, 0xe6, 0xc9, 0x74, 0xa6, 0x47, 0x6e, 0x75, 0x4f, 0x26, 0xe4, 0xe1,
		0xd1, 0x9a, 0xdf, 0x47, 0x68, 0xbe, 0x1e, 0x95, 0x79, 0x7f, 0x24, 0xe6, 0xfd, 0xd1, 0x97, 0xf7,
		0x47, 0x5c, 0xc4, 0x7c, 0xb3, 0x6f, 0xeb, 0x65, 0xe4, 0x97, 0x60, 0x53, 0x99, 0xc4, 0x69, 0x81,
		0x87, 0x15, 0xef, 0xae, 0x73, 0xdc, 0x67, 0x26, 0xe9, 0x9b, 0x44, 0xe8, 0x65, 0xd6, 0x8c, 0xb7,
		0x59, 0x32, 0x3e, 0x67, 0xc5, 0x14, 0x23, 0x0b, 0xc6, 0xf7, 0xac, 0x97, 0xc2, 0x64, 0xb9, 0x14,
		0x26, 0xab, 0xa5, 0x30, 0x59, 0x2c, 0x1c, 0x26, 0xfd, 0xe8, 0x2d, 0x7a, 0x9b, 0x95, 0x32, 0x57,
		0x94, 0x68, 0xa7, 0xe1, 0x23, 0xe6, 0x8d, 0xbd, 0xac, 0x87, 0x77, 0xc5, 0x3c, 0x2f, 0x2a, 0xe4,
		0x71, 0x0a, 0x42, 0x11, 0x8a, 0x02, 0x15, 0x25, 0x29, 0x7a, 0x52, 0xf8, 0xc3, 0xf7, 0x79, 0x16,
		0xa8, 0xa4, 0x87, 0xcf, 0x97, 0x1f, 0x8a, 0x50, 0x73, 0xa7, 0x68, 0x5b, 0xa7, 0x18, 0x19, 0x00,
		0x85, 0xdd, 0x4d, 0xe4, 0x63, 0xdd, 0xeb, 0xeb, 0x84, 0x93, 0x63, 0xdf, 0xd1, 0xb8, 0xf2, 0x5f,
		0x13, 0x9d, 0x7f, 0xce, 0xfd, 0x55, 0xcb, 0xc6, 0xf3, 0x43, 0x28, 0xbb, 0xcf, 0xb4, 0x10, 0xca,
		0x96, 0xb0, 0x34, 0x84, 0xb2, 0xa5, 0x76, 0x04, 0x42, 0x99, 0xe5, 0x89, 0x22, 0x94, 0x95, 0x80,
		0xe9, 0x14, 0x44, 0x28, 0xf3, 0xb2, 0x7a, 0xb7, 0xc7, 0xd5, 0xb9, 0x11, 0xca, 0x1e, 0xcd, 0xf6,
		0x11, 0xca, 0xac, 0xb3, 0x7d, 0x84, 0xb2, 0xb2, 0xba, 0x8f, 0xf9, 0xad, 0x83, 0x50, 0x66, 0x7d,
		0xeb, 0x34, 0xea, 0x7b, 0x8d, 0xbd, 0x9d, 0xdd, 0xfa, 0x1e, 0xf2, 0x58, 0x49, 0x03, 0x42, 0x7f,
		0x67, 0x85, 0x3c, 0xe6, 0xf3, 0x4c, 0xb8, 0x58, 0xf1, 0xe3, 0x79, 0x95, 0xe8, 0x62, 0x85, 0x3f,
		0x77, 0xac, 0x3d, 0xb8, 0x55, 0xf1, 0x64, 0x85, 0x37, 0xdd, 0xf5, 0x1d, 0x69, 0x5f, 0x52, 0x34,
		0xfd, 0xba, 0x19, 0xed, 0xdf, 0x4d, 0xe8, 0x42, 0xdc, 0x7c, 0xf6, 0xeb, 0xa6, 0xb3, 0xeb, 0x3d,
		0xe6, 0x99, 0x43, 0x2b, 0x8f, 0x23, 0xab, 0x78, 0x71, 0x21, 0x4e, 0xfe, 0x62, 0xb2, 0x5b, 0x57,
		0xed, 0xce, 0x41, 0xba, 0x19, 0xd9, 0x11, 0x5c, 0xf8, 0x02, 0x13, 0x85, 0x86, 0x07, 0x37, 0x3b,
		0x45, 0xdf, 0x4e, 0x1d, 0xd8, 0xa8, 0xe3, 0xab, 0xbf, 0x5e, 0x5c, 0xf5, 0x75, 0x7c, 0xb5, 0xd7,
		0xf9, 0x55, 0x5e, 0x1f, 0xd2, 0x1a, 0xfc, 0x4a, 0x5f, 0xf0, 0x25, 0x4d, 0xc1, 0xbb, 0x74, 0x04,
		0xef, 0xd2, 0x0e, 0xbc, 0x4b, 0x2f, 0x58, 0xad, 0xe8, 0xc6, 0xf5, 0xd5, 0xd9, 0xca, 0x59, 0x94,
		0xb4, 0xa3, 0xe4, 0x3c, 0xc8, 0x3c, 0xb8, 0x2a, 0x3b, 0xc5, 0xb0, 0xd9, 0x49, 0xb9, 0x56, 0x82,
		0xbc, 0x38, 0xc7, 0xf2, 0x26, 0xa3, 0xcf, 0xa7, 0x0c, 0x3e, 0x3f, 0x33, 0xf6, 0x7c, 0xcb, 0xd0,
		0xf3, 0x36, 0x23, 0xcf, 0xdb, 0x0c, 0x3c, 0x6f, 0x33, 0xee, 0x56, 0x5b, 0x93, 0xf7, 0x26, 0x83,
		0xee, 0x9a, 0x73, 0xa5, 0x03, 0x0f, 0x15, 0x78, 0xd2, 0x07, 0x65, 0xca, 0xc2, 0xf6, 0x3c, 0x98,
		0xcb, 0xf8, 0x65, 0xf9, 0x91, 0x16, 0xe7, 0x61, 0x41, 0xa5, 0x8b, 0x5e, 0x9c, 0x05, 0x71, 0x78,
		0x66, 0x62, 0x9f, 0x0a, 0x2a, 0x79, 0x64, 0x41, 0x7e, 0x5a, 0x92, 0x7f, 0x16, 0xb5, 0x60, 0x59,
		0xa4, 0xf1, 0x3e, 0x62, 0x6a, 0xa4, 0xf1, 0x3e, 0x72, 0xe1, 0x48, 0xe3, 0xb5, 0x37, 0xcd, 0xe9,
		0xa5, 0xdd, 0x1d, 0x72, 0x10, 0x4b, 0x12, 0xb4, 0xfe, 0x78, 0xef, 0x90, 0xc7, 0x6b, 0x7f, 0xef,
		0x54, 0x1b, 0xcf, 0x9a, 0xbb, 0x24, 0xf1, 0x96, 0x84, 0x73, 0x16, 0x67, 0x56, 0x27, 0xdc, 0x7e,
		0x2b, 0x64, 0xb8, 0xec, 0x77, 0x93, 0x32, 0x9f, 0x9b, 0x92, 0x79, 0xda, 0x84, 0xcc, 0x9f, 0xd9,
		0x9c, 0x90, 0xbf, 0xee, 0x23, 0x04, 0x5c, 0x17, 0x60, 0xed, 0x7d, 0xd9, 0x09, 0xc2, 0x76, 0x3b,
		0x35, 0x59, 0xe6, 0xa3, 0x0a, 0xe3, 0x51, 0x61, 0xb8, 0xca, 0x71, 0x98, 0xe7, 0x26, 0x4d, 0xbc,
		0xa3, 0xc8, 0x95, 0x7f, 0xaf, 0xdf, 0xd6, 0x76, 0x7f, 0xf7, 0xea, 0xe6, 0x0f, 0xef, 0xe8, 0xce,
		0xbf, 0x7b, 0xf5, 0xfc, 0x8e, 0xbf, 0xd9, 0xb9, 0x7a, 0x7e, 0xcf, 0x67, 0x34, 0xef, 0xe8, 0xf0,
		0x5f, 0xbf, 0xeb, 0x17, 0x1a, 0x77, 0xfc, 0xc2, 0xf6, 0x5d, 0xbf, 0xb0, 0x7d, 0xc7, 0x2f, 0xdc,
		0x39, 0xa5, 0xfa, 0x1d, 0xbf, 0xd0, 0xbc, 0xfa, 0xbe, 0xf0, 0xef, 0xd7, 0x6f, 0xff, 0xa7, 0x3b,
		0x57, 0x1b, 0xdf, 0xef, 0xfa, 0xbb, 0xdd, 0xab, 0xef, 0xcf, 0x37, 0x36, 0xfe, 0xe2, 0x4f, 0x0d,
		0x82, 0x13, 0x9f, 0xb6, 0xca, 0xdb, 0xf7, 0x87, 0xff, 0x64, 0xbf, 0xb0, 0x5f, 0x7c, 0xde, 0x2f,
		0xdc, 0x72, 0xf2, 0x60, 0x1d, 0x1c, 0xa6, 0x90, 0x3b, 0x4c, 0x0d, 0x6c, 0x75, 0xe3, 0x6e, 0x9a,
		0xf9, 0x93, 0x6c, 0x34, 0x9e, 0x0f, 0x79, 0x46, 0xe4, 0x19, 0xfd, 0xc4, 0x52, 0xc8, 0x33, 0xfa,
		0xa1, 0x05, 0x93, 0x67, 0xf4, 0xc0, 0x89, 0x91, 0x67, 0xe4, 0xa1, 0x60, 0xe1, 0x61, 0x9e, 0x91,
		0x37, 0x47, 0xfa, 0x1e, 0x1d, 0xe1, 0x7b, 0x76, 0x64, 0xef, 0x91, 0xbc, 0xe5, 0xe3, 0x91, 0xbc,
		0xaf, 0x85, 0x52, 0x3d, 0xad, 0x9c, 0xe5, 0xf3, 0x01, 0xa1, 0x4f, 0x45, 0x8b, 0x7d, 0x3c, 0x41,
		0xf7, 0xdd, 0xd4, 0x7d, 0xad, 0x74, 0xe5, 0xb5, 0xcd, 0x23, 0x97, 0xf8, 0x20, 0x97, 0x50, 0x82,
		0x65, 0xde, 0xcd, 0x53, 0x82, 0xe5, 0xe1, 0x93, 0xf4, 0xab, 0x04, 0xcb, 0x4a, 0x0a, 0x80, 0xbd,
		0xd4, 0x74, 0x4c, 0x6a, 0x12, 0x1f, 0xee, 0x07, 0x4f, 0x28, 0xd6, 0xcc, 0x9c, 0x1c, 0xa3, 0xcc,
		0x4b, 0xd3, 0x09, 0xfb, 0xf1, 0x50, 0x13, 0xa8, 0x55, 0xab, 0xc8, 0x92, 0x6b, 0xc8, 0x92, 0x3f,
		0xb1, 0x5d, 0x64, 0xc9, 0x1f, 0x5a, 0x30, 0xb2, 0xe4, 0x03, 0x27, 0x86, 0x2c, 0xe9, 0x63, 0xf4,
		0x89, 0x2c, 0xf9, 0x53, 0x2f, 0x85, 0x2c, 0x79, 0xf3, 0x0b, 0x59, 0xb2, 0xd0, 0x5a, 0x0d, 0xb2,
		0x64, 0x51, 0xe0, 0xf9, 0x26, 0x11, 0xc6, 0xd4, 0x1f, 0x68, 0xea, 0xc8, 0x92, 0x45, 0x0b, 0x88,
		0xfc, 0x99, 0x05, 0x59, 0x5c, 0xfa, 0xdb, 0x22, 0xf7, 0x21, 0x1c, 0x9d, 0x86, 0xa2, 0x1e, 0x94,
		0xe0, 0x40, 0x2a, 0x41, 0x2a, 0x41, 0x2a, 0x41, 0x2a, 0x41, 0x2a, 0x41, 0x2a, 0x59, 0xc0, 0x9d,
		0xa8, 0x6d, 0x92, 0x3c, 0xca, 0x2f, 0x53, 0xd3, 0xf1, 0xa9, 0x52, 0x94, 0x0f, 0x07, 0x72, 0x87,
		0xe3, 0xa5, 0x79, 0x11, 0x66, 0x1e, 0x41, 0xe1, 0xe4, 0xc5, 0x7d, 0xf8, 0xfd, 0xcd, 0x9b, 0x83,
		0xa3, 0xd3, 0x83, 0x37, 0xbf, 0xee, 0x1f, 0xbf, 0xff, 0xfd, 0x68, 0xff, 0xc3, 0xe1, 0xdb, 0x37,
		0xa7, 0xef, 0x7f, 0x7f, 0xf1, 0xe1, 0xe8, 0x8f, 0xd3, 0x0f, 0xff, 0x3a, 0x3e, 0xf0, 0x05, 0x21,
		0x87, 0x34, 0x2a, 0xf3, 0xea, 0xba, 0x91, 0xa7, 0x8d, 0xc4, 0xc7, 0x6f, 0xf4, 0xd7, 0xb7, 0x47,
		0x6f, 0xdf, 0x55, 0x90, 0x2f, 0x0a, 0xf3, 0xde, 0xde, 0xbf, 0xfb, 0x70, 0x70, 0xfa, 0xfe, 0xe0,
		0xb7, 0xd7, 0x07, 0x6f, 0x3e, 0x9c, 0x1e, 0x1d, 0xbe, 0xff, 0xc0, 0xcb, 0x2b, 0xd8, 0xcb, 0x7b,
		0x71, 0xf8, 0xe6, 0xe5, 0xe1, 0x9b, 0xdf, 0x4e, 0xdf, 0x1f, 0xbe, 0xe4, 0xdd, 0x15, 0xec, 0xdd,
		0x1d, 0xbf, 0x3b, 0x78, 0x75, 0xf0, 0xee, 0xe0, 0xcd, 0xaf, 0x07, 0xbc, 0xba, 0xc2, 0xf9, 0xba,
		0x77, 0x07, 0xaf, 0xdf, 0x7e, 0x38, 0x38, 0x3d, 0x78, 0xf3, 0xf2, 0xf8, 0xed, 0xe1, 0x1b, 0x9f,
		0x80, 0xd3, 0x8b, 0x99, 0x9c, 0xac, 0x3a, 0x5d, 0xa3, 0xd6, 0xbf, 0x8e, 0x58, 0x40, 0x27, 0xa3,
		0x47, 0x75, 0x32, 0x72, 0xd7, 0x96, 0x73, 0x35, 0x3a, 0x18, 0x39, 0x95, 0xf2, 0x7d, 0x90, 0xf0,
		0x1d, 0x4b, 0xf7, 0xce, 0x25, 0x7b, 0xfa, 0x17, 0x2d, 0xcc, 0x86, 0xfe, 0x45, 0x77, 0x4c, 0x88,
		0xfe, 0x45, 0xc4, 0x34, 0x33, 0xab, 0xef, 0x5c, 0x6a, 0x9f, 0xe2, 0x46, 0x6c, 0xc2, 0x8e, 0x5b,
		0x79, 0x7d, 0x2a, 0xab, 0x3b, 0xcc, 0x43, 0xac, 0x1c, 0x8f, 0xc3, 0xba, 0xcd, 0xcd, 0x51, 0xe0,
		0xb4, 0x35, 0xf4, 0xab, 0xab, 0x12, 0x3d, 0x3d, 0x29, 0xf1, 0x9e, 0x9b, 0x34, 0x25, 0x77, 0x10,
		0x28, 0xb9, 0xbd, 0xfa, 0xe6, 0xfe, 0xaa, 0x9b, 0x97, 0x57, 0xdb, 0xdc, 0x5e, 0x65, 0xd3, 0x36,
		0x7e, 0xc7, 0xe4, 0xb9, 0x60, 0xa4, 0xb9, 0xe2, 0xa4, 0x11, 0xae, 0x4c, 0xcb, 0x6f, 0x5d, 0xe7,
		0xa5, 0xe7, 0x42, 0x74, 0x46, 0x52, 0xda, 0xa7, 0xae, 0xf6, 0x67, 0x51, 0xf6, 0xa5, 0x8e, 0x11,
		0xcb, 0x9b, 0x94, 0x82, 0x39, 0xe9, 0xea, 0x51, 0x2e, 0xf4, 0x27, 0x65, 0xbd, 0x49, 0x5d, 0x5f,
		0x72, 0xa1, 0x27, 0xb9, 0xd5, 0x8f, 0x5c, 0xe9, 0x45, 0xce, 0xf5, 0x21, 0xe7, 0x7a, 0x90, 0x73,
		0xfd, 0xa7, 0x5c, 0x6e, 0x5c, 0x5d, 0xcf, 0x71, 0xa8, 0xdf, 0xb8, 0xd0, 0x6b, 0x5c, 0xea, 0x33,
		0x0a, 0xd1, 0xc1, 0x93, 0x02, 0xef, 0x01, 0x45, 0x7d, 0x45, 0x57, 0x4f, 0xd1, 0xd7, 0x4f, 0xbc,
		0xd0, 0x4b, 0x74, 0xf5, 0x11, 0x69, 0xe3, 0x54, 0xe6, 0x57, 0xbe, 0xf3, 0x2a, 0x05, 0x37, 0x61,
		0x5f, 0xd0, 0x90, 0x85, 0x79, 0x39, 0xf0, 0x95, 0x79, 0xb2, 0xd0, 0x8e, 0xd1, 0xda, 0x29, 0xde,
		0xee, 0x10, 0x19, 0x2b, 0xb3, 0x6f, 0x03, 0x76, 0x9f, 0x68, 0xd9, 0x9a, 0xa4, 0xad, 0xc8, 0x3b,
		0xeb, 0x11, 0x00, 0x54, 0x8b, 0x00, 0x6a, 0xd7, 0xa6, 0xed, 0x59, 0x9e, 0x9d, 0x27, 0x59, 0xb2,
		0xdd, 0x49, 0x00, 0x1b, 0x25, 0x6d, 0x63, 0x4b, 0x07, 0x90, 0x89, 0x54, 0xe5, 0x22, 0x52, 0xd5,
		0xc8, 0x53, 0x26, 0xc2, 0xb4, 0x65, 0x0d, 0x42, 0x08, 0xe6, 0x12, 0xb9, 0x2c, 0x82, 0xd4, 0x23,
		0xc1, 0xc9, 0x0e, 0x10, 0x2d, 0x0f, 0x1b, 0xcb, 0x3d, 0x61, 0x49, 0x13, 0xb3, 0x6d, 0x5a, 0x0e,
		0x4c, 0x6a, 0xb9, 0xf7, 0xf8, 0xf8, 0xd5, 0x5f, 0x62, 0xe5, 0x2b, 0xad, 0xee, 0xc5, 0x45, 0x3f,
		0x89, 0xf2, 0xc8, 0x2c, 0xdf, 0x3d, 0x69, 0xa6, 0xfb, 0xd1, 0xf5, 0x43, 0x97, 0xb4, 0x8a, 0x89,
		0x9c, 0xb6, 0xe4, 0x63, 0x6c, 0x9d, 0x56, 0xd8, 0x3c, 0x85, 0x90, 0x39, 0x5d, 0xb0, 0x7d, 0x6a,
		0x20, 0x76, 0x1a, 0x20, 0xa6, 0xf2, 0x8b, 0xa9, 0xf7, 0x6e, 0xf1, 0xf1, 0x65, 0x64, 0x27, 0x5e,
		0x9a, 0xee, 0xce, 0x4b, 0x7b, 0x36, 0x72, 0x73, 0xe3, 0x5f, 0xda, 0xb2, 0x11, 0x3b, 0xdb, 0xdf,
		0x3a, 0x0c, 0x48, 0xc0, 0x81, 0x2c, 0x2c, 0x48, 0xc1, 0x83, 0x38, 0x4c, 0x88, 0xc3, 0x85, 0x38,
		0x6c, 0xf8, 0xc9, 0xeb, 0x6c, 0xc1, 0xc9, 0xf4, 0x81, 0x23, 0x86, 0x68, 0xdd, 0xae, 0xa6, 0xd5,
		0x4e, 0x2c, 0x12, 0xd0, 0x9b, 0xf0, 0x62, 0xf9, 0xf4, 0x42, 0x2c, 0x37, 0x42, 0x32, 0x07, 0x42,
		0x27, 0xd7, 0x41, 0x3a, 0xa7, 0x41, 0x2d, 0x77, 0x41, 0x2d, 0x47, 0x41, 0x2d, 0x17, 0xc1, 0x6f,
		0xe9, 0x54, 0x2c, 0x87, 0x40, 0x21, 0x57, 0x40, 0x32, 0x27, 0x60, 0xf1, 0xec, 0x7f, 0x04, 0x94,
		0xbe, 0x6a, 0x9b, 0x56, 0xc5, 0x96, 0x30, 0x37, 0x72, 0x0e, 0x67, 0xf4, 0x78, 0x19, 0x87, 0x53,
		0x93, 0x72, 0x38, 0x75, 0x1c, 0x0e, 0x0e, 0x07, 0x87, 0xe3, 0x61, 0x7c, 0x2c, 0x48, 0xbf, 0xd5,
		0xe8, 0xb8, 0x52, 0xfc, 0x2c, 0x1e, 0x47, 0x6b, 0xc0, 0x9b, 0x2e, 0xcc, 0x69, 0xc1, 0x9d, 0x3a,
		0xec, 0xa9, 0xc3, 0x9f, 0x3a, 0x0c, 0xca, 0xc0, 0xa1, 0x10, 0x2c, 0xca, 0xc7, 0xe3, 0x0b, 0xfb,
		0xa6, 0x9f, 0xc8, 0x64, 0x12, 0x2c, 0xc4, 0x64, 0x7b, 0x82, 0x63, 0x8c, 0x97, 0x4b, 0xb6, 0x90,
		0xa6, 0x42, 0x06, 0xdf, 0xe4, 0xa5, 0x9c, 0x9d, 0xf7, 0x82, 0xff, 0x9a, 0x38, 0x0e, 0xfe, 0x4c,
		0xba, 0xff, 0x4d, 0x82, 0xa9, 0xa3, 0x09, 0x94, 0x6e, 0xbc, 0x68, 0x56, 0x9b, 0x75, 0x53, 0x4d,
		0x76, 0xba, 0xd4, 0x2f, 0x7e, 0x3b, 0x3e, 0xfd, 0x9f, 0x83, 0xa3, 0xa3, 0xd3, 0x7f, 0xbc, 0x79,
		0xfb, 0x3f, 0x6f, 0x4e, 0xdf, 0x7f, 0x78, 0x79, 0xfa, 0xeb, 0xdb, 0xd7, 0xaf, 0x7f, 0x7f, 0x73,
		0xf8, 0xe1, 0x5f, 0x5a, 0x77, 0x8b, 0x1c, 0x54, 0x82, 0x55, 0xbe, 0xf3, 0x32, 0x59, 0xed, 0x37,
		0x6f, 0x4f, 0x0f, 0xfe, 0x79, 0xfc, 0xf6, 0x9d, 0x62, 0x41, 0x3b, 0xc5, 0x5b, 0xcf, 0xee, 0x16,
		0x75, 0xff, 0xe5, 0x1f, 0x07, 0xef, 0x3e, 0x1c, 0xbe, 0x3f, 0x60, 0x5d, 0x6d, 0xae, 0xeb, 0xf1,
		0xc1, 0xc1, 0x3b, 0x56, 0x54, 0x60, 0xfb, 0x9f, 0xbe, 0xff, 0xfd, 0xc5, 0xaf, 0x6f, 0xdf, 0xbc,
		0x3a, 0x78, 0x59, 0xb6, 0x5b, 0x5f, 0x27, 0xdc, 0xd8, 0xf1, 0x28, 0x88, 0xca, 0xf2, 0xb6, 0xc3,
		0xe8, 0x69, 0x4f, 0x61, 0x2c, 0x95, 0xd0, 0x57, 0x1f, 0x36, 0xdc, 0x75, 0xac, 0x74, 0xd0, 0x99,
		0xd2, 0x51, 0x07, 0x4a, 0x37, 0x65, 0x81, 0xdc, 0x95, 0xad, 0x74, 0x5c, 0x32, 0xd2, 0x71, 0x87,
		0x48, 0x1f, 0xba, 0xe2, 0x5d, 0xb9, 0xa9, 0x03, 0xb5, 0xf2, 0x26, 0xe7, 0xba, 0x53, 0xa3, 0x17,
		0xb6, 0x57, 0xd2, 0x9a, 0x44, 0x27, 0x65, 0x2a, 0x66, 0xe0, 0x20, 0xc0, 0xc8, 0xf2, 0x34, 0x4a,
		0xce, 0x5d, 0xd4, 0x30, 0x78, 0xa6, 0x5b, 0xc3, 0x20, 0x37, 0x69, 0xa2, 0x1e, 0x63, 0x54, 0xfe,
		0xbd, 0xbe, 0xd3, 0x6c, 0x6e, 0x7f, 0xac, 0x06, 0xcd, 0x93, 0xef, 0x3b, 0xcd, 0xe6, 0xc7, 0x6a,
		0x50, 0x3f, 0xf9, 0x58, 0x0d, 0xf6, 0x06, 0x7f, 0x6a, 0x0c, 0xbf, 0xf9, 0x56, 0xbf, 0xfa, 0xbe,
		0x33, 0xf8, 0x8b, 0xc6, 0xc9, 0xf5, 0x9f, 0x67, 0xfe, 0xb8, 0x7d, 0xf5, 0xfd, 0x63, 0x2d, 0x68,
		0x8e, 0xff, 0xd4, 0x18, 0xfe, 0x69, 0x6f, 0xfc, 0xa7, 0xda, 0xd3, 0xc1, 0xdf, 0x0e, 0xbe, 0xdd,
		0x78, 0xae, 0x35, 0xd0, 0x5f, 0xf4, 0x28, 0xeb, 0x89, 0xa6, 0x85, 0xbc, 0x7d, 0x7f, 0xf8, 0x4f,
		0xcc, 0xa4, 0x90, 0x66, 0x52, 0x92, 0x5a, 0x24, 0x27, 0x05, 0xbd, 0x6c, 0x7f, 0x52, 0xa8, 0xb3,
		0x45, 0x95, 0x42, 0x26, 0x7a, 0x05, 0x4c, 0x9c, 0x16, 0x2e, 0xd1, 0x29, 0x58, 0x22, 0x70, 0x91,
		0x5f, 0x20, 0x15, 0x4c, 0x26, 0x43, 0x7d, 0x21, 0x5e, 0x93, 0xc8, 0x54, 0x57, 0xe2, 0x6b, 0x64,
		0xdc, 0x3c, 0x7c, 0x34, 0x32, 0x6e, 0x6c, 0x0d, 0x48, 0xc6, 0xcd, 0x8f, 0x56, 0x47, 0x31, 0xe3,
		0x26, 0x4a, 0xf2, 0x9d, 0x86, 0x42, 0xca, 0x8d, 0x20, 0xbf, 0x54, 0x52, 0xac, 0x75, 0x0a, 0xad,
		0xe9, 0x25, 0x9d, 0x28, 0x17, 0x91, 0x55, 0x56, 0x9c, 0x5d, 0xa8, 0x7c, 0x57, 0x3a, 0x95, 0xf1,
		0x4a, 0x6f, 0x22, 0xee, 0xfa, 0x23, 0x38, 0xb1, 0x1a, 0x88, 0xa6, 0x2c, 0xbd, 0xa0, 0x4e, 0x98,
		0x46, 0x69, 0x94, 0x99, 0x42, 0x20, 0xd3, 0xef, 0x2f, 0x25, 0x9a, 0x2f, 0x52, 0x7d, 0xcb, 0xb1,
		0xbc, 0x42, 0xf5, 0x2d, 0x05, 0x6b, 0x28, 0x7c, 0xf5, 0xad, 0x5b, 0xf1, 0xc0, 0x61, 0x01, 0xae,
		0x5f, 0xa7, 0x73, 0xa0, 0x04, 0x57, 0x91, 0x4b, 0x70, 0xcd, 0x16, 0x9c, 0x2a, 0x60, 0x11, 0x2e,
		0xf3, 0x35, 0x0f, 0x44, 0x0a, 0x71, 0xdd, 0x7c, 0x30, 0xc5, 0xb8, 0x74, 0x45, 0x43, 0x8a, 0x71,
		0x51, 0x8c, 0xeb, 0xfe, 0x5b, 0x5f, 0xa0, 0x20, 0xd7, 0xfc, 0xe3, 0x29, 0xca, 0xe5, 0x17, 0x3c,
		0x48, 0xc1, 0x84, 0x38, 0x5c, 0x88, 0xc3, 0x86, 0x38, 0x7c, 0xf8, 0x49, 0xf7, 0x28, 0xca, 0x45,
		0x51, 0x2e, 0x3d, 0xd8, 0x91, 0x86, 0x1f, 0x35, 0x18, 0x52, 0x83, 0x23, 0x35, 0x58, 0x2a, 0x86,
		0x4e, 0x49, 0x51, 0xae, 0xbb, 0x20, 0x81, 0xa2, 0x5c, 0x14, 0xe5, 0xa2, 0x28, 0x17, 0x0e, 0x07,
		0x87, 0x63, 0x75, 0x15, 0xc4, 0x8a, 0x72, 0xc9, 0xd0, 0x70, 0x55, 0x5a, 0xae, 0x14, 0x47, 0x8b,
		0xc7, 0xd3, 0x1a, 0x30, 0xa7, 0x0b, 0x77, 0x5a, 0xb0, 0xa7, 0x0e, 0x7f, 0xea, 0x30, 0xa8, 0x0e,
		0x87, 0x32, 0xb0, 0x28, 0x04, 0x8f, 0xf2, 0x71, 0xf9, 0xc2, 0xbe, 0x39, 0x3b, 0xef, 0x05, 0x73,
		0x60, 0x16, 0xa4, 0xa6, 0xf5, 0x45, 0xba, 0x8e, 0x01, 0x25, 0xbb, 0xac, 0xbc, 0x2a, 0xaa, 0x4d,
		0x78, 0xff, 0xf6, 0x6e, 0x21, 0x40, 0x5c, 0x06, 0x15, 0x1c, 0x58, 0xf1, 0x96, 0xdf, 0xf4, 0xca,
		0xfb, 0x68, 0xb4, 0xc9, 0x1f, 0x3f, 0x56, 0x83, 0x67, 0xe3, 0x21, 0xc7, 0x3f, 0xfa, 0x58, 0x0d,
		0x6a, 0xd7, 0x63, 0x8d, 0x7e, 0xf8, 0xb1, 0x1a, 0xec, 0x5c, 0x0f, 0x38, 0xfc, 0xd9, 0xf0, 0x31,
		0xd3, 0x51, 0x07, 0x3f, 0xba, 0x7e, 0xd4, 0xb7, 0xe6, 0xf0, 0x27, 0x1f, 0xab, 0xc1, 0xf6, 0xf8,
		0x07, 0x3b, 0x57, 0xdf, 0x1b, 0x33, 0x0f, 0xde, 0x1d, 0xce, 0x73, 0xf2, 0x97, 0x7b, 0x37, 0x66,
		0xfd, 0x8c, 0x9b, 0xa5, 0xd8, 0xdc, 0x2a, 0xd8, 0x1c, 0x95, 0x0a, 0x70, 0x4e, 0x3e, 0x3b, 0xa7,
		0xf5, 0xd1, 0x26, 0xbd, 0xde, 0x28, 0xdf, 0x6b, 0xc3, 0xff, 0x1b, 0x7d, 0x5f, 0xbf, 0x86, 0x84,
		0xef, 0xf5, 0xe6, 0x70, 0x6f, 0x6e, 0x7c, 0xfa, 0xb4, 0xb9, 0xf1, 0x6d, 0xfb, 0xea, 0xe1, 0xbf,
		0x48, 0xb5, 0x82, 0x62, 0xfb, 0x14, 0x4c, 0x05, 0x57, 0x80, 0x2b, 0x28, 0xaf, 0x2b, 0x28, 0x62,
		0x28, 0x87, 0x4f, 0x29, 0xb6, 0x4f, 0xc1, 0xe6, 0x70, 0x4e, 0x38, 0x27, 0x9c, 0xd3, 0xcf, 0x80,
		0x22, 0xed, 0xf6, 0x73, 0xf3, 0xe9, 0x53, 0x90, 0x87, 0xe9, 0xb9, 0xc9, 0x9f, 0xa3, 0x6f, 0xa0,
		0xa9, 0x61, 0x82, 0x98, 0x20, 0xae, 0x0b, 0xd7, 0x55, 0x34, 0xd7, 0x85, 0x8c, 0x82, 0xc7, 0xc1,
		0x72, 0x70, 0x14, 0x38, 0x0a, 0x1c, 0xc5, 0x0f, 0xb7, 0x3b, 0xda, 0x08, 0x1e, 0x07, 0x13, 0xc4,
		0x04, 0x71, 0x5d, 0xb8, 0xae, 0x82, 0xb8, 0xae, 0x6e, 0x1a, 0x9d, 0x47, 0x09, 0xda, 0x08, 0xf2,
		0x1c, 0x26, 0x88, 0x09, 0xe2, 0xba, 0x70, 0x5d, 0x85, 0x73, 0x5d, 0x88, 0x2c, 0x78, 0x1c, 0x2c,
		0x07, 0x47, 0x81, 0xa3, 0xc0, 0x51, 0xfc, 0x70, 0xbb, 0xa3, 0x8d, 0xe0, 0x71, 0x30, 0x41, 0x4c,
		0x10, 0xd7, 0x85, 0xeb, 0xf2, 0xdc, 0x75, 0xb5, 0xba, 0x71, 0x37, 0x7d, 0x3e, 0xdc, 0xab, 0xdf,
		0xea, 0x57, 0x48, 0x16, 0x78, 0x14, 0x2c, 0xc3, 0x67, 0xa0, 0x2f, 0x7a, 0xd7, 0xd1, 0xa7, 0xa5,
		0xa9, 0x70, 0x11, 0x25, 0x61, 0x7a, 0xa9, 0x58, 0xd1, 0x42, 0xa3, 0xa0, 0xc5, 0x91, 0x49, 0xce,
		0x87, 0xc5, 0x04, 0x4b, 0x57, 0xd2, 0x42, 0xb3, 0xb1, 0xd9, 0xcd, 0x37, 0x57, 0x7d, 0xaa, 0x3b,
		0xec, 0xa4, 0x8b, 0xd5, 0x33, 0xe5, 0x71, 0x1d, 0xb4, 0xae, 0x52, 0x0e, 0x80, 0xd7, 0xb4, 0x1b,
		0xa0, 0x61, 0x4a, 0xfa, 0xa6, 0x84, 0x23, 0x77, 0x3a, 0x7f, 0xda, 0x87, 0xdf, 0xea, 0xbd, 0x68,
		0x1f, 0xee, 0xad, 0xe5, 0xd2, 0x3e, 0xdc, 0x85, 0xcf, 0xa2, 0x26, 0xe8, 0xc3, 0x47, 0xa3, 0x26,
		0xa8, 0xad, 0x01, 0xa9, 0x09, 0xfa, 0xa3, 0xd5, 0xa1, 0x7d, 0xf8, 0x83, 0x86, 0xa0, 0x7d, 0xb8,
		0xff, 0x94, 0x88, 0xf6, 0xe1, 0xc5, 0x63, 0xcf, 0xb4, 0x0f, 0xa7, 0x7d, 0xb8, 0x3a, 0xd1, 0xa4,
		0x7d, 0xb8, 0xd5, 0xe7, 0xab, 0xb5, 0x75, 0xbd, 0xd1, 0xbe, 0x74, 0xee, 0xcf, 0xb4, 0x11, 0x7f,
		0x58, 0xf0, 0x4f, 0x1b, 0x71, 0xda, 0x88, 0xcb, 0xe2, 0x83, 0x27, 0xb8, 0xe0, 0xb0, 0x9d, 0xf8,
		0xc1, 0xd7, 0x9c, 0x8e, 0xe2, 0x92, 0xa6, 0xe6, 0xcc, 0xc4, 0x9c, 0x75, 0x15, 0x7f, 0xa2, 0xf8,
		0xd6, 0x6c, 0xbd, 0x2d, 0xb5, 0xb7, 0xb4, 0xc4, 0x56, 0x7f, 0xe0, 0xd6, 0x7e, 0xdc, 0xfb, 0x7f,
		0xf8, 0xdb, 0x7b, 0xd8, 0x6f, 0x3c, 0xf0, 0x3d, 0x2f, 0xfb, 0x7e, 0x55, 0xde, 0xeb, 0x23, 0xde,
		0xe9, 0x03, 0xde, 0xe5, 0xc3, 0xde, 0xe3, 0xfd, 0xdf, 0xc6, 0x03, 0xde, 0x44, 0xa5, 0x35, 0x11,
		0xc9, 0x1f, 0xf6, 0x06, 0xa6, 0xfa, 0xda, 0xf8, 0xf7, 0x1f, 0xf8, 0xee, 0x1f, 0xd7, 0xe4, 0xf0,
		0xd1, 0x8a, 0xfe, 0x32, 0x4a, 0xfd, 0xac, 0x02, 0x9f, 0x98, 0x7c, 0x60, 0x30, 0x8f, 0xb1, 0x8a,
		0x25, 0x95, 0x75, 0x6b, 0x8a, 0xb9, 0x35, 0x25, 0xfc, 0xa6, 0xc2, 0x3d, 0x59, 0x1b, 0xcf, 0x50,
		0xe6, 0xb1, 0x4d, 0xfa, 0x2a, 0x6d, 0xd3, 0x09, 0xfb, 0x71, 0x1e, 0x5c, 0x98, 0x3c, 0x8d, 0x5a,
		0x8f, 0x7f, 0x71, 0x13, 0xf3, 0xb9, 0xf1, 0xbc, 0x47, 0x2e, 0xfa, 0x72, 0x82, 0xd5, 0xd2, 0x47,
		0x62, 0x36, 0x8e, 0xbc, 0xec, 0x6c, 0x28, 0x5b, 0x1b, 0xcb, 0xfa, 0x06, 0xb3, 0xbe, 0xd1, 0xac,
		0x6f, 0x38, 0x37, 0xe1, 0xdc, 0xd2, 0x47, 0x3e, 0x73, 0x47, 0x3a, 0xdb, 0xf5, 0x65, 0x6c, 0x66,
		0xbc, 0x8b, 0x96, 0x68, 0xb6, 0x6c, 0xe9, 0x48, 0xc6, 0x02, 0x09, 0xb1, 0x79, 0xa4, 0x62, 0x59,
		0x0f, 0xb7, 0x7d, 0x24, 0x22, 0x21, 0x5e, 0x5b, 0x90, 0x31, 0xac, 0x1e, 0x59, 0x48, 0xbd, 0x82,
		0x69, 0x76, 0x7e, 0xd3, 0xe3, 0x77, 0xe1, 0x88, 0xd7, 0x9e, 0x68, 0xf1, 0xa9, 0x47, 0xc4, 0x8d,
		0x26, 0x09, 0xcf, 0x62, 0xd3, 0x5e, 0x3e, 0xfe, 0x98, 0x3c, 0x88, 0xc0, 0x83, 0xc0, 0x83, 0xc0,
		0xe3, 0x51, 0x76, 0x73, 0xd6, 0xed, 0xc6, 0x26, 0x4c, 0x2c, 0x44, 0x1e, 0xb5, 0x9a, 0xc7, 0x90,
		0x13, 0xb5, 0x4d, 0x92, 0x47, 0x9d, 0xc8, 0xa4, 0xcb, 0xa3, 0xce, 0xcc, 0xb3, 0x00, 0x1e, 0x80,
		0x07, 0xe0, 0x59, 0x62, 0x17, 0xe5, 0x97, 0xa9, 0xe9, 0xd8, 0x00, 0x9f, 0x25, 0x42, 0xc0, 0xca,
		0xe1, 0x78, 0x2a, 0x2f, 0xc2, 0xcc, 0x82, 0x09, 0x4e, 0x3e, 0xe0, 0xe1, 0x9b, 0xf7, 0x1f, 0xf6,
		0x8f, 0x8e, 0x4e, 0x8f, 0xdf, 0xbd, 0xfd, 0xf0, 0xf6, 0xd7, 0xb7, 0x47, 0xa7, 0x1f, 0xfe, 0x75,
		0x7c, 0xb0, 0xac, 0x39, 0x0e, 0x43, 0xdf, 0xcc, 0x4a, 0xda, 0x9c, 0xa5, 0xd8, 0x7e, 0xf2, 0x71,
		0x8f, 0x0f, 0x5f, 0x57, 0x7c, 0x60, 0x2e, 0x96, 0x3f, 0xd6, 0xe1, 0x6f, 0xaf, 0x8f, 0xcb, 0xf8,
		0xb9, 0x5e, 0x1e, 0xbe, 0x3b, 0xf8, 0xf5, 0xc3, 0xd1, 0xbf, 0x4e, 0x7f, 0x7d, 0xfb, 0xe6, 0xcd,
		0xc1, 0xaf, 0x1f, 0x0e, 0x5e, 0x96, 0xf1, 0x53, 0xbe, 0x7d, 0x7f, 0xfc, 0x6a, 0xbb, 0x8c, 0x1f,
		0xec, 0xfd, 0x87, 0xfd, 0x0f, 0x87, 0xbf, 0x96, 0x72, 0xc3, 0xbd, 0x3f, 0x7c, 0x5f, 0xc6, 0xcf,
		0xf5, 0xe2, 0xb7, 0xe3, 0xb2, 0xee, 0xb0, 0x32, 0x7e, 0xae, 0xa3, 0xb7, 0xbf, 0xee, 0x1f, 0x9d,
		0xee, 0xff, 0xf6, 0xdb, 0xbb, 0x83, 0xdf, 0xf6, 0x3f, 0x1c, 0x54, 0x1c, 0x0b, 0x41, 0x27, 0xda,
		0xf1, 0xa1, 0x0a, 0x2b, 0x1b, 0x1f, 0x28, 0x2f, 0xc9, 0xc7, 0x86, 0x4f, 0x81, 0x89, 0xc1, 0xc4,
		0x60, 0x62, 0x8f, 0xb2, 0x9b, 0xa5, 0xcb, 0x4d, 0x5d, 0x97, 0x8f, 0x22, 0x89, 0x47, 0x23, 0x89,
		0x67, 0x9c, 0x9f, 0xe2, 0x41, 0xa6, 0xcd, 0x12, 0xb2, 0xda, 0xf2, 0x72, 0xda, 0x23, 0xc1, 0x9b,
		0x8c, 0x1b, 0x32, 0x6e, 0x1e, 0x0a, 0x09, 0x8f, 0x06, 0xdb, 0xe9, 0x7b, 0x8f, 0x4d, 0xd8, 0x79,
		0x9c, 0xd4, 0x35, 0x45, 0xd7, 0x47, 0x1c, 0xed, 0x57, 0x8e, 0xc7, 0x28, 0xb4, 0xb9, 0x39, 0xba,
		0xcd, 0xb1, 0x35, 0xb3, 0xdb, 0x7c, 0xc0, 0x8f, 0xf3, 0x8b, 0xde, 0x12, 0xc8, 0x31, 0xf8, 0xed,
		0xd5, 0xc8, 0xd2, 0x7b, 0xc4, 0x47, 0x5d, 0x0d, 0xc0, 0x18, 0x2e, 0x4c, 0x59, 0xf2, 0xf3, 0xce,
		0xe3, 0xee, 0x59, 0x18, 0x2f, 0xcf, 0x88, 0xc6, 0xcf, 0x59, 0x8e, 0x13, 0xd5, 0x4a, 0xc2, 0x89,
		0x1e, 0xb9, 0x75, 0x20, 0x44, 0x8f, 0xdb, 0x5a, 0x6e, 0xd8, 0xd0, 0x63, 0xb7, 0xdc, 0x75, 0xd0,
		0x9e, 0x5d, 0xd8, 0x3b, 0xfa, 0x19, 0x3c, 0x6c, 0xc9, 0x77, 0xb1, 0xdc, 0x26, 0xb4, 0xb6, 0x19,
		0x6d, 0x6e, 0x4a, 0x81, 0xcd, 0x69, 0x7b, 0x93, 0x8a, 0x6d, 0x56, 0xb1, 0x4d, 0x2b, 0xb3, 0x79,
		0xed, 0x88, 0x96, 0xcb, 0xde, 0x6d, 0x5b, 0x76, 0x53, 0x4f, 0x1f, 0x74, 0x11, 0xf6, 0x7a, 0x51,
		0x72, 0x9e, 0xd9, 0xb3, 0x8f, 0x89, 0x09, 0x4f, 0x9f, 0xfc, 0xd4, 0x6a, 0xa6, 0x64, 0xcd, 0xd2,
		0xe3, 0x6c, 0x97, 0x8b, 0x92, 0x28, 0x0f, 0x25, 0x00, 0x07, 0x52, 0xb0, 0x20, 0x0e, 0x0f, 0xe2,
		0x30, 0x21, 0x0b, 0x17, 0x76, 0x60, 0xc3, 0x12, 0x7c, 0x58, 0x87, 0x91, 0x9b, 0x70, 0x62, 0xdf,
		0xac, 0x6e, 0xa0, 0x8a, 0x6d, 0xa3, 0xb2, 0x0b, 0x2e, 0x62, 0x20, 0x23, 0x09, 0x36, 0x0a, 0xa0,
		0x23, 0x0d, 0x3e, 0x6a, 0x20, 0xa4, 0x06, 0x46, 0x3a, 0xa0, 0x64, 0x17, 0x9c, 0x2c, 0x83, 0x94,
		0x18, 0x58, 0x4d, 0x1f, 0xfc, 0xc8, 0x4b, 0xb1, 0x0f, 0xde, 0x50, 0x8f, 0xba, 0x3c, 0xeb, 0x18,
		0xc2, 0xc4, 0xa1, 0x4c, 0x03, 0xd2, 0x14, 0xa1, 0x4d, 0x0b, 0xe2, 0xd4, 0xa1, 0x4e, 0x1d, 0xf2,
		0x74, 0xa1, 0x4f, 0x06, 0x02, 0x85, 0xa0, 0x50, 0x1c, 0x12, 0xaf, 0xb5, 0x1f, 0x25, 0x2b, 0x9e,
		0xca, 0x43, 0xa3, 0xf1, 0x84, 0x2d, 0x4a, 0xa7, 0x0e, 0xa0, 0x38, 0x64, 0x6a, 0x42, 0xa7, 0x03,
		0x08, 0xd5, 0x86, 0x52, 0x67, 0x90, 0xea, 0x0c, 0x5a, 0xdd, 0x40, 0xac, 0x2c, 0xd4, 0x0a, 0x43,
		0xee, 0x74, 0xc9, 0xc4, 0x6b, 0x1a, 0x2f, 0xec, 0xb8, 0xa8, 0xf7, 0xa5, 0x11, 0x84, 0xed, 0x76,
		0x6a, 0xb2, 0x4c, 0xb1, 0xd1, 0x90, 0x46, 0xe7, 0x3b, 0xf5, 0x8e, 0x77, 0x15, 0xcd, 0x1e, 0xcc,
		0xeb, 0x7f, 0xfd, 0xf8, 0xe9, 0x53, 0xef, 0xdb, 0x9b, 0xab, 0xc1, 0x7f, 0x8f, 0xae, 0x4e, 0xfe,
		0xbe, 0xf1, 0x4b, 0x85, 0x7e, 0x1f, 0xfa, 0xfb, 0xb6, 0x92, 0x65, 0x17, 0x41, 0x1a, 0x26, 0xe7,
		0x26, 0x53, 0x8c, 0x68, 0xae, 0xc7, 0x24, 0xaa, 0x21, 0xaa, 0x21, 0xaa, 0x21, 0xaa, 0x21, 0xaa,
		0xb1, 0x92, 0xfd, 0xf7, 0xe8, 0x80, 0x66, 0x57, 0x27, 0xa0, 0x19, 0xe7, 0x38, 0xb7, 0x82, 0xb0,
		0x15, 0x3f, 0x0f, 0x5b, 0xf1, 0xcc, 0xb7, 0x41, 0x66, 0xf2, 0xec, 0xc6, 0x9f, 0x27, 0x7f, 0x1c,
		0x25, 0x23, 0x8e, 0xff, 0x30, 0xbc, 0xc0, 0x51, 0x54, 0x4f, 0x5e, 0x28, 0x29, 0x45, 0xb8, 0x70,
		0xf9, 0x75, 0x0c, 0x22, 0x9d, 0x02, 0x3f, 0x80, 0xb9, 0xad, 0x51, 0x9a, 0xdb, 0x56, 0x96, 0x5d,
		0x6c, 0x4d, 0xce, 0xe1, 0x27, 0xdf, 0x3c, 0x2a, 0x47, 0xde, 0xdd, 0x3b, 0x97, 0xe8, 0xa6, 0x25,
		0xac, 0x6a, 0xe9, 0xa8, 0x59, 0xf4, 0xd3, 0xf2, 0x2a, 0xae, 0x43, 0xf0, 0x2f, 0x66, 0xdc, 0x46,
		0x27, 0x2d, 0x57, 0x71, 0x99, 0x46, 0x3c, 0xb6, 0x78, 0xcb, 0x63, 0x8c, 0xc9, 0xab, 0xec, 0xfd,
		0x86, 0xbd, 0x4b, 0xe4, 0x9d, 0xdf, 0x70, 0x98, 0x82, 0x1f, 0x76, 0xd7, 0xf1, 0x7d, 0xf8, 0x3e,
		0x7c, 0x9f, 0x17, 0xbe, 0x8f, 0xc3, 0x6e, 0x0f, 0x69, 0x82, 0x1a, 0x5d, 0xd0, 0x84, 0x4e, 0x07,
		0x10, 0xaa, 0x0d, 0xa5, 0xce, 0x20, 0xd5, 0x19, 0xb4, 0xba, 0x81, 0x58, 0x79, 0x99, 0x6d, 0x8d,
		0xc3, 0x6e, 0x8b, 0x01, 0x25, 0x87, 0xdd, 0x1c, 0x76, 0xeb, 0xed, 0x5d, 0x0e, 0xbb, 0x89, 0x6a,
		0x88, 0x6a, 0x88, 0x6a, 0x88, 0x6a, 0x56, 0x23, 0xaa, 0xe1, 0xb0, 0x9b, 0xc3, 0x6e, 0x1f, 0xa4,
		0x94, 0xd5, 0x39, 0xec, 0x16, 0x68, 0xd4, 0x2d, 0xf7, 0xca, 0xfd, 0xbe, 0x7f, 0x37, 0x6e, 0xe4,
		0x2d, 0xa2, 0x5a, 0xc9, 0x74, 0xf4, 0x9e, 0x3e, 0x5d, 0xac, 0xb3, 0xf7, 0xf5, 0x08, 0x8a, 0x1d,
		0xbe, 0xa7, 0x83, 0x8a, 0x74, 0xfa, 0x96, 0x32, 0x1f, 0x61, 0xcc, 0x71, 0x8f, 0x35, 0x15, 0x91,
		0xb3, 0xba, 0x7b, 0x75, 0x97, 0x3d, 0x3c, 0xbf, 0xe8, 0x9d, 0xfe, 0x36, 0x9c, 0xda, 0xe9, 0xfb,
		0xec, 0xe2, 0xf4, 0xf5, 0x78, 0x46, 0x4f, 0xfc, 0x44, 0xa7, 0x2b, 0x5a, 0xd2, 0x4b, 0x1a, 0x24,
		0xed, 0xdf, 0x0b, 0xd9, 0xfe, 0xfd, 0xc6, 0xeb, 0xb4, 0x51, 0xfb, 0xe9, 0x71, 0xf0, 0x41, 0xc3,
		0x79, 0x5f, 0xed, 0x42, 0xa1, 0xe9, 0xfc, 0x8c, 0x2d, 0x54, 0x7c, 0xee, 0x5a, 0x96, 0xe4, 0x26,
		0xed, 0x84, 0xad, 0x25, 0xd4, 0xcd, 0xeb, 0xb3, 0x86, 0xeb, 0x67, 0x51, 0x17, 0x92, 0xba, 0x90,
		0xce, 0x54, 0xb7, 0x82, 0xd5, 0x85, 0x9c, 0x6e, 0x1b, 0x7b, 0xd5, 0x21, 0xaf, 0x1f, 0x49, 0x8d,
		0x48, 0x85, 0x8d, 0x6a, 0x7b, 0xc3, 0x8a, 0x6d, 0x5c, 0xb1, 0x0d, 0x2c, 0xb3, 0x91, 0xfd, 0x08,
		0x80, 0xad, 0xd5, 0x88, 0xb4, 0x5c, 0x1f, 0x49, 0xa6, 0x1e, 0x12, 0xf5, 0x21, 0xa9, 0x0f, 0xb9,
		0x46, 0x7d, 0x48, 0xbb, 0xd2, 0x88, 0xf5, 0xfa, 0x90, 0xcb, 0xf6, 0x37, 0xff, 0xe9, 0x4e, 0x58,
		0xae, 0xef, 0xf9, 0xdd, 0x0b, 0x61, 0x3a, 0x61, 0x3f, 0x1e, 0xbe, 0xf2, 0x4e, 0x18, 0x67, 0x46,
		0xa8, 0xfe, 0x64, 0x95, 0xfa, 0x93, 0xd4, 0x9f, 0xf4, 0x09, 0xec, 0x74, 0x40, 0xcf, 0x2e, 0xf8,
		0x59, 0x06, 0xc1, 0xe9, 0x12, 0x88, 0xa5, 0x0b, 0x58, 0xec, 0x38, 0xff, 0xd3, 0xe8, 0xa8, 0xe6,
		0xeb, 0x91, 0x80, 0xc5, 0xd0, 0xa5, 0x13, 0xc5, 0xb9, 0x49, 0x83, 0xd1, 0xce, 0x13, 0x48, 0x7f,
		0x9b, 0xbe, 0xaf, 0x9b, 0x03, 0xe1, 0x14, 0x70, 0x0a, 0x38, 0x05, 0x9c, 0x82, 0x55, 0x8b, 0x5f,
		0xba, 0x07, 0xe5, 0x4f, 0x7d, 0xc2, 0xb3, 0x15, 0xf0, 0x09, 0x53, 0x65, 0x31, 0x88, 0x04, 0xd9,
		0xc7, 0xdc, 0x28, 0x78, 0x03, 0xbc, 0x01, 0xde, 0x00, 0x6f, 0x50, 0x14, 0x84, 0x59, 0x39, 0x9f,
		0xf0, 0xbf, 0x7d, 0x93, 0x5e, 0x06, 0xc3, 0x15, 0xfd, 0xb2, 0x44, 0x6f, 0xc1, 0x9f, 0xbe, 0xb3,
		0x1b, 0xe3, 0xe0, 0x17, 0xf0, 0x0b, 0xf8, 0x05, 0xfc, 0x82, 0x5d, 0xbf, 0x70, 0x7e, 0xd1, 0x9b,
		0x42, 0x4c, 0x90, 0x0f, 0xc6, 0x93, 0xf3, 0x0e, 0x3b, 0x02, 0x8f, 0xfe, 0x3d, 0x89, 0x86, 0xa9,
		0xd3, 0x95, 0xcc, 0xb4, 0xba, 0x49, 0x5b, 0xe2, 0x02, 0x61, 0xe5, 0x5d, 0x98, 0x9c, 0x1b, 0xb1,
		0x6b, 0xb7, 0x82, 0xf7, 0x28, 0x5e, 0x47, 0x89, 0x42, 0x71, 0x15, 0x9d, 0x2b, 0x95, 0x7f, 0x84,
		0x71, 0xdf, 0xc8, 0xd5, 0xee, 0x99, 0x8e, 0xf3, 0x2a, 0x0d, 0x5b, 0x79, 0xd4, 0x4d, 0x5e, 0x46,
		0xe7, 0x23, 0xcb, 0xaa, 0x16, 0xf2, 0x1a, 0xef, 0xeb, 0xf0, 0x6b, 0xf9, 0x5e, 0x7d, 0xb5, 0xde,
		0x28, 0xd1, 0xdb, 0x2f, 0xc8, 0xed, 0xa2, 0x93, 0x15, 0x08, 0xe9, 0xbf, 0x98, 0x34, 0x93, 0xb8,
		0x61, 0x32, 0xf5, 0xb3, 0x93, 0x01, 0x08, 0xe2, 0x09, 0xe2, 0x09, 0xe2, 0x09, 0xe2, 0xed, 0x07,
		0xf1, 0x32, 0x08, 0x33, 0x8b, 0x32, 0x4d, 0x42, 0x6b, 0x42, 0x6b, 0x42, 0xeb, 0x52, 0x86, 0xd6,
		0xdb, 0xc4, 0xd5, 0xc4, 0xd5, 0x36, 0x9f, 0xc4, 0x2d, 0xdb, 0xf3, 0x8b, 0xde, 0xd6, 0xf5, 0x15,
		0xb1, 0xeb, 0x6f, 0xad, 0x36, 0x52, 0xb0, 0x70, 0xdb, 0xf6, 0xa9, 0x8d, 0x4c, 0xff, 0xfe, 0xe0,
		0xd3, 0x65, 0x12, 0xb9, 0xfe, 0xe3, 0x27, 0x93, 0xed, 0xef, 0x21, 0x31, 0x22, 0xdb, 0xdf, 0x0d,
		0xf1, 0x29, 0x79, 0xb6, 0xff, 0xff, 0xf6, 0x4d, 0x1a, 0x49, 0x26, 0x60, 0x4e, 0x06, 0x90, 0x51,
		0x63, 0x6a, 0xa8, 0x31, 0xa8, 0x31, 0xa8, 0x31, 0x7e, 0xaa, 0x31, 0x52, 0xd5, 0xe0, 0x2b, 0xa9,
		0x69, 0x99, 0xe8, 0x8b, 0xc0, 0x1d, 0xa5, 0x85, 0x2d, 0x35, 0x1d, 0xa9, 0xe0, 0x4d, 0x32, 0x68,
		0x10, 0xe5, 0x03, 0xcc, 0xa9, 0xc3, 0x9d, 0x3a, 0xec, 0xe9, 0xc2, 0x9f, 0xb0, 0x0c, 0x51, 0xd8,
		0x26, 0x19, 0xa2, 0xdd, 0x83, 0x16, 0xf6, 0xa5, 0x64, 0x17, 0x21, 0x25, 0xa0, 0x5c, 0x04, 0xcc,
		0x3a, 0xc5, 0xa4, 0x0b, 0x00, 0xa4, 0xce, 0x00, 0xd5, 0x19, 0xb0, 0xba, 0x01, 0x58, 0x59, 0xa0,
		0x15, 0x06, 0x5c, 0x35, 0xe0, 0x9d, 0x0e, 0xf4, 0xa5, 0xa6, 0x67, 0xf9, 0xd3, 0xac, 0x87, 0x9a,
		0x96, 0xc9, 0xeb, 0x1c, 0x97, 0xa8, 0xc5, 0xb0, 0x2e, 0xa1, 0xd9, 0x21, 0x44, 0xbb, 0x82, 0x6a,
		0xe7, 0x90, 0xed, 0x1c, 0xba, 0xdd, 0x42, 0xb8, 0x0e, 0x94, 0x2b, 0x41, 0xfa, 0x74, 0x29, 0xd5,
		0xfa, 0x04, 0x2c, 0xec, 0xd8, 0x7e, 0x94, 0xe4, 0xdb, 0x75, 0xcd, 0x0d, 0x3b, 0xc6, 0xdf, 0x5d,
		0xc5, 0x21, 0x65, 0x53, 0x47, 0xee, 0xfa, 0xd2, 0x05, 0xa4, 0x35, 0xad, 0x54, 0x13, 0x4f, 0x1c,
		0xeb, 0xc2, 0xf0, 0x93, 0xfc, 0x04, 0x57, 0xe3, 0x2b, 0xe6, 0x2d, 0x38, 0x86, 0xab, 0x79, 0x93,
		0x0b, 0xbf, 0xae, 0xbc, 0xc9, 0x35, 0xea, 0x7b, 0x8d, 0xbd, 0x9d, 0xdd, 0xfa, 0x5e, 0x73, 0x85,
		0x6d, 0xef, 0x49, 0x39, 0x47, 0x3b, 0x79, 0x52, 0x8e, 0xcf, 0xa3, 0x80, 0x0d, 0x95, 0x2f, 0x75,
		0x07, 0xc4, 0xb1, 0x0e, 0x71, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x10, 0x47, 0x88, 0x23, 0xc4,
		0x11, 0xe2, 0x08, 0x71, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x10, 0xc7, 0xe2, 0x10, 0xc7, 0x6d,
		0x07, 0xc4, 0x71, 0x1b, 0xe2, 0x08, 0x71, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x10, 0x47, 0x88,
		0x23, 0xc4, 0x11, 0xe2, 0x08, 0x71, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x05, 0x18, 0x41, 0x3a,
		0xdb, 0x56, 0xb8, 0x99, 0xfc, 0xc2, 0x78, 0x4e, 0xab, 0x0c, 0x8c, 0x6e, 0xce, 0x6f, 0x8d, 0x2f,
		0xbb, 0x6e, 0x4d, 0xae, 0x8d, 0x6d, 0x8d, 0xee, 0x46, 0x3c, 0x29, 0xa6, 0x95, 0x14, 0xeb, 0x5a,
		0x8d, 0x92, 0xbd, 0x79, 0x69, 0x67, 0x92, 0x77, 0xe2, 0x1e, 0xd2, 0x94, 0xfa, 0x70, 0x32, 0xd5,
		0xd3, 0x5f, 0xc7, 0x53, 0x3d, 0xfd, 0xff, 0x8f, 0xa6, 0x7a, 0xfa, 0x6e, 0x32, 0xd5, 0x82, 0x94,
		0x8c, 0x11, 0x30, 0xd3, 0x4a, 0x36, 0xa2, 0xde, 0xc2, 0x77, 0x56, 0x87, 0xa3, 0x70, 0x5f, 0xd5,
		0x95, 0xd2, 0xc6, 0x7d, 0xd5, 0x02, 0x2a, 0x65, 0xdc, 0x57, 0xbd, 0x7b, 0x69, 0xb8, 0xaf, 0xea,
		0x1d, 0x50, 0x2e, 0x02, 0x26, 0xf7, 0x55, 0x8b, 0x00, 0xa4, 0xce, 0x00, 0xd5, 0x19, 0xb0, 0xba,
		0x01, 0xd8, 0x72, 0x30, 0x68, 0xee, 0xab, 0xda, 0x84, 0x62, 0x4e, 0x8f, 0x0b, 0x0d, 0xd1, 0xae,
		0xa0, 0xda, 0x39, 0x64, 0x3b, 0x87, 0x6e, 0xb7, 0x10, 0xae, 0x03, 0xe5, 0x4a, 0x90, 0x3e, 0x5d,
		0x4a, 0x4e, 0x8f, 0x45, 0x87, 0xe4, 0xf4, 0xb8, 0x7c, 0x8e, 0x75, 0x61, 0x78, 0x4e, 0x8f, 0x39,
		0x3d, 0x76, 0x64, 0x72, 0x9c, 0x1e, 0x73, 0x7a, 0xec, 0xfb, 0xe7, 0xe1, 0xbe, 0x2a, 0xc4, 0x11,
		0xe2, 0x08, 0x71, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x10, 0x47, 0x88, 0x23, 0xc4, 0x11, 0xe2,
		0x08, 0x71, 0x84, 0x38, 0x42, 0x1c, 0xdd, 0x13, 0x47, 0xee, 0xab, 0x42, 0x1c, 0x21, 0x8e, 0x10,
		0x47, 0x88, 0x23, 0xc4, 0x11, 0xe2, 0x08, 0x71, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x10, 0x47,
		0x88, 0x63, 0x81, 0x89, 0x23, 0xf7, 0x55, 0x1f, 0x30, 0x9e, 0x4f, 0xf7, 0x08, 0x33, 0x93, 0xe4,
		0xdc, 0x55, 0x55, 0xb3, 0xb9, 0x95, 0xbc, 0xab, 0x2a, 0x78, 0x2d, 0x71, 0xcd, 0xe2, 0x3d, 0xd5,
		0xf7, 0x83, 0x69, 0x16, 0xe5, 0x8e, 0xaa, 0xd7, 0xed, 0x5f, 0x85, 0x8d, 0xdc, 0x27, 0xe3, 0x96,
		0x68, 0xb9, 0x6c, 0xc7, 0x9e, 0xed, 0x9a, 0xb2, 0x3d, 0x83, 0xb3, 0x68, 0x6c, 0x95, 0xd4, 0xf4,
		0xba, 0x69, 0x2e, 0xd8, 0xc3, 0x7c, 0x32, 0x00, 0x3d, 0xcc, 0xe9, 0x61, 0xfe, 0x83, 0xd7, 0x49,
		0x0f, 0xf3, 0xf2, 0x39, 0x31, 0xb1, 0x1e, 0xe6, 0xb2, 0x97, 0x9e, 0x55, 0x2e, 0x3b, 0xab, 0x55,
		0x83, 0xa8, 0x53, 0x0d, 0xc2, 0x03, 0x80, 0x53, 0x07, 0x3a, 0x75, 0xc0, 0xd3, 0x05, 0xbe, 0x62,
		0x52, 0x57, 0xf1, 0x6a, 0x10, 0x0a, 0x97, 0x91, 0xf5, 0x2e, 0x21, 0x2b, 0xc9, 0xc7, 0x6a, 0x29,
		0x00, 0xd4, 0x81, 0x28, 0x36, 0x94, 0x3a, 0x83, 0x54, 0x37, 0xd0, 0x2a, 0xaf, 0x3b, 0xae, 0x29,
		0x28, 0xd3, 0x6a, 0x47, 0xf7, 0xfa, 0x47, 0xf6, 0x8a, 0x47, 0xf5, 0xca, 0x47, 0xf4, 0x8a, 0x89,
		0x16, 0x2e, 0x8e, 0xe4, 0x1d, 0x9d, 0x8b, 0xba, 0x3a, 0x82, 0x77, 0x79, 0xfc, 0xa9, 0x78, 0xe4,
		0xee, 0xe4, 0xa8, 0xdd, 0xb5, 0x29, 0xb9, 0x3a, 0x5a, 0x77, 0x6a, 0x53, 0x25, 0x39, 0x72, 0x3e,
		0x29, 0xea, 0x71, 0xa5, 0xa0, 0x0c, 0xa0, 0x70, 0x29, 0x57, 0xef, 0x32, 0x2e, 0x04, 0x0a, 0x02,
		0x05, 0x81, 0x82, 0x40, 0x41, 0xa0, 0x20, 0x50, 0x10, 0x28, 0x08, 0x14, 0x04, 0x0a, 0x02, 0x05,
		0x81, 0x82, 0x40, 0x89, 0x12, 0xa8, 0x6d, 0x45, 0x02, 0xb5, 0x0d, 0x81, 0x82, 0x40, 0x41, 0xa0,
		0x20, 0x50, 0x10, 0x28, 0x08, 0x14, 0x04, 0x0a, 0x02, 0x05, 0x81, 0x82, 0x40, 0x41, 0xa0, 0x20,
		0x50, 0xd2, 0x04, 0x8a, 0x0b, 0x73, 0xb7, 0x8c, 0xe3, 0xc3, 0x9d, 0xa2, 0xf1, 0x6d, 0x13, 0xc9,
		0xfb, 0x98, 0x5c, 0x45, 0x2b, 0xad, 0xd9, 0x78, 0x78, 0x15, 0xed, 0xdd, 0x78, 0x66, 0xbe, 0x5e,
		0x45, 0x7b, 0xe2, 0x91, 0xc9, 0x4a, 0x99, 0xaa, 0x0f, 0x26, 0x6a, 0xd1, 0x34, 0x97, 0x34, 0x49,
		0x3b, 0xa6, 0xb8, 0xbc, 0xe1, 0x58, 0x30, 0x9a, 0xca, 0x74, 0x9d, 0x83, 0xa8, 0x6d, 0xcd, 0x64,
		0xa6, 0x3c, 0x7c, 0xee, 0xe9, 0x96, 0x4c, 0xdc, 0x6e, 0xb4, 0x6d, 0x5d, 0x79, 0x94, 0x50, 0x18,
		0x05, 0x95, 0x44, 0x29, 0xc5, 0x50, 0x5c, 0x19, 0x14, 0x57, 0x00, 0x65, 0x95, 0x3e, 0xbf, 0xdc,
		0x86, 0x75, 0x85, 0x6e, 0x6a, 0xb1, 0xb1, 0x09, 0x3b, 0xa9, 0xe9, 0xd8, 0xb4, 0xd8, 0xc9, 0xbd,
		0x41, 0x8b, 0x9a, 0x5b, 0xe5, 0x78, 0xec, 0xd9, 0x36, 0x37, 0x47, 0x81, 0xf3, 0xd6, 0x1c, 0x72,
		0x95, 0x12, 0xef, 0x07, 0x6f, 0x45, 0x10, 0xf0, 0xed, 0xbd, 0x74, 0xcb, 0x17, 0x45, 0x8b, 0x87,
		0xf8, 0x1d, 0xf0, 0xde, 0x05, 0xde, 0x77, 0xca, 0x8a, 0xf6, 0xb6, 0x2f, 0x61, 0x56, 0x5a, 0x93,
		0x1d, 0x25, 0x54, 0x41, 0x63, 0xfc, 0x7c, 0x0a, 0x68, 0xa8, 0x14, 0xd0, 0xe8, 0x50, 0x3e, 0xc3,
		0x21, 0x0c, 0x69, 0xc0, 0x51, 0x31, 0x64, 0x37, 0xb1, 0xe2, 0x19, 0xd3, 0x20, 0x45, 0xbe, 0x80,
		0xc6, 0xf5, 0x50, 0xb2, 0x45, 0x34, 0xaa, 0xd2, 0x45, 0x34, 0xaa, 0x25, 0x29, 0xa2, 0xd1, 0xa1,
		0x84, 0x86, 0xc7, 0xa0, 0xa7, 0x09, 0x7e, 0x32, 0x20, 0x28, 0x04, 0x86, 0x72, 0x4c, 0x5d, 0x91,
		0xb9, 0x6b, 0x30, 0xf9, 0x3b, 0x99, 0xfd, 0xd6, 0xd0, 0x8c, 0x9e, 0xcf, 0x48, 0xcc, 0x37, 0x7e,
		0x30, 0xfe, 0xf3, 0x50, 0x14, 0x2e, 0xca, 0xb1, 0x99, 0xc4, 0x69, 0x4d, 0xff, 0x4c, 0xd1, 0x3f,
		0xce, 0x8d, 0x86, 0x8b, 0xc4, 0x45, 0xe2, 0x22, 0x71, 0x91, 0xb8, 0x48, 0x4f, 0x5d, 0xe4, 0xc7,
		0x6b, 0x17, 0xf9, 0x7f, 0x5a, 0xfd, 0x34, 0x35, 0x49, 0xbe, 0xbe, 0xb1, 0xb5, 0xb9, 0x79, 0xad,
		0x96, 0x9f, 0x8c, 0x7f, 0x65, 0x16, 0xd7, 0xb3, 0x5b, 0x7e, 0x36, 0x7d, 0x72, 0xdb, 0x7c, 0x25,
		0x49, 0xc5, 0xc6, 0x4b, 0x3c, 0xf8, 0x3a, 0x4c, 0xc1, 0xb3, 0x9f, 0x1c, 0x2c, 0x2f, 0xd8, 0x74,
		0x5b, 0x81, 0xf9, 0x9a, 0x3f, 0xcf, 0x4d, 0x6c, 0x2e, 0x4c, 0x9e, 0x5e, 0x06, 0xdd, 0x24, 0x68,
		0x7d, 0x1e, 0x66, 0x3b, 0xab, 0x88, 0x38, 0x9d, 0x30, 0xce, 0x34, 0x54, 0x1c, 0xdf, 0x05, 0x9c,
		0x13, 0xf2, 0xa6, 0xee, 0x9b, 0x94, 0x32, 0x77, 0xce, 0xb5, 0x35, 0xd6, 0xa7, 0x57, 0xa0, 0x58,
		0xb6, 0x4c, 0xdd, 0x59, 0xd1, 0x7a, 0xb3, 0xe2, 0x3a, 0x7f, 0x1d, 0x9d, 0x5f, 0x2d, 0xbe, 0x47,
		0xe7, 0x2f, 0x5f, 0xe4, 0x82, 0xce, 0x8f, 0x88, 0x81, 0x88, 0x81, 0x88, 0x81, 0x88, 0x81, 0x88,
		0xa1, 0x20, 0x62, 0xa0, 0xf3, 0xaf, 0xa1, 0xf3, 0xe3, 0x22, 0x71, 0x91, 0xb8, 0x48, 0x5c, 0x24,
		0x2e, 0x12, 0x9d, 0xbf, 0x58, 0x6c, 0x79, 0x65, 0x44, 0x55, 0x81, 0x0b, 0xcc, 0xdc, 0xfa, 0x2c,
		0xa6, 0x2d, 0xb8, 0xbf, 0xfa, 0x39, 0xfd, 0xee, 0x9d, 0xe9, 0x94, 0xe9, 0x3a, 0xd0, 0x85, 0xb9,
		0x38, 0x33, 0x69, 0xf6, 0x39, 0xea, 0x05, 0xe7, 0x69, 0xb7, 0xdf, 0xcb, 0xec, 0x5f, 0x09, 0x5a,
		0x1c, 0x82, 0x6b, 0x41, 0x56, 0xe2, 0x77, 0x2e, 0x82, 0xea, 0x44, 0xe4, 0xab, 0x74, 0x11, 0xd4,
		0xfa, 0xd5, 0xa0, 0xe1, 0x96, 0x97, 0x3b, 0x30, 0x1c, 0x3d, 0x9e, 0x03, 0x43, 0x3a, 0xeb, 0xba,
		0x97, 0x08, 0xe8, 0xac, 0xab, 0x48, 0x83, 0xc4, 0x0e, 0x0d, 0x65, 0x00, 0x4b, 0x05, 0xb8, 0x6e,
		0x02, 0x18, 0x4a, 0xa8, 0x53, 0x60, 0xd3, 0x02, 0x38, 0x75, 0xa0, 0x53, 0x07, 0x3c, 0x5d, 0xe0,
		0x93, 0x53, 0x96, 0xd6, 0x50, 0x43, 0x1f, 0x16, 0x81, 0x69, 0xa8, 0xa1, 0xd3, 0x92, 0x1f, 0x23,
		0x48, 0x5e, 0xe5, 0x23, 0x41, 0x9a, 0xca, 0xbb, 0x8a, 0xe1, 0x71, 0x7d, 0xb8, 0x3e, 0x5c, 0x9f,
		0x67, 0x5c, 0x40, 0x89, 0x13, 0xa8, 0x72, 0x03, 0x25, 0x8e, 0xa0, 0xc6, 0x15, 0x34, 0x81, 0xd3,
		0x01, 0x80, 0x6a, 0x03, 0xa9, 0x33, 0x40, 0x75, 0x06, 0xac, 0x6e, 0x00, 0x56, 0x16, 0x68, 0x85,
		0x01, 0x57, 0x8f, 0x73, 0x2c, 0xec, 0xb8, 0xa8, 0xf7, 0xa5, 0x11, 0x84, 0xed, 0x76, 0x6a, 0xb2,
		0x4c, 0xb1, 0xbd, 0x47, 0xed, 0x99, 0xc2, 0x58, 0xc7, 0x61, 0x9e, 0x9b, 0x34, 0x51, 0xeb, 0xf0,
		0x51, 0x59, 0x5f, 0xff, 0x58, 0x0d, 0xf6, 0x4e, 0xbe, 0x7f, 0xac, 0x05, 0x7b, 0x27, 0xa3, 0x6f,
		0x6b, 0xc3, 0xff, 0x1b, 0x7d, 0x5f, 0xff, 0x58, 0x0d, 0x1a, 0x93, 0xef, 0x9b, 0x1f, 0xab, 0x41,
		0xf3, 0x64, 0xe3, 0xd3, 0xa7, 0xcd, 0x8d, 0x6f, 0xdb, 0x57, 0x0f, 0xff, 0xc5, 0xf5, 0xbf, 0x7e,
		0xfc, 0xf4, 0xa9, 0xf7, 0xed, 0xcd, 0xd5, 0xe0, 0xbf, 0x47, 0x57, 0x27, 0x7f, 0xdf, 0xf8, 0xa5,
		0x42, 0x75, 0x7d, 0xfd, 0x7d, 0x5b, 0x19, 0x15, 0xfa, 0x36, 0xa9, 0x5e, 0x38, 0x33, 0x1d, 0x91,
		0x88, 0x86, 0x88, 0x86, 0x88, 0x86, 0x88, 0x86, 0x88, 0x86, 0x88, 0x86, 0x88, 0x86, 0x88, 0xc6,
		0xd2, 0x4b, 0xcf, 0x94, 0x34, 0xc6, 0xa9, 0x7e, 0x3d, 0x1a, 0x8f, 0x68, 0x86, 0x68, 0x86, 0x68,
		0x86, 0x68, 0x86, 0x68, 0x86, 0x68, 0x86, 0x68, 0x66, 0xb5, 0xa2, 0x19, 0xba, 0x1f, 0xde, 0x16,
		0x87, 0xb9, 0xbb, 0x2d, 0xb2, 0x70, 0xc7, 0x60, 0x94, 0xcc, 0x41, 0x13, 0x44, 0xab, 0x01, 0x87,
		0x58, 0xc2, 0xf5, 0x51, 0x94, 0xe5, 0xfb, 0x79, 0x2e, 0x94, 0xd1, 0xf9, 0x3a, 0x4a, 0x0e, 0x62,
		0x33, 0x08, 0x1d, 0x32, 0x99, 0x38, 0xb7, 0xf2, 0x3a, 0xfc, 0x3a, 0x33, 0x42, 0xed, 0x59, 0xa3,
		0xb1, 0xb3, 0xdb, 0x68, 0x54, 0x77, 0xb7, 0x77, 0xab, 0x7b, 0xcd, 0x66, 0x6d, 0xa7, 0x26, 0xd0,
		0x99, 0xb7, 0xf2, 0x36, 0x6d, 0x9b, 0xd4, 0xb4, 0x5f, 0x0c, 0x5e, 0x4b, 0xd2, 0x8f, 0x63, 0x6e,
		0x2d, 0x7a, 0x85, 0x3d, 0xfe, 0x74, 0xd2, 0xfc, 0xcd, 0x7e, 0x5e, 0x1b, 0x17, 0x29, 0x8b, 0x6b,
		0x9e, 0x65, 0xba, 0xbe, 0x68, 0x37, 0x63, 0x51, 0x24, 0x43, 0x51, 0xec, 0x9a, 0x62, 0x9d, 0x6b,
		0x8a, 0x45, 0x12, 0x54, 0xb8, 0xa6, 0xe8, 0xf3, 0x35, 0x45, 0x93, 0x84, 0x67, 0xb1, 0x69, 0xcb,
		0x5d, 0x54, 0x9c, 0x0c, 0x60, 0xfb, 0x1a, 0x94, 0xe9, 0x84, 0xfd, 0x78, 0xf8, 0xca, 0x87, 0x55,
		0x8c, 0x85, 0xae, 0x42, 0x56, 0xe9, 0x91, 0xc6, 0x55, 0x48, 0x9f, 0xc0, 0x4e, 0x07, 0xf4, 0x8a,
		0xc1, 0xcc, 0xc5, 0x54, 0xde, 0xa9, 0xc5, 0x9f, 0x75, 0xbb, 0xb1, 0x09, 0x13, 0x09, 0x8b, 0x9f,
		0x44, 0x47, 0xb5, 0x15, 0x28, 0x9e, 0xdd, 0x89, 0xe2, 0xdc, 0xa4, 0xc1, 0x68, 0xe7, 0x99, 0x4c,
		0xce, 0xd9, 0xdc, 0x1c, 0x08, 0xa7, 0x80, 0x53, 0xc0, 0x29, 0xe0, 0x14, 0x2c, 0x93, 0xe4, 0x34,
		0x4a, 0xce, 0x25, 0x7d, 0xc2, 0xb3, 0x15, 0xf0, 0x09, 0x73, 0x7d, 0xe6, 0xc5, 0x1c, 0xc2, 0xdc,
		0x28, 0x78, 0x03, 0xbc, 0x01, 0xde, 0x00, 0x6f, 0x50, 0x14, 0x84, 0x59, 0x39, 0x9f, 0xf0, 0xbf,
		0x7d, 0x93, 0x5e, 0x06, 0xe6, 0x6b, 0x2f, 0x4a, 0x25, 0x59, 0xc2, 0xfc, 0x30, 0x78, 0x05, 0xbc,
		0x02, 0x5e, 0x01, 0xaf, 0x60, 0xd5, 0xe2, 0xf3, 0xe8, 0xc2, 0xe4, 0x51, 0xeb, 0xcf, 0x6c, 0xa7,
		0x21, 0xe8, 0x14, 0x04, 0x92, 0xff, 0x2a, 0xbf, 0x27, 0xd1, 0x30, 0x99, 0xa3, 0x92, 0x84, 0x49,
		0x37, 0x33, 0xad, 0x6e, 0xd2, 0x96, 0x48, 0x68, 0xac, 0xbc, 0x1b, 0xb6, 0x39, 0x94, 0x4a, 0x29,
		0x14, 0xcc, 0xf6, 0x7a, 0x1d, 0x25, 0x0a, 0x65, 0x3d, 0x74, 0x92, 0xe0, 0xff, 0x08, 0xe3, 0xbe,
		0x51, 0x18, 0xe7, 0x55, 0x1a, 0xb6, 0xf2, 0xa8, 0x9b, 0xbc, 0x8c, 0xce, 0x47, 0xd6, 0x55, 0x2d,
		0xe4, 0x85, 0x8b, 0xd7, 0xe1, 0xd7, 0xd2, 0xbd, 0x7a, 0x9d, 0xa4, 0x2d, 0x67, 0xd6, 0x50, 0x90,
		0x14, 0xc8, 0x93, 0x95, 0x89, 0xee, 0x87, 0x7c, 0xe9, 0x4b, 0x18, 0x4b, 0x87, 0xf7, 0xd3, 0x71,
		0x88, 0xef, 0x89, 0xef, 0x89, 0xef, 0x89, 0xef, 0xed, 0xaa, 0x3e, 0xe7, 0x17, 0xbd, 0x29, 0xc4,
		0x04, 0xf9, 0x60, 0x3c, 0xb9, 0x30, 0x7f, 0x47, 0x32, 0xcc, 0x27, 0xc4, 0x5f, 0x8d, 0x10, 0xbf,
		0x46, 0x88, 0xbf, 0xb2, 0x21, 0x7e, 0xb5, 0xde, 0x20, 0xa4, 0x27, 0xa4, 0xb7, 0x1f, 0xd2, 0x7f,
		0x31, 0x69, 0x26, 0x71, 0xb5, 0x65, 0xea, 0x67, 0x27, 0x03, 0x10, 0xc4, 0x13, 0xc4, 0x13, 0xc4,
		0x13, 0xc4, 0xdb, 0x0f, 0xe2, 0x65, 0x10, 0x66, 0x16, 0x65, 0x9a, 0x84, 0xd6, 0x84, 0xd6, 0x84,
		0xd6, 0xa5, 0x0c, 0xad, 0xb7, 0x89, 0xab, 0x89, 0xab, 0x6d, 0x3e, 0x89, 0x0b, 0xbd, 0x77, 0x5e,
		0xe8, 0xb5, 0x58, 0xd3, 0xc2, 0xc2, 0x25, 0xde, 0x27, 0x0e, 0xdf, 0xf2, 0xa4, 0x26, 0x85, 0xc5,
		0xdc, 0x33, 0xbb, 0xa5, 0x28, 0xec, 0x97, 0x9e, 0x50, 0x29, 0x35, 0x61, 0xb7, 0xb4, 0xc4, 0xb2,
		0x2f, 0xd9, 0xf2, 0x16, 0x76, 0xb8, 0x75, 0x2b, 0x56, 0x6e, 0xbc, 0x3f, 0xa2, 0x04, 0xc4, 0x72,
		0x68, 0xf1, 0xf8, 0x3d, 0xfe, 0xb8, 0xdf, 0x7c, 0xa4, 0xc1, 0xd8, 0x32, 0x14, 0x75, 0x03, 0x79,
		0xdc, 0xdb, 0x79, 0xf8, 0xda, 0x3e, 0xec, 0x37, 0x1e, 0xf8, 0x16, 0x96, 0x5d, 0x7d, 0x9d, 0x55,
		0x7f, 0xc4, 0x0e, 0x7c, 0xc8, 0x8e, 0x7b, 0xd8, 0x9b, 0xbc, 0xff, 0xfb, 0x78, 0xc0, 0xbb, 0xa8,
		0x44, 0x59, 0xf4, 0xf0, 0x9c, 0xe1, 0x6b, 0x2d, 0x60, 0xf0, 0xdb, 0x0f, 0x7c, 0xf3, 0x8f, 0x2b,
		0x70, 0xf1, 0x68, 0x95, 0x70, 0x19, 0x15, 0x70, 0x4e, 0xe5, 0x7b, 0xf8, 0x47, 0xb5, 0xa1, 0xe2,
		0x59, 0x53, 0xe9, 0xac, 0xa9, 0x70, 0x0b, 0x2a, 0xdb, 0x60, 0x61, 0x3c, 0x43, 0x97, 0xc7, 0x16,
		0x7c, 0xa8, 0x9c, 0xc7, 0xdd, 0xb3, 0x25, 0xb2, 0x6c, 0xae, 0x7b, 0x32, 0x8d, 0x9e, 0xf3, 0xc8,
		0x15, 0x5e, 0xae, 0x06, 0xcc, 0xd2, 0x82, 0xba, 0x0d, 0xe1, 0xdc, 0xc2, 0xd6, 0xb1, 0xb5, 0x85,
		0xac, 0x6f, 0x25, 0xeb, 0x5b, 0xca, 0xee, 0xd6, 0x72, 0x13, 0x4e, 0x2d, 0x5b, 0x63, 0xa5, 0x12,
		0x76, 0xa2, 0x20, 0x0b, 0x3b, 0xd1, 0xf2, 0xef, 0x79, 0x62, 0x7a, 0xd3, 0x27, 0x2e, 0xcb, 0x1b,
		0xad, 0x94, 0x64, 0xb2, 0x76, 0xce, 0x65, 0xf3, 0x5c, 0xcb, 0xe2, 0x36, 0xb5, 0xbd, 0x5d, 0xc5,
		0xb6, 0xad, 0xd8, 0xf6, 0x95, 0xd9, 0xc6, 0x7e, 0x68, 0x27, 0xb6, 0x4a, 0x28, 0x55, 0xc2, 0x8e,
		0xfd, 0x02, 0x6c, 0x61, 0xc7, 0xf7, 0xea, 0x6b, 0xd5, 0x82, 0x54, 0x5f, 0xb3, 0x03, 0x01, 0x52,
		0x50, 0x20, 0x0e, 0x09, 0xe2, 0xd0, 0x20, 0x0b, 0x11, 0xf6, 0x84, 0xda, 0x35, 0x9f, 0xab, 0xaf,
		0x0d, 0xfc, 0xfa, 0x98, 0x60, 0x0b, 0x25, 0xd0, 0x4c, 0x47, 0x20, 0x83, 0x46, 0x25, 0x83, 0xc6,
		0x2e, 0xec, 0x48, 0xc3, 0x8f, 0x1a, 0x0c, 0xa9, 0xc1, 0x91, 0x0e, 0x2c, 0xd9, 0x85, 0x27, 0xcb,
		0x30, 0x35, 0x5d, 0x02, 0xf9, 0x0c, 0x9a, 0xd8, 0x84, 0x9d, 0xd4, 0x74, 0x24, 0xeb, 0x1e, 0xec,
		0x0a, 0x3c, 0xfb, 0x78, 0x2c, 0xb6, 0x6e, 0x6e, 0x8e, 0x0e, 0x15, 0xb7, 0xa6, 0x28, 0xb9, 0x02,
		0x39, 0x9b, 0xad, 0x09, 0xc4, 0x0a, 0x79, 0x9c, 0xf1, 0xf3, 0x65, 0xfc, 0x4d, 0x0d, 0x7f, 0x83,
		0xbf, 0xc1, 0xdf, 0xf8, 0xe9, 0x6f, 0x6c, 0x87, 0xc7, 0xf2, 0x61, 0xb2, 0x56, 0xb8, 0x2c, 0x1c,
		0x36, 0x8b, 0xc3, 0x99, 0x06, 0xac, 0x29, 0xc2, 0x9b, 0x16, 0xcc, 0xa9, 0xc3, 0x9d, 0x3a, 0xec,
		0xe9, 0xc2, 0x9f, 0x0c, 0x0c, 0x0a, 0xc1, 0xa1, 0x7c, 0x18, 0xbe, 0xb0, 0x63, 0xa2, 0xb6, 0x49,
		0xf2, 0x28, 0xbf, 0x94, 0x09, 0xc9, 0x17, 0x62, 0x31, 0xc1, 0x3a, 0x11, 0x95, 0xc3, 0xf1, 0x47,
		0x79, 0x11, 0x66, 0x8a, 0x1d, 0x4e, 0xf7, 0x5f, 0x1d, 0x9e, 0x7e, 0xf8, 0xd7, 0xf1, 0x41, 0x45,
		0x23, 0x7d, 0x38, 0x53, 0x69, 0xa8, 0xa7, 0xd4, 0x96, 0x73, 0xb2, 0x82, 0x87, 0xc7, 0x7f, 0x34,
		0x14, 0xba, 0x53, 0x3e, 0x2d, 0xe1, 0xba, 0xed, 0x14, 0xbd, 0xab, 0xe7, 0xc9, 0xca, 0xe7, 0xa6,
		0x0b, 0xd8, 0xa5, 0x58, 0x87, 0x8e, 0x05, 0x13, 0x94, 0xe9, 0xd4, 0x41, 0xe8, 0x4b, 0xe8, 0x4b,
		0xe8, 0x4b, 0xe8, 0x2b, 0xbc, 0x63, 0xe4, 0x3a, 0x75, 0x2c, 0x84, 0xbd, 0xb5, 0x15, 0x76, 0x46,
		0x17, 0x26, 0x4f, 0xa3, 0x96, 0xbc, 0x2f, 0x1a, 0x8f, 0x23, 0x64, 0x96, 0x33, 0xcd, 0xa3, 0x6a,
		0x55, 0xfc, 0x1d, 0xfe, 0x0e, 0x7f, 0x87, 0xbf, 0x2b, 0x96, 0xbf, 0xeb, 0x47, 0x49, 0xbe, 0x5d,
		0x57, 0x70, 0x77, 0xbb, 0x82, 0x43, 0xc8, 0x56, 0x31, 0xd0, 0x63, 0xf2, 0x2a, 0x55, 0x0d, 0x94,
		0x1c, 0xcb, 0xc2, 0x70, 0x4a, 0x35, 0x82, 0xa7, 0xe3, 0x29, 0x5e, 0x79, 0x57, 0x94, 0x93, 0x54,
		0xaa, 0x1f, 0xb8, 0x36, 0x91, 0x46, 0x7d, 0xaf, 0xb1, 0xb7, 0xb3, 0x5b, 0xdf, 0x6b, 0x96, 0xd8,
		0x56, 0x9e, 0x14, 0xf3, 0xe9, 0x27, 0x2b, 0xcc, 0x5a, 0x32, 0xbd, 0x03, 0xe4, 0x8c, 0x13, 0x64,
		0x68, 0x05, 0xb4, 0x02, 0x5a, 0x51, 0x4c, 0x5a, 0xc1, 0x09, 0xf2, 0x92, 0x0b, 0xf8, 0x9e, 0x23,
		0xe4, 0x65, 0x97, 0xf0, 0xf7, 0x37, 0x87, 0xbf, 0xee, 0xbf, 0xff, 0xc0, 0x29, 0xf2, 0xc3, 0x97,
		0xee, 0xf5, 0xef, 0x47, 0x1f, 0xb4, 0x16, 0x8f, 0xa3, 0x64, 0xd9, 0x38, 0xd8, 0xeb, 0x54, 0x4f,
		0xa1, 0xf2, 0x62, 0xd7, 0x11, 0xbb, 0x78, 0x51, 0x94, 0x2c, 0xca, 0xb6, 0x46, 0xb5, 0x0d, 0xb6,
		0x26, 0xb7, 0xab, 0xb7, 0xc2, 0xce, 0xd6, 0x38, 0x7b, 0x7d, 0x05, 0xee, 0x01, 0x5c, 0xf4, 0xe3,
		0x3c, 0x0a, 0xf2, 0x6e, 0xaf, 0x1b, 0x77, 0xcf, 0x2f, 0xe5, 0xee, 0x03, 0xdc, 0x18, 0x87, 0x7b,
		0x01, 0xdc, 0x0b, 0x70, 0x4f, 0x73, 0xb8, 0x17, 0xa0, 0xe8, 0x2c, 0xc4, 0xee, 0x05, 0x08, 0x5d,
		0x65, 0x5a, 0xd8, 0x50, 0x22, 0x57, 0x9a, 0x84, 0x21, 0x0c, 0x45, 0x07, 0x45, 0x07, 0x45, 0xc7,
		0x57, 0x45, 0x47, 0x0a, 0x12, 0xa7, 0x03, 0x88, 0x2b, 0xde, 0x0b, 0x5b, 0x53, 0x58, 0xf8, 0xbe,
		0x09, 0x97, 0xd2, 0x15, 0xbe, 0xa5, 0x61, 0x53, 0x13, 0x3e, 0x1d, 0xc0, 0xa8, 0x36, 0x9c, 0x3a,
		0x83, 0x55, 0x67, 0xf0, 0xea, 0x06, 0x66, 0x75, 0xe4, 0x1f, 0x61, 0x65, 0x4e, 0x5e, 0x50, 0x5f,
		0xd8, 0x71, 0x3a, 0xc2, 0xfa, 0x42, 0x4c, 0xa9, 0x70, 0x10, 0xaf, 0x2b, 0xb4, 0x2f, 0x2c, 0xac,
		0x92, 0xde, 0x3e, 0x1d, 0x57, 0x51, 0x77, 0x9f, 0x7c, 0x7d, 0x53, 0x1b, 0x69, 0x4d, 0xff, 0x2a,
		0x97, 0xd2, 0x96, 0xf7, 0x63, 0x3d, 0x77, 0x14, 0xd7, 0x53, 0x65, 0xa4, 0x13, 0xf2, 0x6d, 0xf4,
		0xed, 0x59, 0x21, 0x9f, 0x65, 0xc1, 0x78, 0x33, 0xc2, 0x7b, 0xc2, 0x7b, 0xc2, 0x7b, 0xc2, 0x7b,
		0xc2, 0x7b, 0xc2, 0x7b, 0xc5, 0xa0, 0xe9, 0x3d, 0xf1, 0xbd, 0xd4, 0xd2, 0xaa, 0xe5, 0xd9, 0xac,
		0x4e, 0x88, 0xaf, 0x98, 0x7f, 0x43, 0x9c, 0xef, 0x49, 0x9c, 0x5f, 0xa8, 0x73, 0x07, 0xe1, 0xbc,
		0x9d, 0x6b, 0x86, 0xe2, 0x2a, 0x7f, 0x67, 0x3e, 0xdb, 0x44, 0x24, 0x9d, 0x47, 0xee, 0xcd, 0x8b,
		0xdc, 0x7d, 0x18, 0x76, 0x4d, 0x94, 0xbf, 0xf7, 0x30, 0x1c, 0xa6, 0xe0, 0x27, 0xe4, 0x75, 0x4e,
		0xc8, 0x3d, 0xe2, 0x7c, 0x9c, 0x90, 0xaf, 0xb2, 0xa7, 0xe2, 0x84, 0x7c, 0x59, 0xb8, 0x44, 0x42,
		0xf3, 0x1a, 0x46, 0xb5, 0xe1, 0xd4, 0x19, 0xac, 0x3a, 0x83, 0x57, 0x37, 0x30, 0xab, 0x44, 0x68,
		0x90, 0xd0, 0xec, 0xc4, 0x94, 0x9c, 0x90, 0xdb, 0x1e, 0x97, 0x13, 0xf2, 0x42, 0x6e, 0x79, 0x3f,
		0xd6, 0x93, 0x13, 0x72, 0xdf, 0x1c, 0x4d, 0x21, 0x4f, 0xc8, 0xa5, 0x8b, 0xa6, 0x2e, 0x98, 0xae,
		0x6c, 0xf1, 0x54, 0x42, 0x7b, 0x42, 0x7b, 0x42, 0x7b, 0x42, 0xfb, 0x82, 0x86, 0xf6, 0xf2, 0xc5,
		0x59, 0x17, 0xc2, 0xfa, 0x1a, 0x4e, 0x71, 0x61, 0x6d, 0x48, 0x1b, 0xc3, 0x31, 0xe2, 0x18, 0x71,
		0x8c, 0x38, 0x46, 0x5f, 0x1c, 0x23, 0x9a, 0x97, 0xd0, 0xc2, 0x92, 0x36, 0x26, 0xb6, 0xb4, 0xa4,
		0x8d, 0x59, 0x5f, 0x52, 0xd2, 0xc6, 0x7c, 0xf5, 0x38, 0x1c, 0xc6, 0xaf, 0xad, 0x62, 0xda, 0xd8,
		0x28, 0x9b, 0x89, 0x4a, 0x61, 0xfe, 0x9b, 0x8e, 0x2f, 0x26, 0x53, 0x11, 0x49, 0xdd, 0x4b, 0xfb,
		0xad, 0x7c, 0x4c, 0xd8, 0x2b, 0x6f, 0x46, 0x73, 0x3d, 0x1c, 0x4f, 0xf5, 0xf4, 0x78, 0x3c, 0xc1,
		0xd3, 0xc3, 0x2c, 0xca, 0x4e, 0x7f, 0x1b, 0x4e, 0xf0, 0x74, 0xbf, 0x73, 0xfa, 0x7a, 0x30, 0xaf,
		0x0f, 0x93, 0x69, 0xad, 0x40, 0x21, 0x33, 0x39, 0x59, 0x43, 0x5c, 0xc6, 0x10, 0x92, 0x2d, 0x28,
		0x5f, 0xe6, 0x46, 0x76, 0xa0, 0x7c, 0x59, 0x19, 0x3d, 0x98, 0x98, 0x2c, 0x30, 0xb5, 0xf8, 0xd8,
		0x84, 0x1d, 0x19, 0x09, 0x60, 0x4a, 0xf9, 0x05, 0xda, 0xb8, 0x54, 0x8e, 0xc7, 0x4e, 0x77, 0x73,
		0x73, 0x14, 0x30, 0x6d, 0x5d, 0xc3, 0xe4, 0x2a, 0xb8, 0x1d, 0x91, 0xc4, 0x7a, 0xd1, 0x84, 0x7a,
		0xf1, 0x6a, 0x99, 0x75, 0xdc, 0x0d, 0xee, 0x06, 0x77, 0xb3, 0xd4, 0x12, 0x88, 0x55, 0xcb, 0xd4,
		0x6b, 0x82, 0x42, 0x0f, 0x14, 0x67, 0xb0, 0xa6, 0x08, 0x6f, 0x5a, 0x30, 0xa7, 0x0e, 0x77, 0xea,
		0xb0, 0xa7, 0x0b, 0x7f, 0x72, 0x4a, 0xd4, 0x1a, 0x3d, 0x50, 0x1e, 0x1e, 0x8b, 0x95, 0xaf, 0x07,
		0x0a, 0x2d, 0x50, 0x96, 0x5d, 0x41, 0x9d, 0xc4, 0xf2, 0xf2, 0xf5, 0x3f, 0xd1, 0x49, 0x20, 0xa7,
		0xf5, 0x89, 0xec, 0x53, 0x25, 0xae, 0xc1, 0x4b, 0x27, 0x84, 0x2b, 0x25, 0x82, 0x13, 0xfa, 0x12,
		0xfa, 0x12, 0xfa, 0x12, 0xfa, 0x0a, 0xed, 0x18, 0xf9, 0x44, 0x6d, 0xe1, 0x04, 0xed, 0x62, 0x38,
		0xa3, 0x0b, 0x93, 0xa7, 0x51, 0x4b, 0xde, 0x17, 0x8d, 0xc7, 0x91, 0xaa, 0xd0, 0x60, 0x3a, 0x61,
		0x3f, 0x1e, 0x6e, 0xd8, 0x5a, 0x15, 0x7f, 0x87, 0xbf, 0xc3, 0xdf, 0xe1, 0xef, 0x8a, 0xe5, 0xef,
		0xfa, 0x51, 0x92, 0x6f, 0xd7, 0x15, 0xdc, 0xdd, 0xae, 0xe0, 0x10, 0xef, 0xc2, 0xe4, 0xdc, 0x88,
		0xab, 0x20, 0x0a, 0x59, 0xf1, 0xaf, 0xa3, 0x44, 0xf1, 0x46, 0x88, 0xca, 0x85, 0xa1, 0xe9, 0x70,
		0x43, 0xad, 0x4a, 0x71, 0xbc, 0x57, 0x69, 0xd8, 0xca, 0xa3, 0x6e, 0xf2, 0x32, 0x3a, 0x8f, 0xf2,
		0x6c, 0x30, 0x70, 0x19, 0xe4, 0xa4, 0xca, 0xeb, 0xf0, 0x6b, 0xe9, 0x4d, 0xa4, 0x51, 0xdf, 0x6b,
		0xec, 0xed, 0xec, 0xd6, 0xf7, 0x9a, 0x25, 0xb6, 0x95, 0x82, 0xa6, 0x6d, 0x9f, 0xac, 0x72, 0x25,
		0x49, 0xbd, 0x03, 0xe4, 0x8c, 0x13, 0x64, 0x68, 0x05, 0xb4, 0x02, 0x5a, 0x51, 0x4c, 0x5a, 0xc1,
		0x09, 0xf2, 0x92, 0x0b, 0xf8, 0x9e, 0x23, 0xe4, 0x65, 0x97, 0x50, 0xed, 0x9a, 0x66, 0xf9, 0x4e,
		0x91, 0x15, 0xaf, 0x63, 0x72, 0x94, 0x2c, 0x1c, 0x07, 0x73, 0x37, 0xce, 0xc5, 0xdd, 0x38, 0x81,
		0xfb, 0x93, 0x16, 0x2f, 0x01, 0x3c, 0xf1, 0xc8, 0x16, 0x06, 0x21, 0xe9, 0x6c, 0xca, 0xec, 0x9a,
		0x6d, 0xea, 0x53, 0x39, 0x8a, 0xb2, 0x7c, 0x3f, 0xcf, 0xed, 0x26, 0x15, 0x57, 0x5e, 0x47, 0xc9,
		0x41, 0x6c, 0x06, 0x91, 0x66, 0x66, 0x97, 0xe6, 0x54, 0x5e, 0x87, 0x5f, 0x67, 0x9e, 0x5c, 0x7b,
		0xd6, 0x68, 0xec, 0xec, 0x36, 0x1a, 0xd5, 0xdd, 0xed, 0xdd, 0xea, 0x5e, 0xb3, 0x59, 0xdb, 0xb1,
		0x19, 0xee, 0x54, 0xde, 0xa6, 0x6d, 0x93, 0x9a, 0xf6, 0x8b, 0xc1, 0x3b, 0x48, 0xfa, 0x71, 0xec,
		0x95, 0x69, 0x08, 0xc1, 0x83, 0x33, 0x58, 0xa8, 0x58, 0xbd, 0x7d, 0xf3, 0x88, 0xbb, 0xb1, 0x76,
		0x10, 0x69, 0x79, 0xfc, 0x58, 0xee, 0x09, 0x4b, 0x9a, 0x97, 0x6d, 0xb3, 0x72, 0x63, 0x4e, 0xcb,
		0xbd, 0xca, 0xc7, 0xbf, 0x80, 0x25, 0x16, 0xbf, 0xd2, 0x9a, 0xa8, 0x42, 0xcb, 0x2d, 0xfa, 0x34,
		0x4e, 0x1d, 0x3f, 0x6f, 0x49, 0x73, 0xb0, 0x73, 0x27, 0xcc, 0x9a, 0xe4, 0x65, 0x53, 0xda, 0x12,
		0x90, 0xb0, 0x6c, 0x4b, 0x55, 0x62, 0x92, 0x94, 0x98, 0xf4, 0x24, 0x23, 0x31, 0xb9, 0x85, 0x44,
		0x5b, 0x77, 0xae, 0x2a, 0x61, 0x3f, 0xff, 0x6c, 0x92, 0x3c, 0x6a, 0x0d, 0xf1, 0x35, 0x68, 0x7d,
		0x36, 0xad, 0x3f, 0xed, 0xd9, 0xca, 0xf4, 0x7e, 0xd5, 0x6d, 0xa3, 0x58, 0x7a, 0xbb, 0x33, 0x59,
		0x3d, 0x03, 0x9b, 0xb1, 0xf5, 0x58, 0xbb, 0x82, 0xbb, 0x75, 0x81, 0x5d, 0x42, 0x50, 0x17, 0x14,
		0xd0, 0xa5, 0x04, 0x73, 0x71, 0x81, 0x5c, 0x5c, 0x10, 0x97, 0x15, 0xc0, 0xfd, 0xa2, 0x8e, 0xd6,
		0x05, 0x6d, 0xc1, 0x3c, 0x50, 0xcb, 0x79, 0x9f, 0x16, 0x62, 0x70, 0x0b, 0xb1, 0x40, 0x27, 0xcc,
		0xf2, 0xa0, 0x13, 0x77, 0xbb, 0xed, 0x28, 0x39, 0xb7, 0x0f, 0xf3, 0xf3, 0x8f, 0x07, 0xdf, 0xc1,
		0x77, 0xf0, 0x1d, 0x7c, 0x07, 0xdf, 0xd5, 0xf0, 0x3d, 0x8a, 0xda, 0x41, 0x1e, 0x7f, 0xb1, 0x8f,
		0xec, 0x93, 0x07, 0xdb, 0xc7, 0xf4, 0x4e, 0x18, 0x67, 0x80, 0x3a, 0xa0, 0x0e, 0xa8, 0x03, 0xea,
		0x80, 0xfa, 0xad, 0xa0, 0x3e, 0x56, 0x9a, 0x05, 0x50, 0x7d, 0xf2, 0x64, 0xfb, 0xb0, 0x5e, 0x05,
		0xd2, 0x81, 0x74, 0x20, 0x7d, 0xd5, 0x20, 0x3d, 0xcb, 0x53, 0x7b, 0xd4, 0x7f, 0x0e, 0xd1, 0x9f,
		0x95, 0x08, 0xd1, 0x63, 0xf3, 0xc5, 0xc4, 0x41, 0x2b, 0xec, 0x85, 0x67, 0x51, 0x1c, 0xe5, 0x97,
		0xf6, 0x91, 0x7d, 0x61, 0x04, 0xfb, 0x08, 0x7f, 0x74, 0xf0, 0xc7, 0xc1, 0xd1, 0x69, 0xed, 0xb4,
		0x0e, 0xd2, 0x83, 0xf4, 0x20, 0xfd, 0xaa, 0x21, 0xfd, 0x08, 0x61, 0xf2, 0xc1, 0xf3, 0x05, 0xd0,
		0xbe, 0x61, 0xf1, 0x99, 0x07, 0x49, 0xff, 0x62, 0xb0, 0x06, 0x57, 0x25, 0xf2, 0x20, 0x17, 0xe1,
		0xd7, 0xc0, 0xb4, 0x2e, 0x7a, 0x41, 0x2f, 0xcc, 0x3f, 0x67, 0xf6, 0xfd, 0xc7, 0x8d, 0xe7, 0x83,
		0xf0, 0x20, 0x3c, 0x08, 0xbf, 0x62, 0x08, 0xdf, 0x8f, 0x92, 0xfc, 0x99, 0x00, 0xb8, 0xdb, 0x4c,
		0x87, 0x95, 0x29, 0x25, 0x20, 0x90, 0xd9, 0x2e, 0x59, 0x2a, 0x40, 0xfa, 0x72, 0xa8, 0x70, 0x29,
		0x00, 0x8d, 0xeb, 0xdc, 0x12, 0xd7, 0x8b, 0x25, 0xaf, 0xf6, 0x6b, 0xbd, 0xd2, 0x7a, 0xb3, 0x59,
		0xe0, 0x97, 0xea, 0xe9, 0x7d, 0x8d, 0x93, 0x72, 0x05, 0x9a, 0xd1, 0x45, 0xff, 0x22, 0x08, 0x53,
		0x13, 0x06, 0x61, 0xbb, 0x9d, 0x9a, 0x2c, 0x33, 0x32, 0x01, 0xe7, 0x6d, 0xe3, 0xd8, 0x97, 0x2d,
		0xb6, 0x09, 0x66, 0x09, 0x66, 0x09, 0x66, 0x09, 0x66, 0x09, 0x66, 0x09, 0x66, 0x09, 0x66, 0x09,
		0x66, 0x09, 0x66, 0x57, 0x26, 0x98, 0x4d, 0x4c, 0x6e, 0x3f, 0x72, 0x1d, 0x3c, 0x94, 0x90, 0x92,
		0x90, 0x92, 0x90, 0x72, 0xc5, 0x42, 0x4a, 0x7b, 0x1b, 0x7f, 0x6d, 0x2e, 0xd1, 0xc1, 0xe2, 0x33,
		0x8f, 0xc3, 0x3c, 0x37, 0x69, 0x62, 0x3d, 0xa6, 0xac, 0xfc, 0xfb, 0x63, 0x18, 0x74, 0xf6, 0x83,
		0x57, 0xd5, 0x60, 0xef, 0xe4, 0x5b, 0xfd, 0x6a, 0xfd, 0xd3, 0xa7, 0xcd, 0xd9, 0x9f, 0x34, 0xae,
		0x36, 0xbe, 0x6d, 0x3f, 0xdd, 0xbb, 0xba, 0xf1, 0xe3, 0xfa, 0xd5, 0x5f, 0xec, 0x99, 0xd9, 0x89,
		0xcd, 0x75, 0x7a, 0xfb, 0xfe, 0xf0, 0x9f, 0xa5, 0x5e, 0x2c, 0xaf, 0xf6, 0x24, 0x15, 0x3e, 0x7e,
		0x30, 0x98, 0x4c, 0x85, 0x0f, 0x2f, 0xe2, 0xaf, 0x5e, 0x37, 0x92, 0xb9, 0x9e, 0x30, 0x79, 0x30,
		0xd7, 0x13, 0x88, 0xef, 0x88, 0xef, 0x88, 0xef, 0xac, 0x58, 0xec, 0x2a, 0x5c, 0x4f, 0xa0, 0xae,
		0xcf, 0x63, 0xeb, 0xfa, 0x8c, 0x6b, 0xd9, 0x14, 0xb0, 0xaa, 0xcf, 0x79, 0x1a, 0xb6, 0x4c, 0xa7,
		0x1f, 0x07, 0xa9, 0xc9, 0xf2, 0x30, 0xcd, 0xed, 0xd5, 0xf7, 0x59, 0x78, 0x32, 0x95, 0x7e, 0x14,
		0xfd, 0x22, 0x95, 0x7e, 0xa8, 0xf4, 0xf3, 0x83, 0x07, 0x59, 0x2a, 0xe6, 0xb5, 0x60, 0xc0, 0x56,
		0x8a, 0x7a, 0x59, 0xde, 0xf2, 0x84, 0xc8, 0x84, 0xc8, 0x84, 0xc8, 0xb6, 0x21, 0x64, 0xfa, 0x40,
		0xa9, 0xde, 0xb4, 0xc2, 0x3d, 0x69, 0xa5, 0x78, 0xbd, 0x10, 0xbf, 0x17, 0x03, 0x31, 0x49, 0x30,
		0x53, 0x00, 0x35, 0x69, 0x70, 0x53, 0x03, 0x39, 0x35, 0xb0, 0xd3, 0x01, 0x3d, 0xbb, 0xe0, 0x67,
		0x19, 0x04, 0xe5, 0xf4, 0x02, 0x05, 0xdd, 0x40, 0x48, 0x3f, 0xb0, 0xff, 0xc2, 0x2c, 0xbe, 0xac,
		0xca, 0x67, 0x13, 0xf7, 0x4c, 0x1a, 0x74, 0x93, 0xf8, 0x52, 0xce, 0xd1, 0xcc, 0x0e, 0x82, 0x33,
		0xc0, 0x19, 0xe0, 0x0c, 0x70, 0x06, 0x38, 0x83, 0x32, 0x92, 0xa0, 0x52, 0xf4, 0x26, 0xb8, 0x29,
		0xb0, 0x5a, 0x51, 0xa1, 0xed, 0xbd, 0x2f, 0x1b, 0x67, 0xc4, 0xa3, 0x4e, 0x2c, 0xd6, 0x55, 0xaa,
		0xd1, 0x63, 0x3d, 0x17, 0xa9, 0xea, 0x88, 0x54, 0x88, 0x54, 0x88, 0x54, 0x88, 0x54, 0x88, 0x54,
		0xf0, 0x12, 0x78, 0x09, 0xbc, 0x04, 0x5e, 0x82, 0x48, 0x85, 0x48, 0x85, 0x33, 0xc0, 0x19, 0xe0,
		0x0c, 0x70, 0x06, 0x88, 0x54, 0xc5, 0x14, 0xa9, 0x2c, 0x36, 0xd7, 0x25, 0xe5, 0xd5, 0xa3, 0x17,
		0x5b, 0xb1, 0x22, 0xf7, 0x3d, 0xb8, 0x2d, 0xea, 0x6f, 0xe3, 0x69, 0xbc, 0x1b, 0xcf, 0xa2, 0x80,
		0x29, 0xb8, 0xd1, 0x79, 0x2f, 0xc8, 0x3e, 0x77, 0xd3, 0xbc, 0xd5, 0xcf, 0x33, 0x7b, 0xf9, 0xb7,
		0xf3, 0x8f, 0x25, 0xf9, 0x56, 0x31, 0xd4, 0x23, 0xf9, 0x96, 0xe4, 0xdb, 0x1f, 0x3c, 0x28, 0xec,
		0x44, 0x02, 0x5d, 0x35, 0x3b, 0x11, 0x69, 0xb7, 0x3e, 0xf2, 0x3d, 0x4e, 0x34, 0xdc, 0xf0, 0xb9,
		0x92, 0x9f, 0x68, 0x84, 0x9d, 0x28, 0x18, 0x47, 0x4a, 0x42, 0x4a, 0xd3, 0x74, 0x04, 0x64, 0x26,
		0x64, 0x26, 0x64, 0x26, 0x64, 0x26, 0xab, 0x16, 0x1f, 0x9b, 0xb0, 0x93, 0x9a, 0x8e, 0xa4, 0xcc,
		0xb4, 0x2b, 0xf0, 0xec, 0xe3, 0x31, 0xbb, 0xde, 0xdc, 0x1c, 0x29, 0x19, 0x5b, 0x53, 0x94, 0x5c,
		0x81, 0x03, 0x0e, 0xcb, 0xb7, 0xc6, 0x16, 0x6c, 0xc2, 0xea, 0xed, 0x31, 0xa1, 0x70, 0x16, 0x7f,
		0x83, 0xbf, 0xc1, 0xdf, 0xd8, 0xf6, 0x37, 0xb6, 0xc3, 0x63, 0xf9, 0x30, 0x59, 0x2b, 0x5c, 0x16,
		0x0e, 0x9b, 0xc5, 0xe1, 0x4c, 0x03, 0xd6, 0x14, 0xe1, 0x4d, 0x0b, 0xe6, 0xd4, 0xe1, 0x4e, 0x1d,
		0xf6, 0x74, 0xe1, 0x4f, 0x06, 0x06, 0x85, 0xe0, 0x50, 0x3e, 0x0c, 0x5f, 0xd8, 0x31, 0x51, 0xdb,
		0x24, 0x79, 0x94, 0x5f, 0xca, 0x84, 0xe4, 0x0b, 0xb1, 0x58, 0x53, 0x70, 0x8c, 0xc3, 0xf1, 0x47,
		0x79, 0x11, 0x66, 0x0a, 0xfb, 0x73, 0xb2, 0x80, 0xfb, 0xaf, 0x0e, 0x4f, 0x3f, 0xfc, 0xeb, 0xf8,
		0x40, 0x7a, 0x7b, 0x0e, 0xeb, 0x1b, 0x67, 0xd6, 0xeb, 0x12, 0xde, 0xf6, 0xf5, 0x4d, 0x7c, 0x84,
		0xb9, 0x15, 0x3c, 0x3c, 0xfe, 0xa3, 0x51, 0x11, 0x1f, 0xf2, 0xea, 0x69, 0x09, 0xd7, 0x6d, 0x47,
		0x61, 0xdd, 0x44, 0x47, 0x38, 0x29, 0x1a, 0xe0, 0x17, 0xa2, 0x8e, 0x7b, 0xf2, 0x79, 0xd4, 0x93,
		0x51, 0x3c, 0xf6, 0x9d, 0x0c, 0x44, 0xe8, 0x4b, 0xe8, 0x4b, 0xe8, 0x4b, 0xe8, 0x4b, 0xe8, 0xbb,
		0x4a, 0xa1, 0xef, 0xf1, 0xfe, 0x87, 0xff, 0x7b, 0xfa, 0xfe, 0xe0, 0xc3, 0xef, 0xc7, 0xa7, 0xc7,
		0xef, 0xde, 0x7e, 0x78, 0xfb, 0xeb, 0xdb, 0x23, 0xa2, 0x60, 0x0b, 0x8b, 0x79, 0xf4, 0xf2, 0x98,
		0x78, 0x78, 0xa9, 0x15, 0x7c, 0xf7, 0xfe, 0x0f, 0x96, 0x70, 0xb9, 0x25, 0x7c, 0xff, 0x0e, 0x6e,
		0x51, 0x0e, 0x8f, 0x2a, 0x52, 0x68, 0x7f, 0x61, 0x14, 0xb1, 0xc2, 0xfb, 0x8b, 0x23, 0x29, 0x16,
		0xe2, 0x5f, 0x18, 0x5c, 0xa4, 0x30, 0xbf, 0x02, 0xcb, 0xf4, 0xfa, 0x14, 0x48, 0xe8, 0xc6, 0xc3,
		0xf4, 0xf9, 0xaa, 0x09, 0xf2, 0x73, 0xf9, 0xd7, 0x5b, 0x61, 0x27, 0xb2, 0x5a, 0x9f, 0xc3, 0xfe,
		0x0b, 0xb5, 0x99, 0x28, 0x60, 0xb7, 0x6e, 0xc7, 0x82, 0x7b, 0xb2, 0x59, 0xbf, 0x63, 0x21, 0x3e,
		0x97, 0x4a, 0x13, 0xa8, 0x93, 0x26, 0xa0, 0x28, 0x22, 0x90, 0x26, 0x50, 0x46, 0x07, 0x41, 0x9a,
		0xc0, 0x7d, 0x61, 0x0c, 0xad, 0xd4, 0x29, 0xbc, 0x69, 0xc1, 0x9c, 0x3a, 0xdc, 0xa9, 0xc3, 0x9e,
		0x2e, 0xfc, 0x15, 0x93, 0xd9, 0xa1, 0x95, 0x3e, 0x62, 0x0c, 0xd2, 0x04, 0x8a, 0xa9, 0x4d, 0x91,
		0x26, 0xf0, 0xe8, 0x75, 0x23, 0x4d, 0x40, 0x1b, 0xf0, 0x49, 0x13, 0x20, 0x4d, 0x80, 0xd0, 0x97,
		0xd0, 0x97, 0xd0, 0x97, 0xd0, 0x77, 0xd5, 0x43, 0x5f, 0xd2, 0x04, 0x64, 0x16, 0x93, 0x34, 0x81,
		0x65, 0x57, 0x90, 0x34, 0x81, 0xa5, 0x97, 0x90, 0x34, 0x81, 0xb2, 0x78, 0x54, 0xd2, 0x04, 0x2c,
		0x0e, 0x4e, 0x9a, 0x00, 0x69, 0x02, 0x0f, 0x4d, 0x13, 0xb0, 0x58, 0x21, 0xd1, 0xfe, 0xfb, 0xf4,
		0xab, 0xaa, 0xce, 0x3f, 0xcc, 0xa5, 0xc0, 0x99, 0x9a, 0x0c, 0x04, 0xca, 0x41, 0x9e, 0x2a, 0xc4,
		0xc9, 0x40, 0x1a, 0x35, 0x53, 0x7f, 0x04, 0x09, 0x15, 0xab, 0xa9, 0x39, 0x0f, 0xae, 0xb1, 0xb9,
		0xdf, 0x89, 0x28, 0xd8, 0x5a, 0xf8, 0x82, 0xad, 0xf3, 0xf5, 0x40, 0x8b, 0x58, 0x27, 0x35, 0xc9,
		0x4d, 0x1a, 0xc4, 0xe6, 0x8b, 0x89, 0x83, 0x5e, 0xda, 0xed, 0x85, 0xe7, 0xc3, 0x57, 0x11, 0xf4,
		0xba, 0x71, 0xd4, 0x8a, 0x8c, 0xcd, 0xd2, 0xa9, 0x3f, 0x1b, 0x89, 0x6a, 0xaa, 0x3f, 0x5d, 0x43,
		0xaa, 0xa9, 0x52, 0x4d, 0xf5, 0x47, 0x1f, 0xc9, 0x5a, 0x35, 0xd5, 0xe1, 0x36, 0xad, 0x05, 0x79,
		0x77, 0xb4, 0x61, 0xeb, 0xf6, 0x4b, 0xab, 0x2e, 0x8c, 0x40, 0x9d, 0x55, 0x8f, 0xe0, 0x41, 0x0a,
		0x26, 0xc4, 0xe1, 0x42, 0x1c, 0x36, 0x64, 0xe1, 0xc3, 0x4f, 0x46, 0x68, 0xbd, 0xce, 0x2a, 0x35,
		0xef, 0x04, 0x21, 0x46, 0x12, 0x6a, 0x14, 0x20, 0x47, 0x1a, 0x7a, 0xd4, 0x20, 0x48, 0x0d, 0x8a,
		0x74, 0x20, 0xa9, 0x18, 0x32, 0xa6, 0x58, 0x32, 0x7b, 0x7b, 0xd4, 0x34, 0x32, 0x88, 0x2e, 0x7a,
		0xdd, 0x34, 0x1f, 0xb1, 0x96, 0x4b, 0xf9, 0xec, 0x9e, 0xdb, 0x87, 0x15, 0xb2, 0x9f, 0x99, 0xc6,
		0x98, 0xef, 0x0e, 0xfe, 0x7f, 0x07, 0xbf, 0x7e, 0x38, 0x7d, 0xf7, 0xf6, 0xf7, 0x0f, 0x07, 0xa4,
		0x16, 0xa9, 0xe3, 0xeb, 0x6d, 0x38, 0x9b, 0xf6, 0xba, 0x31, 0xa9, 0x45, 0x1e, 0xe3, 0xef, 0x5d,
		0x38, 0x3c, 0x7c, 0x71, 0x1c, 0x84, 0xae, 0xe9, 0xa6, 0x16, 0x4d, 0x90, 0x73, 0x04, 0x99, 0x92,
		0x39, 0x92, 0x73, 0xc1, 0x61, 0x43, 0x70, 0x8c, 0x83, 0xa4, 0x7f, 0x31, 0x58, 0xbc, 0x55, 0xce,
		0xab, 0x55, 0xf6, 0xbf, 0x2a, 0x7e, 0x17, 0x47, 0x88, 0x23, 0xc4, 0x11, 0xe2, 0x08, 0x65, 0x76,
		0x8c, 0x5c, 0x53, 0x88, 0x05, 0xe7, 0xb7, 0x2b, 0x38, 0xc6, 0xf1, 0xf4, 0x44, 0x6f, 0x64, 0x48,
		0xcf, 0xd3, 0x6e, 0x3f, 0x8f, 0x92, 0xf3, 0x31, 0x36, 0x4f, 0x7f, 0x3c, 0xf6, 0xf7, 0x6d, 0xd3,
		0x89, 0x92, 0x28, 0x8f, 0xba, 0x49, 0x76, 0xf7, 0x5f, 0x4d, 0xff, 0xc6, 0x7e, 0xb3, 0x09, 0x69,
		0xfb, 0x21, 0xa3, 0xcc, 0xe2, 0xe0, 0xb3, 0xe9, 0x17, 0x4a, 0x89, 0xdb, 0xfd, 0xcc, 0xa4, 0xd2,
		0x78, 0xaf, 0xe4, 0xc8, 0x6e, 0x3a, 0xb3, 0xee, 0x68, 0x35, 0x83, 0xb3, 0xcb, 0x8a, 0x7c, 0x76,
		0xae, 0xba, 0x53, 0x5b, 0x70, 0x6c, 0xc3, 0x37, 0x29, 0x3a, 0xe4, 0x15, 0x37, 0xf4, 0xc8, 0x9d,
		0x54, 0x4b, 0x69, 0xf9, 0x49, 0x9e, 0xc6, 0xd6, 0xcd, 0x93, 0x5b, 0x4a, 0x30, 0xd9, 0xf2, 0x09,
		0x94, 0x60, 0xe2, 0xd4, 0xca, 0x17, 0xd2, 0xc8, 0xa9, 0x95, 0xa2, 0x03, 0xe1, 0xd4, 0x6a, 0x99,
		0xc5, 0xe3, 0xd4, 0x0a, 0xb1, 0x0e, 0xb1, 0x0e, 0xb1, 0x8e, 0x53, 0xab, 0x47, 0x07, 0x87, 0x9c,
		0x5a, 0x89, 0x1a, 0x11, 0xa7, 0x56, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0x10, 0x47, 0x78, 0xef, 0x1d,
		0xc3, 0xa9, 0x15, 0xa7, 0x56, 0x8f, 0x1d, 0x85, 0x53, 0x2b, 0xa9, 0x5d, 0xc9, 0xa9, 0x55, 0x41,
		0x9d, 0xda, 0x1a, 0xa7, 0x56, 0x0e, 0x98, 0x04, 0xa7, 0x56, 0xfe, 0x9e, 0x5a, 0x51, 0x11, 0xc4,
		0xb5, 0xa5, 0x78, 0x6e, 0x21, 0x8e, 0x0b, 0x44, 0x1c, 0x0e, 0xe6, 0x7b, 0x34, 0x98, 0xc9, 0xf1,
		0xf5, 0x6c, 0x8f, 0xc7, 0x93, 0x3d, 0x1d, 0xfe, 0x45, 0xed, 0x43, 0xf7, 0x68, 0x34, 0x55, 0x5f,
		0x2a, 0x49, 0x3c, 0xb5, 0x74, 0xf5, 0xb8, 0x3e, 0x7d, 0x0d, 0x35, 0xa1, 0xab, 0xc7, 0xb3, 0x23,
		0x70, 0xf5, 0xd8, 0x86, 0xc0, 0xc1, 0xd5, 0x63, 0xa5, 0xd8, 0x8e, 0xab, 0xc7, 0x4b, 0x3c, 0x90,
		0xab, 0xc7, 0x82, 0x10, 0x23, 0x09, 0x35, 0x0a, 0x90, 0xa3, 0x45, 0x41, 0x49, 0xe2, 0x28, 0x23,
		0x9f, 0x22, 0x89, 0x63, 0x99, 0xc5, 0x23, 0x89, 0xc3, 0x13, 0x7c, 0xbd, 0x0d, 0x67, 0x39, 0xbb,
		0x2a, 0x88, 0xcc, 0xc7, 0xd9, 0xd5, 0xdd, 0x4b, 0x43, 0x12, 0xc7, 0x12, 0x63, 0x90, 0xc4, 0x41,
		0x12, 0x07, 0x8e, 0x10, 0x47, 0x88, 0x23, 0xc4, 0x11, 0xde, 0x7f, 0xc7, 0x90, 0xc4, 0x41, 0x12,
		0xc7, 0x63, 0x47, 0x21, 0x89, 0x43, 0x6a, 0x57, 0x92, 0xc4, 0x51, 0x50, 0xa7, 0xb6, 0x46, 0x12,
		0x87, 0x03, 0x26, 0x41, 0x12, 0x87, 0x5f, 0x47, 0xf4, 0x33, 0x27, 0xb7, 0x5c, 0x3d, 0xb6, 0xe5,
		0x13, 0xb8, 0x7a, 0xcc, 0xa9, 0x95, 0x2f, 0xa4, 0x91, 0x53, 0x2b, 0x45, 0x07, 0xc2, 0xa9, 0xd5,
		0x32, 0x8b, 0xc7, 0xa9, 0x15, 0x62, 0x1d, 0x62, 0x1d, 0x62, 0x1d, 0xa7, 0x56, 0x8f, 0x0e, 0x0e,
		0x39, 0xb5, 0x12, 0x35, 0x22, 0x4e, 0xad, 0x70, 0x84, 0x38, 0x42, 0x1c, 0x21, 0x8e, 0xf0, 0xde,
		0x3b, 0x86, 0x53, 0x2b, 0x4e, 0xad, 0x1e, 0x3b, 0x0a, 0xa7, 0x56, 0x52, 0xbb, 0x92, 0x53, 0xab,
		0x82, 0x3a, 0xb5, 0x35, 0x4e, 0xad, 0x1c, 0x30, 0x09, 0x4e, 0xad, 0xfc, 0x3d, 0xb5, 0xe2, 0xea,
		0xb1, 0x6b, 0x4b, 0xf1, 0xdc, 0x42, 0xfc, 0xbf, 0x7a, 0x5c, 0x1f, 0x5f, 0x3d, 0xae, 0xd1, 0xc4,
		0xbe, 0xf8, 0x4d, 0xec, 0x65, 0x3b, 0xb3, 0x8b, 0x58, 0x61, 0x11, 0x7b, 0xed, 0xc7, 0x59, 0x2f,
		0x38, 0x8b, 0x72, 0x7b, 0x2d, 0xf5, 0x27, 0x0f, 0xa4, 0x73, 0xfe, 0x7d, 0x54, 0x30, 0x3a, 0xe7,
		0xd3, 0x39, 0xff, 0xce, 0x8f, 0x64, 0xad, 0x73, 0x7e, 0x98, 0xe7, 0x61, 0xeb, 0xf3, 0x80, 0xcc,
		0x59, 0xd8, 0xe9, 0x0b, 0x66, 0x3c, 0xf7, 0x74, 0xca, 0x56, 0x78, 0x04, 0x0b, 0xd2, 0x1a, 0x02,
		0x65, 0x2b, 0x8a, 0x44, 0x5b, 0x28, 0x5b, 0xb1, 0x46, 0xd9, 0x0a, 0x2d, 0xc8, 0xd1, 0x92, 0x2f,
		0x49, 0x00, 0x2c, 0xa3, 0x16, 0x27, 0x96, 0x00, 0x18, 0x9d, 0x27, 0xdd, 0xd4, 0x58, 0x8d, 0x83,
		0xee, 0xdc, 0x54, 0x33, 0x63, 0xc9, 0xa7, 0xfa, 0x75, 0xc2, 0x38, 0x33, 0xa4, 0x36, 0xa8, 0x43,
		0xa8, 0x22, 0x94, 0x6a, 0x41, 0xaa, 0x3a, 0xb4, 0xaa, 0x43, 0xac, 0x2e, 0xd4, 0xca, 0x40, 0xae,
		0x10, 0xf4, 0x4e, 0x97, 0x46, 0x2f, 0xb5, 0xe1, 0xac, 0xdb, 0x8d, 0x4d, 0x98, 0x68, 0xa4, 0x36,
		0xd4, 0x56, 0x38, 0xe7, 0x2e, 0xeb, 0xf7, 0x7a, 0xa9, 0xc9, 0x32, 0x1d, 0xe7, 0x37, 0x37, 0x1a,
		0xee, 0x0f, 0xf7, 0x87, 0xfb, 0xc3, 0xfd, 0xe1, 0xfe, 0x70, 0x7f, 0xc5, 0x27, 0xa7, 0xa5, 0x4a,
		0x14, 0x19, 0x1f, 0xd7, 0x6d, 0xcd, 0x8a, 0xf8, 0xdc, 0x60, 0xb6, 0x16, 0x05, 0x71, 0x83, 0x19,
		0x01, 0xd3, 0x93, 0x30, 0x03, 0x01, 0x53, 0xd1, 0x47, 0x20, 0x60, 0xc2, 0xe0, 0x60, 0x70, 0x30,
		0x38, 0x18, 0x1c, 0x0c, 0x6e, 0x25, 0x19, 0x1c, 0x02, 0x26, 0xee, 0x0f, 0xf7, 0x87, 0xfb, 0xc3,
		0xfd, 0xe1, 0xfe, 0x56, 0xd0, 0xfd, 0x21, 0x60, 0x3a, 0x15, 0x30, 0xb9, 0xcc, 0xe6, 0xda, 0x18,
		0xdc, 0x1b, 0x81, 0xe3, 0xfb, 0x6a, 0x47, 0x59, 0xef, 0x45, 0x94, 0x9f, 0xee, 0x8f, 0x67, 0xf4,
		0x22, 0xca, 0xcb, 0xd4, 0x10, 0xb3, 0xfb, 0xc5, 0xa4, 0x71, 0x37, 0x14, 0xba, 0x51, 0x30, 0xf7,
		0x74, 0x6e, 0x14, 0x78, 0x18, 0xd3, 0x72, 0xa3, 0xc0, 0x4d, 0x4c, 0xca, 0x8d, 0x82, 0xa5, 0x36,
		0x02, 0x37, 0x0a, 0x38, 0x90, 0xf3, 0x86, 0x36, 0x73, 0x20, 0xa7, 0xc8, 0x79, 0xc4, 0x0e, 0xe4,
		0xc2, 0xf6, 0x17, 0x93, 0xe6, 0x51, 0x66, 0x82, 0xcf, 0xd1, 0xf9, 0xe7, 0xe0, 0xc2, 0xe4, 0x69,
		0xd4, 0x92, 0x97, 0x27, 0x6f, 0x1f, 0x16, 0x9d, 0xd2, 0x05, 0xa0, 0x6a, 0x00, 0xab, 0x22, 0xc0,
		0x6a, 0x01, 0xad, 0x3a, 0xe0, 0xaa, 0x03, 0xaf, 0x2e, 0x00, 0xcb, 0xc9, 0x59, 0x6b, 0xe8, 0x94,
		0x0f, 0x8b, 0x04, 0x57, 0xfa, 0x98, 0xce, 0xe4, 0x4a, 0x27, 0x74, 0xe3, 0x81, 0x70, 0x7a, 0x38,
		0x3d, 0x9c, 0x1e, 0x4e, 0x0f, 0xa7, 0x87, 0xd3, 0x73, 0xec, 0xf4, 0x82, 0x6e, 0x12, 0x9c, 0x75,
		0xbb, 0x7a, 0xce, 0x6f, 0x3a, 0x20, 0x4e, 0x10, 0x27, 0x88, 0x13, 0xc4, 0x09, 0xe2, 0x04, 0x71,
		0x82, 0xfa, 0x4f, 0x24, 0x43, 0xe5, 0x1e, 0xc9, 0x09, 0xb3, 0xa7, 0xda, 0x2b, 0x74, 0xc5, 0x2e,
		0x35, 0x83, 0x58, 0x25, 0x4f, 0xa3, 0xf3, 0x73, 0x93, 0x66, 0x72, 0x67, 0x7b, 0x37, 0xc6, 0xe1,
		0x8c, 0x8f, 0x33, 0x3e, 0xf7, 0x81, 0x07, 0x67, 0x7c, 0x8a, 0x5e, 0x43, 0xec, 0x8c, 0x6f, 0x0e,
		0x5a, 0xe4, 0xb9, 0xdd, 0xfc, 0x70, 0xb2, 0x8c, 0xab, 0x06, 0xe3, 0x82, 0x71, 0xc1, 0xb8, 0x56,
		0x83, 0x71, 0x49, 0x01, 0xe4, 0x74, 0x00, 0xa1, 0xfc, 0xad, 0x3b, 0x37, 0xa6, 0x48, 0x3e, 0x97,
		0x32, 0x54, 0xaa, 0x41, 0xa6, 0x26, 0x74, 0x3a, 0x80, 0x50, 0x6d, 0x28, 0x75, 0x06, 0xa9, 0xce,
		0xa0, 0xd5, 0x0d, 0xc4, 0xca, 0x42, 0xad, 0x30, 0xe4, 0xaa, 0x41, 0xef, 0x74, 0xa0, 0xb6, 0x89,
		0xc3, 0x4b, 0x3d, 0xe3, 0xbf, 0x6e, 0xd4, 0x3c, 0x18, 0x56, 0xc9, 0xfe, 0x64, 0x4f, 0x0b, 0x9c,
		0x01, 0xb3, 0x0b, 0x80, 0x76, 0x08, 0xd4, 0xae, 0x00, 0xdb, 0x39, 0x70, 0x3b, 0x07, 0x70, 0xb7,
		0x40, 0xae, 0x03, 0xe8, 0x4a, 0xc0, 0x3e, 0x5d, 0x4a, 0xf1, 0xd3, 0x8c, 0x3b, 0x77, 0x6c, 0x3f,
		0x4a, 0xf2, 0xda, 0x8e, 0xe6, 0x86, 0x1d, 0xe3, 0xef, 0x8e, 0xe2, 0x90, 0xef, 0xc2, 0xe4, 0x7c,
		0xf0, 0x69, 0x3f, 0xaa, 0x6e, 0x10, 0x5d, 0x40, 0x5a, 0x1b, 0x37, 0xeb, 0x55, 0x47, 0x42, 0x47,
		0x8e, 0x75, 0x61, 0xf8, 0x3f, 0xc2, 0xb8, 0x6f, 0x1c, 0x8e, 0xff, 0x2a, 0x0d, 0x5b, 0x79, 0xd4,
		0x4d, 0x5e, 0x46, 0xe7, 0xd1, 0xa8, 0x57, 0xb2, 0xfa, 0x3c, 0xae, 0x9e, 0x3a, 0x30, 0xb9, 0xf0,
		0xeb, 0xca, 0x9b, 0xdc, 0x4e, 0xb3, 0xb9, 0xdd, 0x5c, 0x61, 0xb3, 0x7b, 0x52, 0xce, 0xd1, 0x4e,
		0x9e, 0x94, 0xe3, 0xf3, 0x28, 0xc0, 0x82, 0xd2, 0x29, 0xc7, 0x9d, 0x61, 0x8c, 0xc6, 0xa9, 0x07,
		0x4c, 0x12, 0x26, 0x09, 0x93, 0x84, 0x49, 0xc2, 0x24, 0x6f, 0xdd, 0xb1, 0x51, 0xdb, 0x24, 0x79,
		0x94, 0x5f, 0xa6, 0xa6, 0xe3, 0x80, 0x4e, 0xd6, 0x14, 0xe3, 0xaf, 0xca, 0xe1, 0xf8, 0xa3, 0xbe,
		0x08, 0x33, 0x07, 0x78, 0x31, 0x59, 0xf0, 0xb7, 0x7f, 0x1c, 0xbc, 0x3b, 0x7a, 0xbb, 0xff, 0xf2,
		0xf4, 0xdd, 0xc1, 0xfb, 0x83, 0x0f, 0xa7, 0x1f, 0xde, 0x1d, 0xfe, 0xf6, 0xdb, 0xc1, 0xbb, 0xd3,
		0x0f, 0xff, 0x3a, 0x3e, 0xd0, 0x46, 0x90, 0x61, 0x20, 0x9c, 0xa9, 0x33, 0x6c, 0x37, 0x2c, 0x7b,
		0xee, 0x25, 0xfc, 0xcf, 0xfe, 0xe1, 0x87, 0xd3, 0x57, 0x6f, 0xdf, 0x9d, 0xbe, 0xf8, 0xed, 0xb8,
		0xb2, 0x0a, 0x84, 0xcf, 0x97, 0xf5, 0x7e, 0xff, 0xaf, 0xf7, 0x1f, 0x0e, 0x5e, 0x57, 0x4a, 0x4e,
		0x76, 0x4e, 0xca, 0xe6, 0x06, 0x39, 0xe9, 0xfb, 0x71, 0x24, 0x24, 0x9b, 0xbb, 0xbc, 0x30, 0x9e,
		0xfb, 0x5c, 0xe6, 0xf9, 0xcc, 0xdb, 0xf9, 0x3f, 0x8a, 0x24, 0x3a, 0xeb, 0x19, 0x8c, 0xa0, 0xb1,
		0x28, 0xf3, 0x6d, 0x27, 0x3c, 0x5b, 0x89, 0x5f, 0x93, 0x3a, 0x53, 0x4c, 0xfe, 0x4c, 0xea, 0x0c,
		0xa9, 0x33, 0x1e, 0xf1, 0xe1, 0xe9, 0x8e, 0x8b, 0x4d, 0xd8, 0xd1, 0xe1, 0xc0, 0x53, 0xee, 0xbb,
		0xab, 0x30, 0xd6, 0xf1, 0x38, 0x46, 0xd8, 0xdc, 0x1c, 0x15, 0xc8, 0x9d, 0xf7, 0xd4, 0xb8, 0xe8,
		0x5b, 0x62, 0x2b, 0x91, 0xf6, 0x60, 0x77, 0xda, 0x9d, 0x44, 0xbb, 0xb0, 0x3b, 0x2d, 0x4e, 0xcb,
		0x25, 0xd7, 0x71, 0xc9, 0xb8, 0x64, 0x5c, 0x72, 0xa9, 0x5c, 0x32, 0xd9, 0xac, 0x85, 0xe3, 0x48,
		0xea, 0x5c, 0xc9, 0x05, 0x40, 0x3b, 0x04, 0x6a, 0x57, 0x80, 0xed, 0x1c, 0xb8, 0x9d, 0x03, 0xb8,
		0x5b, 0x20, 0xd7, 0x01, 0x74, 0x25, 0x60, 0xd7, 0xe7, 0x5c, 0x0b, 0x3b, 0x96, 0x6c, 0x56, 0xb1,
		0x2f, 0xb2, 0x59, 0x55, 0x87, 0x27, 0x9b, 0x95, 0x6c, 0x56, 0x47, 0x26, 0x47, 0x36, 0x6b, 0x29,
		0x47, 0x23, 0x9b, 0xf5, 0xfe, 0x66, 0x48, 0x36, 0x2b, 0x4c, 0x12, 0x26, 0x09, 0x93, 0x84, 0x49,
		0xae, 0x2a, 0x93, 0x24, 0x9b, 0x55, 0x79, 0xc1, 0xc9, 0x66, 0x5d, 0x23, 0x9b, 0x95, 0x6c, 0xd6,
		0x52, 0x93, 0x1d, 0xb2, 0x59, 0xfd, 0x1a, 0x81, 0x6c, 0x56, 0xd5, 0x6c, 0x56, 0x81, 0xc6, 0xd2,
		0x7a, 0xf6, 0x52, 0xac, 0x62, 0x75, 0xff, 0x30, 0x97, 0x6a, 0xc5, 0x30, 0x8f, 0xa2, 0x2c, 0xdf,
		0xcf, 0x73, 0xe1, 0xea, 0x78, 0xaf, 0xa3, 0xe4, 0x20, 0x36, 0x03, 0x5e, 0x91, 0xc9, 0x92, 0xe6,
		0xca, 0xeb, 0xf0, 0xeb, 0xcc, 0x48, 0xb5, 0x67, 0x8d, 0xc6, 0xce, 0x6e, 0xa3, 0x51, 0xdd, 0xdd,
		0xde, 0xad, 0xee, 0x35, 0x9b, 0xb5, 0x1d, 0xc9, 0xe0, 0xb4, 0xf2, 0x36, 0x6d, 0x9b, 0xd4, 0xb4,
		0x5f, 0x0c, 0x5e, 0x5f, 0xd2, 0x8f, 0xe3, 0x42, 0x59, 0x9d, 0x12, 0xde, 0x79, 0x8e, 0x73, 0x15,
		0xd1, 0x9c, 0xba, 0xc7, 0xf6, 0x52, 0x7f, 0x3b, 0x9e, 0xfe, 0xe0, 0xfb, 0x77, 0x83, 0xe9, 0x7e,
		0x90, 0xcc, 0x5c, 0xa4, 0xe6, 0x7e, 0xb9, 0x2d, 0x7e, 0x15, 0x6a, 0xef, 0xcb, 0xe4, 0xaf, 0x8a,
		0xe6, 0xab, 0x8a, 0x57, 0xda, 0xaf, 0x53, 0x69, 0x7f, 0x76, 0x08, 0x2a, 0xed, 0x3f, 0x18, 0x28,
		0xa9, 0xb4, 0x4f, 0x37, 0xed, 0x65, 0x16, 0x8f, 0x9e, 0x6a, 0xae, 0x81, 0x55, 0x11, 0x60, 0xb5,
		0x80, 0x56, 0x1d, 0x70, 0xd5, 0x81, 0x57, 0x17, 0x80, 0x8b, 0x29, 0x9a, 0xd0, 0x53, 0xcd, 0x25,
		0xbf, 0xa3, 0x9b, 0x36, 0x4e, 0x0f, 0xa7, 0x87, 0xd3, 0xc3, 0xe9, 0xe1, 0xf4, 0x70, 0x7a, 0x4b,
		0x3b, 0x3d, 0xba, 0x69, 0xe3, 0x04, 0x71, 0x82, 0x38, 0x41, 0x9c, 0x20, 0x4e, 0xd0, 0x73, 0x27,
		0xc8, 0xc9, 0x9e, 0xd3, 0x93, 0x3d, 0x81, 0xb4, 0x1c, 0x8b, 0x07, 0x7a, 0x4f, 0x3c, 0x32, 0x0a,
		0x29, 0x63, 0x70, 0x6f, 0x04, 0x15, 0xab, 0xe7, 0xa6, 0x16, 0x72, 0x14, 0xec, 0xd8, 0xe3, 0xf2,
		0xd6, 0xb3, 0xdc, 0x13, 0x96, 0xb4, 0x3b, 0xdb, 0xf6, 0xe6, 0xc4, 0xce, 0x2c, 0x98, 0xd6, 0xe3,
		0x4d, 0x6a, 0x39, 0x33, 0x7a, 0xfc, 0xcb, 0x5f, 0xe2, 0xc5, 0x57, 0x2e, 0x7a, 0xf1, 0xf2, 0x9d,
		0xfe, 0xa7, 0x01, 0xc7, 0xf0, 0x69, 0x4b, 0x9a, 0xa1, 0x9d, 0xac, 0x02, 0x6b, 0xd4, 0xc7, 0x26,
		0xc5, 0x11, 0xa0, 0x32, 0xb6, 0x29, 0x8b, 0x18, 0x35, 0x11, 0xa3, 0x20, 0x32, 0x54, 0xc3, 0x2d,
		0x14, 0xdb, 0x3a, 0xb5, 0xaf, 0x44, 0xe7, 0xbd, 0x20, 0x6e, 0xf7, 0x82, 0xec, 0x32, 0xb1, 0x77,
		0x38, 0x7f, 0x7d, 0x6f, 0x6b, 0xf6, 0xe9, 0x96, 0xde, 0xa6, 0xdd, 0xa4, 0x22, 0xeb, 0x0a, 0x88,
		0x84, 0xe2, 0x21, 0xa8, 0x70, 0x48, 0x29, 0x1a, 0xe2, 0x0a, 0x86, 0xb8, 0x62, 0x21, 0xab, 0x50,
		0xf8, 0xc5, 0x24, 0x6c, 0x27, 0x01, 0x49, 0x75, 0x8f, 0x97, 0xed, 0x16, 0x2f, 0x9e, 0xaf, 0x58,
		0x25, 0x5f, 0x51, 0x01, 0x7a, 0xd4, 0x20, 0x48, 0x5d, 0x3c, 0x25, 0x5f, 0x51, 0x30, 0x5f, 0xd1,
		0x24, 0xe1, 0x59, 0x6c, 0xda, 0xf2, 0x27, 0x54, 0x93, 0x81, 0xe4, 0x4f, 0xa6, 0x06, 0x96, 0xc8,
		0xc1, 0x94, 0x3a, 0x76, 0x2a, 0x62, 0xa8, 0x16, 0x96, 0xaa, 0x63, 0xaa, 0x3a, 0xb6, 0xea, 0x62,
		0xac, 0x0c, 0xd6, 0x0a, 0x61, 0xee, 0x74, 0x69, 0x38, 0x98, 0x72, 0xf8, 0x62, 0x25, 0xb2, 0x33,
		0x7a, 0xdd, 0x2c, 0x0f, 0x32, 0x93, 0x65, 0x51, 0x37, 0x09, 0xfa, 0xbd, 0x40, 0xb6, 0x46, 0xf3,
		0xf4, 0xed, 0xde, 0x3e, 0x2c, 0x8e, 0x0a, 0x47, 0x85, 0xa3, 0xc2, 0x51, 0x15, 0xca, 0x51, 0x89,
		0xd7, 0x38, 0x56, 0xa8, 0x69, 0xac, 0x54, 0xc3, 0x58, 0xa1, 0xe4, 0x88, 0x66, 0x8d, 0x62, 0xed,
		0x12, 0x8d, 0xca, 0x35, 0x88, 0x5d, 0x14, 0x7f, 0xd5, 0x28, 0x26, 0xaa, 0x59, 0x53, 0xd8, 0x95,
		0x89, 0x28, 0xd6, 0x0c, 0x76, 0x62, 0x26, 0x05, 0x2d, 0xda, 0x73, 0x42, 0x0a, 0x9c, 0x8d, 0xb0,
		0xa7, 0x4c, 0x29, 0x70, 0x17, 0xbd, 0x38, 0xdb, 0x9a, 0x3d, 0x25, 0x15, 0x69, 0xb2, 0x4a, 0x45,
		0x0b, 0xdb, 0xa2, 0x01, 0x15, 0x2d, 0x38, 0x21, 0xf2, 0x91, 0x1c, 0x72, 0x42, 0xc4, 0x09, 0xd1,
		0xcf, 0x17, 0x88, 0x13, 0x22, 0xc7, 0xd8, 0xa9, 0x88, 0xa1, 0x5a, 0x58, 0xaa, 0x8e, 0xa9, 0xea,
		0xd8, 0xaa, 0x8b, 0xb1, 0xb2, 0x74, 0x84, 0x13, 0xa2, 0x07, 0x04, 0x7b, 0x9c, 0x10, 0x71, 0x42,
		0x84, 0xa3, 0xc2, 0x51, 0xe1, 0xa8, 0x70, 0x54, 0x0f, 0xdf, 0x31, 0x9c, 0x10, 0xdd, 0xfb, 0x8b,
		0x13, 0xa2, 0xa5, 0x86, 0xe3, 0x84, 0xc8, 0x8e, 0x89, 0x70, 0x42, 0x54, 0x78, 0x33, 0xe1, 0x84,
		0x48, 0x96, 0x69, 0x70, 0x42, 0xe4, 0xee, 0x84, 0x88, 0x0a, 0x09, 0xae, 0x2d, 0xc1, 0xb1, 0x05,
		0x38, 0x2e, 0x8f, 0xf0, 0xba, 0x17, 0x67, 0xa7, 0x87, 0xe7, 0xbd, 0xa3, 0x76, 0xef, 0xfd, 0x60,
		0x36, 0xd4, 0x46, 0x28, 0x7a, 0x6d, 0x04, 0x0b, 0xb7, 0xf2, 0x97, 0x31, 0xa6, 0x22, 0x96, 0x45,
		0x48, 0xb2, 0xd4, 0x5e, 0x55, 0x84, 0xc1, 0xc3, 0x28, 0x8a, 0xa0, 0xa8, 0x3d, 0x51, 0x14, 0x81,
		0xa2, 0x08, 0x3f, 0x78, 0x90, 0xe5, 0xdb, 0xcb, 0x32, 0xb7, 0x96, 0x29, 0x84, 0x40, 0x21, 0x84,
		0x35, 0x0a, 0x21, 0xd8, 0x25, 0x0c, 0xd6, 0x0b, 0x21, 0x48, 0xe5, 0x8c, 0x08, 0xe7, 0x8a, 0x48,
		0xd7, 0xb7, 0x15, 0xd2, 0xbd, 0x28, 0xb5, 0xa0, 0x0b, 0x6e, 0x6a, 0x20, 0xa7, 0x06, 0x76, 0x3a,
		0xa0, 0x57, 0x0c, 0x1d, 0x4d, 0xec, 0x8c, 0x4c, 0x21, 0x89, 0x43, 0x28, 0x79, 0x03, 0xa1, 0xcc,
		0x63, 0x19, 0x23, 0xc9, 0x52, 0xab, 0xe9, 0xf3, 0x16, 0x34, 0x29, 0x2b, 0xa2, 0x8a, 0xcd, 0x34,
		0x79, 0x91, 0xf4, 0x78, 0x31, 0x2a, 0x52, 0x87, 0x8a, 0x40, 0x45, 0xa0, 0x22, 0x50, 0x11, 0xa8,
		0x08, 0x54, 0x04, 0x2a, 0x02, 0x15, 0x81, 0x8a, 0x40, 0x45, 0x8a, 0x42, 0x45, 0x2c, 0xe6, 0x69,
		0x70, 0x3a, 0xee, 0xf6, 0x5d, 0x3a, 0x3a, 0x1c, 0x7f, 0x93, 0xa5, 0x45, 0x3c, 0x1b, 0x4f, 0x4d,
		0xc7, 0xa4, 0x26, 0x69, 0x99, 0xe0, 0x2c, 0x4c, 0xda, 0xff, 0x8d, 0xda, 0xc3, 0xd7, 0x64, 0xe9,
		0xac, 0xfc, 0xb6, 0x87, 0x73, 0x76, 0xae, 0x18, 0xd0, 0x71, 0x76, 0xce, 0xd9, 0xf9, 0x0f, 0x1e,
		0xc4, 0xd9, 0x39, 0x82, 0x15, 0x82, 0x15, 0x82, 0x95, 0x85, 0x07, 0x4a, 0xc4, 0x11, 0x8a, 0x71,
		0x05, 0x42, 0x13, 0x42, 0x13, 0x42, 0x13, 0x42, 0xd3, 0x0d, 0x8b, 0xef, 0x47, 0x49, 0xbe, 0x5d,
		0x17, 0xd4, 0x99, 0x76, 0x05, 0x1e, 0x2d, 0x7b, 0xff, 0x53, 0xf0, 0x16, 0xae, 0xc6, 0x7d, 0x4f,
		0xa5, 0x4b, 0x7c, 0x5a, 0xf7, 0x3b, 0x35, 0x2f, 0xec, 0x09, 0xde, 0xe7, 0x54, 0xb9, 0xc7, 0xa9,
		0xfd, 0xea, 0x1b, 0xf5, 0xbd, 0xc6, 0xde, 0xce, 0x6e, 0x7d, 0xaf, 0x59, 0x22, 0x1b, 0x28, 0xc8,
		0xa5, 0xc7, 0x13, 0xe4, 0xfb, 0xfb, 0xc4, 0x10, 0x65, 0x90, 0xef, 0x6f, 0x21, 0x03, 0x64, 0x16,
		0xdd, 0x37, 0xc0, 0x21, 0xb3, 0x08, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06,
		0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06, 0xa1, 0x06,
		0xa1, 0x06, 0xa1, 0x46, 0x5a, 0xa8, 0x21, 0xef, 0x52, 0xea, 0x1d, 0x3b, 0x7f, 0xb7, 0x8e, 0xf2,
		0x30, 0xdf, 0x4d, 0x66, 0xf2, 0x62, 0x3a, 0x91, 0x02, 0xa6, 0x65, 0x66, 0xe6, 0x7c, 0xc0, 0x19,
		0x82, 0xb4, 0xdb, 0xcf, 0xa3, 0xe4, 0xdc, 0x5e, 0x4a, 0xe6, 0xcd, 0x07, 0x93, 0x8e, 0x79, 0x1f,
		0x36, 0x6d, 0x27, 0xab, 0x98, 0x64, 0xcc, 0x1b, 0x5c, 0x78, 0xd9, 0x94, 0xe9, 0x35, 0x52, 0x31,
		0x7f, 0x66, 0xbc, 0xa4, 0x62, 0xfa, 0x06, 0x03, 0xd2, 0x52, 0x5a, 0xf9, 0xf4, 0x7d, 0x1b, 0x30,
		0xe1, 0x67, 0x5c, 0xcf, 0xbd, 0x61, 0x51, 0xc6, 0x5f, 0x78, 0x15, 0xdf, 0x2a, 0xe0, 0x48, 0x03,
		0x8f, 0x1a, 0x00, 0xa9, 0x01, 0x91, 0x06, 0x20, 0xc9, 0x48, 0x2b, 0xdc, 0xe9, 0xbd, 0x25, 0x6a,
		0xa9, 0xad, 0x42, 0xa3, 0xd6, 0xf4, 0xfc, 0x4c, 0xb0, 0x4f, 0xeb, 0xe0, 0xe9, 0x40, 0x3f, 0xd0,
		0x0f, 0xf4, 0x03, 0xfd, 0xd6, 0xac, 0x3d, 0x36, 0x61, 0x27, 0x35, 0x1d, 0x49, 0xe8, 0x97, 0x38,
		0xbe, 0x3d, 0x1e, 0x4b, 0xab, 0x9b, 0x9b, 0x5b, 0x8b, 0xff, 0xbb, 0xa1, 0xb3, 0x6d, 0x0d, 0x90,
		0x33, 0x1b, 0xfe, 0x77, 0xa4, 0x79, 0x6f, 0xc5, 0xdd, 0x56, 0x18, 0x07, 0x51, 0x7b, 0x25, 0xba,
		0x87, 0xa7, 0xb1, 0xa8, 0x53, 0x8a, 0x71, 0x4a, 0x38, 0x25, 0x9c, 0x12, 0x4e, 0x09, 0xa7, 0xf4,
		0x40, 0xa7, 0x14, 0x0f, 0x9d, 0x52, 0x5c, 0x18, 0xa7, 0xc4, 0xa9, 0xbc, 0xed, 0x93, 0xdb, 0x9b,
		0x36, 0xc1, 0xd5, 0x89, 0xfb, 0x86, 0x1d, 0x5c, 0x9d, 0xf0, 0x33, 0xae, 0xe0, 0x60, 0xc5, 0x45,
		0xdc, 0xc0, 0xc1, 0xca, 0x72, 0xbb, 0x80, 0x83, 0x15, 0x88, 0x0c, 0x44, 0x06, 0x22, 0x63, 0xdd,
		0xda, 0x39, 0x58, 0xb1, 0xa4, 0x61, 0x71, 0xb0, 0x02, 0xf4, 0x03, 0xfd, 0x40, 0x3f, 0x1a, 0x16,
		0x07, 0x2b, 0xde, 0x38, 0x25, 0x0e, 0x56, 0x70, 0x4a, 0x38, 0x25, 0x9c, 0x12, 0x4e, 0x89, 0x83,
		0x15, 0xe7, 0x4f, 0xe2, 0x60, 0xe5, 0x07, 0x07, 0x2b, 0x5c, 0x75, 0x94, 0x7a, 0xbf, 0x4e, 0xdf,
		0xab, 0xa3, 0x6b, 0x8e, 0xef, 0x47, 0xb3, 0x78, 0x37, 0x9e, 0x44, 0x11, 0xaf, 0x38, 0x5a, 0x39,
		0x96, 0xb3, 0x7a, 0x1c, 0x67, 0xfd, 0x3a, 0x63, 0x9d, 0xee, 0x12, 0x3e, 0xc4, 0x93, 0x74, 0x97,
		0x78, 0xc0, 0x47, 0xb2, 0x76, 0xa5, 0x31, 0xec, 0xe7, 0x9f, 0x4d, 0x92, 0x47, 0xad, 0x21, 0xd2,
		0x07, 0xad, 0xcf, 0xa6, 0xf5, 0xa7, 0xfd, 0x63, 0xf8, 0x5b, 0x47, 0xb1, 0x75, 0x8a, 0x78, 0xdd,
		0xcd, 0x70, 0x60, 0x33, 0x96, 0x0f, 0xfb, 0xab, 0x34, 0xb4, 0xf0, 0x99, 0xe5, 0x52, 0x27, 0xb1,
		0x48, 0x94, 0xc1, 0x3a, 0x6f, 0x15, 0x3c, 0x3f, 0xb3, 0x7c, 0x6e, 0xe6, 0x47, 0x96, 0x55, 0x27,
		0xcc, 0xf2, 0xa0, 0x13, 0x77, 0xbb, 0x6d, 0x1b, 0xf5, 0x2a, 0x16, 0xde, 0xc2, 0xfc, 0xe3, 0xc1,
		0x77, 0xf0, 0x1d, 0x7c, 0x07, 0xdf, 0xc1, 0x77, 0x35, 0x7c, 0x8f, 0xa2, 0x76, 0x90, 0xc7, 0x5f,
		0xec, 0x23, 0xfb, 0xe4, 0xc1, 0xf6, 0x31, 0xdd, 0x66, 0x07, 0x72, 0x40, 0x1d, 0x50, 0x07, 0xd4,
		0x01, 0xf5, 0x92, 0x81, 0xfa, 0x58, 0x63, 0x16, 0x40, 0xf5, 0xc9, 0x93, 0xed, 0xc3, 0x7a, 0x15,
		0x48, 0x07, 0xd2, 0x81, 0xf4, 0x55, 0x83, 0xf4, 0x2c, 0x4f, 0xed, 0x51, 0xff, 0x39, 0x44, 0x7f,
		0x56, 0x22, 0x44, 0x8f, 0xcd, 0x17, 0x13, 0x07, 0xad, 0xb0, 0x17, 0x9e, 0x45, 0x71, 0x94, 0x5f,
		0xda, 0x47, 0xf6, 0x85, 0x11, 0xec, 0x23, 0xfc, 0xd1, 0xc1, 0x1f, 0x07, 0x47, 0xa7, 0xb5, 0xd3,
		0x3a, 0x48, 0x0f, 0xd2, 0x83, 0xf4, 0xab, 0x86, 0xf4, 0x23, 0x84, 0xc9, 0x07, 0xcf, 0x17, 0x40,
		0xfb, 0x86, 0xc5, 0x67, 0x1e, 0x24, 0xfd, 0x8b, 0xc1, 0x1a, 0x5c, 0x95, 0xc8, 0x83, 0x5c, 0x84,
		0x5f, 0x03, 0xd3, 0xba, 0xe8, 0x05, 0xbd, 0x30, 0xff, 0x9c, 0xd9, 0xf7, 0x1f, 0x37, 0x9e, 0x0f,
		0xc2, 0x83, 0xf0, 0x20, 0xfc, 0x8a, 0x21, 0x7c, 0x3f, 0x4a, 0xf2, 0x67, 0x02, 0xe0, 0x6e, 0xb1,
		0x81, 0x8b, 0x50, 0x77, 0x26, 0x81, 0xc4, 0x6a, 0xc9, 0x6e, 0x4c, 0xc2, 0xad, 0x78, 0xa4, 0xbb,
		0x2f, 0x69, 0x74, 0xdc, 0x11, 0xe8, 0xb6, 0x24, 0xda, 0x65, 0x49, 0xeb, 0x95, 0xd6, 0x9b, 0xcd,
		0x02, 0xbf, 0x54, 0x4f, 0xf3, 0xf4, 0x4f, 0xca, 0x15, 0x68, 0x46, 0x17, 0xfd, 0x8b, 0x20, 0x4c,
		0x4d, 0x18, 0x84, 0xed, 0x76, 0x6a, 0xb2, 0xcc, 0xc8, 0x04, 0x9c, 0xb7, 0x8d, 0x63, 0x5f, 0xb6,
		0xd8, 0x26, 0x98, 0x25, 0x98, 0x25, 0x98, 0x25, 0x98, 0x25, 0x98, 0x25, 0x98, 0x25, 0x98, 0x25,
		0x98, 0x25, 0x98, 0x5d, 0x99, 0x60, 0x36, 0x31, 0xb9, 0xfd, 0xc8, 0x75, 0xf0, 0x50, 0x42, 0x4a,
		0x42, 0x4a, 0x42, 0xca, 0x15, 0x0b, 0x29, 0xed, 0x6d, 0xfc, 0xb5, 0xb9, 0x44, 0x07, 0x8b, 0xcf,
		0x3c, 0x0e, 0xf3, 0xdc, 0xa4, 0x89, 0xf5, 0x98, 0xb2, 0xf2, 0xef, 0x8f, 0x61, 0xd0, 0xd9, 0x0f,
		0x5e, 0x55, 0x83, 0xbd, 0x93, 0x6f, 0xf5, 0xab, 0xf5, 0x4f, 0x9f, 0x36, 0x67, 0x7f, 0xd2, 0xb8,
		0xda, 0xf8, 0xb6, 0xfd, 0x74, 0xef, 0xea, 0xc6, 0x8f, 0xeb, 0x57, 0x7f, 0xb1, 0x67, 0x66, 0x27,
		0x36, 0xd7, 0xe9, 0xed, 0xfb, 0xc3, 0x7f, 0x96, 0x7a, 0xb1, 0xbc, 0xda, 0x93, 0x47, 0x51, 0x96,
		0xef, 0xe7, 0xb9, 0xe5, 0xea, 0xaf, 0xaf, 0xa3, 0xe4, 0x20, 0x36, 0x03, 0x58, 0xcb, 0xec, 0x06,
		0x9b, 0x83, 0xe0, 0x78, 0xe6, 0xc9, 0xb5, 0x67, 0x8d, 0xc6, 0xce, 0x6e, 0xa3, 0x51, 0xdd, 0xdd,
		0xde, 0xad, 0xee, 0x35, 0x9b, 0xb5, 0x9d, 0x9a, 0x4d, 0x16, 0xf8, 0x36, 0x6d, 0x9b, 0xd4, 0xb4,
		0x5f, 0x5c, 0x56, 0x9e, 0xaf, 0x25, 0xfd, 0x38, 0x2e, 0x51, 0xfc, 0xd5, 0xeb, 0x46, 0x32, 0xd7,
		0x13, 0x26, 0x0f, 0xe6, 0x7a, 0x02, 0xf1, 0x1d, 0xf1, 0x1d, 0xf1, 0x9d, 0x15, 0x8b, 0x5d, 0x85,
		0xeb, 0x09, 0x54, 0x18, 0x7a, 0x74, 0x85, 0xa1, 0xe5, 0x2b, 0x45, 0xb9, 0x29, 0xe9, 0x93, 0x47,
		0x17, 0x26, 0xcd, 0xec, 0xd5, 0xf4, 0x19, 0x3f, 0xcf, 0xb3, 0xa2, 0x3e, 0x55, 0x8a, 0xfa, 0xf8,
		0xe0, 0xf2, 0x28, 0xea, 0xf3, 0x90, 0xb0, 0xd3, 0x56, 0x51, 0x9f, 0xd6, 0x64, 0x17, 0x58, 0x0e,
		0xb3, 0xc7, 0xcf, 0xf5, 0xbc, 0x9d, 0x0e, 0xd1, 0x30, 0xd1, 0xf0, 0xaa, 0x46, 0xc3, 0xd6, 0x5b,
		0xea, 0xc4, 0x59, 0x2f, 0x88, 0xa3, 0x8e, 0x19, 0x78, 0xf9, 0x20, 0x4a, 0x72, 0x93, 0x7e, 0x09,
		0x63, 0xb9, 0x6a, 0xd6, 0xb7, 0x0f, 0x67, 0xd9, 0x1e, 0x66, 0xe8, 0x7d, 0xad, 0x5e, 0xad, 0x52,
		0x3d, 0x5b, 0xa5, 0x7a, 0xb6, 0x65, 0xbc, 0x93, 0xc6, 0x3d, 0x35, 0xfc, 0x53, 0xc3, 0x41, 0x1d,
		0x3c, 0xb4, 0x8b, 0x8b, 0x96, 0xf1, 0x51, 0x4e, 0x35, 0x58, 0xb0, 0xf8, 0x7e, 0x94, 0xe4, 0xb5,
		0x1d, 0xc1, 0x02, 0xda, 0x3b, 0x02, 0x8f, 0x96, 0xc9, 0x40, 0x9a, 0x7c, 0xc9, 0x6c, 0xd0, 0x35,
		0xe9, 0x8c, 0x24, 0x61, 0x60, 0x5f, 0x18, 0x46, 0x38, 0x43, 0x69, 0x3a, 0x8e, 0x42, 0x52, 0x8b,
		0xd0, 0xf6, 0x9d, 0x7f, 0xf5, 0x82, 0x99, 0x4b, 0xae, 0x5e, 0xfd, 0x4e, 0xb3, 0xb9, 0xdd, 0x2c,
		0xd1, 0xeb, 0x7f, 0x52, 0x8c, 0xa7, 0x9e, 0xac, 0x40, 0x37, 0x9a, 0x41, 0x84, 0x9d, 0x9a, 0x4e,
		0x6a, 0xb2, 0xcf, 0x4a, 0xf1, 0xfc, 0xc2, 0x68, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb,
		0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0x7e, 0xc5, 0xdb, 0x34,
		0xda, 0xb2, 0x9d, 0x2e, 0x31, 0xca, 0x12, 0xd8, 0x1a, 0x9f, 0x20, 0x96, 0xa9, 0x96, 0x5b, 0xd6,
		0x0b, 0xce, 0x4d, 0x62, 0x52, 0xbb, 0x6f, 0x68, 0x8e, 0x41, 0xcd, 0x3c, 0x9f, 0xb3, 0x57, 0x0f,
		0xb9, 0x11, 0x67, 0xaf, 0x6e, 0xb8, 0x4f, 0xc9, 0xcf, 0x5e, 0x2d, 0xa7, 0x71, 0x2c, 0x6c, 0x04,
		0xab, 0xe9, 0x1c, 0x42, 0xd0, 0x82, 0x1c, 0x83, 0x1c, 0x83, 0x1c, 0x63, 0x5b, 0x8e, 0xb1, 0x0d,
		0x55, 0x73, 0xd1, 0x50, 0x27, 0x4a, 0xb3, 0x3c, 0xf8, 0x6f, 0x18, 0xe5, 0x72, 0x02, 0xf3, 0xad,
		0x61, 0xd2, 0x6d, 0x03, 0x3f, 0x2d, 0xe4, 0x8d, 0x76, 0x29, 0xb0, 0xd3, 0x00, 0x3d, 0x45, 0xf0,
		0xd3, 0x02, 0x41, 0x75, 0x30, 0x54, 0x07, 0x45, 0x5d, 0x70, 0x14, 0xd6, 0x29, 0x84, 0xf6, 0x8c,
		0x98, 0x86, 0xbd, 0xb0, 0x63, 0xfa, 0x51, 0x92, 0xef, 0x34, 0x24, 0x37, 0xcc, 0x18, 0xbf, 0x9e,
		0x09, 0x0e, 0x21, 0xab, 0x6d, 0x4f, 0xbe, 0x64, 0x37, 0xfc, 0x9a, 0x96, 0xd6, 0xad, 0xe4, 0x58,
		0x16, 0x86, 0x53, 0xd2, 0xbe, 0xa7, 0xe3, 0x29, 0x8a, 0xa0, 0xc2, 0x70, 0x30, 0x6f, 0x22, 0x0a,
		0x9a, 0xb8, 0x6b, 0x13, 0x91, 0xbd, 0xf6, 0xec, 0x9d, 0xd5, 0x3c, 0x29, 0xe6, 0xd3, 0x4f, 0x0a,
		0x22, 0xfd, 0x4b, 0xd4, 0xb0, 0x1a, 0x70, 0x80, 0x8b, 0xf0, 0xab, 0x0b, 0xea, 0xb1, 0x38, 0x2c,
		0xc4, 0x03, 0xe2, 0x01, 0xf1, 0x80, 0x78, 0x40, 0x3c, 0x20, 0x1e, 0x10, 0x0f, 0x88, 0x07, 0xc4,
		0x03, 0xe2, 0x01, 0xf1, 0x28, 0x2f, 0xf1, 0xc8, 0x4c, 0xab, 0x9b, 0xb4, 0x5d, 0x70, 0x8f, 0x5b,
		0x47, 0x86, 0x7e, 0x40, 0x3f, 0xa0, 0x1f, 0xd0, 0x0f, 0xe8, 0x07, 0xf4, 0x03, 0xfa, 0x01, 0xfd,
		0x80, 0x7e, 0x40, 0x3f, 0xa0, 0x1f, 0x1e, 0xd0, 0x0f, 0xaf, 0xf3, 0xc2, 0x84, 0xae, 0x1a, 0x4c,
		0x9f, 0xef, 0xe2, 0xca, 0xc1, 0x7c, 0x02, 0xbd, 0xd5, 0x1b, 0x08, 0xf6, 0x5f, 0xaa, 0xcd, 0x9b,
		0xde, 0xa3, 0x0a, 0x95, 0x62, 0xd9, 0xc3, 0xa3, 0xc7, 0x17, 0x2c, 0x79, 0xb8, 0x4e, 0xf2, 0xb0,
		0x22, 0x7f, 0x24, 0x79, 0xb8, 0x8c, 0x4e, 0x42, 0x2c, 0x79, 0x38, 0x6c, 0x87, 0xbd, 0x3c, 0xfa,
		0x62, 0x82, 0x21, 0x72, 0xcb, 0x8b, 0x67, 0x37, 0xc6, 0x43, 0x32, 0x43, 0x32, 0x43, 0x32, 0x43,
		0x32, 0x2b, 0x94, 0x64, 0x36, 0x8f, 0x61, 0x41, 0x3e, 0x18, 0x58, 0x5e, 0x3f, 0xab, 0x35, 0x04,
		0xc7, 0x38, 0x48, 0xfa, 0x17, 0x83, 0xc5, 0xbb, 0x5a, 0xf1, 0x13, 0x25, 0xee, 0xd1, 0xe0, 0x1c,
		0x71, 0x8e, 0x38, 0x47, 0x9c, 0xe3, 0x63, 0x77, 0x0c, 0xe7, 0x49, 0xf7, 0xfe, 0xe2, 0x3c, 0x69,
		0xa9, 0xe1, 0x38, 0x4f, 0xb2, 0x63, 0x22, 0x9c, 0x27, 0x95, 0xcd, 0x6a, 0x38, 0x4f, 0x2a, 0x24,
		0xf9, 0xe0, 0x1e, 0x0d, 0xc4, 0x03, 0xe2, 0x01, 0xf1, 0x80, 0x78, 0x40, 0x3c, 0x20, 0x1e, 0x10,
		0x0f, 0x88, 0x07, 0xc4, 0x03, 0xe2, 0x01, 0xf1, 0x10, 0x27, 0x1e, 0xdc, 0xa3, 0x81, 0x7e, 0x40,
		0x3f, 0xa0, 0x1f, 0xd0, 0x0f, 0xe8, 0x07, 0xf4, 0x03, 0xfa, 0x01, 0xfd, 0x80, 0x7e, 0x40, 0x3f,
		0xa0, 0x1f, 0xa2, 0x4f, 0xe4, 0x1e, 0xcd, 0x83, 0xef, 0xd1, 0x8c, 0xae, 0x7f, 0xd0, 0xc0, 0xc5,
		0x9d, 0x35, 0x78, 0x60, 0x05, 0x15, 0xab, 0xd7, 0x95, 0xd2, 0x7e, 0x2b, 0x4f, 0xc6, 0x21, 0xec,
		0x9b, 0xd1, 0xf4, 0x0e, 0xc7, 0xb3, 0x3b, 0x3d, 0x1e, 0xcf, 0xe9, 0xf4, 0x30, 0x8b, 0xb2, 0xd3,
		0xdf, 0x86, 0x73, 0x3a, 0xfd, 0x30, 0x9c, 0xd3, 0xe9, 0x51, 0xd6, 0xfb, 0xed, 0x7a, 0x4a, 0x25,
		0xea, 0x2d, 0x93, 0xf5, 0x3a, 0xf6, 0x1b, 0xca, 0x0c, 0x1e, 0x4a, 0x17, 0x19, 0x0f, 0x55, 0x09,
		0xba, 0xc8, 0xb8, 0x51, 0x15, 0xe8, 0x22, 0xb3, 0xd4, 0x46, 0xa0, 0x8b, 0x0c, 0x17, 0x41, 0x9d,
		0x43, 0x90, 0x1a, 0x14, 0xe9, 0x40, 0x52, 0x31, 0x58, 0x8e, 0xd8, 0x45, 0xd0, 0xac, 0xd7, 0x19,
		0x5f, 0x42, 0xd1, 0x3b, 0x01, 0xba, 0x65, 0x4c, 0xce, 0x7e, 0xb4, 0xa1, 0x4e, 0x11, 0xf2, 0xb4,
		0xa0, 0x4f, 0x1d, 0x02, 0xd5, 0xa1, 0x50, 0x17, 0x12, 0x65, 0x25, 0x30, 0xce, 0x7e, 0xee, 0x8d,
		0x5f, 0x9c, 0xfd, 0xdc, 0xe3, 0x83, 0x70, 0xf6, 0x63, 0x6f, 0x3c, 0xce, 0x7e, 0x0a, 0x6b, 0x22,
		0x9c, 0xfd, 0x14, 0xe1, 0xe9, 0xab, 0x9c, 0x7a, 0x36, 0x08, 0xff, 0x3f, 0x77, 0xe3, 0xb6, 0x32,
		0xe3, 0x98, 0x1f, 0x52, 0x28, 0xf8, 0x78, 0x69, 0x3a, 0x61, 0x3f, 0x1e, 0x86, 0x65, 0xcd, 0x6a,
		0xb5, 0x0a, 0xaf, 0x81, 0xd7, 0xc0, 0x6b, 0xe0, 0x35, 0xf0, 0x1a, 0x78, 0x0d, 0xbc, 0x06, 0x5e,
		0x03, 0xaf, 0x81, 0xd7, 0xc0, 0x6b, 0x4a, 0xcc, 0x6b, 0xc6, 0x17, 0x5b, 0x74, 0x99, 0xcd, 0xcd,
		0x41, 0x21, 0x1d, 0x90, 0x0e, 0x48, 0x07, 0xa4, 0x03, 0xd2, 0x01, 0xe9, 0x80, 0x74, 0x40, 0x3a,
		0x20, 0x1d, 0x90, 0x0e, 0x48, 0x87, 0x07, 0xa4, 0x83, 0x8b, 0x34, 0xca, 0x57, 0x28, 0xb2, 0x5e,
		0x87, 0x2e, 0x34, 0xd6, 0xa8, 0x26, 0x5d, 0x68, 0x48, 0x3e, 0xf6, 0x84, 0x2c, 0x92, 0x7c, 0xac,
		0xe8, 0x19, 0xe8, 0x42, 0x83, 0x4e, 0x86, 0x4e, 0x86, 0x4e, 0x86, 0x4e, 0xe6, 0x81, 0x4e, 0x46,
		0x17, 0x1a, 0xf7, 0x3c, 0xee, 0x29, 0xf7, 0x70, 0x70, 0x89, 0xb8, 0x44, 0x5c, 0x22, 0x2e, 0xd1,
		0x07, 0x97, 0xc8, 0xd1, 0xd1, 0xbd, 0xbf, 0x38, 0x3a, 0x5a, 0x6a, 0x38, 0x8e, 0x8e, 0xec, 0x98,
		0x08, 0x47, 0x47, 0x65, 0xb3, 0x1a, 0x8e, 0x8e, 0x0a, 0x49, 0x39, 0xb8, 0x87, 0x03, 0xaf, 0x81,
		0xd7, 0xc0, 0x6b, 0xe0, 0x35, 0xf0, 0x1a, 0x78, 0x0d, 0xbc, 0x06, 0x5e, 0x03, 0xaf, 0x81, 0xd7,
		0xc0, 0x6b, 0x8a, 0xce, 0x6b, 0xb8, 0x87, 0x03, 0xe9, 0x80, 0x74, 0x40, 0x3a, 0x20, 0x1d, 0x90,
		0x0e, 0x48, 0x07, 0xa4, 0x03, 0xd2, 0x01, 0xe9, 0x80, 0x74, 0x40, 0x3a, 0x04, 0x9e, 0xc8, 0x3d,
		0x9c, 0xfb, 0xdd, 0xc3, 0xa1, 0x8b, 0x8d, 0x6b, 0x13, 0x70, 0xf5, 0xea, 0xfd, 0x68, 0x5d, 0xf3,
		0xbe, 0xd7, 0x29, 0x55, 0xc3, 0x1a, 0xab, 0x97, 0xbd, 0x44, 0x2e, 0x79, 0x89, 0x35, 0xad, 0xa9,
		0xd3, 0xb4, 0xa6, 0x48, 0xca, 0x02, 0x4d, 0x6b, 0x7c, 0x6e, 0x5a, 0x13, 0x67, 0xbd, 0x20, 0x8e,
		0x3a, 0x66, 0x80, 0xd7, 0x72, 0x82, 0xe9, 0x5c, 0xfb, 0xef, 0xc5, 0xe1, 0x6c, 0xdf, 0x58, 0xbb,
		0x4e, 0xff, 0xa8, 0xd5, 0xad, 0xa7, 0x7f, 0x08, 0xb1, 0x20, 0x3a, 0xe6, 0xe8, 0xe2, 0x9e, 0x1a,
		0xfe, 0xa9, 0xe1, 0xa0, 0x0e, 0x1e, 0x16, 0x83, 0x46, 0x89, 0x29, 0xa6, 0x73, 0x4a, 0x69, 0x6d,
		0x47, 0xc2, 0xe0, 0xc7, 0xf8, 0xb2, 0x23, 0xf0, 0x68, 0x59, 0x65, 0x54, 0x50, 0x9f, 0xd6, 0x50,
		0x42, 0x95, 0xe4, 0x2d, 0x2d, 0xe5, 0x53, 0x53, 0xbb, 0x12, 0x54, 0x3a, 0x55, 0x14, 0x4e, 0xed,
		0x57, 0xbf, 0xd3, 0x6c, 0x6e, 0x37, 0x4b, 0xf4, 0xfa, 0x0b, 0x22, 0xfd, 0x9d, 0xac, 0x40, 0x19,
		0x98, 0x41, 0x84, 0x9d, 0x9a, 0x4e, 0x6a, 0xb2, 0xcf, 0x4a, 0xf1, 0xfc, 0xc2, 0x68, 0xc4, 0xdb,
		0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb, 0xc4, 0xdb,
		0xc4, 0xdb, 0x7e, 0xc5, 0xdb, 0x9c, 0xf7, 0x4a, 0x9d, 0xf7, 0xda, 0x3b, 0xe6, 0xb7, 0x70, 0xd0,
		0xfa, 0xc4, 0xe1, 0xeb, 0xb5, 0xfd, 0x5a, 0x5d, 0xbc, 0xce, 0x8a, 0x95, 0x93, 0xea, 0x47, 0x1e,
		0xd9, 0x2f, 0x67, 0x45, 0x8f, 0x7f, 0xf7, 0x4b, 0xbc, 0xf7, 0x4a, 0x9e, 0x86, 0x49, 0xd6, 0xeb,
		0xa6, 0xf9, 0xd2, 0xaf, 0x7c, 0x1a, 0xf7, 0x5e, 0x3f, 0x72, 0x49, 0x7b, 0xb4, 0x73, 0x1c, 0x6f,
		0x8d, 0x36, 0xdb, 0xa4, 0xc9, 0x02, 0xb4, 0xd8, 0x36, 0x0d, 0x16, 0xa3, 0xbd, 0x62, 0x34, 0x57,
		0x86, 0xd6, 0xba, 0xc5, 0x64, 0x5b, 0xc7, 0xe7, 0x95, 0xd6, 0x64, 0x17, 0x58, 0x4e, 0xc0, 0x19,
		0x3f, 0xd7, 0xf3, 0x0c, 0x9c, 0x2a, 0x19, 0x38, 0x45, 0x52, 0xc4, 0xc8, 0xc0, 0xf1, 0x3d, 0x03,
		0xe7, 0x22, 0xef, 0x07, 0x59, 0xf4, 0xff, 0x8c, 0xac, 0x50, 0x3f, 0x1d, 0x05, 0x81, 0x1e, 0x81,
		0xde, 0x1d, 0x1c, 0xa9, 0xc1, 0x92, 0x0e, 0x3c, 0xc9, 0xc8, 0x27, 0x08, 0xf4, 0x0b, 0xf8, 0x82,
		0x40, 0x3f, 0x33, 0x71, 0x04, 0xfa, 0x87, 0x8f, 0x83, 0x40, 0xef, 0xed, 0xab, 0x47, 0xa0, 0x77,
		0xf2, 0x54, 0x04, 0xfa, 0x7b, 0x85, 0x0f, 0xa5, 0x10, 0xe8, 0x27, 0x3a, 0xa2, 0xd5, 0x96, 0x58,
		0xdc, 0x86, 0x72, 0xad, 0xc5, 0x70, 0x1b, 0x0a, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06,
		0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06, 0x2d, 0x06,
		0x2d, 0x06, 0x2d, 0xc6, 0x77, 0x2d, 0x86, 0x7c, 0x49, 0xa9, 0x37, 0xeb, 0xe8, 0x8d, 0xba, 0x4a,
		0x99, 0x9c, 0x8e, 0xef, 0x2a, 0x6b, 0xf2, 0x89, 0xa2, 0xcd, 0xd8, 0xb2, 0x15, 0x55, 0x1b, 0x59,
		0xc2, 0x32, 0x1e, 0x61, 0x11, 0x8f, 0xb3, 0x83, 0x87, 0xbf, 0xc5, 0x47, 0xbc, 0xc1, 0xca, 0xf0,
		0xa2, 0x68, 0x27, 0x6c, 0x99, 0xec, 0xd1, 0x6f, 0x6f, 0xca, 0x74, 0x66, 0x9e, 0xf5, 0x48, 0x5b,
		0x5a, 0x4e, 0x98, 0x5d, 0x5a, 0x19, 0xb1, 0xa1, 0x80, 0x58, 0x54, 0x3a, 0x6c, 0x29, 0x1a, 0xd6,
		0x95, 0x0b, 0xeb, 0x0a, 0x85, 0x5d, 0x25, 0x42, 0x17, 0xff, 0x96, 0x15, 0x3e, 0xaf, 0xb7, 0x8d,
		0xbd, 0x44, 0xf5, 0xeb, 0x47, 0x92, 0xa8, 0xae, 0x28, 0x49, 0x92, 0xa8, 0x4e, 0xa2, 0xfa, 0x0f,
		0x1e, 0x14, 0x76, 0xa2, 0x20, 0x0b, 0x3b, 0x91, 0xfd, 0xd3, 0xd1, 0xe9, 0x93, 0x49, 0x56, 0xf7,
		0x08, 0x0e, 0xa4, 0x60, 0x41, 0x1c, 0x1e, 0xc4, 0x61, 0x42, 0x16, 0x2e, 0xfc, 0x54, 0x4b, 0xac,
		0x1f, 0x90, 0x86, 0x1d, 0xb9, 0x63, 0xd1, 0xb0, 0x23, 0x74, 0x18, 0x5a, 0xe3, 0x30, 0x94, 0xc3,
		0x50, 0x9f, 0x20, 0x48, 0x07, 0x8a, 0xec, 0x42, 0x92, 0x65, 0x68, 0x12, 0x83, 0xa8, 0xb9, 0xc8,
		0x67, 0xac, 0x98, 0x08, 0x77, 0xff, 0x9a, 0x8e, 0x44, 0xcb, 0x2f, 0x6d, 0x58, 0x53, 0x84, 0x37,
		0x2d, 0x98, 0x53, 0x87, 0x3b, 0x75, 0xd8, 0xd3, 0x85, 0x3f, 0x19, 0x18, 0x14, 0x82, 0xc3, 0xe9,
		0xd2, 0xe8, 0xb5, 0xfc, 0x8a, 0x4d, 0xd8, 0x49, 0x4d, 0x47, 0xa1, 0xe7, 0x57, 0x6d, 0x57, 0x70,
		0x8c, 0xe3, 0xb1, 0x88, 0xbf, 0xb9, 0x39, 0x3a, 0x54, 0xdb, 0x9a, 0xa2, 0xf2, 0x0a, 0x37, 0xc3,
		0xb4, 0x7c, 0x4d, 0xfd, 0x4e, 0x1b, 0xb2, 0x7a, 0x6d, 0x5d, 0x29, 0x8c, 0xc7, 0xff, 0xe1, 0xff,
		0xf0, 0x7f, 0xbe, 0xfa, 0x3f, 0x29, 0x5a, 0xa0, 0x47, 0x0f, 0xb4, 0x69, 0x82, 0x12, 0x5d, 0x50,
		0x83, 0x4d, 0x4d, 0xf8, 0x74, 0x00, 0xa3, 0xda, 0x70, 0xea, 0x0c, 0x56, 0x9d, 0xc1, 0xab, 0x1b,
		0x98, 0x95, 0x85, 0x5b, 0x61, 0xd8, 0xd5, 0xa3, 0x1f, 0x0b, 0x3b, 0x2e, 0x6a, 0x9b, 0x24, 0x8f,
		0xf2, 0x4b, 0x59, 0x2a, 0xb2, 0x10, 0x53, 0x2a, 0x34, 0x12, 0xad, 0x1c, 0x8e, 0x3f, 0xda, 0x8b,
		0x30, 0x53, 0xdc, 0xe7, 0x93, 0x85, 0xdd, 0x7f, 0x75, 0x78, 0xfa, 0xe1, 0x5f, 0xc7, 0x07, 0x15,
		0xcd, 0xae, 0xad, 0x99, 0x78, 0xfb, 0xe5, 0xd9, 0xaf, 0x6f, 0x6a, 0x23, 0xcd, 0xad, 0xec, 0xe1,
		0xf1, 0x1f, 0x8d, 0x8a, 0xda, 0xd0, 0x57, 0x4f, 0x57, 0x60, 0x3d, 0x77, 0x14, 0xd7, 0x53, 0x65,
		0xa4, 0x13, 0xfa, 0x05, 0xeb, 0xdb, 0x73, 0xc5, 0x24, 0xe1, 0x59, 0x6c, 0xda, 0x7a, 0xb1, 0xfd,
		0x64, 0x40, 0x42, 0x7b, 0x42, 0x7b, 0x42, 0x7b, 0x42, 0x7b, 0x42, 0xfb, 0x99, 0x1d, 0x77, 0xd6,
		0xed, 0xc6, 0x26, 0x4c, 0x34, 0xc3, 0xfa, 0x1a, 0x4e, 0x71, 0x61, 0x6d, 0x32, 0x7d, 0xc9, 0x2b,
		0x43, 0xf3, 0xc2, 0x31, 0xe2, 0x18, 0x71, 0x8c, 0x38, 0xc6, 0xdb, 0x76, 0x1c, 0x9a, 0x97, 0xd0,
		0xc2, 0xbe, 0x47, 0xf4, 0x92, 0x5a, 0xda, 0xdf, 0xdf, 0x1c, 0xfe, 0xba, 0xff, 0xfe, 0x03, 0xba,
		0x97, 0xbd, 0x25, 0x7d, 0xfd, 0xfb, 0xd1, 0x07, 0xed, 0x45, 0x45, 0xfc, 0x72, 0x1b, 0xe7, 0x17,
		0xea, 0x30, 0x5e, 0xa8, 0xe8, 0xc2, 0x22, 0x43, 0x51, 0xb9, 0x8e, 0x7d, 0x7d, 0x65, 0xf8, 0xfa,
		0xdb, 0xad, 0xc9, 0x6d, 0xa6, 0xad, 0xb0, 0x63, 0xb5, 0x40, 0xa6, 0xfc, 0x8b, 0x97, 0xc8, 0x1b,
		0xcb, 0xf4, 0x92, 0xa7, 0x33, 0xb2, 0xa7, 0x9d, 0x53, 0x41, 0xb2, 0xc7, 0x0a, 0x48, 0xf5, 0xc8,
		0x1e, 0x73, 0x48, 0xe5, 0x4a, 0x9f, 0x3d, 0x9d, 0x91, 0x3e, 0x6d, 0xbb, 0xae, 0xf4, 0xdd, 0x2e,
		0xd0, 0x62, 0x9d, 0xe9, 0x3b, 0xad, 0x47, 0xda, 0xfd, 0xd5, 0x71, 0x7f, 0xb8, 0x3f, 0xdc, 0x9f,
		0x17, 0xee, 0x8f, 0xe4, 0x69, 0x4f, 0xd9, 0x82, 0x1a, 0x6b, 0xd0, 0x84, 0x4f, 0x07, 0x30, 0xaa,
		0x0d, 0xa7, 0xce, 0x60, 0xd5, 0x19, 0xbc, 0xba, 0x81, 0x59, 0x79, 0xe1, 0x6d, 0x8d, 0x83, 0x24,
		0x7b, 0x31, 0x25, 0xc9, 0xd3, 0xb6, 0xc7, 0x25, 0x79, 0xba, 0x90, 0x5b, 0xde, 0x8f, 0xf5, 0x24,
		0x79, 0xda, 0x37, 0x47, 0x43, 0xf2, 0xf4, 0x7d, 0x4c, 0x97, 0xe4, 0x69, 0x42, 0x7b, 0x42, 0x7b,
		0x42, 0x7b, 0x42, 0xfb, 0x5b, 0x76, 0x1c, 0xc9, 0xd3, 0x5e, 0x38, 0x45, 0x92, 0xa7, 0x71, 0x8c,
		0x38, 0x46, 0x1c, 0x23, 0x8e, 0xd1, 0x17, 0xc7, 0x88, 0xe6, 0x25, 0xb4, 0xb0, 0x24, 0x4f, 0x8b,
		0x2d, 0x2d, 0xc9, 0xd3, 0xd6, 0x97, 0x94, 0xe4, 0x69, 0x5f, 0x3d, 0x0e, 0x87, 0xf1, 0x6b, 0x2b,
		0x98, 0x3c, 0x6d, 0xb1, 0xa3, 0x9d, 0xfc, 0x7b, 0xf7, 0xbb, 0x34, 0xf6, 0x3f, 0xcc, 0xe5, 0x6c,
		0xea, 0xc3, 0x9a, 0x14, 0x21, 0xac, 0x1c, 0x45, 0x59, 0xbe, 0x9f, 0xe7, 0x42, 0x85, 0xb8, 0x5f,
		0x47, 0xc9, 0x41, 0x6c, 0x06, 0xf1, 0x74, 0x26, 0x43, 0xfe, 0x2a, 0xaf, 0xc3, 0xaf, 0x33, 0x23,
		0xd4, 0x9e, 0x35, 0x1a, 0x3b, 0xbb, 0x8d, 0x46, 0x75, 0x77, 0x7b, 0xb7, 0xba, 0xd7, 0x6c, 0xd6,
		0x76, 0x24, 0x82, 0xb6, 0xca, 0xdb, 0xb4, 0x6d, 0x52, 0xd3, 0x7e, 0x31, 0x78, 0x47, 0x49, 0x3f,
		0x8e, 0xbd, 0x36, 0x25, 0x61, 0x10, 0xf2, 0x04, 0x7c, 0x2a, 0x22, 0x39, 0xa0, 0xf7, 0x6f, 0xbd,
		0x77, 0x38, 0x99, 0xd4, 0xe9, 0x7e, 0xa7, 0x42, 0x3b, 0x57, 0x77, 0x76, 0xe9, 0x83, 0x3d, 0x7a,
		0xd3, 0xd5, 0xd5, 0x42, 0x8f, 0xb1, 0xb0, 0x9f, 0x7f, 0x1e, 0x50, 0xd2, 0x96, 0xdd, 0x57, 0x75,
		0x9d, 0xdd, 0x37, 0xff, 0x7c, 0x3a, 0x4a, 0x2d, 0xbd, 0xa2, 0x74, 0x94, 0xd2, 0xd3, 0x11, 0xe9,
		0x28, 0xb5, 0xc4, 0x03, 0x85, 0x4a, 0xd4, 0xcb, 0x96, 0xa6, 0xa7, 0xb3, 0x94, 0x0a, 0xe4, 0x48,
		0x43, 0x8f, 0x1a, 0x04, 0xa9, 0x41, 0x91, 0x0e, 0x24, 0x15, 0x83, 0x3e, 0x8b, 0x75, 0x96, 0xfa,
		0x6c, 0xe2, 0xb8, 0x1b, 0x08, 0xc5, 0x44, 0x77, 0x6e, 0xaf, 0x5b, 0x47, 0x95, 0xba, 0x40, 0x62,
		0x3a, 0x61, 0x3f, 0x1e, 0x1a, 0x4f, 0x27, 0x8c, 0x33, 0xee, 0x66, 0xeb, 0xc3, 0xaa, 0x22, 0xbc,
		0x6a, 0xc1, 0xac, 0x3a, 0xdc, 0xaa, 0xc3, 0xae, 0x2e, 0xfc, 0xca, 0xc0, 0xb0, 0x10, 0x1c, 0x4f,
		0x97, 0x46, 0xef, 0x6e, 0xb6, 0x7c, 0xea, 0x94, 0x70, 0xca, 0xd4, 0xaa, 0x09, 0xde, 0x65, 0x56,
		0x29, 0xe7, 0xfc, 0xb6, 0x48, 0x89, 0x19, 0x8b, 0x1a, 0xa1, 0x45, 0xd5, 0xe0, 0xcf, 0xe1, 0x21,
		0x86, 0x10, 0xb9, 0x1b, 0x3c, 0x1c, 0x66, 0x07, 0xb3, 0x83, 0xd9, 0xc1, 0xec, 0x3c, 0x16, 0xa3,
		0x74, 0x44, 0x29, 0x61, 0x08, 0x83, 0x55, 0xc1, 0xaa, 0x60, 0x55, 0xbe, 0xb2, 0x2a, 0xf9, 0x92,
		0x1f, 0xfd, 0xfc, 0x73, 0xd0, 0x0b, 0xb3, 0x6c, 0x6c, 0x63, 0x5a, 0x75, 0x3f, 0xe6, 0x86, 0xe5,
		0x22, 0x84, 0x6f, 0x40, 0xea, 0x00, 0x50, 0xb5, 0x81, 0xd5, 0x19, 0xc0, 0x3a, 0x03, 0x5a, 0x37,
		0x80, 0x2b, 0x0b, 0xbc, 0xc2, 0x00, 0xac, 0x27, 0x6f, 0x2d, 0xec, 0xb8, 0xb4, 0xdb, 0xcf, 0xa3,
		0xe4, 0x5c, 0x0b, 0x25, 0xe7, 0x42, 0xcc, 0x67, 0xa4, 0x10, 0x2b, 0x38, 0xf7, 0x55, 0x48, 0x21,
		0x9e, 0xd7, 0xc7, 0xfe, 0x34, 0x97, 0x94, 0x61, 0xa6, 0xfe, 0xe4, 0x03, 0x62, 0x29, 0xea, 0x4f,
		0x42, 0x46, 0x21, 0xa3, 0x90, 0x51, 0xc8, 0x28, 0x64, 0x14, 0x32, 0x0a, 0x19, 0x85, 0x8c, 0x42,
		0x46, 0x21, 0xa3, 0x90, 0x51, 0x4b, 0x64, 0x94, 0x6b, 0xad, 0x45, 0x31, 0x20, 0xbf, 0x0c, 0xc7,
		0xa3, 0x2b, 0x89, 0x73, 0x73, 0x3b, 0xfd, 0x87, 0xb9, 0x5c, 0x91, 0xf4, 0xa3, 0xd6, 0xe7, 0x30,
		0x4a, 0x44, 0x73, 0x90, 0x46, 0x23, 0x90, 0x88, 0x44, 0x22, 0x92, 0xfb, 0x78, 0x9d, 0x44, 0x24,
		0x5c, 0x99, 0x8c, 0x2b, 0x93, 0x40, 0x39, 0xab, 0xfe, 0x6c, 0x34, 0xc1, 0x15, 0x70, 0x6a, 0x32,
		0xe7, 0x02, 0xa2, 0xe7, 0x01, 0xe2, 0xee, 0xac, 0x8e, 0x3b, 0xc3, 0x9d, 0xe1, 0xce, 0x96, 0x5a,
		0x02, 0x6e, 0x4c, 0x3e, 0x7e, 0xe9, 0xb8, 0x31, 0xe9, 0x1a, 0x56, 0x15, 0xe1, 0x55, 0x0b, 0x66,
		0xd5, 0xe1, 0x56, 0x1d, 0x76, 0x75, 0xe1, 0x57, 0x4e, 0x72, 0x5b, 0xe3, 0xc6, 0xe4, 0xc3, 0xe2,
		0x40, 0x6e, 0x4c, 0x42, 0x40, 0x1f, 0x42, 0x40, 0x05, 0x04, 0x78, 0x8a, 0xaa, 0x15, 0xd4, 0x18,
		0x2a, 0x56, 0xb9, 0xf4, 0xf2, 0xe2, 0x43, 0x99, 0x4a, 0xbd, 0x9d, 0x75, 0xda, 0xf6, 0xeb, 0xbb,
		0x0d, 0x1e, 0x4a, 0x51, 0x37, 0x0f, 0x03, 0x5a, 0x8a, 0xba, 0xb9, 0x09, 0x48, 0x29, 0xea, 0xb6,
		0xd4, 0x46, 0xa0, 0xa8, 0x1b, 0x12, 0xa5, 0x37, 0x9c, 0x19, 0x89, 0x52, 0x91, 0xf0, 0x88, 0x49,
		0x94, 0x67, 0x9d, 0x76, 0x90, 0xc7, 0x5f, 0xe4, 0x55, 0xc9, 0xc9, 0x40, 0x08, 0x84, 0x08, 0x84,
		0x08, 0x84, 0x08, 0x84, 0x08, 0x84, 0x08, 0x84, 0x08, 0x84, 0x8f, 0xd0, 0x84, 0xce, 0x3a, 0xed,
		0x15, 0xaa, 0xa3, 0x46, 0xce, 0xc7, 0x62, 0x0c, 0x42, 0xce, 0x07, 0x84, 0x0a, 0x42, 0x05, 0xa1,
		0x82, 0x50, 0x41, 0xa8, 0x20, 0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0x0a, 0x42, 0xb5, 0x14, 0xa1,
		0x22, 0xcd, 0xc2, 0xb5, 0x25, 0x38, 0xb6, 0x00, 0xf7, 0xb9, 0x15, 0x2f, 0x3a, 0xed, 0x32, 0x25,
		0x54, 0xb4, 0xa2, 0xb4, 0xd5, 0x8f, 0xf2, 0xa0, 0xd5, 0xed, 0x0f, 0x3e, 0x62, 0x66, 0x3f, 0xbb,
		0x62, 0x61, 0x04, 0x52, 0x2d, 0x3c, 0x8c, 0x64, 0x49, 0xb5, 0x70, 0x13, 0x89, 0x96, 0x3c, 0xd5,
		0x02, 0x5d, 0x10, 0x5d, 0x10, 0x5d, 0x10, 0x5d, 0xb0, 0x30, 0xba, 0x60, 0xd8, 0xfe, 0x4f, 0xd0,
		0xfa, 0x1c, 0x26, 0xe7, 0x26, 0x93, 0xd7, 0x06, 0x67, 0x07, 0x43, 0x1f, 0x44, 0x1f, 0x44, 0x1f,
		0x44, 0x1f, 0x2c, 0x94, 0x3e, 0x38, 0xe6, 0x74, 0xdb, 0x75, 0x05, 0x85, 0x70, 0x57, 0x70, 0x88,
		0x77, 0x03, 0x0c, 0xae, 0x3c, 0x5f, 0xfb, 0x28, 0x6a, 0xb3, 0x0a, 0x85, 0xee, 0x5e, 0x47, 0x89,
		0x62, 0x91, 0x47, 0x95, 0x1a, 0xa0, 0xd3, 0xe1, 0xfe, 0x08, 0xe3, 0xbe, 0x51, 0x1c, 0xef, 0x55,
		0x1a, 0xb6, 0xf2, 0xa8, 0x9b, 0xbc, 0x8c, 0xce, 0xa3, 0x7c, 0x10, 0x0d, 0x54, 0xe5, 0xeb, 0x39,
		0x2a, 0xd4, 0x23, 0x7c, 0x1d, 0x7e, 0x2d, 0xbd, 0x89, 0x34, 0xea, 0x7b, 0x8d, 0xbd, 0x9d, 0xdd,
		0xfa, 0x5e, 0xb3, 0xc4, 0xb6, 0x52, 0xd0, 0x7a, 0x92, 0x27, 0x2b, 0x5c, 0x32, 0x7f, 0x10, 0xf0,
		0x27, 0xfd, 0x8b, 0x33, 0x93, 0xea, 0x90, 0x8b, 0xf1, 0x58, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0x02,
		0x6e, 0x51, 0x28, 0x6e, 0xd1, 0x8f, 0x92, 0x1c, 0x62, 0x01, 0xb1, 0x80, 0x58, 0x40, 0x2c, 0x20,
		0x16, 0x10, 0x0b, 0x88, 0xc5, 0x8f, 0x88, 0x45, 0x3f, 0xff, 0x1c, 0x74, 0xc2, 0x28, 0xd6, 0x38,
		0xb5, 0xb8, 0x1e, 0x0b, 0x62, 0x01, 0xb1, 0x80, 0x58, 0x40, 0x2c, 0x0a, 0x45, 0x2c, 0x38, 0xb4,
		0x80, 0x5b, 0xc0, 0x2d, 0xe0, 0x16, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0xe2, 0x9e, 0xdc, 0x22, 0xbf,
		0xec, 0x19, 0x55, 0x82, 0x31, 0x33, 0x20, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x80, 0x65, 0xc0, 0x32,
		0x60, 0x19, 0xb0, 0x0c, 0x58, 0x06, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x28, 0x19, 0xcb, 0x88, 0xda,
		0x41, 0x27, 0x32, 0x71, 0x3b, 0x88, 0x4d, 0x12, 0x5c, 0x44, 0xd9, 0x45, 0x98, 0xb7, 0x3e, 0x6b,
		0x5c, 0xc2, 0xb8, 0x6b, 0x60, 0x58, 0x07, 0xac, 0x03, 0xd6, 0x01, 0xeb, 0x80, 0x75, 0xc0, 0x3a,
		0x60, 0x1d, 0xb0, 0x0e, 0x58, 0x07, 0xac, 0x03, 0xd6, 0x51, 0x36, 0xd6, 0x91, 0x44, 0xb9, 0xd6,
		0xb1, 0xc6, 0xcc, 0x58, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0x02, 0x6e, 0x01, 0xb7, 0x80, 0x5b, 0xc0,
		0x2d, 0xe0, 0x16, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0xa2, 0x64, 0xdc, 0x22, 0x0e, 0x93, 0xa0, 0x1d,
		0x65, 0x7a, 0xe5, 0xa4, 0x6e, 0x0e, 0x08, 0xcb, 0x80, 0x65, 0xc0, 0x32, 0x60, 0x19, 0xb0, 0x0c,
		0x58, 0x06, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x80, 0x65, 0xc0, 0x32, 0x4a, 0xc6, 0x32, 0x2e, 0xc2,
		0xaf, 0x41, 0x98, 0x9a, 0x30, 0x08, 0xdb, 0xed, 0xd4, 0x64, 0x99, 0x6a, 0xee, 0xd4, 0x8f, 0x06,
		0x87, 0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0xb0, 0x0f, 0xd8, 0x07, 0xec, 0x03, 0xf6, 0x01, 0xfb, 0x80,
		0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0x25, 0x63, 0x1f, 0xa9, 0xf9, 0x8f, 0x69, 0xe5, 0xa6, 0x1d, 0x84,
		0xed, 0xff, 0xc8, 0xd3, 0x8d, 0xb9, 0xd1, 0xe0, 0x17, 0xf0, 0x0b, 0xf8, 0x05, 0xfc, 0x02, 0x7e,
		0x01, 0xbf, 0x80, 0x5f, 0xc0, 0x2f, 0xe0, 0x17, 0xf0, 0x0b, 0xf8, 0x85, 0x4b, 0x7e, 0x41, 0x67,
		0x74, 0x37, 0x7d, 0xb1, 0x6f, 0x76, 0x58, 0xa6, 0x4d, 0xba, 0x73, 0xb3, 0xf0, 0xc9, 0x1c, 0xdc,
		0xf7, 0x4c, 0xff, 0x75, 0x34, 0xa3, 0x5f, 0x27, 0x13, 0x2a, 0x53, 0xff, 0xf4, 0x09, 0x9f, 0xb7,
		0xdd, 0x35, 0x7d, 0xf4, 0x5c, 0x7a, 0xa5, 0x7b, 0x28, 0x52, 0xd0, 0x2b, 0xdd, 0x8d, 0xc8, 0x50,
		0xf2, 0x5e, 0xe9, 0x13, 0xdc, 0xce, 0x25, 0xd4, 0x88, 0x6b, 0x60, 0x99, 0x1d, 0x45, 0xa6, 0x73,
		0x7a, 0x55, 0xaa, 0x73, 0x7a, 0x95, 0xce, 0xe9, 0x0a, 0x30, 0xa4, 0x06, 0x47, 0x6a, 0xb0, 0xa4,
		0x03, 0x4f, 0xc5, 0xe0, 0x41, 0x62, 0x5a, 0xa7, 0x06, 0xc2, 0xcc, 0x05, 0x33, 0x0d, 0x81, 0x67,
		0x1f, 0x24, 0xfd, 0x8b, 0xc1, 0xea, 0x5c, 0xf9, 0x4a, 0x9e, 0x2c, 0x46, 0x31, 0x26, 0x09, 0xcf,
		0x62, 0xd3, 0x96, 0x73, 0x35, 0x93, 0x01, 0x6c, 0xf7, 0xfe, 0x37, 0x9d, 0xb0, 0x1f, 0x0f, 0xf7,
		0x70, 0x27, 0x8c, 0x33, 0xbc, 0x18, 0x5e, 0x0c, 0x2f, 0x86, 0x17, 0xb3, 0x6c, 0xf1, 0x67, 0xdd,
		0x6e, 0x6c, 0xc2, 0x44, 0xd2, 0x81, 0xd5, 0x56, 0xc0, 0xc9, 0x7c, 0x36, 0x71, 0xdc, 0x0d, 0x7a,
		0x61, 0xbb, 0x1d, 0x25, 0xe7, 0x72, 0xae, 0x66, 0x7e, 0x18, 0x1c, 0x02, 0x0e, 0x01, 0x87, 0x80,
		0x43, 0x90, 0x83, 0x18, 0xc8, 0x8d, 0xe7, 0x7e, 0x67, 0x7a, 0x1c, 0x12, 0x44, 0x82, 0x0c, 0x67,
		0x6e, 0x14, 0xbc, 0x0e, 0x5e, 0x07, 0xaf, 0x83, 0xd7, 0x29, 0x0a, 0xc2, 0xcc, 0xf9, 0x9b, 0x67,
		0x2b, 0xe0, 0x13, 0x7a, 0x61, 0x96, 0x45, 0x5f, 0x04, 0xcf, 0x56, 0x26, 0x03, 0x20, 0x78, 0xe1,
		0x69, 0xf0, 0x34, 0x78, 0x1a, 0x04, 0xaf, 0x82, 0x08, 0x5e, 0xa4, 0xa4, 0x09, 0xa7, 0xa4, 0x8d,
		0x5c, 0x41, 0x89, 0xf2, 0xbe, 0x44, 0xf8, 0xa5, 0x64, 0xd4, 0x67, 0xd9, 0xcb, 0x93, 0x03, 0x46,
		0x0e, 0x98, 0x0b, 0x6f, 0xed, 0x17, 0x54, 0x5b, 0xf7, 0xca, 0xd7, 0xb5, 0x3c, 0x4d, 0xd8, 0x49,
		0x4d, 0xc7, 0xa6, 0xc5, 0x4e, 0xbc, 0xb0, 0xc5, 0x7b, 0x61, 0x95, 0xe3, 0xb1, 0x37, 0xd9, 0xdc,
		0x1c, 0x25, 0x9d, 0x6f, 0xcd, 0x21, 0x57, 0x29, 0xf1, 0x7e, 0xf0, 0x56, 0x04, 0x01, 0xdf, 0xde,
		0x4b, 0x5f, 0xf9, 0xac, 0xdf, 0x0e, 0x78, 0xef, 0x02, 0xef, 0x3b, 0x64, 0xfc, 0xde, 0xf3, 0x81,
		0x96, 0x2f, 0x0f, 0x2c, 0x6c, 0x02, 0xab, 0x97, 0x08, 0x84, 0x60, 0xa5, 0x3c, 0x72, 0x51, 0x07,
		0xb1, 0xc8, 0x47, 0xb1, 0xa8, 0xb3, 0x6a, 0x52, 0x91, 0x6d, 0x98, 0x5a, 0x8c, 0x81, 0x34, 0x7a,
		0x65, 0x4d, 0x86, 0xa2, 0xcc, 0x8b, 0x36, 0xa8, 0xa9, 0x81, 0x9b, 0x16, 0xc8, 0xa9, 0x83, 0x9d,
		0x3a, 0xe8, 0x69, 0x82, 0x9f, 0x0c, 0x08, 0x0a, 0x81, 0xa1, 0x1c, 0x53, 0x57, 0x64, 0xee, 0x1a,
		0x4c, 0xfe, 0x4e, 0x66, 0xbf, 0x35, 0x34, 0xa3, 0xe7, 0x33, 0xb2, 0xee, 0x8d, 0x1f, 0x8c, 0xff,
		0x3c, 0xbc, 0x13, 0xbc, 0xc2, 0x95, 0xd0, 0xb2, 0xfe, 0x99, 0xa2, 0x7f, 0x9c, 0x1b, 0x0d, 0x17,
		0x89, 0x8b, 0xc4, 0x45, 0xe2, 0x22, 0x71, 0x91, 0x9e, 0xba, 0xc8, 0x8f, 0xd7, 0x2e, 0xf2, 0xff,
		0xb4, 0xfa, 0x69, 0x6a, 0x92, 0x7c, 0x7d, 0x63, 0x6b, 0x73, 0xf3, 0x5a, 0x2d, 0x3f, 0x19, 0xff,
		0xca, 0x2c, 0xae, 0x67, 0xb7, 0xfc, 0x6c, 0xfa, 0xe4, 0xb6, 0xf9, 0x5a, 0xa1, 0x2e, 0x90, 0x85,
		0x97, 0x78, 0xf0, 0x75, 0x58, 0x7e, 0xca, 0x7e, 0x21, 0x3b, 0x79, 0xc1, 0xa6, 0xdb, 0x0a, 0xcc,
		0xd7, 0xfc, 0x79, 0x6e, 0x62, 0x73, 0x61, 0xf2, 0xf4, 0x32, 0xe8, 0x26, 0xe3, 0xde, 0x6f, 0x3a,
		0x22, 0xce, 0x30, 0x19, 0x4d, 0x41, 0xc5, 0xf1, 0x5d, 0xc0, 0x39, 0xa1, 0x54, 0xd5, 0x7d, 0x13,
		0x41, 0xe6, 0xce, 0xb9, 0xac, 0xa6, 0x85, 0xd8, 0x7f, 0xb5, 0x57, 0x56, 0xeb, 0x26, 0x85, 0xb9,
		0x60, 0xe2, 0xe9, 0xe8, 0xf1, 0x05, 0xd3, 0xf9, 0xeb, 0xe8, 0xfc, 0x6a, 0xf1, 0x3d, 0x3a, 0x7f,
		0xf9, 0x22, 0x17, 0x74, 0x7e, 0x44, 0x0c, 0x44, 0x0c, 0x44, 0x0c, 0x44, 0x0c, 0x44, 0x0c, 0x05,
		0x11, 0x03, 0x9d, 0x7f, 0x0d, 0x9d, 0x1f, 0x17, 0x89, 0x8b, 0xc4, 0x45, 0xe2, 0x22, 0x71, 0x91,
		0xe8, 0xfc, 0xc5, 0x62, 0xcb, 0x2b, 0x23, 0xaa, 0x52, 0xfc, 0xdf, 0xb5, 0x4d, 0x78, 0x63, 0x0b,
		0xee, 0x2b, 0xff, 0x4f, 0xbf, 0x7b, 0x67, 0x3a, 0x65, 0xba, 0x0e, 0x14, 0x9b, 0x2f, 0x26, 0xce,
		0xec, 0xdf, 0x03, 0x1a, 0x3f, 0x97, 0x0b, 0x40, 0x56, 0x22, 0x75, 0xae, 0x7c, 0xea, 0xc4, 0xde,
		0x94, 0xfd, 0x5f, 0x16, 0x4a, 0xe4, 0x8e, 0x06, 0x47, 0x8f, 0xe7, 0x0a, 0x10, 0x15, 0x63, 0xdc,
		0x8b, 0x01, 0x54, 0x8c, 0x51, 0x24, 0x3c, 0x62, 0xc7, 0x83, 0x61, 0xfb, 0x3f, 0x61, 0xcb, 0x24,
		0xad, 0xc8, 0x64, 0xf2, 0x02, 0xe8, 0xec, 0x60, 0xb2, 0xfa, 0x67, 0x4d, 0x5a, 0xff, 0xac, 0xd3,
		0xf1, 0xd9, 0x03, 0xb0, 0x53, 0x07, 0x3d, 0x75, 0xf0, 0xd3, 0x05, 0x41, 0x39, 0x3d, 0x69, 0x4d,
		0x50, 0x03, 0x95, 0x02, 0xc7, 0x05, 0x90, 0xbc, 0x94, 0x37, 0xe4, 0x9b, 0x50, 0x79, 0x29, 0x6d,
		0xc8, 0xb2, 0x80, 0x29, 0x1e, 0x0d, 0xba, 0x00, 0x50, 0x07, 0x40, 0xaa, 0x0d, 0xa8, 0xce, 0x80,
		0xd5, 0x19, 0xc0, 0xba, 0x01, 0x5a, 0x59, 0xc0, 0x15, 0x06, 0x5e, 0x35, 0x00, 0x9e, 0x0e, 0x24,
		0x93, 0x79, 0xfb, 0xd3, 0xfd, 0x2d, 0x91, 0x91, 0xeb, 0x18, 0x90, 0xd5, 0x81, 0xd9, 0x05, 0x40,
		0x3b, 0x04, 0x6a, 0x57, 0x80, 0xed, 0x1c, 0xb8, 0x9d, 0x03, 0xb8, 0x5b, 0x20, 0xd7, 0x01, 0x74,
		0x25, 0x60, 0x57, 0x07, 0xf8, 0xc5, 0x88, 0x3b, 0xd0, 0x85, 0xfc, 0xbb, 0xe3, 0xf0, 0x40, 0xd3,
		0x09, 0xdc, 0x74, 0x06, 0x55, 0xe5, 0x61, 0xb5, 0x9d, 0x82, 0x4b, 0xe7, 0xe0, 0x81, 0x93, 0x70,
		0xed, 0x2c, 0xbc, 0x71, 0x1a, 0xde, 0x38, 0x0f, 0x3f, 0x9c, 0x88, 0xae, 0x33, 0x51, 0x76, 0x2a,
		0xd3, 0x25, 0x16, 0x4f, 0x61, 0xfb, 0xe9, 0x8e, 0x1f, 0xbc, 0xd5, 0xe0, 0x3a, 0xd9, 0x22, 0x6c,
		0xff, 0xc7, 0x09, 0xda, 0xaf, 0x09, 0xf7, 0x8c, 0xfa, 0xe9, 0xd8, 0x32, 0x3d, 0xa5, 0xfc, 0xb1,
		0x6e, 0x45, 0xcb, 0x9e, 0x09, 0x1c, 0x72, 0x17, 0xf6, 0x7d, 0x4b, 0x00, 0x23, 0xd4, 0xe5, 0x8c,
		0xf8, 0x85, 0xf8, 0x85, 0xf8, 0x85, 0xf8, 0x85, 0xf8, 0xc5, 0xd9, 0x8e, 0x1f, 0xa6, 0x05, 0xb9,
		0xc0, 0x77, 0x22, 0x96, 0x32, 0x45, 0x2c, 0xa9, 0x09, 0x83, 0xb0, 0xdd, 0x4e, 0x4d, 0x96, 0x39,
		0x8c, 0x57, 0x66, 0x67, 0x41, 0xb4, 0x42, 0xb4, 0x42, 0xb4, 0x42, 0xb4, 0x42, 0xb4, 0x52, 0xa2,
		0x68, 0xc5, 0x21, 0xc2, 0xcf, 0xc5, 0x2b, 0xcf, 0x1c, 0x8c, 0x7d, 0x1c, 0xe6, 0xb9, 0x49, 0x13,
		0x91, 0x1a, 0x75, 0xf7, 0x9a, 0xc0, 0xbf, 0x3f, 0x56, 0x83, 0xbd, 0xfd, 0xe0, 0x55, 0x18, 0x74,
		0x4e, 0xbe, 0xd5, 0xaf, 0x3e, 0x7d, 0xda, 0x5c, 0x9f, 0xfd, 0x49, 0x63, 0xf0, 0x93, 0x8d, 0x6f,
		0xd5, 0xa7, 0xdb, 0x57, 0x7f, 0xd1, 0xdf, 0x79, 0x27, 0x2e, 0xde, 0xc8, 0xdb, 0xf7, 0x87, 0xff,
		0xe4, 0xb5, 0xfc, 0xf0, 0xb5, 0x94, 0x1a, 0x10, 0x8f, 0xa2, 0x2c, 0xdf, 0xcf, 0xf3, 0xd4, 0x0d,
		0x28, 0xbe, 0x8e, 0x92, 0x83, 0xd8, 0x0c, 0x7c, 0x5e, 0xa6, 0x1f, 0x00, 0x8e, 0x66, 0x10, 0x7e,
		0x9d, 0x99, 0x41, 0xed, 0x59, 0xa3, 0xb1, 0xb3, 0xdb, 0x68, 0x54, 0x77, 0xb7, 0x77, 0xab, 0x7b,
		0xcd, 0x66, 0x6d, 0xa7, 0xd6, 0x74, 0x30, 0xa9, 0xb7, 0x69, 0xdb, 0xa4, 0xa6, 0xfd, 0xe2, 0xb2,
		0xf2, 0x7c, 0x2d, 0xe9, 0xc7, 0x31, 0xf4, 0x6e, 0xe9, 0x25, 0x6d, 0x47, 0x59, 0x90, 0x5d, 0x66,
		0xb9, 0xb9, 0xb0, 0xd9, 0xe5, 0xf2, 0xc1, 0xde, 0x7f, 0x7e, 0x1a, 0x10, 0x3c, 0x08, 0x1e, 0x04,
		0x0f, 0x82, 0x07, 0xc1, 0x2b, 0x11, 0xc1, 0x73, 0x05, 0xef, 0xb0, 0xbb, 0x7f, 0x2f, 0x90, 0x86,
		0x9f, 0xfc, 0x00, 0x92, 0xc7, 0xdb, 0x71, 0xc9, 0xf5, 0x4a, 0x19, 0x69, 0xc7, 0xdd, 0x56, 0x18,
		0x07, 0xe6, 0x6b, 0x6e, 0x92, 0xb6, 0x69, 0x07, 0xad, 0x28, 0x6d, 0xf5, 0xa3, 0xdc, 0x69, 0xd4,
		0x7d, 0xf7, 0x94, 0x88, 0xc0, 0x89, 0xc0, 0x89, 0xc0, 0x89, 0xc0, 0x89, 0xc0, 0x4b, 0x14, 0x81,
		0xbb, 0x07, 0xfa, 0x59, 0xb0, 0xdf, 0x75, 0x30, 0xf4, 0xbb, 0x61, 0xe7, 0x1c, 0x57, 0xa1, 0x9e,
		0x1b, 0xb4, 0x5b, 0x1b, 0x0b, 0xca, 0xce, 0xe0, 0xd6, 0xb1, 0x97, 0x5f, 0x98, 0xc6, 0x1f, 0x61,
		0xdc, 0x37, 0x1e, 0xcc, 0xe3, 0x55, 0x1a, 0xb6, 0xf2, 0xa8, 0x9b, 0xbc, 0x8c, 0xce, 0xa3, 0x91,
		0xce, 0xef, 0x6c, 0x3e, 0x57, 0x4f, 0x1d, 0x9a, 0x66, 0xf8, 0x15, 0xd3, 0xbc, 0x61, 0x9a, 0x8d,
		0xfa, 0x5e, 0x63, 0x6f, 0x67, 0xb7, 0xbe, 0xd7, 0xc4, 0x46, 0xdd, 0x44, 0x07, 0xee, 0x46, 0x85,
		0x6b, 0x2f, 0x6f, 0xb6, 0x17, 0xfd, 0x38, 0x8f, 0x82, 0xbc, 0xdb, 0xeb, 0xc6, 0xdd, 0xf3, 0x4b,
		0x77, 0x04, 0xfb, 0xc6, 0x3c, 0x60, 0xd5, 0xb0, 0x6a, 0x58, 0x35, 0xac, 0x1a, 0x56, 0x5d, 0x22,
		0x56, 0x7d, 0xd6, 0xed, 0xc6, 0x26, 0x4c, 0x5c, 0x9e, 0x6a, 0xd5, 0x08, 0x19, 0x96, 0x5e, 0xcb,
		0xc4, 0x44, 0xe7, 0x9f, 0xcf, 0xba, 0xe9, 0x54, 0x1c, 0x71, 0x7b, 0x41, 0xf3, 0xf6, 0xe9, 0x10,
		0x40, 0x10, 0x40, 0x10, 0x40, 0x10, 0x40, 0x10, 0x40, 0x94, 0x28, 0x80, 0xe0, 0x9e, 0x26, 0xf7,
		0x34, 0x2d, 0xc6, 0x2f, 0x5e, 0x65, 0x18, 0xfc, 0x70, 0x56, 0x44, 0x33, 0x44, 0x33, 0x44, 0x33,
		0x44, 0x33, 0x44, 0x33, 0x25, 0x8a, 0x66, 0x48, 0x32, 0x20, 0xc9, 0xc0, 0xe1, 0x17, 0x49, 0x06,
		0xf3, 0xf3, 0x20, 0xc9, 0x60, 0x8d, 0x24, 0x83, 0xdb, 0x4d, 0x93, 0x24, 0x03, 0xd7, 0xd1, 0x81,
		0xbb, 0x51, 0x49, 0x32, 0xb0, 0xc8, 0xb8, 0xa3, 0xde, 0x97, 0x86, 0xfb, 0x12, 0x49, 0xb7, 0x4f,
		0x07, 0x8e, 0x0d, 0xc7, 0x86, 0x63, 0xc3, 0xb1, 0xe1, 0xd8, 0x25, 0xe2, 0xd8, 0xb3, 0x08, 0x1f,
		0x24, 0xdd, 0xe0, 0xff, 0x75, 0x13, 0xc3, 0xad, 0x5a, 0xe5, 0x09, 0xac, 0x0f, 0x6b, 0xf1, 0x9c,
		0x7c, 0xff, 0x58, 0x0b, 0xf6, 0x4e, 0x46, 0xdf, 0xd6, 0x86, 0xff, 0x37, 0xfa, 0xbe, 0xfe, 0xb1,
		0x1a, 0x34, 0x26, 0xdf, 0x37, 0x3f, 0x56, 0x83, 0xe6, 0xc9, 0xc6, 0xb0, 0x5c, 0xcf, 0xf6, 0xd5,
		0xc3, 0x7f, 0x71, 0xfd, 0xaf, 0x1f, 0x3f, 0x7d, 0xea, 0x7d, 0x7b, 0x73, 0x35, 0xf8, 0xef, 0xd1,
		0xd5, 0xc9, 0xdf, 0x37, 0x7e, 0x71, 0x85, 0x74, 0x83, 0x89, 0x7d, 0xfa, 0xb4, 0x79, 0xf2, 0x37,
		0x6e, 0xa1, 0x16, 0x3d, 0x68, 0xdd, 0xf1, 0x2b, 0x68, 0xdd, 0x21, 0x68, 0x25, 0x68, 0x25, 0x68,
		0x25, 0x68, 0x25, 0x68, 0x2d, 0x69, 0xd0, 0xba, 0x43, 0xd0, 0xea, 0x3c, 0x68, 0x7d, 0xfe, 0x7d,
		0x10, 0xc1, 0x85, 0x41, 0x67, 0x3f, 0x78, 0x75, 0xf2, 0xad, 0xfa, 0xb4, 0x71, 0xb5, 0xf1, 0x7c,
		0x63, 0xfd, 0xe6, 0xcf, 0x9e, 0x6f, 0x7c, 0xab, 0x3e, 0x6d, 0x5e, 0xad, 0xaf, 0xdf, 0xf2, 0x37,
		0xbf, 0xdc, 0xf6, 0x8c, 0x8d, 0xef, 0xeb, 0xeb, 0xeb, 0xe3, 0x70, 0x75, 0x2e, 0x84, 0xfd, 0x58,
		0xad, 0x9d, 0xfc, 0x32, 0xfc, 0x76, 0xf4, 0xdf, 0x69, 0x10, 0x7c, 0xaf, 0x7f, 0xbc, 0xe1, 0x53,
		0xe8, 0xbb, 0xbe, 0xfe, 0xf1, 0xdf, 0xcf, 0x4f, 0xfe, 0xfe, 0x7c, 0xe3, 0xdb, 0xce, 0xd5, 0xe4,
		0xfb, 0xe1, 0x7f, 0x37, 0xbe, 0xaf, 0x6f, 0xfe, 0xed, 0xd3, 0xa7, 0xcd, 0xcd, 0xbf, 0x6d, 0x8c,
		0x16, 0x62, 0xfc, 0xef, 0xfe, 0x36, 0xfa, 0xdb, 0x5f, 0x9e, 0x3f, 0x5f, 0xf8, 0xd1, 0xc6, 0xfa,
		0x5f, 0x37, 0x1d, 0x47, 0xf1, 0xa3, 0xf7, 0xf7, 0x9c, 0x60, 0xbe, 0xf8, 0xc1, 0x7c, 0x96, 0xf4,
		0x42, 0x0f, 0x82, 0xf8, 0xe1, 0x34, 0x08, 0xde, 0x09, 0xde, 0x09, 0xde, 0x09, 0xde, 0x09, 0xde,
		0x4b, 0x14, 0xbc, 0x3b, 0x40, 0x76, 0xe7, 0xc1, 0xfa, 0x91, 0x49, 0xce, 0xf3, 0xcf, 0x24, 0x72,
		0x39, 0x9a, 0x04, 0x89, 0x5c, 0x73, 0xf3, 0x20, 0x91, 0x6b, 0x8d, 0x44, 0xae, 0xdb, 0x4d, 0xb3,
		0x8e, 0x6d, 0x3a, 0x0a, 0x04, 0xdc, 0x8d, 0x0a, 0x7d, 0xb6, 0x40, 0x9f, 0xe3, 0x9e, 0xd3, 0xbb,
		0x51, 0xc3, 0xe1, 0xa1, 0xcb, 0xd0, 0x65, 0xe8, 0x32, 0x74, 0x19, 0xba, 0x5c, 0x22, 0xba, 0x6c,
		0x92, 0xfe, 0x85, 0x49, 0xc3, 0x41, 0x4c, 0xc4, 0x9d, 0xee, 0x32, 0x9a, 0x18, 0xed, 0xc1, 0x68,
		0x0f, 0xb6, 0x0a, 0x21, 0x72, 0x2f, 0x8d, 0xba, 0x69, 0x94, 0x3b, 0x2c, 0xa1, 0x38, 0x9d, 0x01,
		0x81, 0x32, 0x81, 0x32, 0x81, 0x32, 0x81, 0x32, 0x81, 0x72, 0x89, 0x02, 0xe5, 0x7e, 0x94, 0xe4,
		0xcf, 0x1c, 0x86, 0xc8, 0x4d, 0xea, 0x03, 0xa8, 0x86, 0xad, 0x68, 0xf7, 0xe3, 0x69, 0x70, 0xac,
		0xe4, 0x1a, 0xfd, 0x6e, 0xf2, 0x19, 0x4c, 0xf3, 0x86, 0x69, 0xd6, 0xea, 0xbb, 0x18, 0xa7, 0x9b,
		0x40, 0xc0, 0xdd, 0xa8, 0x9c, 0x2b, 0x2d, 0x6f, 0xb6, 0xa9, 0xb9, 0x08, 0xa3, 0x24, 0x4a, 0xce,
		0x83, 0xcf, 0xdd, 0xb8, 0x1d, 0xe4, 0xd1, 0x85, 0xc3, 0x42, 0xc2, 0xb7, 0x4d, 0x06, 0x2a, 0x0d,
		0x95, 0x86, 0x4a, 0x43, 0xa5, 0xa1, 0xd2, 0x25, 0xa3, 0xd2, 0xb5, 0x1d, 0x87, 0x5c, 0x7a, 0x07,
		0x2e, 0x0d, 0x97, 0x86, 0x4b, 0xc3, 0xa5, 0xe1, 0xd2, 0x0b, 0xa6, 0xb9, 0xd3, 0x6c, 0x6e, 0x53,
		0x66, 0x0f, 0x36, 0x0d, 0x9b, 0x7e, 0x04, 0x9b, 0xce, 0xf2, 0x30, 0xcd, 0x83, 0x2c, 0x0f, 0xf3,
		0x7e, 0xe6, 0x92, 0x48, 0xcf, 0xcd, 0x03, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0,
		0x25, 0xe2, 0xd0, 0xf4, 0xf2, 0x2b, 0x57, 0xc8, 0xd0, 0xef, 0xf5, 0xba, 0x69, 0xee, 0x41, 0xcc,
		0x30, 0x9e, 0x08, 0x41, 0x03, 0x41, 0x03, 0x41, 0x03, 0x41, 0x03, 0x41, 0x03, 0x41, 0x03, 0x41,
		0x83, 0xbf, 0x41, 0x83, 0xdb, 0xa2, 0xa8, 0x0b, 0x33, 0x21, 0x6c, 0x20, 0x6c, 0x20, 0x6c, 0x20,
		0x6c, 0x20, 0x6c, 0x20, 0x6c, 0x20, 0x6c, 0xf0, 0x2b, 0x6c, 0xc8, 0x2e, 0xb3, 0xdc, 0x5c, 0x38,
		0x6d, 0xb2, 0x7b, 0x3d, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x85, 0x12,
		0x05, 0x0a, 0xae, 0xe0, 0x7d, 0x6d, 0xe5, 0xab, 0xa5, 0xff, 0xfb, 0x63, 0x35, 0xd8, 0xdb, 0x0f,
		0x5e, 0x85, 0x41, 0xe7, 0xe4, 0x5b, 0xe3, 0xea, 0xd3, 0xa7, 0xcd, 0x9f, 0xfc, 0xe0, 0x2f, 0x0e,
		0xea, 0x68, 0xbb, 0x78, 0x31, 0x6f, 0xdf, 0x1f, 0xfe, 0x93, 0xb7, 0x73, 0x9f, 0xb7, 0x43, 0x84,
		0xbd, 0xf4, 0x7b, 0xce, 0xbb, 0xbd, 0x6e, 0xdc, 0x3d, 0x77, 0x58, 0x83, 0x62, 0x3a, 0x03, 0xe2,
		0x6b, 0xe2, 0x6b, 0xe2, 0x6b, 0xe2, 0x6b, 0xe2, 0xeb, 0x12, 0xc5, 0xd7, 0x51, 0xdb, 0x24, 0x79,
		0x94, 0x5f, 0xa6, 0xa6, 0xe3, 0x32, 0xc2, 0x76, 0x51, 0x8a, 0xe2, 0x70, 0xfc, 0xd1, 0x5f, 0x84,
		0x99, 0x43, 0xdc, 0x99, 0xbc, 0x88, 0xfd, 0x57, 0x87, 0xa7, 0xef, 0x07, 0xff, 0xf9, 0xf0, 0xaf,
		0xe3, 0x03, 0x57, 0xd8, 0x33, 0xcc, 0xd8, 0xcf, 0x9c, 0x45, 0xb5, 0x6b, 0x4e, 0xaf, 0x15, 0xcd,
		0xbd, 0x8e, 0xc3, 0xe3, 0x3f, 0x76, 0x4e, 0x5f, 0xff, 0x7e, 0xf4, 0xe1, 0xf0, 0xd7, 0xfd, 0xf7,
		0x1f, 0x2a, 0xab, 0x78, 0x97, 0xc5, 0x9f, 0x37, 0xd1, 0x38, 0xfd, 0xfd, 0x0d, 0xef, 0xc1, 0x87,
		0xf7, 0xc0, 0x8e, 0xf0, 0x05, 0x9b, 0xdc, 0xef, 0x08, 0x27, 0x23, 0x9f, 0x10, 0x81, 0x5a, 0xb5,
		0x29, 0x6a, 0xb9, 0x52, 0xcb, 0xd5, 0x95, 0xbd, 0x6b, 0xea, 0x68, 0xfd, 0x9e, 0xe3, 0x52, 0x34,
		0x93, 0x09, 0xa0, 0xa2, 0x89, 0x0e, 0x8c, 0x8a, 0x86, 0x8a, 0x86, 0x8a, 0xb6, 0x5a, 0x31, 0x8c,
		0x7b, 0x15, 0x6d, 0x80, 0xec, 0x59, 0x1e, 0x5e, 0xf4, 0x1c, 0x6a, 0x68, 0xbb, 0x54, 0xa0, 0x51,
		0x0d, 0x5c, 0x29, 0xf3, 0x31, 0x9e, 0x06, 0x15, 0x68, 0x7c, 0xd2, 0x28, 0xa8, 0x40, 0x73, 0x8b,
		0x69, 0x36, 0xea, 0x7b, 0x8d, 0xbd, 0x9d, 0xdd, 0xfa, 0x1e, 0x65, 0x68, 0x1c, 0xeb, 0x37, 0x94,
		0xa1, 0x29, 0xd6, 0x48, 0x4a, 0x48, 0x56, 0xd9, 0x4f, 0x92, 0x6e, 0x3e, 0xea, 0x19, 0xa5, 0x09,
		0x5e, 0x95, 0xac, 0xf5, 0xd9, 0x5c, 0x84, 0xbd, 0x70, 0xd8, 0xeb, 0xb8, 0xb2, 0xd5, 0xed, 0x99,
		0xa4, 0x35, 0xe4, 0xae, 0x41, 0x62, 0xf2, 0xff, 0x76, 0xd3, 0x3f, 0x83, 0x28, 0xc9, 0xf2, 0x30,
		0x69, 0x99, 0xad, 0x9b, 0x3f, 0xc8, 0x16, 0x7e, 0xb2, 0xd5, 0x4b, 0xbb, 0x79, 0xb7, 0xd5, 0x8d,
		0xb3, 0xe9, 0x77, 0x5b, 0x83, 0x80, 0x7f, 0x2b, 0x4a, 0x72, 0x93, 0x76, 0xc2, 0xc1, 0xef, 0x4c,
		0xbf, 0xdd, 0x8a, 0xcd, 0x17, 0x13, 0x67, 0xa3, 0xff, 0xdb, 0x0a, 0xdb, 0xff, 0x09, 0x5b, 0x26,
		0x69, 0x45, 0x26, 0x9b, 0x7e, 0x7f, 0xb9, 0x95, 0xe5, 0x61, 0x6e, 0x74, 0xe8, 0x82, 0xbc, 0x39,
		0x29, 0x98, 0x92, 0x83, 0x0b, 0x09, 0xce, 0x32, 0x55, 0x95, 0x7d, 0xac, 0xba, 0xa4, 0xe3, 0x42,
		0xca, 0x71, 0x28, 0xe1, 0xb8, 0x92, 0x6e, 0x9c, 0x4b, 0x36, 0xce, 0xa5, 0x1a, 0xb7, 0x12, 0x4d,
		0xb9, 0xdc, 0xb8, 0xba, 0x14, 0x33, 0xdd, 0xb1, 0xb1, 0x09, 0x3b, 0xba, 0x49, 0x4c, 0xd3, 0xe4,
		0x25, 0x45, 0xe5, 0xa5, 0x72, 0x3c, 0x8e, 0x54, 0x36, 0x37, 0x47, 0xc1, 0xc1, 0xd6, 0xb5, 0xdb,
		0x29, 0x4b, 0x98, 0xf0, 0xa4, 0xc0, 0x1b, 0x61, 0x80, 0xa6, 0x9a, 0xc1, 0x80, 0xee, 0xf9, 0xad,
		0xfe, 0x79, 0xad, 0x17, 0xe7, 0xb3, 0xba, 0xe7, 0xb1, 0xd2, 0x16, 0xaa, 0xcc, 0xb4, 0xfc, 0x66,
		0x58, 0x15, 0x0d, 0x4e, 0x92, 0xa7, 0xfd, 0x56, 0x9e, 0x8c, 0xfd, 0xd4, 0x9b, 0xd1, 0x27, 0x3a,
		0x1c, 0x7f, 0xa0, 0xd3, 0xe3, 0xf1, 0xc7, 0x38, 0x3d, 0xcc, 0xa2, 0xec, 0xf4, 0x70, 0x32, 0xf7,
		0xd3, 0xa3, 0xc1, 0xa4, 0x4f, 0xf7, 0xa7, 0x13, 0x7d, 0x52, 0x4c, 0xcc, 0x95, 0x79, 0xb2, 0xd0,
		0x1e, 0xd1, 0xda, 0x1b, 0x3e, 0xee, 0x09, 0x19, 0x03, 0xb3, 0xff, 0xfa, 0x05, 0x5e, 0x7d, 0x25,
		0xec, 0x44, 0x41, 0x16, 0x76, 0x22, 0xb1, 0x97, 0x3e, 0x8d, 0x52, 0xa7, 0x23, 0x09, 0x19, 0xf0,
		0x24, 0x24, 0x15, 0x7a, 0xbc, 0xb4, 0x06, 0xa0, 0xc1, 0xf9, 0x15, 0x39, 0xbe, 0x16, 0xa7, 0x57,
		0xe7, 0xf0, 0xea, 0x9c, 0x5d, 0x97, 0xa3, 0x17, 0xcb, 0x69, 0xbd, 0x8c, 0x64, 0xa3, 0xff, 0x4a,
		0xd8, 0x91, 0xb7, 0xe0, 0x6b, 0x80, 0x94, 0x36, 0x5d, 0x59, 0x88, 0x54, 0x83, 0x4a, 0x4d, 0xc8,
		0x74, 0x00, 0x9d, 0xda, 0x10, 0xea, 0x0c, 0x4a, 0x9d, 0x41, 0xaa, 0x1b, 0x68, 0x2d, 0x87, 0xca,
		0x23, 0x0d, 0xb9, 0x73, 0x91, 0xe9, 0x98, 0x39, 0x2a, 0x1f, 0x67, 0x4d, 0x47, 0xe6, 0x34, 0xab,
		0x68, 0x30, 0xed, 0x10, 0xae, 0x5d, 0xc1, 0xb6, 0x73, 0xf8, 0x76, 0x0e, 0xe3, 0x6e, 0xe1, 0x5c,
		0x07, 0xd6, 0x95, 0xe0, 0x7d, 0xba, 0x94, 0x9c, 0x66, 0x49, 0x83, 0xe2, 0xcd, 0xd3, 0xac, 0xa9,
		0xd7, 0x21, 0xe7, 0xe5, 0xde, 0x8b, 0xd8, 0x9a, 0xb8, 0x32, 0xe5, 0x08, 0x61, 0x3c, 0xae, 0x6e,
		0x7c, 0x50, 0x23, 0x3e, 0x20, 0x3e, 0x20, 0x3e, 0x20, 0x3e, 0xf0, 0x21, 0x3e, 0xd0, 0xa2, 0x81,
		0xee, 0xe8, 0xa0, 0x6b, 0x5a, 0xe8, 0x88, 0x1e, 0x3a, 0x73, 0x03, 0x2e, 0xdd, 0x81, 0x07, 0x6e,
		0xc1, 0xb5, 0x7b, 0xf0, 0xc6, 0x4d, 0x78, 0xe3, 0x2e, 0xfc, 0x70, 0x1b, 0xba, 0xee, 0x43, 0xd9,
		0x8d, 0xb8, 0xa3, 0x9b, 0x0b, 0x3b, 0x9e, 0x6a, 0x70, 0x1e, 0x55, 0x83, 0xa3, 0x10, 0x9c, 0xc3,
		0xaf, 0xb9, 0xb2, 0x57, 0x14, 0xbb, 0x72, 0xba, 0xfe, 0x3b, 0x14, 0xb9, 0x2a, 0x99, 0x63, 0x2d,
		0x65, 0x89, 0x21, 0x93, 0x84, 0x67, 0xb1, 0x71, 0xd8, 0x0a, 0x67, 0x32, 0x01, 0xa8, 0x19, 0xd4,
		0x0c, 0x6a, 0x06, 0x35, 0x83, 0x9a, 0x95, 0x88, 0x9a, 0xd1, 0x31, 0xaf, 0x14, 0x41, 0xc2, 0x85,
		0xc9, 0xd3, 0xa8, 0xe5, 0x2e, 0x46, 0x18, 0x8f, 0xaf, 0xbc, 0x7d, 0x5e, 0x9a, 0x4e, 0xd8, 0x8f,
		0x87, 0x00, 0x55, 0xab, 0x12, 0x9f, 0x10, 0x9f, 0x10, 0x9f, 0x10, 0x9f, 0x10, 0x9f, 0x94, 0x29,
		0x3e, 0xe9, 0x47, 0x49, 0xbe, 0x5d, 0xa7, 0xfe, 0xa1, 0xe2, 0x17, 0xf5, 0x0f, 0xa9, 0x7f, 0x38,
		0x33, 0x0f, 0xea, 0x1f, 0xae, 0x51, 0xff, 0xf0, 0x76, 0xd3, 0xa4, 0xfe, 0xa1, 0xeb, 0x80, 0xc0,
		0xdd, 0xa8, 0x74, 0xe1, 0x5c, 0xde, 0x6c, 0x33, 0xf7, 0x89, 0x57, 0x19, 0x99, 0x57, 0xd0, 0x67,
		0xe8, 0x33, 0xf4, 0x19, 0xfa, 0x5c, 0x46, 0xfa, 0x4c, 0xe6, 0x95, 0x27, 0x99, 0x57, 0xf4, 0xe0,
		0xf4, 0x26, 0xf5, 0x87, 0xa6, 0x8f, 0xce, 0x5f, 0x81, 0x0f, 0xfd, 0x1e, 0x49, 0xc1, 0x2a, 0x36,
		0x4f, 0xa3, 0x4e, 0xbd, 0x0d, 0x06, 0xea, 0x4b, 0xc5, 0xb8, 0x71, 0x01, 0xb3, 0xad, 0xb0, 0xb3,
		0x35, 0xbe, 0x00, 0xca, 0x55, 0x5d, 0x8f, 0x75, 0x04, 0x67, 0xfa, 0x01, 0x05, 0x3d, 0x4a, 0xa5,
		0x0f, 0x70, 0x61, 0x97, 0x0b, 0xbb, 0xc5, 0xf7, 0xde, 0x14, 0xf4, 0x90, 0x06, 0xc5, 0x85, 0xf2,
		0xf4, 0x54, 0xf4, 0x78, 0x44, 0x98, 0x60, 0xce, 0x07, 0x1b, 0x3e, 0x48, 0xbb, 0xfd, 0x3c, 0x4a,
		0x1c, 0x94, 0xf6, 0xb8, 0x39, 0x01, 0x6a, 0x7c, 0x94, 0x21, 0x64, 0xc8, 0x52, 0x02, 0x86, 0x15,
		0x0c, 0x18, 0xb2, 0x94, 0x70, 0xe1, 0x71, 0x0b, 0xa9, 0x5f, 0xdf, 0x63, 0x52, 0xee, 0x3f, 0xc8,
		0xa2, 0x76, 0xe6, 0xb0, 0xca, 0xc7, 0xfc, 0x3c, 0xdc, 0x9c, 0x38, 0xd7, 0x38, 0x71, 0x2e, 0xaf,
		0x7b, 0x70, 0xed, 0x26, 0xbc, 0x71, 0x17, 0xde, 0xb8, 0x0d, 0x1f, 0xdc, 0x87, 0xae, 0x1b, 0x51,
		0x76, 0x27, 0xce, 0xdc, 0xca, 0xed, 0xee, 0xc5, 0xfd, 0x51, 0xeb, 0xfc, 0x74, 0x1c, 0x59, 0xbb,
		0x1b, 0x67, 0xe3, 0xdc, 0xe9, 0xf8, 0xe0, 0x7c, 0xbc, 0x71, 0x42, 0xbe, 0x38, 0x23, 0xef, 0x9c,
		0x92, 0x77, 0xce, 0xc9, 0x27, 0x27, 0xe5, 0xc6, 0x59, 0x39, 0x72, 0x5a, 0xce, 0x9d, 0xd7, 0x74,
		0x02, 0xca, 0xe5, 0x6e, 0x7f, 0x0a, 0x5a, 0xaa, 0x65, 0x70, 0x3d, 0x75, 0x63, 0xde, 0xb8, 0x33,
		0x9f, 0xdc, 0x9a, 0x77, 0xee, 0xcd, 0x37, 0x37, 0xe7, 0xad, 0xbb, 0xf3, 0xd6, 0xed, 0xf9, 0xe8,
		0xfe, 0xdc, 0xba, 0x41, 0xc7, 0xee, 0xd0, 0x1b, 0xb7, 0x38, 0x9d, 0xc8, 0x79, 0xda, 0xed, 0xf7,
		0xfc, 0xd9, 0xda, 0x13, 0xec, 0x1b, 0x4d, 0xcb, 0x93, 0xdd, 0x33, 0x53, 0x8e, 0xa2, 0x13, 0xc6,
		0x99, 0xf1, 0x65, 0x5e, 0x7e, 0xdc, 0x1a, 0xf4, 0xce, 0x99, 0xfb, 0xe8, 0xd4, 0xbd, 0x75, 0xee,
		0xbe, 0x3a, 0x79, 0xef, 0x9d, 0xbd, 0xf7, 0x4e, 0xdf, 0x67, 0xe7, 0xef, 0x47, 0x10, 0xe0, 0x49,
		0x30, 0x30, 0x7d, 0x51, 0xce, 0xae, 0x15, 0xfd, 0x14, 0xad, 0xdc, 0x55, 0x13, 0xfb, 0x29, 0x83,
		0xad, 0x3d, 0xc1, 0x90, 0x3d, 0x31, 0xe2, 0x4a, 0x62, 0xa2, 0xf3, 0xcf, 0x67, 0xdd, 0xd4, 0xbf,
		0x78, 0x72, 0x3a, 0x33, 0x42, 0x37, 0x42, 0x37, 0x42, 0x37, 0x42, 0x37, 0x42, 0x37, 0x42, 0xb7,
		0x95, 0x08, 0xdd, 0xa2, 0x5e, 0x10, 0xb6, 0xdb, 0xa9, 0xc9, 0x32, 0x1f, 0xa3, 0xb7, 0x3d, 0x8f,
		0xe6, 0x34, 0x7e, 0x87, 0x1f, 0xbd, 0x82, 0x00, 0xbf, 0x20, 0xfd, 0x86, 0x65, 0x7d, 0x69, 0x78,
		0x68, 0x5b, 0x0b, 0x36, 0xf6, 0xcc, 0xc3, 0xb9, 0x1d, 0x87, 0x79, 0x6e, 0xd2, 0xc4, 0x3b, 0x73,
		0x9b, 0x4e, 0x70, 0x7d, 0xfd, 0x63, 0x35, 0xd8, 0x3b, 0xf9, 0xfe, 0xb1, 0x16, 0xec, 0x9d, 0x8c,
		0xbe, 0xad, 0x0d, 0xff, 0x6f, 0xf4, 0x7d, 0xfd, 0x63, 0x35, 0x68, 0x4c, 0xbe, 0x6f, 0x7e, 0xac,
		0x06, 0xcd, 0x93, 0x8d, 0x4f, 0x9f, 0x36, 0x37, 0xbe, 0x6d, 0x5f, 0x3d, 0xfc, 0x17, 0xd7, 0xff,
		0xfa, 0xf1, 0xd3, 0xa7, 0xde, 0xb7, 0x37, 0x57, 0x83, 0xff, 0x1e, 0x5d, 0x9d, 0xfc, 0x7d, 0xe3,
		0x97, 0x8a, 0x77, 0xab, 0x72, 0xe2, 0xd5, 0x8c, 0xae, 0x9e, 0x82, 0x52, 0xf7, 0x46, 0xa9, 0x1d,
		0x50, 0xaa, 0xb4, 0x28, 0xf5, 0xfc, 0xfb, 0x00, 0x4b, 0xc2, 0xa0, 0xb3, 0x1f, 0xbc, 0x3a, 0xf9,
		0x56, 0x7d, 0xda, 0xb8, 0xda, 0x78, 0xbe, 0xb1, 0x7e, 0xf3, 0x67, 0xcf, 0x37, 0xbe, 0x55, 0x9f,
		0x36, 0xaf, 0xd6, 0xd7, 0x6f, 0xf9, 0x9b, 0x5f, 0x6e, 0x7b, 0xc6, 0xc6, 0xf7, 0xf5, 0xf5, 0xf5,
		0x31, 0x3e, 0xcd, 0x61, 0xd6, 0xc7, 0x6a, 0xed, 0xe4, 0x97, 0xe1, 0xb7, 0xa3, 0xff, 0x4e, 0x51,
		0xef, 0x5e, 0xff, 0x78, 0xe3, 0x56, 0xac, 0x7b, 0xea, 0xad, 0x0b, 0xf8, 0xf7, 0xf3, 0x93, 0xbf,
		0x3f, 0xdf, 0xf8, 0xb6, 0x73, 0x35, 0xf9, 0x7e, 0xf8, 0xdf, 0x8d, 0xef, 0xeb, 0x9b, 0x7f, 0xfb,
		0xf4, 0x69, 0x73, 0xf3, 0x6f, 0x1b, 0xa3, 0x85, 0x1a, 0xff, 0xbb, 0xbf, 0x8d, 0xfe, 0xf6, 0x97,
		0xe7, 0xcf, 0x17, 0x7e, 0xb4, 0xb1, 0xfe, 0xd7, 0x4d, 0x60, 0xbd, 0x20, 0xa4, 0xca, 0x9f, 0x75,
		0x41, 0x56, 0x1d, 0x6c, 0xc4, 0x5e, 0xda, 0xcd, 0xcd, 0xb0, 0x0e, 0x6a, 0x60, 0xe2, 0xe8, 0x3c,
		0x3a, 0x8b, 0x8d, 0x7f, 0x0a, 0xeb, 0x6d, 0x93, 0xf4, 0xef, 0xfc, 0x3e, 0x4f, 0xfb, 0x1c, 0xdf,
		0xdf, 0x3e, 0x1d, 0x34, 0xe0, 0x07, 0x58, 0x3b, 0x1a, 0xf0, 0x7d, 0x8d, 0x1c, 0x0d, 0x78, 0xc9,
		0x09, 0xa2, 0x01, 0x17, 0x83, 0x0b, 0x73, 0x7c, 0xff, 0x18, 0xda, 0xcb, 0xf1, 0xbd, 0x3f, 0x71,
		0x66, 0x16, 0xb5, 0x03, 0x87, 0x17, 0xfd, 0xee, 0x34, 0xdf, 0xf1, 0xbc, 0x08, 0xdb, 0x08, 0xdb,
		0x08, 0xdb, 0x08, 0xdb, 0x08, 0xdb, 0x08, 0xdb, 0x56, 0x22, 0x6c, 0xeb, 0x27, 0x51, 0x37, 0xe1,
		0xd4, 0xfe, 0x5e, 0xaf, 0x8f, 0x53, 0xfb, 0xfb, 0x06, 0x53, 0x69, 0x30, 0x88, 0xa7, 0xf2, 0xc1,
		0xb2, 0x79, 0x7c, 0x1c, 0xb6, 0xe7, 0xe1, 0xdc, 0xbc, 0x34, 0x35, 0x7f, 0x4d, 0x6e, 0xc1, 0xf4,
		0x2e, 0x7a, 0x71, 0x16, 0xc4, 0xe1, 0x99, 0x89, 0x3d, 0x3d, 0xf2, 0xf2, 0xdd, 0x02, 0x8b, 0x61,
		0x89, 0xfe, 0x5b, 0xe4, 0xa2, 0xa7, 0x75, 0xd5, 0x8d, 0xf4, 0xb1, 0xd6, 0xb9, 0x5b, 0x80, 0xa9,
		0xba, 0xed, 0x76, 0x5a, 0x3e, 0x6b, 0x9d, 0x2e, 0xac, 0x0f, 0xdd, 0x54, 0x0b, 0x2e, 0x9b, 0xdc,
		0x7b, 0xda, 0x93, 0x96, 0x98, 0xb5, 0x9d, 0x82, 0x4d, 0xdc, 0xa3, 0xd6, 0x99, 0x05, 0x65, 0x86,
		0xf7, 0xdb, 0x8b, 0xe1, 0x57, 0xf6, 0xa2, 0xf6, 0x5e, 0xac, 0x36, 0x9e, 0x35, 0x77, 0x9b, 0x6c,
		0x48, 0xb5, 0x0d, 0xf9, 0x84, 0x59, 0xda, 0xf8, 0x3a, 0x79, 0x02, 0xec, 0xae, 0x02, 0x9d, 0x30,
		0x49, 0xff, 0xc2, 0xa4, 0xa3, 0xb6, 0x4f, 0xc5, 0xe1, 0x14, 0xb5, 0x46, 0x01, 0xe6, 0x7a, 0x90,
		0xf4, 0x2f, 0x06, 0x0e, 0xd7, 0xef, 0xcd, 0xee, 0xef, 0xec, 0xfc, 0x84, 0x20, 0x4f, 0xa1, 0xa7,
		0x00, 0x9a, 0x9a, 0xe7, 0xd7, 0x1b, 0x16, 0x30, 0xe6, 0x99, 0xc7, 0x73, 0xf4, 0xfd, 0xba, 0xc3,
		0x74, 0xa2, 0xff, 0x9e, 0xbf, 0xc7, 0x50, 0x1b, 0xdd, 0x70, 0xd8, 0xbd, 0xba, 0xf9, 0xc3, 0xef,
		0xb7, 0xfd, 0xb3, 0xda, 0xd3, 0xdd, 0xab, 0xe7, 0x77, 0xfc, 0xcd, 0xce, 0xd5, 0xf3, 0x7b, 0x3e,
		0xa3, 0x79, 0xb5, 0xbe, 0xf0, 0x4f, 0x07, 0x3f, 0xaf, 0xdf, 0xf5, 0x0b, 0x8d, 0x3b, 0x7e, 0x61,
		0xfb, 0xae, 0x5f, 0xd8, 0xbe, 0xe3, 0x17, 0xee, 0x9c, 0x52, 0xfd, 0x8e, 0x5f, 0x68, 0x5e, 0x7d,
		0x5f, 0xf8, 0xf7, 0xeb, 0xb7, 0xff, 0xd3, 0x9d, 0xab, 0x8d, 0xef, 0x77, 0xfd, 0xdd, 0xee, 0xd5,
		0xf7, 0xe7, 0x1b, 0x1b, 0x7f, 0xa9, 0xf8, 0x0b, 0xed, 0x3e, 0x6f, 0xad, 0xb7, 0xef, 0x0f, 0xff,
		0xc9, 0xfe, 0x62, 0x7f, 0x15, 0x79, 0x7f, 0x3d, 0x21, 0xd4, 0x2c, 0xde, 0x3a, 0x71, 0x53, 0xb6,
		0x1c, 0xac, 0xd5, 0x67, 0x96, 0xea, 0x29, 0x2b, 0xe5, 0x36, 0xa1, 0x6f, 0xeb, 0xb1, 0xda, 0x45,
		0x8f, 0x1d, 0x35, 0x43, 0xbf, 0x73, 0x3e, 0x3e, 0x36, 0x49, 0xbf, 0xd1, 0x4a, 0x73, 0x6b, 0xbe,
		0xb5, 0xda, 0xfc, 0x1f, 0x55, 0x3b, 0xaa, 0xfb, 0x67, 0xd2, 0x0e, 0xcd, 0xd9, 0x9f, 0x4a, 0x87,
		0xbe, 0x55, 0x38, 0xf4, 0xe4, 0x6c, 0x91, 0xce, 0x12, 0x3f, 0xb2, 0x15, 0x3a, 0x4b, 0xdc, 0x65,
		0xbc, 0x74, 0x96, 0x78, 0xa8, 0x4f, 0xa7, 0xb3, 0x84, 0x5f, 0x41, 0x96, 0x37, 0xd7, 0x19, 0x1c,
		0xf6, 0xb2, 0xff, 0x29, 0x87, 0xf4, 0x20, 0x7d, 0x72, 0xb1, 0xf7, 0xfd, 0xd4, 0x83, 0x13, 0xcf,
		0xe9, 0x53, 0x01, 0x3f, 0xae, 0xbe, 0xfa, 0x75, 0xe5, 0x95, 0x58, 0x8e, 0x58, 0x8e, 0x58, 0x8e,
		0x58, 0x8e, 0x58, 0x8e, 0x58, 0x8e, 0x58, 0xee, 0x41, 0xb1, 0xdc, 0xd8, 0x7f, 0x13, 0xc9, 0xe9,
		0x47, 0x72, 0x83, 0xf5, 0xf7, 0x28, 0x90, 0x1b, 0x4e, 0x87, 0x6e, 0xaf, 0x73, 0x71, 0x5c, 0x9d,
		0x38, 0x8e, 0x38, 0x8e, 0x38, 0x8e, 0x38, 0x6e, 0x45, 0xe2, 0x38, 0x6f, 0xba, 0xbd, 0x86, 0x71,
		0xdc, 0x6d, 0x85, 0xb9, 0x69, 0x07, 0xed, 0xcb, 0x24, 0xbc, 0x88, 0x5a, 0xc1, 0xe0, 0xcf, 0xb1,
		0x7f, 0x25, 0xbf, 0xee, 0x9a, 0x28, 0x35, 0xc0, 0x7c, 0x16, 0x48, 0x7c, 0x74, 0xb0, 0xde, 0x3a,
		0x5a, 0x5f, 0x1d, 0xae, 0xf7, 0x8e, 0xd7, 0x7b, 0x07, 0xec, 0xb3, 0x23, 0xf6, 0xc3, 0x21, 0x7b,
		0xe2, 0x98, 0xfd, 0x13, 0x5a, 0x16, 0xf9, 0xa3, 0x97, 0xe5, 0x9a, 0xa8, 0x04, 0x76, 0xdf, 0x2f,
		0x8f, 0xf3, 0x7d, 0xbd, 0x2e, 0xc7, 0x44, 0x21, 0xb0, 0xf2, 0x58, 0xdc, 0x82, 0xe5, 0x79, 0x5f,
		0x6e, 0xa9, 0x00, 0x65, 0x96, 0x0a, 0x52, 0x5e, 0xa9, 0x00, 0xb7, 0xf6, 0x8b, 0x54, 0x4e, 0xa9,
		0x60, 0xa5, 0x5b, 0x0a, 0x57, 0x3e, 0xa9, 0x88, 0x55, 0x5a, 0x0a, 0x50, 0x2e, 0xa9, 0x50, 0x65,
		0x92, 0x0a, 0xbb, 0xc7, 0x8a, 0x54, 0x16, 0xa9, 0x90, 0x1b, 0x8d, 0x9a, 0x23, 0x8f, 0xfa, 0xa2,
		0xe6, 0x48, 0xb9, 0xc2, 0xf7, 0x62, 0x94, 0x37, 0x2a, 0x42, 0x59, 0x23, 0xcf, 0xcb, 0x19, 0x71,
		0xb7, 0xbc, 0x50, 0x10, 0x42, 0x17, 0xe6, 0xa5, 0xb1, 0x82, 0x2e, 0xcc, 0x8f, 0x98, 0x20, 0xe5,
		0x52, 0x28, 0x97, 0x32, 0x03, 0xd1, 0x3e, 0x6e, 0xa1, 0x22, 0x94, 0x1f, 0x62, 0x1f, 0xb1, 0x8f,
		0xfc, 0x0d, 0x75, 0xa8, 0x25, 0xe2, 0xd9, 0x7a, 0xf8, 0xd0, 0x31, 0xf2, 0x3c, 0xed, 0xf6, 0x7b,
		0xfe, 0x65, 0x8f, 0x8d, 0xa6, 0xe5, 0x5f, 0xf7, 0xf1, 0x4e, 0x18, 0x67, 0xb4, 0x1f, 0xbf, 0x7d,
		0x3a, 0xe4, 0xb0, 0x3d, 0xc0, 0xc0, 0xc9, 0x61, 0xbb, 0xaf, 0x91, 0x93, 0xc3, 0xb6, 0xe4, 0x04,
		0xc9, 0x61, 0x2b, 0x86, 0x08, 0x44, 0xfb, 0xf1, 0xc7, 0xe8, 0x3d, 0xb4, 0x1f, 0xf7, 0x27, 0x98,
		0xf4, 0xa6, 0xa6, 0xd6, 0x82, 0x01, 0x7b, 0x52, 0x5b, 0x8b, 0xd0, 0x8d, 0xd0, 0x8d, 0xd0, 0x8d,
		0xd0, 0x8d, 0xd0, 0x8d, 0xd0, 0x4d, 0x09, 0xad, 0xa2, 0x9e, 0x87, 0xa7, 0x76, 0xdc, 0x3e, 0xb8,
		0xef, 0x97, 0xdf, 0x27, 0xc2, 0x0d, 0x4e, 0x84, 0x1f, 0x19, 0xdf, 0xf8, 0x7e, 0x92, 0x35, 0x3a,
		0xc8, 0x3a, 0xf9, 0xfe, 0xb1, 0x16, 0xec, 0x9d, 0x8c, 0xbe, 0xad, 0x0d, 0xff, 0x6f, 0xf4, 0x7d,
		0xfd, 0x63, 0x35, 0x68, 0x4c, 0xbe, 0x6f, 0x7e, 0xac, 0x06, 0xcd, 0x93, 0x8d, 0x4f, 0x9f, 0x36,
		0x37, 0xbe, 0x6d, 0x5f, 0x3d, 0xfc, 0x17, 0xd7, 0xff, 0xfa, 0xf1, 0xd3, 0xa7, 0xde, 0xb7, 0x37,
		0x57, 0x83, 0xff, 0x1e, 0x5d, 0x9d, 0xfc, 0x7d, 0xe3, 0x17, 0x0e, 0x73, 0x0a, 0xe1, 0xf7, 0x8a,
		0x81, 0x52, 0xe4, 0xad, 0x94, 0x17, 0xa5, 0x9e, 0xcf, 0x1d, 0x21, 0x57, 0x9f, 0x36, 0xae, 0x36,
		0x9e, 0x6f, 0xac, 0xdf, 0xfc, 0xd9, 0xf3, 0x8d, 0x6f, 0xd5, 0xa7, 0xcd, 0xab, 0xf5, 0xf5, 0x5b,
		0xfe, 0xe6, 0x97, 0xdb, 0x9e, 0xb1, 0xf1, 0x7d, 0x7d, 0x7d, 0x7d, 0x8c, 0x4f, 0x73, 0x98, 0xf5,
		0xb1, 0x5a, 0x3b, 0xf9, 0x65, 0xf8, 0xed, 0xe8, 0xbf, 0x53, 0xd4, 0xbb, 0xd7, 0x3f, 0xde, 0xb8,
		0x15, 0xeb, 0x9e, 0x7a, 0xeb, 0x02, 0xfe, 0xfd, 0xfc, 0xe4, 0xef, 0xcf, 0x37, 0xbe, 0xed, 0x5c,
		0x4d, 0xbe, 0x1f, 0xfe, 0x77, 0xe3, 0xfb, 0xfa, 0xe6, 0xdf, 0x3e, 0x7d, 0xda, 0xdc, 0xfc, 0xdb,
		0xc6, 0x68, 0xa1, 0xc6, 0xff, 0xee, 0x6f, 0xa3, 0xbf, 0xfd, 0xe5, 0xf9, 0xf3, 0x85, 0x1f, 0x6d,
		0xac, 0xff, 0x75, 0x13, 0x58, 0x2f, 0x08, 0xa9, 0x5a, 0xe3, 0x8c, 0xde, 0x27, 0x47, 0x5b, 0xe9,
		0xa5, 0xdd, 0xdc, 0x0c, 0xaf, 0x5a, 0x04, 0x26, 0x8e, 0xce, 0xa3, 0xb3, 0xd8, 0xf8, 0xa7, 0xb0,
		0xde, 0x36, 0x49, 0xff, 0xce, 0xef, 0xf3, 0xb4, 0xcf, 0xf1, 0xfd, 0xed, 0xd3, 0x41, 0x03, 0x7e,
		0x80, 0xb5, 0xa3, 0x01, 0xdf, 0xd7, 0xc8, 0xd1, 0x80, 0x97, 0x9c, 0x20, 0x1a, 0x70, 0x31, 0xb8,
		0x30, 0xc7, 0xf7, 0x8f, 0xa1, 0xbd, 0x1c, 0xdf, 0xfb, 0x13, 0x67, 0x7a, 0xd2, 0x42, 0x61, 0xc1,
		0x7c, 0xbd, 0x68, 0xa5, 0x40, 0xd8, 0x46, 0xd8, 0x46, 0xd8, 0x46, 0xd8, 0x46, 0xd8, 0x46, 0xd8,
		0xa6, 0x84, 0x56, 0xfd, 0xc4, 0xaf, 0xfb, 0xf9, 0x9c, 0xda, 0xdf, 0xf7, 0xcb, 0xe3, 0xf3, 0x30,
		0x3f, 0xcb, 0x51, 0xfa, 0x6c, 0x62, 0x7e, 0x9b, 0x9a, 0xbf, 0x26, 0xb7, 0x60, 0x7a, 0x5e, 0x97,
		0xab, 0x2c, 0x82, 0x05, 0x16, 0xc3, 0x12, 0xfd, 0xb7, 0xc8, 0x45, 0x4f, 0xeb, 0x7b, 0x39, 0xcb,
		0x9b, 0xd6, 0xb9, 0x5b, 0x80, 0xa9, 0x16, 0xa3, 0xbc, 0x65, 0x71, 0xac, 0x75, 0xba, 0xb0, 0x45,
		0x2a, 0x77, 0xe9, 0xa9, 0x6c, 0x72, 0xef, 0x69, 0x17, 0xad, 0xfc, 0xe5, 0x74, 0xe2, 0x05, 0xac,
		0xce, 0xe7, 0x19, 0x33, 0xbc, 0xdf, 0x5e, 0x2c, 0x50, 0x59, 0xcc, 0xd2, 0xec, 0xc5, 0x22, 0x95,
		0xc9, 0x2c, 0xc5, 0x86, 0x7c, 0xc2, 0x2c, 0x6d, 0x7c, 0x9d, 0x3c, 0x01, 0x76, 0x57, 0x81, 0x4e,
		0x14, 0xa3, 0xbc, 0xe6, 0x02, 0xe3, 0x6d, 0x14, 0x60, 0xae, 0x7e, 0x97, 0xdb, 0xf4, 0x1f, 0x8a,
		0xa8, 0xe4, 0x5b, 0x0a, 0xc8, 0x29, 0xca, 0xf5, 0x86, 0x05, 0x8c, 0x79, 0xe6, 0xf1, 0x1c, 0x7d,
		0xbf, 0xee, 0x30, 0x9d, 0x28, 0x65, 0x06, 0x29, 0x33, 0x78, 0x0b, 0xb4, 0xfb, 0xbc, 0xb5, 0x8a,
		0x50, 0xbe, 0x93, 0xfd, 0xc5, 0xfe, 0x2a, 0x5e, 0xe8, 0xc4, 0x95, 0xaa, 0x22, 0x85, 0x96, 0x1e,
		0x67, 0x06, 0xf8, 0xcd, 0x5a, 0x7d, 0x66, 0xa9, 0x9e, 0xb2, 0x52, 0x6e, 0x13, 0xfa, 0xb6, 0x1e,
		0xab, 0xdd, 0x44, 0x7f, 0x3f, 0x49, 0xba, 0xf9, 0x08, 0x5f, 0xbc, 0xe8, 0xa5, 0x9f, 0xb5, 0x3e,
		0x9b, 0x8b, 0xb0, 0x17, 0xe6, 0x9f, 0x07, 0xf0, 0xb7, 0xd5, 0xed, 0x99, 0xa4, 0x35, 0xcc, 0xa6,
		0x0e, 0x12, 0x93, 0xff, 0xb7, 0x9b, 0xfe, 0x19, 0x44, 0x49, 0x96, 0x87, 0x49, 0xcb, 0x6c, 0xdd,
		0xfc, 0x41, 0xb6, 0xf0, 0x93, 0xad, 0x5e, 0xda, 0xcd, 0xbb, 0xad, 0x6e, 0x9c, 0x4d, 0xbf, 0xdb,
		0x8a, 0xb2, 0x28, 0xdb, 0x8a, 0x92, 0xdc, 0xa4, 0x9d, 0x70, 0xf0, 0x3b, 0xd3, 0x6f, 0xb7, 0x62,
		0xf3, 0xc5, 0xc4, 0xd9, 0xe8, 0xff, 0xb6, 0xc2, 0x4e, 0x14, 0x64, 0x61, 0x27, 0xda, 0x0a, 0x3b,
		0x5b, 0x99, 0x39, 0xbf, 0x30, 0x49, 0x1e, 0xa4, 0xdd, 0x7e, 0x1e, 0x25, 0xe7, 0x5b, 0x61, 0xfb,
		0x3f, 0x61, 0xcb, 0x24, 0xad, 0xcb, 0x20, 0x8b, 0xda, 0xd9, 0xfc, 0x1f, 0xb7, 0xb2, 0x3c, 0xcc,
		0x8d, 0xdb, 0x80, 0xc9, 0x9d, 0x45, 0xbb, 0x19, 0xd9, 0xd1, 0x1e, 0xaa, 0xfc, 0xc3, 0x5c, 0xce,
		0xd6, 0x31, 0x5c, 0x73, 0x7a, 0x27, 0xa2, 0x72, 0x14, 0x65, 0xf9, 0x7e, 0x9e, 0xbb, 0x2d, 0xf4,
		0x58, 0x79, 0x1d, 0x25, 0x07, 0xb1, 0x19, 0x6c, 0x97, 0xcc, 0xed, 0x69, 0x66, 0xe5, 0x75, 0xf8,
		0x75, 0x66, 0x26, 0xb5, 0x67, 0x8d, 0xc6, 0xce, 0x6e, 0xa3, 0x51, 0xdd, 0xdd, 0xde, 0xad, 0xee,
		0x35, 0x9b, 0xb5, 0x9d, 0x9a, 0xc3, 0xc3, 0xca, 0xca, 0xdb, 0xb4, 0x6d, 0x52, 0xd3, 0x7e, 0x31,
		0x30, 0xa0, 0xa4, 0x1f, 0xc7, 0x2b, 0xb5, 0x6f, 0x3c, 0xf1, 0x39, 0x85, 0xf7, 0x35, 0x0e, 0x19,
		0x41, 0x25, 0xcb, 0xd3, 0x7e, 0x2b, 0x4f, 0xc6, 0x34, 0xe5, 0xcd, 0x68, 0x31, 0x0e, 0xc7, 0x6b,
		0x71, 0x7a, 0x3c, 0x5e, 0x81, 0xd3, 0xc3, 0x2c, 0xca, 0x4e, 0x0f, 0x27, 0x1f, 0xfb, 0xf4, 0x68,
		0xf0, 0x79, 0x4f, 0xf7, 0x3b, 0xa7, 0xef, 0x47, 0x1f, 0xf3, 0xdd, 0xe8, 0x53, 0x9e, 0xee, 0x4f,
		0x3e, 0xd6, 0xfb, 0xa8, 0xed, 0xc6, 0x77, 0xea, 0x7b, 0x2e, 0xdd, 0x11, 0x95, 0xf7, 0xba, 0xeb,
		0x3d, 0x5e, 0xc0, 0xbd, 0xad, 0x6b, 0xf7, 0x7a, 0xd6, 0xa7, 0x68, 0x79, 0xe3, 0x7b, 0x71, 0xa3,
		0xe5, 0xd4, 0x36, 0xbb, 0x99, 0xaa, 0x2b, 0xd7, 0x93, 0x50, 0xde, 0x75, 0x13, 0x3d, 0x46, 0x79,
		0x58, 0x57, 0xf7, 0x5d, 0x5d, 0xde, 0x6b, 0x75, 0x7e, 0x7f, 0xd5, 0xf5, 0x3d, 0x55, 0x6f, 0xee,
		0xa3, 0x7a, 0x73, 0xef, 0xd4, 0x87, 0xfb, 0xa5, 0xe5, 0x8e, 0x2a, 0x5e, 0x46, 0x6e, 0xe8, 0xed,
		0x0c, 0xa6, 0xbb, 0xdb, 0x6f, 0x8b, 0xfe, 0xc5, 0xd5, 0x86, 0x73, 0xe3, 0x66, 0x9c, 0xbb, 0x1b,
		0x1f, 0xdc, 0x8e, 0x37, 0xee, 0xc7, 0x17, 0x37, 0xe4, 0x9d, 0x3b, 0xf2, 0xce, 0x2d, 0xf9, 0xe4,
		0x9e, 0xdc, 0xd1, 0x6d, 0x97, 0x82, 0x97, 0x2b, 0xb7, 0x35, 0x9d, 0x40, 0x6b, 0x82, 0x98, 0x8e,
		0xf7, 0xe8, 0x04, 0xb4, 0xc6, 0xf3, 0x71, 0xbc, 0x1f, 0xdc, 0xba, 0x31, 0x6f, 0xdc, 0x99, 0x4f,
		0x6e, 0xcd, 0x3b, 0xf7, 0xe6, 0x9b, 0x9b, 0xf3, 0xd6, 0xdd, 0x79, 0xeb, 0xf6, 0x7c, 0x74, 0x7f,
		0x6e, 0xdd, 0xa0, 0x63, 0x77, 0xe8, 0x8d, 0x5b, 0x9c, 0x4e, 0x64, 0x58, 0xff, 0x22, 0xe8, 0xf6,
		0xf2, 0xa8, 0x9b, 0x64, 0xfe, 0xd5, 0xda, 0x9b, 0x9f, 0x1e, 0x25, 0xf7, 0x7c, 0x76, 0xa2, 0x3e,
		0x3a, 0x53, 0x6f, 0x9d, 0xaa, 0xaf, 0xce, 0xd5, 0x7b, 0x27, 0xeb, 0xbd, 0xb3, 0xf5, 0xd9, 0xe9,
		0xfa, 0xe1, 0x7c, 0x3d, 0x71, 0xc2, 0xd3, 0x17, 0xe5, 0x6f, 0xc9, 0x3d, 0x3f, 0x73, 0xa0, 0x7d,
		0xcc, 0x7d, 0xf6, 0x2c, 0xe7, 0x99, 0x0a, 0xce, 0xd7, 0x47, 0x07, 0x3e, 0x36, 0x07, 0xf1, 0x89,
		0x35, 0x12, 0x4e, 0x12, 0x4e, 0x12, 0x4e, 0x12, 0x4e, 0x12, 0x4e, 0x12, 0x4e, 0xca, 0xa2, 0x55,
		0xd4, 0x0b, 0xbc, 0xdb, 0x7c, 0x54, 0x71, 0xbe, 0xef, 0x97, 0xef, 0xbd, 0x97, 0xbd, 0xc4, 0xf5,
		0x35, 0x9a, 0x9a, 0x2e, 0x39, 0x41, 0xcd, 0xd6, 0xcb, 0x5b, 0xe3, 0xc1, 0x36, 0xbe, 0xaf, 0x7f,
		0xac, 0x05, 0xf5, 0x93, 0xc9, 0x1f, 0xb6, 0x3f, 0x56, 0x83, 0xfa, 0xc9, 0xc6, 0x06, 0x0d, 0x3b,
		0x0b, 0xe1, 0x02, 0x8b, 0x81, 0x58, 0x3b, 0x20, 0x56, 0x59, 0x11, 0xab, 0x70, 0x6d, 0x98, 0x67,
		0x81, 0x6f, 0xf0, 0xff, 0xdf, 0xea, 0x57, 0x1b, 0xdf, 0xd7, 0x07, 0x70, 0x59, 0x9b, 0x82, 0x60,
		0x6d, 0xf0, 0x90, 0x67, 0x83, 0x7f, 0xbe, 0x1a, 0x2d, 0x9a, 0xb7, 0x36, 0xff, 0x0e, 0xe0, 0x17,
		0x82, 0x79, 0xad, 0x51, 0x53, 0xc1, 0x27, 0x17, 0x4c, 0xe7, 0xbc, 0x87, 0xf8, 0x58, 0x74, 0xd7,
		0xbb, 0xfc, 0x3c, 0xba, 0xeb, 0xfd, 0x27, 0x86, 0xee, 0xfa, 0xc8, 0x09, 0xa2, 0xbb, 0x16, 0xdd,
		0xfb, 0xa3, 0xbb, 0xfe, 0xd4, 0xef, 0x79, 0xd9, 0xe4, 0x0c, 0xe5, 0xb5, 0x04, 0x3a, 0x86, 0xd7,
		0x4d, 0xcc, 0x68, 0x9f, 0x57, 0x1e, 0x8b, 0x5b, 0xb0, 0x3c, 0xef, 0x9b, 0x94, 0x15, 0xa0, 0x39,
		0x59, 0x41, 0x9a, 0x92, 0x15, 0xa0, 0xd7, 0x45, 0x91, 0x9a, 0x90, 0x15, 0xac, 0xe1, 0x51, 0xe1,
		0x9a, 0x8e, 0x15, 0xb1, 0xb7, 0x51, 0x01, 0x9a, 0x8c, 0x15, 0xaa, 0xb9, 0x58, 0x61, 0xf7, 0x58,
		0x91, 0x9a, 0x89, 0x15, 0x72, 0xa3, 0xd1, 0xa9, 0xe7, 0x51, 0x5f, 0x74, 0xea, 0x29, 0x57, 0xf8,
		0x5e, 0x8c, 0xa6, 0x60, 0x45, 0x68, 0x06, 0xe6, 0x79, 0x13, 0x30, 0x3a, 0x32, 0x14, 0x0a, 0x42,
		0x7c, 0xcf, 0x99, 0xf1, 0xb7, 0xb9, 0x17, 0x49, 0x33, 0xcb, 0x4c, 0x90, 0x26, 0x43, 0x34, 0x19,
		0x9a, 0x81, 0x68, 0x1f, 0xb7, 0x50, 0x11, 0x9a, 0x76, 0xb1, 0x8f, 0xd8, 0x47, 0xfe, 0x86, 0x3a,
		0x64, 0x8b, 0x79, 0xb6, 0x1e, 0x74, 0xe0, 0xa1, 0x03, 0xcf, 0xc3, 0x2a, 0xa7, 0xcf, 0x94, 0xd8,
		0x9e, 0xf9, 0x7e, 0x6b, 0x5c, 0x56, 0x6e, 0x55, 0x9b, 0xef, 0x38, 0x2c, 0x02, 0xea, 0xc9, 0x25,
		0x77, 0xbf, 0x2e, 0xb7, 0x7b, 0x22, 0xbf, 0x53, 0x60, 0xf0, 0x47, 0x96, 0x42, 0x81, 0xc1, 0xbb,
		0x8c, 0x97, 0x02, 0x83, 0x0f, 0xf5, 0xe4, 0x14, 0x18, 0xf4, 0x2b, 0xb4, 0xf2, 0x26, 0x19, 0xf2,
		0xba, 0x94, 0x9f, 0x09, 0x3b, 0xa9, 0xe9, 0xf8, 0x80, 0x37, 0x13, 0xa1, 0xd0, 0x83, 0xcc, 0xa0,
		0xca, 0xf1, 0x38, 0xda, 0xdc, 0xdc, 0x1c, 0xf5, 0x4f, 0x1c, 0x07, 0x75, 0x44, 0x72, 0x0e, 0xc2,
		0xff, 0x61, 0xff, 0x4a, 0x6f, 0x02, 0xb9, 0xd1, 0x74, 0x28, 0x14, 0x3d, 0x17, 0xc7, 0xd5, 0x89,
		0xe3, 0x88, 0xe3, 0x88, 0xe3, 0x88, 0xe3, 0x56, 0x24, 0x8e, 0xa3, 0x50, 0xf4, 0x3d, 0xa3, 0x4b,
		0x0a, 0x45, 0x17, 0x46, 0x0c, 0xf1, 0xd1, 0x99, 0x7a, 0xeb, 0x54, 0x7d, 0x75, 0xae, 0xde, 0x3b,
		0x59, 0xef, 0x9d, 0xad, 0xcf, 0x4e, 0xd7, 0x0f, 0xe7, 0xeb, 0x89, 0x13, 0xf6, 0x4f, 0x54, 0x59,
		0x40, 0x2b, 0x0a, 0x45, 0xdf, 0x7b, 0x4e, 0x14, 0x8a, 0xf6, 0x6e, 0x73, 0x51, 0x28, 0x9a, 0x70,
		0x92, 0x70, 0x92, 0x70, 0x92, 0x70, 0x92, 0x70, 0x92, 0x70, 0xd2, 0x03, 0xb4, 0xa2, 0x50, 0xf4,
		0xc3, 0x5e, 0x21, 0xe5, 0x4a, 0xee, 0x6d, 0x58, 0x14, 0x8a, 0x7e, 0x6c, 0x74, 0x43, 0xa1, 0x68,
		0x0a, 0x45, 0x97, 0xcc, 0x05, 0x16, 0x03, 0xb1, 0x28, 0x14, 0x5d, 0x5a, 0xc4, 0xa2, 0x50, 0xb4,
		0x2b, 0x57, 0x41, 0xa1, 0xe8, 0x15, 0x64, 0x5e, 0x6b, 0x5c, 0xfd, 0xf1, 0xc9, 0x05, 0x53, 0x28,
		0xfa, 0x21, 0x3e, 0x16, 0xdd, 0xf5, 0x2e, 0x3f, 0x8f, 0xee, 0x7a, 0xff, 0x89, 0xa1, 0xbb, 0x3e,
		0x72, 0x82, 0xe8, 0xae, 0x45, 0xf7, 0xfe, 0xe8, 0xae, 0x3f, 0xf5, 0x7b, 0x14, 0x8a, 0x7e, 0xe0,
		0x4b, 0x44, 0x79, 0xbd, 0xa7, 0x69, 0x51, 0x28, 0xba, 0x54, 0x96, 0xe6, 0xaf, 0xc5, 0x2d, 0x58,
		0x1e, 0x85, 0xa2, 0x2d, 0x4c, 0x91, 0x42, 0xd1, 0x96, 0x16, 0x92, 0x42, 0xd1, 0x72, 0xd3, 0xa5,
		0x50, 0xf4, 0xca, 0x04, 0xd1, 0x3f, 0xde, 0x63, 0x14, 0x8a, 0x96, 0xdf, 0x63, 0x14, 0x8a, 0x5e,
		0x05, 0xce, 0x5c, 0xbc, 0xd9, 0x51, 0x28, 0xba, 0x5c, 0xe1, 0x3b, 0x85, 0xa2, 0xad, 0xcd, 0x91,
		0x42, 0xd1, 0x45, 0x86, 0x12, 0x72, 0x66, 0xee, 0x0b, 0x19, 0x14, 0x8a, 0x7e, 0xfc, 0xdc, 0x28,
		0x70, 0x4b, 0x81, 0x5b, 0x0a, 0x45, 0x2f, 0xb7, 0x85, 0x28, 0x14, 0xcd, 0x3e, 0xa2, 0x50, 0x74,
		0x29, 0x42, 0x41, 0xb2, 0xc5, 0x7c, 0x98, 0x01, 0x85, 0xa2, 0xe7, 0xe7, 0x53, 0xe0, 0x42, 0xd1,
		0xa3, 0xaa, 0x72, 0xab, 0x5a, 0x5d, 0xf0, 0xc9, 0x0a, 0xed, 0x9e, 0xca, 0x3f, 0xcc, 0xa5, 0xf3,
		0x74, 0xae, 0xca, 0x51, 0x94, 0xe5, 0xfb, 0x79, 0xee, 0xb6, 0x8a, 0x55, 0xe5, 0x75, 0x94, 0x1c,
		0xc4, 0x66, 0xb0, 0x3f, 0x32, 0xb7, 0x5a, 0x7f, 0xe5, 0x75, 0xf8, 0x75, 0x66, 0x26, 0xb5, 0x67,
		0x8d, 0xc6, 0xce, 0x6e, 0xa3, 0x51, 0xdd, 0xdd, 0xde, 0xad, 0xee, 0x35, 0x9b, 0xb5, 0x9d, 0x9a,
		0x43, 0x49, 0xbf, 0xf2, 0x36, 0x6d, 0x9b, 0xd4, 0xb4, 0x5f, 0x0c, 0xec, 0x26, 0xe9, 0xc7, 0xf1,
		0x4a, 0x6d, 0x17, 0x4f, 0x9c, 0x4c, 0x81, 0x9d, 0x4b, 0xc5, 0x69, 0xf1, 0xd6, 0xb4, 0xdf, 0xca,
		0x93, 0xb1, 0x02, 0xf5, 0x66, 0xb4, 0x0c, 0x87, 0xe3, 0x55, 0x38, 0x3d, 0x1e, 0x7f, 0xf6, 0xd3,
		0xc3, 0x2c, 0xca, 0x4e, 0x0f, 0x27, 0x1f, 0xf8, 0xf4, 0x68, 0xf0, 0x49, 0x4f, 0xf7, 0x3b, 0xa7,
		0xef, 0x47, 0x1f, 0xf0, 0xdd, 0xe8, 0xf3, 0x9d, 0x8e, 0x52, 0x9a, 0xdf, 0x47, 0x6d, 0x37, 0x9e,
		0x52, 0xdf, 0x4f, 0xe9, 0x8e, 0xa8, 0xbc, 0xc5, 0x5d, 0x6f, 0xed, 0xa2, 0x6d, 0x69, 0x5d, 0xa3,
		0xd7, 0x33, 0x3d, 0x9d, 0x91, 0x94, 0x8c, 0xdb, 0x95, 0x51, 0x17, 0xc1, 0x98, 0x15, 0x1d, 0x91,
		0x5d, 0xc7, 0xa3, 0xb3, 0xf3, 0xe4, 0xf7, 0x81, 0xc2, 0x1e, 0x50, 0x2e, 0xd7, 0xee, 0xa4, 0x2c,
		0xbb, 0x72, 0xf9, 0x75, 0xf5, 0x32, 0xeb, 0x2e, 0xae, 0x8e, 0xcd, 0x5e, 0x0d, 0x1b, 0x20, 0x8d,
		0x26, 0x56, 0x38, 0xba, 0xfc, 0xe5, 0xfc, 0x72, 0x97, 0xf3, 0xcb, 0x5b, 0x37, 0x2f, 0x67, 0x0d,
		0x5f, 0x3c, 0x71, 0xc7, 0xa3, 0x96, 0x52, 0xbb, 0x24, 0x79, 0x65, 0xe0, 0xe8, 0xc7, 0xfe, 0x55,
		0x79, 0xdf, 0x4c, 0xa0, 0x62, 0x3a, 0x03, 0x65, 0xab, 0x75, 0x93, 0x9b, 0xea, 0xec, 0x86, 0xb1,
		0xcb, 0x9b, 0xc4, 0x0e, 0xdd, 0x82, 0x6b, 0xf7, 0xe0, 0x8d, 0x9b, 0xf0, 0xc6, 0x5d, 0xf8, 0xe1,
		0x36, 0x56, 0x43, 0x9b, 0x71, 0x76, 0x1b, 0xf7, 0x3a, 0x5d, 0xad, 0x6d, 0x92, 0x3c, 0xca, 0x2f,
		0xdd, 0x74, 0x27, 0x9b, 0xc6, 0xf8, 0x0e, 0x84, 0xff, 0xca, 0xe1, 0xf8, 0xa3, 0xbf, 0x08, 0x33,
		0x87, 0xb8, 0x33, 0x79, 0x11, 0xfb, 0xaf, 0x0e, 0x4f, 0x3f, 0xfc, 0xeb, 0xf8, 0xc0, 0x15, 0xec,
		0x0c, 0xef, 0x56, 0x64, 0x4e, 0x53, 0x86, 0x3c, 0xe9, 0x3d, 0x76, 0x78, 0xfc, 0x47, 0xa3, 0xb2,
		0x8a, 0x4d, 0xe0, 0xfc, 0x59, 0xff, 0x9d, 0xca, 0x8a, 0x1d, 0x93, 0x9f, 0x94, 0xdd, 0xb1, 0x3e,
		0x29, 0xe1, 0xfe, 0xa9, 0x98, 0x24, 0x3c, 0x8b, 0x4d, 0xdb, 0x1d, 0x37, 0x9b, 0x4c, 0x00, 0x6a,
		0x06, 0x35, 0x83, 0x9a, 0x41, 0xcd, 0xa0, 0x66, 0x25, 0xa2, 0x66, 0x67, 0xdd, 0x6e, 0x6c, 0xc2,
		0xc4, 0x25, 0x2d, 0xab, 0x11, 0x24, 0x2c, 0xbd, 0x96, 0x17, 0x26, 0x4f, 0xa3, 0x96, 0xbb, 0x18,
		0x61, 0x3c, 0xbe, 0xf2, 0xf6, 0x79, 0x69, 0x3a, 0x61, 0x3f, 0x1e, 0x02, 0x54, 0xad, 0x4a, 0x7c,
		0x42, 0x7c, 0x42, 0x7c, 0x42, 0x7c, 0x42, 0x7c, 0x52, 0xa6, 0xf8, 0xc4, 0x59, 0x6d, 0x33, 0x87,
		0x35, 0xcb, 0x1c, 0xd7, 0x22, 0x73, 0x7b, 0x8b, 0xc0, 0xf9, 0xfd, 0x23, 0x4f, 0xea, 0x15, 0x4d,
		0xeb, 0x10, 0xb9, 0x9e, 0x87, 0x47, 0x95, 0x85, 0xae, 0xdc, 0x5e, 0x2b, 0xc1, 0x34, 0x6f, 0x98,
		0x66, 0xa3, 0xbe, 0xd7, 0xd8, 0xdb, 0xd9, 0xad, 0xef, 0x35, 0xb1, 0x51, 0x37, 0x01, 0x81, 0xbb,
		0x51, 0x4f, 0x60, 0xed, 0x4b, 0x9b, 0x6d, 0xe6, 0x3e, 0xf1, 0x2a, 0x23, 0xf3, 0x0a, 0xfa, 0x0c,
		0x7d, 0x86, 0x3e, 0x43, 0x9f, 0xcb, 0x48, 0x9f, 0xc9, 0xbc, 0xf2, 0x24, 0xf3, 0xea, 0x3d, 0xa9,
		0x57, 0xbe, 0xa4, 0xfe, 0xfc, 0xfe, 0xe6, 0xf0, 0xd7, 0xfd, 0xf7, 0x1f, 0xc8, 0xbe, 0x72, 0xf7,
		0x0a, 0x5e, 0xff, 0x7e, 0xf4, 0xc1, 0xf5, 0x4b, 0x20, 0x05, 0xab, 0xd8, 0x3c, 0x8d, 0xab, 0xc6,
		0x36, 0x18, 0xa8, 0x8f, 0x57, 0x8d, 0xf5, 0x0a, 0x28, 0x29, 0xdc, 0xd3, 0x7d, 0x52, 0x60, 0xf3,
		0x9c, 0x14, 0x38, 0x9a, 0x68, 0x04, 0x6b, 0x5a, 0x6a, 0x81, 0x6e, 0x51, 0x23, 0xfd, 0xe2, 0x45,
		0x5e, 0x14, 0x29, 0xd2, 0x2d, 0x46, 0x24, 0x6d, 0xaa, 0xca, 0x08, 0xea, 0x23, 0x72, 0x56, 0x54,
		0x6a, 0x02, 0x2c, 0x53, 0x8c, 0x41, 0x16, 0xd5, 0xe5, 0xb0, 0x56, 0xe6, 0xc9, 0x42, 0x5b, 0x42,
		0x6b, 0x2b, 0x78, 0xb7, 0x05, 0x64, 0xac, 0xcb, 0xfe, 0xbb, 0x17, 0x78, 0xef, 0x95, 0xd6, 0x44,
		0xd7, 0x96, 0x79, 0xdf, 0x53, 0xe6, 0x36, 0x1e, 0x47, 0xc8, 0x72, 0x65, 0xab, 0x71, 0x88, 0x8b,
		0xff, 0x1a, 0x22, 0xbf, 0xa2, 0x98, 0xaf, 0x25, 0xda, 0xab, 0x8b, 0xf3, 0xea, 0x22, 0xbc, 0xae,
		0xd8, 0x5e, 0x2c, 0x6f, 0x25, 0x5d, 0xed, 0x42, 0xed, 0x02, 0x95, 0xf2, 0x85, 0xa9, 0xd9, 0xec,
		0xe7, 0x4e, 0x18, 0x67, 0xe2, 0x9c, 0x4c, 0xe7, 0xc4, 0x56, 0xed, 0x84, 0x56, 0xf3, 0x44, 0xd6,
		0xc1, 0x09, 0xac, 0xf6, 0x89, 0xab, 0xb3, 0x13, 0x56, 0x67, 0x27, 0xaa, 0x6e, 0x4e, 0x50, 0x8b,
		0x2d, 0x28, 0xa9, 0x9d, 0x88, 0x3a, 0xb8, 0xe0, 0xa4, 0x74, 0xa1, 0x49, 0x90, 0xe5, 0x0a, 0x86,
		0x92, 0x43, 0xa6, 0x16, 0x24, 0xfd, 0x8b, 0x33, 0x93, 0xea, 0x79, 0xe2, 0xb9, 0x51, 0x71, 0x8f,
		0xb8, 0x47, 0xdc, 0x23, 0xee, 0x11, 0xf7, 0xe8, 0x06, 0x21, 0x67, 0x51, 0x52, 0xe3, 0x78, 0x43,
		0xf7, 0x16, 0x8d, 0xe2, 0xa1, 0xad, 0x8b, 0x5b, 0x32, 0xae, 0xf2, 0x75, 0xa7, 0xdd, 0xb8, 0x95,
		0xc7, 0x75, 0x78, 0xa3, 0x40, 0x33, 0x03, 0xdd, 0xc5, 0xad, 0x16, 0xd7, 0xa6, 0x54, 0x5f, 0x21,
		0x53, 0x2a, 0x49, 0x16, 0xc5, 0x09, 0x8c, 0x6a, 0xc1, 0xac, 0x7a, 0x61, 0x96, 0x45, 0x5f, 0x8c,
		0x1e, 0x99, 0x9a, 0x0c, 0x88, 0xac, 0x09, 0x6f, 0x83, 0xb7, 0xc1, 0xdb, 0xe0, 0x6d, 0x0e, 0x79,
		0x1b, 0xb2, 0xa6, 0x1f, 0x4e, 0x38, 0x8d, 0xba, 0x69, 0x94, 0x5f, 0x2a, 0x7a, 0xe1, 0xc9, 0x88,
		0xb8, 0x45, 0xdc, 0x22, 0x6e, 0x11, 0xb7, 0x88, 0x5b, 0xbc, 0x51, 0x2e, 0xe8, 0x19, 0x3a, 0xe6,
		0x12, 0x5f, 0xe8, 0x98, 0xa2, 0xe2, 0x53, 0x15, 0x1d, 0x53, 0xc4, 0x94, 0x56, 0x50, 0xc7, 0xac,
		0xd5, 0x77, 0x51, 0x32, 0x8b, 0x36, 0xca, 0x09, 0x37, 0x20, 0xe4, 0x21, 0x62, 0xe5, 0x6e, 0x40,
		0x8c, 0xb3, 0xf2, 0x57, 0xf8, 0xfe, 0xc3, 0x67, 0x13, 0xc7, 0xdd, 0x20, 0xec, 0xe7, 0x9f, 0x4d,
		0x92, 0x47, 0x2d, 0xd9, 0x77, 0x3f, 0x0d, 0x37, 0x6f, 0x1d, 0x95, 0xbb, 0x11, 0xae, 0x08, 0x38,
		0x77, 0x23, 0x0a, 0x48, 0xb0, 0xb9, 0x1b, 0x71, 0xf7, 0xd2, 0x88, 0xdf, 0x8d, 0x10, 0xbe, 0x36,
		0xb6, 0xb0, 0x31, 0x45, 0xaf, 0x8f, 0x29, 0x41, 0xa5, 0x1a, 0x64, 0x6a, 0x42, 0xa7, 0x03, 0x08,
		0xd5, 0x86, 0x52, 0x67, 0x90, 0xea, 0x0c, 0x5a, 0xdd, 0x40, 0xac, 0x0e, 0x99, 0x92, 0xd6, 0x2e,
		0xb5, 0x9a, 0x30, 0xeb, 0x46, 0xae, 0x3e, 0x44, 0xb2, 0x8b, 0x4b, 0xad, 0x9b, 0xf1, 0xe1, 0x48,
		0xbf, 0x51, 0x2f, 0x3d, 0x4a, 0xef, 0xff, 0xb5, 0x52, 0xbb, 0x13, 0xe7, 0x6e, 0xc5, 0xad, 0x7b,
		0xd1, 0x71, 0x33, 0x4a, 0xee, 0x66, 0xba, 0x94, 0xea, 0x25, 0x43, 0x1d, 0x76, 0x02, 0x53, 0xee,
		0x00, 0x46, 0xb1, 0xaf, 0x9f, 0xec, 0xe2, 0x15, 0xad, 0xa0, 0x74, 0x5b, 0xe8, 0x23, 0xaa, 0xa8,
		0xca, 0x9b, 0x8b, 0x64, 0xca, 0xd3, 0x9f, 0x46, 0x31, 0xdb, 0x69, 0x30, 0x18, 0x62, 0x01, 0x62,
		0x01, 0x62, 0x01, 0x62, 0x01, 0x62, 0x81, 0x9a, 0x5e, 0xbb, 0xb0, 0xc1, 0x55, 0x74, 0x5b, 0x65,
		0x48, 0x86, 0x98, 0x43, 0xcc, 0x21, 0xe6, 0x10, 0x73, 0xbf, 0x20, 0x7e, 0x3a, 0xe0, 0x80, 0x90,
		0x04, 0xbd, 0x30, 0xcb, 0xc6, 0x36, 0xec, 0xa8, 0x41, 0xd4, 0xfc, 0x34, 0x68, 0x12, 0x55, 0x36,
		0xc7, 0xe0, 0x81, 0x83, 0x70, 0xed, 0x28, 0xbc, 0x71, 0x18, 0xde, 0x38, 0x0e, 0x3f, 0x1c, 0x88,
		0xae, 0x23, 0x51, 0x76, 0x28, 0xd3, 0x25, 0x76, 0xdf, 0x24, 0x2a, 0xed, 0xf6, 0xf3, 0x28, 0x39,
		0x77, 0x85, 0xf2, 0x73, 0x21, 0xff, 0x33, 0xda, 0x95, 0x14, 0x20, 0x18, 0x5a, 0xf5, 0x76, 0x25,
		0xb7, 0x4a, 0xc6, 0x7f, 0x9a, 0x4b, 0x15, 0xd9, 0x58, 0xcf, 0xa4, 0xae, 0x54, 0x1a, 0x0a, 0x84,
		0xb9, 0xd1, 0x17, 0x34, 0x46, 0xc3, 0x96, 0x5c, 0xcf, 0xa8, 0xa3, 0x67, 0xa0, 0x67, 0xa0, 0x67,
		0xe0, 0xc2, 0xd1, 0x33, 0xd0, 0x33, 0xd0, 0x33, 0xd0, 0x33, 0xd0, 0x33, 0xd0, 0x33, 0xd0, 0x33,
		0xd0, 0x33, 0x08, 0x86, 0xd0, 0x33, 0xee, 0xa5, 0x67, 0xd0, 0x8b, 0xd5, 0x17, 0x5b, 0x25, 0x3d,
		0xf3, 0x86, 0x6d, 0xfa, 0xde, 0xed, 0xf2, 0xff, 0x0e, 0xe6, 0xbd, 0x3f, 0x37, 0xed, 0xd3, 0x7f,
		0x98, 0x4b, 0x52, 0x4a, 0x17, 0x97, 0xf9, 0x4f, 0x73, 0xd9, 0xfa, 0x1c, 0x2a, 0x54, 0x03, 0x9a,
		0xcd, 0x2b, 0x1d, 0x8d, 0x48, 0x72, 0xa9, 0xaf, 0x84, 0x8e, 0xe4, 0xd2, 0x12, 0x12, 0x32, 0x92,
		0x4b, 0x71, 0xfc, 0xcb, 0x3a, 0x7e, 0x0d, 0xe0, 0x96, 0xf2, 0xfe, 0xa3, 0xb9, 0x13, 0x02, 0xdc,
		0xb2, 0xd6, 0x1a, 0xc7, 0x80, 0xaa, 0xc7, 0x7f, 0xea, 0xce, 0xbf, 0x8e, 0xf3, 0xc7, 0xf9, 0xe3,
		0xfc, 0x4b, 0xe5, 0xfc, 0x29, 0x43, 0x41, 0x19, 0x8a, 0x62, 0x72, 0x45, 0x17, 0x6e, 0xc3, 0xa1,
		0xfb, 0x70, 0xe5, 0x46, 0x9c, 0xbb, 0x13, 0xe7, 0x6e, 0xc5, 0xad, 0x7b, 0xd1, 0x71, 0x33, 0x4a,
		0xee, 0x66, 0xba, 0x94, 0x94, 0xa1, 0x28, 0xb0, 0xa1, 0x20, 0x77, 0x94, 0x46, 0xee, 0x50, 0x38,
		0x7f, 0xa3, 0x66, 0xb4, 0xaa, 0xdd, 0x79, 0x6d, 0x6f, 0x15, 0x51, 0x85, 0xc7, 0xaa, 0x9a, 0xb6,
		0xca, 0xc5, 0xae, 0x55, 0x9a, 0xe9, 0x6b, 0xb6, 0x88, 0x16, 0xe6, 0x40, 0x14, 0xb7, 0xf6, 0x93,
		0xc3, 0x50, 0xdc, 0x7a, 0x95, 0x1d, 0xae, 0x38, 0xc7, 0x98, 0x41, 0xb0, 0xb0, 0x93, 0x9a, 0x8e,
		0xe4, 0x8e, 0x99, 0x70, 0x08, 0xc1, 0x96, 0x2c, 0x95, 0xe3, 0x71, 0xcc, 0xb0, 0xb9, 0x39, 0x8a,
		0x0b, 0xb7, 0xe6, 0x90, 0x79, 0x85, 0xfd, 0x61, 0x2f, 0x6c, 0xfd, 0x69, 0xf2, 0xa0, 0xd5, 0xed,
		0x0f, 0xe2, 0x86, 0x4c, 0xde, 0x25, 0xde, 0x1c, 0x90, 0x96, 0x0f, 0x78, 0x45, 0xbc, 0x22, 0x5e,
		0xd1, 0xc2, 0xd2, 0xc8, 0xb7, 0x7c, 0xc8, 0x92, 0x9e, 0x62, 0xc3, 0x87, 0xc1, 0x68, 0x24, 0xd9,
		0xf9, 0x06, 0x9b, 0x0e, 0xe0, 0x53, 0x1b, 0x46, 0x9d, 0xc1, 0xa9, 0x33, 0x58, 0x75, 0x03, 0xaf,
		0xb2, 0x30, 0x2b, 0x0c, 0xb7, 0x6a, 0xb0, 0x3b, 0x23, 0x83, 0x51, 0xef, 0x40, 0x0a, 0x98, 0xa9,
		0x77, 0x50, 0x06, 0xc0, 0x76, 0x0e, 0xdc, 0xce, 0x01, 0xdc, 0x2d, 0x90, 0xeb, 0x00, 0xba, 0x12,
		0xb0, 0xab, 0x03, 0xfc, 0x74, 0xc0, 0x76, 0xda, 0xed, 0xf5, 0x8c, 0xc3, 0x4a, 0x07, 0x93, 0x09,
		0x50, 0xe3, 0xa0, 0x6c, 0xce, 0xc0, 0x03, 0xa7, 0xe0, 0xda, 0x39, 0x78, 0xe3, 0x24, 0xbc, 0x71,
		0x16, 0x7e, 0x38, 0x0d, 0x5d, 0xe7, 0xa1, 0xec, 0x44, 0xa6, 0x4b, 0xec, 0xbe, 0xc6, 0xc1, 0x58,
		0x7a, 0xde, 0xae, 0x3b, 0x2c, 0x6e, 0xb0, 0xeb, 0x60, 0xe8, 0x77, 0x61, 0x72, 0x3e, 0x58, 0x80,
		0x8f, 0x4e, 0xf6, 0x96, 0x1b, 0x8c, 0x1b, 0x7e, 0xf0, 0xd7, 0x51, 0xe2, 0x0c, 0x64, 0x1d, 0xfb,
		0xf6, 0x85, 0x69, 0xfc, 0x11, 0xc6, 0x7d, 0xe3, 0xc1, 0x3c, 0x5e, 0xa5, 0x61, 0x2b, 0x8f, 0xba,
		0xc9, 0xcb, 0xe8, 0x3c, 0xca, 0xb3, 0xc1, 0x84, 0x9c, 0xcd, 0xe7, 0xea, 0xa9, 0x43, 0xd3, 0x0c,
		0xbf, 0x62, 0x9a, 0x37, 0x4c, 0xb3, 0x51, 0xdf, 0x6b, 0xec, 0xed, 0xec, 0xd6, 0xf7, 0x9a, 0xd8,
		0xa8, 0x9b, 0x98, 0xc0, 0xdd, 0xa8, 0x27, 0x65, 0xad, 0xf9, 0xa3, 0xa8, 0x39, 0xf5, 0xd2, 0x6e,
		0xcb, 0x64, 0x99, 0x4b, 0xfe, 0x7c, 0x3d, 0x05, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86,
		0x41, 0xc3, 0xa0, 0x61, 0xd0, 0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41,
		0xc3, 0xa0, 0xbd, 0x65, 0xd0, 0xa9, 0x69, 0x99, 0xe8, 0x8b, 0x4b, 0x02, 0x3d, 0x9d, 0x01, 0xfc,
		0x19, 0xfe, 0x0c, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19,
		0xfe, 0x0c, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0x1e, 0xf3, 0xe7, 0x3c, 0x0d, 0x93, 0xec,
		0x22, 0xca, 0x5d, 0x32, 0xe8, 0xe9, 0x1c, 0xe0, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e,
		0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d,
		0x87, 0xf6, 0x96, 0x43, 0x67, 0xa3, 0x00, 0xd6, 0x11, 0x7b, 0x1e, 0x8e, 0x0e, 0x6f, 0x86, 0x37,
		0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc, 0x19, 0xde, 0x0c, 0x6f, 0x86, 0x37, 0xc3,
		0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0xb3, 0x87, 0x23, 0x69, 0x95, 0x43, 0x53, 0xee, 0xb2, 0x74,
		0xad, 0x08, 0x78, 0xd2, 0xfd, 0xe6, 0x46, 0x05, 0xf7, 0xad, 0x56, 0x96, 0xf4, 0x34, 0xba, 0x2d,
		0xe9, 0x59, 0x13, 0x5d, 0xc0, 0xca, 0x62, 0x97, 0xbe, 0xf7, 0x3a, 0x3f, 0x1e, 0xce, 0xf9, 0xd7,
		0xf1, 0x94, 0x4f, 0x7f, 0x1d, 0x4c, 0x99, 0x16, 0xe7, 0x0b, 0x4b, 0x6c, 0xb2, 0xcf, 0x7a, 0x75,
		0xd7, 0x07, 0x83, 0x51, 0x76, 0xfd, 0x41, 0x03, 0x51, 0x76, 0xdd, 0xae, 0x79, 0x50, 0x76, 0x9d,
		0xb2, 0xeb, 0x3f, 0x5b, 0x32, 0xca, 0xae, 0x17, 0x0e, 0x90, 0x17, 0x81, 0x99, 0xb2, 0xeb, 0x65,
		0x00, 0x6c, 0xe7, 0xc0, 0xed, 0x1c, 0xc0, 0xdd, 0x02, 0x79, 0x39, 0x75, 0x06, 0xca, 0xae, 0x6b,
		0xed, 0x5a, 0x12, 0x0f, 0x56, 0xc0, 0x29, 0xb8, 0x76, 0x0e, 0xde, 0x38, 0x09, 0x6f, 0x9c, 0x85,
		0x1f, 0x4e, 0x43, 0xd7, 0x79, 0x28, 0x3b, 0x91, 0xe9, 0x12, 0x93, 0x78, 0x40, 0xe2, 0x81, 0xf2,
		0x07, 0x27, 0xf1, 0xe0, 0x7a, 0x1a, 0x24, 0x1e, 0xb8, 0x46, 0xc0, 0x79, 0xd3, 0x24, 0xf1, 0x60,
		0xc1, 0x34, 0x49, 0x3c, 0x70, 0x1d, 0x13, 0xb8, 0x1b, 0x95, 0x84, 0xfd, 0xe5, 0xcd, 0x96, 0xb2,
		0xeb, 0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0, 0x61, 0xd0,
		0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xdf, 0xc7, 0x6c, 0x29, 0xbb,
		0x0e, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19, 0xfe, 0x0c,
		0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0xf3, 0x7d, 0xf8, 0x33, 0x65, 0xd7,
		0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1,
		0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0xbe, 0x8f, 0xd9, 0x52, 0x76, 0x1d,
		0xde, 0x0c, 0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc, 0x19, 0xde,
		0x0c, 0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0x85, 0xe3, 0xcd, 0x94, 0x5d, 0xb7, 0xa1, 0x08,
		0x78, 0x5a, 0xde, 0xda, 0x64, 0x9f, 0xa9, 0xba, 0xee, 0x8d, 0x99, 0x52, 0x75, 0xfd, 0xda, 0x2c,
		0x0b, 0x56, 0x74, 0xfd, 0x20, 0xfb, 0x4c, 0xcd, 0xf5, 0xc5, 0x15, 0x8e, 0x22, 0xc5, 0x9a, 0xeb,
		0x83, 0xc1, 0xa8, 0xb9, 0xfe, 0xa0, 0x81, 0xa8, 0xb9, 0x6e, 0xd7, 0x3c, 0xa8, 0xb9, 0x4e, 0xcd,
		0xf5, 0x9f, 0x2d, 0x19, 0x35, 0xd7, 0x0b, 0x07, 0xc8, 0x8b, 0xc0, 0x4c, 0xcd, 0xf5, 0x32, 0x00,
		0xb6, 0x73, 0xe0, 0x76, 0x0e, 0xe0, 0x6e, 0x81, 0xbc, 0x9c, 0x22, 0x03, 0x35, 0xd7, 0xb5, 0x76,
		0x2d, 0x59, 0x07, 0x2b, 0xe0, 0x14, 0x5c, 0x3b, 0x07, 0x6f, 0x9c, 0x84, 0x37, 0xce, 0xc2, 0x0f,
		0xa7, 0xa1, 0xeb, 0x3c, 0x94, 0x9d, 0xc8, 0x74, 0x89, 0xc9, 0x3a, 0x20, 0xeb, 0x40, 0xf9, 0x83,
		0x93, 0x75, 0x70, 0x3d, 0x0d, 0xb2, 0x0e, 0x5c, 0x23, 0xe0, 0xbc, 0x69, 0x92, 0x75, 0xb0, 0x60,
		0x9a, 0x64, 0x1d, 0xb8, 0x8e, 0x09, 0xdc, 0x8d, 0x4a, 0xb6, 0xfe, 0xf2, 0x66, 0x4b, 0xcd, 0x75,
		0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0, 0x61, 0xd0, 0x30, 0x68, 0x18,
		0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0, 0xef, 0x63, 0xb6, 0xd4, 0x5c, 0x87,
		0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19, 0xfe, 0x0c, 0x7f, 0x86, 0x3f,
		0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0xf9, 0x3e, 0xfc, 0x99, 0x9a, 0xeb, 0x70,
		0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0, 0x70, 0x68,
		0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xdf, 0xc7, 0x6c, 0xa9, 0xb9, 0x0e, 0x6f,
		0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc, 0x19, 0xde, 0x0c, 0x6f, 0x86,
		0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0xe6, 0xc2, 0xf1, 0x66, 0x6a, 0xae, 0xdb, 0x50, 0x04, 0x3c,
		0x2d, 0x6e, 0x1d, 0x45, 0xd4, 0x5c, 0xf7, 0xc7, 0x4c, 0xa9, 0xb9, 0x7e, 0x6d, 0x96, 0x05, 0xab,
		0xb9, 0x7e, 0x18, 0x51, 0x73, 0xfd, 0x96, 0x15, 0x8e, 0x32, 0xcd, 0x9a, 0xeb, 0x19, 0x35, 0xd7,
		0x1f, 0x38, 0x10, 0x35, 0xd7, 0xed, 0x9a, 0x07, 0x35, 0xd7, 0xa9, 0xb9, 0xfe, 0xb3, 0x25, 0xa3,
		0xe6, 0x7a, 0xe1, 0x00, 0x79, 0x11, 0x98, 0xa9, 0xb9, 0x5e, 0x06, 0xc0, 0x76, 0x0e, 0xdc, 0xce,
		0x01, 0xdc, 0x2d, 0x90, 0x97, 0x53, 0x64, 0xa0, 0xe6, 0xba, 0xd6, 0xae, 0x25, 0xeb, 0x60, 0x05,
		0x9c, 0x82, 0x6b, 0xe7, 0xe0, 0x8d, 0x93, 0xf0, 0xc6, 0x59, 0xf8, 0xe1, 0x34, 0x74, 0x9d, 0x87,
		0xb2, 0x13, 0x99, 0x2e, 0x31, 0x59, 0x07, 0x64, 0x1d, 0x28, 0x7f, 0x70, 0xb2, 0x0e, 0xae, 0xa7,
		0x41, 0xd6, 0x81, 0x6b, 0x04, 0x9c, 0x37, 0x4d, 0xb2, 0x0e, 0x16, 0x4c, 0x93, 0xac, 0x03, 0xd7,
		0x31, 0x81, 0xbb, 0x51, 0xc9, 0xd6, 0x5f, 0xde, 0x6c, 0xa9, 0xb9, 0x0e, 0x83, 0x86, 0x41, 0xc3,
		0xa0, 0x61, 0xd0, 0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0,
		0x61, 0xd0, 0x30, 0x68, 0x18, 0xf4, 0x7d, 0xcc, 0x96, 0x9a, 0xeb, 0xf0, 0x67, 0xf8, 0x33, 0xfc,
		0x19, 0xfe, 0x0c, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19,
		0xfe, 0x0c, 0x7f, 0x86, 0x3f, 0xdf, 0x87, 0x3f, 0x53, 0x73, 0x1d, 0x0e, 0x0d, 0x87, 0x86, 0x43,
		0xc3, 0xa1, 0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3,
		0xa1, 0xe1, 0xd0, 0x70, 0xe8, 0xfb, 0x98, 0x2d, 0x35, 0xd7, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33,
		0xbc, 0x19, 0xde, 0x0c, 0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc,
		0x19, 0xde, 0x5c, 0x38, 0xde, 0x4c, 0xcd, 0x75, 0x1b, 0x8a, 0x80, 0xaf, 0xc5, 0xad, 0x33, 0x6a,
		0xae, 0xfb, 0x63, 0xa6, 0xd4, 0x5c, 0xbf, 0x36, 0xcb, 0xa2, 0xd5, 0x5c, 0xcf, 0xa8, 0xb9, 0x7e,
		0xcb, 0x0a, 0xc7, 0x59, 0x4f, 0xaf, 0xe6, 0xfa, 0x60, 0x30, 0x6a, 0xae, 0x3f, 0x68, 0x20, 0x6a,
		0xae, 0xdb, 0x35, 0x0f, 0x6a, 0xae, 0x53, 0x73, 0xfd, 0x67, 0x4b, 0x46, 0xcd, 0xf5, 0xc2, 0x01,
		0xf2, 0x22, 0x30, 0x53, 0x73, 0xbd, 0x0c, 0x80, 0xed, 0x1c, 0xb8, 0x9d, 0x03, 0xb8, 0x5b, 0x20,
		0x2f, 0xa7, 0xc8, 0x40, 0xcd, 0x75, 0xad, 0x5d, 0x4b, 0xd6, 0xc1, 0x0a, 0x38, 0x05, 0xd7, 0xce,
		0xc1, 0x1b, 0x27, 0xe1, 0x8d, 0xb3, 0xf0, 0xc3, 0x69, 0xe8, 0x3a, 0x0f, 0x65, 0x27, 0x32, 0x5d,
		0x62, 0xb2, 0x0e, 0xc8, 0x3a, 0x50, 0xfe, 0xe0, 0x64, 0x1d, 0x5c, 0x4f, 0x83, 0xac, 0x03, 0xd7,
		0x08, 0x38, 0x6f, 0x9a, 0x64, 0x1d, 0x2c, 0x98, 0x26, 0x59, 0x07, 0xae, 0x63, 0x02, 0x77, 0xa3,
		0x92, 0xad, 0xbf, 0xbc, 0xd9, 0x52, 0x73, 0x1d, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0, 0x61,
		0xd0, 0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0, 0x61, 0xd0,
		0x30, 0xe8, 0xfb, 0x98, 0x2d, 0x35, 0xd7, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19, 0xfe,
		0x0c, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19, 0xfe, 0x0c,
		0x7f, 0xbe, 0x0f, 0x7f, 0xa6, 0xe6, 0x3a, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1,
		0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1,
		0xd0, 0xf7, 0x31, 0x5b, 0x6a, 0xae, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc, 0x19,
		0xde, 0x0c, 0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc, 0xb9, 0x70,
		0xbc, 0x99, 0x9a, 0xeb, 0x36, 0x14, 0x01, 0x4f, 0x8b, 0x5b, 0xc7, 0x59, 0x8f, 0x9a, 0xeb, 0xde,
		0x98, 0x29, 0x35, 0xd7, 0xaf, 0xcd, 0xb2, 0x60, 0x35, 0xd7, 0x8f, 0xb2, 0x1e, 0x35, 0xd7, 0x17,
		0x57, 0xb8, 0x97, 0x25, 0x8a, 0x45, 0xd7, 0x87, 0xa3, 0x51, 0x75, 0xfd, 0x41, 0x03, 0x51, 0x75,
		0xdd, 0xae, 0x79, 0x50, 0x75, 0x9d, 0xaa, 0xeb, 0x3f, 0x5b, 0x32, 0xaa, 0xae, 0x17, 0x0e, 0x90,
		0x17, 0x81, 0x99, 0xaa, 0xeb, 0x65, 0x00, 0x6c, 0xe7, 0xc0, 0xed, 0x1c, 0xc0, 0xdd, 0x02, 0x79,
		0x39, 0x65, 0x06, 0xaa, 0xae, 0x6b, 0xed, 0x5a, 0xf2, 0x0e, 0x56, 0xc0, 0x29, 0xb8, 0x76, 0x0e,
		0xde, 0x38, 0x09, 0x6f, 0x9c, 0x85, 0x1f, 0x4e, 0x43, 0xd7, 0x79, 0x28, 0x3b, 0x91, 0xe9, 0x12,
		0x93, 0x77, 0x40, 0xde, 0x81, 0xf2, 0x07, 0x27, 0xef, 0xe0, 0x7a, 0x1a, 0xe4, 0x1d, 0xb8, 0x46,
		0xc0, 0x79, 0xd3, 0x24, 0xef, 0x60, 0xc1, 0x34, 0xc9, 0x3b, 0x70, 0x1d, 0x13, 0xb8, 0x1b, 0x95,
		0x7c, 0xfd, 0xe5, 0xcd, 0x96, 0xaa, 0xeb, 0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83,
		0x86, 0x41, 0xc3, 0xa0, 0x61, 0xd0, 0x30, 0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86,
		0x41, 0xdf, 0xc7, 0x6c, 0xa9, 0xba, 0x0e, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67,
		0xf8, 0x33, 0xfc, 0x19, 0xfe, 0x0c, 0x7f, 0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8,
		0xf3, 0x7d, 0xf8, 0x33, 0x55, 0xd7, 0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d,
		0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87,
		0xbe, 0x8f, 0xd9, 0x52, 0x75, 0x1d, 0xde, 0x0c, 0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0,
		0x66, 0x78, 0x33, 0xbc, 0x19, 0xde, 0x0c, 0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0x85, 0xe3,
		0xcd, 0x54, 0x5d, 0xb7, 0xa1, 0x08, 0x78, 0x5a, 0xde, 0xba, 0x97, 0x25, 0x94, 0x5d, 0xf7, 0xc7,
		0x4e, 0x29, 0xbb, 0x3e, 0x63, 0x97, 0x05, 0xab, 0xbb, 0x7e, 0x3c, 0x98, 0x32, 0x85, 0xd7, 0x17,
		0x96, 0xb8, 0x9f, 0xfc, 0x99, 0x74, 0xff, 0x9b, 0xe8, 0xd5, 0x5e, 0x9f, 0x0c, 0x48, 0xf9, 0xf5,
		0x07, 0x0d, 0x44, 0xf9, 0x75, 0xbb, 0xe6, 0x41, 0xf9, 0x75, 0xca, 0xaf, 0xff, 0x6c, 0xc9, 0x28,
		0xbf, 0x5e, 0x38, 0x40, 0x5e, 0x04, 0x66, 0xca, 0xaf, 0x97, 0x01, 0xb0, 0x9d, 0x03, 0xb7, 0x73,
		0x00, 0x77, 0x0b, 0xe4, 0xe5, 0xd4, 0x1b, 0x28, 0xbf, 0xae, 0xb5, 0x6b, 0x49, 0x40, 0x58, 0x01,
		0xa7, 0xe0, 0xda, 0x39, 0x78, 0xe3, 0x24, 0xbc, 0x71, 0x16, 0x7e, 0x38, 0x0d, 0x5d, 0xe7, 0xa1,
		0xec, 0x44, 0xa6, 0x4b, 0x4c, 0x02, 0x02, 0x09, 0x08, 0xca, 0x1f, 0x9c, 0x04, 0x84, 0xeb, 0x69,
		0x90, 0x80, 0xe0, 0x1a, 0x01, 0xe7, 0x4d, 0x93, 0x04, 0x84, 0x05, 0xd3, 0x24, 0x01, 0xc1, 0x75,
		0x4c, 0xe0, 0x6e, 0x54, 0x12, 0xf7, 0x97, 0x37, 0x5b, 0xca, 0xaf, 0xc3, 0xa0, 0x61, 0xd0, 0x30,
		0x68, 0x18, 0x34, 0x0c, 0x1a, 0x06, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xa0, 0x61, 0xd0, 0x30, 0x68,
		0x18, 0x34, 0x0c, 0x1a, 0x06, 0x7d, 0x1f, 0xb3, 0xa5, 0xfc, 0x3a, 0xfc, 0x19, 0xfe, 0x0c, 0x7f,
		0x86, 0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf0, 0x67, 0xf8, 0x33, 0xfc, 0x19, 0xfe, 0x0c, 0x7f, 0x86,
		0x3f, 0xc3, 0x9f, 0xe1, 0xcf, 0xf7, 0xe1, 0xcf, 0x94, 0x5f, 0x87, 0x43, 0xc3, 0xa1, 0xe1, 0xd0,
		0x70, 0x68, 0x38, 0x34, 0x1c, 0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0, 0x70,
		0x68, 0x38, 0x34, 0x1c, 0xfa, 0x3e, 0x66, 0x4b, 0xf9, 0x75, 0x78, 0x33, 0xbc, 0x19, 0xde, 0x0c,
		0x6f, 0x86, 0x37, 0xc3, 0x9b, 0xe1, 0xcd, 0xf0, 0x66, 0x78, 0x33, 0xbc, 0x19, 0xde, 0x0c, 0x6f,
		0x86, 0x37, 0x17, 0x8e, 0x37, 0x53, 0x7e, 0xdd, 0x86, 0x22, 0xe0, 0x69, 0x99, 0xeb, 0x71, 0xa9,
		0x62, 0x2a, 0xb0, 0x7b, 0x63, 0xaa, 0x54, 0x60, 0x9f, 0x37, 0xcd, 0x82, 0x15, 0x61, 0xff, 0x7d,
		0x3c, 0xeb, 0xa2, 0xd6, 0x61, 0x7f, 0x52, 0xa0, 0x2d, 0xa3, 0xb5, 0x55, 0x7c, 0xdd, 0x22, 0x82,
		0x5b, 0xc3, 0xe2, 0x96, 0x90, 0xd9, 0x0a, 0xf6, 0x0d, 0x55, 0xc0, 0x48, 0x85, 0xab, 0x5e, 0xab,
		0x54, 0xb9, 0x16, 0xae, 0x6a, 0x2d, 0x5e, 0xc5, 0x5a, 0x43, 0xaa, 0x57, 0x94, 0xe4, 0xb5, 0xa4,
		0x77, 0x75, 0x89, 0x5d, 0x5d, 0x4a, 0xd7, 0x95, 0xcc, 0x8b, 0xe5, 0x58, 0xa5, 0xab, 0x46, 0x57,
		0x4c, 0x12, 0x9e, 0xc5, 0x0a, 0x97, 0x74, 0xa7, 0x3b, 0x73, 0x32, 0xa0, 0x74, 0x3f, 0x05, 0xd3,
		0x09, 0xfb, 0xf1, 0xd0, 0xa4, 0x3a, 0x61, 0x9c, 0x19, 0xa5, 0x1e, 0x30, 0x55, 0x7a, 0xc0, 0xf8,
		0x0c, 0xda, 0xda, 0xe0, 0xed, 0x0c, 0xc4, 0x9d, 0x81, 0xb9, 0x1b, 0x50, 0x2f, 0x87, 0xe0, 0xa0,
		0x76, 0xae, 0x39, 0xdd, 0x71, 0x67, 0xdd, 0x6e, 0x6c, 0x42, 0x15, 0x6a, 0x3f, 0x89, 0x5e, 0x6b,
		0x34, 0x46, 0x5b, 0x58, 0x9b, 0x21, 0xa9, 0x0c, 0x92, 0xfe, 0xc5, 0x99, 0x49, 0xf5, 0x3c, 0xf1,
		0xdc, 0xa8, 0xb8, 0x47, 0xdc, 0x23, 0xee, 0x11, 0xf7, 0x88, 0x7b, 0x74, 0x83, 0x90, 0xb3, 0x28,
		0xa9, 0x70, 0x68, 0xad, 0x9c, 0xc9, 0xa3, 0x78, 0xc0, 0xe7, 0x22, 0x53, 0xc7, 0x55, 0xd6, 0xed,
		0x24, 0xdd, 0xa1, 0xa6, 0x3c, 0xae, 0xc3, 0xac, 0x06, 0xcd, 0xec, 0x71, 0x17, 0x99, 0x35, 0xae,
		0x4d, 0xa9, 0xbe, 0x42, 0xa6, 0x54, 0x92, 0x53, 0xf6, 0x13, 0x18, 0xd5, 0x82, 0x59, 0xf5, 0xc2,
		0x2c, 0x8b, 0xbe, 0x18, 0x3d, 0x32, 0x35, 0x19, 0x10, 0x59, 0x13, 0xde, 0x06, 0x6f, 0x83, 0xb7,
		0xc1, 0xdb, 0x1c, 0xf2, 0x36, 0x64, 0x4d, 0x3f, 0x9c, 0x70, 0x1a, 0x75, 0xd3, 0x28, 0xbf, 0x54,
		0xf4, 0xc2, 0x93, 0x11, 0x71, 0x8b, 0xb8, 0x45, 0xdc, 0x22, 0x6e, 0x11, 0xb7, 0x38, 0xb3, 0xe3,
		0xfa, 0x51, 0x92, 0x3f, 0x43, 0xc7, 0x5c, 0xe2, 0x0b, 0x1d, 0x53, 0x54, 0x7c, 0xaa, 0xa2, 0x63,
		0x8a, 0x98, 0xd2, 0x0a, 0xea, 0x98, 0xb5, 0xfa, 0x2e, 0x4a, 0x66, 0xd1, 0x46, 0x39, 0xe1, 0xb2,
		0x86, 0x3c, 0x44, 0xac, 0xdc, 0x65, 0x0d, 0xc1, 0x2b, 0x75, 0xc5, 0xb8, 0xfc, 0x90, 0x47, 0x17,
		0x26, 0xcd, 0xe4, 0x6f, 0x3f, 0x8c, 0xc7, 0x29, 0xf8, 0xf5, 0x87, 0x2a, 0xd7, 0x1f, 0x3c, 0xe2,
		0xd4, 0x5c, 0x7f, 0x58, 0x65, 0x57, 0x25, 0x7e, 0xfd, 0xa1, 0x35, 0xd9, 0xf5, 0x4a, 0x02, 0xe5,
		0x78, 0x3c, 0x1d, 0x79, 0xb2, 0x86, 0x3c, 0xe9, 0x33, 0x84, 0x6a, 0x43, 0xa9, 0x33, 0x48, 0x75,
		0x06, 0xad, 0x6e, 0x20, 0x56, 0x87, 0x2f, 0x49, 0xcb, 0x93, 0xd2, 0xd0, 0x3b, 0x1d, 0xe8, 0xb3,
		0x89, 0xe3, 0x6e, 0x30, 0x8c, 0xdd, 0xbf, 0x84, 0xb1, 0xde, 0x2e, 0x98, 0x6c, 0xf4, 0x1b, 0xe3,
		0x2b, 0x59, 0xa4, 0xae, 0x3c, 0xa2, 0x5e, 0x9f, 0xd3, 0x45, 0x5d, 0x4e, 0x87, 0xf5, 0x38, 0x5d,
		0xd5, 0xe1, 0x74, 0x5e, 0x7f, 0xd3, 0x79, 0xdd, 0x4d, 0xb7, 0xf5, 0x36, 0xcb, 0x55, 0x93, 0x49,
		0xbd, 0xae, 0xe6, 0xdc, 0xc9, 0x94, 0x6a, 0x31, 0x4d, 0x07, 0x45, 0x34, 0x1d, 0x15, 0xcf, 0x74,
		0x50, 0x25, 0xd5, 0x65, 0xb1, 0x4c, 0xc7, 0x95, 0x08, 0x5d, 0x17, 0xc7, 0xf4, 0xa1, 0xe0, 0xa0,
		0x83, 0x62, 0x98, 0x4e, 0x8b, 0x60, 0xfa, 0x62, 0x72, 0xae, 0x8b, 0x5e, 0x7a, 0x61, 0x7b, 0x25,
		0x2d, 0xfe, 0x78, 0x52, 0x96, 0x8a, 0x80, 0x4f, 0xb5, 0x08, 0xe5, 0x45, 0x3f, 0xce, 0xa3, 0x5e,
		0x1c, 0x99, 0xd4, 0x15, 0xa5, 0x9c, 0x99, 0x01, 0xa4, 0x12, 0x52, 0x09, 0xa9, 0x84, 0x54, 0x42,
		0x2a, 0x95, 0x49, 0xe5, 0x33, 0x07, 0x9c, 0xb2, 0x09, 0xa7, 0x84, 0x53, 0xc2, 0x29, 0xe1, 0x94,
		0x25, 0x30, 0xb9, 0x7a, 0x13, 0x32, 0x09, 0x99, 0xf4, 0x95, 0x4c, 0x52, 0x5e, 0xfe, 0x01, 0xe3,
		0xf9, 0x92, 0x8e, 0x39, 0xca, 0x12, 0xdc, 0x1a, 0x67, 0xc2, 0x70, 0x6d, 0x72, 0xf1, 0x45, 0x89,
		0xd6, 0xaa, 0x5e, 0x08, 0x93, 0x25, 0x6b, 0x56, 0xdf, 0x74, 0x67, 0x6a, 0x19, 0x49, 0x75, 0x32,
		0x92, 0x0a, 0xa4, 0x3c, 0x90, 0x91, 0x44, 0x46, 0xd2, 0xcf, 0x97, 0x8c, 0x8c, 0xa4, 0x12, 0x31,
		0x0e, 0xc4, 0xe3, 0x72, 0x41, 0xb8, 0x73, 0x28, 0x77, 0x0e, 0xe9, 0x6e, 0xa1, 0x5d, 0x97, 0x45,
		0x92, 0x91, 0x24, 0x86, 0xbf, 0x64, 0x24, 0x09, 0x7c, 0x50, 0xd4, 0x63, 0xd4, 0x63, 0x6d, 0x93,
		0x43, 0x3d, 0x26, 0x23, 0x09, 0x11, 0xd9, 0xfb, 0xcf, 0x43, 0x46, 0x12, 0xa4, 0x12, 0x52, 0x09,
		0xa9, 0x84, 0x54, 0x42, 0x2a, 0x35, 0x48, 0x25, 0x19, 0x49, 0x70, 0x4a, 0x38, 0x25, 0x9c, 0x12,
		0x4e, 0xf9, 0x38, 0x93, 0x23, 0x23, 0x09, 0x32, 0xe9, 0x2f, 0x99, 0x24, 0x23, 0xe9, 0x01, 0xe3,
		0x79, 0x96, 0x91, 0x24, 0x58, 0x27, 0x4e, 0xde, 0x3e, 0x28, 0x41, 0xe8, 0xbf, 0x85, 0x55, 0x44,
		0x93, 0xc6, 0xd2, 0x7e, 0x2b, 0x4f, 0xc6, 0x44, 0xe3, 0xcd, 0x68, 0xea, 0x87, 0xe3, 0x99, 0x9f,
		0x1e, 0x8f, 0xe7, 0x7b, 0x7a, 0x98, 0x45, 0xd9, 0xe9, 0xe1, 0x64, 0x92, 0xa7, 0x47, 0x83, 0xd9,
		0x9d, 0x7e, 0x18, 0xcd, 0xae, 0x28, 0x15, 0x12, 0x9f, 0x78, 0x6c, 0xe1, 0x95, 0x7f, 0x98, 0x4b,
		0xe1, 0xce, 0x81, 0x95, 0xa3, 0x28, 0xcb, 0xf7, 0xf3, 0x5c, 0x46, 0x45, 0x1c, 0xd0, 0x9a, 0x83,
		0xd8, 0x5c, 0x98, 0x64, 0x14, 0xe2, 0x08, 0x94, 0xa3, 0x7c, 0x1d, 0x7e, 0x9d, 0x19, 0xa1, 0xf6,
		0xac, 0xd1, 0xd8, 0xd9, 0x6d, 0x34, 0xaa, 0xbb, 0xdb, 0xbb, 0xd5, 0xbd, 0x66, 0xb3, 0xb6, 0x53,
		0x13, 0x08, 0xf0, 0x2a, 0x6f, 0xd3, 0xb6, 0x49, 0x4d, 0xfb, 0xc5, 0xe0, 0xed, 0x24, 0xfd, 0x38,
		0xf6, 0xda, 0x88, 0x84, 0xe1, 0xd1, 0x17, 0x58, 0x14, 0xc0, 0xc3, 0x65, 0x70, 0xd0, 0x2e, 0x00,
		0xda, 0x83, 0x29, 0x3b, 0x4f, 0xb2, 0x64, 0xa3, 0x52, 0xb6, 0xe9, 0xde, 0x26, 0xed, 0xbc, 0xfe,
		0xe5, 0x5f, 0x96, 0x85, 0x17, 0x55, 0xb9, 0xe8, 0xc5, 0xf6, 0xea, 0xfd, 0x4e, 0xe5, 0xcb, 0xe1,
		0x53, 0x2d, 0x99, 0x91, 0xdd, 0x84, 0x70, 0xeb, 0x07, 0x3f, 0x12, 0x07, 0x3b, 0x82, 0x07, 0x37,
		0x52, 0x07, 0x33, 0xe2, 0x07, 0x2f, 0xe2, 0x07, 0x2b, 0xb2, 0x07, 0x27, 0x7e, 0x41, 0xb3, 0xed,
		0x04, 0xe9, 0x4a, 0x74, 0xde, 0x0b, 0xe2, 0x76, 0x2f, 0xc8, 0x2e, 0x93, 0x96, 0x7d, 0xdb, 0x9a,
		0x6c, 0x87, 0xb9, 0x51, 0x6c, 0x87, 0xe3, 0x22, 0xf7, 0x4e, 0xc4, 0xce, 0x99, 0x25, 0xcf, 0x93,
		0x15, 0xce, 0x8d, 0xa5, 0xcf, 0x87, 0xd5, 0xce, 0x81, 0xd5, 0xce, 0x7b, 0x75, 0xce, 0x75, 0xfd,
		0xa6, 0xcc, 0x52, 0xf7, 0x3a, 0xa4, 0x8b, 0x7b, 0xeb, 0x14, 0xf5, 0xa6, 0xef, 0x81, 0x17, 0xd0,
		0xa6, 0x05, 0x71, 0xea, 0x50, 0xa7, 0x0e, 0x79, 0xba, 0xd0, 0x27, 0xa7, 0x43, 0xae, 0x15, 0xb9,
		0xef, 0x81, 0x49, 0xc2, 0xb3, 0xd8, 0xb4, 0xf5, 0x6e, 0x19, 0x4f, 0x06, 0xd4, 0xeb, 0x8f, 0x3e,
		0xb0, 0x60, 0xfa, 0xc0, 0x7a, 0x87, 0xd5, 0x0e, 0x30, 0x5b, 0x1b, 0xbb, 0x9d, 0x61, 0xb8, 0x33,
		0x2c, 0x77, 0x83, 0xe9, 0xb2, 0xd8, 0x2e, 0x8c, 0xf1, 0xd3, 0x25, 0xa3, 0x3d, 0xba, 0xc7, 0x06,
		0x20, 0xda, 0x1e, 0xbd, 0x9b, 0xe5, 0x41, 0x66, 0xb2, 0x2c, 0xea, 0x26, 0x41, 0xbf, 0x17, 0xb4,
		0x4d, 0x1c, 0x6a, 0xf6, 0x4a, 0xbf, 0x75, 0x78, 0x1c, 0x26, 0x0e, 0x13, 0x87, 0x89, 0xc3, 0xc4,
		0x61, 0xde, 0xc8, 0xdb, 0xaf, 0xed, 0x28, 0xfa, 0xcb, 0x1d, 0x3a, 0xa7, 0x3f, 0xfe, 0x83, 0xd1,
		0x39, 0x5d, 0x7e, 0x5c, 0x3a, 0xa7, 0x97, 0xd6, 0x94, 0x76, 0x9a, 0xcd, 0xed, 0x26, 0xbd, 0xd3,
		0x8b, 0x36, 0x0a, 0xbd, 0xd3, 0x15, 0x40, 0x62, 0x15, 0x12, 0x97, 0x2f, 0x7a, 0x71, 0xb6, 0x35,
		0x7b, 0x26, 0x2f, 0x5a, 0xaa, 0xb3, 0x18, 0x1d, 0xd4, 0x65, 0x4b, 0x72, 0xaa, 0x94, 0xe2, 0x54,
		0x3b, 0x47, 0xac, 0x73, 0x8e, 0xe8, 0x11, 0xb5, 0xe6, 0x1c, 0x71, 0x95, 0xdd, 0x15, 0xe7, 0x88,
		0x8f, 0x5d, 0x38, 0xce, 0x11, 0x3d, 0xc7, 0x6a, 0x07, 0x98, 0xad, 0x8d, 0xdd, 0xce, 0x30, 0xdc,
		0x19, 0x96, 0xbb, 0xc1, 0x74, 0x1d, 0x92, 0xc6, 0x39, 0xa2, 0x85, 0xe0, 0x95, 0x73, 0xc4, 0xc5,
		0xb5, 0xe1, 0x1c, 0x11, 0x87, 0x89, 0xc3, 0xc4, 0x61, 0xe2, 0x30, 0x7d, 0x77, 0x98, 0x9c, 0x23,
		0x2e, 0xfd, 0xc5, 0x39, 0xa2, 0xc8, 0xb0, 0x9c, 0x23, 0xca, 0x9a, 0x12, 0xe7, 0x88, 0xa5, 0x37,
		0x27, 0xce, 0x11, 0xdd, 0x32, 0x2c, 0xce, 0x11, 0x6f, 0x19, 0xc7, 0xab, 0x73, 0x44, 0xc1, 0x02,
		0x5b, 0xab, 0x56, 0x66, 0xa8, 0xc4, 0x15, 0x62, 0x16, 0xec, 0xc6, 0x9f, 0x32, 0x31, 0xaf, 0x7b,
		0x71, 0x76, 0x7a, 0x78, 0xde, 0x3b, 0x6a, 0xf7, 0xde, 0x0f, 0x26, 0x46, 0xc1, 0x18, 0x77, 0xa6,
		0xea, 0xda, 0x44, 0x6d, 0x56, 0xef, 0x78, 0xbc, 0x35, 0x96, 0xa9, 0x68, 0x8d, 0xdd, 0x24, 0x0b,
		0x91, 0xa4, 0x0a, 0xb1, 0xb2, 0x35, 0x75, 0xca, 0xd6, 0x14, 0x49, 0xff, 0xa3, 0x6c, 0x8d, 0xcf,
		0x65, 0x6b, 0x5a, 0x51, 0xda, 0xea, 0x47, 0x79, 0x90, 0x4b, 0x08, 0x7c, 0xd7, 0x55, 0x1f, 0x66,
		0x47, 0x91, 0x29, 0x5b, 0x53, 0xa5, 0x6c, 0x0d, 0x65, 0x6b, 0x7c, 0x82, 0x25, 0x1d, 0x78, 0x2a,
		0x06, 0x05, 0x13, 0x3b, 0x3e, 0xd0, 0x40, 0x98, 0xb9, 0x60, 0xa6, 0x21, 0xf0, 0xec, 0x83, 0xa4,
		0x7f, 0x31, 0x58, 0x9d, 0x2b, 0x5f, 0x39, 0x92, 0xc5, 0x28, 0x46, 0x2a, 0x09, 0x4e, 0x38, 0xe9,
		0x6d, 0x36, 0xc9, 0xad, 0x13, 0xc6, 0x19, 0x5e, 0x0c, 0x2f, 0x86, 0x17, 0xc3, 0x8b, 0x59, 0xb6,
		0x78, 0xb9, 0x2c, 0x31, 0xa1, 0xac, 0x30, 0x3f, 0x9d, 0xcc, 0xa8, 0x83, 0x63, 0x2f, 0x6c, 0xb7,
		0xa3, 0xe4, 0x5c, 0xce, 0xd5, 0xcc, 0x0f, 0x83, 0x43, 0xc0, 0x21, 0xe0, 0x10, 0x70, 0x08, 0x72,
		0x10, 0x03, 0xb9, 0xf1, 0xdc, 0xef, 0x4c, 0x4f, 0x3d, 0x82, 0x48, 0x90, 0xe1, 0xcc, 0x8d, 0x82,
		0xd7, 0xc1, 0xeb, 0xe0, 0x75, 0xf0, 0x3a, 0x45, 0x41, 0x98, 0x39, 0x7f, 0xf3, 0x6c, 0x05, 0x7c,
		0x42, 0x2f, 0xcc, 0xb2, 0xe8, 0x8b, 0xe0, 0xd9, 0xca, 0x64, 0x00, 0x04, 0x2f, 0x3c, 0x0d, 0x9e,
		0x06, 0x4f, 0x83, 0xe0, 0x55, 0x10, 0xc1, 0x8b, 0xcc, 0x33, 0xd9, 0xcc, 0x33, 0x8b, 0x29, 0xb4,
		0x7e, 0x24, 0x7d, 0x8d, 0x3b, 0xa3, 0x5a, 0xcf, 0xfa, 0xb2, 0xda, 0x71, 0x95, 0x6e, 0x65, 0xa4,
		0x7d, 0xad, 0x91, 0xf6, 0x65, 0x17, 0x9d, 0xed, 0xa7, 0x7d, 0xc9, 0xb4, 0xfb, 0x91, 0x6d, 0xf3,
		0x43, 0x87, 0x32, 0x38, 0x03, 0x9c, 0x61, 0x65, 0x3b, 0x94, 0x65, 0x49, 0x2f, 0x18, 0x46, 0x77,
		0x5f, 0xc2, 0x58, 0xa1, 0x51, 0xd9, 0xdc, 0x70, 0xb2, 0x75, 0x06, 0xab, 0xf4, 0x2b, 0x73, 0x09,
		0x74, 0x5a, 0x80, 0xa7, 0x0e, 0x7c, 0xea, 0x00, 0xa8, 0x0b, 0x84, 0x32, 0x80, 0x28, 0x04, 0x8c,
		0xf2, 0xa2, 0xca, 0xc2, 0x8e, 0x11, 0x2f, 0xa1, 0xa1, 0x50, 0x3a, 0x43, 0xa9, 0x64, 0x86, 0x42,
		0x61, 0x13, 0xcd, 0x12, 0x19, 0xca, 0xf5, 0x0c, 0xb4, 0x4b, 0x62, 0xb8, 0xa8, 0x5d, 0xa0, 0x50,
		0x02, 0x43, 0xb5, 0xf4, 0x85, 0x2b, 0x13, 0x51, 0x2c, 0x75, 0xe1, 0xc4, 0x4c, 0x0a, 0x5a, 0x12,
		0xe2, 0x64, 0x85, 0x2b, 0x96, 0xc7, 0x59, 0x2f, 0xe8, 0x85, 0xad, 0x28, 0x39, 0x57, 0xe4, 0x17,
		0xb7, 0x0d, 0x0a, 0xcb, 0x80, 0x65, 0xc0, 0x32, 0x60, 0x19, 0x85, 0x63, 0x19, 0x3b, 0x0d, 0x05,
		0x96, 0xf1, 0x0c, 0x96, 0x01, 0xcb, 0x80, 0x65, 0xc0, 0x32, 0xee, 0x61, 0x22, 0xb5, 0x67, 0x8d,
		0xc6, 0xce, 0x6e, 0xa3, 0x51, 0xdd, 0xdd, 0xde, 0xad, 0xee, 0x35, 0x9b, 0xb5, 0x9d, 0x1a, 0xa4,
		0x03, 0xd2, 0xe1, 0xc5, 0x13, 0xa9, 0x6f, 0x76, 0xef, 0x14, 0x9e, 0x51, 0x66, 0x8a, 0x48, 0x53,
		0x2d, 0x3f, 0xb3, 0x85, 0x65, 0x9a, 0x67, 0x89, 0x36, 0xcd, 0x12, 0x3f, 0x95, 0xaf, 0x73, 0x2a,
		0xaf, 0x48, 0x1f, 0x39, 0x95, 0x2f, 0xa3, 0x8f, 0xe0, 0x54, 0x1e, 0xbd, 0x0c, 0xbd, 0x0c, 0xbd,
		0x0c, 0xbd, 0xcc, 0x0b, 0xbd, 0x8c, 0x53, 0x79, 0xf4, 0x32, 0xf4, 0x32, 0xf4, 0x32, 0x6f, 0x4c,
		0x84, 0x53, 0x79, 0x04, 0x32, 0xbf, 0xb6, 0x21, 0xa7, 0xf2, 0xb0, 0x0c, 0x58, 0x06, 0x2c, 0x03,
		0x96, 0xf1, 0x68, 0x96, 0xc1, 0xa9, 0x3c, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0xf0, 0xc6, 0x44, 0x38,
		0x95, 0x87, 0x74, 0xf8, 0xfa, 0x44, 0x4e, 0xe5, 0x1f, 0x7a, 0x2a, 0x2f, 0xd0, 0xa2, 0x8e, 0xea,
		0x2a, 0x05, 0x33, 0x02, 0xf7, 0x9d, 0xbd, 0x3e, 0x8c, 0xe6, 0xe1, 0x4b, 0x99, 0x97, 0x27, 0x0e,
		0xcd, 0x6d, 0xc0, 0x2d, 0x2d, 0x97, 0xef, 0xab, 0x1c, 0x45, 0x59, 0xbe, 0x9f, 0xe7, 0x76, 0x4e,
		0x8f, 0x07, 0x71, 0xf0, 0x41, 0x6c, 0x06, 0xe4, 0x30, 0xb3, 0x13, 0x7e, 0x0c, 0xc2, 0xa6, 0x99,
		0x27, 0xca, 0x04, 0x18, 0x95, 0xb7, 0x69, 0xdb, 0xa4, 0xa6, 0xfd, 0x62, 0xb0, 0xba, 0x49, 0x3f,
		0x8e, 0x9d, 0xbe, 0x64, 0xcb, 0x58, 0xe2, 0x10, 0x43, 0x2a, 0x56, 0x1a, 0xe1, 0x3d, 0x02, 0x34,
		0x96, 0x43, 0x8b, 0xc7, 0xef, 0xf1, 0xc7, 0xfd, 0xe6, 0x23, 0x0d, 0xc6, 0x96, 0xa1, 0xa8, 0x1b,
		0xc8, 0xe3, 0xde, 0xce, 0xc3, 0xd7, 0xf6, 0x11, 0xeb, 0x5a, 0x89, 0xcd, 0x17, 0x13, 0x3f, 0xbe,
		0x04, 0xd7, 0xb5, 0xce, 0x3c, 0x7a, 0xce, 0x23, 0xdf, 0xec, 0x72, 0x19, 0x77, 0x4b, 0x4b, 0xc3,
		0x36, 0xa4, 0x5f, 0x8b, 0xd2, 0xae, 0x2d, 0xe9, 0xd6, 0xba, 0x34, 0x6b, 0x5d, 0x7a, 0xb5, 0x2b,
		0xad, 0xea, 0xa2, 0xd1, 0xb2, 0x19, 0x68, 0xa3, 0x2d, 0xb3, 0xfc, 0x4b, 0x9e, 0xdb, 0x81, 0xcb,
		0xbe, 0x60, 0x3b, 0xa9, 0xaf, 0xd6, 0xce, 0x6a, 0x6c, 0x9e, 0xc9, 0x08, 0x9c, 0xbd, 0xd8, 0x3e,
		0x63, 0x11, 0x3b, 0x4b, 0x11, 0x3b, 0x33, 0x91, 0x39, 0x1b, 0x71, 0x4b, 0x3a, 0x6c, 0xa5, 0x96,
		0x56, 0xc2, 0x7e, 0xfe, 0xd9, 0x24, 0x79, 0xd4, 0xb2, 0x4b, 0x94, 0xa7, 0x86, 0x7c, 0xe3, 0xf9,
		0x94, 0xbb, 0xf4, 0x08, 0x1a, 0xa4, 0x20, 0x42, 0x1c, 0x2a, 0xc4, 0x21, 0x43, 0x16, 0x3a, 0xfc,
		0x94, 0xcb, 0x28, 0x77, 0xb9, 0x46, 0xb9, 0x4b, 0x2d, 0xc8, 0x91, 0x86, 0x1e, 0x35, 0x08, 0x52,
		0x83, 0x22, 0x1d, 0x48, 0xb2, 0x0b, 0x4d, 0x96, 0x21, 0x4a, 0x0c, 0xaa, 0xae, 0x21, 0x2b, 0x4b,
		0x7a, 0x81, 0x50, 0x48, 0x74, 0x37, 0x8e, 0xdd, 0x32, 0xa8, 0x90, 0xed, 0x08, 0xf7, 0x17, 0xb9,
		0x09, 0xa2, 0xa4, 0xd9, 0x39, 0x05, 0x57, 0x2d, 0x90, 0x55, 0x07, 0x5b, 0x75, 0xd0, 0xd5, 0x05,
		0x5f, 0x19, 0x10, 0x16, 0x02, 0xe3, 0xe9, 0xd2, 0xe8, 0xa5, 0xd9, 0xc9, 0xf5, 0x2f, 0x59, 0x88,
		0x02, 0x6b, 0x2b, 0x9e, 0x0b, 0xae, 0xed, 0x0b, 0x6f, 0x19, 0x13, 0x57, 0x88, 0x2b, 0xc4, 0x15,
		0xe2, 0x0a, 0x71, 0x85, 0xb8, 0x42, 0x57, 0xae, 0xb0, 0xe7, 0x82, 0x17, 0xf6, 0xe0, 0x85, 0x38,
		0x43, 0x9c, 0x21, 0xce, 0x10, 0x67, 0x88, 0x33, 0xf4, 0xe2, 0x89, 0xa4, 0xeb, 0xdf, 0x96, 0x44,
		0x37, 0x4a, 0x2b, 0x1b, 0xfd, 0xdf, 0xd6, 0xbc, 0xbf, 0x5e, 0xa1, 0x22, 0x7a, 0x7f, 0x0e, 0xd3,
		0xa0, 0x85, 0x8e, 0xfa, 0x06, 0x0f, 0xe7, 0x9c, 0x8f, 0x73, 0x3e, 0xf7, 0x21, 0x06, 0xe7, 0x7c,
		0x8a, 0xfe, 0x41, 0xee, 0x9c, 0x4f, 0x26, 0x35, 0x61, 0x61, 0x43, 0x89, 0xa4, 0x28, 0x08, 0x43,
		0x18, 0x6c, 0x0a, 0x36, 0x05, 0x9b, 0xf2, 0x95, 0x4d, 0x49, 0x41, 0xe2, 0x74, 0x80, 0x41, 0x00,
		0x1b, 0xf4, 0xc2, 0x2c, 0x1b, 0xdb, 0x98, 0xb0, 0x31, 0xcf, 0xe6, 0x89, 0x5e, 0x0f, 0x2b, 0x6c,
		0x5f, 0x3a, 0x37, 0xf1, 0xc5, 0x01, 0x54, 0x13, 0x48, 0x1d, 0x00, 0xaa, 0x36, 0xb0, 0x3a, 0x03,
		0x58, 0x67, 0x40, 0xeb, 0x06, 0x70, 0x65, 0x81, 0x57, 0x18, 0x80, 0xf5, 0x64, 0xad, 0x85, 0x1d,
		0x97, 0x76, 0xfb, 0x79, 0x94, 0x9c, 0x6b, 0xa1, 0xe4, 0x5c, 0x88, 0xf9, 0xac, 0xa0, 0x65, 0x35,
		0x8a, 0xe5, 0xdc, 0x85, 0xf5, 0x30, 0x8f, 0x74, 0xb1, 0x3f, 0xcd, 0xa5, 0x88, 0x36, 0x26, 0xf7,
		0xde, 0x25, 0x8e, 0x15, 0x65, 0x1a, 0x4f, 0x2c, 0x00, 0x87, 0x44, 0x03, 0x0a, 0x75, 0x12, 0x5a,
		0x87, 0x84, 0x42, 0x42, 0x21, 0xa1, 0x90, 0x50, 0x48, 0x28, 0x24, 0x14, 0x12, 0x0a, 0x09, 0x85,
		0x84, 0x42, 0x42, 0x21, 0xa1, 0x90, 0xd0, 0xe5, 0x48, 0xa8, 0x40, 0x3d, 0x45, 0x41, 0x0e, 0x4a,
		0x36, 0x8f, 0x6b, 0x83, 0xa9, 0x88, 0xc8, 0x00, 0xf7, 0x2f, 0xa7, 0x76, 0x34, 0x98, 0xd7, 0xe9,
		0xfe, 0xdc, 0xbc, 0x4e, 0xff, 0x61, 0x2e, 0x57, 0x24, 0xc5, 0xa8, 0xf5, 0x39, 0x14, 0xa8, 0xea,
		0x3d, 0x9b, 0x67, 0x34, 0x1a, 0x81, 0x64, 0x23, 0x92, 0x8d, 0xdc, 0xc7, 0xe6, 0x24, 0x1b, 0xe1,
		0xbe, 0xec, 0xba, 0x2f, 0x09, 0x74, 0xb3, 0xe6, 0xc3, 0x46, 0x93, 0xa3, 0xe1, 0xf4, 0xb2, 0xc8,
		0x4a, 0xc3, 0x69, 0x5c, 0x18, 0x2e, 0x8c, 0x7c, 0x59, 0x7b, 0x0f, 0xa6, 0x2e, 0x8e, 0x55, 0x10,
		0xe5, 0xfe, 0xa3, 0x53, 0x70, 0xd5, 0x02, 0x59, 0x75, 0xb0, 0x55, 0x07, 0x5d, 0x5d, 0xf0, 0x95,
		0x13, 0xd6, 0xd6, 0xb8, 0xff, 0xf8, 0xb0, 0x28, 0x90, 0xba, 0x38, 0xd4, 0xc5, 0xc1, 0x15, 0xe2,
		0x0a, 0x71, 0x85, 0xb8, 0x42, 0x5c, 0xe1, 0xca, 0xba, 0x42, 0xea, 0xe2, 0xe0, 0x0c, 0x71, 0x86,
		0x38, 0x43, 0x9c, 0x21, 0xce, 0x90, 0xba, 0x38, 0xf6, 0x76, 0x4d, 0xe9, 0x8f, 0x22, 0x69, 0x63,
		0xeb, 0xda, 0x18, 0xdc, 0x1b, 0x81, 0xab, 0x36, 0xb6, 0xb7, 0x1d, 0x3f, 0x7b, 0xd3, 0xca, 0xd6,
		0x42, 0xc3, 0x2f, 0xcb, 0xc5, 0x4d, 0x64, 0x8a, 0x99, 0xd0, 0xc2, 0x89, 0x16, 0x4e, 0x6b, 0xb4,
		0x70, 0xb2, 0xeb, 0x2a, 0xac, 0xb7, 0x70, 0x9a, 0x07, 0xec, 0xa0, 0xf5, 0xd9, 0xb4, 0xfe, 0x94,
		0xcb, 0x5b, 0xb9, 0x75, 0x34, 0xdb, 0x47, 0xe4, 0xd7, 0x8c, 0x7e, 0x60, 0x6b, 0x42, 0x59, 0x32,
		0x55, 0x12, 0x3d, 0xc9, 0x92, 0xf1, 0x91, 0x98, 0x93, 0x25, 0x23, 0x48, 0xbc, 0x15, 0x08, 0xb7,
		0x10, 0xd1, 0xf6, 0x33, 0x4d, 0xd2, 0x24, 0xe1, 0x59, 0x6c, 0xda, 0x72, 0x0e, 0x67, 0x32, 0x80,
		0x9c, 0x8f, 0x91, 0x50, 0x8d, 0x71, 0x32, 0x38, 0x19, 0x9c, 0x0c, 0x4e, 0x06, 0x27, 0x63, 0xe3,
		0xb3, 0x0e, 0x95, 0xa9, 0x20, 0xe9, 0x5f, 0x9c, 0x99, 0x54, 0xce, 0xd3, 0xcc, 0x8d, 0x82, 0x3b,
		0xc0, 0x1d, 0xe0, 0x0e, 0x70, 0x07, 0x45, 0x41, 0x98, 0x59, 0x94, 0x69, 0x0a, 0x3c, 0xfa, 0x5d,
		0x98, 0x9c, 0x0f, 0x3e, 0xc3, 0x47, 0x11, 0xf3, 0x13, 0x3c, 0x60, 0x7d, 0x1d, 0x25, 0x0a, 0x49,
		0x02, 0x3a, 0x75, 0x82, 0xfe, 0x08, 0xe3, 0xbe, 0x91, 0x2b, 0xe4, 0x36, 0x1d, 0xe7, 0x55, 0x1a,
		0xb6, 0xf2, 0xa8, 0x9b, 0xbc, 0x8c, 0xce, 0xa3, 0x3c, 0x1b, 0x7c, 0x30, 0xb9, 0x7c, 0x00, 0xc1,
		0x03, 0xef, 0xd7, 0xe1, 0xd7, 0xd2, 0xbd, 0xfa, 0x7a, 0x89, 0x5e, 0x7d, 0x41, 0xf2, 0x10, 0x4e,
		0x56, 0x20, 0xc2, 0xbe, 0x30, 0x79, 0x1a, 0xb5, 0x82, 0x2c, 0xbf, 0x8c, 0x05, 0x2f, 0xbd, 0xce,
		0x8d, 0x42, 0x84, 0x4d, 0x84, 0x4d, 0x84, 0x4d, 0x84, 0x5d, 0x14, 0x84, 0x99, 0x53, 0x5d, 0x1a,
		0x02, 0xcf, 0x3e, 0x48, 0xfa, 0x17, 0x83, 0xd5, 0xb9, 0x22, 0xe5, 0xea, 0x3e, 0xdb, 0xa9, 0x3c,
		0x29, 0x57, 0x36, 0x8b, 0x6c, 0xfb, 0x91, 0xde, 0x24, 0x22, 0xd8, 0x49, 0xd2, 0x68, 0xcb, 0xe1,
		0x03, 0xa9, 0x4e, 0xa4, 0x3a, 0xb9, 0x08, 0x03, 0xfc, 0x82, 0x68, 0xeb, 0xee, 0x7e, 0x06, 0x01,
		0xc2, 0x4e, 0x6a, 0x3a, 0x36, 0x2d, 0x76, 0xe2, 0xd9, 0x77, 0x2d, 0x3e, 0xf3, 0x78, 0xec, 0x45,
		0x36, 0x37, 0x47, 0xc9, 0xd4, 0x5b, 0x73, 0xc8, 0x55, 0x26, 0xbc, 0x8f, 0x92, 0x3f, 0x83, 0xe1,
		0x47, 0x0c, 0xda, 0x61, 0x1e, 0x9e, 0x85, 0x99, 0x11, 0x80, 0xfd, 0x5b, 0x06, 0xf1, 0x3c, 0xd1,
		0xb5, 0x0e, 0xfa, 0x83, 0xfe, 0x2b, 0x8a, 0xfe, 0xd6, 0x13, 0x5d, 0xe3, 0xac, 0x27, 0x78, 0xf8,
		0x9b, 0xf5, 0x28, 0x28, 0x8a, 0x22, 0x85, 0x22, 0xb5, 0x5a, 0x8a, 0x94, 0x58, 0x35, 0xb6, 0x38,
		0xeb, 0x05, 0x51, 0x5b, 0xa7, 0xe8, 0x4c, 0xd4, 0xe6, 0xce, 0xbb, 0x3a, 0xa4, 0x29, 0x42, 0x9b,
		0x16, 0xc4, 0xa9, 0x43, 0x9d, 0x3a, 0xe4, 0xe9, 0x42, 0x9f, 0x0c, 0x04, 0x0a, 0x41, 0xa1, 0x1c,
		0x6b, 0x57, 0x64, 0xf1, 0x1a, 0xac, 0xfe, 0x1e, 0x2c, 0x7f, 0x84, 0xc9, 0x34, 0x4d, 0xa4, 0x69,
		0x22, 0xbe, 0x0f, 0xdf, 0x87, 0xef, 0x2b, 0x8c, 0xef, 0x13, 0x6f, 0x9a, 0x38, 0xbc, 0x2f, 0x9b,
		0x8d, 0xce, 0x79, 0x75, 0xfa, 0x25, 0x4e, 0x47, 0xa4, 0x55, 0xa2, 0x6f, 0xf0, 0xe9, 0x00, 0x46,
		0xb5, 0xe1, 0xd4, 0x19, 0xac, 0x3a, 0x83, 0x57, 0x37, 0x30, 0x2b, 0x0b, 0xb7, 0xc2, 0xb0, 0xab,
		0x47, 0x3d, 0x16, 0x76, 0x5c, 0x3f, 0x4a, 0xf2, 0xda, 0x8e, 0x62, 0x83, 0xc4, 0x1d, 0x85, 0xa1,
		0x64, 0x73, 0xf5, 0x6f, 0x7e, 0xe9, 0x00, 0xc8, 0x9a, 0x56, 0x2e, 0xbf, 0x23, 0xc7, 0xb6, 0x30,
		0xec, 0x24, 0xe1, 0x5b, 0x7b, 0x5c, 0xc5, 0x04, 0x70, 0x65, 0x78, 0x99, 0x37, 0xa5, 0xf0, 0xeb,
		0xca, 0x99, 0xd2, 0x4e, 0xb3, 0xb9, 0xdd, 0x5c, 0x21, 0x73, 0x7a, 0x52, 0x8e, 0x51, 0x4e, 0x8a,
		0xda, 0x52, 0x57, 0x50, 0x0d, 0xe8, 0xc4, 0xe1, 0x79, 0xa6, 0x47, 0xa2, 0x46, 0xc3, 0xc1, 0xa0,
		0x60, 0x50, 0x30, 0x28, 0x18, 0x14, 0x0c, 0x6a, 0xae, 0x3e, 0x4f, 0xff, 0xc2, 0xa4, 0x92, 0x15,
		0xde, 0x6f, 0x03, 0x49, 0x89, 0x0b, 0x18, 0x0b, 0x63, 0xc9, 0x5c, 0xc8, 0xd0, 0x36, 0x89, 0xa3,
		0x28, 0xcb, 0xf7, 0xf3, 0x3c, 0xd5, 0x31, 0x8b, 0xd7, 0x51, 0x72, 0x10, 0x9b, 0xc1, 0xae, 0xcd,
		0x74, 0x22, 0xdd, 0x41, 0x24, 0x3f, 0x33, 0x62, 0xed, 0x59, 0xa3, 0xb1, 0xb3, 0xdb, 0x68, 0x54,
		0x77, 0xb7, 0x77, 0xab, 0x7b, 0xcd, 0x66, 0x6d, 0xa7, 0xa6, 0x10, 0xf2, 0x56, 0xde, 0xa6, 0x6d,
		0x93, 0x9a, 0xf6, 0x8b, 0xcb, 0xca, 0xf3, 0xb5, 0xa4, 0x1f, 0xc7, 0x84, 0x6c, 0x0b, 0x4b, 0x14,
		0xb5, 0x83, 0xd8, 0x24, 0xe7, 0xc3, 0xb3, 0x52, 0xa5, 0xb0, 0xed, 0x7a, 0x48, 0x42, 0x37, 0x42,
		0x37, 0x42, 0x37, 0x42, 0x37, 0x42, 0xb7, 0x1b, 0xe2, 0xf7, 0x33, 0xc5, 0xa0, 0xad, 0x89, 0xf6,
		0xbd, 0x54, 0x60, 0x85, 0xf6, 0x2d, 0x3c, 0x2e, 0xda, 0x77, 0x69, 0x4d, 0xa9, 0xde, 0x44, 0xf9,
		0x2e, 0xdc, 0x28, 0x28, 0xdf, 0xb7, 0xd0, 0xa8, 0x2c, 0xc8, 0x35, 0x22, 0x85, 0x6b, 0x12, 0x35,
		0x1e, 0x10, 0x0a, 0x05, 0x85, 0x82, 0x42, 0x41, 0xa1, 0xa0, 0x50, 0x7a, 0x15, 0x3d, 0x61, 0x52,
		0x30, 0x29, 0x2b, 0xe1, 0x6f, 0x0d, 0x26, 0x05, 0x93, 0xb2, 0xc4, 0xa4, 0xe0, 0x51, 0xf0, 0xa8,
		0xe2, 0xf3, 0x28, 0xe1, 0x0b, 0xda, 0x8b, 0x91, 0x82, 0xe4, 0x45, 0x6d, 0x58, 0x14, 0x2c, 0x0a,
		0x16, 0x05, 0x8b, 0x2a, 0x2a, 0x8b, 0xd2, 0xc0, 0xc6, 0x59, 0x7c, 0xac, 0x3d, 0x53, 0x18, 0xeb,
		0x38, 0xcc, 0x73, 0x93, 0x26, 0x6a, 0x14, 0xaa, 0xf2, 0xef, 0x8f, 0xd5, 0x60, 0x6f, 0x3f, 0x78,
		0x15, 0x06, 0x9d, 0x93, 0x6f, 0x8d, 0xab, 0x4f, 0x9f, 0x36, 0xef, 0xf7, 0x83, 0x93, 0xe1, 0x7f,
		0x82, 0xeb, 0x6f, 0xff, 0x22, 0xbf, 0x45, 0x4e, 0x34, 0x5e, 0xc0, 0xdb, 0xf7, 0x87, 0xff, 0xe4,
		0x2d, 0x10, 0x18, 0x3e, 0xe8, 0xfd, 0x5d, 0x84, 0x5f, 0xa3, 0x8b, 0xfe, 0x45, 0x10, 0xa6, 0x26,
		0x0c, 0xc2, 0x76, 0x3b, 0x35, 0x59, 0x66, 0x14, 0x73, 0xcd, 0xef, 0x18, 0x9f, 0xc0, 0x91, 0xc0,
		0x91, 0xc0, 0x91, 0xc0, 0x91, 0xc0, 0x91, 0x0c, 0x26, 0x8b, 0x5f, 0xe8, 0xee, 0x22, 0xc3, 0x92,
		0xc1, 0x24, 0x6b, 0x4a, 0x64, 0x30, 0x95, 0xdc, 0x98, 0x50, 0xde, 0x4b, 0x4b, 0xb0, 0x7a, 0xed,
		0xbe, 0xfa, 0x4d, 0x90, 0x99, 0x31, 0x21, 0x52, 0x10, 0x29, 0x88, 0x14, 0x44, 0x0a, 0x22, 0x45,
		0x1d, 0x24, 0x98, 0x14, 0x4c, 0x0a, 0x26, 0x45, 0x1d, 0x24, 0xb8, 0x14, 0x5c, 0xaa, 0xb0, 0x5c,
		0x4a, 0xf7, 0x3a, 0xc8, 0x74, 0x44, 0x78, 0x14, 0x3c, 0x0a, 0x1e, 0x05, 0x8f, 0x82, 0x47, 0x51,
		0x0d, 0x69, 0xd5, 0xdd, 0x70, 0x6a, 0x2e, 0xc2, 0x28, 0x89, 0x92, 0xf3, 0x20, 0x8e, 0x3a, 0x26,
		0x8f, 0x2e, 0x14, 0x1d, 0xf2, 0x2d, 0x63, 0xe3, 0x9a, 0x71, 0xcd, 0xb8, 0x66, 0x5c, 0x33, 0xae,
		0x19, 0x89, 0xd3, 0xe6, 0x17, 0x12, 0xa7, 0xa8, 0x2e, 0x85, 0xc4, 0x29, 0x63, 0x4a, 0x48, 0x9c,
		0xa5, 0x37, 0x27, 0x24, 0xce, 0xd2, 0x72, 0xab, 0xcc, 0xfc, 0x6f, 0xdf, 0x24, 0x2d, 0x33, 0xa9,
		0xb2, 0xa0, 0x46, 0xac, 0x6e, 0x0e, 0x0c, 0xab, 0x82, 0x55, 0xc1, 0xaa, 0x60, 0x55, 0xb0, 0xaa,
		0x1b, 0xac, 0x6a, 0xbb, 0xae, 0xc8, 0xaa, 0x76, 0x61, 0x55, 0xb0, 0x2a, 0x58, 0x15, 0xac, 0xca,
		0x81, 0x29, 0x35, 0xea, 0x7b, 0x8d, 0xbd, 0x9d, 0xdd, 0xfa, 0x1e, 0xd4, 0x0a, 0x6a, 0x55, 0x02,
		0x6a, 0xf5, 0xc5, 0xa4, 0x59, 0xd4, 0x4d, 0xf4, 0x28, 0xd5, 0x64, 0x40, 0xe1, 0x30, 0xe8, 0xa5,
		0xe9, 0x84, 0xfd, 0x78, 0x18, 0x38, 0xd6, 0xa0, 0x6d, 0xd0, 0x36, 0x68, 0x1b, 0xb4, 0x0d, 0xda,
		0xc6, 0xc5, 0x69, 0x58, 0x1b, 0xac, 0x0d, 0xd6, 0xc6, 0xc5, 0x69, 0xe8, 0x1a, 0x74, 0xad, 0xb8,
		0x74, 0xad, 0xae, 0xce, 0xd7, 0xea, 0x10, 0x36, 0x08, 0x1b, 0x84, 0x0d, 0xc2, 0x06, 0x61, 0x83,
		0xb0, 0x41, 0xd8, 0x20, 0x6c, 0x10, 0x36, 0x08, 0x1b, 0x84, 0x0d, 0xc2, 0x56, 0x06, 0xc2, 0xf6,
		0xa4, 0x40, 0x10, 0x51, 0xd9, 0x4f, 0x92, 0x6e, 0x3e, 0xba, 0x5e, 0x28, 0x89, 0x0a, 0x95, 0xac,
		0xf5, 0xd9, 0x5c, 0x84, 0xbd, 0x70, 0x58, 0xa3, 0xab, 0xb2, 0xd5, 0xed, 0x99, 0xa4, 0x35, 0x24,
		0x34, 0x41, 0x62, 0xf2, 0xff, 0x76, 0xd3, 0x3f, 0x83, 0x28, 0xc9, 0xf2, 0x30, 0x69, 0x99, 0xad,
		0x9b, 0x3f, 0xc8, 0x16, 0x7e, 0xb2, 0xd5, 0x4b, 0xbb, 0x79, 0xb7, 0xd5, 0x8d, 0xb3, 0xe9, 0x77,
		0x5b, 0x83, 0x28, 0x73, 0x6b, 0xd8, 0x3d, 0x6b, 0xfc, 0x7f, 0x5b, 0x71, 0x94, 0xfc, 0x19, 0x64,
		0x79, 0x98, 0x9b, 0xa0, 0x1d, 0xe6, 0xe1, 0x59, 0x98, 0x99, 0xad, 0x38, 0xeb, 0x6d, 0x0d, 0x7f,
		0x24, 0x13, 0x90, 0xda, 0x7f, 0xf7, 0x02, 0xef, 0xbd, 0x92, 0xc7, 0x5f, 0xe4, 0xca, 0x4f, 0x4f,
		0x03, 0xcc, 0xe1, 0x28, 0x42, 0x56, 0x3b, 0xb9, 0xa6, 0x2a, 0xf4, 0x78, 0x69, 0xaa, 0xad, 0x41,
		0xb1, 0x15, 0xa9, 0xb5, 0x16, 0xa5, 0x56, 0xa7, 0xd2, 0xea, 0x14, 0x5a, 0x97, 0x3a, 0x17, 0xcb,
		0x53, 0xbd, 0x8c, 0x64, 0x53, 0xf5, 0x07, 0x80, 0xa5, 0x27, 0x84, 0x0e, 0x06, 0xd3, 0xd1, 0x25,
		0x6b, 0xe8, 0x92, 0x3e, 0x83, 0xa7, 0x36, 0x88, 0x3a, 0x03, 0x53, 0x67, 0xa0, 0xea, 0x06, 0x5c,
		0x75, 0x88, 0x92, 0xb4, 0x2e, 0x29, 0x0d, 0xba, 0xd3, 0x81, 0x66, 0x9b, 0x93, 0xe8, 0xed, 0x81,
		0xc9, 0x36, 0x9f, 0x1b, 0x5d, 0xc9, 0x1a, 0x75, 0xe0, 0x59, 0x1d, 0xa6, 0x5d, 0xc0, 0xb5, 0x43,
		0xd8, 0x76, 0x05, 0xdf, 0xce, 0x61, 0xdc, 0x39, 0x9c, 0xbb, 0x85, 0x75, 0x3d, 0x1d, 0x6c, 0x4d,
		0x4f, 0x20, 0x56, 0x83, 0xfb, 0x6b, 0x59, 0x68, 0xa8, 0xc5, 0xa8, 0x6f, 0x9a, 0xe9, 0x8d, 0xdc,
		0xe1, 0xf0, 0x4f, 0x9d, 0x88, 0xe1, 0xda, 0x1d, 0xb4, 0xb5, 0x1d, 0x80, 0x4b, 0x47, 0xe0, 0x81,
		0x43, 0x70, 0xed, 0x18, 0xbc, 0x71, 0x10, 0xde, 0x38, 0x0a, 0x3f, 0x1c, 0x86, 0xae, 0xe3, 0x50,
		0x76, 0x20, 0xce, 0x1c, 0xc9, 0x35, 0x8f, 0x50, 0xa6, 0x10, 0x77, 0x53, 0x0a, 0x55, 0x36, 0x71,
		0x97, 0x93, 0xa9, 0x3a, 0x1a, 0xde, 0x95, 0xb3, 0xf1, 0xc1, 0xe9, 0x78, 0xe4, 0x7c, 0x7c, 0x71,
		0x42, 0xde, 0x39, 0x23, 0xef, 0x9c, 0x92, 0x5f, 0xce, 0xc9, 0x8d, 0x93, 0x72, 0xe4, 0xac, 0xa6,
		0x4b, 0xaf, 0x96, 0x84, 0xf7, 0x73, 0xe7, 0xa1, 0xaf, 0x47, 0xfd, 0x90, 0xaa, 0x3c, 0x73, 0x38,
		0x07, 0xed, 0x7e, 0xdb, 0x77, 0x4e, 0x64, 0xae, 0x0f, 0x77, 0xfd, 0xea, 0xd3, 0xa7, 0xcd, 0xf5,
		0x85, 0xbe, 0xdb, 0x1b, 0xdf, 0xaa, 0x4f, 0xb7, 0xaf, 0xfe, 0xe2, 0x6e, 0xc7, 0x9e, 0xb8, 0x7c,
		0x53, 0x2e, 0xda, 0xa3, 0x17, 0xfc, 0x75, 0xad, 0x14, 0xc0, 0x1e, 0x45, 0x59, 0xbe, 0x9f, 0xe7,
		0xa9, 0x5b, 0x90, 0x7d, 0x1d, 0x25, 0x07, 0xb1, 0x19, 0xf8, 0xd8, 0xcc, 0x5d, 0x80, 0xba, 0x36,
		0xce, 0xc5, 0x9c, 0x99, 0x49, 0xed, 0x59, 0xa3, 0xb1, 0xb3, 0xdb, 0x68, 0x54, 0x77, 0xb7, 0x77,
		0xab, 0x7b, 0xcd, 0x66, 0x6d, 0xa7, 0xd6, 0x74, 0x38, 0xb9, 0xb7, 0x69, 0xdb, 0xa4, 0xa6, 0xfd,
		0xe2, 0xb2, 0xf2, 0x7c, 0x2d, 0xe9, 0xc7, 0xf1, 0x93, 0xd5, 0x08, 0x40, 0xca, 0xcd, 0xcb, 0x95,
		0xd2, 0xfd, 0xee, 0x1c, 0xdf, 0xa3, 0x34, 0xc0, 0x3c, 0xfe, 0x92, 0x0d, 0xfe, 0xb3, 0x35, 0x1b,
		0x6c, 0x49, 0x26, 0x07, 0xba, 0xb7, 0xb8, 0x72, 0x1d, 0x56, 0x38, 0xb2, 0x65, 0xef, 0x6d, 0x58,
		0xf3, 0xd4, 0x33, 0xcb, 0xd3, 0x7e, 0x2b, 0x4f, 0xc6, 0xb4, 0xe5, 0xcd, 0xe8, 0xc3, 0x1d, 0x8e,
		0x3f, 0xdb, 0xe9, 0xf1, 0xf8, 0x13, 0x9d, 0x1e, 0x66, 0x51, 0x76, 0x7a, 0x34, 0xf8, 0x28, 0xa7,
		0x47, 0x59, 0xef, 0xf4, 0x43, 0xfc, 0xe5, 0x74, 0x3f, 0x35, 0xe1, 0xfe, 0x78, 0xc2, 0x25, 0xc9,
		0x58, 0x57, 0x30, 0xfc, 0x4a, 0xd8, 0xcf, 0x3f, 0x9b, 0x24, 0x8f, 0x5a, 0xba, 0x86, 0x7f, 0xcd,
		0x4c, 0xe7, 0xc7, 0x27, 0x57, 0xc2, 0x0e, 0x73, 0x22, 0x57, 0x42, 0xc5, 0x8c, 0xc8, 0x95, 0x20,
		0x57, 0xc2, 0xd6, 0x52, 0x92, 0x2b, 0x51, 0x3a, 0xe0, 0x77, 0xe6, 0x00, 0x5c, 0x3a, 0x02, 0x0f,
		0x1c, 0x82, 0x6b, 0xc7, 0xe0, 0x8d, 0x83, 0xf0, 0xc6, 0x51, 0xf8, 0xe1, 0x30, 0x56, 0x43, 0x93,
		0x71, 0x97, 0x2b, 0x31, 0x17, 0xcb, 0x07, 0x7f, 0x9a, 0x4b, 0x0f, 0xd2, 0x26, 0x16, 0xe7, 0x44,
		0x06, 0x85, 0x93, 0x09, 0x90, 0x41, 0xe1, 0x93, 0x6b, 0xf2, 0xce, 0x45, 0x79, 0xe7, 0xaa, 0xfc,
		0x72, 0x59, 0x6e, 0x5c, 0x97, 0x23, 0x17, 0x36, 0x5d, 0x7a, 0x7f, 0x32, 0x28, 0xb2, 0x3c, 0x8d,
		0x92, 0x73, 0x2f, 0x72, 0x27, 0x56, 0xe5, 0xe0, 0xcc, 0x01, 0x5f, 0x68, 0xa5, 0x97, 0xbd, 0xbc,
		0x1b, 0xe4, 0x2e, 0xcd, 0x6e, 0x6a, 0x72, 0xb3, 0x93, 0x21, 0x66, 0x21, 0x66, 0x21, 0x66, 0x21,
		0x66, 0x21, 0x66, 0x21, 0x66, 0xb9, 0x37, 0x62, 0x98, 0xa4, 0x7f, 0x61, 0x52, 0xcd, 0x83, 0xb5,
		0x1f, 0x06, 0x2e, 0x0d, 0x87, 0x73, 0x38, 0x48, 0xfa, 0x17, 0x83, 0x97, 0x72, 0x45, 0xd6, 0x51,
		0xf1, 0xb7, 0x1a, 0x59, 0x47, 0xb7, 0x65, 0x6c, 0xcc, 0x09, 0x5d, 0xe4, 0x1d, 0x15, 0xc6, 0xaa,
		0xc9, 0x3b, 0xba, 0xd3, 0x8a, 0x0b, 0x92, 0x79, 0x34, 0x3f, 0x67, 0x92, 0x8f, 0xee, 0xbd, 0xe6,
		0xe6, 0x6b, 0x6e, 0x92, 0xb6, 0x69, 0x07, 0x51, 0xef, 0x4b, 0x23, 0x48, 0x4d, 0xd8, 0xfa, 0x1c,
		0x9e, 0x45, 0x71, 0x94, 0x5f, 0xea, 0x27, 0x22, 0xfd, 0x60, 0x2e, 0x24, 0x25, 0x15, 0x95, 0x4c,
		0x93, 0x94, 0x44, 0x52, 0x12, 0x49, 0x49, 0x4b, 0x2c, 0xa5, 0x7a, 0x52, 0xd2, 0xc8, 0x64, 0x4d,
		0xe6, 0x2e, 0x2f, 0x69, 0x3a, 0x03, 0x52, 0x93, 0xca, 0xe6, 0x0e, 0x3c, 0x70, 0x0b, 0xae, 0xdd,
		0x83, 0x37, 0x6e, 0xc2, 0x1b, 0x77, 0xe1, 0x87, 0xdb, 0x58, 0x0d, 0xe1, 0xc6, 0x59, 0x6a, 0x52,
		0xcf, 0xed, 0x41, 0xce, 0x0d, 0xe7, 0xe2, 0xf8, 0x38, 0xaf, 0xc6, 0x71, 0x1e, 0xc7, 0x79, 0x1c,
		0xe7, 0xf9, 0xef, 0x92, 0xfc, 0x72, 0x4d, 0x6e, 0x5c, 0x94, 0x23, 0x57, 0xe5, 0xdc, 0x65, 0xf9,
		0xe2, 0xba, 0xfc, 0x72, 0x61, 0x37, 0x5d, 0x59, 0xd5, 0xf1, 0x34, 0x5c, 0xbb, 0x34, 0x9f, 0x5c,
		0x9b, 0x87, 0x2e, 0xce, 0x37, 0x57, 0xe7, 0xad, 0xcb, 0xf3, 0xd6, 0xf5, 0xf9, 0xe9, 0x02, 0xdd,
		0xba, 0x42, 0xc7, 0x2e, 0x71, 0xfa, 0x4a, 0x9c, 0x67, 0xba, 0x2c, 0x20, 0x4e, 0x6c, 0xc2, 0x4e,
		0x6a, 0x3a, 0x3e, 0x20, 0xce, 0x84, 0x6b, 0xed, 0x7a, 0x30, 0x97, 0xe3, 0xf1, 0x19, 0xef, 0xe6,
		0xe6, 0x28, 0x2f, 0x60, 0x6b, 0x8c, 0x39, 0x4f, 0xfe, 0x3f, 0xf6, 0xbe, 0x6f, 0xa9, 0x6d, 0x65,
		0xf9, 0xfa, 0x3e, 0x4f, 0x41, 0xa9, 0xce, 0x45, 0x52, 0x15, 0xc5, 0x40, 0x8c, 0x09, 0xdc, 0x09,
		0x2c, 0x88, 0x4e, 0x84, 0xed, 0x92, 0x05, 0x27, 0x39, 0x6c, 0x8e, 0x4a, 0xd8, 0x03, 0xd1, 0x17,
		0x21, 0xb9, 0x24, 0x99, 0x84, 0xdf, 0xde, 0xbc, 0xfb, 0x57, 0xb6, 0x6c, 0xf1, 0xc7, 0x38, 0x04,
		0x63, 0x6b, 0xba, 0x47, 0xcb, 0x17, 0x1b, 0x87, 0x1d, 0x42, 0x6b, 0xbc, 0xba, 0x7b, 0x75, 0x4f,
		0xaf, 0x99, 0x6a, 0xfa, 0x8e, 0x44, 0xbf, 0x91, 0x24, 0xba, 0x9d, 0xeb, 0x30, 0x32, 0x44, 0xb8,
		0xc4, 0xda, 0x12, 0xe0, 0x72, 0xe0, 0x72, 0xe0, 0x72, 0xe0, 0x72, 0xd5, 0xe6, 0x72, 0xb2, 0xdb,
		0x1c, 0x85, 0x21, 0x57, 0x22, 0x4b, 0x82, 0x1e, 0x1d, 0xef, 0x9e, 0x06, 0xc0, 0x89, 0x5d, 0x44,
		0x3c, 0x88, 0x46, 0xfb, 0x83, 0x5c, 0xea, 0xa4, 0x98, 0x42, 0x09, 0xa7, 0x52, 0xaa, 0x29, 0x95,
		0x7c, 0x6a, 0x25, 0x9f, 0x62, 0x69, 0xa7, 0x5a, 0x1a, 0x29, 0x97, 0x48, 0xea, 0xa5, 0xd7, 0x4e,
		0x99, 0x89, 0x58, 0x3f, 0x83, 0xbe, 0xd0, 0x49, 0x25, 0xc0, 0xfb, 0x49, 0x70, 0x9b, 0x90, 0x49,
		0x8e, 0x1f, 0x5d, 0x0a, 0xe9, 0x67, 0x95, 0x3f, 0x7e, 0xd1, 0x8a, 0xea, 0x6b, 0x93, 0x43, 0xb3,
		0xc9, 0xa5, 0x1b, 0xa2, 0xec, 0x6a, 0xc6, 0xbc, 0x13, 0x3f, 0x1c, 0x0a, 0xf9, 0x0d, 0x93, 0xb9,
		0xf6, 0x1d, 0x24, 0x7e, 0x2f, 0x0b, 0xe2, 0xa8, 0x19, 0x5c, 0x06, 0xf9, 0x99, 0xe8, 0xe4, 0xec,
		0xbc, 0x7d, 0x4f, 0xd0, 0x25, 0xfc, 0x5f, 0x70, 0x89, 0xd7, 0xba, 0x44, 0x63, 0x7b, 0x7b, 0x7b,
		0x53, 0xe6, 0x39, 0xf7, 0xec, 0x3d, 0xe3, 0x0d, 0xac, 0x79, 0xea, 0x75, 0xf6, 0x06, 0xeb, 0x41,
		0x24, 0x72, 0x52, 0x19, 0x89, 0x99, 0xe1, 0xc9, 0xb4, 0xda, 0xbf, 0xe8, 0x11, 0xfd, 0xde, 0x20,
		0xf4, 0x88, 0x5e, 0x64, 0x1a, 0x7a, 0x44, 0x0b, 0x1a, 0x88, 0x1e, 0x11, 0x7f, 0x06, 0x80, 0x1e,
		0xd1, 0x73, 0x11, 0x6b, 0x2c, 0x9b, 0x26, 0xe7, 0x80, 0x14, 0x6e, 0x1c, 0x9c, 0x4d, 0x3c, 0x44,
		0xae, 0xb4, 0x9b, 0x31, 0xec, 0x7f, 0x6f, 0xc7, 0x57, 0xda, 0x9d, 0xfd, 0x73, 0xba, 0xa1, 0xef,
		0x9c, 0xe5, 0x6f, 0x37, 0xc6, 0x5f, 0xf2, 0xf7, 0x9b, 0xa7, 0xeb, 0x7a, 0x7d, 0xfa, 0x7e, 0xeb,
		0x74, 0x5d, 0xdf, 0x3a, 0x7b, 0x37, 0xbe, 0xf5, 0xee, 0xe3, 0xed, 0xcb, 0x7f, 0xb0, 0x36, 0xf9,
		0x65, 0xef, 0xfe, 0x79, 0x7b, 0xba, 0xa1, 0x6f, 0x9e, 0x4d, 0xff, 0xf0, 0xf1, 0x74, 0x5d, 0xdf,
		0x3c, 0x7b, 0xf7, 0xee, 0x5f, 0x74, 0x62, 0xd0, 0x19, 0x25, 0xf0, 0x50, 0xba, 0x14, 0x11, 0x08,
		0x42, 0xf5, 0xc8, 0xae, 0x7a, 0x4c, 0xf5, 0xf3, 0x20, 0xa3, 0x57, 0x3c, 0xe6, 0x66, 0xa1, 0x76,
		0x44, 0xed, 0x88, 0xda, 0x11, 0xb5, 0x23, 0x6a, 0x47, 0xd4, 0x8e, 0x95, 0xa9, 0x1d, 0xcf, 0xe3,
		0x38, 0x14, 0x7e, 0x44, 0xb1, 0x6e, 0xdc, 0x00, 0x71, 0x23, 0x43, 0xdc, 0x86, 0x03, 0xbd, 0x1f,
		0xff, 0x8c, 0xe8, 0x51, 0xb7, 0xa9, 0x61, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20,
		0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x64, 0xc8, 0x5b, 0xa5, 0xa5, 0x4d, 0x92, 0x4f, 0x8b,
		0x9f, 0xb1, 0x87, 0xe2, 0xb9, 0xdb, 0xf3, 0x4f, 0x3f, 0xae, 0x4d, 0xcf, 0xc3, 0x9c, 0xbc, 0x91,
		0x71, 0xb2, 0x3c, 0x1d, 0x3c, 0x4b, 0x95, 0x8e, 0x0f, 0xcf, 0x47, 0x9f, 0x17, 0x21, 0xf1, 0xf8,
		0xc4, 0x20, 0xc8, 0xc7, 0x21, 0x1f, 0x67, 0x53, 0xd6, 0x40, 0x3e, 0xce, 0xbd, 0x7c, 0x81, 0x7c,
		0x9c, 0x1e, 0xc7, 0x22, 0x23, 0x1f, 0xcf, 0x73, 0x12, 0xc1, 0xdd, 0xdd, 0xdc, 0x2e, 0x5a, 0x1d,
		0xc2, 0x0d, 0x74, 0x08, 0xc9, 0xa7, 0x50, 0xc2, 0xa9, 0x94, 0x6a, 0x4a, 0x25, 0x9f, 0x5a, 0xc9,
		0xa7, 0x58, 0xda, 0xa9, 0x96, 0x4e, 0x63, 0x65, 0x8d, 0x50, 0x87, 0x90, 0x4a, 0x0a, 0x2e, 0x0c,
		0xba, 0x08, 0xfd, 0xcb, 0x94, 0x5e, 0x50, 0x98, 0xc6, 0xd1, 0xdc, 0x3c, 0x62, 0xfe, 0x46, 0x2b,
		0x31, 0x93, 0x4d, 0xd0, 0x94, 0x13, 0x35, 0x83, 0x84, 0x4d, 0x3d, 0x71, 0xb3, 0x49, 0xe0, 0x6c,
		0x12, 0x39, 0x8f, 0x84, 0x4e, 0x2b, 0xb1, 0x13, 0x4b, 0xf0, 0x64, 0x13, 0xfd, 0x5d, 0xed, 0x4d,
		0xe2, 0x6c, 0xd3, 0xe7, 0x4b, 0x71, 0x02, 0x67, 0x9e, 0x32, 0x23, 0x00, 0xe4, 0x89, 0x00, 0x07,
		0x42, 0xc0, 0x88, 0x18, 0x70, 0x21, 0x08, 0xec, 0x88, 0x02, 0x3b, 0xc2, 0xc0, 0x8b, 0x38, 0xd0,
		0x24, 0x10, 0x44, 0x89, 0x04, 0x79, 0x42, 0x41, 0xbc, 0x93, 0xc0, 0xaa, 0xb3, 0x30, 0x8f, 0x68,
		0xac, 0x13, 0x37, 0x93, 0x3a, 0xe1, 0xe0, 0x44, 0x3c, 0x18, 0x12, 0x10, 0x6e, 0x44, 0x84, 0x2d,
		0x21, 0x61, 0x4b, 0x4c, 0x78, 0x12, 0x14, 0xda, 0x44, 0x85, 0x38, 0x61, 0x29, 0x3e, 0x72, 0x72,
		0x43, 0xd1, 0xcf, 0x46, 0x5c, 0x11, 0x0d, 0xaf, 0x44, 0x92, 0x0f, 0xa3, 0x32, 0x88, 0xba, 0xd3,
		0x6e, 0x44, 0x9d, 0x81, 0xad, 0x66, 0x34, 0xbc, 0x1a, 0x81, 0x01, 0x2e, 0xf5, 0x9a, 0x55, 0xb4,
		0x83, 0x34, 0x33, 0xb2, 0x2c, 0xe1, 0xe1, 0x56, 0x47, 0x41, 0x64, 0x86, 0x62, 0x14, 0xf5, 0x53,
		0xfa, 0x14, 0x71, 0x6d, 0x72, 0xc8, 0xeb, 0x3d, 0x8b, 0x37, 0x3e, 0xd5, 0xeb, 0x8d, 0xed, 0x7a,
		0x7d, 0x7d, 0xfb, 0xe3, 0xf6, 0xfa, 0xce, 0xd6, 0xd6, 0x46, 0x83, 0xea, 0xd1, 0xa5, 0x0f, 0x1e,
		0xa2, 0x9d, 0xf4, 0x45, 0x22, 0xfa, 0x7b, 0x37, 0xda, 0xee, 0x5a, 0x34, 0x0c, 0xc3, 0x37, 0x48,
		0xb1, 0x8a, 0xc5, 0x02, 0x2d, 0xe3, 0x90, 0x5a, 0x8b, 0xb4, 0x3a, 0xb6, 0x16, 0x05, 0x37, 0x0a,
		0x6e, 0x14, 0xdc, 0x28, 0xb8, 0x51, 0x70, 0xa3, 0xe0, 0x46, 0xc1, 0x8d, 0x82, 0x3b, 0x3f, 0x96,
		0xb4, 0x2f, 0xa2, 0x2c, 0xc8, 0x6e, 0x68, 0xdc, 0x0a, 0xfc, 0xc7, 0x05, 0x37, 0x87, 0x2a, 0xc0,
		0x9a, 0x2c, 0xed, 0x9e, 0x9f, 0x32, 0xca, 0x13, 0x53, 0x60, 0x58, 0x5d, 0xab, 0xeb, 0x75, 0x8f,
		0xf7, 0x5c, 0xfb, 0xc4, 0x73, 0xbf, 0x75, 0x4c, 0x2e, 0xe9, 0x62, 0x7c, 0xd3, 0x45, 0x4a, 0xee,
		0xe4, 0xcf, 0xdf, 0xbd, 0xfe, 0x66, 0x63, 0xe9, 0x43, 0x84, 0x74, 0x3c, 0xc7, 0x34, 0xf6, 0x3f,
		0x1b, 0x7b, 0x96, 0x6d, 0xb9, 0xdf, 0x26, 0x60, 0xe9, 0x72, 0x42, 0x0b, 0x67, 0xd4, 0xf0, 0x44,
		0xcf, 0xb3, 0x28, 0xea, 0x38, 0xe6, 0x81, 0xf5, 0xd5, 0x3b, 0xb0, 0x8d, 0xc3, 0xae, 0xc6, 0xee,
		0xd1, 0x6e, 0xdf, 0x03, 0x3f, 0x72, 0xf1, 0x63, 0x75, 0x4e, 0xea, 0x9e, 0xd3, 0x3e, 0x76, 0x4d,
		0xc7, 0xb3, 0x9a, 0x40, 0x10, 0x10, 0xf4, 0x52, 0x04, 0xb9, 0xc6, 0x21, 0x60, 0x03, 0xd8, 0x2c,
		0x00, 0x9b, 0x46, 0x1d, 0xc0, 0x01, 0x70, 0x16, 0xc8, 0x58, 0x0d, 0x64, 0x2c, 0x20, 0xe8, 0xd5,
		0x9c, 0xb9, 0xcb, 0x12, 0x3d, 0xac, 0x2c, 0x3e, 0x7b, 0x03, 0xaf, 0x44, 0xff, 0x43, 0xa5, 0xca,
		0x15, 0x38, 0x41, 0x85, 0x0a, 0xa4, 0xa0, 0x12, 0x05, 0x3c, 0x50, 0x71, 0x02, 0x20, 0xca, 0x65,
		0x9a, 0x06, 0x32, 0x0d, 0x90, 0xa2, 0x66, 0x05, 0x09, 0x94, 0xac, 0x1a, 0x25, 0x93, 0xd0, 0xb1,
		0x6f, 0x74, 0xb0, 0xc7, 0x0b, 0xfc, 0x2c, 0x15, 0x47, 0x8e, 0x67, 0xd8, 0x87, 0x6d, 0xc7, 0x72,
		0x3f, 0x1f, 0xa1, 0xe3, 0x09, 0x04, 0x2d, 0x84, 0xa0, 0xbb, 0x3f, 0xa1, 0xed, 0xb9, 0xda, 0x17,
		0xda, 0x9e, 0x20, 0x05, 0xaa, 0x05, 0x73, 0x20, 0x05, 0x41, 0x1b, 0x50, 0xa1, 0x52, 0x8f, 0x76,
		0x31, 0x4b, 0x0a, 0xf4, 0x2c, 0x1b, 0x45, 0xb6, 0xd5, 0xfa, 0x82, 0x91, 0x0a, 0x40, 0x67, 0x01,
		0xe8, 0x1c, 0xb7, 0xf6, 0xdb, 0xad, 0xae, 0xeb, 0x18, 0x56, 0xcb, 0x6c, 0x7a, 0x76, 0xb7, 0x03,
		0x10, 0x01, 0x44, 0x0b, 0xc5, 0x1f, 0xc3, 0x75, 0x1d, 0x6b, 0xef, 0xd8, 0x35, 0x31, 0xce, 0x0e,
		0x08, 0xbd, 0x18, 0x42, 0xe3, 0x2d, 0x9c, 0x96, 0x69, 0x1d, 0x7e, 0xde, 0x6b, 0x3b, 0x9e, 0xd1,
		0x6c, 0x3a, 0x66, 0x17, 0x40, 0x02, 0x90, 0x16, 0x01, 0x52, 0xdd, 0xb3, 0x5a, 0xae, 0xe9, 0x1c,
		0x18, 0xfb, 0x26, 0x90, 0x04, 0x24, 0x2d, 0x4c, 0x8d, 0x5c, 0xcb, 0xb6, 0xfe, 0x6b, 0x36, 0xbd,
		0x3d, 0xa3, 0xd5, 0xfc, 0x8f, 0xd5, 0x74, 0x3f, 0x03, 0x45, 0x40, 0xd1, 0x42, 0xdc, 0xa8, 0xe3,
		0xb4, 0x5d, 0x73, 0xdf, 0xb5, 0xda, 0xad, 0xbc, 0xd2, 0x07, 0x8e, 0x80, 0xa3, 0x17, 0xe2, 0xc8,
		0x31, 0xbb, 0x56, 0xf3, 0xd8, 0xb0, 0x11, 0x8d, 0x80, 0xa2, 0xc5, 0x51, 0x74, 0x64, 0x7c, 0xcd,
		0x23, 0x12, 0x50, 0x04, 0x14, 0xbd, 0xae, 0x58, 0x03, 0xc7, 0x06, 0x92, 0x96, 0x12, 0x8f, 0x1c,
		0xb3, 0x6b, 0x3a, 0x27, 0xc6, 0x9e, 0x6d, 0x22, 0x2a, 0x01, 0x4b, 0xaf, 0x64, 0xda, 0x76, 0x1b,
		0x81, 0x08, 0xe0, 0x59, 0x10, 0x3c, 0x4d, 0xd3, 0x36, 0xbe, 0x79, 0x27, 0x86, 0x63, 0x19, 0xa3,
		0x5a, 0x0d, 0x38, 0x02, 0x8e, 0x5e, 0x8a, 0x23, 0xa3, 0xf9, 0x6f, 0xcf, 0x36, 0x5a, 0x4c, 0x35,
		0xca, 0x80, 0x8f, 0x6c, 0xf8, 0x9c, 0x18, 0x96, 0x0d, 0x2a, 0x04, 0x18, 0xbd, 0x3e, 0x0a, 0x21,
		0x02, 0x01, 0x3a, 0x8b, 0x54, 0x64, 0x56, 0xeb, 0xae, 0x4b, 0x34, 0x26, 0x44, 0x40, 0x11, 0x50,
		0xf4, 0x52, 0x14, 0x1d, 0xb7, 0xf2, 0xaa, 0x1e, 0xbb, 0x67, 0xc0, 0xd1, 0x6b, 0x70, 0x54, 0x80,
		0xc7, 0x2b, 0xc6, 0xd4, 0x5c, 0xd4, 0xf7, 0x00, 0xd2, 0x8b, 0x81, 0x64, 0x7e, 0x75, 0xcd, 0x56,
		0xd3, 0x6c, 0x7a, 0x46, 0x73, 0x94, 0xe1, 0x0e, 0x9d, 0xf6, 0x31, 0x46, 0x1d, 0x81, 0xa3, 0x05,
		0x98, 0x35, 0xe0, 0x03, 0xf8, 0x2c, 0x0c, 0x9f, 0xf1, 0x74, 0x1a, 0xc6, 0x1c, 0x01, 0xa4, 0xd7,
		0x02, 0x09, 0xe5, 0x19, 0xd0, 0xb3, 0x38, 0x7a, 0x5c, 0xd3, 0x6b, 0x9a, 0x07, 0xc6, 0xb1, 0xed,
		0x7a, 0x47, 0xa6, 0xeb, 0x58, 0xfb, 0x10, 0x96, 0xaf, 0xf6, 0x05, 0x61, 0x79, 0xe5, 0x9d, 0x52,
		0x1d, 0xf5, 0x1e, 0x20, 0x52, 0x36, 0x44, 0x18, 0xab, 0xf4, 0x00, 0x16, 0x29, 0xf1, 0x84, 0xa3,
		0x1a, 0x0f, 0x50, 0x91, 0x50, 0x8e, 0x72, 0x56, 0xdd, 0x01, 0x30, 0x52, 0xfa, 0x17, 0x8c, 0x27,
		0x7f, 0x81, 0x98, 0xd2, 0xa9, 0x0b, 0x63, 0x15, 0x1d, 0xd0, 0x22, 0x85, 0xbb, 0xb0, 0x55, 0xcb,
		0x01, 0x2f, 0x65, 0xe3, 0x85, 0xb3, 0x2a, 0x0e, 0x68, 0x29, 0x1b, 0x2d, 0x9c, 0xd5, 0x6f, 0x40,
		0x8b, 0x94, 0xe2, 0x08, 0x5c, 0x17, 0x88, 0x79, 0x51, 0x7c, 0xe1, 0xad, 0x66, 0x03, 0x66, 0xa4,
		0x30, 0x5e, 0x5e, 0xaa, 0x35, 0x80, 0x44, 0x0a, 0x48, 0xd8, 0xaa, 0xd3, 0x80, 0x97, 0xb2, 0xf1,
		0xc2, 0x52, 0x85, 0x06, 0x98, 0x94, 0x0e, 0x13, 0xce, 0x6a, 0x33, 0xc0, 0x45, 0x46, 0x54, 0x41,
		0x44, 0x01, 0x44, 0x14, 0x55, 0x8f, 0x01, 0x2d, 0x65, 0xa3, 0x85, 0xb7, 0x4a, 0x0c, 0x78, 0x29,
		0x1b, 0x2f, 0xcc, 0xd5, 0x60, 0x00, 0x4c, 0xd9, 0x80, 0xe1, 0xad, 0xfa, 0x02, 0x5e, 0xca, 0x67,
		0xb8, 0x80, 0x09, 0x60, 0xf2, 0x2c, 0x4c, 0x98, 0xab, 0xb8, 0x00, 0x98, 0xb2, 0x01, 0x83, 0x72,
		0x08, 0x28, 0x79, 0x1e, 0x25, 0x8c, 0x55, 0x59, 0x3c, 0xd4, 0x58, 0xf4, 0x55, 0x58, 0xb4, 0xd7,
		0x91, 0xae, 0x75, 0x34, 0x2d, 0x23, 0x1a, 0x42, 0x35, 0x23, 0x8a, 0xe2, 0xcc, 0xcf, 0x82, 0x38,
		0xd2, 0x76, 0x09, 0x07, 0x4f, 0x2d, 0xed, 0x7d, 0x17, 0x57, 0xfe, 0xc0, 0xcf, 0xbe, 0x8f, 0xc2,
		0x65, 0x2d, 0x1e, 0x88, 0xa8, 0x17, 0x47, 0x17, 0xc1, 0xa5, 0x1e, 0x89, 0xec, 0x67, 0x9c, 0xfc,
		0xd0, 0x83, 0x28, 0xcd, 0xfc, 0xa8, 0x27, 0x6a, 0x8f, 0xbf, 0x91, 0xce, 0x7c, 0xa7, 0x36, 0x48,
		0xe2, 0x2c, 0xee, 0xc5, 0x61, 0x5a, 0xbc, 0xab, 0x05, 0x69, 0x90, 0xd6, 0x42, 0x71, 0x2d, 0xc2,
		0xc9, 0x97, 0x5a, 0x18, 0x44, 0x3f, 0xf4, 0x34, 0xf3, 0x33, 0xa1, 0xf7, 0xfd, 0xcc, 0x3f, 0xf7,
		0x53, 0x51, 0x0b, 0xd3, 0x41, 0x2d, 0x0b, 0xaf, 0xd3, 0xd1, 0x7f, 0x6a, 0xe2, 0x57, 0x26, 0xa2,
		0xbe, 0xe8, 0xeb, 0xc1, 0xe0, 0xba, 0xae, 0x27, 0xc2, 0xef, 0x7d, 0xf7, 0xcf, 0x83, 0x30, 0xc8,
		0x6e, 0x6a, 0x83, 0x44, 0x5c, 0x04, 0xbf, 0x44, 0x3a, 0x79, 0x53, 0x4b, 0x87, 0xe7, 0xe3, 0x1f,
		0xcb, 0xbf, 0xd6, 0x2e, 0x42, 0xff, 0x32, 0xad, 0x8d, 0xff, 0x6d, 0x9a, 0x81, 0x9d, 0x9e, 0x13,
		0xd1, 0xb2, 0x88, 0x98, 0x3b, 0x53, 0x77, 0x63, 0x15, 0xdd, 0x97, 0xe0, 0x1d, 0xad, 0x5a, 0x9a,
		0x25, 0xc3, 0x5e, 0x16, 0x4d, 0x48, 0x65, 0x2b, 0x5f, 0x37, 0x6b, 0xb2, 0x6c, 0x5e, 0x67, 0xb2,
		0x58, 0x9e, 0x95, 0x06, 0xa9, 0x67, 0x8f, 0x56, 0xc9, 0xb3, 0xd3, 0x81, 0xe7, 0x86, 0xd7, 0x9e,
		0x39, 0x59, 0x0c, 0x6b, 0x70, 0x5d, 0x77, 0xee, 0x2d, 0x85, 0xd7, 0x19, 0xaf, 0x80, 0xd7, 0x1d,
		0x3f, 0xb9, 0x77, 0x30, 0x7e, 0xf2, 0x37, 0x08, 0x0c, 0xc4, 0x83, 0x82, 0x36, 0xc6, 0x74, 0x1a,
		0x0f, 0x93, 0x9e, 0xd0, 0x93, 0x78, 0x98, 0x89, 0x44, 0x0f, 0xfa, 0xe4, 0x62, 0x43, 0x51, 0xff,
		0x3c, 0x6d, 0x2e, 0xb1, 0x20, 0xfb, 0x25, 0x88, 0x46, 0x4b, 0xb8, 0x41, 0xcc, 0xac, 0xfd, 0x71,
		0x20, 0xd5, 0x76, 0xd7, 0xd6, 0x89, 0x19, 0x96, 0x87, 0x0e, 0x9a, 0x09, 0x69, 0x0a, 0xbc, 0xb8,
		0xa7, 0x8f, 0x52, 0x07, 0xc5, 0x60, 0xde, 0x1d, 0xbb, 0x03, 0x59, 0x5a, 0xae, 0x7d, 0x11, 0x37,
		0x3f, 0xe3, 0x64, 0xe4, 0x11, 0x5a, 0x9e, 0x26, 0x89, 0xde, 0x5a, 0xae, 0x7d, 0xf6, 0x53, 0x23,
		0xb9, 0x1c, 0x5e, 0x89, 0x28, 0xd3, 0x76, 0xd7, 0xb2, 0x64, 0x28, 0xa8, 0x16, 0x63, 0x77, 0x56,
		0x16, 0xc0, 0x04, 0x11, 0x67, 0x45, 0xc4, 0x9b, 0x41, 0x42, 0x94, 0x81, 0x8f, 0x8b, 0x4d, 0xb2,
		0xc1, 0x64, 0x1a, 0x8f, 0x73, 0x33, 0x89, 0xfa, 0x27, 0x4d, 0x02, 0x40, 0x9e, 0x08, 0x70, 0x20,
		0x04, 0x8c, 0x88, 0x01, 0x17, 0x82, 0xc0, 0x8e, 0x28, 0xb0, 0x23, 0x0c, 0xbc, 0x88, 0x03, 0x4d,
		0x02, 0x41, 0x94, 0x48, 0x90, 0x27, 0x14, 0x85, 0x81, 0x74, 0xbb, 0x0b, 0x73, 0x63, 0x3b, 0xd5,
		0x0e, 0xc3, 0x3c, 0xc2, 0xb1, 0x4e, 0xdc, 0x4c, 0xea, 0xc4, 0x83, 0x13, 0x01, 0x61, 0x48, 0x44,
		0xb8, 0x11, 0x12, 0xb6, 0xc4, 0x84, 0x2d, 0x41, 0xe1, 0x49, 0x54, 0x68, 0x13, 0x16, 0xe2, 0xc4,
		0xa5, 0xf8, 0xc8, 0xdd, 0x9b, 0x81, 0xe0, 0x15, 0x71, 0xc7, 0x9b, 0x11, 0x7e, 0xbf, 0x9f, 0x88,
		0x94, 0x45, 0xd8, 0x9d, 0xb6, 0x25, 0x3e, 0x31, 0xb0, 0xb5, 0xe3, 0x67, 0x99, 0x48, 0x22, 0x6d,
		0x77, 0xed, 0x94, 0x47, 0xc4, 0xfa, 0xdf, 0xdb, 0xb7, 0xa7, 0xeb, 0xfa, 0xce, 0xd9, 0x3f, 0xa7,
		0x1b, 0xfa, 0xce, 0x59, 0xfe, 0x76, 0x63, 0xfc, 0x25, 0x7f, 0xbf, 0x79, 0xba, 0xae, 0xd7, 0xa7,
		0xef, 0xb7, 0x4e, 0xd7, 0xf5, 0xad, 0xb3, 0x77, 0x7f, 0xfd, 0xf5, 0xe1, 0xdd, 0xdf, 0x1f, 0x6f,
		0x5f, 0xfe, 0x83, 0xff, 0xa2, 0x1f, 0x0c, 0xcf, 0x38, 0x80, 0xac, 0xdd, 0xb5, 0xbe, 0x02, 0x69,
		0xdc, 0x91, 0x86, 0x01, 0x48, 0xd5, 0x08, 0x81, 0x96, 0x71, 0x20, 0x03, 0x05, 0x11, 0x18, 0x5b,
		0x8b, 0x16, 0x01, 0x5a, 0x04, 0x68, 0x11, 0xa0, 0x45, 0x80, 0x16, 0x01, 0x5a, 0x04, 0x68, 0x11,
		0xa0, 0x45, 0x90, 0xb7, 0x08, 0xfa, 0x22, 0xca, 0x82, 0xec, 0x26, 0x11, 0x17, 0x9c, 0x3a, 0x04,
		0x5b, 0x0c, 0x6c, 0xb5, 0x26, 0x4b, 0xbb, 0xe7, 0xa7, 0x8c, 0xf2, 0xc4, 0x9d, 0x90, 0xcf, 0xea,
		0x7a, 0xdd, 0xe3, 0x3d, 0xd7, 0x3e, 0xc9, 0x4f, 0x2c, 0x67, 0x12, 0x75, 0x4f, 0xfc, 0x70, 0x28,
		0x52, 0x36, 0xc5, 0xf2, 0x1a, 0x63, 0xa9, 0x67, 0xe7, 0xa1, 0xd4, 0x33, 0x07, 0x4b, 0x97, 0x13,
		0x5a, 0x38, 0xa3, 0x86, 0x27, 0x7a, 0x9e, 0x45, 0x51, 0xc7, 0x31, 0x0f, 0xac, 0xaf, 0xde, 0x81,
		0x6d, 0x1c, 0xe2, 0x12, 0x59, 0xe0, 0xe7, 0xc5, 0xf8, 0x19, 0x9f, 0x63, 0xe1, 0xb4, 0x8f, 0x5d,
		0xd3, 0x61, 0x75, 0x01, 0x21, 0x10, 0x44, 0x05, 0x41, 0xae, 0x71, 0x08, 0xd8, 0x00, 0x36, 0x0b,
		0xc0, 0xa6, 0x51, 0x07, 0x70, 0x00, 0x9c, 0x05, 0x32, 0x56, 0x03, 0x19, 0x0b, 0x08, 0x7a, 0x35,
		0x67, 0xee, 0xb2, 0x44, 0x0f, 0xee, 0x3c, 0xaf, 0xba, 0x57, 0x2a, 0xd2, 0xff, 0xe0, 0x59, 0xb9,
		0x02, 0x27, 0xa8, 0x50, 0x81, 0x14, 0x54, 0xa2, 0x80, 0x07, 0x2a, 0x4e, 0x00, 0x44, 0xb9, 0x4c,
		0xd3, 0x40, 0xa6, 0x01, 0x52, 0xd4, 0xac, 0x20, 0x81, 0x92, 0x55, 0xa3, 0x64, 0x12, 0x3a, 0xf6,
		0x8d, 0x0e, 0xf6, 0x78, 0x81, 0x9f, 0xa5, 0xe2, 0xc8, 0xf1, 0x0c, 0xfb, 0xb0, 0xed, 0x58, 0xee,
		0xe7, 0x23, 0x74, 0x3c, 0x81, 0xa0, 0x85, 0x10, 0x74, 0xf7, 0x27, 0xb4, 0x3d, 0x57, 0xfb, 0x42,
		0xdb, 0x13, 0xa4, 0x40, 0xb5, 0x60, 0x0e, 0xa4, 0x20, 0x68, 0x03, 0x2a, 0x54, 0xea, 0xd1, 0x2e,
		0x66, 0x49, 0x81, 0x9e, 0x65, 0xa3, 0x68, 0x7c, 0x45, 0x11, 0x46, 0x2a, 0x00, 0x9d, 0x97, 0x43,
		0xe7, 0xb8, 0x55, 0x5c, 0xc7, 0x69, 0x36, 0x3d, 0xbb, 0xdb, 0x01, 0x88, 0x00, 0xa2, 0x85, 0xe2,
		0x8f, 0xe1, 0xba, 0x8e, 0xb5, 0x77, 0xec, 0x9a, 0x18, 0x67, 0x07, 0x84, 0x5e, 0x0c, 0xa1, 0xf1,
		0x16, 0x0e, 0xdf, 0x6b, 0x19, 0x01, 0x24, 0x42, 0x40, 0xaa, 0x7b, 0x56, 0xcb, 0x35, 0x9d, 0x03,
		0x63, 0xdf, 0x04, 0x92, 0x80, 0xa4, 0x85, 0xa9, 0x91, 0x6b, 0xd9, 0xd6, 0x7f, 0x79, 0xde, 0x6f,
		0x0f, 0x14, 0x91, 0xe2, 0x46, 0x1d, 0xa7, 0xed, 0x9a, 0xfb, 0xae, 0xd5, 0x6e, 0xe5, 0x95, 0x3e,
		0x70, 0x04, 0x1c, 0xbd, 0x10, 0x47, 0x8e, 0xd9, 0xb5, 0x9a, 0xc7, 0x86, 0x8d, 0x68, 0x04, 0x14,
		0x2d, 0x8e, 0xa2, 0x23, 0xe3, 0x6b, 0x1e, 0x91, 0x80, 0x22, 0xa0, 0xe8, 0x75, 0xc5, 0x1a, 0x38,
		0x36, 0x90, 0xb4, 0x94, 0x78, 0xe4, 0x98, 0x5d, 0xd3, 0x39, 0x31, 0xf6, 0x6c, 0x13, 0x51, 0x09,
		0x58, 0x7a, 0x25, 0xd3, 0xb6, 0xdb, 0x08, 0x44, 0x00, 0xcf, 0x82, 0xe0, 0x69, 0x9a, 0xb6, 0xf1,
		0xcd, 0x3b, 0x31, 0x1c, 0xcb, 0x18, 0xd5, 0x6a, 0xc0, 0x11, 0x70, 0xf4, 0x52, 0x1c, 0x19, 0xcd,
		0x7f, 0x7b, 0xb6, 0xd1, 0x62, 0xaa, 0x51, 0x06, 0x7c, 0x64, 0xc3, 0xe7, 0xc4, 0xb0, 0x6c, 0x50,
		0x21, 0xc0, 0xe8, 0xf5, 0x51, 0x08, 0x11, 0x08, 0xd0, 0x59, 0xa4, 0x22, 0xb3, 0x5a, 0x77, 0x5d,
		0xa2, 0x31, 0x21, 0x02, 0x8a, 0x80, 0xa2, 0x97, 0xa2, 0xe8, 0xb8, 0x95, 0x57, 0xf5, 0xd8, 0x3d,
		0x03, 0x8e, 0x5e, 0x83, 0xa3, 0x02, 0x3c, 0x5e, 0x31, 0xa6, 0xe6, 0xa2, 0xbe, 0x07, 0x90, 0x5e,
		0x0c, 0x24, 0xf3, 0xab, 0x6b, 0xb6, 0x9a, 0x66, 0xd3, 0x33, 0x9a, 0xa3, 0x0c, 0x77, 0xe8, 0xb4,
		0x8f, 0x31, 0xea, 0x08, 0x1c, 0x2d, 0xc0, 0xac, 0x01, 0x1f, 0xc0, 0x67, 0x61, 0xf8, 0x8c, 0xa7,
		0xd3, 0x30, 0xe6, 0x08, 0x20, 0xbd, 0x16, 0x48, 0x28, 0xcf, 0x80, 0x9e, 0xc5, 0xd1, 0xe3, 0x9a,
		0x5e, 0xd3, 0x3c, 0x30, 0x8e, 0x6d, 0xd7, 0x3b, 0x32, 0x5d, 0xc7, 0xda, 0x87, 0xb0, 0x7c, 0xb5,
		0x2f, 0x08, 0xcb, 0x2b, 0xef, 0x94, 0xea, 0xa8, 0xf7, 0x00, 0x91, 0xb2, 0x21, 0xc2, 0x58, 0xa5,
		0x07, 0xb0, 0x48, 0x89, 0x27, 0x1c, 0xd5, 0x78, 0x80, 0x8a, 0x84, 0x72, 0x94, 0xb3, 0xea, 0x0e,
		0x80, 0x91, 0xd2, 0xbf, 0x60, 0x3c, 0xf9, 0x0b, 0xc4, 0x94, 0x4e, 0x5d, 0x18, 0xab, 0xe8, 0x80,
		0x16, 0x29, 0xdc, 0x85, 0xad, 0x5a, 0x0e, 0x78, 0x29, 0x1b, 0x2f, 0x9c, 0x55, 0x71, 0x40, 0x4b,
		0xd9, 0x68, 0xe1, 0xac, 0x7e, 0x03, 0x5a, 0xa4, 0x14, 0x47, 0xe0, 0xba, 0x40, 0xcc, 0x8b, 0xe2,
		0x0b, 0x6f, 0x35, 0x1b, 0x30, 0x23, 0x85, 0xf1, 0xf2, 0x52, 0xad, 0x01, 0x24, 0x52, 0x40, 0xc2,
		0x56, 0x9d, 0x06, 0xbc, 0x94, 0x8d, 0x17, 0x96, 0x2a, 0x34, 0xc0, 0xa4, 0x74, 0x98, 0x70, 0x56,
		0x9b, 0x01, 0x2e, 0x32, 0xa2, 0x0a, 0x22, 0x0a, 0x20, 0xa2, 0xa8, 0x7a, 0x0c, 0x68, 0x29, 0x1b,
		0x2d, 0xbc, 0x55, 0x62, 0xc0, 0x4b, 0xd9, 0x78, 0x61, 0xae, 0x06, 0x03, 0x60, 0xca, 0x06, 0x0c,
		0x6f, 0xd5, 0x17, 0xf0, 0x52, 0x3e, 0xc3, 0x05, 0x4c, 0x00, 0x93, 0x67, 0x61, 0xc2, 0x5c, 0xc5,
		0x05, 0xc0, 0x94, 0x0d, 0x18, 0x94, 0x43, 0x40, 0xc9, 0xf3, 0x28, 0x61, 0xac, 0xca, 0xe2, 0xa1,
		0xc6, 0xa2, 0xaf, 0xc2, 0xa2, 0xbd, 0x8e, 0x74, 0xad, 0xa3, 0x69, 0x19, 0xd1, 0x10, 0xaa, 0x19,
		0x51, 0x14, 0x67, 0x7e, 0x16, 0xc4, 0x91, 0xb6, 0x4b, 0x38, 0x78, 0x6a, 0x69, 0xef, 0xbb, 0xb8,
		0xf2, 0x07, 0x7e, 0xf6, 0x7d, 0x14, 0x2e, 0x6b, 0xf1, 0x40, 0x44, 0xbd, 0x38, 0xba, 0x08, 0x2e,
		0xf5, 0x48, 0x64, 0x3f, 0xe3, 0xe4, 0x87, 0x1e, 0x44, 0x69, 0xe6, 0x47, 0x3d, 0x51, 0x7b, 0xfc,
		0x8d, 0x74, 0xe6, 0x3b, 0xb5, 0x41, 0x12, 0x67, 0x71, 0x2f, 0x0e, 0xd3, 0xe2, 0x5d, 0x2d, 0x48,
		0x83, 0xb4, 0x16, 0x8a, 0x6b, 0x11, 0x4e, 0xbe, 0xd4, 0xc2, 0x20, 0xfa, 0xa1, 0xa7, 0x99, 0x9f,
		0x09, 0xbd, 0xef, 0x67, 0xfe, 0xb9, 0x9f, 0x8a, 0x5a, 0x98, 0x0e, 0x6a, 0x59, 0x78, 0x9d, 0x8e,
		0xfe, 0x53, 0x13, 0xbf, 0x32, 0x11, 0xf5, 0x45, 0x5f, 0x0f, 0x06, 0xd7, 0x75, 0x3d, 0x11, 0x7e,
		0xef, 0xbb, 0x7f, 0x1e, 0x84, 0x41, 0x76, 0x53, 0x1b, 0x24, 0xe2, 0x22, 0xf8, 0x25, 0xd2, 0xc9,
		0x9b, 0x5a, 0x3a, 0x3c, 0x1f, 0xff, 0x58, 0xfe, 0xb5, 0x36, 0xfe, 0x81, 0x34, 0x1e, 0x26, 0x3d,
		0xa1, 0x27, 0xf1, 0x30, 0x13, 0x89, 0x1e, 0xf4, 0x6b, 0xe3, 0xdf, 0x45, 0x33, 0xd0, 0xd3, 0x73,
		0x2a, 0x5a, 0x16, 0x11, 0x73, 0x6f, 0xea, 0x6e, 0x5d, 0x05, 0x77, 0x26, 0x78, 0x87, 0xab, 0x96,
		0x66, 0xc9, 0xb0, 0x97, 0x45, 0x13, 0xd2, 0xd9, 0xca, 0xd7, 0xd1, 0x9a, 0x2c, 0xa3, 0xd7, 0x99,
		0x2c, 0x9e, 0x67, 0xa5, 0x41, 0xea, 0xd9, 0xa3, 0x55, 0xf3, 0xec, 0x74, 0xe0, 0xb9, 0xe1, 0xb5,
		0x67, 0x4e, 0x16, 0xc7, 0x1a, 0x5c, 0xd7, 0x9d, 0x7b, 0x4b, 0xe3, 0x75, 0xc6, 0x2b, 0xe2, 0x75,
		0xc7, 0x2b, 0xe1, 0x8d, 0xfe, 0x77, 0x77, 0xbc, 0x10, 0xce, 0x78, 0x1d, 0xac, 0x3e, 0xad, 0x78,
		0x46, 0x27, 0x6a, 0x10, 0x8a, 0x18, 0x5a, 0x30, 0xb8, 0x6e, 0xcc, 0xe2, 0x97, 0x5a, 0xe0, 0x28,
		0x8a, 0xa5, 0xa7, 0xcd, 0x25, 0x16, 0x81, 0xbf, 0x04, 0xd1, 0x68, 0x09, 0x37, 0x88, 0x99, 0xb5,
		0x3f, 0x8e, 0xb2, 0xda, 0xee, 0xda, 0x3a, 0x31, 0xc3, 0xf2, 0x38, 0x42, 0x33, 0x5b, 0x4d, 0x81,
		0x17, 0xf7, 0xf4, 0x51, 0x5e, 0xa1, 0x18, 0xd9, 0xf3, 0xa0, 0x4b, 0x96, 0xc3, 0x6b, 0x5f, 0xc4,
		0xcd, 0xcf, 0x38, 0x19, 0x79, 0x84, 0x96, 0xe7, 0x50, 0xa2, 0x57, 0x9c, 0x6b, 0x9f, 0xfd, 0xd4,
		0x48, 0x2e, 0x87, 0x57, 0x22, 0xca, 0xb4, 0xdd, 0xb5, 0x2c, 0x19, 0x0a, 0xaa, 0x95, 0xdb, 0x9d,
		0x95, 0x05, 0x30, 0xc1, 0xd2, 0x59, 0xb1, 0xf4, 0x66, 0x90, 0x10, 0xa5, 0xe7, 0xe3, 0x4a, 0x94,
		0x6c, 0x30, 0x99, 0xc6, 0xe3, 0xdc, 0x4c, 0xa2, 0xfe, 0x49, 0x93, 0x00, 0x90, 0x27, 0x02, 0x1c,
		0x08, 0x01, 0x23, 0x62, 0xc0, 0x85, 0x20, 0xb0, 0x23, 0x0a, 0xec, 0x08, 0x03, 0x2f, 0xe2, 0x40,
		0x93, 0x40, 0x10, 0x25, 0x12, 0xe4, 0x09, 0x45, 0x61, 0x20, 0xdd, 0xee, 0xc2, 0xdc, 0xd8, 0x4e,
		0xb9, 0xa1, 0xf7, 0x14, 0xe1, 0x58, 0x27, 0x6e, 0x26, 0x75, 0xe2, 0xc1, 0x89, 0x80, 0x30, 0x24,
		0x22, 0xdc, 0x08, 0x09, 0x5b, 0x62, 0xc2, 0x96, 0xa0, 0xf0, 0x24, 0x2a, 0xb4, 0x09, 0x0b, 0x71,
		0xe2, 0x52, 0x7c, 0xe4, 0xee, 0xcd, 0x40, 0xf0, 0x8a, 0xb8, 0xe3, 0xcd, 0x08, 0xbf, 0xdf, 0x4f,
		0x44, 0xca, 0x22, 0xec, 0x4e, 0xdb, 0x12, 0x9f, 0x18, 0xd8, 0xda, 0xf1, 0xb3, 0x4c, 0x24, 0x91,
		0xb6, 0xbb, 0x76, 0xca, 0x23, 0x62, 0xfd, 0xef, 0xed, 0xdb, 0xd3, 0x75, 0x7d, 0xc7, 0xd7, 0x2f,
		0x0c, 0xfd, 0xe0, 0xec, 0xef, 0x8d, 0xf7, 0xf5, 0xdb, 0xdd, 0x77, 0x7f, 0x6f, 0xdf, 0x3e, 0xfe,
		0xe6, 0x3f, 0x4f, 0xfd, 0xb5, 0x8d, 0xf7, 0xdb, 0xb7, 0xbb, 0x73, 0xfe, 0x4f, 0xe3, 0x76, 0xf7,
		0x0f, 0xff, 0x8d, 0xad, 0xdb, 0xb7, 0x33, 0x7f, 0x75, 0xf4, 0xfd, 0xcd, 0x79, 0x3f, 0x50, 0x9f,
		0xf3, 0x03, 0x1f, 0xe7, 0xfd, 0xc0, 0xc7, 0x39, 0x3f, 0x30, 0xd7, 0xa4, 0xcd, 0x39, 0x3f, 0xb0,
		0x75, 0xfb, 0xcf, 0xcc, 0xdf, 0x7f, 0xfb, 0xf4, 0x5f, 0x6d, 0xdc, 0xbe, 0xfb, 0x67, 0xde, 0xff,
		0xdb, 0xbe, 0xfd, 0x67, 0xf7, 0xdd, 0xbb, 0x7f, 0xd1, 0x4f, 0x0d, 0x67, 0x1c, 0x5c, 0xae, 0xdd,
		0xb5, 0xbe, 0xc2, 0xef, 0xe0, 0x77, 0x2a, 0xf9, 0x1d, 0x26, 0x69, 0x55, 0x23, 0x8b, 0x5a, 0xc6,
		0x81, 0x28, 0x16, 0x24, 0x71, 0x6c, 0x2d, 0xda, 0x47, 0x68, 0x1f, 0xa1, 0x7d, 0x84, 0xf6, 0x11,
		0xda, 0x47, 0x68, 0x1f, 0xa1, 0x7d, 0x84, 0xf6, 0x51, 0xde, 0x3e, 0xea, 0x8b, 0x28, 0x0b, 0xb2,
		0x9b, 0x44, 0x5c, 0x70, 0xea, 0x1e, 0x6d, 0x31, 0xb0, 0xd5, 0x9a, 0x2c, 0xed, 0x9e, 0x9f, 0x32,
		0xca, 0x13, 0x77, 0x8a, 0x50, 0xab, 0xeb, 0x75, 0x8f, 0xf7, 0x5c, 0xfb, 0x24, 0x3f, 0xfa, 0x9e,
		0x49, 0xd4, 0x3d, 0xf1, 0xc3, 0xa1, 0x48, 0xd9, 0xb4, 0x0e, 0xd6, 0x18, 0x6b, 0x86, 0x3b, 0x0f,
		0x35, 0xc3, 0x39, 0x58, 0xba, 0x9c, 0xd0, 0xc2, 0x19, 0x35, 0x3c, 0xd1, 0xf3, 0x2c, 0x8a, 0x3a,
		0x8e, 0x79, 0x60, 0x7d, 0xf5, 0x0e, 0x6c, 0xe3, 0x10, 0xb7, 0x11, 0x03, 0x3f, 0x2f, 0xc6, 0xcf,
		0xf8, 0x40, 0x14, 0xa7, 0x7d, 0xec, 0x9a, 0x0e, 0xab, 0x9b, 0x2c, 0x81, 0x20, 0x2a, 0x08, 0x72,
		0x8d, 0x43, 0xc0, 0x06, 0xb0, 0x59, 0x00, 0x36, 0x8d, 0x3a, 0x80, 0x03, 0xe0, 0x2c, 0x90, 0xb1,
		0x1a, 0xc8, 0x58, 0x40, 0xd0, 0xab, 0x39, 0x73, 0x97, 0x25, 0x7a, 0x70, 0x79, 0x7e, 0xd5, 0xbd,
		0x52, 0x91, 0xfe, 0x07, 0xcf, 0xca, 0x15, 0x38, 0x41, 0x85, 0x0a, 0xa4, 0xa0, 0x12, 0x05, 0x3c,
		0x50, 0x71, 0x02, 0x20, 0xca, 0x65, 0x9a, 0x06, 0x32, 0x0d, 0x90, 0xa2, 0x66, 0x05, 0x09, 0x94,
		0xac, 0x1a, 0x25, 0x93, 0xd0, 0xb1, 0x6f, 0x74, 0xb0, 0xc7, 0x0b, 0xfc, 0x2c, 0x15, 0x47, 0x8e,
		0x67, 0xd8, 0x87, 0x6d, 0xc7, 0x72, 0x3f, 0x1f, 0xa1, 0xe3, 0x09, 0x04, 0x2d, 0x84, 0xa0, 0xbb,
		0x3f, 0xa1, 0xed, 0xb9, 0xda, 0x17, 0xda, 0x9e, 0x20, 0x05, 0xaa, 0x05, 0x73, 0x20, 0x05, 0x41,
		0x1b, 0x50, 0xa1, 0x52, 0x8f, 0x76, 0x31, 0x4b, 0x0a, 0xf4, 0x2c, 0x1b, 0x45, 0xe3, 0xbb, 0xae,
		0x30, 0x52, 0x01, 0xe8, 0xbc, 0x1c, 0x3a, 0xc7, 0xad, 0xe2, 0x5e, 0x57, 0xb3, 0xe9, 0xd9, 0xdd,
		0x0e, 0x40, 0x04, 0x10, 0x2d, 0x14, 0x7f, 0x0c, 0xd7, 0x75, 0xac, 0xbd, 0x63, 0xd7, 0xc4, 0x38,
		0x3b, 0x20, 0xf4, 0x62, 0x08, 0x8d, 0xb7, 0x70, 0xf8, 0xde, 0xef, 0x09, 0x20, 0x11, 0x02, 0x52,
		0xdd, 0xb3, 0x5a, 0xae, 0xe9, 0x1c, 0x18, 0xfb, 0x26, 0x90, 0x04, 0x24, 0x2d, 0x4c, 0x8d, 0x5c,
		0xcb, 0xb6, 0xfe, 0x6b, 0x36, 0xef, 0xee, 0xc0, 0x07, 0x8a, 0x80, 0xa2, 0x85, 0xb8, 0x51, 0xc7,
		0x69, 0xbb, 0xe6, 0xbe, 0x6b, 0xb5, 0x5b, 0x79, 0xa5, 0x0f, 0x1c, 0x01, 0x47, 0x2f, 0xc4, 0x91,
		0x63, 0x76, 0xad, 0xe6, 0xb1, 0x61, 0x23, 0x1a, 0x01, 0x45, 0x8b, 0xa3, 0xe8, 0xc8, 0xf8, 0x9a,
		0x47, 0x24, 0xa0, 0x08, 0x28, 0x7a, 0x5d, 0xb1, 0x06, 0x8e, 0x0d, 0x24, 0x2d, 0x25, 0x1e, 0x39,
		0x66, 0xd7, 0x74, 0x4e, 0x8c, 0x3d, 0xdb, 0x44, 0x54, 0x02, 0x96, 0x5e, 0xc9, 0xb4, 0xed, 0x36,
		0x02, 0x11, 0xc0, 0xb3, 0x20, 0x78, 0x9a, 0xa6, 0x6d, 0x7c, 0xf3, 0x4e, 0x0c, 0xc7, 0x32, 0x46,
		0xb5, 0x1a, 0x70, 0x04, 0x1c, 0xbd, 0x14, 0x47, 0x46, 0xf3, 0xdf, 0x9e, 0x6d, 0xb4, 0x98, 0x6a,
		0x94, 0x01, 0x1f, 0xd9, 0xf0, 0x39, 0x31, 0x2c, 0x1b, 0x54, 0x08, 0x30, 0x7a, 0x7d, 0x14, 0x42,
		0x04, 0x02, 0x74, 0x16, 0xa9, 0xc8, 0xac, 0xd6, 0x5d, 0x97, 0x68, 0x4c, 0x88, 0x80, 0x22, 0xa0,
		0xe8, 0xa5, 0x28, 0x3a, 0x6e, 0xe5, 0x55, 0x3d, 0x76, 0xcf, 0x80, 0xa3, 0xd7, 0xe0, 0xa8, 0x00,
		0x8f, 0x57, 0x8c, 0xa9, 0xb9, 0xa8, 0xef, 0x01, 0xa4, 0x17, 0x03, 0xc9, 0xfc, 0xea, 0x9a, 0xad,
		0xa6, 0xd9, 0xf4, 0x8c, 0xe6, 0x28, 0xc3, 0x1d, 0x3a, 0xed, 0x63, 0x8c, 0x3a, 0x02, 0x47, 0x0b,
		0x30, 0x6b, 0xc0, 0x07, 0xf0, 0x59, 0x18, 0x3e, 0xe3, 0xe9, 0x34, 0x8c, 0x39, 0x02, 0x48, 0xaf,
		0x05, 0x12, 0xca, 0x33, 0xa0, 0x67, 0x71, 0xf4, 0xb8, 0xa6, 0xd7, 0x34, 0x0f, 0x8c, 0x63, 0xdb,
		0xf5, 0x8e, 0x4c, 0xd7, 0xb1, 0xf6, 0x21, 0x2c, 0x5f, 0xed, 0x0b, 0xc2, 0xf2, 0xca, 0x3b, 0xa5,
		0x3a, 0xea, 0x3d, 0x40, 0xa4, 0x6c, 0x88, 0x30, 0x56, 0xe9, 0x01, 0x2c, 0x52, 0xe2, 0x09, 0x47,
		0x35, 0x1e, 0xa0, 0x22, 0xa1, 0x1c, 0xe5, 0xac, 0xba, 0x03, 0x60, 0xa4, 0xf4, 0x2f, 0x18, 0x4f,
		0xfe, 0x02, 0x31, 0xa5, 0x53, 0x17, 0xc6, 0x2a, 0x3a, 0xa0, 0x45, 0x0a, 0x77, 0x61, 0xab, 0x96,
		0x03, 0x5e, 0xca, 0xc6, 0x0b, 0x67, 0x55, 0x1c, 0xd0, 0x52, 0x36, 0x5a, 0x38, 0xab, 0xdf, 0x80,
		0x16, 0x29, 0xc5, 0x11, 0xb8, 0x2e, 0x10, 0xf3, 0xa2, 0xf8, 0xc2, 0x5b, 0xcd, 0x06, 0xcc, 0x48,
		0x61, 0xbc, 0xbc, 0x54, 0x6b, 0x00, 0x89, 0x14, 0x90, 0xb0, 0x55, 0xa7, 0x01, 0x2f, 0x65, 0xe3,
		0x85, 0xa5, 0x0a, 0x0d, 0x30, 0x29, 0x1d, 0x26, 0x9c, 0xd5, 0x66, 0x80, 0x8b, 0x8c, 0xa8, 0x82,
		0x88, 0x02, 0x88, 0x28, 0xaa, 0x1e, 0x03, 0x5a, 0xca, 0x46, 0x0b, 0x6f, 0x95, 0x18, 0xf0, 0x52,
		0x36, 0x5e, 0x98, 0xab, 0xc1, 0x00, 0x98, 0xb2, 0x01, 0xc3, 0x5b, 0xf5, 0x05, 0xbc, 0x94, 0xcf,
		0x70, 0x01, 0x13, 0xc0, 0xe4, 0x59, 0x98, 0x30, 0x57, 0x71, 0x01, 0x30, 0x65, 0x03, 0x06, 0xe5,
		0x10, 0x50, 0xf2, 0x3c, 0x4a, 0x18, 0xab, 0xb2, 0x78, 0xa8, 0xb1, 0xe8, 0xab, 0xb0, 0x68, 0xaf,
		0x23, 0x5d, 0xeb, 0x68, 0x5a, 0x46, 0x34, 0x84, 0x6a, 0x46, 0x14, 0xc5, 0x99, 0x9f, 0x05, 0x71,
		0xa4, 0xed, 0x12, 0x0e, 0x9e, 0x5a, 0xda, 0xfb, 0x2e, 0xae, 0xfc, 0x81, 0x9f, 0x7d, 0x1f, 0x85,
		0xcb, 0x5a, 0x3c, 0x10, 0x51, 0x2f, 0x8e, 0x2e, 0x82, 0x4b, 0x3d, 0x12, 0xd9, 0xcf, 0x38, 0xf9,
		0xa1, 0x07, 0x51, 0x9a, 0xf9, 0x51, 0x4f, 0xd4, 0x1e, 0x7f, 0x23, 0x9d, 0xf9, 0x4e, 0x6d, 0x90,
		0xc4, 0x59, 0xdc, 0x8b, 0xc3, 0xb4, 0x78, 0x57, 0x0b, 0xd2, 0x20, 0xad, 0x85, 0xe2, 0x5a, 0x84,
		0x93, 0x2f, 0xb5, 0x30, 0x88, 0x7e, 0xe8, 0x69, 0xe6, 0x67, 0x42, 0xef, 0xfb, 0x99, 0x7f, 0xee,
		0xa7, 0xa2, 0x16, 0xa6, 0x83, 0x5a, 0x16, 0x5e, 0xa7, 0xa3, 0xff, 0xd4, 0xc4, 0xaf, 0x4c, 0x44,
		0x7d, 0xd1, 0xd7, 0x83, 0xc1, 0x75, 0x5d, 0x4f, 0x84, 0xdf, 0xfb, 0xee, 0x9f, 0x07, 0x61, 0x90,
		0xdd, 0xd4, 0x06, 0x89, 0xb8, 0x08, 0x7e, 0x89, 0x74, 0xf2, 0xa6, 0x96, 0x0e, 0xcf, 0xc7, 0x3f,
		0x96, 0x7f, 0xad, 0x05, 0x83, 0xeb, 0x86, 0x9e, 0xc6, 0xc3, 0xa4, 0x27, 0xf4, 0x24, 0x1e, 0x66,
		0x22, 0xd1, 0x83, 0x7e, 0x6d, 0xfc, 0xbb, 0x68, 0x06, 0x7a, 0x7a, 0x4e, 0x45, 0xcb, 0x22, 0x62,
		0xee, 0x4d, 0xdd, 0xad, 0xab, 0xe0, 0xce, 0x04, 0xef, 0x70, 0xd5, 0xd2, 0x2c, 0x19, 0xf6, 0xb2,
		0x68, 0x42, 0x3a, 0x5b, 0xf9, 0x3a, 0x5a, 0x93, 0x65, 0xf4, 0x3a, 0x93, 0xc5, 0xf3, 0xac, 0x34,
		0x48, 0x3d, 0x7b, 0xb4, 0x6a, 0x9e, 0x9d, 0x0e, 0x3c, 0x37, 0xbc, 0xf6, 0xcc, 0xc9, 0xe2, 0x58,
		0x83, 0xeb, 0xba, 0x73, 0x6f, 0x69, 0xbc, 0xce, 0x78, 0x45, 0xbc, 0xee, 0x78, 0x25, 0x3c, 0x6b,
		0x70, 0xdd, 0xe8, 0x8e, 0x17, 0xc2, 0x19, 0xaf, 0x83, 0xd5, 0xa7, 0x15, 0xcf, 0xe8, 0x44, 0x0d,
		0x42, 0x11, 0x43, 0xcb, 0x51, 0xad, 0xa7, 0x41, 0x3f, 0x25, 0x17, 0x2e, 0x8a, 0x12, 0xe9, 0xbe,
		0x91, 0xc4, 0xa2, 0xed, 0x97, 0x20, 0xea, 0x6b, 0xbb, 0x6b, 0x1b, 0xc4, 0xcc, 0xda, 0x1f, 0x47,
		0x54, 0x6d, 0x77, 0x6d, 0x9d, 0x98, 0x61, 0x79, 0xcc, 0xa0, 0x99, 0x99, 0xa6, 0x70, 0x8b, 0x7b,
		0xfa, 0x28, 0x87, 0x50, 0x8c, 0xe2, 0x79, 0x80, 0x25, 0xcb, 0xd7, 0xb5, 0x2f, 0xe2, 0xe6, 0x67,
		0x9c, 0xf4, 0xef, 0x9c, 0x96, 0xe8, 0x75, 0xe6, 0xda, 0x67, 0x3f, 0x35, 0x92, 0xcb, 0xe1, 0x95,
		0x88, 0x32, 0x6d, 0x77, 0x2d, 0x4b, 0x86, 0x82, 0x6a, 0x95, 0x76, 0x67, 0x65, 0x01, 0x4c, 0x30,
		0x72, 0x56, 0x8c, 0xbc, 0x19, 0x24, 0x34, 0x03, 0xde, 0x5d, 0x5e, 0xa5, 0x1b, 0x51, 0x66, 0x39,
		0x00, 0xd5, 0x90, 0x42, 0x93, 0x0a, 0x90, 0xa7, 0x04, 0x1c, 0xa8, 0x01, 0x23, 0x8a, 0xc0, 0x85,
		0x2a, 0xb0, 0xa3, 0x0c, 0xec, 0xa8, 0x03, 0x2f, 0x0a, 0x41, 0x93, 0x4a, 0x10, 0xa5, 0x14, 0xe4,
		0xa9, 0x45, 0x61, 0x60, 0xde, 0xd8, 0x26, 0x1f, 0x84, 0xa6, 0x71, 0x3d, 0x37, 0x97, 0xb8, 0x3f,
		0xd3, 0x26, 0x1a, 0x6c, 0x08, 0x07, 0x27, 0xe2, 0xc1, 0x90, 0x80, 0x70, 0x23, 0x22, 0x6c, 0x09,
		0x09, 0x5b, 0x62, 0xc2, 0x93, 0xa0, 0xd0, 0x26, 0x2a, 0xc4, 0x09, 0x0b, 0x1b, 0xe2, 0x52, 0x18,
		0xea, 0x87, 0x97, 0x71, 0x12, 0x64, 0xdf, 0xaf, 0xf8, 0x04, 0xb0, 0x69, 0x8e, 0xb8, 0x33, 0x9d,
		0x49, 0x1c, 0x98, 0x10, 0x9b, 0x75, 0x26, 0xe6, 0x72, 0x21, 0x38, 0x1c, 0x89, 0x0e, 0x63, 0xc2,
		0xc3, 0x95, 0xf8, 0xb0, 0x27, 0x40, 0xec, 0x89, 0x10, 0x6f, 0x42, 0xc4, 0x83, 0x18, 0x31, 0x21,
		0x48, 0x05, 0x14, 0xdc, 0x9b, 0x81, 0xe0, 0x19, 0xb1, 0x87, 0x41, 0x94, 0x7d, 0xe2, 0x14, 0xaf,
		0x27, 0xf4, 0x63, 0x8b, 0x91, 0xc9, 0x8e, 0x1f, 0x5d, 0x8e, 0x16, 0xfb, 0x94, 0x55, 0x7c, 0xe3,
		0x77, 0x8f, 0x8e, 0x76, 0x14, 0x44, 0xec, 0x12, 0x39, 0x53, 0x5e, 0x3d, 0x63, 0xfe, 0x89, 0x1f,
		0x0e, 0x05, 0x63, 0xfb, 0x0f, 0x12, 0xbf, 0x97, 0x05, 0x71, 0xd4, 0x0c, 0x2e, 0x83, 0x2c, 0x1d,
		0x3d, 0x08, 0x2e, 0xeb, 0x2a, 0xc3, 0x65, 0xfd, 0x5f, 0x70, 0x59, 0xc9, 0x2e, 0xbb, 0xb9, 0xb5,
		0x05, 0xa7, 0x05, 0x11, 0x57, 0xcb, 0x5a, 0x1e, 0xd7, 0xb8, 0xd1, 0x5f, 0x4f, 0x06, 0x49, 0x45,
		0xbb, 0x08, 0xfd, 0xcb, 0x94, 0x5f, 0xeb, 0x37, 0x37, 0x1b, 0x6d, 0xdf, 0x55, 0x98, 0x8b, 0xb6,
		0x6f, 0x89, 0x40, 0x46, 0xdb, 0xb7, 0x3c, 0x37, 0x44, 0xdb, 0x57, 0xf2, 0x03, 0xa0, 0xed, 0x0b,
		0xce, 0x31, 0x81, 0x02, 0xdf, 0xb6, 0xaf, 0x88, 0x86, 0x57, 0x22, 0xc9, 0x05, 0xc8, 0xfc, 0x9a,
		0xbf, 0x1b, 0x75, 0x46, 0x36, 0x9b, 0xd1, 0x70, 0x3c, 0x96, 0x00, 0xd7, 0x5b, 0xe6, 0xaa, 0xda,
		0x41, 0x9a, 0x19, 0x59, 0x96, 0xf0, 0x72, 0xbf, 0xa3, 0x20, 0x32, 0x43, 0x31, 0xca, 0x1e, 0x29,
		0xaf, 0xbe, 0x91, 0x76, 0xe4, 0xff, 0xba, 0x67, 0xf9, 0xc6, 0xa7, 0x7a, 0xbd, 0xb1, 0x5d, 0xaf,
		0xaf, 0x6f, 0x7f, 0xdc, 0x5e, 0xdf, 0xd9, 0xda, 0xda, 0x68, 0x6c, 0x70, 0xda, 0x90, 0x69, 0x27,
		0x7d, 0x91, 0x88, 0xfe, 0xde, 0x8d, 0xb6, 0xbb, 0x16, 0x0d, 0xc3, 0x10, 0xad, 0x82, 0xca, 0xb4,
		0x0a, 0xae, 0x27, 0x3d, 0x4f, 0x66, 0xad, 0x82, 0xdc, 0x6c, 0xb4, 0x0a, 0xd0, 0x2a, 0x40, 0xab,
		0x00, 0xad, 0x02, 0xb4, 0x0a, 0xd0, 0x2a, 0x00, 0xdf, 0x40, 0xab, 0xa0, 0x94, 0x88, 0x3d, 0x0c,
		0xa2, 0xec, 0xe3, 0x26, 0xc3, 0x2e, 0xc1, 0x36, 0x46, 0xc4, 0x56, 0xfc, 0xc2, 0x88, 0x18, 0x88,
		0xf5, 0x0b, 0xcc, 0xc7, 0x88, 0x18, 0xd2, 0xe5, 0x22, 0x2e, 0x8b, 0x11, 0x31, 0xe9, 0x2e, 0x5b,
		0xdf, 0xdc, 0xa9, 0xef, 0x34, 0xb6, 0x37, 0x77, 0x30, 0x29, 0x06, 0x42, 0xae, 0x98, 0xb5, 0x98,
		0x14, 0xab, 0x82, 0x85, 0xd4, 0xb5, 0xd6, 0x4c, 0x0e, 0x7a, 0x2f, 0xec, 0x55, 0xeb, 0x84, 0xe8,
		0x7b, 0x87, 0xd7, 0xde, 0x7b, 0x4f, 0xf9, 0xc4, 0x77, 0xfa, 0x5e, 0x47, 0xd8, 0xe3, 0x98, 0x6c,
		0x03, 0xb1, 0xda, 0xfe, 0x61, 0x42, 0x75, 0x71, 0xe2, 0xd1, 0x2a, 0x81, 0x8a, 0x13, 0x8f, 0x56,
		0xe7, 0x5e, 0x38, 0xf1, 0xa8, 0x6c, 0x4a, 0x86, 0x13, 0x8f, 0xaa, 0xc6, 0xc2, 0xd9, 0x6c, 0xd3,
		0x14, 0x11, 0x37, 0x14, 0xfe, 0x45, 0x22, 0x2e, 0x38, 0x44, 0xdc, 0xe9, 0xf4, 0x26, 0x83, 0x8d,
		0x19, 0xad, 0x33, 0x29, 0x6c, 0x3e, 0x7c, 0xc8, 0x8b, 0x80, 0x5a, 0x4e, 0xc1, 0x50, 0x0a, 0x28,
		0x64, 0x19, 0xd5, 0xf3, 0x62, 0xbf, 0x88, 0x1b, 0xea, 0xa4, 0x9f, 0xc7, 0xfc, 0x2d, 0x9f, 0x79,
		0x5b, 0xd6, 0xf3, 0xb5, 0x3c, 0xe6, 0x69, 0x71, 0xc3, 0xe3, 0xeb, 0xec, 0xac, 0x42, 0xc3, 0x8f,
		0xf2, 0x55, 0x01, 0x2b, 0xbf, 0x1b, 0x2e, 0xff, 0x53, 0x37, 0xe8, 0xe3, 0x8a, 0x4b, 0x8e, 0x16,
		0xe1, 0x8a, 0x4b, 0xc4, 0xb3, 0xfc, 0xf6, 0x3d, 0xdc, 0xe8, 0x48, 0xdd, 0x41, 0x88, 0xde, 0xb8,
		0x40, 0xfa, 0x86, 0x05, 0xdc, 0xe2, 0xf8, 0xd2, 0x16, 0x06, 0x6e, 0x71, 0x7c, 0x8d, 0x89, 0xb8,
		0xc5, 0x71, 0x49, 0x86, 0xe2, 0x16, 0x47, 0x90, 0xce, 0xb2, 0x3e, 0x42, 0xb2, 0xb7, 0x38, 0x66,
		0x94, 0x37, 0x16, 0x8a, 0x70, 0x3c, 0xb6, 0x92, 0xf6, 0xcd, 0x8d, 0xeb, 0xb8, 0xb9, 0x51, 0x39,
		0x3a, 0xc0, 0x88, 0x16, 0x70, 0xa1, 0x07, 0xec, 0x68, 0x02, 0x3b, 0xba, 0xc0, 0x8b, 0x36, 0xd0,
		0xa4, 0x0f, 0x44, 0x69, 0x44, 0xf1, 0xd1, 0x92, 0x1f, 0x07, 0x28, 0x22, 0x66, 0xd0, 0x17, 0x51,
		0x16, 0x64, 0x37, 0xb4, 0x47, 0x01, 0x8a, 0x1a, 0x9e, 0xf2, 0x6e, 0x96, 0x35, 0x59, 0xca, 0x3d,
		0x3f, 0x65, 0x34, 0x22, 0x6a, 0x75, 0xad, 0xae, 0xd7, 0x3d, 0xde, 0x73, 0xed, 0x13, 0xcf, 0xfd,
		0xd6, 0x31, 0xa9, 0x87, 0xf9, 0xb1, 0xb2, 0x28, 0x65, 0x21, 0x79, 0x65, 0x76, 0x56, 0x8c, 0xd5,
		0xf1, 0x1c, 0xd3, 0xd8, 0xff, 0x6c, 0xec, 0x59, 0xb6, 0xe5, 0x7e, 0x9b, 0x80, 0xa2, 0xcb, 0x01,
		0x15, 0x1c, 0xd1, 0xc1, 0x0b, 0x25, 0xcf, 0xa2, 0xa5, 0xe3, 0x98, 0x07, 0xd6, 0x57, 0xef, 0xc0,
		0x36, 0x0e, 0xbb, 0x8c, 0x0e, 0xab, 0x78, 0x0f, 0x9c, 0x94, 0x8b, 0x13, 0xab, 0x73, 0x52, 0xf7,
		0x9c, 0xf6, 0xb1, 0x6b, 0x3a, 0x9e, 0xd5, 0x04, 0x52, 0x80, 0x94, 0x79, 0x48, 0x71, 0x8d, 0x43,
		0xc0, 0x03, 0xf0, 0xf8, 0x0d, 0x3c, 0x1a, 0x75, 0x00, 0x04, 0x00, 0xf9, 0x4d, 0xa6, 0x69, 0x20,
		0xd3, 0x00, 0x29, 0x7f, 0xcc, 0x5d, 0xbb, 0xac, 0x50, 0xc2, 0xc2, 0xd2, 0x33, 0x1c, 0x3e, 0x5b,
		0xf9, 0x3e, 0x02, 0xaf, 0xca, 0x10, 0x78, 0x40, 0x05, 0x08, 0x44, 0xa0, 0xd2, 0x03, 0x0c, 0x50,
		0xd1, 0x01, 0x08, 0xa8, 0xdc, 0x80, 0x08, 0x54, 0x68, 0x40, 0x83, 0x5c, 0x34, 0x4c, 0x42, 0xc1,
		0xbe, 0xd1, 0xc1, 0xde, 0x24, 0x70, 0xb2, 0x10, 0x5e, 0x1c, 0xcf, 0xb0, 0x0f, 0xdb, 0x8e, 0xe5,
		0x7e, 0x3e, 0x42, 0x27, 0x10, 0x48, 0xf9, 0x2d, 0x52, 0xee, 0xfe, 0x84, 0x76, 0xe0, 0x72, 0x5f,
		0x68, 0x07, 0x22, 0x79, 0x73, 0x0b, 0xc6, 0x40, 0x04, 0x82, 0x2e, 0x20, 0xb1, 0xea, 0x7a, 0xaf,
		0x8b, 0xd9, 0x43, 0xa0, 0x64, 0x51, 0xb4, 0xd8, 0x56, 0xeb, 0x0b, 0xb6, 0xf8, 0x01, 0x91, 0xdf,
		0x40, 0xe4, 0xb8, 0xb5, 0xdf, 0x6e, 0x75, 0x5d, 0xc7, 0xb0, 0x5a, 0x66, 0xd3, 0xb3, 0xbb, 0x1d,
		0x80, 0x05, 0x60, 0xf9, 0x6d, 0x3c, 0x31, 0x5c, 0xd7, 0xb1, 0xf6, 0x8e, 0x5d, 0x13, 0xe3, 0xcc,
		0x80, 0xca, 0x5c, 0xa8, 0x8c, 0xb7, 0x2a, 0x5a, 0xa6, 0x75, 0xf8, 0x79, 0xaf, 0xed, 0x78, 0x46,
		0xb3, 0xe9, 0x98, 0x5d, 0x00, 0x06, 0x80, 0xf9, 0x1d, 0x60, 0xea, 0x9e, 0xd5, 0x72, 0x4d, 0xe7,
		0xc0, 0xd8, 0x37, 0x81, 0x18, 0x20, 0xe6, 0x59, 0xea, 0xe2, 0x5a, 0xb6, 0xf5, 0x5f, 0xb3, 0xe9,
		0xed, 0x19, 0xad, 0xe6, 0x7f, 0xac, 0xa6, 0xfb, 0x19, 0x68, 0x01, 0x5a, 0x7e, 0xcb, 0x5d, 0x3a,
		0x4e, 0xdb, 0x35, 0xf7, 0x5d, 0xab, 0xdd, 0xca, 0x2b, 0x68, 0xe0, 0x05, 0x78, 0x99, 0x83, 0x17,
		0xc7, 0xec, 0x5a, 0xcd, 0x63, 0xc3, 0x46, 0x74, 0x01, 0x5a, 0x9e, 0x47, 0xcb, 0x91, 0xf1, 0x35,
		0x8f, 0x30, 0x40, 0x0b, 0xd0, 0xf2, 0x67, 0xc5, 0x11, 0xb8, 0x2e, 0x10, 0xf3, 0xa2, 0xf8, 0xe2,
		0x98, 0x5d, 0xd3, 0x39, 0x31, 0xf6, 0x6c, 0x13, 0x51, 0x06, 0x98, 0xf9, 0x43, 0xc6, 0x6b, 0xb7,
		0x11, 0x58, 0x00, 0x92, 0x67, 0x40, 0xd2, 0x34, 0x6d, 0xe3, 0x9b, 0x77, 0x62, 0x38, 0x96, 0x31,
		0xaa, 0x8d, 0x80, 0x17, 0xe0, 0x65, 0x1e, 0x5e, 0x8c, 0xe6, 0xbf, 0x3d, 0xdb, 0x68, 0x31, 0xd3,
		0x84, 0x02, 0x26, 0x65, 0xc3, 0xe4, 0xc4, 0xb0, 0x6c, 0x50, 0x15, 0xc0, 0xe5, 0xcf, 0xa3, 0x0a,
		0x22, 0x0a, 0x20, 0xf2, 0xbb, 0x0a, 0xc8, 0x6a, 0xdd, 0x75, 0x59, 0xc6, 0x84, 0x05, 0x68, 0x01,
		0x5a, 0xe6, 0x8f, 0xb5, 0xe4, 0xd5, 0x32, 0x76, 0x87, 0x80, 0x97, 0x3f, 0xc1, 0x4b, 0x01, 0x12,
		0xaf, 0x18, 0x87, 0x72, 0x51, 0x37, 0x03, 0x30, 0x73, 0x01, 0x63, 0x7e, 0x75, 0xcd, 0x56, 0xd3,
		0x6c, 0x7a, 0x46, 0x73, 0x94, 0x99, 0x0e, 0x9d, 0xf6, 0x31, 0x46, 0xe7, 0x80, 0x97, 0xdf, 0x30,
		0x5c, 0xc0, 0x04, 0x30, 0x79, 0x16, 0x26, 0xe3, 0x29, 0x28, 0x8c, 0xcd, 0x01, 0x30, 0x7f, 0x0a,
		0x18, 0x94, 0x43, 0x40, 0xc9, 0xf3, 0x28, 0x71, 0x4d, 0xaf, 0x69, 0x1e, 0x18, 0xc7, 0xb6, 0xeb,
		0x1d, 0x99, 0xae, 0x63, 0xed, 0x43, 0xc0, 0xbb, 0xdc, 0x17, 0x04, 0xbc, 0x95, 0x71, 0x36, 0xfe,
		0x6a, 0x2b, 0x40, 0x61, 0xd5, 0x50, 0x60, 0xa8, 0xaa, 0x02, 0x28, 0x4a, 0x89, 0x0f, 0x9c, 0xd4,
		0x53, 0x80, 0x44, 0x09, 0xe5, 0x1e, 0x47, 0x95, 0x14, 0x80, 0x51, 0x4a, 0x1f, 0x80, 0xe1, 0x84,
		0x28, 0x90, 0xb1, 0x72, 0x6a, 0xc1, 0x50, 0xf5, 0x04, 0x54, 0x94, 0xc2, 0x2d, 0xd8, 0xa9, 0x9b,
		0x80, 0x8b, 0x55, 0xe3, 0x82, 0xa3, 0x8a, 0x09, 0xa8, 0x58, 0x35, 0x2a, 0x38, 0xaa, 0x95, 0x80,
		0x8a, 0x52, 0x8a, 0x11, 0x70, 0x4e, 0x20, 0x43, 0x21, 0xf5, 0x11, 0xb0, 0x51, 0x0a, 0xf3, 0xe4,
		0xa1, 0x32, 0x02, 0x18, 0x4a, 0x01, 0x03, 0x3b, 0x35, 0x11, 0x70, 0xb1, 0x6a, 0x5c, 0xb0, 0x52,
		0x0d, 0x01, 0x0e, 0x2b, 0x87, 0x03, 0x47, 0x75, 0x10, 0x60, 0x51, 0x46, 0x94, 0x40, 0x84, 0x00,
		0x14, 0x98, 0xaa, 0x7d, 0x80, 0x8a, 0x55, 0xa3, 0x82, 0xa7, 0xaa, 0x07, 0xb8, 0x58, 0x35, 0x2e,
		0x98, 0xaa, 0x77, 0x00, 0x8c, 0x55, 0x03, 0x83, 0xa7, 0x4a, 0x07, 0xb8, 0x58, 0x3d, 0xd3, 0x04,
		0x1c, 0x00, 0x07, 0xee, 0xaa, 0x1b, 0x00, 0x63, 0xd5, 0xc0, 0x40, 0xf9, 0x01, 0x34, 0xb0, 0x56,
		0xd1, 0xd0, 0x56, 0xcf, 0xd0, 0x55, 0xcd, 0xd0, 0x5c, 0x37, 0x7a, 0x56, 0xd1, 0xb2, 0x88, 0x58,
		0x08, 0xd4, 0x8c, 0x28, 0x8a, 0x33, 0x3f, 0x0b, 0xe2, 0x48, 0xdb, 0x25, 0x18, 0xfc, 0xb4, 0xb4,
		0xf7, 0x5d, 0x5c, 0xf9, 0x03, 0x3f, 0xfb, 0x3e, 0x0a, 0x77, 0xb5, 0x78, 0x20, 0xa2, 0x5e, 0x1c,
		0x5d, 0x04, 0x97, 0x7a, 0x24, 0xb2, 0x9f, 0x71, 0xf2, 0x43, 0x0f, 0xa2, 0x34, 0xf3, 0xa3, 0x9e,
		0xa8, 0x3d, 0xfe, 0x46, 0x3a, 0xf3, 0x9d, 0xda, 0x20, 0x89, 0xb3, 0xb8, 0x17, 0x87, 0x69, 0xf1,
		0xae, 0x16, 0xa4, 0x41, 0x5a, 0x0b, 0xc5, 0xb5, 0x08, 0x27, 0x5f, 0x6a, 0x61, 0x10, 0xfd, 0xd0,
		0xd3, 0xcc, 0xcf, 0x84, 0xde, 0xf7, 0x33, 0xff, 0xdc, 0x4f, 0x45, 0x2d, 0x4c, 0x07, 0xb5, 0x2c,
		0xbc, 0x4e, 0x47, 0xff, 0xa9, 0x89, 0x5f, 0x99, 0x88, 0xfa, 0xa2, 0xaf, 0x07, 0x83, 0xeb, 0xba,
		0x9e, 0x08, 0xbf, 0xf7, 0xdd, 0x3f, 0x0f, 0xc2, 0x20, 0xbb, 0xa9, 0x0d, 0x12, 0x71, 0x11, 0xfc,
		0x12, 0xe9, 0xe4, 0x4d, 0x2d, 0x1d, 0x9e, 0x8f, 0x7f, 0x2c, 0xff, 0x5a, 0x1b, 0xff, 0xab, 0xb4,
		0x42, 0x32, 0x1d, 0xf7, 0x20, 0xe4, 0x1a, 0x5a, 0xe6, 0x5f, 0x92, 0xf3, 0x87, 0x22, 0xe9, 0x8f,
		0x8c, 0x23, 0x16, 0x46, 0xbe, 0x04, 0x51, 0x5f, 0xdb, 0x5d, 0xdb, 0x20, 0x66, 0xd6, 0xfe, 0x38,
		0x54, 0x68, 0xbb, 0x6b, 0xeb, 0xc4, 0x0c, 0xeb, 0x8c, 0xc3, 0x03, 0xcd, 0x90, 0x3b, 0x85, 0x59,
		0xdc, 0xd3, 0x47, 0xc1, 0x91, 0xe0, 0x1d, 0x8e, 0x5a, 0x37, 0x1e, 0x26, 0x3d, 0x41, 0x72, 0xf9,
		0x72, 0x77, 0x10, 0x37, 0x3f, 0xe3, 0x64, 0xe4, 0x11, 0x5a, 0x9e, 0x08, 0x88, 0x5e, 0x84, 0xa9,
		0x7d, 0xf6, 0x53, 0x23, 0xb9, 0x1c, 0x5e, 0x89, 0x28, 0xd3, 0x76, 0xd7, 0xb2, 0x64, 0x28, 0x88,
		0x1a, 0x7a, 0xcf, 0xca, 0x02, 0x98, 0xa0, 0x9a, 0xac, 0xa8, 0x66, 0x33, 0x48, 0x88, 0x72, 0xcc,
		0x31, 0x2b, 0x23, 0x1b, 0x4c, 0xa6, 0xf1, 0x38, 0x37, 0x93, 0xa8, 0x7f, 0xd2, 0x24, 0x00, 0xe4,
		0x89, 0x00, 0x07, 0x42, 0xc0, 0x88, 0x18, 0x70, 0x21, 0x08, 0xec, 0x88, 0x02, 0x3b, 0xc2, 0xc0,
		0x8b, 0x38, 0xd0, 0x24, 0x10, 0x44, 0x89, 0x04, 0x79, 0x42, 0x71, 0xbf, 0x8b, 0xf0, 0x71, 0x93,
		0x7e, 0x10, 0xba, 0xd7, 0x57, 0xf8, 0xb8, 0x49, 0x3d, 0x00, 0x4d, 0x88, 0xc6, 0x3a, 0x71, 0x33,
		0xa9, 0x13, 0x0e, 0x4e, 0xc4, 0x83, 0x21, 0x01, 0xe1, 0x46, 0x44, 0xd8, 0x12, 0x12, 0xb6, 0xc4,
		0x84, 0x27, 0x41, 0xa1, 0x4d, 0x54, 0x88, 0x13, 0x96, 0xe2, 0x23, 0x77, 0x6f, 0x06, 0x82, 0x57,
		0xc4, 0x1d, 0x06, 0x51, 0x46, 0x9e, 0x1b, 0xdc, 0xe7, 0x07, 0xdb, 0x0c, 0x4c, 0x75, 0xfc, 0xe8,
		0x72, 0xb4, 0xba, 0xa7, 0x2c, 0x02, 0x15, 0x9f, 0x73, 0x66, 0xb5, 0xa3, 0x20, 0x62, 0x93, 0x71,
		0x99, 0x11, 0xdb, 0x19, 0xb3, 0x4f, 0xfc, 0x70, 0x28, 0x18, 0xda, 0x7d, 0x90, 0xf8, 0xbd, 0x2c,
		0x88, 0xa3, 0x66, 0x70, 0x19, 0x64, 0xe9, 0xe8, 0x01, 0x70, 0x38, 0xf5, 0x2a, 0x5c, 0xd1, 0xff,
		0x05, 0x57, 0x2c, 0xd9, 0x15, 0xeb, 0x9b, 0x3b, 0xf5, 0x9d, 0xc6, 0xf6, 0xe6, 0xce, 0x16, 0x7c,
		0x12, 0x84, 0x98, 0x97, 0x95, 0x67, 0x28, 0x2c, 0x5e, 0xe1, 0x40, 0x76, 0x90, 0x66, 0x46, 0x96,
		0x25, 0x3c, 0x8a, 0x8b, 0xa3, 0x20, 0x32, 0x43, 0x31, 0xaa, 0x7d, 0x53, 0x1e, 0xd1, 0x76, 0x94,
		0xcd, 0xee, 0x59, 0xbc, 0xf1, 0xa9, 0x5e, 0x6f, 0x6c, 0xd7, 0xeb, 0xeb, 0xdb, 0x1f, 0xb7, 0xd7,
		0x77, 0xb6, 0xb6, 0x36, 0x1a, 0x1b, 0x0c, 0x22, 0xae, 0xd6, 0x4e, 0xfa, 0x22, 0x11, 0xfd, 0xbd,
		0x1b, 0x6d, 0x77, 0x2d, 0x1a, 0x86, 0xe1, 0x1b, 0x44, 0x2c, 0x75, 0x2c, 0xa3, 0xba, 0x57, 0x43,
		0x7c, 0xce, 0xb8, 0xb0, 0x53, 0xad, 0x79, 0xe3, 0xcc, 0xbf, 0xa4, 0x38, 0x73, 0x4c, 0xd7, 0x85,
		0x30, 0xc1, 0xc5, 0xd8, 0x89, 0xd5, 0x73, 0x5e, 0x8a, 0xb3, 0xb7, 0x69, 0x96, 0x0c, 0x7b, 0x59,
		0x34, 0x69, 0x0c, 0xb7, 0xf2, 0x55, 0xb3, 0x26, 0x8b, 0xe6, 0x75, 0x26, 0x4b, 0xe5, 0x59, 0x69,
		0x90, 0x7a, 0xf6, 0x68, 0x8d, 0x3c, 0x3b, 0x1d, 0x78, 0x6e, 0x78, 0xed, 0x99, 0x93, 0xa5, 0xb0,
		0x06, 0xd7, 0x75, 0xe7, 0xde, 0x42, 0x78, 0xf9, 0x1e, 0xa4, 0xd7, 0x1d, 0x3f, 0xb7, 0xe7, 0xfa,
		0x97, 0x90, 0x48, 0x90, 0x0f, 0x08, 0x5a, 0xe6, 0x5f, 0x36, 0xea, 0xa4, 0x45, 0x12, 0x8d, 0x3a,
		0x64, 0x12, 0x7f, 0x64, 0x16, 0x64, 0x12, 0xaf, 0x00, 0x1a, 0x64, 0x12, 0x8b, 0xbb, 0x03, 0x64,
		0x12, 0xcb, 0x66, 0x68, 0x90, 0x49, 0x70, 0x27, 0xd9, 0x90, 0x49, 0xbc, 0x2e, 0x1e, 0x43, 0x26,
		0xa1, 0x1e, 0x11, 0xe0, 0x40, 0x08, 0x18, 0x11, 0x03, 0x2e, 0x04, 0x81, 0x1d, 0x51, 0x60, 0x47,
		0x18, 0x78, 0x11, 0x07, 0x9a, 0x04, 0x82, 0x28, 0x91, 0x20, 0x4f, 0x28, 0x88, 0x77, 0x12, 0x58,
		0x75, 0x16, 0xe6, 0x11, 0x0d, 0xc8, 0x24, 0xaa, 0x43, 0x3c, 0x18, 0x12, 0x10, 0x6e, 0x44, 0x84,
		0x2d, 0x21, 0x61, 0x4b, 0x4c, 0x78, 0x12, 0x14, 0xda, 0x44, 0x85, 0x38, 0x61, 0x29, 0x3e, 0x72,
		0x9e, 0x32, 0x09, 0xf2, 0xdc, 0xe0, 0x3e, 0x3f, 0xf8, 0x04, 0x99, 0xc4, 0x92, 0x5f, 0x90, 0x49,
		0x80, 0xd8, 0x3e, 0x61, 0x36, 0x64, 0x12, 0x48, 0x6f, 0xbf, 0x73, 0x45, 0xc8, 0x24, 0x4a, 0x77,
		0x45, 0x9e, 0xe3, 0xbb, 0xca, 0x78, 0x27, 0x04, 0x13, 0x4b, 0x79, 0x41, 0x30, 0xf1, 0x1a, 0x07,
		0x82, 0x60, 0x62, 0xe5, 0x79, 0x0d, 0x82, 0x09, 0x44, 0x2c, 0xc2, 0x96, 0x41, 0x30, 0xf1, 0x3a,
		0x3b, 0x95, 0x9b, 0xb9, 0x6e, 0xd4, 0x21, 0x99, 0xe0, 0x6b, 0x11, 0x24, 0x13, 0x95, 0x77, 0xdf,
		0xaa, 0x8a, 0x26, 0x1a, 0x75, 0xc8, 0x26, 0xc8, 0x07, 0x05, 0x2d, 0xa3, 0xb8, 0xa9, 0x71, 0x37,
		0xdb, 0x30, 0xb2, 0x8e, 0xa6, 0x68, 0x62, 0x1d, 0xa2, 0x89, 0x3f, 0x33, 0x0c, 0xa2, 0x89, 0x57,
		0x99, 0x08, 0xd1, 0xc4, 0x92, 0x0c, 0x85, 0x68, 0x02, 0x34, 0xbb, 0xac, 0x8f, 0x90, 0xec, 0xa8,
		0x40, 0x11, 0xf1, 0x42, 0xe1, 0x5f, 0x24, 0xe2, 0x82, 0x62, 0xc4, 0x9b, 0x8a, 0x12, 0x08, 0x9e,
		0x99, 0xa8, 0x75, 0x26, 0x95, 0xc9, 0x87, 0x0f, 0x79, 0x55, 0x5e, 0x1b, 0x33, 0x14, 0xf0, 0x5c,
		0xc2, 0x96, 0x10, 0x89, 0x0d, 0xa3, 0x44, 0x49, 0x8c, 0xd2, 0xd2, 0xdc, 0x6e, 0xa0, 0xbb, 0xad,
		0xc0, 0x6a, 0xfb, 0x80, 0xe6, 0x36, 0x01, 0x15, 0x67, 0x24, 0xda, 0x07, 0x53, 0xab, 0xff, 0x45,
		0x88, 0x5c, 0xac, 0xbc, 0xe3, 0x45, 0x83, 0x03, 0xc8, 0xcf, 0xb8, 0x72, 0x2d, 0x90, 0x1c, 0x5e,
		0xa8, 0x85, 0x15, 0x45, 0xc2, 0x89, 0x5c, 0xdf, 0x92, 0x87, 0x68, 0x89, 0x68, 0xd6, 0x86, 0x51,
		0x5f, 0x5c, 0x04, 0x91, 0xe8, 0xeb, 0xd3, 0x0f, 0x41, 0x36, 0xa0, 0xef, 0xa6, 0xda, 0x67, 0x4c,
		0x93, 0xec, 0xf5, 0x34, 0x54, 0xf4, 0x64, 0x3a, 0xc0, 0x94, 0x3a, 0xbe, 0x04, 0x3b, 0xbc, 0xd4,
		0x3a, 0xba, 0x64, 0x3b, 0xb8, 0x64, 0x3b, 0xb6, 0x34, 0x3b, 0xb4, 0xd5, 0x66, 0x5e, 0x54, 0x54,
		0xe5, 0x33, 0xd9, 0x89, 0x8e, 0x9f, 0xcf, 0xcb, 0x9f, 0x54, 0xdc, 0x9d, 0xd6, 0x61, 0x34, 0xe4,
		0x36, 0x54, 0x29, 0x6e, 0xa4, 0x12, 0xde, 0x40, 0xa5, 0xba, 0x71, 0x4a, 0x7e, 0xc3, 0x94, 0xfc,
		0x46, 0x29, 0xed, 0x0d, 0x52, 0x6c, 0x7a, 0x50, 0x4c, 0xcb, 0x77, 0x1d, 0x11, 0x92, 0xa7, 0xc6,
		0x91, 0x3e, 0x2d, 0x0e, 0xc7, 0xc4, 0xf2, 0x4f, 0xd4, 0x0c, 0x12, 0x36, 0xf5, 0xc4, 0xcd, 0x26,
		0x81, 0xb3, 0x49, 0xe4, 0x3c, 0x12, 0x3a, 0xad, 0xc4, 0x4e, 0x2c, 0xc1, 0x93, 0x4d, 0xf4, 0x85,
		0x61, 0xa1, 0x88, 0x2e, 0xc7, 0xdb, 0x1f, 0xc4, 0xcf, 0x89, 0x9d, 0xd8, 0x49, 0xfb, 0xa0, 0xd8,
		0x75, 0x1c, 0x14, 0xab, 0x1c, 0x25, 0x60, 0x44, 0x0d, 0xb8, 0x50, 0x04, 0x76, 0x54, 0x81, 0x1d,
		0x65, 0xe0, 0x45, 0x1d, 0x68, 0x52, 0x08, 0xa2, 0x54, 0xa2, 0xf8, 0x68, 0xc9, 0x9f, 0xb7, 0xf6,
		0xe0, 0x9c, 0xb5, 0x4f, 0x94, 0xe3, 0xe5, 0x24, 0x7d, 0x13, 0x3e, 0xdd, 0x80, 0xc9, 0xb1, 0x6a,
		0x3c, 0x4e, 0xe5, 0x60, 0x74, 0x70, 0x29, 0xab, 0x33, 0x9b, 0xb8, 0x1d, 0x9b, 0xc6, 0xf1, 0x40,
		0xa6, 0x5b, 0x1e, 0xc7, 0xc8, 0xc0, 0xc5, 0x56, 0xec, 0x62, 0x9b, 0x5b, 0x5b, 0x70, 0xb2, 0x6a,
		0x11, 0x51, 0xfa, 0xd6, 0x9d, 0xe1, 0x10, 0x16, 0xae, 0x41, 0x9c, 0xe6, 0x49, 0x07, 0x33, 0xa5,
		0x04, 0xc1, 0x13, 0x0f, 0x98, 0x64, 0x12, 0x34, 0x01, 0x97, 0x89, 0x43, 0x34, 0x01, 0x97, 0xe7,
		0x36, 0x68, 0x02, 0xae, 0xd8, 0x60, 0x34, 0x01, 0x55, 0x2d, 0xbb, 0xd0, 0x04, 0x5c, 0x7a, 0xfa,
		0x46, 0x13, 0xf0, 0xb5, 0x2f, 0x34, 0x01, 0xd1, 0xa1, 0x40, 0x13, 0xb0, 0x82, 0xd9, 0xe8, 0xa1,
		0x8b, 0xa1, 0x09, 0xb8, 0x72, 0x17, 0x43, 0x13, 0xb0, 0x72, 0x44, 0x94, 0xbe, 0x75, 0x68, 0x02,
		0xb2, 0x0d, 0xe2, 0xda, 0xf5, 0x24, 0xb0, 0x10, 0xef, 0x02, 0xe6, 0x66, 0xa2, 0x0d, 0xb8, 0x88,
		0x79, 0x68, 0x03, 0x2e, 0x11, 0x88, 0x68, 0x03, 0x2e, 0xcf, 0x6d, 0xd0, 0x06, 0x5c, 0xb1, 0xc1,
		0x68, 0x03, 0xaa, 0x5a, 0x78, 0x31, 0x6a, 0x03, 0x9e, 0x07, 0x91, 0x9f, 0xdc, 0x30, 0xe8, 0x03,
		0xee, 0x80, 0xc6, 0x32, 0xb4, 0x08, 0x17, 0x8a, 0xbc, 0xcc, 0x3e, 0xe6, 0x27, 0xa0, 0xcd, 0x9c,
		0x75, 0x35, 0xf3, 0x1d, 0x8a, 0xb7, 0x03, 0xe1, 0xaa, 0x8d, 0xa7, 0xa0, 0x88, 0xab, 0x36, 0xd4,
		0xa8, 0x34, 0x21, 0x3c, 0x57, 0xb3, 0xa2, 0x84, 0xf0, 0xbc, 0x6a, 0x95, 0x23, 0x84, 0xe7, 0xfc,
		0x09, 0x28, 0xae, 0xda, 0x78, 0x7d, 0x82, 0xc5, 0x55, 0x1b, 0xec, 0x79, 0x2e, 0x4e, 0x9d, 0x7a,
		0x98, 0x28, 0x71, 0xd5, 0xc6, 0x9f, 0x58, 0x85, 0xab, 0x36, 0x96, 0x62, 0x2c, 0xae, 0xda, 0xe0,
		0xd7, 0x21, 0x52, 0xbf, 0x33, 0x54, 0x8d, 0xeb, 0x37, 0x8e, 0xa7, 0x4f, 0x8d, 0x7b, 0x38, 0xe8,
		0x58, 0x80, 0x7b, 0x38, 0xd4, 0x8e, 0x35, 0x95, 0xbd, 0x91, 0xe3, 0x4d, 0x85, 0xbc, 0x69, 0x4a,
		0xa3, 0xa5, 0xf6, 0x9a, 0x68, 0x10, 0x67, 0x3a, 0x44, 0x99, 0x34, 0x31, 0xa6, 0x41, 0x84, 0x65,
		0xb9, 0x0b, 0x91, 0xa4, 0xc3, 0x3c, 0xd9, 0x48, 0x64, 0xad, 0xab, 0x63, 0xa9, 0x72, 0xf2, 0x65,
		0xf9, 0xd9, 0xaa, 0xdc, 0xdf, 0x58, 0xb2, 0xa3, 0xcb, 0x76, 0x70, 0xae, 0x8e, 0x5d, 0x2e, 0xf8,
		0xcb, 0x83, 0x60, 0x39, 0xbf, 0xa9, 0x24, 0x90, 0xcb, 0x02, 0x37, 0x33, 0x50, 0x97, 0x98, 0x9d,
		0x56, 0x90, 0x8d, 0xca, 0xf1, 0xc4, 0xd5, 0xfb, 0x45, 0x09, 0x3e, 0xa1, 0xdd, 0x61, 0x20, 0x7d,
		0x88, 0x80, 0xb2, 0xbc, 0xa3, 0xd8, 0x3f, 0x9c, 0x6b, 0x49, 0x49, 0x91, 0xa1, 0xdc, 0xeb, 0x1f,
		0x4a, 0x9f, 0xae, 0x91, 0x31, 0x35, 0x23, 0x71, 0x1a, 0x46, 0xd6, 0x94, 0x8b, 0xf4, 0xe9, 0x15,
		0xe9, 0x53, 0x29, 0x72, 0xa7, 0x4d, 0xd4, 0x62, 0x2b, 0x65, 0x5f, 0x37, 0xa0, 0x45, 0x22, 0xb8,
		0xfc, 0x7e, 0x1e, 0x27, 0xe5, 0xdf, 0x83, 0x5b, 0xc4, 0x8a, 0x3b, 0x13, 0x4a, 0xc6, 0xad, 0x9c,
		0xfb, 0x7f, 0xa4, 0x8d, 0x59, 0xca, 0x1c, 0xa3, 0x24, 0x30, 0x26, 0x29, 0x7b, 0x0c, 0x92, 0xcc,
		0x98, 0x23, 0x99, 0x31, 0x46, 0x1a, 0x63, 0x8a, 0x6a, 0xf7, 0x76, 0x64, 0xdd, 0x5f, 0x53, 0x44,
		0x75, 0x79, 0xfe, 0xf6, 0x38, 0xbf, 0xc8, 0x72, 0x37, 0xb9, 0xd7, 0xcc, 0x49, 0x9f, 0xea, 0xa7,
		0x30, 0xbd, 0x4f, 0x68, 0x4a, 0x9f, 0xca, 0x34, 0x3e, 0xb9, 0xa9, 0x7b, 0x72, 0xd3, 0xf5, 0xb4,
		0xa6, 0xe8, 0xab, 0xb5, 0x45, 0x2f, 0xfb, 0xda, 0x35, 0xad, 0xe8, 0xc5, 0xca, 0x77, 0xd4, 0x69,
		0xec, 0xba, 0x33, 0x49, 0xb2, 0x5f, 0xd0, 0xb8, 0x37, 0x95, 0x8c, 0x5c, 0x8d, 0x92, 0x3c, 0x8d,
		0xa0, 0x1c, 0x8d, 0x9a, 0xfc, 0x8c, 0xac, 0xdc, 0x8c, 0xac, 0xbc, 0x8c, 0xa6, 0x9c, 0xac, 0xda,
		0x93, 0xa0, 0x54, 0xee, 0x25, 0x2d, 0xb2, 0x12, 0x1d, 0xff, 0x7e, 0x9c, 0x2f, 0xa9, 0xb8, 0x37,
		0xad, 0xeb, 0xc6, 0xc9, 0xa9, 0xbd, 0x29, 0xaa, 0xbc, 0x09, 0xab, 0xbb, 0xa9, 0xaa, 0xba, 0xc9,
		0xab, 0xb9, 0xc9, 0xab, 0xb8, 0x69, 0xab, 0xb7, 0xa1, 0xc8, 0xa4, 0x98, 0x86, 0xef, 0xd2, 0x71,
		0x9f, 0xee, 0x51, 0x2c, 0x41, 0x1f, 0x07, 0xb1, 0xb0, 0x4c, 0xcd, 0x94, 0x53, 0x34, 0x83, 0x54,
		0x4d, 0x3d, 0x65, 0xb3, 0x49, 0xdd, 0x6c, 0x52, 0x38, 0x8f, 0x54, 0x4e, 0x2b, 0xa5, 0x13, 0x4b,
		0xed, 0xc5, 0x47, 0x88, 0x83, 0x58, 0x96, 0x50, 0xf3, 0xb2, 0x38, 0x88, 0x25, 0xe8, 0xe3, 0x18,
		0x16, 0xf2, 0x3e, 0xa9, 0xe5, 0xe7, 0x42, 0x92, 0x25, 0xb9, 0xb9, 0x79, 0x34, 0x79, 0xee, 0x06,
		0x78, 0x2e, 0x78, 0x2e, 0x78, 0x2e, 0x78, 0x2e, 0x78, 0x2e, 0x72, 0xea, 0xe3, 0x8f, 0x90, 0x5a,
		0x2b, 0xab, 0x30, 0x8c, 0x60, 0x4b, 0x6b, 0x26, 0x18, 0x93, 0x6b, 0x6d, 0x3d, 0x4e, 0xfd, 0xb8,
		0xd5, 0x46, 0x3d, 0x2a, 0xc0, 0x88, 0x12, 0x70, 0xa1, 0x06, 0xec, 0x28, 0x02, 0x3b, 0xaa, 0xc0,
		0x8b, 0x32, 0xd0, 0xa4, 0x0e, 0x44, 0x29, 0x44, 0xf1, 0xd1, 0xf2, 0xba, 0xdc, 0xba, 0x51, 0x67,
		0x70, 0xab, 0xcd, 0x27, 0xdc, 0x6e, 0xfd, 0xca, 0x17, 0x6e, 0xb7, 0xae, 0x12, 0xb1, 0x9c, 0x31,
		0x17, 0xb7, 0x5b, 0x57, 0x35, 0x1d, 0x3d, 0x74, 0x31, 0xdc, 0x6e, 0xbd, 0x72, 0x17, 0xa3, 0x7d,
		0xaa, 0xb5, 0x72, 0x5e, 0x87, 0xeb, 0xae, 0x17, 0x7a, 0xe1, 0xba, 0x6b, 0xb6, 0x51, 0x5d, 0xbb,
		0x12, 0x59, 0x12, 0xf4, 0xe8, 0xb7, 0x05, 0x27, 0x76, 0xa2, 0x35, 0xb8, 0x88, 0x79, 0x68, 0x0d,
		0x2e, 0x11, 0x89, 0x68, 0x0d, 0x2e, 0xcf, 0x6d, 0xd0, 0x1a, 0x5c, 0xb1, 0xc1, 0x68, 0x0d, 0xaa,
		0x5a, 0x8b, 0x31, 0x6a, 0x0d, 0xfe, 0x0c, 0xfa, 0x42, 0x27, 0x9d, 0xc0, 0xef, 0x27, 0xf1, 0x6d,
		0xf4, 0x07, 0x5f, 0xf9, 0x42, 0x7f, 0x10, 0xcd, 0x0b, 0x7a, 0x33, 0x72, 0x4a, 0x75, 0x2a, 0xd0,
		0x1f, 0x84, 0x8b, 0x8d, 0x5c, 0xac, 0xb1, 0xbd, 0xbd, 0xbd, 0x89, 0x9e, 0x60, 0xd5, 0x38, 0x29,
		0x7d, 0xeb, 0xd0, 0x13, 0xe4, 0x68, 0x11, 0xb5, 0x49, 0x4a, 0xa2, 0x37, 0x43, 0x16, 0xf6, 0xd1,
		0xbe, 0x9a, 0xe0, 0xe1, 0x61, 0xf0, 0xb5, 0xe2, 0x74, 0xe0, 0xe2, 0x5d, 0xed, 0xce, 0x98, 0xc2,
		0x88, 0x5c, 0x75, 0x01, 0xf5, 0x0e, 0x75, 0xff, 0xd0, 0xa6, 0x17, 0xed, 0xd1, 0xd5, 0xef, 0x4c,
		0x0c, 0x84, 0x82, 0xe7, 0x4f, 0xcc, 0x82, 0x82, 0xe7, 0x15, 0x50, 0x83, 0x82, 0x67, 0x71, 0x77,
		0x80, 0x82, 0x67, 0xd9, 0xa4, 0x05, 0x0a, 0x1e, 0xee, 0xbc, 0x93, 0xac, 0x82, 0x67, 0x72, 0x6f,
		0x37, 0xf9, 0xed, 0x7a, 0x72, 0xf7, 0x8b, 0x33, 0xa0, 0x00, 0xe4, 0xa9, 0x00, 0x07, 0x4a, 0xc0,
		0x88, 0x1a, 0x70, 0xa1, 0x08, 0xec, 0xa8, 0x02, 0x3b, 0xca, 0xc0, 0x8b, 0x3a, 0xd0, 0xa4, 0x10,
		0x44, 0xa9, 0x04, 0x79, 0x4a, 0x51, 0x18, 0xe8, 0xf7, 0xff, 0x9f, 0xdf, 0x13, 0x51, 0xef, 0x46,
		0x4f, 0x83, 0x7e, 0x4a, 0x3f, 0x1a, 0x4d, 0x03, 0xfc, 0x23, 0xbb, 0x89, 0x7b, 0x38, 0x6d, 0xea,
		0xc1, 0x86, 0x82, 0x70, 0xa2, 0x22, 0x0c, 0x29, 0x09, 0x37, 0x6a, 0xc2, 0x96, 0xa2, 0xb0, 0xa5,
		0x2a, 0x3c, 0x29, 0x0b, 0x6d, 0xea, 0x42, 0x9c, 0xc2, 0xb0, 0xa1, 0x32, 0x4f, 0x53, 0x1a, 0x3e,
		0x41, 0xec, 0x49, 0x66, 0xc3, 0x25, 0x90, 0xf1, 0x20, 0x38, 0xec, 0x88, 0x0e, 0x47, 0xc2, 0xc3,
		0x98, 0xf8, 0x70, 0x25, 0x40, 0xec, 0x89, 0x10, 0x7b, 0x42, 0xc4, 0x9b, 0x18, 0xf1, 0x20, 0x48,
		0x4c, 0x88, 0x12, 0x3b, 0xc2, 0x54, 0x18, 0x4c, 0xf3, 0x64, 0xd8, 0x3f, 0xce, 0x33, 0x14, 0x4f,
		0x8e, 0x55, 0x8c, 0x38, 0xb1, 0x25, 0x50, 0x9c, 0x89, 0x94, 0x02, 0x84, 0x8a, 0x3b, 0xb1, 0x52,
		0x86, 0x60, 0x29, 0x43, 0xb4, 0xd4, 0x20, 0x5c, 0xbc, 0x88, 0x17, 0x33, 0x02, 0xc6, 0x96, 0x88,
		0x15, 0x86, 0x5f, 0x84, 0xfe, 0x65, 0xca, 0x37, 0x58, 0x4e, 0xf3, 0x55, 0xfe, 0x18, 0x4c, 0xe3,
		0x0b, 0x2f, 0x8d, 0x98, 0x32, 0x44, 0x4d, 0x05, 0xc2, 0xa6, 0x10, 0x71, 0x53, 0x85, 0xc0, 0x29,
		0x47, 0xe4, 0x94, 0x23, 0x74, 0x6a, 0x11, 0x3b, 0x9e, 0x04, 0x8f, 0x29, 0xd1, 0x2b, 0xa0, 0x43,
		0xfe, 0x90, 0x94, 0x3f, 0xce, 0x18, 0x22, 0x1a, 0x5e, 0x89, 0x24, 0xd7, 0x42, 0x32, 0xce, 0x1a,
		0xd3, 0x2e, 0x57, 0x9d, 0xf1, 0x33, 0x98, 0xd1, 0xf0, 0x6a, 0x04, 0x2a, 0xb8, 0x72, 0x99, 0xab,
		0x6e, 0x07, 0x69, 0x66, 0x64, 0x59, 0xc2, 0xdb, 0x9d, 0x8f, 0x82, 0xc8, 0x0c, 0xc5, 0x28, 0x9b,
		0xa5, 0x7c, 0xa9, 0xf8, 0xda, 0xe4, 0x7c, 0x8f, 0x7b, 0x4f, 0xc2, 0xf7, 0xa4, 0xda, 0x27, 0x1f,
		0xae, 0x9d, 0xf4, 0x45, 0x22, 0xfa, 0x7b, 0x37, 0xda, 0xee, 0x5a, 0x34, 0x0c, 0xc3, 0x37, 0xa0,
		0x1a, 0x88, 0x4d, 0x4f, 0x43, 0xe5, 0x7a, 0x72, 0x16, 0x0b, 0xf3, 0xd6, 0x4c, 0xfe, 0x18, 0x68,
		0xcd, 0xc8, 0x30, 0x1f, 0xad, 0x19, 0x42, 0x8e, 0x80, 0xd6, 0x0c, 0x1d, 0xb7, 0x46, 0x6b, 0x86,
		0xf8, 0x03, 0xa1, 0x35, 0x03, 0xce, 0xb4, 0x20, 0x74, 0xd4, 0x69, 0xcd, 0x0c, 0x83, 0x28, 0xfb,
		0xb8, 0xa9, 0x40, 0x57, 0x66, 0x9b, 0xf1, 0x23, 0xf0, 0x38, 0x1a, 0xf7, 0xb9, 0x17, 0xef, 0x84,
		0xbd, 0xc6, 0xed, 0x68, 0x5d, 0xc5, 0x0b, 0x8b, 0x99, 0xc7, 0x61, 0x76, 0x75, 0xd7, 0xb3, 0xcf,
		0xc3, 0xf0, 0x40, 0x51, 0x45, 0xd3, 0xf9, 0xc3, 0x10, 0xe0, 0xff, 0x42, 0x08, 0x20, 0x1e, 0x02,
		0xea, 0x9b, 0x3b, 0xf5, 0x9d, 0xc6, 0xf6, 0xe6, 0xce, 0x16, 0x62, 0x01, 0x0a, 0x12, 0x58, 0x7f,
		0xff, 0x75, 0x86, 0x76, 0x3f, 0x72, 0xdd, 0x9c, 0x30, 0xf3, 0x53, 0x04, 0x97, 0xdf, 0x33, 0xfe,
		0xfd, 0xfe, 0xc9, 0x73, 0xa0, 0xe1, 0x2f, 0xc3, 0x7c, 0x34, 0xfc, 0x09, 0x79, 0x02, 0x1a, 0xfe,
		0x74, 0xdc, 0x1a, 0x0d, 0x7f, 0xe2, 0x0f, 0x84, 0x86, 0x3f, 0x58, 0xd3, 0x82, 0xd0, 0x51, 0xab,
		0xe1, 0xff, 0x49, 0x81, 0x7e, 0xff, 0x16, 0xfa, 0xfd, 0x92, 0x5f, 0xe8, 0xf7, 0xa3, 0xae, 0x58,
		0xe1, 0xe3, 0xa0, 0xdf, 0x8f, 0x6c, 0x5e, 0x46, 0x08, 0x40, 0xbf, 0x9f, 0x7c, 0x08, 0xd8, 0xdc,
		0x42, 0xa3, 0x1f, 0x85, 0x08, 0xac, 0x7f, 0xf0, 0x42, 0xa3, 0x1f, 0x16, 0xb3, 0x4f, 0xc9, 0xd4,
		0x6f, 0x49, 0x7c, 0xd6, 0x7e, 0x15, 0x6f, 0x51, 0xcc, 0xef, 0xbe, 0x9b, 0x7c, 0xad, 0x3d, 0x3c,
		0xa3, 0xfe, 0xe1, 0x1f, 0x29, 0xde, 0xb8, 0xa8, 0x8e, 0x3f, 0x33, 0xf2, 0x65, 0xa6, 0x4a, 0x22,
		0xd6, 0x0a, 0x22, 0xa6, 0x6c, 0x1f, 0xa7, 0xee, 0xc9, 0x04, 0x3a, 0x4e, 0xdd, 0x93, 0xe7, 0xae,
		0x38, 0x75, 0x8f, 0x1a, 0xf9, 0xc4, 0xa9, 0x7b, 0xe0, 0x34, 0xbf, 0x87, 0x08, 0xdb, 0x8d, 0xbf,
		0x22, 0xe2, 0x87, 0xc2, 0xbf, 0x48, 0xc4, 0x05, 0xc7, 0x88, 0x3f, 0x3d, 0x70, 0x85, 0xa1, 0xb6,
		0x47, 0xeb, 0x4c, 0x4a, 0xc2, 0x0f, 0x1f, 0xf2, 0x22, 0xa9, 0x96, 0x53, 0x4c, 0x94, 0x4a, 0x15,
		0xb6, 0x94, 0xcb, 0x99, 0xef, 0x5f, 0xc4, 0x0d, 0xb7, 0xa2, 0x88, 0xe7, 0x11, 0x3b, 0x7c, 0x8f,
		0xd4, 0x51, 0xea, 0x08, 0x1d, 0x9e, 0x47, 0xe6, 0x70, 0x89, 0x26, 0x4c, 0x5b, 0xbc, 0x15, 0x6f,
		0xed, 0x72, 0xba, 0xe8, 0x28, 0xcd, 0x92, 0x61, 0x2f, 0x8b, 0x26, 0x84, 0xb7, 0x95, 0x2f, 0xbd,
		0x35, 0x79, 0x68, 0xaf, 0x33, 0x59, 0x6f, 0xcf, 0x4a, 0x83, 0xd4, 0xb3, 0x47, 0x0b, 0xed, 0xd9,
		0xe9, 0xc0, 0x73, 0xc3, 0x6b, 0xcf, 0x9c, 0xac, 0xa7, 0x95, 0x3a, 0xf7, 0x56, 0xd3, 0x6b, 0x4d,
		0xd6, 0xd0, 0x2b, 0xfe, 0x91, 0xee, 0x78, 0xc5, 0x3c, 0x63, 0xba, 0x44, 0xdd, 0xa0, 0xcf, 0x83,
		0xcb, 0xdd, 0xe2, 0x42, 0x43, 0x95, 0xa3, 0x2c, 0xb7, 0xe8, 0x5a, 0xb9, 0xa8, 0x4a, 0x3b, 0x4a,
		0xd0, 0xf5, 0x3d, 0xc2, 0x7e, 0xa7, 0xf9, 0xfd, 0xab, 0x20, 0xd2, 0x2f, 0x93, 0x78, 0x38, 0xe0,
		0x74, 0xd7, 0xf8, 0x9d, 0xd1, 0xb8, 0x68, 0x7c, 0x19, 0x66, 0xe2, 0xa2, 0xf1, 0x15, 0xc2, 0x15,
		0x17, 0x8d, 0xaf, 0xb2, 0xbd, 0x83, 0x8b, 0xc6, 0xcb, 0x25, 0x69, 0xb8, 0x68, 0xbc, 0x6a, 0xbc,
		0x9c, 0xcd, 0x45, 0xe3, 0xbc, 0xee, 0xcb, 0x64, 0x79, 0x4f, 0x26, 0x2e, 0x16, 0x07, 0xc1, 0x51,
		0x80, 0xe8, 0x70, 0x25, 0x3c, 0xec, 0x89, 0x0f, 0x7b, 0x02, 0xc4, 0x9b, 0x08, 0xf1, 0x20, 0x44,
		0x4c, 0x88, 0x11, 0x3b, 0x82, 0x54, 0x18, 0xcc, 0xa9, 0xeb, 0x33, 0x37, 0xdb, 0xf0, 0xe9, 0x02,
		0xcd, 0x23, 0x51, 0x18, 0x77, 0x06, 0xa9, 0x52, 0x98, 0x5c, 0x71, 0x27, 0x59, 0xca, 0x90, 0x2d,
		0x65, 0x48, 0x97, 0x1a, 0xe4, 0x8b, 0x17, 0x09, 0x63, 0x46, 0xc6, 0x0a, 0x88, 0xf0, 0x1f, 0x77,
		0x66, 0x7b, 0xa1, 0x01, 0xe3, 0x8b, 0x0c, 0x98, 0x1f, 0x68, 0xc4, 0xfb, 0x4a, 0x46, 0x05, 0x4e,
		0x4e, 0x54, 0xe2, 0xd4, 0x12, 0x55, 0x0e, 0x2c, 0x52, 0xe9, 0x8c, 0x92, 0x5b, 0xde, 0x77, 0x94,
		0xc2, 0xb5, 0x89, 0xb9, 0xb6, 0x2a, 0x17, 0x0f, 0x28, 0xe5, 0xe3, 0x38, 0x07, 0xa7, 0x94, 0xd7,
		0x19, 0x0a, 0xaf, 0x15, 0x3a, 0x24, 0xeb, 0x1b, 0xc2, 0xf9, 0xdf, 0x0c, 0xae, 0xe4, 0x8d, 0xe0,
		0xbc, 0x6f, 0x02, 0x87, 0xf8, 0xb4, 0x92, 0x11, 0x11, 0x72, 0x31, 0xc2, 0xc2, 0x86, 0x62, 0xef,
		0x90, 0xd3, 0xc1, 0x5f, 0x50, 0x40, 0x29, 0x1d, 0x38, 0xa0, 0x80, 0xa2, 0x1c, 0x28, 0x38, 0xcc,
		0xef, 0x97, 0x29, 0x1f, 0xbd, 0x0a, 0xa2, 0xc3, 0xf1, 0xba, 0x40, 0x16, 0xa6, 0x5a, 0x30, 0xd2,
		0xfc, 0x6b, 0x3f, 0x08, 0xfd, 0xf3, 0x50, 0xe8, 0xe7, 0x7e, 0xd4, 0xff, 0x19, 0xf4, 0xc7, 0x1e,
		0xce, 0x45, 0x1e, 0xf6, 0x84, 0xf1, 0x90, 0x89, 0x2d, 0xc3, 0x4c, 0xc8, 0xc4, 0x56, 0x08, 0x5b,
		0xc8, 0xc4, 0x56, 0xe7, 0x5e, 0x90, 0x89, 0x95, 0xcd, 0x64, 0x21, 0x13, 0xab, 0x5a, 0xf1, 0x02,
		0x99, 0xd8, 0x6a, 0xf3, 0x03, 0x64, 0x62, 0x20, 0x36, 0x1c, 0x09, 0x0e, 0x63, 0xa2, 0xc3, 0x95,
		0xf0, 0xb0, 0x27, 0x3e, 0xec, 0x09, 0x10, 0x6f, 0x22, 0xc4, 0x83, 0x10, 0x31, 0x21, 0x46, 0xec,
		0x08, 0x52, 0x61, 0x30, 0x9f, 0xde, 0xcf, 0xdc, 0x5c, 0xc3, 0xa5, 0x03, 0x34, 0x8f, 0x40, 0x41,
		0x22, 0x06, 0x42, 0xa5, 0x30, 0xb1, 0xe2, 0x4e, 0xb0, 0x94, 0x21, 0x5a, 0xca, 0x10, 0x2e, 0x35,
		0x88, 0x17, 0x2f, 0x02, 0xc6, 0x8c, 0x88, 0x15, 0x10, 0xe1, 0x2f, 0x11, 0x0b, 0x84, 0x10, 0x17,
		0x61, 0xec, 0xf3, 0xd6, 0x89, 0xed, 0x30, 0x34, 0xdd, 0x16, 0xd1, 0xe5, 0x98, 0x18, 0x43, 0x28,
		0x56, 0xf2, 0xca, 0x43, 0x28, 0x46, 0xe7, 0x31, 0x0a, 0x35, 0x09, 0x44, 0x24, 0x48, 0xc2, 0x4b,
		0x70, 0x6d, 0x08, 0xc5, 0xe0, 0xda, 0x70, 0x6d, 0x35, 0xaa, 0x01, 0xbe, 0x56, 0x9f, 0x41, 0x5d,
		0x52, 0xf5, 0xd4, 0xa4, 0x65, 0x1c, 0x6b, 0xc3, 0xa2, 0x2e, 0x1c, 0x5b, 0x8f, 0x8e, 0x77, 0x19,
		0x66, 0xa3, 0xe3, 0x2d, 0x11, 0xe7, 0xe8, 0x78, 0xcb, 0x73, 0x57, 0x74, 0xbc, 0x89, 0x3d, 0x08,
		0x3a, 0xde, 0x60, 0x34, 0xcf, 0x40, 0x44, 0x81, 0x8e, 0x77, 0x5f, 0x44, 0x59, 0x90, 0xdd, 0x30,
		0xbf, 0x07, 0x9a, 0xa3, 0x06, 0xdf, 0x9a, 0x2c, 0xfd, 0x9e, 0x9f, 0x32, 0xce, 0x5b, 0x53, 0x20,
		0x59, 0x5d, 0xab, 0xeb, 0x75, 0x8f, 0xf7, 0x5c, 0xfb, 0xc4, 0x73, 0xbf, 0x75, 0x4c, 0xae, 0xe9,
		0x6b, 0xdc, 0xa7, 0x49, 0xd9, 0x6e, 0x44, 0xac, 0xb1, 0xde, 0x8c, 0x78, 0x88, 0xa8, 0x8e, 0xe7,
		0x98, 0xc6, 0xfe, 0x67, 0x63, 0xcf, 0xb2, 0x2d, 0xf7, 0xdb, 0x04, 0x5c, 0x5d, 0xce, 0xe8, 0x52,
		0x09, 0x65, 0x6a, 0xa0, 0xed, 0x59, 0xd4, 0x75, 0x1c, 0xf3, 0xc0, 0xfa, 0xea, 0x1d, 0xd8, 0xc6,
		0x61, 0x57, 0x63, 0xff, 0xa8, 0xb7, 0xef, 0x81, 0x37, 0xda, 0x78, 0xb3, 0x3a, 0x27, 0x75, 0xcf,
		0x69, 0x1f, 0xbb, 0xa6, 0xe3, 0x59, 0x4d, 0x20, 0x0e, 0x88, 0x5b, 0x35, 0xe2, 0x5c, 0xe3, 0x10,
		0x30, 0x03, 0xcc, 0x4a, 0x80, 0x59, 0xa3, 0x0e, 0xa0, 0x01, 0x68, 0x25, 0x64, 0xd0, 0x06, 0x32,
		0x28, 0x10, 0x57, 0x7a, 0x8d, 0xd0, 0x55, 0x02, 0x6d, 0xac, 0x9f, 0xe0, 0x0c, 0x73, 0x66, 0xf0,
		0x6e, 0x54, 0xfe, 0xc0, 0x15, 0x2a, 0x7c, 0x20, 0xab, 0x72, 0xc8, 0x62, 0x5d, 0xc9, 0x03, 0x4e,
		0xa8, 0xd8, 0x01, 0x28, 0xd5, 0x33, 0x5f, 0x03, 0x99, 0x0f, 0xc8, 0x42, 0x05, 0x0e, 0x54, 0x51,
		0x44, 0xd5, 0x24, 0x34, 0xed, 0x1b, 0x1d, 0xcc, 0x1c, 0x00, 0x6f, 0x52, 0x71, 0xe7, 0x78, 0x86,
		0x7d, 0xd8, 0x76, 0x2c, 0xf7, 0xf3, 0x11, 0x3a, 0xd8, 0x40, 0x5c, 0x29, 0x88, 0xbb, 0xfb, 0x13,
		0xda, 0xd8, 0x72, 0x5f, 0x68, 0x63, 0xc3, 0xc5, 0x91, 0x4c, 0x80, 0x2c, 0x24, 0x0d, 0x40, 0xab,
		0x1a, 0xf5, 0x7c, 0x17, 0xb3, 0xde, 0x40, 0x9b, 0x6c, 0xd4, 0xd9, 0x56, 0xeb, 0x0b, 0x46, 0x86,
		0x00, 0xb5, 0x12, 0xa0, 0x76, 0xdc, 0xda, 0x6f, 0xb7, 0xba, 0xae, 0x63, 0x58, 0x2d, 0xb3, 0xe9,
		0xd9, 0xdd, 0x0e, 0x40, 0x07, 0xd0, 0x95, 0x12, 0xdf, 0x0c, 0xd7, 0x75, 0xac, 0xbd, 0x63, 0xd7,
		0x84, 0x9c, 0x05, 0x90, 0x5b, 0x39, 0xe4, 0xc6, 0x5b, 0x7e, 0x2d, 0xd3, 0x3a, 0xfc, 0xbc, 0xd7,
		0x76, 0x3c, 0xa3, 0xd9, 0x74, 0xcc, 0x2e, 0x80, 0x07, 0xe0, 0x95, 0x01, 0xbc, 0xba, 0x67, 0xb5,
		0x5c, 0xd3, 0x39, 0x30, 0xf6, 0x4d, 0x20, 0x0f, 0xc8, 0x2b, 0x8d, 0xda, 0xb9, 0x96, 0x6d, 0xfd,
		0xd7, 0x6c, 0x7a, 0x7b, 0x46, 0xab, 0xf9, 0x1f, 0xab, 0xe9, 0x7e, 0x06, 0xea, 0x80, 0xba, 0x52,
		0xb8, 0x5d, 0xc7, 0x69, 0xbb, 0xe6, 0xbe, 0x6b, 0xb5, 0x5b, 0x79, 0xe7, 0x04, 0xb8, 0x03, 0xee,
		0x56, 0x8c, 0x3b, 0xc7, 0xec, 0x5a, 0xcd, 0x63, 0xc3, 0x46, 0xb4, 0x03, 0xea, 0xca, 0x43, 0xdd,
		0x91, 0xf1, 0x35, 0x8f, 0x78, 0x40, 0x1d, 0x50, 0x57, 0x6e, 0x31, 0x8b, 0x9a, 0x02, 0xc8, 0x93,
		0x12, 0xef, 0x1c, 0xb3, 0x6b, 0x3a, 0x27, 0xc6, 0x9e, 0x6d, 0x22, 0xea, 0x01, 0x7b, 0x25, 0x57,
		0x16, 0x76, 0x1b, 0x81, 0x0e, 0x60, 0x2b, 0x09, 0x6c, 0x4d, 0xd3, 0x36, 0xbe, 0x79, 0x27, 0x86,
		0x63, 0x19, 0xa3, 0x5a, 0x16, 0xb8, 0x03, 0xee, 0x56, 0x8d, 0x3b, 0xa3, 0xf9, 0x6f, 0xcf, 0x36,
		0x5a, 0x8a, 0x9c, 0xe1, 0x00, 0xb8, 0x51, 0x87, 0xdb, 0x89, 0x61, 0xd9, 0xa0, 0x72, 0x80, 0x5d,
		0xf9, 0x51, 0x0e, 0x11, 0x0e, 0x50, 0x2b, 0xa3, 0x62, 0xb5, 0x5a, 0x77, 0x5d, 0xba, 0x31, 0xa1,
		0x03, 0xea, 0x80, 0xba, 0x55, 0xa3, 0xee, 0xb8, 0x95, 0x77, 0x49, 0xb0, 0xfb, 0x0a, 0xdc, 0x95,
		0x89, 0xbb, 0x02, 0x6c, 0x5e, 0x31, 0xd6, 0xe9, 0xa2, 0x5f, 0x02, 0xe0, 0xad, 0x1c, 0x78, 0xe6,
		0x57, 0xd7, 0x6c, 0x35, 0xcd, 0xa6, 0x67, 0x34, 0x47, 0x19, 0xf7, 0xd0, 0x69, 0x1f, 0x63, 0x94,
		0x18, 0xb8, 0x2b, 0xa1, 0x92, 0x00, 0xdc, 0x00, 0xb7, 0xd2, 0xe0, 0x36, 0x9e, 0xe6, 0xc4, 0x18,
		0x31, 0x80, 0x57, 0x36, 0xf0, 0x50, 0xbe, 0x02, 0x6d, 0xe5, 0xa1, 0xcd, 0x35, 0xbd, 0xa6, 0x79,
		0x60, 0x1c, 0xdb, 0xae, 0x77, 0x64, 0xba, 0x8e, 0xb5, 0x8f, 0x83, 0x38, 0xe4, 0xbe, 0x70, 0x10,
		0x07, 0x9c, 0x7c, 0xa9, 0xa9, 0x04, 0x07, 0xd4, 0x01, 0x52, 0xcb, 0x83, 0x94, 0x42, 0x2a, 0x62,
		0x80, 0x8b, 0x64, 0xbc, 0x52, 0x41, 0x2d, 0x0c, 0x68, 0x11, 0x2c, 0xe7, 0x55, 0x52, 0x05, 0x03,
		0x60, 0x04, 0x01, 0xa6, 0x94, 0xfa, 0x17, 0x08, 0x23, 0x47, 0xbd, 0x14, 0x52, 0xf9, 0x02, 0x5d,
		0x24, 0xb9, 0x97, 0x32, 0x6a, 0x5e, 0xe0, 0x8b, 0x1a, 0xbe, 0x54, 0x52, 0xed, 0x02, 0x5d, 0xd4,
		0xd0, 0xa5, 0x92, 0x3a, 0x17, 0xe8, 0x22, 0x59, 0x3c, 0x82, 0xdb, 0x03, 0x61, 0x2b, 0x8d, 0x5f,
		0x6a, 0xa9, 0x6d, 0x81, 0x31, 0x92, 0x0c, 0x9f, 0xb7, 0xaa, 0x16, 0xa0, 0x22, 0x09, 0x2a, 0x65,
		0xd4, 0xb3, 0xc0, 0x17, 0x35, 0x7c, 0x29, 0xa1, 0x92, 0x05, 0xac, 0xc8, 0xc1, 0x4a, 0x25, 0x35,
		0x2c, 0xe0, 0x45, 0x31, 0x6a, 0x21, 0x62, 0x01, 0x52, 0xcb, 0xac, 0x10, 0x15, 0x52, 0xb7, 0x02,
		0x5d, 0xd4, 0xd0, 0xa5, 0x96, 0x8a, 0x15, 0xf8, 0xa2, 0x86, 0x2f, 0xc5, 0xd4, 0xaa, 0x00, 0x18,
		0x35, 0x80, 0xa9, 0xa5, 0x4a, 0x05, 0xbe, 0xe8, 0x31, 0x7a, 0xc0, 0x0a, 0xb0, 0x5a, 0x3a, 0xac,
		0x14, 0x53, 0x99, 0x02, 0x60, 0xd4, 0x00, 0x86, 0x72, 0x11, 0xa8, 0x5a, 0x3e, 0xaa, 0x14, 0x52,
		0x8d, 0xf2, 0x54, 0x8b, 0xf2, 0x53, 0x89, 0xf2, 0x5a, 0x67, 0x3e, 0xd6, 0xf2, 0xb0, 0x94, 0x49,
		0x08, 0xd7, 0x8c, 0x28, 0x8a, 0x33, 0x3f, 0x0b, 0xe2, 0x48, 0xdb, 0x65, 0x14, 0xbc, 0xb5, 0xb4,
		0xf7, 0x5d, 0x5c, 0xf9, 0x03, 0x3f, 0xfb, 0x3e, 0x0a, 0xd7, 0xb5, 0x78, 0x20, 0xa2, 0x5e, 0x1c,
		0x5d, 0x04, 0x97, 0x7a, 0x24, 0xb2, 0x9f, 0x71, 0xf2, 0x43, 0x0f, 0xa2, 0x34, 0xf3, 0xa3, 0x9e,
		0xa8, 0x3d, 0xfe, 0x46, 0x3a, 0xf3, 0x9d, 0xda, 0x20, 0x89, 0xb3, 0xb8, 0x17, 0x87, 0x69, 0xf1,
		0xae, 0x16, 0xa4, 0x41, 0x5a, 0x0b, 0xc5, 0xb5, 0x08, 0x27, 0x5f, 0x6a, 0x61, 0x10, 0xfd, 0xd0,
		0xd3, 0xcc, 0xcf, 0x84, 0xde, 0xf7, 0x33, 0xff, 0xdc, 0x4f, 0x45, 0x2d, 0x4c, 0x07, 0xb5, 0x2c,
		0xbc, 0x4e, 0x47, 0xff, 0xa9, 0x89, 0x5f, 0x99, 0x88, 0xfa, 0xa2, 0xaf, 0x07, 0xa9, 0x9e, 0x08,
		0xbf, 0xf7, 0xdd, 0x3f, 0x0f, 0xc2, 0x20, 0xbb, 0xa9, 0x45, 0x22, 0xb8, 0xfc, 0x7e, 0x1e, 0x27,
		0x69, 0xf1, 0xae, 0x76, 0x67, 0x4c, 0x61, 0x44, 0x3a, 0x3c, 0x1f, 0xff, 0x53, 0xf9, 0xd7, 0x9a,
		0x7f, 0xed, 0x07, 0xa1, 0x7f, 0x1e, 0x0a, 0xfd, 0xdc, 0x8f, 0xfa, 0x3f, 0x83, 0x7e, 0xf6, 0xbd,
		0x36, 0xfe, 0xed, 0x3c, 0x52, 0x0f, 0x7d, 0x37, 0xa5, 0x6d, 0x21, 0xf1, 0x00, 0xc2, 0x2d, 0x70,
		0x54, 0x33, 0x60, 0x30, 0xb8, 0xd7, 0x5f, 0x4b, 0xb3, 0x64, 0xd8, 0xcb, 0xa2, 0x09, 0xf1, 0x6e,
		0xe5, 0x2b, 0x6d, 0x4d, 0x9e, 0xd1, 0xeb, 0x4c, 0x96, 0xd7, 0xb3, 0xd2, 0x20, 0xf5, 0xec, 0xd1,
		0xba, 0x7a, 0x76, 0x3a, 0xf0, 0xdc, 0xf0, 0xda, 0x33, 0x27, 0xcb, 0x67, 0xa5, 0xce, 0xbd, 0xc5,
		0xf3, 0x5a, 0x93, 0x25, 0xf3, 0x8a, 0x7f, 0xa4, 0x3b, 0x5e, 0x20, 0xcf, 0x98, 0x2e, 0xd0, 0x5e,
		0xb1, 0x3e, 0x6f, 0x10, 0xa0, 0x14, 0x0b, 0x4e, 0x5a, 0x01, 0x7e, 0xbd, 0x17, 0x47, 0x69, 0x96,
		0xf8, 0x41, 0x94, 0xa5, 0xe4, 0x63, 0x54, 0x51, 0x79, 0x3e, 0x6d, 0x3e, 0xf1, 0x64, 0xf0, 0x25,
		0x88, 0xfa, 0xda, 0xee, 0xda, 0x06, 0x71, 0x33, 0xf7, 0xc7, 0x01, 0x5f, 0xdb, 0x5d, 0x5b, 0x27,
		0x6e, 0x68, 0x27, 0x11, 0x17, 0xc1, 0x2f, 0x1e, 0x89, 0x75, 0x0a, 0xdc, 0xb8, 0xa7, 0x8f, 0x52,
		0x20, 0x87, 0x94, 0xd3, 0x8d, 0x87, 0x49, 0x4f, 0xb0, 0x29, 0x78, 0xb4, 0x2f, 0xe2, 0xe6, 0x67,
		0x9c, 0x8c, 0x3c, 0x4c, 0x1b, 0xe4, 0xc8, 0x60, 0x52, 0x5d, 0x7e, 0xf6, 0x53, 0x23, 0xb9, 0x1c,
		0x5e, 0x89, 0x28, 0xd3, 0x76, 0xd7, 0xb2, 0x64, 0x28, 0xb8, 0x94, 0xc5, 0x77, 0x56, 0x17, 0xc0,
		0x46, 0x41, 0xa3, 0x74, 0x41, 0xd3, 0x0c, 0x12, 0x1e, 0x01, 0xf7, 0x29, 0x86, 0xc0, 0x27, 0x96,
		0xfd, 0x8e, 0xe7, 0x70, 0x09, 0x6b, 0x3c, 0xe8, 0x0e, 0x3b, 0xda, 0xc3, 0x91, 0xfe, 0x30, 0xa6,
		0x41, 0x5c, 0xe9, 0x10, 0x7b, 0x5a, 0xc4, 0x9e, 0x1e, 0xf1, 0xa6, 0x49, 0x3c, 0xe8, 0x12, 0x13,
		0xda, 0xc4, 0x8e, 0x3e, 0x15, 0x06, 0x73, 0xea, 0x0e, 0xcd, 0xcd, 0x36, 0x7c, 0x7a, 0x44, 0xcc,
		0x49, 0x14, 0x5b, 0x32, 0xc5, 0x99, 0x54, 0x29, 0x40, 0xae, 0xb8, 0x93, 0x2c, 0x65, 0xc8, 0x96,
		0x32, 0xa4, 0x4b, 0x0d, 0xf2, 0xc5, 0x8b, 0x84, 0x31, 0x23, 0x63, 0x6c, 0x49, 0xd9, 0x13, 0xe4,
		0x8c, 0x6f, 0xc4, 0x9c, 0xe5, 0x68, 0x5c, 0x43, 0x26, 0x4f, 0xaa, 0xc6, 0x9e, 0xb2, 0xa9, 0x40,
		0xdd, 0x14, 0xa2, 0x70, 0xaa, 0x50, 0x39, 0xe5, 0x28, 0x9d, 0x72, 0xd4, 0x4e, 0x2d, 0x8a, 0xc7,
		0x93, 0xea, 0x31, 0xa5, 0x7c, 0xec, 0xa9, 0xdf, 0x13, 0x14, 0x50, 0x0f, 0xfa, 0xfc, 0x83, 0xed,
		0x2c, 0x1b, 0x1c, 0x3d, 0x16, 0xf3, 0xf8, 0x34, 0x21, 0x86, 0xeb, 0xcc, 0x1f, 0x83, 0x3b, 0x41,
		0x54, 0x89, 0x28, 0x2a, 0x48, 0x18, 0x55, 0x23, 0x8e, 0xca, 0x12, 0x48, 0x65, 0x89, 0xa4, 0x9a,
		0x84, 0x92, 0x37, 0xb1, 0x64, 0x4e, 0x30, 0x0b, 0x48, 0xb9, 0x37, 0x03, 0xa1, 0x56, 0xc6, 0x09,
		0x85, 0x7f, 0x91, 0x88, 0x0b, 0x15, 0x32, 0xce, 0xb4, 0x73, 0xb7, 0xad, 0xc0, 0xb3, 0x74, 0x26,
		0xda, 0xad, 0x0f, 0x1f, 0x72, 0x1d, 0x64, 0xed, 0x21, 0x95, 0x7e, 0x83, 0x10, 0x86, 0xf0, 0xf5,
		0x32, 0x44, 0xe5, 0x72, 0x5a, 0x65, 0x4a, 0xcb, 0xfc, 0x71, 0xd4, 0x28, 0x29, 0x37, 0x50, 0x52,
		0xa2, 0xa4, 0x44, 0x49, 0x89, 0x92, 0x12, 0x25, 0x25, 0x4a, 0x4a, 0xf0, 0xb1, 0x6a, 0x95, 0x94,
		0xdc, 0xf7, 0x2e, 0x8a, 0x07, 0xb9, 0x3b, 0x88, 0x41, 0x99, 0x00, 0x3d, 0xa3, 0xdf, 0x52, 0x25,
		0x40, 0xab, 0xb1, 0x97, 0xa1, 0x1c, 0x01, 0x55, 0x91, 0x88, 0x2a, 0x4c, 0x48, 0x55, 0x25, 0xa6,
		0xca, 0x13, 0x54, 0xe5, 0x89, 0xaa, 0xda, 0x84, 0x55, 0x0d, 0xe2, 0xaa, 0x08, 0x81, 0x2d, 0xa0,
		0xa6, 0xcc, 0xde, 0xc8, 0x4c, 0xc6, 0x0a, 0x84, 0x10, 0x17, 0x61, 0xec, 0x67, 0x1f, 0x37, 0x55,
		0xca, 0x5a, 0x13, 0x12, 0xb8, 0xa3, 0xd0, 0x23, 0xd9, 0x22, 0xba, 0x1c, 0x17, 0x20, 0xa7, 0x4a,
		0x85, 0x71, 0xb5, 0x68, 0xc5, 0xf8, 0x93, 0x3a, 0x0a, 0x22, 0xe5, 0xf8, 0x92, 0xa2, 0xe5, 0xd5,
		0xcc, 0xe3, 0x9d, 0xf8, 0xe1, 0x70, 0x14, 0x18, 0xeb, 0x8a, 0x3e, 0xdf, 0x41, 0xe2, 0xf7, 0xb2,
		0x20, 0x8e, 0x9a, 0xc1, 0x65, 0x30, 0x16, 0x4c, 0xaf, 0x2b, 0xf7, 0x9c, 0xb7, 0xef, 0x15, 0x0c,
		0x29, 0xfe, 0x2f, 0x84, 0x14, 0x84, 0x14, 0x84, 0x14, 0x54, 0x63, 0x78, 0x9a, 0xbb, 0xd7, 0xd9,
		0x1b, 0x7c, 0x1e, 0x48, 0xb9, 0xcb, 0x09, 0x63, 0x6a, 0xe9, 0x54, 0x66, 0x0a, 0x7d, 0x95, 0xf4,
		0x2a, 0x8a, 0x32, 0x07, 0xec, 0xf5, 0x70, 0x72, 0x28, 0xec, 0xf5, 0xf0, 0x09, 0x13, 0xd8, 0xeb,
		0x61, 0xfe, 0x80, 0xd8, 0xeb, 0x01, 0x07, 0x2c, 0x09, 0x6a, 0xea, 0xee, 0xf5, 0x0c, 0x83, 0x48,
		0xcd, 0x6d, 0x9e, 0x6d, 0x85, 0x1e, 0xc9, 0xf1, 0xa3, 0x4b, 0x81, 0x5d, 0x1e, 0xfa, 0x1f, 0x14,
		0x76, 0x79, 0xf8, 0x3e, 0xde, 0xb4, 0x25, 0xbb, 0x8e, 0x96, 0x2c, 0xe8, 0x06, 0xa1, 0x90, 0x82,
		0x5d, 0x1e, 0xf6, 0x21, 0xa5, 0xbe, 0xb9, 0x53, 0xdf, 0x69, 0x6c, 0x6f, 0xee, 0x6c, 0x21, 0xb6,
		0xa0, 0x20, 0xc3, 0xd3, 0x2c, 0xf3, 0x85, 0xed, 0x1e, 0x3c, 0x41, 0xe5, 0x99, 0x03, 0xd7, 0xab,
		0xbe, 0xe7, 0x3e, 0x8f, 0xfa, 0x37, 0xfa, 0x3e, 0x79, 0x17, 0xe8, 0x93, 0xdf, 0xad, 0xdd, 0xff,
		0x0b, 0xf7, 0xbe, 0xcd, 0xe8, 0xc2, 0x70, 0xf5, 0x82, 0x06, 0x0e, 0xbc, 0x2c, 0xb5, 0x4e, 0x10,
		0x37, 0xaa, 0xec, 0x57, 0x6b, 0x76, 0x90, 0x66, 0x46, 0x96, 0x31, 0x3f, 0xc1, 0xf3, 0x28, 0x88,
		0xcc, 0x50, 0x5c, 0x89, 0xfc, 0x86, 0x1d, 0xc6, 0x05, 0xdc, 0xa8, 0xc0, 0xbe, 0xf7, 0x24, 0x1b,
		0x9f, 0xea, 0xf5, 0xc6, 0x76, 0xbd, 0xbe, 0xbe, 0xfd, 0x71, 0x7b, 0x7d, 0x67, 0x6b, 0x6b, 0xa3,
		0xb1, 0xc1, 0xb8, 0x68, 0xd3, 0xda, 0x49, 0x5f, 0x24, 0xa2, 0xbf, 0x37, 0x72, 0x9f, 0x68, 0x18,
		0x86, 0x88, 0x5a, 0x20, 0x65, 0x20, 0x63, 0xcb, 0x27, 0x63, 0x1a, 0xeb, 0x93, 0xb2, 0x92, 0x61,
		0x2f, 0x8b, 0x26, 0x1b, 0x82, 0xad, 0xfc, 0xf3, 0xb2, 0x26, 0x2b, 0xe5, 0x75, 0x26, 0x1f, 0x92,
		0x67, 0xa5, 0x41, 0xea, 0xd9, 0xa3, 0x4f, 0xc7, 0xb3, 0xd3, 0x81, 0xe7, 0x86, 0xd7, 0x9e, 0x39,
		0xf9, 0x10, 0xac, 0xd4, 0xb9, 0xf7, 0x11, 0x78, 0xad, 0xc9, 0xc2, 0x7b, 0xc5, 0x3f, 0xd2, 0x1d,
		0x2f, 0xb3, 0xb7, 0x37, 0x5d, 0xd0, 0xfd, 0x62, 0xe1, 0xbc, 0xbb, 0xb7, 0x3c, 0xa9, 0xec, 0x2d,
		0xae, 0xe5, 0x41, 0xf0, 0x57, 0x27, 0xe8, 0x23, 0xd8, 0xcf, 0x09, 0xf6, 0xbc, 0xa2, 0x13, 0x1f,
		0x1f, 0x67, 0xe4, 0xdf, 0xda, 0x55, 0xdc, 0x17, 0x21, 0xc7, 0x49, 0xf0, 0x62, 0xdc, 0xa7, 0x78,
		0x02, 0x9e, 0x17, 0x8a, 0xae, 0xe3, 0x42, 0xd1, 0x72, 0x0c, 0xc7, 0x85, 0xa2, 0x52, 0x1f, 0x01,
		0x17, 0x8a, 0x12, 0x79, 0x10, 0x5c, 0x28, 0x0a, 0x56, 0x53, 0x95, 0xca, 0x85, 0xed, 0x90, 0xb3,
		0x02, 0x87, 0xfb, 0x73, 0x3e, 0xcc, 0x7f, 0xf6, 0xf0, 0xfe, 0x82, 0x65, 0xa2, 0x66, 0xaa, 0x7c,
		0xcd, 0xc4, 0xf3, 0x1c, 0x7e, 0xd6, 0xe7, 0xee, 0x33, 0x3d, 0x67, 0x1f, 0xd5, 0x12, 0xaa, 0x25,
		0x54, 0x4b, 0xa8, 0x96, 0x50, 0x2d, 0xa1, 0x5a, 0xa2, 0x0f, 0x11, 0xae, 0xe7, 0xd8, 0xf3, 0x6d,
		0x62, 0xcf, 0xa4, 0x2c, 0xa6, 0xcd, 0xec, 0xc7, 0x34, 0x8d, 0xe9, 0xf0, 0x14, 0xfb, 0x93, 0x49,
		0x54, 0x38, 0x89, 0x44, 0xa1, 0x93, 0x47, 0x54, 0x39, 0x69, 0x44, 0xb9, 0x93, 0x45, 0x94, 0x3b,
		0x49, 0x44, 0xad, 0x93, 0x43, 0x30, 0x89, 0x5e, 0x26, 0x74, 0xd8, 0x9f, 0x04, 0xf2, 0xe0, 0xe4,
		0x8f, 0x4f, 0x9c, 0xf3, 0xc5, 0x84, 0x3e, 0x71, 0x1e, 0xcf, 0x56, 0xe3, 0x60, 0x0f, 0x05, 0xf4,
		0x66, 0x2a, 0x1d, 0xdc, 0xa1, 0xda, 0x09, 0x88, 0x8a, 0x1d, 0xcc, 0xa1, 0xa2, 0x58, 0x5e, 0x85,
		0xb3, 0x5e, 0x55, 0x3a, 0x68, 0x43, 0xd5, 0x10, 0xb0, 0xb9, 0xb5, 0x85, 0x20, 0x80, 0x42, 0x04,
		0xd6, 0xdf, 0x7f, 0x9d, 0x41, 0x37, 0x03, 0x8b, 0xb9, 0xa7, 0x64, 0xe8, 0x66, 0x54, 0xd2, 0xcd,
		0x30, 0x3c, 0x9a, 0x82, 0xd1, 0xf4, 0xd7, 0x1b, 0xc4, 0x9f, 0x25, 0x32, 0xe5, 0xfc, 0x68, 0x09,
		0x66, 0x7b, 0x89, 0x3c, 0x4f, 0x91, 0xe0, 0x7b, 0x6a, 0x84, 0x52, 0xa7, 0x44, 0xf0, 0x3c, 0x15,
		0x82, 0x4b, 0x40, 0x61, 0x4a, 0x64, 0x40, 0x60, 0x74, 0x96, 0xc7, 0x39, 0xc8, 0x3d, 0xbe, 0x81,
		0x07, 0xc7, 0xa3, 0xcf, 0x98, 0x68, 0x5b, 0x48, 0x3c, 0xf4, 0x72, 0x0b, 0xb9, 0x55, 0x0d, 0xb5,
		0xb4, 0x83, 0x05, 0x5d, 0x17, 0x24, 0xec, 0x7e, 0x5a, 0x01, 0x1b, 0xbf, 0x7f, 0x15, 0x44, 0xfa,
		0x65, 0x12, 0x0f, 0x07, 0xe4, 0x9d, 0xb0, 0x98, 0x81, 0x78, 0xd2, 0x7a, 0xe2, 0xc1, 0x8e, 0x87,
		0xb8, 0x87, 0xcd, 0x74, 0x28, 0xa7, 0x29, 0x50, 0x86, 0xd3, 0x9e, 0xdc, 0xa6, 0x3a, 0xd9, 0x4e,
		0x6f, 0xb2, 0x9d, 0xd2, 0xe4, 0x39, 0x8d, 0x09, 0xc2, 0xfe, 0x9a, 0x8f, 0x9c, 0x8b, 0x78, 0x86,
		0x99, 0x7a, 0x99, 0xa5, 0x6a, 0x99, 0x99, 0x5a, 0x99, 0x9d, 0xec, 0x85, 0xa3, 0xcc, 0x85, 0xb1,
		0xac, 0x85, 0xab, 0x8c, 0x85, 0xbd, 0x6c, 0x85, 0xbd, 0x4c, 0x85, 0xb7, 0x2c, 0x05, 0xbb, 0xd2,
		0x55, 0x24, 0x48, 0x85, 0xc1, 0x2c, 0xfb, 0x40, 0x73, 0xd3, 0x0e, 0xc3, 0xbe, 0xd0, 0x3c, 0x5a,
		0x85, 0x23, 0x33, 0x41, 0xb3, 0x14, 0xa6, 0x5b, 0xdc, 0x69, 0x97, 0x32, 0xf4, 0x4b, 0x19, 0x1a,
		0xa6, 0x06, 0x1d, 0xe3, 0x45, 0xcb, 0x98, 0xd1, 0xb3, 0x02, 0x22, 0xfc, 0x8f, 0xcc, 0x64, 0x7b,
		0xff, 0x3f, 0xe3, 0x7b, 0xfe, 0x99, 0xcb, 0x7e, 0x79, 0xdf, 0x5a, 0xa6, 0xc0, 0xf9, 0x22, 0x4a,
		0x68, 0xfb, 0x54, 0x91, 0xf5, 0xaa, 0xa4, 0xe4, 0xbb, 0xe5, 0x7d, 0x8d, 0x1f, 0x5c, 0x9b, 0x98,
		0x6b, 0xab, 0x72, 0xef, 0xbd, 0x52, 0x3e, 0x0e, 0xb5, 0x68, 0x29, 0xaf, 0x33, 0x14, 0x5e, 0x2b,
		0x74, 0x48, 0xd6, 0x97, 0xe8, 0xf2, 0xbf, 0x3c, 0x57, 0xc9, 0x4b, 0x73, 0x79, 0x5f, 0x96, 0x0b,
		0xfd, 0x6a, 0x25, 0x23, 0x22, 0xe4, 0x66, 0x64, 0x35, 0x10, 0x4f, 0x6d, 0x22, 0x72, 0x52, 0xc6,
		0x43, 0x35, 0xa5, 0x74, 0x04, 0x81, 0x6a, 0x8a, 0x45, 0xc4, 0xe0, 0x30, 0xe3, 0x5f, 0x9e, 0x04,
		0x75, 0xfa, 0xf7, 0x8d, 0xd1, 0x02, 0x1d, 0x8e, 0xd7, 0x07, 0xa2, 0x32, 0xd5, 0xa2, 0x93, 0x16,
		0x0c, 0xae, 0xeb, 0x7a, 0x10, 0x65, 0x22, 0xb9, 0xf0, 0x7b, 0x42, 0xf7, 0xfb, 0xfd, 0x44, 0xa4,
		0x29, 0x1f, 0x59, 0xd9, 0x1c, 0xfb, 0x21, 0x2c, 0x5b, 0x86, 0x99, 0x10, 0x96, 0xad, 0x10, 0xb9,
		0x10, 0x96, 0xad, 0xce, 0xbd, 0x20, 0x2c, 0x2b, 0x9b, 0xe0, 0x42, 0x58, 0x56, 0xb5, 0x9a, 0x06,
		0xc2, 0xb2, 0xd5, 0xe6, 0x07, 0x08, 0xcb, 0x40, 0x6c, 0x38, 0x12, 0x1c, 0xc6, 0x44, 0x87, 0x2b,
		0xe1, 0x61, 0x4f, 0x7c, 0xd8, 0x13, 0x20, 0xde, 0x44, 0x88, 0x07, 0x21, 0x62, 0x42, 0x8c, 0xd8,
		0x11, 0xa4, 0xc2, 0x60, 0x2e, 0xcd, 0x9f, 0xb9, 0x99, 0x86, 0x47, 0xf7, 0x67, 0x1e, 0x79, 0x82,
		0x7c, 0x0c, 0x64, 0x4a, 0x61, 0x52, 0xc5, 0x9d, 0x5c, 0x29, 0x43, 0xb2, 0x94, 0x21, 0x5b, 0x6a,
		0x90, 0x2e, 0x5e, 0xe4, 0x8b, 0x19, 0x09, 0x2b, 0x20, 0xc2, 0x5f, 0x3e, 0x36, 0xde, 0xe9, 0xe2,
		0xc9, 0x70, 0xee, 0xb3, 0x9c, 0x8d, 0x4f, 0x0c, 0x6d, 0xef, 0xf8, 0x59, 0x26, 0x92, 0x88, 0xad,
		0x8e, 0x4c, 0xfb, 0xdf, 0xdb, 0xb7, 0xa7, 0xeb, 0xfa, 0xce, 0xd9, 0x3f, 0xa7, 0x1b, 0xfa, 0xce,
		0x59, 0xfe, 0x76, 0x63, 0xfc, 0x25, 0x7f, 0xbf, 0x79, 0xba, 0xae, 0xd7, 0xa7, 0xef, 0xb7, 0x4e,
		0xd7, 0xf5, 0xad, 0xb3, 0x77, 0x7f, 0xfd, 0xf5, 0xe1, 0xdd, 0xdf, 0x1f, 0x6f, 0x5f, 0xfe, 0x83,
		0xff, 0xe2, 0x17, 0x7c, 0xcf, 0x38, 0x82, 0xb2, 0xdd, 0xb5, 0xbe, 0x02, 0x99, 0xaa, 0x23, 0x13,
		0xb4, 0x60, 0x85, 0xe8, 0x83, 0xb8, 0x41, 0xf2, 0x13, 0x40, 0xdc, 0x80, 0x32, 0x44, 0x69, 0x4b,
		0x21, 0x6e, 0x58, 0xad, 0xdd, 0xea, 0x8f, 0x2a, 0x3f, 0x3d, 0xe2, 0x08, 0x79, 0x43, 0x75, 0x2c,
		0x84, 0xbc, 0x01, 0x31, 0x63, 0x19, 0x31, 0x03, 0x02, 0x87, 0xfb, 0x02, 0x07, 0x6b, 0x70, 0x5d,
		0xb7, 0xa6, 0x4b, 0x64, 0x4c, 0x56, 0x08, 0x12, 0x07, 0xd5, 0x22, 0x54, 0xde, 0x38, 0x9d, 0xfa,
		0x0e, 0x53, 0x85, 0xc3, 0x8c, 0xf9, 0x10, 0x38, 0x2c, 0xc3, 0x4c, 0x08, 0x1c, 0x56, 0x08, 0x5c,
		0x08, 0x1c, 0x56, 0xe7, 0x5e, 0x10, 0x38, 0x94, 0x4d, 0x71, 0x21, 0x70, 0xa8, 0x5a, 0x55, 0x03,
		0x81, 0xc3, 0x6a, 0xf3, 0x03, 0x04, 0x0e, 0x20, 0x36, 0x1c, 0x09, 0x0e, 0x63, 0xa2, 0xc3, 0x95,
		0xf0, 0xb0, 0x27, 0x3e, 0xec, 0x09, 0x10, 0x6f, 0x22, 0xc4, 0x83, 0x10, 0x31, 0x21, 0x46, 0xec,
		0x08, 0x52, 0x61, 0x30, 0x04, 0x0e, 0x52, 0xc9, 0x13, 0x04, 0x0e, 0x20, 0x53, 0x0a, 0x93, 0x2a,
		0xee, 0xe4, 0x4a, 0x19, 0x92, 0xa5, 0x0c, 0xd9, 0x52, 0x83, 0x74, 0xf1, 0x22, 0x5f, 0xcc, 0x48,
		0x58, 0x01, 0x11, 0x08, 0x1c, 0x88, 0xb0, 0x1c, 0x08, 0x1c, 0x64, 0x3c, 0x00, 0xc6, 0xc8, 0x7f,
		0xff, 0x82, 0xc0, 0x01, 0xc8, 0x24, 0x8a, 0x4c, 0xd0, 0x82, 0x15, 0xa2, 0x0f, 0x02, 0x07, 0xc9,
		0x4f, 0x00, 0x81, 0x03, 0xca, 0x10, 0xa5, 0x2d, 0x85, 0xc0, 0x61, 0xb5, 0x76, 0x57, 0x64, 0x58,
		0xf9, 0xf1, 0x84, 0x23, 0xf4, 0x0d, 0xd5, 0xb1, 0x10, 0xfa, 0x06, 0x84, 0x8c, 0x25, 0x84, 0x0c,
		0xc8, 0x1b, 0x1e, 0xcb, 0x1b, 0xa6, 0xff, 0x13, 0xea, 0x06, 0x55, 0xe3, 0x93, 0x16, 0x0c, 0xae,
		0x1b, 0xcc, 0x2f, 0x70, 0x68, 0xe0, 0x02, 0x87, 0x15, 0x99, 0x09, 0x7d, 0xc3, 0x0a, 0x91, 0x0b,
		0x7d, 0xc3, 0xea, 0xdc, 0x0b, 0xfa, 0x86, 0xb2, 0x29, 0x2e, 0xf4, 0x0d, 0x55, 0xab, 0x6a, 0xa0,
		0x6f, 0x58, 0x6d, 0x7e, 0x80, 0xbe, 0x01, 0xc4, 0x86, 0x23, 0xc1, 0x61, 0x4c, 0x74, 0xb8, 0x12,
		0x1e, 0xf6, 0xc4, 0x87, 0x3d, 0x01, 0xe2, 0x4d, 0x84, 0x78, 0x10, 0x22, 0x26, 0xc4, 0x88, 0x1d,
		0x41, 0x2a, 0x0c, 0x86, 0xbe, 0x41, 0x2a, 0x79, 0x82, 0xbe, 0x01, 0x64, 0x4a, 0x61, 0x52, 0xc5,
		0x9d, 0x5c, 0x29, 0x43, 0xb2, 0x94, 0x21, 0x5b, 0x6a, 0x90, 0x2e, 0x5e, 0xe4, 0x8b, 0x19, 0x09,
		0x2b, 0x20, 0xa2, 0x84, 0xbe, 0xa1, 0x01, 0x7d, 0x83, 0x24, 0xc6, 0xa0, 0xc8, 0x14, 0xb9, 0xaf,
		0x5f, 0x18, 0xfa, 0xc1, 0xd9, 0xdf, 0x1b, 0xef, 0xeb, 0xb7, 0xbb, 0xef, 0xfe, 0xde, 0xbe, 0x7d,
		0xfc, 0xcd, 0x7f, 0x9e, 0xfa, 0x6b, 0x1b, 0xef, 0xb7, 0x6f, 0x77, 0xe7, 0xfc, 0x9f, 0xc6, 0xed,
		0xee, 0x1f, 0xfe, 0x1b, 0x5b, 0xb7, 0x6f, 0x67, 0xfe, 0xea, 0xe8, 0xfb, 0x9b, 0xf3, 0x7e, 0xa0,
		0x3e, 0xe7, 0x07, 0x3e, 0xce, 0xfb, 0x81, 0x8f, 0x73, 0x7e, 0x60, 0xae, 0x49, 0x9b, 0x73, 0x7e,
		0x60, 0xeb, 0xf6, 0x9f, 0x99, 0xbf, 0xff, 0xf6, 0xe9, 0xbf, 0xda, 0xb8, 0x7d, 0xf7, 0xcf, 0xbc,
		0xff, 0xb7, 0x7d, 0xfb, 0xcf, 0xee, 0x3b, 0xa8, 0x3d, 0x4a, 0x72, 0x51, 0x95, 0xd4, 0x1e, 0xf0,
		0x53, 0xf8, 0xe9, 0x9f, 0xf8, 0x29, 0x28, 0xe3, 0x0a, 0x7d, 0x11, 0xda, 0x17, 0xc9, 0x4f, 0x00,
		0xed, 0x0b, 0x4a, 0x54, 0xa5, 0x2d, 0x85, 0xf6, 0x65, 0xb5, 0x76, 0x57, 0x62, 0x90, 0xbd, 0x81,
		0xcb, 0x3d, 0xaa, 0x6c, 0x21, 0xc4, 0x2f, 0x88, 0x19, 0xcb, 0x88, 0x19, 0x50, 0xbf, 0x3c, 0x52,
		0xbf, 0x34, 0x70, 0xb9, 0x87, 0xf2, 0x11, 0x2a, 0x6f, 0xaa, 0xb3, 0xbe, 0xdc, 0xa3, 0x81, 0xcb,
		0x3d, 0x56, 0x63, 0x26, 0xc4, 0x2f, 0x2b, 0x04, 0x2e, 0xc4, 0x2f, 0xab, 0x73, 0x2f, 0x88, 0x5f,
		0xca, 0xa6, 0xb8, 0x10, 0xbf, 0x54, 0xad, 0xaa, 0x81, 0xf8, 0x65, 0xb5, 0xf9, 0x01, 0xe2, 0x17,
		0x10, 0x1b, 0x8e, 0x04, 0x87, 0x31, 0xd1, 0xe1, 0x4a, 0x78, 0xd8, 0x13, 0x1f, 0xf6, 0x04, 0x88,
		0x37, 0x11, 0xe2, 0x41, 0x88, 0x98, 0x10, 0x23, 0x76, 0x04, 0xa9, 0x30, 0x18, 0xe2, 0x17, 0xa9,
		0xe4, 0x09, 0xe2, 0x17, 0x90, 0x29, 0x85, 0x49, 0x15, 0x77, 0x72, 0xa5, 0x0c, 0xc9, 0x52, 0x86,
		0x6c, 0xa9, 0x41, 0xba, 0x78, 0x91, 0x2f, 0x66, 0x24, 0xac, 0x80, 0x08, 0xc4, 0x2f, 0x44, 0x58,
		0x0e, 0xc4, 0x2f, 0x32, 0x1e, 0x00, 0x43, 0xf5, 0x18, 0xaa, 0xff, 0xf3, 0x17, 0xc4, 0x2f, 0xf0,
		0x53, 0xf8, 0x29, 0x03, 0x3f, 0x05, 0x65, 0x5c, 0xa1, 0x2f, 0x42, 0xfc, 0x22, 0xf9, 0x09, 0x20,
		0x7e, 0x41, 0x89, 0xaa, 0xb4, 0xa5, 0x10, 0xbf, 0xac, 0xd6, 0xee, 0x8a, 0x0c, 0xb2, 0xe3, 0xe2,
		0x97, 0xea, 0x5a, 0x08, 0xed, 0x0b, 0x42, 0xc6, 0x12, 0x42, 0x06, 0xa4, 0x2f, 0x8f, 0xa5, 0x2f,
		0xb8, 0xf8, 0x45, 0xf5, 0xf8, 0xa4, 0x85, 0x7e, 0xa4, 0xfb, 0xfd, 0xff, 0xe7, 0xf7, 0x44, 0xd4,
		0xbb, 0xd1, 0xd3, 0xa0, 0xcf, 0x48, 0xf6, 0xf2, 0x84, 0xed, 0xd0, 0xbc, 0x2c, 0xc3, 0x4c, 0x68,
		0x5e, 0x56, 0x88, 0x5a, 0x68, 0x5e, 0x56, 0xe7, 0x5e, 0xd0, 0xbc, 0x94, 0x4d, 0x6d, 0xa1, 0x79,
		0xa9, 0x5a, 0x35, 0xc3, 0x46, 0xf3, 0x32, 0x43, 0x0f, 0xf8, 0xe9, 0x5f, 0x66, 0x1f, 0x01, 0x5a,
		0x98, 0x2a, 0x13, 0x1e, 0x8e, 0xc4, 0x87, 0x31, 0x01, 0xe2, 0x4a, 0x84, 0xd8, 0x13, 0x22, 0xf6,
		0xc4, 0x88, 0x37, 0x41, 0xe2, 0x41, 0x94, 0x98, 0x10, 0x26, 0x76, 0xc4, 0xa9, 0x30, 0x98, 0x97,
		0x68, 0x78, 0x26, 0xcf, 0x70, 0x12, 0x0f, 0x33, 0x25, 0x4e, 0x6c, 0x09, 0x14, 0x67, 0x22, 0xa5,
		0x00, 0xa1, 0xe2, 0x4e, 0xac, 0x94, 0x21, 0x58, 0xca, 0x10, 0x2d, 0x35, 0x08, 0x17, 0x2f, 0xe2,
		0xc5, 0x8c, 0x80, 0xb1, 0x25, 0x62, 0x85, 0xe1, 0x17, 0xa1, 0x7f, 0x99, 0xf2, 0x0d, 0x96, 0xd3,
		0x7c, 0x95, 0x3f, 0x06, 0xd3, 0xf8, 0xc2, 0x53, 0xa8, 0xcc, 0x9e, 0xa8, 0xa9, 0x40, 0xd8, 0x14,
		0x22, 0x6e, 0xaa, 0x10, 0x38, 0xe5, 0x88, 0x9c, 0x72, 0x84, 0x4e, 0x2d, 0x62, 0xc7, 0x93, 0xe0,
		0x31, 0x25, 0x7a, 0x05, 0x74, 0xd8, 0x0a, 0x9f, 0x67, 0x32, 0x86, 0x88, 0x86, 0x57, 0x22, 0xc9,
		0x67, 0x49, 0x19, 0x67, 0x8d, 0x69, 0x97, 0xab, 0xce, 0xf8, 0x19, 0xcc, 0x68, 0x78, 0x35, 0x02,
		0x15, 0x5c, 0xb9, 0xcc, 0x55, 0x67, 0x2d, 0x48, 0x2b, 0x9e, 0x82, 0xbd, 0x30, 0xed, 0xee, 0x49,
		0x14, 0x14, 0xa8, 0x15, 0x0f, 0xc7, 0x5a, 0xa8, 0xc6, 0x97, 0x6a, 0x30, 0x8c, 0x4d, 0x5a, 0x21,
		0x26, 0x60, 0x34, 0x66, 0x34, 0x97, 0x65, 0xdc, 0x7f, 0x18, 0xb4, 0x69, 0x64, 0x98, 0x8f, 0x36,
		0x0d, 0x21, 0x77, 0x40, 0x9b, 0x86, 0x8e, 0x5b, 0xa3, 0x4d, 0x43, 0xfc, 0x81, 0xd0, 0xa6, 0x01,
		0x7f, 0x5a, 0x10, 0x3a, 0xea, 0xb4, 0x69, 0xd2, 0x9b, 0x34, 0x13, 0x57, 0x7c, 0xe9, 0xd3, 0x1a,
		0xf3, 0xc3, 0xea, 0xee, 0x68, 0x08, 0xf3, 0xc3, 0xb0, 0x8a, 0x07, 0xf9, 0xdf, 0xe9, 0xba, 0xbe,
		0x63, 0xe8, 0x07, 0xbe, 0x7e, 0x71, 0xf6, 0x77, 0xfd, 0xf6, 0xaf, 0xbf, 0x3e, 0x3c, 0xf3, 0x8d,
		0x7f, 0xf1, 0x8d, 0xba, 0x67, 0x9c, 0x01, 0xa7, 0xc2, 0x11, 0x6c, 0xd5, 0x44, 0x1d, 0xba, 0x3b,
		0x60, 0x27, 0x73, 0xfc, 0xe0, 0xda, 0x0f, 0x87, 0x82, 0x7f, 0x5f, 0x27, 0x7f, 0x0c, 0x74, 0x74,
		0x64, 0x98, 0x8f, 0x8e, 0x0e, 0x21, 0x47, 0x40, 0x47, 0x87, 0x8e, 0x5b, 0xa3, 0xa3, 0x43, 0xfc,
		0x81, 0xd0, 0xd1, 0x01, 0x67, 0x5a, 0x10, 0x3a, 0xea, 0x74, 0x74, 0x86, 0x41, 0x94, 0x7d, 0xdc,
		0x54, 0xa0, 0x9d, 0xb3, 0xcd, 0xf8, 0x11, 0x1c, 0x3f, 0xba, 0x14, 0xec, 0xab, 0x6a, 0xde, 0x09,
		0x7b, 0x6d, 0x32, 0xbf, 0xc2, 0x9e, 0x79, 0x28, 0x52, 0x58, 0xcc, 0x3c, 0xce, 0xc9, 0xa4, 0x56,
		0x55, 0xe5, 0x79, 0x0e, 0x12, 0xbf, 0x97, 0x05, 0x71, 0xd4, 0x0c, 0x2e, 0x83, 0x7c, 0x5c, 0x8a,
		0xfd, 0x73, 0xdd, 0xbe, 0x57, 0x20, 0x04, 0xf8, 0xbf, 0x10, 0x02, 0x88, 0x87, 0x80, 0xfa, 0xe6,
		0x4e, 0x7d, 0xa7, 0xb1, 0xbd, 0xb9, 0xb3, 0x85, 0x58, 0x80, 0x82, 0x04, 0xd6, 0xdf, 0x7f, 0xa1,
		0xdd, 0x8f, 0x5c, 0x37, 0x2f, 0xcc, 0xfc, 0x14, 0xc1, 0xe5, 0xf7, 0x8c, 0x7f, 0xbf, 0x7f, 0xf2,
		0x1c, 0x68, 0xf8, 0xcb, 0x30, 0x1f, 0x0d, 0x7f, 0x42, 0x9e, 0x80, 0x86, 0x3f, 0x1d, 0xb7, 0x46,
		0xc3, 0x9f, 0xf8, 0x03, 0xa1, 0xe1, 0x0f, 0xd6, 0xb4, 0x20, 0x74, 0xd4, 0x6a, 0xf8, 0x7f, 0x52,
		0xa0, 0xdf, 0xbf, 0x85, 0x7e, 0xbf, 0xe4, 0x17, 0xfa, 0xfd, 0xa8, 0x2b, 0x56, 0xf8, 0x38, 0xe8,
		0xf7, 0x23, 0x9b, 0x97, 0x11, 0x02, 0xd0, 0xef, 0x27, 0x1f, 0x02, 0x36, 0xb7, 0xd0, 0xe8, 0x47,
		0x21, 0x02, 0xeb, 0x1f, 0xbc, 0xd0, 0xe8, 0x87, 0xc5, 0xec, 0x53, 0x32, 0xd7, 0xeb, 0x87, 0x0b,
		0xfb, 0xd5, 0xbf, 0x53, 0x74, 0xf6, 0x36, 0xc2, 0xd9, 0x6f, 0x71, 0xba, 0x95, 0x98, 0x9f, 0x5f,
		0x33, 0xf2, 0x69, 0xa6, 0x8a, 0x22, 0xd6, 0x4a, 0x22, 0xa6, 0xac, 0x1f, 0x77, 0x2b, 0xc8, 0x04,
		0x3a, 0xee, 0x56, 0x90, 0xe7, 0xae, 0xb8, 0x5b, 0x81, 0x1a, 0x09, 0xc5, 0xdd, 0x0a, 0xe0, 0x34,
		0xbf, 0x87, 0x08, 0xdb, 0x0d, 0xc0, 0xbb, 0x3b, 0x37, 0x85, 0x7f, 0x91, 0x88, 0x0b, 0x8e, 0x11,
		0x7f, 0x7a, 0x62, 0x0b, 0x43, 0x8d, 0x8f, 0xd6, 0x99, 0x94, 0x86, 0x1f, 0x3e, 0xe4, 0x45, 0x52,
		0x2d, 0xa7, 0x98, 0x28, 0x95, 0x2a, 0x6c, 0x29, 0x97, 0x9b, 0xfd, 0xbe, 0x88, 0x1b, 0x6e, 0x45,
		0x11, 0xcf, 0x83, 0x94, 0xf9, 0x1e, 0x9c, 0xac, 0xd4, 0x41, 0xc9, 0x3c, 0x0f, 0x46, 0xe6, 0x12,
		0x4d, 0x98, 0xb6, 0x7a, 0xd1, 0xe2, 0xe5, 0x74, 0x43, 0x7b, 0xfe, 0x89, 0x65, 0xc9, 0xb0, 0x97,
		0x45, 0x13, 0xe2, 0xdb, 0xca, 0x3f, 0x02, 0x6b, 0xf2, 0xf0, 0x5e, 0x67, 0xb2, 0xee, 0x9e, 0x95,
		0x06, 0xa9, 0x67, 0x8f, 0x16, 0xdc, 0xb3, 0xd3, 0x81, 0xe7, 0x86, 0xd7, 0x9e, 0x39, 0x59, 0x57,
		0x2b, 0x75, 0xee, 0xad, 0xaa, 0xd7, 0x9a, 0xac, 0xa5, 0x57, 0xfc, 0x23, 0xdd, 0xf1, 0xca, 0x79,
		0xb6, 0x1f, 0x19, 0xd3, 0x55, 0xea, 0x06, 0x7d, 0x1e, 0xb4, 0x8e, 0x3e, 0x49, 0xa2, 0x6d, 0x21,
		0xf1, 0x80, 0xcb, 0x2d, 0xd0, 0x56, 0x32, 0xc0, 0xd2, 0x8e, 0x14, 0x74, 0xfd, 0x8f, 0xb0, 0xef,
		0x69, 0x63, 0x50, 0xf9, 0x59, 0x96, 0x04, 0xe7, 0xc3, 0x4c, 0xd0, 0xbf, 0xd0, 0xf2, 0xae, 0x35,
		0xf4, 0xc8, 0x70, 0xe2, 0xf1, 0x8d, 0xc7, 0x5d, 0xe2, 0x6c, 0xf6, 0xb7, 0x38, 0xed, 0x67, 0x31,
		0xdc, 0xbf, 0xe2, 0xb6, 0x5f, 0xc5, 0x76, 0x7f, 0x8a, 0xed, 0x7e, 0x14, 0xcf, 0xfd, 0x27, 0x70,
		0xf4, 0xd7, 0x7c, 0xe4, 0x5c, 0xee, 0xea, 0xd6, 0xf2, 0xc9, 0x2e, 0x36, 0xc1, 0xab, 0xb8, 0xa9,
		0x60, 0x6c, 0x36, 0x97, 0x3e, 0x3b, 0x0b, 0x42, 0xc3, 0x8e, 0xd8, 0x70, 0x24, 0x38, 0x8c, 0x89,
		0x0e, 0x57, 0xc2, 0xc3, 0x9e, 0xf8, 0xb0, 0x27, 0x40, 0xbc, 0x89, 0x10, 0x0f, 0x42, 0xc4, 0x84,
		0x18, 0xb1, 0x23, 0x48, 0x85, 0xc1, 0x61, 0xdc, 0xf3, 0x43, 0x7d, 0x90, 0xc4, 0x99, 0xe8, 0xb1,
		0xd4, 0x33, 0xdc, 0xb5, 0x83, 0x1e, 0x3f, 0x09, 0xe6, 0xa1, 0x41, 0xab, 0xd4, 0xa2, 0x57, 0x0a,
		0xd0, 0x2c, 0xee, 0x74, 0x4b, 0x19, 0xda, 0xa5, 0x0c, 0xfd, 0x52, 0x83, 0x86, 0xf1, 0xa2, 0x63,
		0xcc, 0x68, 0x59, 0x01, 0x11, 0xfe, 0xf3, 0xd0, 0x22, 0x1a, 0x5e, 0x89, 0xc4, 0x67, 0x48, 0x70,
		0xee, 0x93, 0x9c, 0x8d, 0x3a, 0x43, 0xdb, 0xcd, 0x68, 0x78, 0x35, 0x02, 0x0f, 0x5c, 0x74, 0x95,
		0xab, 0xcc, 0x72, 0x12, 0xb6, 0xb0, 0x9e, 0xed, 0x44, 0xec, 0xdd, 0x13, 0x28, 0x34, 0x19, 0x5b,
		0x3c, 0x14, 0xcb, 0x09, 0x59, 0x7e, 0x94, 0x00, 0xbd, 0xa4, 0xa5, 0xf2, 0x59, 0x4c, 0x1e, 0x53,
		0x1d, 0x8c, 0x7b, 0x38, 0x79, 0xc4, 0xe9, 0x1c, 0x09, 0x4c, 0xd1, 0x2a, 0x1d, 0x3c, 0x30, 0x45,
		0x4b, 0x3d, 0x58, 0x70, 0x98, 0xfd, 0x2a, 0x51, 0x89, 0x10, 0x44, 0x3f, 0x8c, 0xbb, 0xb5, 0xc1,
		0x78, 0xb1, 0x6a, 0x41, 0x29, 0x9f, 0xd2, 0xed, 0x8b, 0xd0, 0xbf, 0x61, 0x36, 0x59, 0x9c, 0xdb,
		0x8c, 0xa1, 0xe2, 0x65, 0x98, 0x89, 0xa1, 0xe2, 0x15, 0xa2, 0x15, 0x43, 0xc5, 0xab, 0x73, 0x2f,
		0x0c, 0x15, 0x97, 0xcd, 0x5f, 0x31, 0x54, 0x5c, 0xb5, 0x92, 0x05, 0x43, 0xc5, 0xab, 0xcd, 0x0f,
		0x18, 0x2a, 0x06, 0xb1, 0xe1, 0x48, 0x70, 0x18, 0x13, 0x1d, 0xae, 0x84, 0x87, 0x3d, 0xf1, 0x61,
		0x4f, 0x80, 0x78, 0x13, 0x21, 0x1e, 0x84, 0x88, 0x09, 0x31, 0x62, 0x47, 0x90, 0x0a, 0x83, 0x7d,
		0xfd, 0x3c, 0xc8, 0xf8, 0x4e, 0x12, 0xe7, 0xe6, 0x63, 0x7c, 0x18, 0x04, 0x4a, 0x2d, 0x22, 0xa5,
		0x00, 0xa1, 0xe2, 0x4e, 0xac, 0x94, 0x21, 0x58, 0xca, 0x10, 0x2d, 0x35, 0x08, 0x17, 0x2f, 0xe2,
		0xc5, 0x8c, 0x80, 0x15, 0x10, 0xe1, 0x3f, 0x3e, 0x7c, 0x1e, 0xc7, 0xa1, 0xf0, 0x59, 0x8f, 0x0e,
		0x6f, 0x60, 0x78, 0xaf, 0xea, 0xce, 0xa8, 0xf1, 0xd8, 0x4f, 0x9e, 0xeb, 0x85, 0x1c, 0xb6, 0x96,
		0x51, 0x60, 0xa0, 0xc0, 0x40, 0x81, 0x81, 0x02, 0x03, 0x05, 0x06, 0x0a, 0x0c, 0x14, 0x18, 0x28,
		0x30, 0xfe, 0x30, 0xe2, 0x0f, 0x83, 0x28, 0xfb, 0xb8, 0xc9, 0xb8, 0xbe, 0xe0, 0x78, 0x5b, 0x8b,
		0xe3, 0x47, 0x97, 0xa3, 0xd5, 0x3f, 0x65, 0x19, 0x18, 0xf9, 0xde, 0x62, 0xae, 0x1d, 0x05, 0x11,
		0xfb, 0x6b, 0xd8, 0x15, 0xb9, 0x7e, 0xbd, 0xb8, 0x76, 0x9d, 0xfb, 0x73, 0x28, 0x74, 0xd9, 0xfa,
		0xed, 0x7b, 0xc6, 0xae, 0xed, 0xff, 0x82, 0x6b, 0x13, 0x73, 0xed, 0xfa, 0xe6, 0x4e, 0x7d, 0xa7,
		0xb1, 0xbd, 0xb9, 0xb3, 0x05, 0x1f, 0x47, 0x41, 0x50, 0x2d, 0xab, 0xcf, 0xd0, 0xf6, 0xae, 0xb0,
		0xa5, 0xd0, 0xac, 0xaf, 0xd6, 0xee, 0x8a, 0xc8, 0x50, 0xc7, 0x1b, 0x0f, 0x90, 0xab, 0x57, 0xc7,
		0x42, 0xc8, 0xd5, 0x11, 0x27, 0x16, 0x8d, 0x13, 0x50, 0xaa, 0x3f, 0x56, 0xaa, 0x37, 0xc7, 0xcb,
		0x02, 0x91, 0xba, 0x6a, 0xa1, 0xe8, 0x9e, 0xe0, 0x5b, 0xbf, 0xf6, 0x93, 0x80, 0x47, 0x40, 0x7a,
		0x42, 0xae, 0x7e, 0xcf, 0x7a, 0x08, 0xd7, 0x97, 0x61, 0x26, 0x84, 0xeb, 0x2b, 0xc4, 0x2d, 0x84,
		0xeb, 0xab, 0x73, 0x2f, 0x08, 0xd7, 0xcb, 0x66, 0xb2, 0x10, 0xae, 0x57, 0xad, 0x78, 0x81, 0x70,
		0x7d, 0xb5, 0xf9, 0x01, 0xc2, 0x75, 0x10, 0x1b, 0x8e, 0x04, 0x87, 0x31, 0xd1, 0xe1, 0x4a, 0x78,
		0xd8, 0x13, 0x1f, 0xf6, 0x04, 0x88, 0x37, 0x11, 0xe2, 0x41, 0x88, 0x98, 0x10, 0x23, 0x76, 0x04,
		0xa9, 0x30, 0x18, 0xba, 0x12, 0x69, 0xc4, 0x09, 0xba, 0x12, 0x10, 0x29, 0x85, 0x09, 0x15, 0x77,
		0x62, 0xa5, 0x0c, 0xc1, 0x52, 0x86, 0x68, 0xa9, 0x41, 0xb8, 0x78, 0x11, 0x2f, 0x66, 0x04, 0xac,
		0x80, 0x08, 0x74, 0x25, 0xd2, 0xf9, 0x0d, 0x74, 0x25, 0x65, 0xbf, 0xa0, 0x2b, 0x01, 0xb1, 0x5f,
		0xc2, 0x63, 0x40, 0x57, 0x82, 0xf4, 0xbb, 0x4c, 0xd7, 0x86, 0xae, 0x84, 0x9c, 0x6b, 0x43, 0x57,
		0x82, 0x82, 0xa0, 0xaa, 0x56, 0x43, 0x57, 0x52, 0x65, 0x4b, 0xa1, 0x2b, 0x59, 0xad, 0xdd, 0x55,
		0x9a, 0x17, 0xbf, 0x1b, 0x3e, 0x85, 0xc2, 0xa4, 0x3a, 0x16, 0x42, 0x61, 0x82, 0x88, 0xf1, 0xfa,
		0x88, 0x01, 0xad, 0xc9, 0x93, 0x5a, 0x93, 0x93, 0x62, 0x7d, 0x20, 0x3a, 0x51, 0x2d, 0x3a, 0xe5,
		0xb2, 0x8d, 0xa0, 0xcf, 0x4c, 0x67, 0x12, 0xf4, 0x21, 0x2d, 0x59, 0x8a, 0x99, 0x90, 0x96, 0xac,
		0x10, 0xaa, 0x90, 0x96, 0xac, 0xce, 0xbd, 0x20, 0x2d, 0x29, 0x9b, 0xc2, 0x42, 0x5a, 0x52, 0xb5,
		0xaa, 0x05, 0xd2, 0x92, 0xd5, 0xe6, 0x07, 0x48, 0x4b, 0x40, 0x6c, 0x38, 0x12, 0x1c, 0xc6, 0x44,
		0x87, 0x2b, 0xe1, 0x61, 0x4f, 0x7c, 0xd8, 0x13, 0x20, 0xde, 0x44, 0x88, 0x07, 0x21, 0x62, 0x42,
		0x8c, 0xd8, 0x11, 0xa4, 0xc2, 0xe0, 0x30, 0xee, 0xf9, 0x21, 0x5f, 0x69, 0x49, 0x6e, 0x3e, 0xa4,
		0x25, 0x20, 0x50, 0x6a, 0x11, 0x29, 0x05, 0x08, 0x15, 0x77, 0x62, 0xa5, 0x0c, 0xc1, 0x52, 0x86,
		0x68, 0xa9, 0x41, 0xb8, 0x78, 0x11, 0x2f, 0x66, 0x04, 0xac, 0x80, 0x08, 0xa4, 0x25, 0xd2, 0xf9,
		0x0d, 0xa4, 0x25, 0x65, 0xbf, 0x20, 0x2d, 0x01, 0xb1, 0x5f, 0xc2, 0x63, 0x40, 0x5a, 0x82, 0xf4,
		0xbb, 0x4c, 0xd7, 0x86, 0xb4, 0x84, 0x9c, 0x6b, 0x43, 0x5a, 0x82, 0x82, 0xa0, 0xaa, 0x56, 0x43,
		0x5a, 0x52, 0xf9, 0x1c, 0xa5, 0x25, 0xe2, 0x2a, 0xce, 0x04, 0xdf, 0xbe, 0xf7, 0xc4, 0x7e, 0x34,
		0xbe, 0xcb, 0x30, 0x1b, 0x8d, 0x6f, 0x89, 0x48, 0x47, 0xe3, 0x5b, 0x9e, 0xbb, 0xa2, 0xf1, 0x4d,
		0xec, 0x41, 0xd0, 0xf8, 0x06, 0xab, 0x79, 0x06, 0x22, 0x68, 0x7c, 0x4b, 0xe7, 0x37, 0x68, 0x7c,
		0x97, 0xfd, 0x42, 0xe3, 0x1b, 0xc4, 0x7e, 0x09, 0x8f, 0x81, 0xc6, 0x37, 0xd2, 0xef, 0x32, 0x5d,
		0x1b, 0x8d, 0x6f, 0x72, 0xae, 0x8d, 0xc6, 0x37, 0x0a, 0x82, 0xaa, 0x5a, 0x8d, 0xc6, 0x77, 0x95,
		0x2d, 0xc5, 0x99, 0x4a, 0xab, 0xb5, 0xbb, 0x22, 0x27, 0xa4, 0x04, 0x7d, 0x1c, 0xa3, 0x54, 0x1d,
		0x0b, 0x71, 0x8c, 0x12, 0x82, 0xc4, 0x42, 0x41, 0x02, 0x27, 0x27, 0x3d, 0x3e, 0x39, 0xc9, 0xea,
		0xe3, 0xb4, 0x24, 0xe5, 0x82, 0x50, 0x7e, 0xf8, 0x50, 0x18, 0xa7, 0x29, 0xb3, 0xf3, 0x92, 0xc6,
		0x26, 0xe3, 0xc4, 0xa4, 0x65, 0x98, 0x89, 0x13, 0x93, 0x56, 0x08, 0x56, 0x9c, 0x98, 0xb4, 0x3a,
		0xf7, 0xc2, 0x89, 0x49, 0x65, 0xb3, 0x55, 0x9c, 0x98, 0x54, 0xb5, 0x02, 0x05, 0x27, 0x26, 0xad,
		0x36, 0x3f, 0xe0, 0xc4, 0x24, 0x10, 0x1b, 0x8e, 0x04, 0x87, 0x31, 0xd1, 0xe1, 0x4a, 0x78, 0xd8,
		0x13, 0x1f, 0xf6, 0x04, 0x88, 0x37, 0x11, 0xe2, 0x41, 0x88, 0x98, 0x10, 0x23, 0x76, 0x04, 0xa9,
		0x30, 0xd8, 0xd7, 0xcf, 0x83, 0x8c, 0xaf, 0x72, 0x24, 0x37, 0x1f, 0xc2, 0x11, 0x10, 0x28, 0xb5,
		0x88, 0x94, 0x02, 0x84, 0x8a, 0x3b, 0xb1, 0x52, 0x86, 0x60, 0x29, 0x43, 0xb4, 0xd4, 0x20, 0x5c,
		0xbc, 0x88, 0x17, 0x33, 0x02, 0x56, 0x40, 0x84, 0xbf, 0x70, 0xe4, 0x3c, 0x8e, 0x43, 0xe1, 0x47,
		0x8c, 0x95, 0x23, 0x1b, 0x1b, 0x18, 0xd1, 0xab, 0xba, 0x33, 0x32, 0xda, 0x52, 0x9e, 0xeb, 0x89,
		0x5c, 0xb6, 0x98, 0x51, 0x68, 0xa0, 0xd0, 0x40, 0xa1, 0x81, 0x42, 0x03, 0x85, 0x06, 0x0a, 0x0d,
		0x14, 0x1a, 0x28, 0x34, 0xfe, 0x30, 0xe2, 0x43, 0xa1, 0x2e, 0xc1, 0x74, 0x28, 0xd4, 0x25, 0x2d,
		0x3c, 0x14, 0xea, 0x74, 0x1e, 0x03, 0x0a, 0x75, 0xa4, 0xdf, 0x65, 0xba, 0x36, 0x14, 0xea, 0xe4,
		0x5c, 0x1b, 0x0a, 0x75, 0x14, 0x04, 0x55, 0xb5, 0x1a, 0x0a, 0xf5, 0x2a, 0x5b, 0x0a, 0x85, 0xfa,
		0x6a, 0xed, 0xae, 0x88, 0xf8, 0x34, 0x8c, 0xd3, 0x14, 0x1a, 0xf5, 0xea, 0x58, 0x08, 0x8d, 0x3a,
		0xc2, 0xc4, 0x82, 0x61, 0x02, 0x2a, 0xf5, 0xc7, 0x2a, 0x75, 0x7b, 0xb4, 0x2a, 0xd0, 0xa9, 0xab,
		0x16, 0x88, 0xf2, 0x1d, 0xf9, 0x91, 0x07, 0x8a, 0x71, 0x4d, 0xa6, 0x67, 0x1c, 0x9a, 0xf0, 0x0f,
		0xe7, 0x09, 0x1e, 0x5b, 0x0f, 0xf5, 0xfa, 0x32, 0xcc, 0x84, 0x7a, 0x7d, 0x85, 0xb8, 0x85, 0x7a,
		0x7d, 0x75, 0xee, 0x05, 0xf5, 0x7a, 0xd9, 0x3c, 0x16, 0xea, 0xf5, 0xaa, 0x95, 0x2e, 0x50, 0xaf,
		0xaf, 0x36, 0x3f, 0x40, 0xbd, 0x0e, 0x62, 0xc3, 0x91, 0xe0, 0x30, 0x26, 0x3a, 0x5c, 0x09, 0x0f,
		0x7b, 0xe2, 0xc3, 0x9e, 0x00, 0xf1, 0x26, 0x42, 0x3c, 0x08, 0x11, 0x13, 0x62, 0xc4, 0x8e, 0x20,
		0x15, 0x06, 0x67, 0x1c, 0x87, 0x2f, 0x8b, 0x34, 0xc3, 0xa0, 0xef, 0x33, 0x8f, 0x36, 0x41, 0x52,
		0x02, 0x1a, 0xa5, 0x30, 0x9d, 0xe2, 0x4e, 0xab, 0x94, 0xa1, 0x57, 0xca, 0xd0, 0x2c, 0x35, 0xe8,
		0x16, 0x2f, 0xda, 0xc5, 0x8c, 0x7e, 0x15, 0x10, 0xe1, 0x2f, 0x29, 0x11, 0xd1, 0xf0, 0x4a, 0x24,
		0xf9, 0x94, 0x00, 0x63, 0xfd, 0x7a, 0x9d, 0xa1, 0xed, 0x66, 0x34, 0xbc, 0x1a, 0x81, 0x07, 0x2e,
		0xba, 0xca, 0x55, 0xb6, 0x83, 0x34, 0x33, 0xb2, 0x2c, 0xe1, 0xe9, 0xa6, 0x47, 0x41, 0x64, 0x86,
		0x62, 0x94, 0x85, 0x52, 0x9e, 0xa3, 0xe6, 0xda, 0x91, 0xff, 0xeb, 0xde, 0x13, 0x6c, 0x7c, 0xaa,
		0xd7, 0x1b, 0xdb, 0xf5, 0xfa, 0xfa, 0xf6, 0xc7, 0xed, 0xf5, 0x9d, 0xad, 0xad, 0x8d, 0xc6, 0x06,
		0xc3, 0x71, 0x73, 0xad, 0x9d, 0xf4, 0x45, 0x22, 0xfa, 0x7b, 0x37, 0xda, 0xee, 0x5a, 0x34, 0x0c,
		0x43, 0x8c, 0x0f, 0x57, 0xd8, 0x52, 0x8c, 0x0f, 0xaf, 0xd6, 0xee, 0x8a, 0xcc, 0x05, 0x3e, 0x1a,
		0x33, 0xc2, 0x24, 0x71, 0x75, 0x2c, 0xc4, 0x24, 0x31, 0x22, 0xc6, 0xeb, 0x23, 0x06, 0x86, 0x8a,
		0x1f, 0x0f, 0x15, 0x77, 0x8a, 0x05, 0x1a, 0x17, 0xea, 0x18, 0x2f, 0x56, 0x2d, 0x3a, 0x69, 0x57,
		0xfe, 0x2f, 0x7d, 0xec, 0x0b, 0xe7, 0x7e, 0xd4, 0xff, 0x19, 0xf4, 0xc7, 0x1e, 0xcf, 0x64, 0xb8,
		0xf8, 0x09, 0xdb, 0x31, 0x5a, 0xbc, 0x0c, 0x33, 0x31, 0x5a, 0xbc, 0x42, 0xd4, 0x62, 0xb4, 0x78,
		0x75, 0xee, 0x85, 0xd1, 0xe2, 0xb2, 0x89, 0x2d, 0x46, 0x8b, 0xab, 0x56, 0xcb, 0x60, 0xb4, 0x78,
		0xb5, 0xf9, 0x01, 0xa3, 0xc5, 0x20, 0x36, 0x1c, 0x09, 0x0e, 0x63, 0xa2, 0xc3, 0x95, 0xf0, 0xb0,
		0x27, 0x3e, 0xec, 0x09, 0x10, 0x6f, 0x22, 0xc4, 0x83, 0x10, 0x31, 0x21, 0x46, 0xec, 0x08, 0x52,
		0x61, 0x30, 0x9f, 0xd6, 0xcf, 0xdc, 0x5c, 0xc3, 0xa5, 0x03, 0x34, 0x8f, 0x40, 0x61, 0xc8, 0x18,
		0x84, 0x4a, 0x61, 0x62, 0xc5, 0x9d, 0x60, 0x29, 0x43, 0xb4, 0x94, 0x21, 0x5c, 0x6a, 0x10, 0x2f,
		0x5e, 0x04, 0x8c, 0x19, 0x11, 0x2b, 0x20, 0xc2, 0x7f, 0xc8, 0x38, 0x10, 0x42, 0x5c, 0x84, 0xb1,
		0xcf, 0xfb, 0xf0, 0xfa, 0x1d, 0x86, 0xa6, 0xdb, 0x22, 0xba, 0x1c, 0x13, 0x63, 0x9c, 0x5e, 0x5f,
		0xf2, 0xca, 0xe3, 0xf4, 0x7a, 0x3a, 0x8f, 0x51, 0x1c, 0x71, 0x8d, 0x93, 0xad, 0x91, 0x84, 0x97,
		0xe0, 0xda, 0x38, 0xbd, 0x1e, 0xae, 0x0d, 0xd7, 0x56, 0xa3, 0x1a, 0xe0, 0x6b, 0x35, 0x0e, 0xad,
		0xaf, 0xb2, 0xa5, 0x50, 0x9d, 0xac, 0xd6, 0x6e, 0xf5, 0x67, 0xc8, 0x67, 0xe7, 0x4f, 0xa1, 0x39,
		0xa9, 0x8e, 0x85, 0xd0, 0x9c, 0x20, 0x5e, 0xbc, 0x36, 0x5e, 0x40, 0x71, 0x72, 0x5f, 0x71, 0x72,
		0xe4, 0xff, 0xb2, 0x83, 0xe8, 0xc7, 0x5e, 0xb1, 0x3a, 0xd0, 0x9b, 0xa8, 0x16, 0x99, 0xc6, 0x9a,
		0x8d, 0x44, 0xa4, 0x22, 0xb9, 0xf6, 0xcf, 0x43, 0xc1, 0x5a, 0x7a, 0x32, 0xff, 0x31, 0xa0, 0x42,
		0x59, 0x86, 0x99, 0x50, 0xa1, 0xac, 0x10, 0xc0, 0x50, 0xa1, 0xac, 0xce, 0xbd, 0xa0, 0x42, 0x29,
		0x9b, 0xea, 0x42, 0x85, 0x52, 0xb5, 0xea, 0x06, 0x2a, 0x94, 0xd5, 0xe6, 0x07, 0xa8, 0x50, 0x40,
		0x6c, 0x38, 0x12, 0x1c, 0xc6, 0x44, 0x87, 0x2b, 0xe1, 0x61, 0x4f, 0x7c, 0xd8, 0x13, 0x20, 0xde,
		0x44, 0x88, 0x07, 0x21, 0x62, 0x42, 0x8c, 0xd8, 0x11, 0xa4, 0xc2, 0x60, 0xa8, 0x50, 0xa4, 0x13,
		0x28, 0xa8, 0x50, 0x40, 0xa8, 0x14, 0x26, 0x56, 0xdc, 0x09, 0x96, 0x32, 0x44, 0x4b, 0x19, 0xc2,
		0xa5, 0x06, 0xf1, 0xe2, 0x45, 0xc0, 0x98, 0x11, 0xb1, 0x02, 0x22, 0x50, 0xa1, 0xd0, 0x20, 0x39,
		0x50, 0xa1, 0x94, 0xfe, 0x82, 0x0a, 0x05, 0xf4, 0x7e, 0x09, 0x8f, 0x81, 0x51, 0x75, 0x24, 0xe1,
		0x65, 0xba, 0x36, 0x54, 0x28, 0x70, 0x6d, 0xb8, 0xb6, 0x1a, 0xd5, 0x00, 0x5f, 0xab, 0xa1, 0x42,
		0xa9, 0xb2, 0xa5, 0x50, 0xa1, 0xac, 0xd6, 0xee, 0x6a, 0x4c, 0x95, 0xcf, 0x1d, 0x45, 0x85, 0x20,
		0xa5, 0x3a, 0x16, 0x42, 0x90, 0x82, 0xd0, 0xb1, 0xc4, 0xd0, 0x01, 0x6d, 0xca, 0x23, 0x6d, 0x8a,
		0x53, 0xac, 0x14, 0x54, 0x2a, 0x6a, 0x87, 0x2b, 0xed, 0x2a, 0x88, 0xf4, 0x42, 0xad, 0xd5, 0x17,
		0xa1, 0x7f, 0xc3, 0x48, 0x9a, 0x32, 0x6b, 0x3b, 0xf4, 0x28, 0xcb, 0x30, 0x13, 0x7a, 0x94, 0x15,
		0xa2, 0x16, 0x7a, 0x94, 0xd5, 0xb9, 0x17, 0xf4, 0x28, 0x65, 0x33, 0x5d, 0xe8, 0x51, 0xaa, 0x56,
		0xdc, 0x40, 0x8f, 0xb2, 0xda, 0xfc, 0x00, 0x3d, 0x0a, 0x88, 0x0d, 0x47, 0x82, 0xc3, 0x98, 0xe8,
		0x70, 0x25, 0x3c, 0xec, 0x89, 0x0f, 0x7b, 0x02, 0xc4, 0x9b, 0x08, 0xf1, 0x20, 0x44, 0x4c, 0x88,
		0x11, 0x3b, 0x82, 0x54, 0x18, 0xec, 0xeb, 0xe7, 0x41, 0xc6, 0x57, 0x8b, 0x92, 0x9b, 0x0f, 0x1d,
		0x0a, 0x08, 0x94, 0x5a, 0x44, 0x4a, 0x01, 0x42, 0xc5, 0x9d, 0x58, 0x29, 0x43, 0xb0, 0x94, 0x21,
		0x5a, 0x6a, 0x10, 0x2e, 0x5e, 0xc4, 0x8b, 0x19, 0x01, 0x2b, 0x20, 0xc2, 0x5f, 0x87, 0x72, 0x1e,
		0xc7, 0xa1, 0xf0, 0x23, 0xc6, 0x1a, 0x94, 0x8d, 0x0d, 0x0c, 0xfd, 0x55, 0xdd, 0x19, 0xc7, 0x67,
		0x08, 0xf2, 0xd8, 0x5b, 0x9e, 0xeb, 0x89, 0x77, 0x8f, 0x80, 0x42, 0x03, 0x85, 0x06, 0x0a, 0x0d,
		0x14, 0x1a, 0x28, 0x34, 0x50, 0x68, 0x80, 0xd7, 0xa0, 0xd0, 0x50, 0xa2, 0xd0, 0x18, 0x06, 0x11,
		0x6f, 0xad, 0xfb, 0x36, 0x43, 0xd3, 0x1d, 0x3f, 0xba, 0x14, 0x90, 0xba, 0x97, 0xbf, 0xf0, 0x90,
		0xba, 0xd3, 0x79, 0x8c, 0xa9, 0x1e, 0x76, 0x1d, 0x7a, 0x58, 0xa4, 0xdf, 0x25, 0xb8, 0x36, 0xa4,
		0xee, 0xe4, 0x5c, 0xbb, 0xbe, 0xb9, 0x53, 0xdf, 0x69, 0x6c, 0x6f, 0xee, 0x6c, 0xc1, 0xc7, 0x51,
		0x10, 0x54, 0xcb, 0x6a, 0x68, 0xde, 0x2b, 0x9f, 0xa3, 0xc6, 0x3a, 0x25, 0xee, 0xed, 0xef, 0xe2,
		0x11, 0xd0, 0xfe, 0x2e, 0xc3, 0x6c, 0xb4, 0xbf, 0x25, 0x82, 0x1d, 0xed, 0x6f, 0x79, 0xee, 0x8a,
		0xf6, 0x37, 0xb1, 0x07, 0x41, 0xfb, 0x1b, 0xdc, 0xe6, 0x19, 0x88, 0xa0, 0xfd, 0x2d, 0x9d, 0xdf,
		0xa0, 0xfd, 0x5d, 0xf6, 0x0b, 0xed, 0x6f, 0x10, 0xfb, 0x25, 0x3c, 0x06, 0xda, 0xdf, 0x48, 0xbf,
		0xcb, 0x74, 0x6d, 0xb4, 0xbf, 0xc9, 0xb9, 0x36, 0xda, 0xdf, 0x28, 0x08, 0xaa, 0x6a, 0x35, 0xda,
		0xdf, 0x55, 0xb6, 0x14, 0x47, 0xbe, 0xae, 0xd6, 0xee, 0x0a, 0x9c, 0xdb, 0x38, 0x73, 0xc4, 0x1b,
		0xce, 0x79, 0xad, 0x8e, 0x85, 0x38, 0xe7, 0x15, 0xf1, 0xe2, 0xb5, 0xf1, 0x02, 0x87, 0xbb, 0x3e,
		0x38, 0xdc, 0x35, 0x88, 0x8e, 0xfc, 0x5f, 0x76, 0x10, 0xfd, 0x68, 0x8e, 0x17, 0x07, 0x27, 0xba,
		0xaa, 0x16, 0x98, 0xb4, 0x44, 0xa4, 0x41, 0x7f, 0xe8, 0x87, 0x3a, 0x9f, 0x6b, 0x66, 0x8b, 0x3e,
		0xfc, 0x13, 0xb6, 0xe3, 0x44, 0xd7, 0x65, 0x98, 0x89, 0x13, 0x5d, 0x57, 0x88, 0x5a, 0x9c, 0xe8,
		0xba, 0x3a, 0xf7, 0xc2, 0x89, 0xae, 0x65, 0x73, 0x5a, 0x9c, 0xe8, 0x5a, 0xb5, 0x32, 0x06, 0x27,
		0xba, 0xae, 0x36, 0x3f, 0xe0, 0x44, 0x57, 0x10, 0x1b, 0x8e, 0x04, 0x87, 0x31, 0xd1, 0xe1, 0x4a,
		0x78, 0xd8, 0x13, 0x1f, 0xf6, 0x04, 0x88, 0x37, 0x11, 0xe2, 0x41, 0x88, 0x98, 0x10, 0x23, 0x76,
		0x04, 0xa9, 0x30, 0x98, 0x4f, 0xeb, 0x67, 0x6e, 0xae, 0xe1, 0x74, 0x3b, 0xd7, 0x53, 0x04, 0x0a,
		0x8a, 0x13, 0x10, 0x2a, 0x85, 0x89, 0x15, 0x77, 0x82, 0xa5, 0x0c, 0xd1, 0x52, 0x86, 0x70, 0xa9,
		0x41, 0xbc, 0x78, 0x11, 0x30, 0x66, 0x44, 0xac, 0x80, 0x08, 0x7f, 0xc5, 0x49, 0x20, 0x84, 0xb8,
		0x08, 0x63, 0x9f, 0xb7, 0xec, 0x64, 0x87, 0xa1, 0xe9, 0xb6, 0x88, 0x2e, 0xc7, 0xc4, 0x18, 0xba,
		0x93, 0x92, 0x57, 0x1e, 0xba, 0x13, 0x3a, 0x8f, 0x51, 0x0c, 0xa7, 0x63, 0x26, 0x1d, 0x49, 0x78,
		0x09, 0xae, 0x0d, 0xdd, 0x09, 0x5c, 0x1b, 0xae, 0xad, 0x46, 0x35, 0xc0, 0xd7, 0x6a, 0xc8, 0x4d,
		0xaa, 0x6c, 0x29, 0xe4, 0x26, 0xab, 0xb5, 0x5b, 0xfd, 0xf1, 0xf1, 0xd9, 0xf9, 0x53, 0xc8, 0x4d,
		0xaa, 0x63, 0x21, 0xe4, 0x26, 0x88, 0x17, 0xaf, 0x8d, 0x17, 0x90, 0x9b, 0xdc, 0x97, 0x9b, 0x38,
		0x93, 0xf5, 0xd9, 0x2b, 0x96, 0x07, 0x82, 0x13, 0xd5, 0x42, 0x13, 0x93, 0xa9, 0x4c, 0x56, 0xd3,
		0x98, 0x90, 0x95, 0x2c, 0xd9, 0x50, 0xc8, 0x4a, 0x56, 0x6a, 0x32, 0x64, 0x25, 0x25, 0x19, 0x0e,
		0x59, 0x09, 0xf8, 0x00, 0x97, 0x72, 0x85, 0x8d, 0xac, 0x24, 0xe3, 0x34, 0x4d, 0x50, 0xa4, 0x87,
		0xb1, 0xd5, 0xbc, 0x44, 0x25, 0xeb, 0x10, 0x95, 0x54, 0x9e, 0xde, 0x30, 0xa6, 0x39, 0x5c, 0xe9,
		0x0e, 0x7b, 0xda, 0xc3, 0x9e, 0xfe, 0xf0, 0xa6, 0x41, 0x3c, 0xe8, 0x10, 0x13, 0x5a, 0x54, 0x40,
		0x81, 0xdd, 0x0c, 0xe3, 0xdd, 0xec, 0x62, 0x5f, 0x44, 0x59, 0x90, 0xdd, 0x24, 0xe2, 0x82, 0x53,
		0xd4, 0x9e, 0xf6, 0x54, 0x18, 0x1d, 0xc3, 0xa9, 0x59, 0x93, 0xa5, 0xde, 0xf3, 0x53, 0xc1, 0x57,
		0xcb, 0x63, 0x75, 0xad, 0xae, 0xd7, 0x3d, 0xde, 0x73, 0xed, 0x13, 0xcf, 0xfd, 0xd6, 0x31, 0xb9,
		0xa5, 0x9d, 0xf1, 0x44, 0x4d, 0xca, 0x72, 0x64, 0x94, 0xa9, 0x2a, 0xa3, 0x40, 0x4e, 0xc7, 0x73,
		0x4c, 0x63, 0xff, 0xb3, 0xb1, 0x67, 0xd9, 0x96, 0xfb, 0x6d, 0x02, 0xa2, 0x2e, 0x47, 0x14, 0xa9,
		0x80, 0x26, 0xde, 0xa8, 0x7a, 0x16, 0x5d, 0x1d, 0xc7, 0x3c, 0xb0, 0xbe, 0x7a, 0x07, 0xb6, 0x71,
		0xd8, 0xd5, 0x30, 0x47, 0x0a, 0x5c, 0x2d, 0x09, 0x57, 0x56, 0xe7, 0xa4, 0xee, 0x39, 0xed, 0x63,
		0xd7, 0x74, 0x3c, 0xab, 0x09, 0x64, 0x01, 0x59, 0xcb, 0x42, 0x96, 0x6b, 0x1c, 0x02, 0x4e, 0x80,
		0xd3, 0x12, 0xe1, 0xd4, 0xa8, 0x03, 0x50, 0x00, 0xd4, 0x12, 0x33, 0x5f, 0x03, 0x99, 0x0f, 0xc8,
		0x5a, 0x19, 0x57, 0xef, 0xb2, 0x46, 0x15, 0x4b, 0xcb, 0xcf, 0xde, 0xc0, 0x7b, 0xe1, 0xb5, 0x55,
		0xaa, 0xac, 0x81, 0x1f, 0x54, 0xd0, 0x40, 0x10, 0x2a, 0x65, 0xc0, 0xa6, 0x8a, 0xb0, 0xe1, 0x58,
		0x11, 0x03, 0x38, 0xa8, 0x7c, 0x81, 0x20, 0x54, 0xb8, 0x40, 0x4f, 0x55, 0xd0, 0x33, 0x09, 0x35,
		0xfb, 0x46, 0x07, 0x7b, 0xe5, 0xc0, 0x55, 0x29, 0xf8, 0x72, 0x3c, 0xc3, 0x3e, 0x6c, 0x3b, 0x96,
		0xfb, 0xf9, 0x08, 0x9d, 0x5d, 0x20, 0x6b, 0xa9, 0xc8, 0xba, 0xfb, 0x13, 0xda, 0xbb, 0xe5, 0xbe,
		0xd0, 0xde, 0x85, 0xeb, 0x56, 0x2d, 0x19, 0x00, 0x41, 0x08, 0xfa, 0x80, 0x10, 0xb7, 0x7a, 0xb9,
		0x8b, 0xd9, 0x60, 0xa0, 0xaa, 0x2c, 0x74, 0xd9, 0x56, 0xeb, 0x0b, 0x46, 0x58, 0x00, 0xa9, 0x25,
		0x42, 0xea, 0xb8, 0xb5, 0xdf, 0x6e, 0x75, 0x5d, 0xc7, 0xb0, 0x5a, 0x66, 0xd3, 0xb3, 0xbb, 0x1d,
		0x80, 0x0b, 0xe0, 0x5a, 0x6a, 0xbc, 0x32, 0x5c, 0xd7, 0xb1, 0xf6, 0x8e, 0x5d, 0x13, 0x72, 0x06,
		0x40, 0x6b, 0x69, 0xd0, 0x1a, 0x6f, 0x6d, 0xb5, 0x4c, 0xeb, 0xf0, 0xf3, 0x5e, 0xdb, 0xf1, 0x8c,
		0x66, 0xd3, 0x31, 0xbb, 0x00, 0x18, 0x00, 0xb6, 0x4c, 0x80, 0xd5, 0x3d, 0xab, 0xe5, 0x9a, 0xce,
		0x81, 0xb1, 0x6f, 0x02, 0x61, 0x40, 0xd8, 0xd2, 0xa9, 0x97, 0x6b, 0xd9, 0xd6, 0x7f, 0xcd, 0xa6,
		0xb7, 0x67, 0xb4, 0x9a, 0xff, 0xb1, 0x9a, 0xee, 0x67, 0xa0, 0x0b, 0xe8, 0x5a, 0x2a, 0xf7, 0xea,
		0x38, 0x6d, 0xd7, 0xdc, 0x77, 0xad, 0x76, 0x2b, 0xef, 0x48, 0x00, 0x5f, 0xc0, 0xd7, 0x92, 0xf0,
		0xe5, 0x98, 0x5d, 0xab, 0x79, 0x6c, 0xd8, 0x88, 0x5e, 0x40, 0xd7, 0xf2, 0xd1, 0x75, 0x64, 0x7c,
		0xcd, 0x23, 0x18, 0xd0, 0x05, 0x74, 0xad, 0xa6, 0x78, 0x04, 0xb7, 0x07, 0xc2, 0x56, 0x1a, 0xbf,
		0x1c, 0xb3, 0x6b, 0x3a, 0x27, 0xc6, 0x9e, 0x6d, 0x22, 0x8a, 0x01, 0x63, 0x2b, 0x62, 0xf8, 0x76,
		0x1b, 0x81, 0x0b, 0xa0, 0x5a, 0x32, 0xa8, 0x9a, 0xa6, 0x6d, 0x7c, 0xf3, 0x4e, 0x0c, 0xc7, 0x32,
		0x46, 0xb5, 0x23, 0xf0, 0x05, 0x7c, 0x2d, 0x0b, 0x5f, 0x46, 0xf3, 0xdf, 0x9e, 0x6d, 0xb4, 0x98,
		0x6b, 0xe6, 0x01, 0x2b, 0x6a, 0xb0, 0x3a, 0x31, 0x2c, 0x1b, 0x54, 0x0b, 0xf0, 0x5a, 0x5d, 0xd4,
		0x42, 0xc4, 0x02, 0xa4, 0x96, 0x59, 0x21, 0x5a, 0xad, 0xbb, 0x2e, 0xd7, 0x98, 0x70, 0x01, 0x5d,
		0x40, 0xd7, 0xb2, 0xd0, 0x75, 0xdc, 0xca, 0xbb, 0x0f, 0xd8, 0x5d, 0x04, 0xbe, 0x56, 0x81, 0xaf,
		0x02, 0x54, 0x5e, 0x31, 0x3e, 0xe8, 0xa2, 0x0f, 0x01, 0x80, 0x2d, 0x0d, 0x60, 0xe6, 0x57, 0xd7,
		0x6c, 0x35, 0xcd, 0xa6, 0x67, 0x34, 0x47, 0x99, 0xf2, 0xd0, 0x69, 0x1f, 0x63, 0x34, 0x15, 0xf8,
		0x5a, 0x22, 0xa3, 0x07, 0xac, 0x00, 0xab, 0xa5, 0xc3, 0x6a, 0x3c, 0x35, 0x88, 0xb1, 0x54, 0x00,
		0x6c, 0x55, 0x00, 0x43, 0xb9, 0x08, 0x54, 0x2d, 0x1f, 0x55, 0xae, 0xe9, 0x35, 0xcd, 0x03, 0xe3,
		0xd8, 0x76, 0xbd, 0x23, 0xd3, 0x75, 0xac, 0x7d, 0x1c, 0x78, 0x50, 0xee, 0x0b, 0x07, 0x1e, 0xc0,
		0x79, 0x17, 0x4a, 0x05, 0x38, 0x98, 0x0b, 0xd0, 0x79, 0x39, 0x74, 0x14, 0x50, 0x7d, 0x02, 0x44,
		0x24, 0xe2, 0x0f, 0x67, 0x75, 0x27, 0x20, 0x44, 0xa0, 0x5c, 0x56, 0x41, 0xc5, 0x09, 0x20, 0x91,
		0xe8, 0xbb, 0x28, 0x30, 0xd1, 0x0d, 0x24, 0x49, 0xa7, 0x46, 0x0a, 0xa8, 0x32, 0x81, 0x22, 0x12,
		0xdc, 0x88, 0xbd, 0xfa, 0x12, 0x38, 0x92, 0x8d, 0x23, 0x15, 0x54, 0x96, 0x40, 0x91, 0x6c, 0x14,
		0xa9, 0xa0, 0xa6, 0x04, 0x8a, 0x48, 0x14, 0x6b, 0xe0, 0xd8, 0x40, 0xd2, 0x52, 0xe2, 0x91, 0x1a,
		0xea, 0x48, 0x60, 0x89, 0x04, 0xd3, 0xe6, 0xa9, 0x82, 0x04, 0x78, 0x48, 0x80, 0x87, 0xbd, 0xda,
		0x11, 0x38, 0x92, 0x8d, 0x23, 0xd6, 0xaa, 0x46, 0xc0, 0x47, 0x3a, 0x7c, 0x54, 0x50, 0x2f, 0x02,
		0x46, 0x14, 0xa2, 0x10, 0x22, 0x10, 0xa0, 0xb3, 0x48, 0x45, 0xa6, 0x80, 0x1a, 0x11, 0x28, 0x92,
		0x8d, 0x22, 0x35, 0x54, 0x87, 0xc0, 0x91, 0x6c, 0x1c, 0x29, 0xa2, 0x2e, 0x04, 0x90, 0x64, 0x03,
		0x49, 0x0d, 0x15, 0x21, 0x70, 0x24, 0x9f, 0x59, 0x03, 0x3e, 0x80, 0xcf, 0xc2, 0xf0, 0x51, 0x44,
		0x15, 0x08, 0x20, 0xc9, 0x06, 0x12, 0xca, 0x33, 0xa0, 0x67, 0x71, 0xf4, 0x28, 0xa0, 0xf2, 0xe3,
		0xa5, 0xee, 0xe3, 0xa3, 0xea, 0xe3, 0xb1, 0xae, 0xf4, 0xad, 0xa4, 0x6d, 0x21, 0xf1, 0x10, 0xac,
		0x19, 0x51, 0x14, 0x67, 0x7e, 0x16, 0xc4, 0x91, 0xb6, 0xcb, 0x20, 0xf8, 0x6a, 0x69, 0xef, 0xbb,
		0xb8, 0xf2, 0x07, 0x7e, 0xf6, 0x7d, 0x14, 0x6e, 0x6b, 0xf1, 0x40, 0x44, 0xbd, 0x38, 0xba, 0x08,
		0x2e, 0xf5, 0x48, 0x64, 0x3f, 0xe3, 0xe4, 0x87, 0x1e, 0x44, 0x69, 0xe6, 0x47, 0x3d, 0x51, 0x7b,
		0xfc, 0x8d, 0x74, 0xe6, 0x3b, 0xb5, 0x41, 0x12, 0x67, 0x71, 0x2f, 0x0e, 0xd3, 0xe2, 0x5d, 0x2d,
		0x48, 0x83, 0xb4, 0x16, 0x8a, 0x6b, 0x11, 0x4e, 0xbe, 0xd4, 0xc2, 0x20, 0xfa, 0xa1, 0xa7, 0x99,
		0x9f, 0x09, 0xbd, 0xef, 0x67, 0xfe, 0xb9, 0x9f, 0x8a, 0x5a, 0x98, 0x0e, 0x6a, 0x59, 0x78, 0x9d,
		0x8e, 0xfe, 0x53, 0x13, 0xbf, 0x32, 0x11, 0xf5, 0x45, 0x5f, 0x0f, 0x52, 0x3d, 0x11, 0x7e, 0xef,
		0xbb, 0x7f, 0x1e, 0x84, 0x41, 0x76, 0x53, 0x8b, 0x44, 0x70, 0xf9, 0xfd, 0x3c, 0x4e, 0xd2, 0xe2,
		0x5d, 0xed, 0xce, 0x98, 0xc2, 0x88, 0x74, 0x78, 0x3e, 0xfe, 0xa7, 0xf2, 0xaf, 0xb5, 0xf1, 0x6f,
		0xa2, 0x9d, 0x26, 0xe8, 0xba, 0x1c, 0x61, 0x77, 0xd3, 0x46, 0xf8, 0x11, 0x17, 0xfe, 0x30, 0xcc,
		0xf4, 0x2b, 0x91, 0x25, 0x41, 0x8f, 0xbc, 0xc7, 0x15, 0xb4, 0x66, 0xd6, 0x74, 0xe2, 0x61, 0xed,
		0x4b, 0x10, 0xf5, 0xb5, 0xdd, 0xb5, 0x0d, 0xe2, 0x66, 0xee, 0x8f, 0x43, 0x97, 0xb6, 0xbb, 0xb6,
		0x4e, 0xdc, 0xd0, 0x4e, 0x22, 0x2e, 0x82, 0x5f, 0x3c, 0x52, 0xc4, 0x14, 0xb4, 0x71, 0x4f, 0x1f,
		0x05, 0x73, 0x06, 0x77, 0x82, 0x6b, 0xdd, 0x78, 0x98, 0xf4, 0x04, 0x8b, 0xe5, 0xcd, 0xdd, 0x4b,
		0xdc, 0xfc, 0x8c, 0x93, 0x91, 0x87, 0x69, 0x83, 0x1c, 0x19, 0x3c, 0x2a, 0x4d, 0xed, 0xb3, 0x9f,
		0x1a, 0xc9, 0xe5, 0xf0, 0x4a, 0x44, 0x99, 0xb6, 0xbb, 0x96, 0x25, 0x43, 0xc1, 0xc4, 0xf0, 0x7b,
		0x56, 0x17, 0xc0, 0x06, 0x35, 0x57, 0x9a, 0x9a, 0x37, 0x83, 0x84, 0x09, 0x27, 0x1f, 0x33, 0x56,
		0x36, 0xc1, 0x6b, 0x9a, 0x1f, 0x72, 0xb3, 0x99, 0xf8, 0x3f, 0x0f, 0x42, 0xc3, 0x8e, 0xd8, 0x70,
		0x24, 0x38, 0x8c, 0x89, 0x0e, 0x57, 0xc2, 0xc3, 0x9e, 0xf8, 0xb0, 0x27, 0x40, 0xbc, 0x89, 0x10,
		0x0f, 0x42, 0xc4, 0x84, 0x18, 0xb1, 0x23, 0x48, 0x85, 0xc1, 0x4c, 0xda, 0x3e, 0x73, 0x13, 0x0d,
		0x8b, 0xde, 0xcf, 0x3c, 0xea, 0xb4, 0xce, 0xcc, 0x6c, 0x6e, 0x14, 0x8a, 0x33, 0x95, 0x52, 0x80,
		0x52, 0x71, 0xa7, 0x56, 0xca, 0x50, 0x2c, 0x65, 0xa8, 0x96, 0x1a, 0x94, 0x8b, 0x17, 0xf5, 0x62,
		0x46, 0xc1, 0x0a, 0x88, 0xb8, 0x37, 0x03, 0xc1, 0x3b, 0xe2, 0x0f, 0x83, 0x28, 0xfb, 0xb8, 0xc9,
		0x31, 0xe0, 0x4f, 0xf8, 0xcd, 0x36, 0x43, 0xd3, 0x1d, 0x3f, 0xba, 0x1c, 0xad, 0xfe, 0x29, 0xcb,
		0xc0, 0xc8, 0xf7, 0x64, 0x7a, 0xed, 0x28, 0x88, 0xd8, 0x32, 0x04, 0xe6, 0xc4, 0x7e, 0xe6, 0x31,
		0x4e, 0xfc, 0x70, 0x28, 0x14, 0x78, 0x8e, 0x83, 0xc4, 0xef, 0x65, 0x41, 0x1c, 0x35, 0x83, 0xcb,
		0x20, 0x4b, 0x47, 0x0f, 0x84, 0xeb, 0x32, 0x64, 0xb8, 0xb6, 0xff, 0x0b, 0xae, 0x4d, 0xcc, 0xb5,
		0xeb, 0x9b, 0x3b, 0xf5, 0x9d, 0xc6, 0xf6, 0xe6, 0xce, 0x16, 0x7c, 0x1c, 0x05, 0x41, 0xb5, 0xac,
		0xe6, 0x75, 0xcf, 0xca, 0x2d, 0xf6, 0x12, 0xaa, 0x98, 0x49, 0xb9, 0xcd, 0x41, 0x17, 0x76, 0xab,
		0x3f, 0x0f, 0x3d, 0x33, 0x7b, 0xca, 0x61, 0x42, 0x9a, 0x8f, 0x93, 0x62, 0x46, 0xab, 0x42, 0x61,
		0xa3, 0x8a, 0xe1, 0x82, 0xc3, 0xfc, 0x6f, 0x9a, 0x25, 0xc3, 0x5e, 0x16, 0x4d, 0x5a, 0x91, 0xad,
		0x7c, 0x9d, 0xad, 0xc9, 0x13, 0x7a, 0x9d, 0xc9, 0xe2, 0x7a, 0x56, 0x1a, 0xa4, 0x9e, 0x3d, 0x5a,
		0x55, 0xcf, 0x4e, 0x07, 0x9e, 0x1b, 0x5e, 0x7b, 0xe6, 0x64, 0xf1, 0xac, 0xd4, 0xb9, 0xb7, 0x74,
		0x5e, 0x6b, 0xb2, 0x60, 0x5e, 0xf1, 0x8f, 0x74, 0xc7, 0xcb, 0xe3, 0xb9, 0xa2, 0x99, 0xaf, 0xce,
		0x51, 0xbe, 0x38, 0xd0, 0x99, 0xa8, 0x16, 0x97, 0xb4, 0x8c, 0x43, 0x2f, 0xfe, 0x4e, 0x5a, 0x32,
		0xb2, 0x96, 0x87, 0x9a, 0x64, 0x1d, 0x6a, 0x92, 0xe5, 0x18, 0x0a, 0x35, 0xc9, 0x4a, 0x4d, 0x86,
		0x9a, 0xa4, 0x24, 0xc3, 0xa1, 0x26, 0x01, 0x1b, 0xe0, 0x52, 0xa9, 0xb0, 0xd9, 0xa1, 0x2f, 0x22,
		0x6e, 0x28, 0xfc, 0x8b, 0x44, 0x5c, 0x70, 0x88, 0xb8, 0x53, 0x75, 0x06, 0x83, 0x3d, 0x78, 0xad,
		0x33, 0x29, 0xfe, 0x3e, 0x7c, 0xc8, 0x1b, 0x29, 0xb5, 0x31, 0x03, 0x43, 0x1d, 0xa0, 0x5c, 0x1d,
		0x30, 0x1c, 0x95, 0xf6, 0x69, 0x96, 0xf8, 0x41, 0x24, 0xfa, 0x7a, 0x98, 0x0e, 0xf8, 0x14, 0x05,
		0xb3, 0xa6, 0x43, 0x6f, 0x8e, 0x0a, 0x01, 0x15, 0x02, 0x2a, 0x04, 0x54, 0x08, 0xa8, 0x10, 0x50,
		0x21, 0xac, 0xe4, 0x23, 0x87, 0xde, 0x7c, 0xb5, 0xf9, 0x01, 0x7a, 0x73, 0x10, 0x1b, 0x8e, 0x04,
		0x87, 0x31, 0xd1, 0xe1, 0x4a, 0x78, 0xd8, 0x13, 0x1f, 0xf6, 0x04, 0x88, 0x37, 0x11, 0xe2, 0x41,
		0x88, 0x98, 0x10, 0x23, 0x76, 0x04, 0xa9, 0x30, 0xb8, 0x17, 0x0f, 0xc7, 0xc0, 0x65, 0x2a, 0x37,
		0xcf, 0xcd, 0x87, 0xda, 0x1c, 0x04, 0x4a, 0x2d, 0x22, 0xa5, 0x00, 0xa1, 0xe2, 0x4e, 0xac, 0x94,
		0x21, 0x58, 0xca, 0x10, 0x2d, 0x35, 0x08, 0x17, 0x2f, 0xe2, 0xc5, 0x8c, 0x80, 0x15, 0x10, 0x51,
		0x43, 0x6d, 0xbe, 0xd1, 0x60, 0xac, 0x36, 0x6f, 0x40, 0x6d, 0x5e, 0xf2, 0x0b, 0x6a, 0x73, 0x10,
		0xfb, 0x25, 0x3c, 0x06, 0xd4, 0xe6, 0x48, 0xbf, 0xcb, 0x74, 0x6d, 0xa8, 0xcd, 0xc9, 0xb9, 0x76,
		0x63, 0x6b, 0xeb, 0x23, 0x84, 0xe6, 0xa8, 0x05, 0x2a, 0x66, 0x35, 0x84, 0xe6, 0x95, 0x4f, 0x4f,
		0x3c, 0xb4, 0x4f, 0x73, 0xab, 0x42, 0x06, 0x5a, 0x28, 0x45, 0x72, 0x27, 0xfa, 0xdd, 0x32, 0x71,
		0x8e, 0x7e, 0xb7, 0x3c, 0x77, 0x45, 0xbf, 0x9b, 0xd8, 0x83, 0xa0, 0xdf, 0x0d, 0x46, 0xf3, 0x0c,
		0x44, 0xf8, 0xf7, 0xbb, 0x83, 0xbe, 0x88, 0xb2, 0x20, 0xbb, 0xe1, 0xa1, 0xe7, 0x9a, 0x47, 0x72,
		0x36, 0x18, 0x56, 0xd5, 0x9a, 0x35, 0x59, 0xfa, 0x3d, 0x3f, 0x65, 0x9c, 0xb7, 0xee, 0x2e, 0xd8,
		0xb6, 0xba, 0x5e, 0xf7, 0x78, 0xcf, 0xb5, 0x4f, 0x3c, 0xf7, 0x5b, 0xc7, 0xe4, 0x9a, 0xbe, 0xc6,
		0xbd, 0x9a, 0x94, 0xed, 0x66, 0xc4, 0x1a, 0xeb, 0x0d, 0x89, 0x87, 0x88, 0xea, 0x3c, 0xbc, 0xb2,
		0x3d, 0x07, 0x57, 0x97, 0x33, 0xba, 0x54, 0x42, 0x99, 0x1a, 0x68, 0x7b, 0x16, 0x75, 0x1d, 0xc7,
		0x3c, 0xb0, 0xbe, 0x7a, 0x07, 0xb6, 0x71, 0xd8, 0xd5, 0xd8, 0x3f, 0xea, 0xed, 0x7b, 0xe0, 0x8d,
		0x36, 0xde, 0xac, 0xce, 0x49, 0xdd, 0x73, 0xda, 0xc7, 0xae, 0xe9, 0x78, 0x56, 0x13, 0x88, 0x03,
		0xe2, 0x56, 0x8d, 0x38, 0xd7, 0x38, 0x04, 0xcc, 0x00, 0xb3, 0x12, 0x60, 0xd6, 0xa8, 0x03, 0x68,
		0x00, 0x5a, 0x09, 0x19, 0xb4, 0x81, 0x0c, 0x0a, 0xc4, 0x95, 0x5e, 0x23, 0x74, 0x95, 0x40, 0x1b,
		0xeb, 0x27, 0x38, 0xc3, 0xac, 0x19, 0xbc, 0x1b, 0x95, 0x3f, 0x70, 0x85, 0x0a, 0x1f, 0xc8, 0xaa,
		0x1c, 0xb2, 0x58, 0x57, 0xf2, 0x80, 0x13, 0x2a, 0x76, 0x00, 0x4a, 0xf5, 0xcc, 0xd7, 0x40, 0xe6,
		0x03, 0xb2, 0x50, 0x81, 0x03, 0x55, 0x14, 0x51, 0x35, 0x09, 0x4d, 0xfb, 0x46, 0x07, 0x33, 0x07,
		0xc0, 0x9b, 0x54, 0xdc, 0x39, 0x9e, 0x61, 0x1f, 0xb6, 0x1d, 0xcb, 0xfd, 0x7c, 0x84, 0x0e, 0x36,
		0x10, 0x57, 0x0a, 0xe2, 0xee, 0xfe, 0x84, 0x36, 0xb6, 0xdc, 0x17, 0xda, 0xd8, 0x70, 0x71, 0x24,
		0x13, 0x20, 0x0b, 0x49, 0x03, 0xd0, 0xaa, 0x46, 0x3d, 0xdf, 0xc5, 0xac, 0x37, 0xd0, 0x26, 0x1b,
		0x75, 0xb6, 0xd5, 0xfa, 0x82, 0x91, 0x21, 0x40, 0xad, 0x04, 0xa8, 0x1d, 0xb7, 0xf6, 0xdb, 0xad,
		0xae, 0xeb, 0x18, 0x56, 0xcb, 0x6c, 0x7a, 0x76, 0xb7, 0x03, 0xd0, 0x01, 0x74, 0xa5, 0xc4, 0x37,
		0xc3, 0x75, 0x1d, 0x6b, 0xef, 0xd8, 0x35, 0x21, 0x67, 0x01, 0xe4, 0x56, 0x0e, 0xb9, 0xf1, 0x96,
		0x5f, 0xcb, 0xb4, 0x0e, 0x3f, 0xef, 0xb5, 0x1d, 0xcf, 0x68, 0x36, 0x1d, 0xb3, 0x0b, 0xe0, 0x01,
		0x78, 0x65, 0x00, 0xaf, 0xee, 0x59, 0x2d, 0xd7, 0x74, 0x0e, 0x8c, 0x7d, 0x13, 0xc8, 0x03, 0xf2,
		0x4a, 0xa3, 0x76, 0xae, 0x65, 0x5b, 0xff, 0x35, 0x9b, 0xde, 0x9e, 0xd1, 0x6a, 0xfe, 0xc7, 0x6a,
		0xba, 0x9f, 0x81, 0x3a, 0xa0, 0xae, 0x14, 0x6e, 0xd7, 0x71, 0xda, 0xae, 0xb9, 0xef, 0x5a, 0xed,
		0x56, 0xde, 0x39, 0x01, 0xee, 0x80, 0xbb, 0x15, 0xe3, 0xce, 0x31, 0xbb, 0x56, 0xf3, 0xd8, 0xb0,
		0x11, 0xed, 0x80, 0xba, 0xf2, 0x50, 0x77, 0x64, 0x7c, 0xcd, 0x23, 0x1e, 0x50, 0x07, 0xd4, 0x95,
		0x5b, 0xcc, 0xa2, 0xa6, 0x00, 0xf2, 0xa4, 0xc4, 0x3b, 0xc7, 0xec, 0x9a, 0xce, 0x89, 0xb1, 0x67,
		0x9b, 0x88, 0x7a, 0xc0, 0x5e, 0xc9, 0x95, 0x85, 0xdd, 0x46, 0xa0, 0x03, 0xd8, 0x4a, 0x02, 0x5b,
		0xd3, 0xb4, 0x8d, 0x6f, 0xde, 0x89, 0xe1, 0x58, 0xc6, 0xa8, 0x96, 0x05, 0xee, 0x80, 0xbb, 0x55,
		0xe3, 0xce, 0x68, 0xfe, 0xdb, 0xb3, 0x8d, 0x96, 0x22, 0x67, 0x38, 0x00, 0x6e, 0xd4, 0xe1, 0x76,
		0x62, 0x58, 0x36, 0xa8, 0x1c, 0x60, 0x57, 0x7e, 0x94, 0x43, 0x84, 0x03, 0xd4, 0xca, 0xa8, 0x58,
		0xad, 0xd6, 0x5d, 0x97, 0x6e, 0x4c, 0xe8, 0x80, 0x3a, 0xa0, 0x6e, 0xd5, 0xa8, 0x3b, 0x6e, 0xe5,
		0x5d, 0x12, 0xec, 0xbe, 0x02, 0x77, 0x65, 0xe2, 0xae, 0x00, 0x9b, 0x57, 0x8c, 0x75, 0xba, 0xe8,
		0x97, 0x00, 0x78, 0x2b, 0x07, 0x9e, 0xf9, 0xd5, 0x35, 0x5b, 0x4d, 0xb3, 0xe9, 0x19, 0xcd, 0x51,
		0xc6, 0x3d, 0x74, 0xda, 0xc7, 0x18, 0x25, 0x06, 0xee, 0x4a, 0xa8, 0x24, 0x00, 0x37, 0xc0, 0xad,
		0x34, 0xb8, 0x8d, 0xa7, 0x39, 0x31, 0x46, 0x0c, 0xe0, 0x95, 0x0d, 0x3c, 0x94, 0xaf, 0x40, 0x5b,
		0x79, 0x68, 0x73, 0x4d, 0xaf, 0x69, 0x1e, 0x18, 0xc7, 0xb6, 0xeb, 0x1d, 0x99, 0xae, 0x63, 0xed,
		0xe3, 0x20, 0x0e, 0xb9, 0x2f, 0x1c, 0xc4, 0x01, 0x27, 0x5f, 0x6a, 0x2a, 0xc1, 0x01, 0x75, 0x80,
		0xd4, 0xf2, 0x20, 0xa5, 0x90, 0x8a, 0x18, 0xe0, 0x22, 0x19, 0xaf, 0x54, 0x50, 0x0b, 0x03, 0x5a,
		0x04, 0xcb, 0x79, 0x95, 0x54, 0xc1, 0x00, 0x18, 0x41, 0x80, 0x29, 0xa5, 0xfe, 0x05, 0xc2, 0xc8,
		0x51, 0x2f, 0x85, 0x54, 0xbe, 0x40, 0x17, 0x49, 0xee, 0xa5, 0x8c, 0x9a, 0x17, 0xf8, 0xa2, 0x86,
		0x2f, 0x95, 0x54, 0xbb, 0x40, 0x17, 0x35, 0x74, 0xa9, 0xa4, 0xce, 0x05, 0xba, 0x48, 0x16, 0x8f,
		0xe0, 0xf6, 0x40, 0xd8, 0x4a, 0xe3, 0x97, 0x5a, 0x6a, 0x5b, 0x60, 0x8c, 0x24, 0xc3, 0xe7, 0xad,
		0xaa, 0x05, 0xa8, 0x48, 0x82, 0x4a, 0x19, 0xf5, 0x2c, 0xf0, 0x45, 0x0d, 0x5f, 0x4a, 0xa8, 0x64,
		0x01, 0x2b, 0x72, 0xb0, 0x52, 0x49, 0x0d, 0x0b, 0x78, 0x51, 0x8c, 0x5a, 0x88, 0x58, 0x80, 0xd4,
		0x32, 0x2b, 0x44, 0x85, 0xd4, 0xad, 0x40, 0x17, 0x35, 0x74, 0xa9, 0xa5, 0x62, 0x05, 0xbe, 0xa8,
		0xe1, 0x4b, 0x31, 0xb5, 0x2a, 0x00, 0x46, 0x0d, 0x60, 0x6a, 0xa9, 0x52, 0x81, 0x2f, 0x7a, 0x8c,
		0x1e, 0xb0, 0x02, 0xac, 0x96, 0x0e, 0x2b, 0xc5, 0x54, 0xa6, 0x00, 0x18, 0x35, 0x80, 0xa1, 0x5c,
		0x04, 0xaa, 0x96, 0x8f, 0x2a, 0x85, 0x54, 0xa3, 0x3c, 0xd5, 0xa2, 0xfc, 0x54, 0xa2, 0xbc, 0xd6,
		0x99, 0x8f, 0xb5, 0x3c, 0x2c, 0x65, 0x12, 0xc2, 0x35, 0x23, 0x8a, 0xe2, 0xcc, 0xcf, 0x82, 0x38,
		0xd2, 0x76, 0x19, 0x05, 0x6f, 0x2d, 0xed, 0x7d, 0x17, 0x57, 0xfe, 0xc0, 0xcf, 0xbe, 0x8f, 0xc2,
		0x75, 0x2d, 0x1e, 0x88, 0xa8, 0x17, 0x47, 0x17, 0xc1, 0xa5, 0x1e, 0x89, 0xec, 0x67, 0x9c, 0xfc,
		0xd0, 0x83, 0x28, 0xcd, 0xfc, 0xa8, 0x27, 0x6a, 0x8f, 0xbf, 0x91, 0xce, 0x7c, 0xa7, 0x36, 0x48,
		0xe2, 0x2c, 0xee, 0xc5, 0x61, 0x5a, 0xbc, 0xab, 0x05, 0x69, 0x90, 0xd6, 0x42, 0x71, 0x2d, 0xc2,
		0xc9, 0x97, 0x5a, 0x18, 0x44, 0x3f, 0xf4, 0x34, 0xf3, 0x33, 0xa1, 0xf7, 0xfd, 0xcc, 0x3f, 0xf7,
		0x53, 0x51, 0x0b, 0xd3, 0x41, 0x2d, 0x0b, 0xaf, 0xd3, 0xd1, 0x7f, 0x6a, 0xe2, 0x57, 0x26, 0xa2,
		0xbe, 0xe8, 0xeb, 0x41, 0xaa, 0x27, 0xc2, 0xef, 0x7d, 0xf7, 0xcf, 0x83, 0x30, 0xc8, 0x6e, 0x6a,
		0x91, 0x08, 0x2e, 0xbf, 0x9f, 0xc7, 0x49, 0x5a, 0xbc, 0xab, 0xdd, 0x19, 0x53, 0x18, 0x91, 0x0e,
		0xcf, 0xc7, 0xff, 0x54, 0xfe, 0xb5, 0x36, 0x1c, 0x3d, 0x50, 0x9a, 0x25, 0x7e, 0x10, 0x89, 0xbe,
		0x3e, 0xfa, 0x45, 0xe3, 0xdf, 0xcd, 0x23, 0xf1, 0xd0, 0x77, 0x52, 0xda, 0x16, 0x12, 0x0f, 0x1f,
		0xdc, 0xc2, 0x46, 0x15, 0xc3, 0x05, 0x83, 0x3b, 0xfd, 0xb5, 0x34, 0x4b, 0x86, 0xbd, 0x2c, 0x9a,
		0x90, 0xee, 0x56, 0xbe, 0xce, 0xd6, 0xe4, 0x09, 0xbd, 0xce, 0x64, 0x71, 0x3d, 0x2b, 0x0d, 0x52,
		0xcf, 0x1e, 0xad, 0xaa, 0x67, 0xa7, 0x03, 0xcf, 0x0d, 0xaf, 0x3d, 0x73, 0xb2, 0x78, 0x56, 0xea,
		0xdc, 0x5b, 0x3a, 0xaf, 0x35, 0x59, 0x30, 0xaf, 0xf8, 0x47, 0xba, 0xe3, 0xe5, 0xf1, 0x8e, 0xef,
		0x2f, 0x8f, 0x9d, 0x0e, 0x68, 0x87, 0x51, 0xba, 0xc1, 0x89, 0x70, 0x60, 0xd2, 0x86, 0x51, 0x22,
		0x52, 0x91, 0x5c, 0x8b, 0xbe, 0x7e, 0xee, 0x47, 0xfd, 0x9f, 0x41, 0x7f, 0xec, 0xee, 0xb4, 0xc3,
		0x53, 0x51, 0x72, 0x3e, 0x69, 0x3d, 0xf1, 0x34, 0xf0, 0x25, 0x88, 0xfa, 0xda, 0xee, 0xda, 0x06,
		0x71, 0x33, 0xf7, 0xc7, 0xa1, 0x5e, 0xdb, 0x5d, 0x5b, 0x27, 0x6e, 0x68, 0x27, 0x11, 0x17, 0xc1,
		0x2f, 0x1e, 0x29, 0x75, 0x8a, 0xdb, 0xb8, 0xa7, 0x8f, 0x92, 0x1f, 0x87, 0x74, 0xd3, 0x8d, 0x87,
		0x49, 0x4f, 0xb0, 0x29, 0x74, 0xb4, 0x2f, 0xe2, 0xe6, 0x67, 0x9c, 0x8c, 0x3c, 0x4c, 0x1b, 0xe4,
		0xc8, 0x60, 0x52, 0x55, 0x7e, 0xf6, 0x53, 0x23, 0xb9, 0x1c, 0x5e, 0x89, 0x28, 0xd3, 0x76, 0xd7,
		0xb2, 0x64, 0x28, 0xb8, 0x94, 0xc3, 0x77, 0x56, 0x17, 0xc0, 0x46, 0x29, 0xa3, 0x74, 0x29, 0xd3,
		0x0c, 0x12, 0x26, 0x35, 0x8c, 0xc8, 0x86, 0x03, 0x7d, 0x90, 0x04, 0x71, 0x12, 0x64, 0x37, 0x7c,
		0xa2, 0xd8, 0x34, 0x51, 0x3c, 0xb2, 0x9f, 0x49, 0x44, 0xe0, 0x41, 0x71, 0xd8, 0x51, 0x1d, 0x8e,
		0x94, 0x87, 0x31, 0xf5, 0xe1, 0x4a, 0x81, 0xd8, 0x53, 0x21, 0xf6, 0x94, 0x88, 0x37, 0x35, 0xe2,
		0x41, 0x91, 0x98, 0x50, 0x25, 0x76, 0x94, 0xa9, 0x30, 0x98, 0x1d, 0x69, 0x9a, 0x49, 0x35, 0xcc,
		0x68, 0xd3, 0x63, 0xfa, 0xb4, 0xce, 0xcc, 0x6c, 0x6e, 0x34, 0x8a, 0x33, 0x9d, 0x52, 0x80, 0x56,
		0x71, 0xa7, 0x57, 0xca, 0xd0, 0x2c, 0x65, 0xe8, 0x96, 0x1a, 0xb4, 0x8b, 0x17, 0xfd, 0x62, 0x46,
		0xc3, 0x0a, 0x88, 0xb8, 0x37, 0x03, 0xc1, 0x3b, 0xe2, 0x87, 0xc2, 0xbf, 0x48, 0xc4, 0x05, 0xc7,
		0x88, 0x3f, 0xed, 0x0f, 0x6d, 0x33, 0xb4, 0xbd, 0x33, 0x99, 0x87, 0xf8, 0xf0, 0x21, 0x9f, 0x2d,
		0xaa, 0x15, 0x2c, 0x13, 0xb3, 0x8b, 0x55, 0x8f, 0x2c, 0x5a, 0x3e, 0x6d, 0xc6, 0xb6, 0x60, 0xca,
		0xcd, 0xe7, 0x59, 0x2d, 0x6d, 0xa0, 0x5a, 0x42, 0xb5, 0x84, 0x6a, 0x09, 0xd5, 0x12, 0xaa, 0x25,
		0x54, 0x4b, 0xe0, 0x34, 0xcb, 0x85, 0x08, 0xb7, 0xe6, 0x75, 0x61, 0x38, 0x9f, 0x99, 0xc6, 0x67,
		0x73, 0x16, 0x97, 0x01, 0xc7, 0xe7, 0x88, 0xda, 0x3a, 0x53, 0xf3, 0xb9, 0x12, 0x36, 0x15, 0x88,
		0x9b, 0x42, 0x04, 0x4e, 0x15, 0x22, 0xa7, 0x1c, 0xa1, 0x53, 0x8e, 0xd8, 0xa9, 0x45, 0xf0, 0x78,
		0x12, 0x3d, 0xa6, 0x84, 0xaf, 0x80, 0x0e, 0xdb, 0x36, 0xf9, 0x4c, 0xc6, 0x08, 0x84, 0x10, 0x17,
		0x61, 0xec, 0x67, 0x1f, 0x37, 0x39, 0x67, 0x8d, 0x09, 0x89, 0xda, 0x61, 0xfc, 0x08, 0xb6, 0x88,
		0x2e, 0xc7, 0x84, 0xfc, 0x94, 0x75, 0x58, 0xe5, 0x7f, 0xe7, 0xbb, 0x76, 0x14, 0x44, 0xec, 0xf9,
		0x87, 0x22, 0xe5, 0xc5, 0xcc, 0xe3, 0x9c, 0xf8, 0xe1, 0x70, 0x14, 0xb8, 0xea, 0x8a, 0x3c, 0xcf,
		0x41, 0xe2, 0xf7, 0xb2, 0x20, 0x8e, 0x9a, 0xc1, 0x65, 0x90, 0xa5, 0xa3, 0x0f, 0x8a, 0xfd, 0x73,
		0xdd, 0xbe, 0x57, 0x20, 0x04, 0xf8, 0xbf, 0x10, 0x02, 0x10, 0x02, 0x10, 0x02, 0xaa, 0x54, 0x8d,
		0xf0, 0xb7, 0xfe, 0xec, 0x0d, 0xd6, 0x1b, 0x29, 0xee, 0xe9, 0x30, 0xc3, 0x76, 0x70, 0x7d, 0xa6,
		0x66, 0x65, 0x3a, 0xc0, 0xae, 0x48, 0x3e, 0x46, 0xc7, 0x9f, 0x92, 0x2f, 0xa0, 0xe3, 0x4f, 0xc7,
		0xad, 0xd1, 0xf1, 0x27, 0xfe, 0x40, 0xe8, 0xf8, 0x83, 0x39, 0x2d, 0x08, 0x1d, 0x75, 0x3a, 0xfe,
		0xc3, 0x20, 0xca, 0x3e, 0x29, 0xd0, 0xeb, 0xdf, 0x62, 0xfc, 0x08, 0x8e, 0x1f, 0x5d, 0x0a, 0xb4,
		0xfa, 0xe5, 0x7f, 0x10, 0x68, 0xf5, 0xd3, 0x7d, 0x9c, 0x69, 0x9f, 0x6f, 0x1d, 0x7d, 0x3e, 0x64,
		0xf3, 0x15, 0x86, 0x00, 0xb4, 0xfa, 0xc9, 0x87, 0x80, 0x6d, 0x84, 0x00, 0x94, 0x21, 0xb0, 0xfe,
		0xfe, 0x0b, 0xad, 0x7e, 0x58, 0xcc, 0x3e, 0x21, 0x73, 0xbd, 0x33, 0xa2, 0xb0, 0xbf, 0x0a, 0x87,
		0xc1, 0xcf, 0x9e, 0x25, 0x5d, 0x7b, 0x78, 0xfe, 0x22, 0xa7, 0xdb, 0x24, 0xf8, 0xb9, 0x35, 0xce,
		0x1b, 0x5b, 0x2a, 0x41, 0x16, 0x37, 0x0c, 0xb7, 0x10, 0x35, 0x3b, 0x48, 0x33, 0x23, 0xcb, 0x98,
		0x9d, 0x95, 0x76, 0x14, 0x44, 0x66, 0x28, 0xae, 0x44, 0x94, 0x73, 0x5d, 0x46, 0x27, 0x16, 0x1c,
		0xf9, 0xbf, 0xee, 0x59, 0xbe, 0xf1, 0xa9, 0x5e, 0x6f, 0x6c, 0xd7, 0xeb, 0xeb, 0xdb, 0x1f, 0xb7,
		0xd7, 0x77, 0xb6, 0xb6, 0x36, 0x1a, 0x1b, 0x8c, 0xba, 0x8f, 0x5a, 0x3b, 0xe9, 0x8b, 0x44, 0xf4,
		0xf7, 0x46, 0xc8, 0x8f, 0x86, 0x61, 0x88, 0x80, 0x02, 0x06, 0x03, 0xe6, 0xc2, 0x6c, 0x82, 0xa4,
		0xc4, 0x0b, 0x6e, 0xba, 0xa3, 0x35, 0xea, 0xb0, 0x3a, 0xbf, 0x07, 0x97, 0x84, 0x29, 0x1d, 0x6d,
		0x71, 0x49, 0x18, 0x8b, 0xe8, 0x8a, 0x9b, 0xb0, 0x94, 0xf3, 0x3e, 0x6d, 0x98, 0x05, 0x61, 0xf0,
		0x7f, 0x4c, 0xef, 0xc1, 0x9a, 0xb5, 0x1d, 0xb7, 0x60, 0x2d, 0xc3, 0x4c, 0xdc, 0x82, 0xb5, 0x42,
		0xd4, 0xe2, 0x16, 0xac, 0x55, 0x76, 0x7f, 0x70, 0x0b, 0x56, 0xb9, 0xc4, 0x0d, 0xb7, 0x60, 0x55,
		0x8d, 0xab, 0xf3, 0xb9, 0x05, 0x8b, 0xd5, 0xb1, 0xa4, 0x2c, 0x8f, 0x23, 0xc5, 0x9d, 0x57, 0x20,
		0x38, 0x0a, 0x10, 0x1d, 0xae, 0x84, 0x87, 0x3d, 0xf1, 0x61, 0x4f, 0x80, 0x78, 0x13, 0x21, 0x1e,
		0x84, 0x88, 0x09, 0x31, 0x62, 0x47, 0x90, 0x0a, 0x83, 0xf9, 0x1e, 0x17, 0xca, 0xfe, 0x98, 0x50,
		0xdc, 0x7a, 0x05, 0x42, 0x55, 0x01, 0x62, 0xc5, 0x9d, 0x60, 0x29, 0x43, 0xb4, 0x94, 0x21, 0x5c,
		0x6a, 0x10, 0x2f, 0x5e, 0x04, 0x8c, 0x19, 0x11, 0x2b, 0x20, 0xc2, 0xff, 0xd6, 0x2b, 0xde, 0xc7,
		0x78, 0x32, 0x3e, 0xbe, 0x93, 0xfb, 0xb1, 0x9d, 0x8c, 0x05, 0xed, 0x2a, 0x68, 0x77, 0x15, 0x11,
		0xec, 0xa9, 0x72, 0x26, 0x9f, 0x4a, 0x02, 0x3d, 0xc6, 0xda, 0x5c, 0x25, 0x34, 0xb9, 0x70, 0x6d,
		0xb8, 0x36, 0xaa, 0x01, 0xd6, 0x56, 0x9f, 0x41, 0xd2, 0x56, 0xf5, 0xd4, 0xa4, 0x65, 0x1c, 0x6b,
		0xc3, 0xa2, 0x2e, 0x1c, 0x5b, 0x8f, 0x8e, 0x77, 0x19, 0x66, 0xa3, 0xe3, 0x2d, 0x11, 0xe7, 0xe8,
		0x78, 0xcb, 0x73, 0x57, 0x74, 0xbc, 0x89, 0x3d, 0x08, 0x3a, 0xde, 0x60, 0x34, 0xcf, 0x40, 0x44,
		0x81, 0x8e, 0x77, 0x5f, 0x44, 0x59, 0x90, 0xdd, 0x24, 0xe2, 0x82, 0x71, 0xc7, 0x7b, 0x83, 0xe1,
		0x29, 0x96, 0x9a, 0x35, 0x59, 0xfa, 0x3d, 0x3f, 0x15, 0xfc, 0x4f, 0x93, 0xb7, 0xba, 0x56, 0xd7,
		0xeb, 0x1e, 0xef, 0xb9, 0xf6, 0x89, 0xe7, 0x7e, 0xeb, 0x98, 0x5c, 0xd3, 0xd7, 0xb8, 0x4f, 0x93,
		0xb2, 0x3e, 0x54, 0x94, 0x79, 0xc3, 0xaf, 0x40, 0x54, 0xc7, 0x73, 0x4c, 0x63, 0xff, 0xb3, 0xb1,
		0x67, 0xd9, 0x96, 0xfb, 0x6d, 0x02, 0xae, 0x2e, 0x67, 0x74, 0xa9, 0x84, 0x32, 0x35, 0xd0, 0xf6,
		0x2c, 0xea, 0x3a, 0x8e, 0x79, 0x60, 0x7d, 0xf5, 0x0e, 0x6c, 0xe3, 0xb0, 0xab, 0xe1, 0xa4, 0x51,
		0xe0, 0x6d, 0xc5, 0x78, 0xb3, 0x3a, 0x27, 0x75, 0xcf, 0x69, 0x1f, 0xbb, 0xa6, 0xe3, 0x59, 0x4d,
		0x20, 0x0e, 0x88, 0x5b, 0x35, 0xe2, 0x5c, 0xe3, 0x10, 0x30, 0x03, 0xcc, 0x4a, 0x80, 0x59, 0xa3,
		0x0e, 0xa0, 0x01, 0x68, 0x25, 0x64, 0xd0, 0x06, 0x32, 0x28, 0x10, 0x57, 0x7a, 0x8d, 0xd0, 0x55,
		0x02, 0x6d, 0xac, 0x9f, 0xe0, 0x0c, 0x73, 0x66, 0xf0, 0x6e, 0x54, 0xfe, 0xc0, 0x15, 0x2a, 0x7c,
		0x20, 0xab, 0x72, 0xc8, 0x62, 0x5d, 0xc9, 0x03, 0x4e, 0xa8, 0xd8, 0x01, 0x28, 0xd5, 0x33, 0x5f,
		0x03, 0x99, 0x0f, 0xc8, 0x42, 0x05, 0x0e, 0x54, 0x51, 0x44, 0xd5, 0x24, 0x34, 0xed, 0x1b, 0x1d,
		0xcc, 0x1c, 0x00, 0x6f, 0x52, 0x71, 0xe7, 0x78, 0x86, 0x7d, 0xd8, 0x76, 0x2c, 0xf7, 0xf3, 0x11,
		0x3a, 0xd8, 0x40, 0x5c, 0x29, 0x88, 0xbb, 0xfb, 0x13, 0xda, 0xd8, 0x72, 0x5f, 0x68, 0x63, 0xc3,
		0xc5, 0x91, 0x4c, 0x80, 0x2c, 0x24, 0x0d, 0x40, 0xab, 0x1a, 0xf5, 0x7c, 0x17, 0xb3, 0xde, 0x40,
		0x9b, 0x6c, 0xd4, 0xd9, 0x56, 0xeb, 0x0b, 0x46, 0x86, 0x00, 0xb5, 0x12, 0xa0, 0x76, 0xdc, 0xda,
		0x6f, 0xb7, 0xba, 0xae, 0x63, 0x58, 0x2d, 0xb3, 0xe9, 0xd9, 0xdd, 0x0e, 0x40, 0x07, 0xd0, 0x95,
		0x12, 0xdf, 0x0c, 0xd7, 0x75, 0xac, 0xbd, 0x63, 0xd7, 0x84, 0x9c, 0x05, 0x90, 0x5b, 0x39, 0xe4,
		0xc6, 0x5b, 0x7e, 0x2d, 0xd3, 0x3a, 0xfc, 0xbc, 0xd7, 0x76, 0x3c, 0xa3, 0xd9, 0x74, 0xcc, 0x2e,
		0x80, 0x07, 0xe0, 0x95, 0x01, 0xbc, 0xba, 0x67, 0xb5, 0x5c, 0xd3, 0x39, 0x30, 0xf6, 0x4d, 0x20,
		0x0f, 0xc8, 0x2b, 0x8d, 0xda, 0xb9, 0x96, 0x6d, 0xfd, 0xd7, 0x6c, 0x7a, 0x7b, 0x46, 0xab, 0xf9,
		0x1f, 0xab, 0xe9, 0x7e, 0x06, 0xea, 0x80, 0xba, 0x52, 0xb8, 0x5d, 0xc7, 0x69, 0xbb, 0xe6, 0xbe,
		0x6b, 0xb5, 0x5b, 0x79, 0xe7, 0x04, 0xb8, 0x03, 0xee, 0x56, 0x8c, 0x3b, 0xc7, 0xec, 0x5a, 0xcd,
		0x63, 0xc3, 0x46, 0xb4, 0x03, 0xea, 0xca, 0x43, 0xdd, 0x91, 0xf1, 0x35, 0x8f, 0x78, 0x40, 0x1d,
		0x50, 0x57, 0x6e, 0x31, 0x8b, 0x9a, 0x02, 0xc8, 0x93, 0x12, 0xef, 0x1c, 0xb3, 0x6b, 0x3a, 0x27,
		0xc6, 0x9e, 0x6d, 0x22, 0xea, 0x01, 0x7b, 0x25, 0x57, 0x16, 0x76, 0x1b, 0x81, 0x0e, 0x60, 0x2b,
		0x09, 0x6c, 0x4d, 0xd3, 0x36, 0xbe, 0x79, 0x27, 0x86, 0x63, 0x19, 0xa3, 0x5a, 0x16, 0xb8, 0x03,
		0xee, 0x56, 0x8d, 0x3b, 0xa3, 0xf9, 0x6f, 0xcf, 0x36, 0x5a, 0x8a, 0x9c, 0xe1, 0x00, 0xb8, 0x51,
		0x87, 0xdb, 0x89, 0x61, 0xd9, 0xa0, 0x72, 0x80, 0x5d, 0xf9, 0x51, 0x0e, 0x11, 0x0e, 0x50, 0x2b,
		0xa3, 0x62, 0xb5, 0x5a, 0x77, 0x5d, 0xba, 0x31, 0xa1, 0x03, 0xea, 0x80, 0xba, 0x55, 0xa3, 0xee,
		0xb8, 0x95, 0x77, 0x49, 0xb0, 0xfb, 0x0a, 0xdc, 0x95, 0x89, 0xbb, 0x02, 0x6c, 0x5e, 0x31, 0xd6,
		0xe9, 0xa2, 0x5f, 0x02, 0xe0, 0xad, 0x1c, 0x78, 0xe6, 0x57, 0xd7, 0x6c, 0x35, 0xcd, 0xa6, 0x67,
		0x34, 0x47, 0x19, 0xf7, 0xd0, 0x69, 0x1f, 0x63, 0x94, 0x18, 0xb8, 0x2b, 0xa1, 0x92, 0x00, 0xdc,
		0x00, 0xb7, 0xd2, 0xe0, 0x36, 0x9e, 0xe6, 0xc4, 0x18, 0x31, 0x80, 0x57, 0x36, 0xf0, 0x50, 0xbe,
		0x02, 0x6d, 0xe5, 0xa1, 0xcd, 0x35, 0xbd, 0xa6, 0x79, 0x60, 0x1c, 0xdb, 0xae, 0x77, 0x64, 0xba,
		0x8e, 0xb5, 0x8f, 0x83, 0x38, 0xe4, 0xbe, 0x70, 0x10, 0x07, 0x9c, 0x7c, 0xa9, 0xa9, 0x04, 0x07,
		0xd4, 0x01, 0x52, 0xcb, 0x83, 0x94, 0x42, 0x2a, 0x62, 0x80, 0x8b, 0x64, 0xbc, 0x52, 0x41, 0x2d,
		0x0c, 0x68, 0x11, 0x2c, 0xe7, 0x55, 0x52, 0x05, 0x03, 0x60, 0x04, 0x01, 0xa6, 0x94, 0xfa, 0x17,
		0x08, 0x23, 0x47, 0xbd, 0x14, 0x52, 0xf9, 0x02, 0x5d, 0x24, 0xb9, 0x97, 0x32, 0x6a, 0x5e, 0xe0,
		0x8b, 0x1a, 0xbe, 0x54, 0x52, 0xed, 0x02, 0x5d, 0xd4, 0xd0, 0xa5, 0x92, 0x3a, 0x17, 0xe8, 0x22,
		0x59, 0x3c, 0x82, 0xdb, 0x03, 0x61, 0x2b, 0x8d, 0x5f, 0x6a, 0xa9, 0x6d, 0x81, 0x31, 0x92, 0x0c,
		0x9f, 0xb7, 0xaa, 0x16, 0xa0, 0x22, 0x09, 0x2a, 0x65, 0xd4, 0xb3, 0xc0, 0x17, 0x35, 0x7c, 0x29,
		0xa1, 0x92, 0x05, 0xac, 0xc8, 0xc1, 0x4a, 0x25, 0x35, 0x2c, 0xe0, 0x45, 0x31, 0x6a, 0x21, 0x62,
		0x01, 0x52, 0xcb, 0xac, 0x10, 0x15, 0x52, 0xb7, 0x02, 0x5d, 0xd4, 0xd0, 0xa5, 0x96, 0x8a, 0x15,
		0xf8, 0xa2, 0x86, 0x2f, 0xc5, 0xd4, 0xaa, 0x00, 0x18, 0x35, 0x80, 0xa9, 0xa5, 0x4a, 0x05, 0xbe,
		0xe8, 0x31, 0x7a, 0xc0, 0x0a, 0xb0, 0x5a, 0x3a, 0xac, 0x14, 0x53, 0x99, 0x02, 0x60, 0xd4, 0x00,
		0x86, 0x72, 0x11, 0xa8, 0x5a, 0x3e, 0xaa, 0x14, 0x52, 0x8d, 0xf2, 0x54, 0x8b, 0xf2, 0x53, 0x89,
		0xf2, 0x5a, 0x67, 0x3e, 0xd6, 0xf2, 0xb0, 0x94, 0x49, 0x08, 0xd7, 0x8c, 0x28, 0x8a, 0x33, 0x3f,
		0x0b, 0xe2, 0x48, 0xdb, 0x65, 0x14, 0xbc, 0xb5, 0xb4, 0xf7, 0x5d, 0x5c, 0xf9, 0x03, 0x3f, 0xfb,
		0x3e, 0x0a, 0xd7, 0xb5, 0x78, 0x20, 0xa2, 0x5e, 0x1c, 0x5d, 0x04, 0x97, 0x7a, 0x24, 0xb2, 0x9f,
		0x71, 0xf2, 0x43, 0x0f, 0xa2, 0x34, 0xf3, 0xa3, 0x9e, 0xa8, 0x3d, 0xfe, 0x46, 0x3a, 0xf3, 0x9d,
		0xda, 0x20, 0x89, 0xb3, 0xb8, 0x17, 0x87, 0x69, 0xf1, 0xae, 0x16, 0xa4, 0x41, 0x5a, 0x0b, 0xc5,
		0xb5, 0x08, 0x27, 0x5f, 0x6a, 0x61, 0x10, 0xfd, 0xd0, 0xd3, 0xcc, 0xcf, 0x84, 0xde, 0xf7, 0x33,
		0xff, 0xdc, 0x4f, 0x45, 0x2d, 0x4c, 0x07, 0xb5, 0x2c, 0xbc, 0x4e, 0x47, 0xff, 0xa9, 0x89, 0x5f,
		0x99, 0x88, 0xfa, 0xa2, 0xaf, 0x07, 0xa9, 0x9e, 0x08, 0xbf, 0xf7, 0xdd, 0x3f, 0x0f, 0xc2, 0x20,
		0xbb, 0xa9, 0x45, 0x22, 0xb8, 0xfc, 0x7e, 0x1e, 0x27, 0x69, 0xf1, 0xae, 0x76, 0x67, 0x4c, 0x61,
		0x44, 0x3a, 0x3c, 0x1f, 0xff, 0x53, 0xf9, 0xd7, 0xda, 0x30, 0x0b, 0xc2, 0xe0, 0xff, 0x44, 0x5f,
		0x3f, 0xf7, 0xa3, 0xfe, 0xcf, 0xa0, 0x9f, 0x7d, 0xaf, 0x8d, 0x7f, 0x39, 0x8f, 0xcc, 0x43, 0xdf,
		0x4b, 0x69, 0x5b, 0x48, 0x3c, 0x7e, 0x70, 0x8b, 0x1b, 0x95, 0x8c, 0x17, 0xda, 0x7b, 0x06, 0x9f,
		0x4b, 0x96, 0x0c, 0x7b, 0x59, 0x34, 0xa1, 0xdd, 0xad, 0x7c, 0xa1, 0xad, 0xc9, 0x23, 0x7a, 0x9d,
		0xc9, 0xea, 0x7a, 0x56, 0x1a, 0xa4, 0x9e, 0x3d, 0x5a, 0x56, 0xcf, 0x4e, 0x07, 0x9e, 0x1b, 0x5e,
		0x7b, 0xe6, 0x64, 0xf5, 0xac, 0xd4, 0xb9, 0xb7, 0x76, 0x5e, 0x6b, 0xb2, 0x62, 0x5e, 0xf1, 0x8f,
		0x74, 0xc7, 0xeb, 0xe3, 0x1d, 0x4f, 0xd6, 0x67, 0xaf, 0x58, 0x9e, 0x37, 0x08, 0x4f, 0xea, 0x58,
		0x46, 0x34, 0x60, 0x6a, 0x5f, 0xc4, 0xcd, 0x08, 0xd9, 0xd9, 0xcd, 0x40, 0x10, 0xf5, 0x47, 0xcd,
		0x0e, 0xd2, 0xcc, 0xc8, 0xb2, 0x84, 0x74, 0x24, 0xd7, 0x8e, 0x82, 0xc8, 0x0c, 0xc5, 0x95, 0x88,
		0xb2, 0x54, 0xdb, 0x5d, 0x5b, 0x7f, 0x4f, 0xd8, 0x52, 0xff, 0xd7, 0x3d, 0x4b, 0x37, 0x3e, 0xd5,
		0xeb, 0x8d, 0xed, 0x7a, 0x7d, 0x7d, 0xfb, 0xe3, 0xf6, 0xfa, 0xce, 0xd6, 0xd6, 0x46, 0x63, 0x63,
		0x8b, 0xb0, 0xf1, 0xed, 0xa4, 0x2f, 0x12, 0xd1, 0xdf, 0x1b, 0xa1, 0x36, 0x1a, 0x86, 0x21, 0x9c,
		0x5d, 0x3d, 0x56, 0xa4, 0x3e, 0x1b, 0x22, 0x4c, 0x7d, 0xca, 0xa3, 0x3c, 0x34, 0x09, 0x0e, 0x3d,
		0xfa, 0x40, 0xcb, 0x22, 0x62, 0xb1, 0x8d, 0x7a, 0x4c, 0x53, 0x38, 0x96, 0xd1, 0xf2, 0x5f, 0x3a,
		0x5e, 0x42, 0xc8, 0x43, 0xb4, 0x61, 0xd4, 0x17, 0x17, 0x41, 0x24, 0xfa, 0xfa, 0xf4, 0x43, 0xa3,
		0xe6, 0x24, 0xc5, 0x9e, 0xd6, 0xac, 0xa9, 0xc4, 0x22, 0xcd, 0x97, 0x20, 0xea, 0x8f, 0x08, 0x33,
		0x31, 0xb3, 0xf6, 0xc7, 0xd1, 0x84, 0x5e, 0xcd, 0xa1, 0x75, 0x12, 0x71, 0x11, 0xfc, 0xa2, 0x19,
		0x95, 0xa7, 0xa0, 0x8b, 0x7b, 0xfa, 0x28, 0x7e, 0x12, 0xe4, 0x63, 0x5a, 0x37, 0x1e, 0x26, 0x3d,
		0x41, 0x96, 0xa8, 0x6b, 0x5f, 0xc4, 0xcd, 0xcf, 0x38, 0x19, 0x79, 0x84, 0x36, 0xc8, 0x3f, 0x69,
		0xa2, 0x55, 0xcf, 0x67, 0x3f, 0x35, 0x92, 0xcb, 0xe1, 0xa8, 0xe0, 0xd5, 0x76, 0xd7, 0xb2, 0x64,
		0x28, 0xa8, 0x96, 0x67, 0x77, 0x56, 0x16, 0xc0, 0x04, 0x1b, 0x65, 0xc5, 0x46, 0x9b, 0x01, 0xcd,
		0x36, 0xd5, 0x4c, 0x76, 0xa5, 0x1b, 0x57, 0xe6, 0xf1, 0x01, 0xaa, 0xe1, 0x85, 0x26, 0x2d, 0x20,
		0x4f, 0x0f, 0x38, 0xd0, 0x04, 0x46, 0x74, 0x81, 0x0b, 0x6d, 0x60, 0x47, 0x1f, 0xd8, 0xd1, 0x08,
		0x5e, 0x74, 0x82, 0x26, 0xad, 0x20, 0x4a, 0x2f, 0xc8, 0xd3, 0x8c, 0xc2, 0xc0, 0x7c, 0x14, 0x88,
		0x7c, 0x10, 0x9a, 0xc6, 0xf5, 0xdc, 0x5c, 0xe2, 0xfe, 0x4c, 0x9b, 0x68, 0xb0, 0x21, 0x1c, 0x9c,
		0x88, 0x07, 0x43, 0x02, 0xc2, 0x8d, 0x88, 0xb0, 0x25, 0x24, 0x6c, 0x89, 0x09, 0x4f, 0x82, 0x42,
		0x9b, 0xa8, 0x10, 0x27, 0x2c, 0x6c, 0x88, 0x4b, 0x61, 0x68, 0x28, 0xa2, 0xcb, 0xf1, 0x96, 0x1d,
		0x93, 0xe8, 0x35, 0x4d, 0x10, 0x13, 0xbb, 0x99, 0x44, 0x80, 0x09, 0xa5, 0x59, 0x67, 0x62, 0x2e,
		0x17, 0x6a, 0xc3, 0x91, 0xe2, 0x30, 0xa6, 0x3a, 0x5c, 0x29, 0x0f, 0x7b, 0xea, 0xc3, 0x9e, 0x02,
		0xf1, 0xa6, 0x42, 0x3c, 0x28, 0x11, 0x13, 0x6a, 0x54, 0x40, 0xc1, 0xbd, 0x19, 0x08, 0x9e, 0x11,
		0x7b, 0x18, 0x44, 0xd9, 0x27, 0x4e, 0xf1, 0x7a, 0x42, 0x3f, 0xb6, 0x18, 0x99, 0xec, 0xf8, 0xd1,
		0xe5, 0x68, 0xb1, 0x4f, 0x59, 0xc5, 0x37, 0x7e, 0xb2, 0x7b, 0xed, 0x28, 0x88, 0xd8, 0x25, 0x72,
		0xa6, 0xbc, 0x7a, 0xc6, 0xfc, 0x13, 0x3f, 0x1c, 0x0a, 0xc6, 0xf6, 0x1f, 0x24, 0x7e, 0x2f, 0x0b,
		0xe2, 0xa8, 0x19, 0x5c, 0x06, 0xb9, 0x1c, 0x84, 0xdf, 0xf1, 0x00, 0xef, 0x19, 0xba, 0xac, 0xff,
		0x0b, 0x2e, 0x2b, 0xd9, 0x65, 0x37, 0xb7, 0xb6, 0xe0, 0xb4, 0x20, 0xe2, 0x6a, 0x59, 0x7b, 0x86,
		0x33, 0x0d, 0xaa, 0x92, 0x54, 0x72, 0x25, 0x2c, 0xbb, 0xb6, 0x2f, 0x61, 0xfd, 0x2e, 0xf3, 0x4c,
		0x87, 0xa6, 0x6f, 0x99, 0x38, 0x46, 0xd3, 0xb7, 0x3c, 0x37, 0x44, 0xd3, 0x57, 0xf2, 0x03, 0xa0,
		0xe9, 0x0b, 0xc6, 0x31, 0x81, 0x02, 0x9a, 0xbe, 0x65, 0xd3, 0x0f, 0x34, 0x7d, 0x57, 0xfd, 0x42,
		0xd3, 0x17, 0xbc, 0xfa, 0x05, 0xe6, 0xa3, 0xe9, 0x8b, 0x6c, 0xb9, 0x88, 0xcb, 0xa2, 0xe9, 0x2b,
		0xdd, 0x65, 0xd1, 0xf4, 0x05, 0x11, 0x57, 0xce, 0x5a, 0x34, 0x7d, 0x2b, 0x93, 0x54, 0xb4, 0xeb,
		0x49, 0x20, 0x63, 0xd6, 0xf5, 0xcd, 0xcd, 0x46, 0xdb, 0x77, 0x15, 0xe6, 0xa2, 0xed, 0x5b, 0x22,
		0x90, 0xd1, 0xf6, 0x2d, 0xcf, 0x0d, 0xd1, 0xf6, 0x95, 0xfc, 0x00, 0x68, 0xfb, 0x82, 0x73, 0x4c,
		0xa0, 0xc0, 0xb7, 0xed, 0x7b, 0x1e, 0x44, 0x7e, 0x72, 0xc3, 0xb0, 0xef, 0xbb, 0x03, 0x5a, 0x5f,
		0x01, 0x0b, 0x71, 0x3f, 0xc5, 0x72, 0xed, 0x55, 0xf0, 0x14, 0xd3, 0x99, 0xf3, 0x26, 0x67, 0xbe,
		0xc3, 0xe1, 0x42, 0x1b, 0xc2, 0xf7, 0x30, 0x10, 0x3e, 0x24, 0x89, 0xc5, 0x90, 0x17, 0xa7, 0xe1,
		0x2e, 0x26, 0xd5, 0x3d, 0x0e, 0x27, 0x41, 0x15, 0xbf, 0x86, 0xc3, 0x49, 0x50, 0xad, 0x2b, 0x5a,
		0xa5, 0x83, 0x94, 0x57, 0xa2, 0x1a, 0xbf, 0x77, 0xda, 0x87, 0x7f, 0x91, 0x88, 0x0b, 0x0e, 0x11,
		0x77, 0x7a, 0x7a, 0xd9, 0x36, 0x03, 0x5b, 0x3b, 0x93, 0x3a, 0xe7, 0xc3, 0x87, 0xbc, 0x04, 0xa8,
		0x8d, 0x19, 0x18, 0xea, 0x00, 0x85, 0x2c, 0xc3, 0x7d, 0x6c, 0x0b, 0x9b, 0x88, 0xfb, 0xd8, 0x96,
		0x6c, 0x29, 0xee, 0x63, 0xab, 0xa8, 0xb3, 0xe3, 0x3e, 0x36, 0xc2, 0xdd, 0xbf, 0x8a, 0xdf, 0xd1,
		0x76, 0x3c, 0x5d, 0x0e, 0x5c, 0xd6, 0xc6, 0xd7, 0x22, 0x5c, 0xd6, 0x86, 0x40, 0x37, 0x73, 0xad,
		0x16, 0xae, 0x6d, 0x23, 0x6c, 0x09, 0x11, 0x8f, 0x9d, 0xd6, 0x21, 0x41, 0x9f, 0x48, 0x1a, 0xa4,
		0x59, 0x75, 0xd0, 0xad, 0x32, 0x58, 0x55, 0x15, 0x34, 0xab, 0x08, 0x2a, 0xae, 0x48, 0x34, 0x69,
		0x2a, 0x98, 0x2c, 0x09, 0x51, 0xfe, 0x12, 0x28, 0x3e, 0x0d, 0x22, 0x20, 0x3f, 0xed, 0xca, 0xb5,
		0x40, 0x72, 0x94, 0xa1, 0x16, 0x5d, 0xd4, 0x89, 0x2a, 0x72, 0xdd, 0x4b, 0x1e, 0xa8, 0x25, 0x02,
		0x9a, 0xc8, 0xb5, 0x43, 0xa4, 0xae, 0x15, 0x22, 0x72, 0x6d, 0x10, 0x99, 0xc9, 0x1b, 0x4a, 0x93,
		0x35, 0x04, 0x27, 0x67, 0xa8, 0x4d, 0xc6, 0x90, 0x9d, 0x7c, 0x21, 0x3b, 0xd9, 0x42, 0x73, 0x72,
		0xa5, 0xda, 0x24, 0x8b, 0xca, 0xb5, 0x37, 0x5a, 0x7a, 0x93, 0x66, 0xe2, 0x4a, 0x0f, 0xfa, 0x74,
		0x1c, 0xbc, 0x48, 0x96, 0x85, 0x69, 0x54, 0x5a, 0x60, 0xa4, 0x46, 0x5a, 0xc9, 0x8d, 0xae, 0x52,
		0x1c, 0x51, 0x25, 0x3c, 0x8a, 0x4a, 0x75, 0xe4, 0x94, 0xfc, 0x68, 0x29, 0xf9, 0x11, 0x52, 0xda,
		0xa3, 0xa2, 0xd8, 0xd6, 0xb8, 0xff, 0x51, 0x91, 0x1b, 0xf1, 0x24, 0x9b, 0xfe, 0x1e, 0xd4, 0x8e,
		0x9f, 0x08, 0xd9, 0xd4, 0xf1, 0xb3, 0x4c, 0x24, 0x11, 0xb9, 0xe3, 0xf0, 0xb4, 0xff, 0x9d, 0xae,
		0xeb, 0x3b, 0x86, 0x7e, 0xe0, 0xeb, 0x17, 0x67, 0x7f, 0xd7, 0x6f, 0xff, 0xfa, 0xeb, 0xc3, 0x33,
		0xdf, 0xf8, 0x17, 0x9d, 0x28, 0x71, 0x46, 0xe9, 0x03, 0x6e, 0x77, 0xad, 0xaf, 0xf8, 0x94, 0x57,
		0xf1, 0x29, 0xa3, 0xe3, 0x8f, 0x62, 0x14, 0x1d, 0xff, 0x25, 0x77, 0xfc, 0x09, 0xa8, 0x84, 0x2b,
		0xda, 0xed, 0x27, 0xd3, 0xcc, 0x20, 0xc7, 0xe2, 0x88, 0x34, 0x2f, 0xd0, 0xf5, 0xe7, 0xd1, 0xa4,
		0x40, 0xd7, 0x9f, 0x7b, 0x33, 0x02, 0x5d, 0x7f, 0x7a, 0x44, 0x8b, 0x4c, 0xb3, 0x81, 0xa0, 0x5e,
		0x94, 0x92, 0x1e, 0x74, 0x56, 0xef, 0x79, 0x97, 0xc6, 0xab, 0x4a, 0xeb, 0xde, 0x54, 0xc8, 0x61,
		0xa7, 0xc3, 0xce, 0xb2, 0xc9, 0x1b, 0x8d, 0x19, 0x67, 0x3a, 0x33, 0xcd, 0xa4, 0x67, 0x98, 0x69,
		0xcc, 0x2c, 0xcb, 0xf2, 0x18, 0x22, 0x3d, 0x04, 0xee, 0xbd, 0x03, 0x4d, 0xea, 0xac, 0xdc, 0x8a,
		0x06, 0x8c, 0xe5, 0xe4, 0xcc, 0xf2, 0x33, 0x56, 0xb9, 0xbf, 0xb1, 0x64, 0x4f, 0x97, 0xed, 0xe1,
		0x4c, 0x3d, 0xbb, 0x5c, 0xec, 0x97, 0x87, 0xc0, 0x72, 0x7e, 0x53, 0x49, 0x18, 0x97, 0x85, 0x6d,
		0x56, 0x98, 0x2e, 0x31, 0x35, 0x2d, 0x3d, 0x15, 0x95, 0xe3, 0x85, 0xab, 0xf7, 0x89, 0x12, 0xfc,
		0x41, 0xfb, 0x1e, 0xa7, 0xd3, 0x95, 0x2f, 0xc7, 0x13, 0x8a, 0x66, 0x44, 0xf1, 0x9b, 0x4b, 0xf2,
		0xfa, 0x72, 0x07, 0xe1, 0x4b, 0x6f, 0x7d, 0xcb, 0x68, 0x71, 0x4b, 0x6c, 0x65, 0xcb, 0x6a, 0x59,
		0x4b, 0x6f, 0x4d, 0x4b, 0x6f, 0x41, 0xcb, 0x6d, 0x35, 0xab, 0xc5, 0x44, 0xca, 0x1e, 0x0c, 0x97,
		0xa4, 0x90, 0x92, 0xaa, 0x88, 0x92, 0xa4, 0x80, 0x92, 0xb6, 0xf7, 0x29, 0x73, 0xaf, 0x93, 0xc0,
		0xde, 0xa6, 0xec, 0xbd, 0x4c, 0x32, 0x7b, 0x97, 0x64, 0xf6, 0x2a, 0x69, 0xec, 0x4d, 0xaa, 0xdd,
		0xae, 0x91, 0xa5, 0x30, 0x2a, 0xbf, 0x7e, 0xa0, 0x52, 0x4f, 0xcc, 0x4b, 0x33, 0x92, 0x36, 0x4c,
		0xa4, 0x8f, 0xda, 0x50, 0x18, 0xb1, 0x21, 0x34, 0x5a, 0x43, 0x65, 0xa4, 0x86, 0xdc, 0x28, 0x0d,
		0xb9, 0x11, 0x1a, 0x5a, 0xa3, 0x33, 0xd5, 0xda, 0x79, 0x97, 0x3e, 0x22, 0x73, 0xaf, 0x32, 0x49,
		0x82, 0xe8, 0x52, 0x66, 0xc0, 0x28, 0xc4, 0x36, 0x95, 0x42, 0x00, 0x66, 0x1e, 0x1e, 0x59, 0x82,
		0x99, 0x07, 0x72, 0x11, 0x12, 0x3b, 0xbd, 0xab, 0xfc, 0xfd, 0x14, 0x77, 0xc5, 0xa6, 0xb5, 0x84,
		0x0c, 0x71, 0x07, 0x76, 0x75, 0x59, 0xe1, 0x98, 0x34, 0x7e, 0x79, 0xec, 0xe2, 0x7e, 0x9e, 0x5a,
		0x8b, 0x7d, 0xdb, 0x3f, 0x5e, 0xed, 0x29, 0x60, 0xf4, 0xa0, 0x9f, 0x96, 0xbf, 0x77, 0xfb, 0xe0,
		0xb7, 0x63, 0xff, 0x96, 0x6b, 0xff, 0x04, 0xfb, 0xb7, 0xd8, 0xbf, 0xc5, 0xfe, 0xed, 0x2b, 0x96,
		0xb2, 0xf4, 0xfd, 0xdb, 0x7b, 0x81, 0x57, 0xde, 0x2e, 0xee, 0x7d, 0x23, 0xb0, 0x97, 0xab, 0x5a,
		0x52, 0x20, 0x90, 0x1c, 0x64, 0x27, 0x09, 0x32, 0xc9, 0x82, 0x4c, 0xd2, 0xa0, 0x91, 0x3c, 0xaa,
		0xd1, 0x90, 0x91, 0xb6, 0x97, 0x2b, 0x33, 0xb9, 0x10, 0x4a, 0x32, 0x8f, 0x93, 0x0d, 0x76, 0x74,
		0xb1, 0xa3, 0x8b, 0x1d, 0x5d, 0x06, 0xc9, 0x89, 0x56, 0x92, 0x92, 0x93, 0xac, 0x24, 0x25, 0xad,
		0x62, 0xe9, 0xe9, 0xec, 0xe8, 0xca, 0x3f, 0xec, 0x80, 0xc2, 0x21, 0x07, 0xb3, 0x87, 0x1b, 0xdc,
		0x4f, 0xac, 0x55, 0xd9, 0xc0, 0x93, 0x50, 0xba, 0xc8, 0xbd, 0x8b, 0x82, 0xc4, 0x1d, 0x14, 0x92,
		0xef, 0x9e, 0x00, 0x81, 0x02, 0x81, 0x02, 0x81, 0x02, 0x81, 0xe2, 0x45, 0xa0, 0x64, 0xdf, 0x15,
		0x41, 0xa2, 0x0b, 0x40, 0xb0, 0x1b, 0x40, 0xa4, 0x2b, 0x40, 0x26, 0xb9, 0x51, 0x4a, 0x72, 0x04,
		0x93, 0x1d, 0xb5, 0xa4, 0x47, 0x36, 0xf9, 0x91, 0x4d, 0x82, 0x34, 0x93, 0xa1, 0xdc, 0xa4, 0x28,
		0x39, 0x39, 0xd2, 0xe9, 0x32, 0xcc, 0x44, 0x9c, 0x61, 0x10, 0x65, 0x1b, 0x0d, 0x42, 0x27, 0x2b,
		0x36, 0x08, 0x98, 0xe2, 0xf8, 0xd1, 0xa5, 0x20, 0x73, 0x86, 0x3f, 0xad, 0x7b, 0xc3, 0x09, 0xde,
		0x04, 0x44, 0xea, 0xc2, 0xab, 0xc2, 0xac, 0x13, 0x3f, 0x1c, 0x0a, 0x82, 0x76, 0x1d, 0x24, 0x7e,
		0x2f, 0x0b, 0xe2, 0xa8, 0x19, 0x5c, 0x06, 0xb9, 0x6c, 0x80, 0xce, 0xa5, 0x3f, 0xb4, 0x2e, 0xa2,
		0x07, 0xd4, 0x5f, 0x08, 0xf5, 0xc6, 0xd6, 0xd6, 0xc7, 0x2d, 0xc0, 0x9d, 0x07, 0x17, 0xa2, 0x63,
		0xc5, 0x19, 0x2e, 0xa1, 0x28, 0xdd, 0x2d, 0xb2, 0x78, 0x10, 0x87, 0xf1, 0xe5, 0x0d, 0xa9, 0x6e,
		0xc9, 0x7d, 0xa3, 0xd0, 0x2d, 0x41, 0xb7, 0x04, 0xdd, 0x12, 0x74, 0x4b, 0xd0, 0x2d, 0x41, 0xb7,
		0x04, 0xdd, 0x12, 0x74, 0x4b, 0xd0, 0x2d, 0x41, 0xb7, 0x04, 0xe5, 0x23, 0xba, 0x25, 0xe8, 0x96,
		0xa0, 0x5b, 0x82, 0x6e, 0x49, 0x65, 0x39, 0x21, 0x89, 0x73, 0x77, 0xee, 0x67, 0x78, 0x1a, 0xe7,
		0xef, 0xdc, 0x0f, 0xc4, 0x64, 0xcf, 0xe1, 0x29, 0x8c, 0x24, 0x71, 0x1e, 0x8f, 0x7c, 0x8f, 0xbe,
		0xc5, 0xdd, 0x4b, 0x12, 0xec, 0xa0, 0x78, 0xee, 0xc9, 0xfd, 0x73, 0x29, 0xee, 0xff, 0x41, 0xe6,
		0x25, 0xcd, 0x38, 0xaf, 0x6a, 0xc9, 0x6c, 0x34, 0xbf, 0xad, 0x4f, 0xa2, 0x08, 0x5d, 0x6a, 0xee,
		0x94, 0x9f, 0x2b, 0x49, 0xe6, 0x46, 0xb9, 0xb9, 0x10, 0x67, 0xb6, 0xd1, 0x8d, 0xfd, 0x9a, 0x14,
		0xf1, 0xcf, 0xa2, 0x67, 0x61, 0x4d, 0xff, 0x92, 0xd5, 0xc7, 0xa9, 0x73, 0x0c, 0x3c, 0x12, 0xa7,
		0xce, 0xcd, 0xf1, 0x40, 0x9c, 0xe5, 0xf6, 0xe7, 0x9f, 0x65, 0x30, 0xb8, 0xae, 0xeb, 0xe2, 0x57,
		0x26, 0x92, 0xc8, 0x0f, 0x1f, 0xde, 0xc2, 0x56, 0xfe, 0xc9, 0x6e, 0xf3, 0x6d, 0xc1, 0x39, 0x6f,
		0x4b, 0xf9, 0x85, 0x38, 0xe7, 0xad, 0xac, 0x32, 0x01, 0xe7, 0xbc, 0xe1, 0x9c, 0xb7, 0xe5, 0x2c,
		0x65, 0xe9, 0xe7, 0xbc, 0xe5, 0x90, 0x15, 0xa9, 0xbc, 0x43, 0xde, 0x0a, 0x0b, 0x70, 0xc2, 0x9b,
		0x6a, 0xe9, 0x80, 0x40, 0x5a, 0x90, 0x9d, 0x1e, 0xc8, 0xa4, 0x09, 0x32, 0xe9, 0x82, 0x46, 0xda,
		0x28, 0xbf, 0x1c, 0x5d, 0xab, 0xd2, 0x09, 0x6f, 0x03, 0xb9, 0xd3, 0xa7, 0x8f, 0x92, 0x0b, 0x8e,
		0x25, 0xc1, 0xb1, 0x24, 0x38, 0x96, 0x84, 0x5c, 0x2a, 0x22, 0x97, 0x92, 0x68, 0xa5, 0x26, 0x39,
		0x29, 0x4a, 0x52, 0xaa, 0x92, 0x9e, 0xb2, 0x0a, 0x03, 0xfa, 0xe2, 0xc2, 0x1f, 0x86, 0x99, 0x7e,
		0x25, 0xb2, 0x24, 0xe8, 0xd1, 0xd1, 0xda, 0x3c, 0xb2, 0x8b, 0x86, 0xdc, 0x66, 0x03, 0x72, 0x1b,
		0x32, 0xa9, 0x8e, 0x60, 0xca, 0xa3, 0x96, 0xfa, 0xc8, 0xa6, 0x40, 0xb2, 0xa9, 0x90, 0x66, 0x4a,
		0x94, 0x9b, 0x1a, 0x25, 0xa7, 0x48, 0x32, 0xa9, 0xb2, 0x30, 0x44, 0xee, 0x11, 0x94, 0x73, 0xe3,
		0x9f, 0xcc, 0x23, 0x29, 0x89, 0x26, 0x4c, 0x72, 0x89, 0x93, 0x62, 0x02, 0x25, 0x9c, 0x48, 0xa9,
		0x26, 0x54, 0xf2, 0x89, 0x95, 0x7c, 0x82, 0xa5, 0x9d, 0x68, 0x69, 0x24, 0x5c, 0x22, 0x89, 0x97,
		0x5c, 0x02, 0x2e, 0x0c, 0xba, 0x08, 0xfd, 0xcb, 0x94, 0x5e, 0x50, 0x98, 0xc6, 0xd1, 0xdc, 0xbc,
		0xf7, 0x10, 0x9d, 0x31, 0x4c, 0xd0, 0x94, 0x13, 0x35, 0x83, 0x84, 0x4d, 0x3d, 0x71, 0xb3, 0x49,
		0xe0, 0x6c, 0x12, 0x39, 0x8f, 0x84, 0x4e, 0x2b, 0xb1, 0x13, 0x4b, 0xf0, 0xc5, 0x47, 0x48, 0xe6,
		0x60, 0x8b, 0xb9, 0x11, 0x4f, 0x44, 0xc3, 0x2b, 0x91, 0xe4, 0xf3, 0xc1, 0x04, 0xa3, 0xde, 0xb4,
		0xfa, 0xad, 0x13, 0xb4, 0xcd, 0x8c, 0x86, 0x57, 0xa3, 0x0f, 0x97, 0x98, 0x0b, 0xe0, 0xd8, 0x82,
		0x27, 0x3e, 0x2b, 0x22, 0x9b, 0x32, 0x73, 0xdd, 0x90, 0xc4, 0xe6, 0x0c, 0x28, 0x2e, 0x28, 0x2e,
		0x28, 0x2e, 0x28, 0x2e, 0x28, 0x2e, 0x28, 0xae, 0x42, 0x14, 0x37, 0xf2, 0x93, 0x24, 0xfe, 0xa9,
		0x93, 0x4c, 0xb1, 0xf7, 0xd3, 0xec, 0x16, 0x41, 0xd3, 0x68, 0x1d, 0xf9, 0xf6, 0xf8, 0x45, 0x33,
		0x4f, 0xac, 0x51, 0x3d, 0x12, 0x8e, 0x09, 0xbf, 0x9b, 0x31, 0x73, 0x7a, 0x8e, 0xd6, 0x06, 0x71,
		0x3b, 0x09, 0x9f, 0xa9, 0x45, 0x3c, 0x8b, 0x3c, 0x74, 0x1d, 0xff, 0x17, 0x5c, 0x67, 0xc9, 0xae,
		0xd3, 0xf8, 0x08, 0xdf, 0x51, 0x93, 0x0f, 0xd2, 0xb5, 0xea, 0x0c, 0x7d, 0x31, 0xc2, 0x96, 0x50,
		0xd9, 0x0b, 0x27, 0x72, 0x5a, 0xd8, 0x8c, 0x5d, 0x24, 0xcf, 0xaf, 0x98, 0x7b, 0xf6, 0x41, 0x6d,
		0xaa, 0x86, 0x9d, 0xbc, 0xa9, 0x3d, 0x9c, 0xfa, 0x96, 0x79, 0xbc, 0x18, 0x3d, 0xf8, 0x57, 0x7b,
		0xfa, 0x93, 0x98, 0xc3, 0xa9, 0xe5, 0x68, 0x14, 0x66, 0xe6, 0x5f, 0x71, 0xb6, 0xd3, 0xe0, 0xba,
		0x6e, 0x4e, 0x9e, 0xda, 0xb9, 0xf7, 0xd0, 0x5e, 0xde, 0xd8, 0xf6, 0x9a, 0xf9, 0xb3, 0x1e, 0xe5,
		0x8f, 0x8a, 0xcb, 0x7c, 0x4a, 0xff, 0x68, 0xfb, 0x22, 0xf4, 0x6f, 0x08, 0x2a, 0x8c, 0xee, 0x59,
		0x05, 0x7d, 0x11, 0xf4, 0x45, 0xcf, 0xe0, 0x05, 0xfa, 0xa2, 0xf9, 0xf0, 0x85, 0xbe, 0xe8, 0xa5,
		0x74, 0x06, 0xfa, 0x22, 0x6a, 0x0c, 0x13, 0xfa, 0xa2, 0xdf, 0xc7, 0x3f, 0xe8, 0x8b, 0xe8, 0x27,
		0x4e, 0x8a, 0x09, 0x94, 0x70, 0x22, 0xa5, 0x9a, 0x50, 0xc9, 0x27, 0x56, 0xf2, 0x09, 0x96, 0x76,
		0xa2, 0xa5, 0xd3, 0x54, 0x5a, 0x83, 0xbe, 0x68, 0xbe, 0x41, 0xd0, 0x17, 0x2d, 0x9c, 0x98, 0x31,
		0x7c, 0xc9, 0x37, 0x51, 0x33, 0x48, 0xd8, 0xd4, 0x13, 0x37, 0x9b, 0x04, 0xce, 0x26, 0x91, 0xf3,
		0x48, 0xe8, 0xb4, 0x12, 0x3b, 0xb1, 0x04, 0x5f, 0x7c, 0x84, 0xf4, 0x87, 0x2f, 0x47, 0xa8, 0x9a,
		0xb4, 0x86, 0x75, 0x8a, 0x69, 0x76, 0x0d, 0x2a, 0x23, 0x15, 0x1c, 0x81, 0xd4, 0x6d, 0x81, 0x33,
		0xd6, 0x91, 0xbb, 0x3d, 0x70, 0xd6, 0x42, 0x06, 0xb7, 0x09, 0xce, 0x18, 0x4d, 0xea, 0x76, 0x41,
		0xba, 0x89, 0x0b, 0x3a, 0xbc, 0x3f, 0x4f, 0x57, 0xd0, 0xe1, 0xa1, 0x14, 0x44, 0x29, 0x88, 0x52,
		0x10, 0xa5, 0x20, 0x4a, 0x41, 0x94, 0x82, 0xcb, 0x8d, 0x78, 0xd0, 0xe1, 0x2d, 0x6e, 0x1a, 0x74,
		0x78, 0x8b, 0x97, 0x5e, 0x10, 0x13, 0x2d, 0xc9, 0x4c, 0xe8, 0xf0, 0x54, 0xcf, 0x22, 0x8f, 0x7b,
		0x02, 0x70, 0x9d, 0x25, 0xbb, 0x0e, 0x74, 0x78, 0xaa, 0xf2, 0x41, 0xba, 0x56, 0x41, 0x87, 0x47,
		0xd9, 0x12, 0xe8, 0xf0, 0x7e, 0x6f, 0x17, 0x7b, 0x79, 0xd0, 0x9d, 0x36, 0x02, 0x2a, 0x3c, 0x3a,
		0x16, 0x40, 0x85, 0xa7, 0xac, 0x9b, 0xa9, 0xae, 0xc1, 0x0b, 0xfd, 0x1b, 0x28, 0xf0, 0x64, 0x7d,
		0xb0, 0x22, 0x49, 0xe2, 0x84, 0x9c, 0x02, 0xef, 0x81, 0x55, 0x50, 0xe0, 0x41, 0x81, 0xf7, 0x0c,
		0x5e, 0xa0, 0xc0, 0x9b, 0x0f, 0x5f, 0x28, 0xf0, 0x5e, 0x4a, 0x65, 0xa0, 0xc0, 0xa3, 0xc6, 0x2e,
		0xa1, 0xc0, 0xfb, 0x7d, 0xfc, 0x83, 0x02, 0x8f, 0x7e, 0xe2, 0xa4, 0x98, 0x40, 0x09, 0x27, 0x52,
		0xaa, 0x09, 0x95, 0x7c, 0x62, 0x25, 0x9f, 0x60, 0x69, 0x27, 0x5a, 0x3a, 0x0d, 0xa5, 0x35, 0x28,
		0xf0, 0xe6, 0x1b, 0x04, 0x05, 0xde, 0xc2, 0x89, 0x19, 0x63, 0x97, 0x7c, 0x13, 0x35, 0x83, 0x84,
		0x4d, 0x3d, 0x71, 0xb3, 0x49, 0xe0, 0x6c, 0x12, 0x39, 0x8f, 0x84, 0x4e, 0x2b, 0xb1, 0x13, 0x4b,
		0xf0, 0xc5, 0x47, 0x08, 0x05, 0xde, 0x52, 0x6b, 0x60, 0x28, 0xf0, 0xb8, 0x3a, 0x02, 0x14, 0x78,
		0xaf, 0xb4, 0x10, 0x0a, 0x3c, 0x65, 0x13, 0x17, 0x14, 0x78, 0x7f, 0x9e, 0xae, 0xa0, 0xc0, 0x43,
		0x29, 0x88, 0x52, 0x10, 0xa5, 0x20, 0x4a, 0x41, 0x94, 0x82, 0x28, 0x05, 0x97, 0x1b, 0xf1, 0xa0,
		0xc0, 0x5b, 0xdc, 0x34, 0x28, 0xf0, 0x16, 0x2f, 0xbd, 0x20, 0x23, 0x5a, 0x92, 0x99, 0x50, 0xe0,
		0xa9, 0x9e, 0x45, 0x1e, 0xf7, 0x04, 0xe0, 0x3a, 0x4b, 0x76, 0x1d, 0x28, 0xf0, 0x54, 0xe5, 0x83,
		0x74, 0xad, 0x82, 0x02, 0x8f, 0xb2, 0x25, 0x50, 0xe0, 0xfd, 0xde, 0x2e, 0xe6, 0xd2, 0xa0, 0xfb,
		0xda, 0x08, 0x28, 0xf0, 0xe8, 0x58, 0x00, 0x05, 0x9e, 0xb2, 0x6e, 0xa6, 0xb6, 0x02, 0xcf, 0x1c,
		0x3d, 0x29, 0x14, 0x78, 0xb2, 0x3e, 0x58, 0xf1, 0x6b, 0x20, 0xa2, 0x54, 0xd0, 0xd3, 0xe0, 0x3d,
		0xb4, 0x0b, 0x2a, 0x3c, 0xa8, 0xf0, 0x9e, 0x41, 0x0c, 0x54, 0x78, 0xf3, 0xe1, 0x0b, 0x15, 0xde,
		0x4b, 0xe9, 0x0c, 0x54, 0x78, 0xd4, 0x18, 0x26, 0x54, 0x78, 0xbf, 0x8f, 0x7f, 0x50, 0xe1, 0xd1,
		0x4f, 0x9c, 0x14, 0x13, 0x28, 0xe1, 0x44, 0x4a, 0x35, 0xa1, 0x92, 0x4f, 0xac, 0xe4, 0x13, 0x2c,
		0xed, 0x44, 0x4b, 0xa7, 0xa9, 0xb4, 0x06, 0x15, 0xde, 0x7c, 0x83, 0xa0, 0xc2, 0x5b, 0x38, 0x31,
		0x63, 0xf4, 0x92, 0x6f, 0xa2, 0x66, 0x90, 0xb0, 0xa9, 0x27, 0x6e, 0x36, 0x09, 0x9c, 0x4d, 0x22,
		0xe7, 0x91, 0xd0, 0x69, 0x25, 0x76, 0x62, 0x09, 0xbe, 0xf8, 0x08, 0xa1, 0xc2, 0x5b, 0x6a, 0x0d,
		0x0c, 0x15, 0x1e, 0x57, 0x47, 0x80, 0x0a, 0xef, 0x95, 0x16, 0x42, 0x85, 0xa7, 0x6c, 0xe2, 0x82,
		0x0a, 0xef, 0xcf, 0xd3, 0x15, 0x54, 0x78, 0x28, 0x05, 0x51, 0x0a, 0xa2, 0x14, 0x44, 0x29, 0x88,
		0x52, 0x10, 0xa5, 0xe0, 0x72, 0x23, 0x1e, 0x54, 0x78, 0x8b, 0x9b, 0x06, 0x15, 0xde, 0xe2, 0xa5,
		0x17, 0xa4, 0x44, 0x4b, 0x32, 0x13, 0x2a, 0x3c, 0xd5, 0xb3, 0xc8, 0xe3, 0x9e, 0x00, 0x5c, 0x67,
		0xc9, 0xae, 0x03, 0x15, 0x9e, 0xaa, 0x7c, 0x90, 0xae, 0x55, 0x50, 0xe1, 0x51, 0xb6, 0x04, 0x2a,
		0xbc, 0xdf, 0xdb, 0xc5, 0x5d, 0x1e, 0xf4, 0x40, 0x1d, 0x01, 0x1d, 0x1e, 0x1d, 0x0b, 0xa0, 0xc3,
		0x53, 0xd8, 0xd1, 0x14, 0x57, 0xe2, 0xe5, 0xcf, 0x0a, 0x2d, 0x9e, 0xac, 0x8f, 0x76, 0x40, 0x63,
		0x83, 0xa1, 0x68, 0xad, 0x91, 0x68, 0x83, 0x13, 0xa9, 0xc5, 0xa0, 0xbd, 0xfb, 0x1d, 0x52, 0xa0,
		0xbd, 0x9b, 0x0f, 0x5f, 0x68, 0xef, 0x5e, 0x4a, 0x61, 0xa0, 0xbd, 0xa3, 0xc6, 0x2a, 0xc9, 0x6c,
		0x03, 0x15, 0x11, 0x27, 0x14, 0xfe, 0x45, 0x22, 0x2e, 0x28, 0x44, 0x9c, 0xe9, 0x9c, 0xdf, 0x36,
		0x01, 0x5b, 0x3a, 0x13, 0xa2, 0xfd, 0xe1, 0x43, 0x5e, 0x14, 0x4e, 0x78, 0x2c, 0xd8, 0x9c, 0x0c,
		0xa2, 0x4e, 0x41, 0x26, 0x4a, 0x4a, 0x1e, 0x8a, 0x73, 0x14, 0xc0, 0xe5, 0xc0, 0xe5, 0xc0, 0xe5,
		0xc0, 0xe5, 0x24, 0x7e, 0x24, 0x64, 0xce, 0x51, 0x18, 0xd0, 0x9a, 0xa7, 0xa4, 0xd5, 0xf6, 0x20,
		0xd6, 0xfe, 0x20, 0x97, 0x3a, 0x29, 0xa6, 0x50, 0xc2, 0xa9, 0x94, 0x6a, 0x4a, 0x25, 0x9f, 0x5a,
		0xc9, 0xa7, 0x58, 0xda, 0xa9, 0x96, 0x46, 0xca, 0x25, 0x92, 0x7a, 0xe9, 0xb5, 0x53, 0x66, 0x22,
		0xd6, 0x78, 0x6b, 0x8c, 0x9c, 0x03, 0x16, 0x75, 0xe3, 0x27, 0x42, 0x36, 0x75, 0xfc, 0x2c, 0x13,
		0x49, 0x44, 0x6e, 0x7c, 0x56, 0xfb, 0xdf, 0xdb, 0xb7, 0xa7, 0xeb, 0xfa, 0xce, 0xd9, 0x3f, 0xa7,
		0x1b, 0xfa, 0xce, 0x59, 0xfe, 0x76, 0x63, 0xfc, 0x25, 0x7f, 0xbf, 0x79, 0xba, 0xae, 0xd7, 0xa7,
		0xef, 0xb7, 0x4e, 0xd7, 0xf5, 0xad, 0xb3, 0x77, 0x7f, 0xfd, 0xf5, 0xe1, 0xdd, 0xdf, 0x1f, 0x6f,
		0x5f, 0xfe, 0x83, 0xb5, 0xc9, 0x2f, 0x7b, 0xf7, 0xcf, 0xdb, 0xd3, 0x0d, 0x7d, 0xf3, 0x6c, 0xfa,
		0x87, 0x8f, 0xa7, 0xeb, 0xfa, 0xe6, 0xd9, 0xbb, 0x77, 0xff, 0xa2, 0x13, 0x83, 0xce, 0x28, 0x81,
		0xa7, 0xdd, 0xb5, 0xbe, 0x02, 0x41, 0xdc, 0x10, 0x84, 0x11, 0x1b, 0x2a, 0x79, 0x54, 0x1b, 0x0e,
		0xf4, 0x7e, 0xfc, 0x33, 0xa2, 0x57, 0x3e, 0x4e, 0x0d, 0x43, 0xfd, 0x88, 0xfa, 0x11, 0xf5, 0x23,
		0xea, 0x47, 0xd4, 0x8f, 0xa8, 0x1f, 0x2b, 0x53, 0x3f, 0x9e, 0xc7, 0x71, 0x28, 0xfc, 0x88, 0x62,
		0xed, 0xb8, 0x01, 0xf2, 0x46, 0xc0, 0x02, 0xcc, 0x47, 0x3f, 0xb4, 0x87, 0xf9, 0x7c, 0x34, 0x01,
		0xe5, 0x81, 0xc4, 0xe9, 0x92, 0x37, 0x15, 0xf2, 0xa0, 0x11, 0xc3, 0x92, 0xce, 0xae, 0x68, 0x9c,
		0xc8, 0x45, 0xe7, 0xe4, 0x2d, 0xd2, 0x27, 0x6c, 0xd1, 0x38, 0x49, 0x4b, 0x96, 0xbb, 0x10, 0x49,
		0x34, 0xcc, 0x13, 0x8c, 0x26, 0x75, 0x80, 0x6f, 0x45, 0x4a, 0x1b, 0x39, 0xf9, 0xb2, 0xfc, 0x6c,
		0x55, 0xee, 0x6f, 0x2c, 0xd9, 0xd1, 0x65, 0x3b, 0x38, 0x57, 0xc7, 0x2e, 0x17, 0xfc, 0xe5, 0x41,
		0xb0, 0x9c, 0xdf, 0x54, 0x12, 0xc8, 0x65, 0x81, 0x9b, 0x19, 0xa8, 0x4b, 0xcc, 0x4e, 0x2b, 0xc8,
		0x46, 0xe5, 0x78, 0xe2, 0xea, 0xfd, 0xa2, 0x04, 0x9f, 0xc8, 0xe7, 0x22, 0x82, 0x28, 0x13, 0xc9,
		0x85, 0xdf, 0x13, 0xba, 0xdf, 0xef, 0x27, 0x22, 0x4d, 0x45, 0x79, 0xb7, 0x4f, 0x3c, 0x9c, 0xd0,
		0x78, 0xca, 0x92, 0x92, 0x22, 0x43, 0xb9, 0x23, 0xfc, 0xa5, 0xef, 0x17, 0xc9, 0xd8, 0x0f, 0x92,
		0xb8, 0xdf, 0x23, 0x6b, 0x3f, 0x47, 0xfa, 0x7e, 0x8d, 0xf4, 0xfd, 0x18, 0xb9, 0xfb, 0x2d, 0x6a,
		0xb1, 0x95, 0xb2, 0x47, 0xda, 0x25, 0x69, 0xbb, 0xa4, 0x6a, 0xb9, 0x24, 0x69, 0xb7, 0xa4, 0x0d,
		0x0c, 0xc8, 0x1c, 0x0c, 0x20, 0x30, 0x00, 0x20, 0x7b, 0xa3, 0x9f, 0xcc, 0x86, 0x3e, 0x99, 0x8d,
		0x7b, 0x1a, 0x1b, 0xf4, 0x6a, 0xf7, 0x74, 0x64, 0x69, 0xa3, 0xb4, 0x09, 0x8d, 0x97, 0xe7, 0x6e,
		0xd3, 0x88, 0x33, 0x35, 0x44, 0xd6, 0x26, 0x93, 0xd4, 0x69, 0x35, 0xe9, 0xd3, 0x69, 0x14, 0xa6,
		0xd1, 0x08, 0x4d, 0x9f, 0x51, 0x99, 0x36, 0x23, 0x37, 0x5d, 0x46, 0x6e, 0x9a, 0x8c, 0xd6, 0xf4,
		0x58, 0xb5, 0x36, 0xe6, 0xa5, 0x4f, 0x83, 0x3d, 0xec, 0x4d, 0xc9, 0xcd, 0x20, 0x6b, 0x44, 0xe4,
		0x42, 0x64, 0xe4, 0x41, 0xe5, 0x8a, 0x39, 0x24, 0x8a, 0x35, 0xce, 0x64, 0x7e, 0xd8, 0x94, 0xe4,
		0x3c, 0xd5, 0xf9, 0xc4, 0x2b, 0x15, 0xe6, 0x31, 0xfa, 0xf4, 0xc8, 0x12, 0x8c, 0x3e, 0x91, 0xa3,
		0x41, 0x98, 0xf8, 0x58, 0xe5, 0xef, 0x27, 0xbb, 0x39, 0xfe, 0xc4, 0x76, 0xa4, 0x8c, 0xc9, 0x60,
		0x0c, 0x7b, 0xb0, 0xc2, 0x35, 0x2b, 0x3c, 0xf3, 0x19, 0xf5, 0xb0, 0xa6, 0xc6, 0x1b, 0x85, 0xed,
		0x18, 0xf4, 0xf8, 0xe3, 0xb5, 0xbf, 0xfb, 0xfc, 0x67, 0x86, 0x7d, 0x24, 0x8e, 0x7a, 0x48, 0x1a,
		0x3c, 0xc2, 0xb0, 0xc7, 0x0a, 0x3f, 0x5d, 0x0c, 0x7b, 0x94, 0x67, 0x00, 0x86, 0x3d, 0xd4, 0x61,
		0x2b, 0xa5, 0x0f, 0x7b, 0x14, 0x93, 0xcb, 0xd2, 0xe6, 0x3d, 0x0a, 0x0b, 0x30, 0xf2, 0xa1, 0x5a,
		0x3a, 0x20, 0x90, 0x16, 0x64, 0xa7, 0x07, 0x32, 0x69, 0x82, 0x4c, 0xba, 0xa0, 0x91, 0x36, 0xaa,
		0xd1, 0xd4, 0x91, 0x36, 0xf2, 0x21, 0xf9, 0xf8, 0x5b, 0x1a, 0xc7, 0xdd, 0x4a, 0x3e, 0x11, 0x1e,
		0x03, 0x1f, 0x18, 0xf8, 0x20, 0x9d, 0x8a, 0xc8, 0xa5, 0x24, 0x5a, 0xa9, 0x49, 0x4e, 0x8a, 0x92,
		0x94, 0xaa, 0xa4, 0xa7, 0xac, 0xc2, 0x80, 0xbe, 0xb8, 0xf0, 0x87, 0x61, 0x36, 0xbd, 0x15, 0x91,
		0xcc, 0x1d, 0x27, 0x8f, 0xec, 0xc2, 0x65, 0x27, 0xb8, 0xec, 0x84, 0x7c, 0xca, 0xa3, 0x96, 0xfa,
		0xc8, 0xa6, 0x40, 0xb2, 0xa9, 0x90, 0x66, 0x4a, 0x94, 0x9b, 0x1a, 0x25, 0xa7, 0x48, 0x32, 0xa9,
		0xb2, 0x30, 0x84, 0xc6, 0x6d, 0x60, 0x33, 0xf1, 0x8f, 0xc2, 0xad, 0x60, 0xc4, 0x12, 0x26, 0xb9,
		0xc4, 0x49, 0x31, 0x81, 0x12, 0x4e, 0xa4, 0x54, 0x13, 0x2a, 0xf9, 0xc4, 0x4a, 0x3e, 0xc1, 0xd2,
		0x4e, 0xb4, 0x34, 0x12, 0x2e, 0x91, 0xc4, 0x4b, 0x2e, 0x01, 0x17, 0x06, 0x5d, 0x84, 0xfe, 0x65,
		0x4a, 0x2f, 0x28, 0x4c, 0xe3, 0x68, 0x6e, 0x1e, 0x31, 0x7f, 0xa3, 0x75, 0x86, 0x3c, 0xd9, 0x04,
		0x4d, 0x39, 0x51, 0x33, 0x48, 0xd8, 0xd4, 0x13, 0x37, 0x9b, 0x04, 0xce, 0x26, 0x91, 0xf3, 0x48,
		0xe8, 0xb4, 0x12, 0x3b, 0xb1, 0x04, 0x5f, 0x7c, 0x84, 0xe4, 0xce, 0xa4, 0x9f, 0x89, 0x78, 0x22,
		0x1a, 0x5e, 0x89, 0x24, 0x9f, 0x73, 0x26, 0x18, 0xf5, 0xa6, 0xd5, 0x6f, 0x9d, 0xa0, 0x6d, 0x66,
		0x34, 0xbc, 0x1a, 0x7d, 0xb8, 0xc4, 0x5c, 0xe0, 0x0d, 0x9c, 0x71, 0xf6, 0xb3, 0x22, 0xb2, 0x29,
		0x33, 0xd7, 0x0d, 0x49, 0x6c, 0xce, 0x80, 0xe2, 0x82, 0xe2, 0x82, 0xe2, 0x82, 0xe2, 0x82, 0xe2,
		0x82, 0xe2, 0x2a, 0x44, 0x71, 0x23, 0x3f, 0x49, 0xe2, 0x9f, 0x3a, 0xc9, 0x14, 0x7b, 0x3f, 0xcd,
		0x6e, 0x11, 0x34, 0xcd, 0xf1, 0xa3, 0x4b, 0x41, 0xee, 0x2e, 0xd6, 0xe9, 0x8b, 0x66, 0x9e, 0x58,
		0x9b, 0x1c, 0x09, 0x40, 0x36, 0x91, 0x11, 0xe7, 0x77, 0x33, 0x66, 0x9e, 0xf8, 0xe1, 0x50, 0xd0,
		0xd9, 0x03, 0x9d, 0x6b, 0xe7, 0x41, 0xe2, 0xf7, 0x46, 0x85, 0x74, 0x33, 0xb8, 0x0c, 0xf2, 0x93,
		0x20, 0xc8, 0xda, 0x7b, 0xfb, 0x9e, 0xb0, 0xeb, 0xf8, 0xbf, 0xe0, 0x3a, 0x4b, 0x76, 0x9d, 0xc6,
		0x47, 0xf8, 0x8e, 0x9a, 0x7c, 0x90, 0xae, 0x55, 0x67, 0xe8, 0x8b, 0x11, 0xb6, 0x84, 0xca, 0x5e,
		0x38, 0xb1, 0xbb, 0x27, 0x0b, 0xbb, 0x68, 0x9f, 0xc3, 0xf1, 0xec, 0x1d, 0x94, 0x0f, 0xa7, 0xbe,
		0x29, 0x5c, 0x49, 0x49, 0x07, 0xfe, 0xb8, 0xec, 0x15, 0x97, 0xbd, 0xae, 0xc8, 0xd1, 0x28, 0xcc,
		0xcc, 0x2f, 0xe1, 0xa4, 0x9c, 0xa7, 0xaf, 0xe8, 0xf3, 0x9a, 0xf9, 0xb3, 0x1e, 0xe5, 0x8f, 0x5a,
		0xd5, 0x0b, 0x6e, 0xdf, 0xcb, 0xd4, 0x18, 0x85, 0xfe, 0x0d, 0x41, 0x85, 0xd1, 0x3d, 0xab, 0xa0,
		0x2f, 0x82, 0xbe, 0xe8, 0x19, 0xbc, 0x40, 0x5f, 0x34, 0x1f, 0xbe, 0xd0, 0x17, 0xbd, 0x94, 0xce,
		0x40, 0x5f, 0x44, 0x8d, 0x61, 0x42, 0x5f, 0xf4, 0xfb, 0xf8, 0x07, 0x7d, 0x11, 0xfd, 0xc4, 0x49,
		0x31, 0x81, 0x12, 0x4e, 0xa4, 0x54, 0x13, 0x2a, 0xf9, 0xc4, 0x4a, 0x3e, 0xc1, 0xd2, 0x4e, 0xb4,
		0x74, 0x9a, 0x4a, 0x6b, 0xd0, 0x17, 0xcd, 0x37, 0x08, 0xfa, 0xa2, 0x85, 0x13, 0x33, 0x86, 0x2f,
		0xf9, 0x26, 0x6a, 0x06, 0x09, 0x9b, 0x7a, 0xe2, 0x66, 0x93, 0xc0, 0xd9, 0x24, 0x72, 0x1e, 0x09,
		0x9d, 0x56, 0x62, 0x27, 0x96, 0xe0, 0x8b, 0x8f, 0x90, 0xfe, 0xf0, 0xe5, 0x08, 0x55, 0x93, 0xd6,
		0xb0, 0x4e, 0x31, 0xcd, 0xae, 0x41, 0x65, 0xa4, 0x82, 0x23, 0x90, 0xb8, 0x07, 0x6a, 0xae, 0x75,
		0x64, 0xee, 0x87, 0x9a, 0x6f, 0x21, 0xe1, 0x7b, 0xa3, 0xe6, 0x1a, 0x4d, 0xe2, 0x3e, 0x29, 0xfa,
		0x89, 0x0b, 0x3a, 0xbc, 0x3f, 0x4f, 0x57, 0xd0, 0xe1, 0xa1, 0x14, 0x44, 0x29, 0x88, 0x52, 0x10,
		0xa5, 0x20, 0x4a, 0x41, 0x94, 0x82, 0xcb, 0x8d, 0x78, 0xd0, 0xe1, 0x2d, 0x6e, 0x1a, 0x74, 0x78,
		0x8b, 0x97, 0x5e, 0x10, 0x13, 0x2d, 0xc9, 0x4c, 0xe8, 0xf0, 0x54, 0xcf, 0x22, 0x8f, 0x7b, 0x02,
		0x70, 0x9d, 0x25, 0xbb, 0x0e, 0x74, 0x78, 0xaa, 0xf2, 0x41, 0xba, 0x56, 0x41, 0x87, 0x47, 0xd9,
		0x12, 0xe8, 0xf0, 0x7e, 0x6f, 0x17, 0x7b, 0x79, 0xd0, 0x9d, 0x36, 0x02, 0x2a, 0x3c, 0x3a, 0x16,
		0x40, 0x85, 0xa7, 0xac, 0x9b, 0xa9, 0xae, 0xc1, 0x0b, 0xfd, 0x1b, 0x28, 0xf0, 0x64, 0x7d, 0xb0,
		0x22, 0x49, 0xe2, 0x84, 0x9c, 0x02, 0xef, 0x81, 0x55, 0x50, 0xe0, 0x41, 0x81, 0xf7, 0x0c, 0x5e,
		0xa0, 0xc0, 0x9b, 0x0f, 0x5f, 0x28, 0xf0, 0x5e, 0x4a, 0x65, 0xa0, 0xc0, 0xa3, 0xc6, 0x2e, 0xa1,
		0xc0, 0xfb, 0x7d, 0xfc, 0x83, 0x02, 0x8f, 0x7e, 0xe2, 0xa4, 0x98, 0x40, 0x09, 0x27, 0x52, 0xaa,
		0x09, 0x95, 0x7c, 0x62, 0x25, 0x9f, 0x60, 0x69, 0x27, 0x5a, 0x3a, 0x0d, 0xa5, 0x35, 0x28, 0xf0,
		0xe6, 0x1b, 0x04, 0x05, 0xde, 0xc2, 0x89, 0x19, 0x63, 0x97, 0x7c, 0x13, 0x35, 0x83, 0x84, 0x4d,
		0x3d, 0x71, 0xb3, 0x49, 0xe0, 0x6c, 0x12, 0x39, 0x8f, 0x84, 0x4e, 0x2b, 0xb1, 0x13, 0x4b, 0xf0,
		0xc5, 0x47, 0x08, 0x05, 0xde, 0x52, 0x6b, 0x60, 0x28, 0xf0, 0xb8, 0x3a, 0x02, 0x14, 0x78, 0xaf,
		0xb4, 0x10, 0x0a, 0x3c, 0x65, 0x13, 0x17, 0x14, 0x78, 0x7f, 0x9e, 0xae, 0xa0, 0xc0, 0x43, 0x29,
		0x88, 0x52, 0x10, 0xa5, 0x20, 0x4a, 0x41, 0x94, 0x82, 0x28, 0x05, 0x97, 0x1b, 0xf1, 0xa0, 0xc0,
		0x5b, 0xdc, 0x34, 0x28, 0xf0, 0x16, 0x2f, 0xbd, 0x20, 0x23, 0x5a, 0x92, 0x99, 0x50, 0xe0, 0xa9,
		0x9e, 0x45, 0x1e, 0xf7, 0x04, 0xe0, 0x3a, 0x4b, 0x76, 0x1d, 0x28, 0xf0, 0x54, 0xe5, 0x83, 0x74,
		0xad, 0x82, 0x02, 0x8f, 0xb2, 0x25, 0x50, 0xe0, 0xfd, 0xde, 0x2e, 0xe6, 0xd2, 0xa0, 0xfb, 0xda,
		0x08, 0x28, 0xf0, 0xe8, 0x58, 0x00, 0x05, 0x9e, 0xb2, 0x6e, 0xa6, 0xb6, 0x02, 0xcf, 0x1c, 0x3d,
		0x29, 0x14, 0x78, 0xb2, 0x3e, 0x58, 0xf1, 0x6b, 0x20, 0xa2, 0x54, 0xd0, 0xd3, 0xe0, 0x3d, 0xb4,
		0x0b, 0x2a, 0x3c, 0xa8, 0xf0, 0x9e, 0x41, 0x0c, 0x54, 0x78, 0xf3, 0xe1, 0x0b, 0x15, 0xde, 0x4b,
		0xe9, 0x0c, 0x54, 0x78, 0xd4, 0x18, 0x26, 0x54, 0x78, 0xbf, 0x8f, 0x7f, 0x50, 0xe1, 0xd1, 0x4f,
		0x9c, 0x14, 0x13, 0x28, 0xe1, 0x44, 0x4a, 0x35, 0xa1, 0x92, 0x4f, 0xac, 0xe4, 0x13, 0x2c, 0xed,
		0x44, 0x4b, 0xa7, 0xa9, 0xb4, 0x06, 0x15, 0xde, 0x7c, 0x83, 0xa0, 0xc2, 0x5b, 0x38, 0x31, 0x63,
		0xf4, 0x92, 0x6f, 0xa2, 0x66, 0x90, 0xb0, 0xa9, 0x27, 0x6e, 0x36, 0x09, 0x9c, 0x4d, 0x22, 0xe7,
		0x91, 0xd0, 0x69, 0x25, 0x76, 0x62, 0x09, 0xbe, 0xf8, 0x08, 0xa1, 0xc2, 0x5b, 0x6a, 0x0d, 0x0c,
		0x15, 0x1e, 0x57, 0x47, 0x80, 0x0a, 0xef, 0x95, 0x16, 0x42, 0x85, 0xa7, 0x6c, 0xe2, 0x82, 0x0a,
		0xef, 0xcf, 0xd3, 0x15, 0x54, 0x78, 0x28, 0x05, 0x51, 0x0a, 0xa2, 0x14, 0x44, 0x29, 0x88, 0x52,
		0x10, 0xa5, 0xe0, 0x72, 0x23, 0x1e, 0x54, 0x78, 0x8b, 0x9b, 0x06, 0x15, 0xde, 0xe2, 0xa5, 0x17,
		0xa4, 0x44, 0x4b, 0x32, 0x13, 0x2a, 0x3c, 0xd5, 0xb3, 0xc8, 0xe3, 0x9e, 0x00, 0x5c, 0x67, 0xc9,
		0xae, 0x03, 0x15, 0x9e, 0xaa, 0x7c, 0x90, 0xae, 0x55, 0x50, 0xe1, 0x51, 0xb6, 0x04, 0x2a, 0xbc,
		0xdf, 0xdb, 0xc5, 0x5d, 0x1e, 0xf4, 0x40, 0x1d, 0x01, 0x1d, 0x1e, 0x1d, 0x0b, 0xa0, 0xc3, 0x53,
		0xd8, 0xd1, 0x14, 0x57, 0xe2, 0xe5, 0xcf, 0x0a, 0x2d, 0x9e, 0xac, 0x8f, 0x76, 0x40, 0x63, 0x83,
		0xa1, 0x68, 0xad, 0x91, 0x68, 0x83, 0x13, 0xa9, 0xc5, 0xa0, 0xbd, 0xfb, 0x1d, 0x52, 0xa0, 0xbd,
		0x9b, 0x0f, 0x5f, 0x68, 0xef, 0x5e, 0x4a, 0x61, 0xa0, 0xbd, 0xa3, 0xc6, 0x2a, 0xc9, 0x6c, 0x03,
		0x15, 0x11, 0x27, 0x14, 0xfe, 0x45, 0x22, 0x2e, 0x28, 0x44, 0x9c, 0xe9, 0x9c, 0xdf, 0x36, 0x01,
		0x5b, 0x3a, 0x13, 0xa2, 0xfd, 0xe1, 0x43, 0x5e, 0x14, 0x4e, 0x78, 0x2c, 0xd8, 0x9c, 0x0c, 0xa2,
		0x4e, 0x41, 0x26, 0x4a, 0x4a, 0x1e, 0x8a, 0x73, 0x14, 0xc0, 0xe5, 0xc0, 0xe5, 0xc0, 0xe5, 0xc0,
		0xe5, 0x24, 0x7e, 0x24, 0x64, 0xce, 0x51, 0x18, 0xd0, 0x9a, 0xa7, 0xa4, 0xd5, 0xf6, 0x20, 0xd6,
		0xfe, 0x20, 0x97, 0x3a, 0x29, 0xa6, 0x50, 0xc2, 0xa9, 0x94, 0x6a, 0x4a, 0x25, 0x9f, 0x5a, 0xc9,
		0xa7, 0x58, 0xda, 0xa9, 0x96, 0x46, 0xca, 0x25, 0x92, 0x7a, 0xe9, 0xb5, 0x53, 0x66, 0x22, 0xd6,
		0x78, 0x6b, 0x8c, 0x9c, 0x03, 0x16, 0x75, 0xe3, 0x27, 0x42, 0x36, 0x75, 0xfc, 0x2c, 0x13, 0x49,
		0x44, 0x6e, 0x7c, 0x56, 0xfb, 0xdf, 0xdb, 0xb7, 0xa7, 0xeb, 0xfa, 0xce, 0xd9, 0x3f, 0xa7, 0x1b,
		0xfa, 0xce, 0x59, 0xfe, 0x76, 0x63, 0xfc, 0x25, 0x7f, 0xbf, 0x79, 0xba, 0xae, 0xd7, 0xa7, 0xef,
		0xb7, 0x4e, 0xd7, 0xf5, 0xad, 0xb3, 0x77, 0x7f, 0xfd, 0xf5, 0xe1, 0xdd, 0xdf, 0x1f, 0x6f, 0x5f,
		0xfe, 0x83, 0xb5, 0xc9, 0x2f, 0x7b, 0xf7, 0xcf, 0xdb, 0xd3, 0x0d, 0x7d, 0xf3, 0x6c, 0xfa, 0x87,
		0x8f, 0xa7, 0xeb, 0xfa, 0xe6, 0xd9, 0xbb, 0x77, 0xff, 0xa2, 0x13, 0x83, 0xce, 0x28, 0x81, 0xa7,
		0xdd, 0xb5, 0xbe, 0x02, 0x41, 0xdc, 0x10, 0x84, 0x11, 0x1b, 0x2a, 0x79, 0x54, 0x1b, 0x0e, 0xf4,
		0x7e, 0xfc, 0x33, 0xa2, 0x57, 0x3e, 0x4e, 0x0d, 0x43, 0xfd, 0x88, 0xfa, 0x11, 0xf5, 0x23, 0xea,
		0x47, 0xd4, 0x8f, 0xa8, 0x1f, 0x2b, 0x53, 0x3f, 0x9e, 0xc7, 0x71, 0x28, 0xfc, 0x88, 0x62, 0xed,
		0xb8, 0x01, 0xf2, 0x46, 0xc0, 0x02, 0xcc, 0x47, 0x3f, 0xb4, 0x87, 0xf9, 0x7c, 0x34, 0x01, 0xe5,
		0x81, 0xc4, 0xe9, 0x92, 0x37, 0x15, 0xf2, 0xa0, 0x11, 0xc3, 0x92, 0xce, 0xae, 0x68, 0x9c, 0xc8,
		0x45, 0xe7, 0xe4, 0x2d, 0xd2, 0x27, 0x6c, 0xd1, 0x38, 0x49, 0x4b, 0x96, 0xbb, 0x10, 0x49, 0x34,
		0xcc, 0x13, 0x8c, 0x26, 0x75, 0x80, 0x6f, 0x45, 0x4a, 0x1b, 0x39, 0xf9, 0xb2, 0xfc, 0x6c, 0x55,
		0xee, 0x6f, 0x2c, 0xd9, 0xd1, 0x65, 0x3b, 0x38, 0x57, 0xc7, 0x2e, 0x17, 0xfc, 0xe5, 0x41, 0xb0,
		0x9c, 0xdf, 0x54, 0x12, 0xc8, 0x65, 0x81, 0x9b, 0x19, 0xa8, 0x4b, 0xcc, 0x4e, 0x2b, 0xc8, 0x46,
		0xe5, 0x78, 0xe2, 0xea, 0xfd, 0xa2, 0x04, 0x9f, 0xc8, 0xe7, 0x22, 0xd2, 0x24, 0x2c, 0xf1, 0xbe,
		0x89, 0x87, 0x33, 0x19, 0xf9, 0xef, 0x2e, 0xc9, 0xfb, 0xcb, 0x1d, 0xd3, 0x2f, 0x7d, 0x4f, 0x48,
		0xc6, 0x9e, 0x8f, 0xc4, 0x3d, 0x1d, 0x59, 0x7b, 0x36, 0xd2, 0xf7, 0x64, 0xa4, 0xef, 0xb9, 0xc8,
		0xdd, 0x53, 0x51, 0x8b, 0x91, 0x94, 0x3d, 0xb6, 0x7e, 0x17, 0x76, 0xcb, 0x77, 0x9c, 0x99, 0xc8,
		0x5f, 0xb6, 0xe3, 0xc8, 0xd1, 0x69, 0x49, 0x1b, 0x0e, 0x90, 0x39, 0x04, 0x40, 0x60, 0xb3, 0x5f,
		0xf6, 0xa6, 0x3e, 0x99, 0xcd, 0x7b, 0x32, 0x9b, 0xf4, 0x34, 0x36, 0xe3, 0xd5, 0xee, 0xdf, 0xc8,
		0xd2, 0x41, 0x69, 0xd3, 0xf2, 0x54, 0x8f, 0x86, 0x57, 0xe7, 0x42, 0xde, 0x56, 0xc6, 0x5d, 0x9a,
		0x79, 0x64, 0x90, 0xac, 0x0d, 0x26, 0xa9, 0x93, 0x6a, 0xd2, 0x27, 0xd3, 0x28, 0x4c, 0xa2, 0x11,
		0x9a, 0x3c, 0xa3, 0x32, 0x69, 0x46, 0x6e, 0xb2, 0x8c, 0xdc, 0x24, 0x19, 0xad, 0xc9, 0xb1, 0x6a,
		0x6d, 0xca, 0x4b, 0x9f, 0x04, 0x23, 0x74, 0x20, 0x0b, 0x85, 0x83, 0x58, 0x66, 0x0f, 0x60, 0x79,
		0x9c, 0x5c, 0xab, 0xb2, 0xf7, 0x27, 0xa1, 0x8c, 0x91, 0x7b, 0xe2, 0x0a, 0x89, 0x93, 0x56, 0x24,
		0x9f, 0xb0, 0x02, 0x12, 0x05, 0x12, 0x05, 0x12, 0x05, 0x12, 0xc5, 0x8b, 0x44, 0xc9, 0x3e, 0x11,
		0x85, 0xc8, 0x45, 0xf6, 0xa4, 0x2e, 0xae, 0xc7, 0xb1, 0xaf, 0xf4, 0x12, 0x1b, 0xc1, 0x04, 0x47,
		0x2d, 0xd1, 0x91, 0x4d, 0x78, 0x64, 0x13, 0x1f, 0xcd, 0x04, 0x28, 0x37, 0x11, 0x4a, 0x4e, 0x88,
		0x74, 0xba, 0x0b, 0x33, 0x11, 0x47, 0x44, 0xc3, 0x2b, 0x91, 0xe4, 0x83, 0x69, 0x84, 0x8e, 0x7e,
		0x25, 0x70, 0xc5, 0x3b, 0x91, 0x2b, 0xdd, 0x65, 0x43, 0x96, 0xd4, 0x95, 0xed, 0xf4, 0xae, 0x68,
		0x67, 0x71, 0x25, 0x3b, 0xad, 0x2b, 0xd8, 0xab, 0x79, 0x7a, 0x31, 0x95, 0x4d, 0xca, 0x99, 0x0c,
		0x40, 0x63, 0xb3, 0x12, 0x65, 0x0a, 0xca, 0x14, 0x94, 0x29, 0x28, 0x53, 0x50, 0xa6, 0xa0, 0x4c,
		0x79, 0x22, 0xe2, 0x0c, 0x83, 0x28, 0xfb, 0xb8, 0x49, 0xa8, 0x42, 0xa1, 0x70, 0x37, 0x05, 0xad,
		0xdb, 0xc6, 0x09, 0x1d, 0x9e, 0x42, 0xf1, 0x36, 0x71, 0xa2, 0x57, 0x20, 0x17, 0x57, 0x1e, 0x53,
		0xb3, 0x8b, 0xf0, 0x0d, 0xc7, 0x84, 0x6e, 0x03, 0x27, 0x79, 0xfb, 0x37, 0x75, 0xa8, 0xd7, 0x37,
		0x77, 0xea, 0x3b, 0x8d, 0xed, 0xcd, 0x9d, 0x2d, 0x60, 0x9e, 0x07, 0x21, 0xa2, 0x63, 0xc5, 0x19,
		0x5a, 0x27, 0xe5, 0xb7, 0x4e, 0x0a, 0xbd, 0xf0, 0x85, 0xdf, 0x13, 0xba, 0xdf, 0xef, 0x27, 0x22,
		0x25, 0xb4, 0xbd, 0x3b, 0xc7, 0x3e, 0x34, 0x52, 0xd0, 0x48, 0x41, 0x23, 0x05, 0x8d, 0x14, 0x34,
		0x52, 0xd0, 0x48, 0x21, 0x13, 0x71, 0xc6, 0xb9, 0x8a, 0x46, 0x86, 0x5a, 0x23, 0x76, 0x11, 0x05,
		0xb9, 0x0b, 0x28, 0xca, 0xbd, 0x36, 0x80, 0xc0, 0xb5, 0x00, 0x67, 0x14, 0x40, 0x40, 0xf1, 0x22,
		0x89, 0xea, 0x21, 0x01, 0x65, 0x96, 0x9c, 0x32, 0x2b, 0x12, 0xc1, 0xe5, 0xf7, 0xf3, 0x38, 0x21,
		0x5a, 0x65, 0xcd, 0x98, 0x87, 0x22, 0x0b, 0x45, 0x16, 0x8a, 0x2c, 0x14, 0x59, 0x28, 0xb2, 0x50,
		0x64, 0xa1, 0xc8, 0x42, 0x91, 0x05, 0x6a, 0x8d, 0x22, 0x0b, 0x48, 0x40, 0x91, 0x45, 0xb5, 0xc8,
		0x1a, 0xa4, 0x11, 0xb9, 0x09, 0xe0, 0x7b, 0x36, 0xa1, 0x9c, 0x42, 0x39, 0x85, 0x72, 0x0a, 0xe5,
		0x14, 0xca, 0x29, 0x94, 0x53, 0x64, 0x22, 0xce, 0x30, 0x88, 0xb2, 0x4f, 0x84, 0xea, 0xa8, 0x2d,
		0xcc, 0xfe, 0x3e, 0x7a, 0x61, 0xf6, 0x97, 0x03, 0xaf, 0x99, 0x31, 0x0b, 0xb3, 0xbf, 0xdc, 0xa2,
		0xf3, 0x43, 0xa8, 0x63, 0xf6, 0xf7, 0xc5, 0x50, 0xdf, 0xdc, 0xc2, 0xd0, 0x2f, 0x13, 0x22, 0x44,
		0xc7, 0x0a, 0x34, 0x4a, 0xca, 0x77, 0x8b, 0x34, 0x09, 0x2f, 0xf5, 0xeb, 0x89, 0xd7, 0x12, 0x69,
		0x94, 0xdc, 0xb3, 0x09, 0x8d, 0x12, 0x34, 0x4a, 0xd0, 0x28, 0x41, 0xa3, 0x04, 0x8d, 0x12, 0x34,
		0x4a, 0x48, 0x35, 0x4a, 0xa0, 0x92, 0x46, 0xa7, 0x04, 0x9d, 0x12, 0x74, 0x4a, 0xd0, 0x29, 0x41,
		0xa7, 0xe4, 0x55, 0x50, 0x87, 0x4a, 0x1a, 0x0d, 0x13, 0xa6, 0x0d, 0x13, 0x1c, 0x99, 0xf8, 0x30,
		0xcd, 0xe3, 0xc8, 0xc4, 0x97, 0x1b, 0x89, 0x23, 0x13, 0x65, 0xfb, 0x92, 0x96, 0xde, 0xa4, 0x99,
		0xb8, 0xd2, 0x83, 0x3e, 0xa1, 0x0e, 0x60, 0x61, 0x12, 0x1a, 0x80, 0x68, 0x00, 0x3e, 0x03, 0x16,
		0x34, 0x00, 0xe7, 0xc3, 0x17, 0x0d, 0xc0, 0x17, 0x1a, 0x86, 0x06, 0x20, 0x39, 0x9e, 0x47, 0xaf,
		0x01, 0x48, 0x25, 0x3d, 0xad, 0x41, 0x75, 0xf2, 0x8c, 0x41, 0xff, 0x3b, 0x5d, 0xd7, 0x77, 0x0c,
		0xfd, 0xc0, 0xd7, 0x2f, 0xce, 0xfe, 0xae, 0xdf, 0xfe, 0xf5, 0xd7, 0x87, 0x67, 0xbe, 0x01, 0xe5,
		0xc8, 0x1a, 0x61, 0xe5, 0x08, 0xc7, 0x4f, 0xb3, 0xaa, 0x15, 0x4d, 0xa5, 0xae, 0xe2, 0x32, 0xa2,
		0x28, 0xce, 0xf2, 0xeb, 0x3d, 0xa4, 0xde, 0xc8, 0x95, 0xf6, 0xbe, 0x8b, 0x2b, 0x7f, 0x30, 0xb9,
		0xcc, 0xb3, 0x16, 0x0f, 0x44, 0xd4, 0x1b, 0xd7, 0x0e, 0x7a, 0x24, 0xb2, 0x9f, 0x71, 0xf2, 0x43,
		0x9f, 0x9e, 0x43, 0x5f, 0x7b, 0xfc, 0x8d, 0x74, 0xe6, 0x3b, 0xb5, 0x41, 0x12, 0x67, 0x71, 0x2f,
		0x0e, 0xd3, 0xe2, 0x5d, 0x6d, 0x44, 0x88, 0x6a, 0xa1, 0xb8, 0x16, 0xe1, 0xe4, 0x4b, 0x2d, 0x0c,
		0xa2, 0x1f, 0xfa, 0xf8, 0xee, 0x48, 0xbd, 0xef, 0x67, 0xfe, 0xb9, 0x9f, 0x8a, 0x5a, 0x98, 0x0e,
		0x6a, 0x59, 0x78, 0x9d, 0x8e, 0xfe, 0x53, 0x1b, 0xcb, 0x34, 0xd3, 0x24, 0xbc, 0x4c, 0xef, 0xde,
		0xe6, 0x97, 0x8c, 0x56, 0xe6, 0x52, 0x51, 0xa5, 0x2f, 0xa4, 0xff, 0x22, 0x6e, 0xe4, 0x5f, 0x70,
		0x20, 0xb7, 0x1b, 0x28, 0xbf, 0xfb, 0x47, 0xb2, 0xdb, 0x27, 0xb7, 0xbb, 0x57, 0xb6, 0x1f, 0x48,
		0xce, 0x01, 0x6c, 0x62, 0xbf, 0x26, 0xe5, 0x8a, 0xe5, 0x64, 0xd8, 0xcb, 0xa2, 0x49, 0xfd, 0xd6,
		0xca, 0x1f, 0xd6, 0x9a, 0x3c, 0xab, 0xd7, 0x99, 0x3c, 0xa1, 0x67, 0xa5, 0x41, 0xea, 0xd9, 0xa3,
		0x47, 0xf3, 0xec, 0x74, 0xe0, 0xb9, 0xe1, 0xb5, 0x67, 0x0d, 0xae, 0xeb, 0xdd, 0x91, 0xd5, 0x6f,
		0xd4, 0xcc, 0x18, 0xe5, 0xfc, 0xa6, 0x92, 0x7c, 0x51, 0x96, 0x0f, 0x12, 0xf7, 0xbd, 0x72, 0xb0,
		0xbb, 0x7a, 0x24, 0x95, 0x80, 0xa2, 0xfc, 0x50, 0x91, 0x4c, 0xe8, 0x49, 0x3c, 0xcc, 0x44, 0x52,
		0xe6, 0xae, 0xc8, 0xc3, 0x73, 0x4d, 0x1e, 0x98, 0x50, 0x92, 0xf7, 0x94, 0x7b, 0x09, 0x7b, 0xe9,
		0xbb, 0x1a, 0x32, 0x76, 0x2f, 0x24, 0xee, 0x52, 0xc8, 0xda, 0x8d, 0x90, 0xbe, 0xeb, 0x20, 0x7d,
		0x77, 0x41, 0xee, 0x2e, 0x82, 0x5a, 0x19, 0xbd, 0xec, 0x4b, 0xce, 0xb5, 0xbc, 0x33, 0x51, 0xba,
		0xd3, 0x14, 0x7b, 0x0b, 0xe3, 0x5f, 0x5f, 0x76, 0x09, 0x5f, 0x6a, 0xe0, 0x97, 0x96, 0x00, 0x64,
		0x26, 0x02, 0x02, 0x09, 0x41, 0x76, 0x62, 0x20, 0x93, 0x20, 0xc8, 0x24, 0x0a, 0x1a, 0x09, 0xa3,
		0xfc, 0xa2, 0x53, 0x46, 0x7b, 0xa6, 0xec, 0x44, 0x52, 0xfc, 0xe2, 0xf2, 0x2b, 0x89, 0xb9, 0x31,
		0xa7, 0xec, 0x8a, 0x62, 0x5e, 0xa2, 0x91, 0x34, 0xc6, 0x24, 0x7d, 0x8e, 0x8a, 0xc2, 0xfc, 0x14,
		0xa1, 0xb9, 0x29, 0x2a, 0xf3, 0x52, 0xe4, 0xe6, 0xa4, 0xc8, 0xcd, 0x47, 0xd1, 0x9a, 0x8b, 0xaa,
		0xd6, 0xde, 0xb2, 0xf4, 0xf9, 0x27, 0x6a, 0x07, 0xee, 0x52, 0x18, 0x79, 0x22, 0x33, 0xea, 0x54,
		0x99, 0xe3, 0x54, 0xcf, 0x64, 0x7e, 0xd8, 0x94, 0xc6, 0xa1, 0xaa, 0xf3, 0x89, 0x57, 0x2a, 0xcc,
		0x93, 0x90, 0x33, 0xd1, 0x91, 0x31, 0x91, 0x96, 0x2f, 0xd1, 0x90, 0x2d, 0x61, 0x90, 0x69, 0xc9,
		0x1c, 0x17, 0x03, 0x1c, 0x4f, 0x6f, 0x22, 0xdf, 0xdf, 0x8b, 0x94, 0x31, 0xb9, 0x87, 0x69, 0x08,
		0x56, 0x80, 0xe6, 0x01, 0xe4, 0x32, 0x77, 0x62, 0x5f, 0x37, 0x7e, 0xe4, 0x0a, 0x67, 0x6c, 0xb4,
		0xd5, 0xc7, 0x20, 0xc7, 0x9f, 0xaf, 0x79, 0x30, 0xb8, 0x6e, 0xcc, 0x5e, 0x17, 0x2d, 0x52, 0x29,
		0xf3, 0x1c, 0x4f, 0x5b, 0x82, 0xb1, 0x8e, 0xe5, 0x54, 0x67, 0x18, 0xeb, 0x28, 0x05, 0x46, 0x18,
		0xeb, 0xc0, 0x58, 0xc7, 0xb2, 0x96, 0x12, 0x63, 0x1d, 0xca, 0x05, 0x7e, 0x69, 0x09, 0x40, 0x66,
		0x22, 0x20, 0x90, 0x10, 0x64, 0x27, 0x06, 0x32, 0x09, 0x82, 0x4c, 0xa2, 0xa0, 0x91, 0x30, 0xaa,
		0xd1, 0xb4, 0x91, 0x36, 0xd6, 0x21, 0xfb, 0xe6, 0xe6, 0x22, 0xe2, 0xc8, 0xdd, 0x90, 0xc3, 0x48,
		0x07, 0x46, 0x3a, 0x08, 0x25, 0x21, 0x72, 0xc9, 0x88, 0x5c, 0x52, 0xa2, 0x95, 0x9c, 0xe4, 0x24,
		0x29, 0x49, 0xc9, 0xaa, 0x58, 0x7a, 0x52, 0x23, 0x1d, 0x0d, 0x8c, 0x74, 0x4c, 0x22, 0x39, 0xb1,
		0x0d, 0x7e, 0x5f, 0xbf, 0x30, 0xf4, 0x83, 0xb3, 0xbf, 0x37, 0xde, 0xd7, 0x6f, 0x77, 0xdf, 0xfd,
		0xbd, 0x7d, 0xfb, 0xf8, 0x9b, 0xff, 0x3c, 0xf5, 0xd7, 0x36, 0xde, 0x6f, 0xdf, 0xee, 0xce, 0xf9,
		0x3f, 0x8d, 0xdb, 0xdd, 0x3f, 0xfc, 0x37, 0xb6, 0x6e, 0xdf, 0xce, 0xfc, 0xd5, 0xd1, 0xf7, 0x37,
		0xe7, 0xfd, 0x40, 0x7d, 0xce, 0x0f, 0x7c, 0x9c, 0xf7, 0x03, 0x1f, 0xe7, 0xfc, 0xc0, 0x5c, 0x93,
		0x36, 0xe7, 0xfc, 0xc0, 0xd6, 0xed, 0x3f, 0x33, 0x7f, 0xff, 0xed, 0xd3, 0x7f, 0xb5, 0x71, 0xfb,
		0xee, 0x9f, 0x79, 0xff, 0x6f, 0xfb, 0xf6, 0x9f, 0xdd, 0x77, 0x18, 0x70, 0x01, 0xfe, 0x81, 0x7f,
		0x49, 0xf8, 0xc7, 0xb8, 0x4f, 0xe9, 0x56, 0x60, 0xdc, 0xe7, 0x8f, 0x8c, 0xc3, 0xb8, 0x8f, 0x82,
		0x9d, 0x23, 0x8c, 0xfb, 0x3c, 0x39, 0x25, 0xf1, 0xe4, 0x56, 0x35, 0xa6, 0x7e, 0xd8, 0xe0, 0x1b,
		0x53, 0x3f, 0x7f, 0x80, 0x67, 0x36, 0xc3, 0x3f, 0x0d, 0x6b, 0x6a, 0xbc, 0x51, 0xd8, 0x8e, 0x21,
		0xa0, 0x3f, 0x5e, 0xfb, 0xf1, 0xe7, 0x9f, 0x08, 0xbf, 0xf7, 0xdd, 0x3f, 0x0f, 0xc2, 0x20, 0xbb,
		0x91, 0x34, 0xfd, 0xf3, 0xc0, 0x04, 0x8c, 0xfd, 0x2c, 0xa7, 0x66, 0xc5, 0xd8, 0x4f, 0x29, 0x30,
		0xc2, 0xd8, 0x0f, 0xc6, 0x7e, 0x96, 0xb5, 0x94, 0xa5, 0x8f, 0xfd, 0xe4, 0x90, 0x15, 0xa9, 0xbc,
		0xc9, 0x9f, 0xc2, 0x02, 0x0c, 0xff, 0xa8, 0x96, 0x0e, 0x08, 0xa4, 0x05, 0xd9, 0xe9, 0x81, 0x4c,
		0x9a, 0x20, 0x93, 0x2e, 0x68, 0xa4, 0x8d, 0x6a, 0xb4, 0x70, 0xa4, 0x0d, 0xff, 0x0c, 0xe4, 0x0e,
		0x7d, 0x3c, 0x4a, 0x2e, 0x92, 0x47, 0x7f, 0x36, 0x30, 0xfa, 0x83, 0xd1, 0x1f, 0x8c, 0xfe, 0xd0,
		0x4f, 0x49, 0xb4, 0x52, 0x93, 0x9c, 0x14, 0x25, 0x29, 0x55, 0x49, 0x4f, 0x59, 0x54, 0x52, 0x17,
		0xad, 0x14, 0xf6, 0x38, 0x95, 0xe1, 0xa2, 0x47, 0x3a, 0xa9, 0x8d, 0x60, 0x8a, 0xa3, 0x96, 0xea,
		0xc8, 0xa6, 0x3c, 0xb2, 0xa9, 0x8f, 0x66, 0x0a, 0x94, 0x9b, 0x0a, 0x25, 0xa7, 0xc4, 0xe2, 0x23,
		0xa1, 0x77, 0xd1, 0x63, 0x28, 0xfc, 0x8b, 0x44, 0x5c, 0x50, 0xba, 0xe6, 0x71, 0x9b, 0xc6, 0x35,
		0x8f, 0xe3, 0x3d, 0xde, 0x0f, 0x1f, 0xf2, 0xb9, 0x80, 0xda, 0x24, 0xe6, 0xe0, 0xf2, 0xee, 0xd2,
		0x3f, 0x0a, 0x39, 0xb2, 0xd6, 0xb9, 0x0e, 0x23, 0x43, 0xe6, 0x4a, 0xac, 0x2d, 0x01, 0x2e, 0x07,
		0x2e, 0x07, 0x2e, 0x07, 0x2e, 0x57, 0x6d, 0x2e, 0x27, 0xbb, 0xcd, 0x51, 0x18, 0x72, 0x25, 0xb2,
		0x24, 0xe8, 0xd1, 0xf1, 0xee, 0x69, 0x00, 0x9c, 0xd8, 0x45, 0xc4, 0x83, 0x68, 0xb4, 0x3f, 0xc8,
		0xa5, 0x4e, 0x8a, 0x29, 0x94, 0x70, 0x2a, 0xa5, 0x9a, 0x52, 0xc9, 0xa7, 0x56, 0xf2, 0x29, 0x96,
		0x76, 0xaa, 0xa5, 0x91, 0x72, 0x89, 0xa4, 0x5e, 0x7a, 0xed, 0x94, 0x99, 0x88, 0xf5, 0x33, 0xe8,
		0x0b, 0x9d, 0x54, 0x02, 0xbc, 0x9f, 0x04, 0xb7, 0x09, 0x99, 0xe4, 0xf8, 0xd1, 0xa5, 0x90, 0x2e,
		0xc8, 0x7c, 0xfc, 0xa2, 0x15, 0xd5, 0xd7, 0x26, 0x42, 0x36, 0x72, 0xe9, 0x86, 0x28, 0xbb, 0x9a,
		0x31, 0xef, 0xc4, 0x0f, 0x87, 0x42, 0x7e, 0xc3, 0x64, 0xae, 0x7d, 0x07, 0x89, 0xdf, 0xcb, 0x82,
		0x38, 0x6a, 0x06, 0x97, 0x41, 0xae, 0x53, 0x24, 0x67, 0xe7, 0xed, 0x7b, 0x82, 0x2e, 0xe1, 0xff,
		0x82, 0x4b, 0xbc, 0xd6, 0x25, 0x1a, 0xdb, 0xdb, 0xdb, 0x9b, 0x32, 0xb5, 0xa7, 0xec, 0x3d, 0xe3,
		0x0d, 0xac, 0x79, 0xea, 0x75, 0xf6, 0x06, 0xeb, 0x41, 0x24, 0x72, 0x52, 0x19, 0x89, 0x99, 0xe1,
		0xc9, 0xb4, 0xda, 0xbf, 0xe8, 0x11, 0xfd, 0xde, 0x20, 0xf4, 0x88, 0x5e, 0x64, 0x1a, 0x7a, 0x44,
		0x0b, 0x1a, 0x88, 0x1e, 0x11, 0x7f, 0x06, 0x80, 0x1e, 0xd1, 0x73, 0x11, 0x6b, 0x2c, 0x9b, 0x26,
		0xe7, 0x80, 0x14, 0xce, 0xa9, 0x9b, 0x4d, 0x3c, 0x44, 0xce, 0xed, 0x9a, 0x31, 0x0c, 0xe7, 0x78,
		0x49, 0x3b, 0xc7, 0xab, 0xf6, 0x76, 0x63, 0xf3, 0x74, 0x5d, 0xff, 0x94, 0x5f, 0xf0, 0xb7, 0x71,
		0x36, 0x73, 0xef, 0xdf, 0xf8, 0xbf, 0x32, 0x8f, 0xfb, 0x9a, 0x29, 0x88, 0x28, 0x79, 0x14, 0xa5,
		0xe3, 0xf0, 0xe0, 0x56, 0x70, 0x2b, 0xf4, 0x19, 0x54, 0xe8, 0x33, 0xa4, 0xfa, 0x79, 0x90, 0xd1,
		0x6b, 0x33, 0xe4, 0x66, 0xa1, 0xcb, 0x80, 0x2e, 0x03, 0xba, 0x0c, 0xe8, 0x32, 0xa0, 0xcb, 0x80,
		0x2e, 0x43, 0x65, 0xba, 0x0c, 0xe7, 0x71, 0x1c, 0x0a, 0x3f, 0xa2, 0xd8, 0x61, 0xd8, 0x00, 0x71,
		0x23, 0x43, 0xdc, 0x86, 0x03, 0xbd, 0x1f, 0xff, 0x8c, 0xe8, 0x51, 0xb7, 0xa9, 0x61, 0x20, 0x6f,
		0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f, 0x20, 0x6f,
		0x77, 0x9f, 0xc9, 0x2f, 0x9a, 0x5d, 0xb7, 0x5f, 0xe8, 0xba, 0x81, 0xb8, 0x81, 0xb8, 0x81, 0xb8,
		0x81, 0xb8, 0x81, 0xb8, 0x81, 0xb8, 0x81, 0xb8, 0xd1, 0x22, 0x6e, 0x95, 0x3e, 0xbd, 0x40, 0xf2,
		0xd5, 0x50, 0x33, 0xf6, 0x90, 0xbd, 0x5a, 0xe7, 0xfe, 0xbd, 0x26, 0xb5, 0xe9, 0x49, 0xf7, 0x93,
		0x37, 0x32, 0xee, 0x8c, 0xa2, 0x03, 0x63, 0xa9, 0x87, 0x42, 0x0d, 0xcf, 0x47, 0x1f, 0x13, 0xa1,
		0x63, 0xa1, 0x26, 0x06, 0xe1, 0x60, 0x28, 0x1c, 0x0c, 0xc5, 0xa6, 0x9a, 0xc1, 0xc1, 0x50, 0xdc,
		0xab, 0x16, 0x1c, 0x0c, 0x45, 0x8f, 0x5a, 0x91, 0x39, 0x18, 0x2a, 0xcf, 0x49, 0x04, 0xa7, 0xf1,
		0x72, 0xbb, 0x68, 0x35, 0x06, 0x37, 0xd0, 0x18, 0x24, 0x9f, 0x42, 0x09, 0xa7, 0x52, 0xaa, 0x29,
		0x95, 0x7c, 0x6a, 0x25, 0x9f, 0x62, 0x69, 0xa7, 0x5a, 0x3a, 0xfd, 0x94, 0x35, 0x42, 0x8d, 0x41,
		0x2a, 0x29, 0xb8, 0x30, 0xe8, 0x22, 0xf4, 0x2f, 0x53, 0x7a, 0x41, 0x61, 0x1a, 0x47, 0x73, 0xf3,
		0x88, 0xf9, 0x1b, 0xad, 0xc4, 0x4c, 0x36, 0x41, 0x53, 0x4e, 0xd4, 0x0c, 0x12, 0x36, 0xf5, 0xc4,
		0xcd, 0x26, 0x81, 0xb3, 0x49, 0xe4, 0x3c, 0x12, 0x3a, 0xad, 0xc4, 0x4e, 0x2c, 0xc1, 0x93, 0x4d,
		0xf4, 0x77, 0xb5, 0x37, 0x89, 0x5b, 0x0b, 0x9e, 0x2f, 0xc5, 0x09, 0xdc, 0x66, 0xc0, 0x8c, 0x00,
		0x90, 0x27, 0x02, 0x1c, 0x08, 0x01, 0x23, 0x62, 0xc0, 0x85, 0x20, 0xb0, 0x23, 0x0a, 0xec, 0x08,
		0x03, 0x2f, 0xe2, 0x40, 0x93, 0x40, 0x10, 0x25, 0x12, 0xe4, 0x09, 0x05, 0xf1, 0x4e, 0x02, 0xab,
		0xce, 0xc2, 0x3c, 0xa2, 0xb1, 0x4e, 0xdc, 0x4c, 0xea, 0x84, 0x83, 0x13, 0xf1, 0x60, 0x48, 0x40,
		0xb8, 0x11, 0x11, 0xb6, 0x84, 0x84, 0x2d, 0x31, 0xe1, 0x49, 0x50, 0x68, 0x13, 0x15, 0xe2, 0x84,
		0xa5, 0xf8, 0xc8, 0xc9, 0xcd, 0x42, 0x3f, 0x1b, 0x71, 0x45, 0x34, 0xbc, 0x12, 0x49, 0x3e, 0x83,
		0xca, 0x20, 0xea, 0x4e, 0xbb, 0x11, 0x75, 0x06, 0xb6, 0x9a, 0xd1, 0xf0, 0x6a, 0x04, 0x06, 0xb8,
		0xd4, 0x6b, 0x56, 0xd1, 0x0e, 0xd2, 0xcc, 0xc8, 0xb2, 0x84, 0x87, 0x5b, 0x1d, 0x05, 0x91, 0x19,
		0x8a, 0x51, 0xd4, 0x4f, 0xe9, 0x53, 0xc4, 0xb5, 0xc9, 0xf5, 0x0d, 0xf7, 0x2c, 0xde, 0xf8, 0x54,
		0xaf, 0x37, 0xb6, 0xeb, 0xf5, 0xf5, 0xed, 0x8f, 0xdb, 0xeb, 0x3b, 0x5b, 0x5b, 0x1b, 0x0d, 0xaa,
		0x97, 0x12, 0x3c, 0x78, 0x88, 0x76, 0xd2, 0x17, 0x89, 0xe8, 0xef, 0xdd, 0x68, 0xbb, 0x6b, 0xd1,
		0x30, 0x0c, 0xdf, 0x20, 0xc5, 0x2a, 0x16, 0x0b, 0xb4, 0x8c, 0x43, 0x6a, 0x2d, 0xd2, 0xea, 0xd8,
		0x5a, 0x14, 0xdc, 0x28, 0xb8, 0x51, 0x70, 0xa3, 0xe0, 0x46, 0xc1, 0x8d, 0x82, 0x1b, 0x05, 0x37,
		0x0a, 0xee, 0xfc, 0xc2, 0x81, 0xbe, 0x88, 0xb2, 0x20, 0xbb, 0x49, 0xc4, 0x05, 0xa7, 0x82, 0x9b,
		0x43, 0x15, 0x60, 0x4d, 0x96, 0x76, 0xcf, 0x4f, 0x19, 0xe5, 0x89, 0x29, 0x30, 0xac, 0xae, 0xd5,
		0xf5, 0xba, 0xc7, 0x7b, 0xae, 0x7d, 0xe2, 0xb9, 0xdf, 0x3a, 0x26, 0x97, 0x74, 0x31, 0xbe, 0xc3,
		0x2e, 0x25, 0x77, 0x7c, 0xfd, 0xef, 0x5e, 0x7f, 0xb3, 0xb1, 0xf4, 0x21, 0x42, 0x3a, 0x9e, 0x63,
		0x1a, 0xfb, 0x9f, 0x8d, 0x3d, 0xcb, 0xb6, 0xdc, 0x6f, 0x13, 0xb0, 0x74, 0x39, 0xa1, 0x85, 0x33,
		0x6a, 0x78, 0xa2, 0xe7, 0x59, 0x14, 0x75, 0x1c, 0xf3, 0xc0, 0xfa, 0xea, 0x1d, 0xd8, 0xc6, 0x61,
		0x57, 0x63, 0xf7, 0x68, 0xb7, 0xef, 0x81, 0x1f, 0xb9, 0xf8, 0xb1, 0x3a, 0x27, 0x75, 0xcf, 0x69,
		0x1f, 0xbb, 0xa6, 0xe3, 0x59, 0x4d, 0x20, 0x08, 0x08, 0x7a, 0x29, 0x82, 0x5c, 0xe3, 0x10, 0xb0,
		0x01, 0x6c, 0x16, 0x80, 0x4d, 0xa3, 0x0e, 0xe0, 0x00, 0x38, 0x0b, 0x64, 0xac, 0x06, 0x32, 0x16,
		0x10, 0xf4, 0x6a, 0xce, 0xdc, 0x65, 0x89, 0x1e, 0x56, 0x16, 0x9f, 0xbd, 0x81, 0x57, 0xa2, 0xff,
		0xa1, 0x52, 0xe5, 0x0a, 0x9c, 0xa0, 0x42, 0x05, 0x52, 0x50, 0x89, 0x02, 0x1e, 0xa8, 0x38, 0x01,
		0x10, 0xe5, 0x32, 0x4d, 0x03, 0x99, 0x06, 0x48, 0x51, 0xb3, 0x82, 0x04, 0x4a, 0x56, 0x8d, 0x92,
		0x49, 0xe8, 0xd8, 0x37, 0x3a, 0xd8, 0xe3, 0x05, 0x7e, 0x96, 0x8a, 0x23, 0xc7, 0x33, 0xec, 0xc3,
		0xb6, 0x63, 0xb9, 0x9f, 0x8f, 0xd0, 0xf1, 0x04, 0x82, 0x16, 0x42, 0xd0, 0xdd, 0x9f, 0xd0, 0xf6,
		0x5c, 0xed, 0x0b, 0x6d, 0x4f, 0x90, 0x02, 0xd5, 0x82, 0x39, 0x90, 0x82, 0xa0, 0x0d, 0xa8, 0x50,
		0xa9, 0x47, 0xbb, 0x98, 0x25, 0x05, 0x7a, 0x96, 0x8d, 0x22, 0xdb, 0x6a, 0x7d, 0xc1, 0x48, 0x05,
		0xa0, 0xb3, 0x00, 0x74, 0x8e, 0x5b, 0xfb, 0xed, 0x56, 0xd7, 0x75, 0x0c, 0xab, 0x65, 0x36, 0x3d,
		0xbb, 0xdb, 0x01, 0x88, 0x00, 0xa2, 0x85, 0xe2, 0x8f, 0xe1, 0xba, 0x8e, 0xb5, 0x77, 0xec, 0x9a,
		0x18, 0x67, 0x07, 0x84, 0x5e, 0x0c, 0xa1, 0xf1, 0x16, 0x4e, 0xcb, 0xb4, 0x0e, 0x3f, 0xef, 0xb5,
		0x1d, 0xcf, 0x68, 0x36, 0x1d, 0xb3, 0x0b, 0x20, 0x01, 0x48, 0x8b, 0x00, 0xa9, 0xee, 0x59, 0x2d,
		0xd7, 0x74, 0x0e, 0x8c, 0x7d, 0x13, 0x48, 0x02, 0x92, 0x16, 0xa6, 0x46, 0xae, 0x65, 0x5b, 0xff,
		0x35, 0x9b, 0xde, 0x9e, 0xd1, 0x6a, 0xfe, 0xc7, 0x6a, 0xba, 0x9f, 0x81, 0x22, 0xa0, 0x68, 0x21,
		0x6e, 0xd4, 0x71, 0xda, 0xae, 0xb9, 0xef, 0x5a, 0xed, 0x56, 0x5e, 0xe9, 0x03, 0x47, 0xc0, 0xd1,
		0x0b, 0x71, 0xe4, 0x98, 0x5d, 0xab, 0x79, 0x6c, 0xd8, 0x88, 0x46, 0x40, 0xd1, 0xe2, 0x28, 0x3a,
		0x32, 0xbe, 0xe6, 0x11, 0x09, 0x28, 0x02, 0x8a, 0x5e, 0x57, 0xac, 0x81, 0x63, 0x03, 0x49, 0x4b,
		0x89, 0x47, 0x8e, 0xd9, 0x35, 0x9d, 0x13, 0x63, 0xcf, 0x36, 0x11, 0x95, 0x80, 0xa5, 0x57, 0x32,
		0x6d, 0xbb, 0x8d, 0x40, 0x04, 0xf0, 0x2c, 0x08, 0x9e, 0xa6, 0x69, 0x1b, 0xdf, 0xbc, 0x13, 0xc3,
		0xb1, 0x8c, 0x51, 0xad, 0x06, 0x1c, 0x01, 0x47, 0x2f, 0xc5, 0x91, 0xd1, 0xfc, 0xb7, 0x67, 0x1b,
		0x2d, 0xa6, 0x1a, 0x65, 0xc0, 0x47, 0x36, 0x7c, 0x4e, 0x0c, 0xcb, 0x06, 0x15, 0x02, 0x8c, 0x5e,
		0x1f, 0x85, 0x10, 0x81, 0x00, 0x9d, 0x45, 0x2a, 0x32, 0xab, 0x75, 0xd7, 0x25, 0x1a, 0x13, 0x22,
		0xa0, 0x08, 0x28, 0x7a, 0x29, 0x8a, 0x8e, 0x5b, 0x79, 0x55, 0x8f, 0xdd, 0x33, 0xe0, 0xe8, 0x35,
		0x38, 0x2a, 0xc0, 0xe3, 0x15, 0x63, 0x6a, 0x2e, 0xea, 0x7b, 0x00, 0xe9, 0xc5, 0x40, 0x32, 0xbf,
		0xba, 0x66, 0xab, 0x69, 0x36, 0x3d, 0xa3, 0x39, 0xca, 0x70, 0x87, 0x4e, 0xfb, 0x18, 0xa3, 0x8e,
		0xc0, 0xd1, 0x02, 0xcc, 0x1a, 0xf0, 0x01, 0x7c, 0x16, 0x86, 0xcf, 0x78, 0x3a, 0x0d, 0x63, 0x8e,
		0x00, 0xd2, 0x6b, 0x81, 0x84, 0xf2, 0x0c, 0xe8, 0x59, 0x1c, 0x3d, 0xae, 0xe9, 0x35, 0xcd, 0x03,
		0xe3, 0xd8, 0x76, 0xbd, 0x23, 0xd3, 0x75, 0xac, 0x7d, 0x08, 0xcb, 0x57, 0xfb, 0x82, 0xb0, 0xbc,
		0xf2, 0x4e, 0xa9, 0x8e, 0x7a, 0x0f, 0x10, 0x29, 0x1b, 0x22, 0x8c, 0x55, 0x7a, 0x00, 0x8b, 0x94,
		0x78, 0xc2, 0x51, 0x8d, 0x07, 0xa8, 0x48, 0x28, 0x47, 0x39, 0xab, 0xee, 0x00, 0x18, 0x29, 0xfd,
		0x0b, 0xc6, 0x93, 0xbf, 0x40, 0x4c, 0xe9, 0xd4, 0x85, 0xb1, 0x8a, 0x0e, 0x68, 0x91, 0xc2, 0x5d,
		0xd8, 0xaa, 0xe5, 0x80, 0x97, 0xb2, 0xf1, 0xc2, 0x59, 0x15, 0x07, 0xb4, 0x94, 0x8d, 0x16, 0xce,
		0xea, 0x37, 0xa0, 0x45, 0x4a, 0x71, 0x04, 0xae, 0x0b, 0xc4, 0xbc, 0x28, 0xbe, 0xf0, 0x56, 0xb3,
		0x01, 0x33, 0x52, 0x18, 0x2f, 0x2f, 0xd5, 0x1a, 0x40, 0x22, 0x05, 0x24, 0x6c, 0xd5, 0x69, 0xc0,
		0x4b, 0xd9, 0x78, 0x61, 0xa9, 0x42, 0x03, 0x4c, 0x4a, 0x87, 0x09, 0x67, 0xb5, 0x19, 0xe0, 0x22,
		0x23, 0xaa, 0x20, 0xa2, 0x00, 0x22, 0x8a, 0xaa, 0xc7, 0x80, 0x96, 0xb2, 0xd1, 0xc2, 0x5b, 0x25,
		0x06, 0xbc, 0x94, 0x8d, 0x17, 0xe6, 0x6a, 0x30, 0x00, 0xa6, 0x6c, 0xc0, 0xf0, 0x56, 0x7d, 0x01,
		0x2f, 0xe5, 0x33, 0x5c, 0xc0, 0x04, 0x30, 0x79, 0x16, 0x26, 0xcc, 0x55, 0x5c, 0x00, 0x4c, 0xd9,
		0x80, 0x41, 0x39, 0x04, 0x94, 0x3c, 0x8f, 0x12, 0xc6, 0xaa, 0x2c, 0x1e, 0x6a, 0x2c, 0xfa, 0x2a,
		0x2c, 0xda, 0xeb, 0x48, 0xd7, 0x3a, 0x9a, 0x96, 0x11, 0x0d, 0xa1, 0x9a, 0x11, 0x45, 0x71, 0xe6,
		0x67, 0x41, 0x1c, 0x69, 0xbb, 0x84, 0x83, 0xa7, 0x96, 0xf6, 0xbe, 0x8b, 0x2b, 0x7f, 0xe0, 0x67,
		0xdf, 0x47, 0xe1, 0xb2, 0x16, 0x0f, 0x44, 0xd4, 0x8b, 0xa3, 0x8b, 0xe0, 0x52, 0x8f, 0x44, 0xf6,
		0x33, 0x4e, 0x7e, 0xe8, 0x41, 0x94, 0x66, 0x7e, 0xd4, 0x13, 0xb5, 0xc7, 0xdf, 0x48, 0x67, 0xbe,
		0x53, 0x1b, 0x24, 0x71, 0x16, 0xf7, 0xe2, 0x30, 0x2d, 0xde, 0xd5, 0x82, 0x34, 0x48, 0x6b, 0xa1,
		0xb8, 0x16, 0xe1, 0xe4, 0x4b, 0x2d, 0x0c, 0xa2, 0x1f, 0x7a, 0x9a, 0xf9, 0x99, 0xd0, 0xfb, 0x7e,
		0xe6, 0x9f, 0xfb, 0xa9, 0xa8, 0x85, 0xe9, 0xa0, 0x96, 0x85, 0xd7, 0xe9, 0xe8, 0x3f, 0xb5, 0x60,
		0x70, 0xdd, 0xd0, 0x13, 0xe1, 0xf7, 0xbe, 0xfb, 0xe7, 0x41, 0x18, 0x64, 0x37, 0xb5, 0x41, 0x22,
		0x2e, 0x82, 0x5f, 0x22, 0x9d, 0xbc, 0xa9, 0xa5, 0xc3, 0xf3, 0xf1, 0xdf, 0xce, 0xbf, 0xd6, 0x2e,
		0x42, 0xff, 0x32, 0xad, 0x8d, 0xff, 0x49, 0x9a, 0xf1, 0x9c, 0x9e, 0xef, 0xd0, 0xb2, 0x88, 0x98,
		0x17, 0x53, 0xf7, 0x5e, 0x85, 0xbc, 0x96, 0xe0, 0x8d, 0xac, 0x5a, 0x9a, 0x25, 0xc3, 0x5e, 0x16,
		0x4d, 0x28, 0x64, 0x2b, 0x5f, 0x2e, 0x6b, 0xb2, 0x5a, 0x5e, 0x67, 0xb2, 0x46, 0x9e, 0x95, 0x06,
		0xa9, 0x67, 0x8f, 0x16, 0xc7, 0xb3, 0xd3, 0x81, 0xe7, 0x86, 0xd7, 0x9e, 0x35, 0xb8, 0x6e, 0x38,
		0xf7, 0x96, 0xc0, 0xeb, 0x8c, 0x9f, 0xdc, 0xeb, 0x8e, 0x9f, 0xd8, 0x3b, 0x18, 0x3f, 0xf1, 0x1b,
		0xc4, 0x01, 0xe2, 0x31, 0x40, 0x0b, 0x06, 0xd7, 0x75, 0x3d, 0x8d, 0x87, 0x49, 0x4f, 0xe8, 0x49,
		0x3c, 0xcc, 0x44, 0xa2, 0x07, 0x7d, 0x72, 0xa1, 0xa0, 0xa8, 0x72, 0x9e, 0x36, 0x97, 0x58, 0x4c,
		0xfd, 0x12, 0x44, 0xa3, 0x25, 0xdc, 0x20, 0x66, 0xd6, 0xfe, 0x38, 0x6e, 0x6a, 0xbb, 0x6b, 0xeb,
		0xc4, 0x0c, 0xcb, 0x43, 0x07, 0xcd, 0xfc, 0x33, 0x05, 0x5e, 0xdc, 0xd3, 0x47, 0x99, 0x82, 0x62,
		0x10, 0xef, 0x8e, 0xdd, 0x81, 0x2c, 0xf9, 0xd6, 0xbe, 0x88, 0x9b, 0x9f, 0x71, 0x32, 0xf2, 0x08,
		0x2d, 0x4f, 0x8f, 0x44, 0xef, 0x26, 0xd7, 0x3e, 0xfb, 0xa9, 0x91, 0x5c, 0x0e, 0xaf, 0x44, 0x94,
		0x69, 0xbb, 0x6b, 0x59, 0x32, 0x14, 0x54, 0x4b, 0xae, 0x3b, 0x2b, 0x0b, 0x60, 0x82, 0x77, 0xb3,
		0xe2, 0xdd, 0xcd, 0x20, 0x21, 0x4a, 0xb8, 0xc7, 0xb5, 0x25, 0xd9, 0x60, 0x32, 0x8d, 0xc7, 0xb9,
		0x99, 0x44, 0xfd, 0x93, 0x26, 0x01, 0x20, 0x4f, 0x04, 0x38, 0x10, 0x02, 0x46, 0xc4, 0x80, 0x0b,
		0x41, 0x60, 0x47, 0x14, 0xd8, 0x11, 0x06, 0x5e, 0xc4, 0x81, 0x26, 0x81, 0x20, 0x4a, 0x24, 0xc8,
		0x13, 0x8a, 0xc2, 0x40, 0xba, 0xdd, 0x85, 0xb9, 0xb1, 0x9d, 0x6a, 0x87, 0x61, 0x1e, 0xe1, 0x58,
		0x27, 0x6e, 0x26, 0x75, 0xe2, 0xc1, 0x89, 0x80, 0x30, 0x24, 0x22, 0xdc, 0x08, 0x09, 0x5b, 0x62,
		0xc2, 0x96, 0xa0, 0xf0, 0x24, 0x2a, 0xb4, 0x09, 0x0b, 0x71, 0xe2, 0x52, 0x7c, 0xe4, 0xee, 0xcd,
		0x40, 0xf0, 0x8a, 0xb8, 0xe3, 0xcd, 0x08, 0xbf, 0xdf, 0x4f, 0x44, 0xca, 0x22, 0xec, 0x4e, 0xdb,
		0x12, 0x9f, 0x18, 0xd8, 0xda, 0xf1, 0xb3, 0x4c, 0x24, 0x91, 0xb6, 0xbb, 0x76, 0xca, 0x23, 0x62,
		0xfd, 0xef, 0xed, 0xdb, 0xd3, 0x75, 0x7d, 0xe7, 0xec, 0x9f, 0xd3, 0x0d, 0x7d, 0xe7, 0x2c, 0x7f,
		0xbb, 0x31, 0xfe, 0x92, 0xbf, 0xdf, 0x3c, 0x5d, 0xd7, 0xeb, 0xd3, 0xf7, 0x5b, 0xa7, 0xeb, 0xfa,
		0xd6, 0xd9, 0xbb, 0xbf, 0xfe, 0xfa, 0xf0, 0xee, 0xef, 0x8f, 0xb7, 0x2f, 0xff, 0xc1, 0x7f, 0xd1,
		0x0f, 0x86, 0x67, 0x1c, 0x40, 0xd6, 0xee, 0x5a, 0x5f, 0x81, 0x34, 0xee, 0x48, 0xc3, 0x98, 0xa3,
		0x6a, 0x84, 0x40, 0xcb, 0x38, 0x90, 0x81, 0x82, 0x08, 0x8c, 0xad, 0x45, 0x8b, 0x00, 0x2d, 0x02,
		0xb4, 0x08, 0xd0, 0x22, 0x40, 0x8b, 0x00, 0x2d, 0x02, 0xb4, 0x08, 0xd0, 0x22, 0xc8, 0x5b, 0x04,
		0x7d, 0x11, 0x65, 0x41, 0x76, 0x93, 0x88, 0x0b, 0x4e, 0x1d, 0x82, 0x2d, 0x06, 0xb6, 0x5a, 0x93,
		0xa5, 0xdd, 0xf3, 0x53, 0x46, 0x79, 0xe2, 0x4e, 0xae, 0x67, 0x75, 0xbd, 0xee, 0xf1, 0x9e, 0x6b,
		0x9f, 0xe4, 0xe7, 0x92, 0x33, 0x89, 0xba, 0x27, 0x7e, 0x38, 0x14, 0x29, 0x9b, 0x62, 0x79, 0x8d,
		0xb1, 0xa0, 0xb3, 0xf3, 0x50, 0xd0, 0x99, 0x83, 0xa5, 0xcb, 0x09, 0x2d, 0x9c, 0x51, 0xc3, 0x13,
		0x3d, 0xcf, 0xa2, 0xa8, 0xe3, 0x98, 0x07, 0xd6, 0x57, 0xef, 0xc0, 0x36, 0x0e, 0x71, 0x55, 0x2c,
		0xf0, 0xf3, 0x62, 0xfc, 0x8c, 0x4f, 0xab, 0x70, 0xda, 0xc7, 0xae, 0xe9, 0xb0, 0xba, 0x66, 0x10,
		0x08, 0xa2, 0x82, 0x20, 0xd7, 0x38, 0x04, 0x6c, 0x00, 0x9b, 0x05, 0x60, 0xd3, 0xa8, 0x03, 0x38,
		0x00, 0xce, 0x02, 0x19, 0xab, 0x81, 0x8c, 0x05, 0x04, 0xbd, 0x9a, 0x33, 0x77, 0x59, 0xa2, 0x07,
		0x37, 0x9b, 0x57, 0xdd, 0x2b, 0x15, 0xe9, 0x7f, 0xf0, 0xac, 0x5c, 0x81, 0x13, 0x54, 0xa8, 0x40,
		0x0a, 0x2a, 0x51, 0xc0, 0x03, 0x15, 0x27, 0x00, 0xa2, 0x5c, 0xa6, 0x69, 0x20, 0xd3, 0x00, 0x29,
		0x6a, 0x56, 0x90, 0x40, 0xc9, 0xaa, 0x51, 0x32, 0x09, 0x1d, 0xfb, 0x46, 0x07, 0x7b, 0xbc, 0xc0,
		0xcf, 0x52, 0x71, 0xe4, 0x78, 0x86, 0x7d, 0xd8, 0x76, 0x2c, 0xf7, 0xf3, 0x11, 0x3a, 0x9e, 0x40,
		0xd0, 0x42, 0x08, 0xba, 0xfb, 0x13, 0xda, 0x9e, 0xab, 0x7d, 0xa1, 0xed, 0x09, 0x52, 0xa0, 0x5a,
		0x30, 0xff, 0xff, 0xec, 0x7d, 0x51, 0x53, 0xdb, 0xc8, 0xf2, 0xfd, 0xfb, 0x7e, 0x0a, 0x4a, 0x75,
		0x1f, 0x76, 0xab, 0xd6, 0x31, 0x10, 0x63, 0x02, 0x6f, 0x02, 0x0b, 0xa2, 0x1b, 0x61, 0xbb, 0x64,
		0xc1, 0x4d, 0x6e, 0x96, 0xab, 0x12, 0xf6, 0x40, 0xf4, 0x8f, 0x90, 0x5d, 0x92, 0x4c, 0xc2, 0x6f,
		0x97, 0xef, 0xfe, 0x2f, 0x5b, 0x46, 0x90, 0x10, 0x87, 0x00, 0xb6, 0xd4, 0x67, 0x7c, 0xfc, 0xb0,
		0x10, 0x6f, 0x08, 0xad, 0xf1, 0xe9, 0xee, 0xd3, 0x3d, 0x7d, 0x66, 0x88, 0x14, 0x06, 0x6d, 0x42,
		0x45, 0x4a, 0x3d, 0xda, 0xe3, 0x2c, 0x29, 0xd1, 0xb3, 0x68, 0x14, 0x4d, 0x2f, 0x22, 0xe2, 0x48,
		0x05, 0xa1, 0xf3, 0x74, 0xe8, 0x1c, 0xb7, 0x8b, 0x4b, 0x37, 0xad, 0x96, 0xef, 0xf4, 0xba, 0x04,
		0x11, 0x41, 0xf4, 0xac, 0xf8, 0x63, 0x7a, 0x9e, 0x6b, 0xef, 0x1d, 0x7b, 0x16, 0xc7, 0xd9, 0x09,
		0xa1, 0x27, 0x43, 0x68, 0xba, 0x85, 0x83, 0x7b, 0xf9, 0x22, 0x81, 0x24, 0x08, 0x48, 0x0d, 0xdf,
		0x6e, 0x7b, 0x96, 0x7b, 0x60, 0xee, 0x5b, 0x44, 0x12, 0x91, 0xf4, 0x6c, 0x6a, 0xe4, 0xd9, 0x8e,
		0xfd, 0x5f, 0xcc, 0x5b, 0xec, 0x89, 0x22, 0x51, 0xdc, 0xa8, 0xeb, 0x76, 0x3c, 0x6b, 0xdf, 0xb3,
		0x3b, 0xed, 0xbc, 0xd2, 0x27, 0x8e, 0x88, 0xa3, 0x27, 0xe2, 0xc8, 0xb5, 0x7a, 0x76, 0xeb, 0xd8,
		0x74, 0x18, 0x8d, 0x88, 0xa2, 0xe7, 0xa3, 0xe8, 0xc8, 0x7c, 0x9f, 0x47, 0x24, 0xa2, 0x88, 0x28,
		0x7a, 0x59, 0xb1, 0x46, 0x8e, 0x4d, 0x24, 0x2d, 0x24, 0x1e, 0xb9, 0x56, 0xcf, 0x72, 0x4f, 0xcc,
		0x3d, 0xc7, 0x62, 0x54, 0x22, 0x96, 0x5e, 0xc8, 0xb4, 0x9d, 0x0e, 0x03, 0x11, 0xc1, 0xf3, 0x4c,
		0xf0, 0xb4, 0x2c, 0xc7, 0xfc, 0xe0, 0x9f, 0x98, 0xae, 0x6d, 0x4e, 0x6a, 0x35, 0xe2, 0x88, 0x38,
		0x7a, 0x2a, 0x8e, 0xcc, 0xd6, 0xbf, 0x7d, 0xc7, 0x6c, 0x83, 0x6a, 0x94, 0x09, 0x9f, 0xaa, 0xe1,
		0x73, 0x62, 0xda, 0x0e, 0xa9, 0x10, 0x61, 0xf4, 0xf2, 0x28, 0xc4, 0x08, 0x44, 0xe8, 0x3c, 0xa7,
		0x22, 0xb3, 0xdb, 0x77, 0x5d, 0xa2, 0x29, 0x21, 0x22, 0x8a, 0x88, 0xa2, 0xa7, 0xa2, 0xe8, 0xb8,
		0x9d, 0x57, 0xf5, 0xdc, 0x3d, 0x23, 0x8e, 0x5e, 0x82, 0xa3, 0x02, 0x3c, 0x7e, 0x31, 0xa6, 0xe6,
		0xb1, 0xbe, 0x27, 0x90, 0x9e, 0x0c, 0x24, 0xeb, 0xbd, 0x67, 0xb5, 0x5b, 0x56, 0xcb, 0x37, 0x5b,
		0x93, 0x0c, 0x77, 0xe8, 0x76, 0x8e, 0x39, 0xea, 0x48, 0x1c, 0x3d, 0x83, 0x59, 0x13, 0x3e, 0x84,
		0xcf, 0xb3, 0xe1, 0x33, 0x9d, 0x4e, 0xe3, 0x98, 0x23, 0x81, 0xf4, 0x52, 0x20, 0xb1, 0x3c, 0x23,
		0x7a, 0x9e, 0x8f, 0x1e, 0xcf, 0xf2, 0x5b, 0xd6, 0x81, 0x79, 0xec, 0x78, 0xfe, 0x91, 0xe5, 0xb9,
		0xf6, 0x3e, 0x85, 0xe5, 0xcb, 0x7d, 0x51, 0x58, 0xbe, 0xf2, 0x4e, 0xa9, 0x8f, 0x7a, 0x8f, 0x10,
		0x29, 0x1b, 0x22, 0xc0, 0x2a, 0x3d, 0x82, 0xa5, 0x92, 0x78, 0x82, 0xa8, 0xc6, 0x23, 0x54, 0x2a,
		0x28, 0x47, 0x91, 0x55, 0x77, 0x04, 0x4c, 0x25, 0xfd, 0x0b, 0xe0, 0xc9, 0x5f, 0x22, 0xa6, 0x74,
		0xea, 0x02, 0xac, 0xa2, 0x23, 0x5a, 0x2a, 0xe1, 0x2e, 0xb0, 0x6a, 0x39, 0xe2, 0xa5, 0x6c, 0xbc,
		0x20, 0xab, 0xe2, 0x88, 0x96, 0xb2, 0xd1, 0x82, 0xac, 0x7e, 0x23, 0x5a, 0x2a, 0x29, 0x8e, 0xc8,
		0x75, 0x89, 0x98, 0x27, 0xc5, 0x17, 0x6c, 0x35, 0x1b, 0x31, 0x53, 0x09, 0xe3, 0xc5, 0x52, 0xad,
		0x11, 0x24, 0x95, 0x80, 0x04, 0x56, 0x9d, 0x46, 0xbc, 0x94, 0x8d, 0x17, 0x48, 0x15, 0x1a, 0x61,
		0x52, 0x3a, 0x4c, 0x90, 0xd5, 0x66, 0x84, 0x4b, 0x15, 0x51, 0x85, 0x11, 0x85, 0x10, 0xd1, 0x54,
		0x3d, 0x46, 0xb4, 0x94, 0x8d, 0x16, 0x6c, 0x95, 0x18, 0xf1, 0x52, 0x36, 0x5e, 0xc0, 0xd5, 0x60,
		0x04, 0x4c, 0xd9, 0x80, 0xc1, 0x56, 0x7d, 0x11, 0x2f, 0xe5, 0x33, 0x5c, 0xc2, 0x84, 0x30, 0x79,
		0x14, 0x26, 0xe0, 0x2a, 0x2e, 0x02, 0xa6, 0x6c, 0xc0, 0xb0, 0x1c, 0x22, 0x4a, 0x1e, 0x47, 0x09,
		0xb0, 0x2a, 0x0b, 0x43, 0x8d, 0x25, 0x5f, 0x85, 0x25, 0x7b, 0x1d, 0xe5, 0x5a, 0x27, 0xd3, 0x32,
		0xa1, 0x21, 0xd4, 0x30, 0xe3, 0x78, 0x98, 0x05, 0x59, 0x38, 0x8c, 0x8d, 0x5d, 0xc1, 0xc1, 0xd3,
		0x48, 0xfb, 0x9f, 0xd4, 0x65, 0x30, 0x0a, 0xb2, 0x4f, 0x93, 0x70, 0x59, 0x1f, 0x8e, 0x54, 0xdc,
		0x1f, 0xc6, 0xe7, 0xe1, 0x45, 0x2d, 0x56, 0xd9, 0x97, 0x61, 0xf2, 0xb9, 0x16, 0xc6, 0x69, 0x16,
		0xc4, 0x7d, 0x55, 0xff, 0xfe, 0x8d, 0xf4, 0xc1, 0x3b, 0xf5, 0x51, 0x32, 0xcc, 0x86, 0xfd, 0x61,
		0x94, 0x16, 0xdf, 0xd5, 0xc3, 0x34, 0x4c, 0xeb, 0x91, 0xba, 0x52, 0xd1, 0xec, 0x4b, 0x3d, 0x0a,
		0xe3, 0xcf, 0xb5, 0x34, 0x0b, 0x32, 0x55, 0x1b, 0x04, 0x59, 0x70, 0x16, 0xa4, 0xaa, 0x1e, 0xa5,
		0xa3, 0x7a, 0x16, 0x5d, 0xa5, 0x93, 0xff, 0xd4, 0xc3, 0xd1, 0x55, 0xb3, 0x96, 0xa8, 0xa0, 0xff,
		0x29, 0x38, 0x0b, 0xa3, 0x30, 0xbb, 0xae, 0x8f, 0x12, 0x75, 0x1e, 0x7e, 0x55, 0xe9, 0xec, 0x9b,
		0x7a, 0x3a, 0x3e, 0x9b, 0xfe, 0xed, 0xfc, 0xeb, 0xe4, 0x07, 0x1a, 0xb5, 0x74, 0x38, 0x4e, 0xfa,
		0xaa, 0x96, 0x0c, 0xc7, 0x99, 0x4a, 0x6a, 0xe1, 0xa0, 0x3e, 0xfd, 0x15, 0x32, 0xe3, 0xbb, 0x3c,
		0x5f, 0x92, 0x65, 0x91, 0x30, 0xaf, 0x96, 0xee, 0xcd, 0x1a, 0x7b, 0xb1, 0xc0, 0x1b, 0x5b, 0x8d,
		0x34, 0x4b, 0xc6, 0xfd, 0x2c, 0x9e, 0x51, 0xcc, 0x76, 0xbe, 0x7c, 0xf6, 0x6c, 0xf5, 0xfc, 0xee,
		0x6c, 0xcd, 0x7c, 0x3b, 0x0d, 0x53, 0xdf, 0x99, 0x2c, 0x96, 0xef, 0xa4, 0x23, 0xdf, 0x8b, 0xae,
		0x7c, 0x7b, 0x74, 0xd5, 0x74, 0xef, 0x2d, 0x89, 0xdf, 0x9d, 0xae, 0x84, 0xdf, 0x9b, 0xae, 0xc0,
		0xe4, 0x7f, 0x37, 0x7a, 0xd3, 0x05, 0x70, 0xa7, 0xcf, 0x6f, 0x0f, 0x64, 0x85, 0x2f, 0x39, 0x41,
		0x42, 0x50, 0x80, 0x30, 0xa6, 0x40, 0x7f, 0x80, 0x5b, 0x69, 0x71, 0xa2, 0x28, 0x89, 0x7e, 0x6c,
		0xae, 0xb0, 0x80, 0xfb, 0x2e, 0x8c, 0x27, 0x4b, 0xb8, 0x21, 0xcc, 0xac, 0xfd, 0x69, 0x50, 0x35,
		0x76, 0xd7, 0xd6, 0x85, 0x19, 0x96, 0xc7, 0x11, 0x99, 0xc9, 0xe9, 0x16, 0x78, 0xc3, 0x7e, 0x6d,
		0x92, 0x46, 0x24, 0x46, 0xf4, 0x3c, 0xe8, 0x8a, 0x65, 0xea, 0xc6, 0x3b, 0x75, 0xfd, 0x65, 0x98,
		0x4c, 0x3c, 0xc2, 0xc8, 0x73, 0xa7, 0xd0, 0x8b, 0xcc, 0x8d, 0xb7, 0x41, 0x6a, 0x26, 0x17, 0xe3,
		0x4b, 0x15, 0x67, 0xc6, 0xee, 0x5a, 0x96, 0x8c, 0x95, 0xd4, 0xfa, 0xec, 0xce, 0xca, 0x02, 0x98,
		0x24, 0xe5, 0x50, 0xa4, 0xbc, 0x15, 0x26, 0x42, 0xd9, 0xf8, 0xb4, 0xf0, 0x14, 0x1b, 0x4c, 0x6e,
		0xe3, 0x71, 0x6e, 0xa6, 0x50, 0xff, 0x94, 0x49, 0x00, 0xc4, 0x13, 0x01, 0x04, 0x42, 0x00, 0x44,
		0x0c, 0x50, 0x08, 0x02, 0x1c, 0x51, 0x80, 0x23, 0x0c, 0x58, 0xc4, 0x41, 0x26, 0x81, 0x10, 0x4a,
		0x24, 0xc4, 0x13, 0x8a, 0xc2, 0x40, 0xb9, 0xdd, 0x85, 0xb9, 0xb1, 0x5d, 0x72, 0x23, 0xef, 0x47,
		0x84, 0x63, 0x5d, 0xb8, 0x99, 0xd2, 0x89, 0x07, 0x12, 0x01, 0x01, 0x24, 0x22, 0x68, 0x84, 0x04,
		0x96, 0x98, 0xc0, 0x12, 0x14, 0x4c, 0xa2, 0x22, 0x9b, 0xb0, 0x08, 0x27, 0x2e, 0xc5, 0x47, 0xee,
		0x5d, 0x8f, 0x14, 0x56, 0xc4, 0x9d, 0x6e, 0x46, 0x04, 0x83, 0x41, 0xa2, 0x52, 0x88, 0xb0, 0x7b,
		0xdb, 0x96, 0x78, 0x03, 0x60, 0x6b, 0x37, 0xc8, 0x32, 0x95, 0xc4, 0xc6, 0xee, 0xda, 0x47, 0x8c,
		0x88, 0xf5, 0xbf, 0xdf, 0x7f, 0xff, 0xb8, 0x5e, 0xdb, 0x09, 0x6a, 0xe7, 0x66, 0xed, 0xe0, 0xf4,
		0xef, 0x8d, 0x3f, 0x1b, 0x37, 0xbb, 0x7f, 0xfc, 0xbd, 0x7d, 0xf3, 0xfd, 0x9b, 0xff, 0xfc, 0xe8,
		0xaf, 0x6d, 0xfc, 0xb9, 0x7d, 0xb3, 0x3b, 0xe7, 0xff, 0x34, 0x6f, 0x76, 0x7f, 0xf1, 0xdf, 0xd8,
		0xba, 0xf9, 0xfd, 0xc1, 0x5f, 0x9d, 0xbc, 0xbf, 0x39, 0xef, 0x07, 0x1a, 0x73, 0x7e, 0xe0, 0xf5,
		0xbc, 0x1f, 0x78, 0x3d, 0xe7, 0x07, 0xe6, 0x9a, 0xb4, 0x39, 0xe7, 0x07, 0xb6, 0x6e, 0xfe, 0x79,
		0xf0, 0xf7, 0x7f, 0xff, 0xf1, 0x5f, 0x6d, 0xde, 0xfc, 0xf1, 0xcf, 0xbc, 0xff, 0xb7, 0x7d, 0xf3,
		0xcf, 0xee, 0x1f, 0x7f, 0xfc, 0x4b, 0x7e, 0x6a, 0x38, 0x45, 0x70, 0xb9, 0x4e, 0xcf, 0x7e, 0x4f,
		0xbf, 0xa3, 0xdf, 0xe9, 0xe4, 0x77, 0x9c, 0x97, 0xd5, 0x8d, 0x2c, 0x1a, 0x19, 0x02, 0x51, 0x2c,
		0x48, 0xe2, 0xd4, 0x5a, 0xb6, 0x8f, 0xd8, 0x3e, 0x62, 0xfb, 0x88, 0xed, 0x23, 0xb6, 0x8f, 0xd8,
		0x3e, 0x62, 0xfb, 0x88, 0xed, 0xa3, 0xbc, 0x7d, 0x34, 0x50, 0x71, 0x16, 0x66, 0xd7, 0x89, 0x3a,
		0x47, 0xea, 0x1e, 0x6d, 0x01, 0xd8, 0x6a, 0xcf, 0x96, 0x76, 0x2f, 0x48, 0x81, 0xf2, 0xc4, 0x9d,
		0xee, 0xd3, 0xee, 0xf9, 0xbd, 0xe3, 0x3d, 0xcf, 0x39, 0xc9, 0x0f, 0xb8, 0x07, 0x89, 0xba, 0x27,
		0x41, 0x34, 0x56, 0x29, 0x4c, 0xeb, 0x60, 0x0d, 0x58, 0x19, 0xdc, 0xfd, 0x56, 0x19, 0x9c, 0x83,
		0xa5, 0x87, 0x84, 0x16, 0x64, 0xd4, 0x60, 0xa2, 0xe7, 0x51, 0x14, 0x75, 0x5d, 0xeb, 0xc0, 0x7e,
		0xef, 0x1f, 0x38, 0xe6, 0x21, 0xef, 0x1c, 0x26, 0x7e, 0x9e, 0x8c, 0x9f, 0xe9, 0xb1, 0x27, 0x6e,
		0xe7, 0xd8, 0xb3, 0x5c, 0xa8, 0xfb, 0x2a, 0x89, 0x20, 0x29, 0x08, 0xf2, 0xcc, 0x43, 0xc2, 0x86,
		0xb0, 0x79, 0x06, 0x6c, 0x9a, 0x0d, 0x02, 0x87, 0xc0, 0x79, 0x46, 0xc6, 0x6a, 0x32, 0x63, 0x11,
		0x41, 0x2f, 0xe6, 0xcc, 0x3d, 0x48, 0xf4, 0xf0, 0x8a, 0xfc, 0x55, 0xf7, 0x4a, 0x4d, 0xfa, 0x1f,
		0x98, 0x95, 0x2b, 0x71, 0xc2, 0x0a, 0x95, 0x48, 0x61, 0x25, 0x4a, 0x78, 0xb0, 0xe2, 0x24, 0x40,
		0xb4, 0xcb, 0x34, 0x4d, 0x66, 0x1a, 0x22, 0x45, 0xcf, 0x0a, 0x92, 0x28, 0x59, 0x36, 0x4a, 0x66,
		0xa1, 0x63, 0xdf, 0xec, 0x72, 0x8f, 0x97, 0xf8, 0x59, 0x28, 0x8e, 0x5c, 0xdf, 0x74, 0x0e, 0x3b,
		0xae, 0xed, 0xbd, 0x3d, 0x62, 0xc7, 0x93, 0x08, 0x7a, 0x16, 0x82, 0xee, 0xfe, 0xc4, 0xb6, 0xe7,
		0x72, 0x5f, 0x6c, 0x7b, 0x92, 0x14, 0xe8, 0x16, 0xcc, 0x89, 0x14, 0x06, 0x6d, 0x42, 0x45, 0x4a,
		0x3d, 0xda, 0xe3, 0x2c, 0x29, 0xd1, 0xb3, 0x68, 0x14, 0x4d, 0x6f, 0xb4, 0xe2, 0x48, 0x05, 0xa1,
		0xf3, 0x74, 0xe8, 0x1c, 0xb7, 0x8b, 0xdb, 0x5b, 0xad, 0x96, 0xef, 0xf4, 0xba, 0x04, 0x11, 0x41,
		0xf4, 0xac, 0xf8, 0x63, 0x7a, 0x9e, 0x6b, 0xef, 0x1d, 0x7b, 0x16, 0xc7, 0xd9, 0x09, 0xa1, 0x27,
		0x43, 0x68, 0xba, 0x85, 0x83, 0x7b, 0x8b, 0x27, 0x81, 0x24, 0x08, 0x48, 0x0d, 0xdf, 0x6e, 0x7b,
		0x96, 0x7b, 0x60, 0xee, 0x5b, 0x44, 0x12, 0x91, 0xf4, 0x6c, 0x6a, 0xe4, 0xd9, 0x8e, 0xfd, 0x5f,
		0xab, 0x75, 0x77, 0xd3, 0x3d, 0x51, 0x44, 0x14, 0x3d, 0x8b, 0x1b, 0x75, 0xdd, 0x8e, 0x67, 0xed,
		0x7b, 0x76, 0xa7, 0x9d, 0x57, 0xfa, 0xc4, 0x11, 0x71, 0xf4, 0x44, 0x1c, 0xb9, 0x56, 0xcf, 0x6e,
		0x1d, 0x9b, 0x0e, 0xa3, 0x11, 0x51, 0xf4, 0x7c, 0x14, 0x1d, 0x99, 0xef, 0xf3, 0x88, 0x44, 0x14,
		0x11, 0x45, 0x2f, 0x2b, 0xd6, 0xc8, 0xb1, 0x89, 0xa4, 0x85, 0xc4, 0x23, 0xd7, 0xea, 0x59, 0xee,
		0x89, 0xb9, 0xe7, 0x58, 0x8c, 0x4a, 0xc4, 0xd2, 0x0b, 0x99, 0xb6, 0xd3, 0x61, 0x20, 0x22, 0x78,
		0x9e, 0x09, 0x9e, 0x96, 0xe5, 0x98, 0x1f, 0xfc, 0x13, 0xd3, 0xb5, 0xcd, 0x49, 0xad, 0x46, 0x1c,
		0x11, 0x47, 0x4f, 0xc5, 0x91, 0xd9, 0xfa, 0xb7, 0xef, 0x98, 0x6d, 0x50, 0x8d, 0x32, 0xe1, 0x53,
		0x35, 0x7c, 0x4e, 0x4c, 0xdb, 0x21, 0x15, 0x22, 0x8c, 0x5e, 0x1e, 0x85, 0x18, 0x81, 0x08, 0x9d,
		0xe7, 0x54, 0x64, 0x76, 0xfb, 0xae, 0x4b, 0x34, 0x25, 0x44, 0x44, 0x11, 0x51, 0xf4, 0x54, 0x14,
		0x1d, 0xb7, 0xf3, 0xaa, 0x9e, 0xbb, 0x67, 0xc4, 0xd1, 0x4b, 0x70, 0x54, 0x80, 0xc7, 0x2f, 0xc6,
		0xd4, 0x3c, 0xd6, 0xf7, 0x04, 0xd2, 0x93, 0x81, 0x64, 0xbd, 0xf7, 0xac, 0x76, 0xcb, 0x6a, 0xf9,
		0x66, 0x6b, 0x92, 0xe1, 0x0e, 0xdd, 0xce, 0x31, 0x47, 0x1d, 0x89, 0xa3, 0x67, 0x30, 0x6b, 0xc2,
		0x87, 0xf0, 0x79, 0x36, 0x7c, 0xa6, 0xd3, 0x69, 0x1c, 0x73, 0x24, 0x90, 0x5e, 0x0a, 0x24, 0x96,
		0x67, 0x44, 0xcf, 0xf3, 0xd1, 0xe3, 0x59, 0x7e, 0xcb, 0x3a, 0x30, 0x8f, 0x1d, 0xcf, 0x3f, 0xb2,
		0x3c, 0xd7, 0xde, 0xa7, 0xb0, 0x7c, 0xb9, 0x2f, 0x0a, 0xcb, 0x57, 0xde, 0x29, 0xf5, 0x51, 0xef,
		0x11, 0x22, 0x65, 0x43, 0x04, 0x58, 0xa5, 0x47, 0xb0, 0x54, 0x12, 0x4f, 0x10, 0xd5, 0x78, 0x84,
		0x4a, 0x05, 0xe5, 0x28, 0xb2, 0xea, 0x8e, 0x80, 0xa9, 0xa4, 0x7f, 0x01, 0x3c, 0xf9, 0x4b, 0xc4,
		0x94, 0x4e, 0x5d, 0x80, 0x55, 0x74, 0x44, 0x4b, 0x25, 0xdc, 0x05, 0x56, 0x2d, 0x47, 0xbc, 0x94,
		0x8d, 0x17, 0x64, 0x55, 0x1c, 0xd1, 0x52, 0x36, 0x5a, 0x90, 0xd5, 0x6f, 0x44, 0x4b, 0x25, 0xc5,
		0x11, 0xb9, 0x2e, 0x11, 0xf3, 0xa4, 0xf8, 0x82, 0xad, 0x66, 0x23, 0x66, 0x2a, 0x61, 0xbc, 0x58,
		0xaa, 0x35, 0x82, 0xa4, 0x12, 0x90, 0xc0, 0xaa, 0xd3, 0x88, 0x97, 0xb2, 0xf1, 0x02, 0xa9, 0x42,
		0x23, 0x4c, 0x4a, 0x87, 0x09, 0xb2, 0xda, 0x8c, 0x70, 0xa9, 0x22, 0xaa, 0x30, 0xa2, 0x10, 0x22,
		0x9a, 0xaa, 0xc7, 0x88, 0x96, 0xb2, 0xd1, 0x82, 0xad, 0x12, 0x23, 0x5e, 0xca, 0xc6, 0x0b, 0xb8,
		0x1a, 0x8c, 0x80, 0x29, 0x1b, 0x30, 0xd8, 0xaa, 0x2f, 0xe2, 0xa5, 0x7c, 0x86, 0x4b, 0x98, 0x10,
		0x26, 0x8f, 0xc2, 0x04, 0x5c, 0xc5, 0x45, 0xc0, 0x94, 0x0d, 0x18, 0x96, 0x43, 0x44, 0xc9, 0xe3,
		0x28, 0x01, 0x56, 0x65, 0x61, 0xa8, 0xb1, 0xe4, 0xab, 0xb0, 0x64, 0xaf, 0xa3, 0x5c, 0xeb, 0x64,
		0x5a, 0x26, 0x34, 0x84, 0x1a, 0x66, 0x1c, 0x0f, 0xb3, 0x20, 0x0b, 0x87, 0xb1, 0xb1, 0x2b, 0x38,
		0x78, 0x1a, 0x69, 0xff, 0x93, 0xba, 0x0c, 0x46, 0x41, 0xf6, 0x69, 0x12, 0x2e, 0xeb, 0xc3, 0x91,
		0x8a, 0xfb, 0xc3, 0xf8, 0x3c, 0xbc, 0xa8, 0xc5, 0x2a, 0xfb, 0x32, 0x4c, 0x3e, 0xd7, 0xc2, 0x38,
		0xcd, 0x82, 0xb8, 0xaf, 0xea, 0xdf, 0xbf, 0x91, 0x3e, 0x78, 0xa7, 0x3e, 0x4a, 0x86, 0xd9, 0xb0,
		0x3f, 0x8c, 0xd2, 0xe2, 0xbb, 0x7a, 0x98, 0x86, 0x69, 0x3d, 0x52, 0x57, 0x2a, 0x9a, 0x7d, 0xa9,
		0x47, 0x61, 0xfc, 0xb9, 0x96, 0x66, 0x41, 0xa6, 0x6a, 0x83, 0x20, 0x0b, 0xce, 0x82, 0x54, 0xd5,
		0xa3, 0x74, 0x54, 0xcf, 0xa2, 0xab, 0x74, 0xf2, 0x9f, 0x7a, 0x38, 0xba, 0x6a, 0xd6, 0x12, 0x15,
		0xf4, 0x3f, 0x05, 0x67, 0x61, 0x14, 0x66, 0xd7, 0xf5, 0x51, 0xa2, 0xce, 0xc3, 0xaf, 0x2a, 0x9d,
		0x7d, 0x53, 0x4f, 0xc7, 0x67, 0xd3, 0xbf, 0x9d, 0x7f, 0xcd, 0x7f, 0x20, 0x1d, 0x8e, 0x93, 0xbe,
		0xaa, 0x25, 0xc3, 0x71, 0xa6, 0x92, 0x5a, 0x38, 0xa8, 0x4f, 0x7f, 0x85, 0xcc, 0xf8, 0x2e, 0xcf,
		0x97, 0x64, 0x59, 0x24, 0xcc, 0xab, 0xa5, 0x7b, 0xb3, 0xc6, 0x5e, 0x2c, 0xf0, 0xc6, 0x56, 0x23,
		0xcd, 0x92, 0x71, 0x3f, 0x8b, 0x67, 0x14, 0xb3, 0x9d, 0x2f, 0x9f, 0x3d, 0x5b, 0x3d, 0xbf, 0x3b,
		0x5b, 0x33, 0xdf, 0x4e, 0xc3, 0xd4, 0x77, 0x26, 0x8b, 0xe5, 0x3b, 0xe9, 0xc8, 0xf7, 0xa2, 0x2b,
		0xdf, 0x1e, 0x5d, 0x35, 0xdd, 0x7b, 0x4b, 0xe2, 0x77, 0xa7, 0x2b, 0xe1, 0xf7, 0xa6, 0x2b, 0x30,
		0xfd, 0xdf, 0xbd, 0xe9, 0x02, 0xb8, 0xd3, 0xe7, 0xb7, 0x07, 0xb2, 0xc2, 0x97, 0x9c, 0x20, 0x21,
		0x28, 0x40, 0x18, 0x39, 0x9a, 0x6b, 0x69, 0x38, 0x48, 0xc5, 0x45, 0x87, 0xa2, 0x10, 0xba, 0x6f,
		0xa4, 0xb0, 0xe0, 0xfa, 0x2e, 0x8c, 0x07, 0xc6, 0xee, 0xda, 0x86, 0x30, 0xb3, 0xf6, 0xa7, 0x01,
		0xd4, 0xd8, 0x5d, 0x5b, 0x17, 0x66, 0x58, 0x1e, 0x33, 0x64, 0x26, 0xa2, 0x5b, 0xb8, 0x0d, 0xfb,
		0xb5, 0x49, 0xca, 0x90, 0x18, 0xbd, 0xf3, 0x00, 0x2b, 0x96, 0x95, 0x1b, 0xef, 0xd4, 0xf5, 0x97,
		0x61, 0x32, 0xb8, 0x73, 0x5a, 0xa1, 0x97, 0x96, 0x1b, 0x6f, 0x83, 0xd4, 0x4c, 0x2e, 0xc6, 0x97,
		0x2a, 0xce, 0x8c, 0xdd, 0xb5, 0x2c, 0x19, 0x2b, 0xa9, 0xb5, 0xd8, 0x9d, 0x95, 0x05, 0x30, 0x49,
		0xc0, 0xa1, 0x08, 0x78, 0x2b, 0x4c, 0x64, 0x06, 0xbc, 0xbb, 0xbc, 0x2a, 0x37, 0xa2, 0x3c, 0xe4,
		0x00, 0x52, 0x43, 0x8a, 0x4c, 0x2a, 0x20, 0x9e, 0x12, 0x20, 0x50, 0x03, 0x20, 0x8a, 0x80, 0x42,
		0x15, 0xe0, 0x28, 0x03, 0x1c, 0x75, 0xc0, 0xa2, 0x10, 0x32, 0xa9, 0x84, 0x50, 0x4a, 0x21, 0x9e,
		0x5a, 0x14, 0x06, 0xe6, 0x7d, 0x6c, 0xf1, 0x41, 0xe8, 0x36, 0xae, 0xe7, 0xe6, 0x0a, 0xf7, 0x67,
		0xd9, 0x44, 0x03, 0x86, 0x70, 0x20, 0x11, 0x0f, 0x40, 0x02, 0x82, 0x46, 0x44, 0x60, 0x09, 0x09,
		0x2c, 0x31, 0xc1, 0x24, 0x28, 0xb2, 0x89, 0x8a, 0x70, 0xc2, 0x02, 0x43, 0x5c, 0x0a, 0x43, 0x83,
		0xe8, 0x62, 0x98, 0x84, 0xd9, 0xa7, 0x4b, 0x9c, 0x00, 0x76, 0x9b, 0x23, 0xee, 0x4c, 0x07, 0x89,
		0x03, 0x33, 0x62, 0xb3, 0x0e, 0x62, 0x2e, 0x0a, 0xc1, 0x41, 0x24, 0x3a, 0xc0, 0x84, 0x07, 0x95,
		0xf8, 0xc0, 0x13, 0x20, 0x78, 0x22, 0x84, 0x4d, 0x88, 0x30, 0x88, 0x11, 0x08, 0x41, 0x2a, 0xa0,
		0xe0, 0x5d, 0x8f, 0x14, 0x66, 0xc4, 0x1e, 0x87, 0x71, 0xf6, 0x06, 0x29, 0x5e, 0xcf, 0xe8, 0xc7,
		0x16, 0x90, 0xc9, 0x6e, 0x10, 0x5f, 0x4c, 0x16, 0xfb, 0x23, 0x54, 0x7c, 0xc3, 0xbb, 0x2d, 0xc7,
		0x38, 0x0a, 0x63, 0xb8, 0x44, 0x0e, 0xca, 0xab, 0x1f, 0x98, 0x7f, 0x12, 0x44, 0x63, 0x05, 0x6c,
		0xff, 0x41, 0x12, 0xf4, 0xb3, 0x70, 0x18, 0xb7, 0xc2, 0x8b, 0x30, 0x4b, 0x27, 0x0f, 0xc2, 0x2b,
		0xb9, 0xca, 0x70, 0xd9, 0xe0, 0x2b, 0x5d, 0xb6, 0x62, 0x97, 0xdd, 0xdc, 0xda, 0xa2, 0xd3, 0x92,
		0x88, 0xeb, 0x65, 0x2d, 0xc6, 0x65, 0x6d, 0xf2, 0xd7, 0x13, 0x20, 0xa9, 0x18, 0xe7, 0x51, 0x70,
		0x91, 0xe2, 0xb5, 0x7e, 0x73, 0xb3, 0xd9, 0xf6, 0x5d, 0x86, 0xb9, 0x6c, 0xfb, 0x96, 0x08, 0x64,
		0xb6, 0x7d, 0xcb, 0x73, 0x43, 0xb6, 0x7d, 0x2b, 0x7e, 0x00, 0xb6, 0x7d, 0xc9, 0x39, 0x66, 0x50,
		0xc0, 0x6d, 0xfb, 0xaa, 0x78, 0x7c, 0xa9, 0x92, 0x5c, 0x6f, 0x8c, 0xd7, 0xfc, 0xdd, 0x68, 0x00,
		0xd9, 0x6c, 0xc5, 0xe3, 0xe9, 0x58, 0x02, 0x5d, 0x6f, 0x91, 0xab, 0xea, 0x84, 0x69, 0x66, 0x66,
		0x59, 0x82, 0xe5, 0x7e, 0x47, 0x61, 0x6c, 0x45, 0x6a, 0x92, 0x3d, 0x52, 0xac, 0xbe, 0x91, 0x71,
		0x14, 0x7c, 0xbd, 0x67, 0xf9, 0xc6, 0x9b, 0x46, 0xa3, 0xb9, 0xdd, 0x68, 0xac, 0x6f, 0xbf, 0xde,
		0x5e, 0xdf, 0xd9, 0xda, 0xda, 0x68, 0x6e, 0x20, 0x6d, 0xc8, 0x74, 0x92, 0x81, 0x4a, 0xd4, 0x60,
		0xef, 0xda, 0xd8, 0x5d, 0x8b, 0xc7, 0x51, 0xc4, 0x56, 0xc1, 0xca, 0xb4, 0x0a, 0xae, 0x66, 0x3d,
		0x4f, 0xb0, 0x56, 0x41, 0x6e, 0x36, 0x5b, 0x05, 0x6c, 0x15, 0xb0, 0x55, 0xc0, 0x56, 0x01, 0x5b,
		0x05, 0x6c, 0x15, 0x90, 0x6f, 0xb0, 0x55, 0x50, 0x4a, 0xc4, 0x1e, 0x87, 0x71, 0xf6, 0x7a, 0x13,
		0xb0, 0x4b, 0xb0, 0xcd, 0x11, 0xb1, 0x25, 0xbf, 0x38, 0x22, 0x46, 0x62, 0xfd, 0x04, 0xf3, 0x39,
		0x22, 0xc6, 0x74, 0xf9, 0x1c, 0x97, 0xe5, 0x88, 0x58, 0xe5, 0x2e, 0xdb, 0xd8, 0xdc, 0x69, 0xec,
		0x34, 0xb7, 0x37, 0x77, 0x38, 0x29, 0x46, 0x42, 0xae, 0x99, 0xb5, 0x9c, 0x14, 0x5b, 0x05, 0x0b,
		0xa5, 0x6b, 0xad, 0x41, 0x8e, 0x73, 0x2f, 0xec, 0xd5, 0xe2, 0x40, 0xe8, 0x7b, 0x67, 0xd6, 0xde,
		0xfb, 0x5e, 0xf2, 0xb9, 0xee, 0xf2, 0x9d, 0x4d, 0xb0, 0xa3, 0x81, 0xec, 0xfe, 0x40, 0xed, 0xfa,
		0x80, 0x30, 0x5c, 0x1e, 0x74, 0xb4, 0x4c, 0xa0, 0xf2, 0xa0, 0xa3, 0xe5, 0xb9, 0x17, 0x0f, 0x3a,
		0x2a, 0x9b, 0x89, 0xf1, 0xa0, 0xa3, 0x55, 0x23, 0xdf, 0x30, 0xbb, 0x33, 0x45, 0xc4, 0x8d, 0x54,
		0x70, 0x9e, 0xa8, 0x73, 0x84, 0x88, 0x7b, 0x3b, 0xb4, 0x09, 0xb0, 0x1f, 0x63, 0x74, 0x67, 0xf5,
		0xcc, 0xab, 0x57, 0x79, 0x11, 0x50, 0xcf, 0x29, 0x18, 0x4b, 0x01, 0x8d, 0x2c, 0x93, 0x7a, 0x4c,
		0xec, 0x3b, 0x75, 0x2d, 0x9d, 0xf4, 0x63, 0x8c, 0xdd, 0xe2, 0x8c, 0xd9, 0x42, 0x8f, 0xd5, 0x62,
		0x8c, 0xd1, 0xf2, 0xfa, 0xc6, 0x97, 0xd9, 0xa9, 0x71, 0x9f, 0x4f, 0xf2, 0xc5, 0x00, 0x4b, 0xbb,
		0x01, 0x2e, 0xff, 0x53, 0x2f, 0x1c, 0xf0, 0xde, 0x4a, 0x44, 0x8b, 0x78, 0x6f, 0xe5, 0x6a, 0x87,
		0x2f, 0x5e, 0xd7, 0x28, 0xde, 0x2f, 0x84, 0x5e, 0xa7, 0x20, 0xfa, 0xfa, 0x04, 0x5e, 0xd1, 0xf8,
		0xd4, 0x46, 0x05, 0xaf, 0x68, 0x7c, 0x89, 0x89, 0xbc, 0xa2, 0x71, 0x41, 0x86, 0xf2, 0x8a, 0x46,
		0x72, 0xcd, 0xb2, 0x3e, 0x42, 0xb1, 0x57, 0x34, 0x66, 0x92, 0xb7, 0x0f, 0x8a, 0x70, 0x3c, 0xb5,
		0x52, 0xf6, 0xb5, 0x8c, 0xeb, 0xbc, 0x96, 0x51, 0x3b, 0x3a, 0x00, 0x44, 0x0b, 0x50, 0xe8, 0x01,
		0x1c, 0x4d, 0x80, 0xa3, 0x0b, 0x58, 0xb4, 0x41, 0x26, 0x7d, 0x10, 0x4a, 0x23, 0x8a, 0x8f, 0x56,
		0xfc, 0xa6, 0x7f, 0x11, 0x31, 0xc3, 0x81, 0x8a, 0xb3, 0x30, 0xbb, 0x96, 0xbd, 0xe1, 0x5f, 0xd4,
		0xf0, 0x92, 0xf7, 0xac, 0xec, 0xd9, 0x52, 0xee, 0x05, 0x29, 0xd0, 0x20, 0xa8, 0xdd, 0xb3, 0x7b,
		0x7e, 0xef, 0x78, 0xcf, 0x73, 0x4e, 0x7c, 0xef, 0x43, 0xd7, 0x92, 0x1e, 0xe6, 0xa7, 0xb2, 0xa1,
		0x14, 0x42, 0xcf, 0x0a, 0x76, 0x10, 0x8c, 0xdd, 0xf5, 0x5d, 0xcb, 0xdc, 0x7f, 0x6b, 0xee, 0xd9,
		0x8e, 0xed, 0x7d, 0x98, 0x81, 0xa2, 0x87, 0x80, 0x0a, 0x44, 0x74, 0x60, 0xa1, 0xe4, 0x51, 0xb4,
		0x74, 0x5d, 0xeb, 0xc0, 0x7e, 0xef, 0x1f, 0x38, 0xe6, 0x61, 0x0f, 0xe8, 0x24, 0x8a, 0x3f, 0x89,
		0x93, 0x72, 0x71, 0x62, 0x77, 0x4f, 0x1a, 0xbe, 0xdb, 0x39, 0xf6, 0x2c, 0xd7, 0xb7, 0x5b, 0x44,
		0x0a, 0x91, 0x32, 0x0f, 0x29, 0x9e, 0x79, 0x48, 0x78, 0x10, 0x1e, 0x3f, 0x81, 0x47, 0xb3, 0x41,
		0x80, 0x10, 0x20, 0x3f, 0xc9, 0x34, 0x4d, 0x66, 0x1a, 0x22, 0xe5, 0x97, 0xb9, 0x6b, 0x0f, 0x0a,
		0x25, 0x10, 0x96, 0x9e, 0xf2, 0x64, 0xd9, 0x95, 0xef, 0x23, 0x60, 0x55, 0x86, 0xc4, 0x03, 0x2b,
		0x40, 0x22, 0x82, 0x95, 0x1e, 0x61, 0xc0, 0x8a, 0x8e, 0x40, 0x60, 0xe5, 0x46, 0x44, 0xb0, 0x42,
		0x23, 0x1a, 0xaa, 0x45, 0xc3, 0x2c, 0x14, 0xec, 0x9b, 0x5d, 0xee, 0x4d, 0x12, 0x27, 0xcf, 0xc2,
		0x8b, 0xeb, 0x9b, 0xce, 0x61, 0xc7, 0xb5, 0xbd, 0xb7, 0x47, 0xec, 0x04, 0x12, 0x29, 0x3f, 0x45,
		0xca, 0xdd, 0x9f, 0xd8, 0x0e, 0x5c, 0xec, 0x8b, 0xed, 0x40, 0x26, 0x6f, 0xb4, 0x60, 0x4c, 0x44,
		0x30, 0xe8, 0x12, 0x12, 0xcb, 0xae, 0xf7, 0x7a, 0x9c, 0x3d, 0x24, 0x4a, 0x9e, 0x8b, 0x16, 0xc7,
		0x6e, 0xbf, 0xe3, 0x16, 0x3f, 0x21, 0xf2, 0x13, 0x88, 0x1c, 0xb7, 0xf7, 0x3b, 0xed, 0x9e, 0xe7,
		0x9a, 0x76, 0xdb, 0x6a, 0xf9, 0x4e, 0xaf, 0x4b, 0xb0, 0x10, 0x2c, 0x3f, 0x8d, 0x27, 0xa6, 0xe7,
		0xb9, 0xf6, 0xde, 0xb1, 0x67, 0x71, 0x9c, 0x99, 0x50, 0x99, 0x0b, 0x95, 0xe9, 0x56, 0x45, 0xdb,
		0xb2, 0x0f, 0xdf, 0xee, 0x75, 0x5c, 0xdf, 0x6c, 0xb5, 0x5c, 0xab, 0x47, 0xc0, 0x10, 0x30, 0x3f,
		0x03, 0x4c, 0xc3, 0xb7, 0xdb, 0x9e, 0xe5, 0x1e, 0x98, 0xfb, 0x16, 0x11, 0x43, 0xc4, 0x3c, 0x4a,
		0x5d, 0x3c, 0xdb, 0xb1, 0xff, 0x6b, 0xb5, 0xfc, 0x3d, 0xb3, 0xdd, 0xfa, 0x8f, 0xdd, 0xf2, 0xde,
		0x12, 0x2d, 0x44, 0xcb, 0x4f, 0xb9, 0x4b, 0xd7, 0xed, 0x78, 0xd6, 0xbe, 0x67, 0x77, 0xda, 0x79,
		0x05, 0x4d, 0xbc, 0x10, 0x2f, 0x73, 0xf0, 0xe2, 0x5a, 0x3d, 0xbb, 0x75, 0x6c, 0x3a, 0x8c, 0x2e,
		0x44, 0xcb, 0xe3, 0x68, 0x39, 0x32, 0xdf, 0xe7, 0x11, 0x86, 0x68, 0x21, 0x5a, 0x7e, 0xad, 0x38,
		0x22, 0xd7, 0x25, 0x62, 0x9e, 0x14, 0x5f, 0x5c, 0xab, 0x67, 0xb9, 0x27, 0xe6, 0x9e, 0x63, 0x31,
		0xca, 0x10, 0x33, 0xbf, 0xc8, 0x78, 0x9d, 0x0e, 0x03, 0x0b, 0x41, 0xf2, 0x08, 0x48, 0x5a, 0x96,
		0x63, 0x7e, 0xf0, 0x4f, 0x4c, 0xd7, 0x36, 0x27, 0xb5, 0x11, 0xf1, 0x42, 0xbc, 0xcc, 0xc3, 0x8b,
		0xd9, 0xfa, 0xb7, 0xef, 0x98, 0x6d, 0x30, 0x4d, 0x28, 0x61, 0x52, 0x36, 0x4c, 0x4e, 0x4c, 0xdb,
		0x21, 0x55, 0x21, 0x5c, 0x7e, 0x3d, 0xaa, 0x30, 0xa2, 0x10, 0x22, 0x3f, 0xab, 0x80, 0xec, 0xf6,
		0x5d, 0x97, 0x65, 0x4a, 0x58, 0x88, 0x16, 0xa2, 0x65, 0xfe, 0x58, 0x4b, 0x5e, 0x2d, 0x73, 0x77,
		0x88, 0x78, 0xf9, 0x15, 0xbc, 0x14, 0x20, 0xf1, 0x8b, 0x71, 0x28, 0x8f, 0x75, 0x33, 0x01, 0x33,
		0x17, 0x30, 0xd6, 0x7b, 0xcf, 0x6a, 0xb7, 0xac, 0x96, 0x6f, 0xb6, 0x26, 0x99, 0xe9, 0xd0, 0xed,
		0x1c, 0x73, 0x74, 0x8e, 0x78, 0xf9, 0x09, 0xc3, 0x25, 0x4c, 0x08, 0x93, 0x47, 0x61, 0x32, 0x9d,
		0x82, 0xe2, 0xd8, 0x1c, 0x01, 0xf3, 0xab, 0x80, 0x61, 0x39, 0x44, 0x94, 0x3c, 0x8e, 0x12, 0xcf,
		0xf2, 0x5b, 0xd6, 0x81, 0x79, 0xec, 0x78, 0xfe, 0x91, 0xe5, 0xb9, 0xf6, 0x3e, 0x05, 0xbc, 0x8b,
		0x7d, 0x51, 0xc0, 0xbb, 0x32, 0xce, 0x86, 0xaf, 0xb6, 0x22, 0x14, 0x96, 0x0d, 0x05, 0x40, 0x55,
		0x15, 0x41, 0x51, 0x4a, 0x7c, 0x40, 0x52, 0x4f, 0x11, 0x12, 0x25, 0x94, 0x7b, 0x88, 0x2a, 0x29,
		0x02, 0xa3, 0x94, 0x3e, 0x00, 0xe0, 0x84, 0x28, 0x91, 0xb1, 0x74, 0x6a, 0x01, 0xa8, 0x7a, 0x22,
		0x2a, 0x4a, 0xe1, 0x16, 0x70, 0xea, 0x26, 0xe2, 0x62, 0xd9, 0xb8, 0x40, 0x54, 0x31, 0x11, 0x15,
		0xcb, 0x46, 0x05, 0xa2, 0x5a, 0x89, 0xa8, 0x28, 0xa5, 0x18, 0x21, 0xe7, 0x24, 0x32, 0x34, 0x52,
		0x1f, 0x11, 0x1b, 0xa5, 0x30, 0x4f, 0x0c, 0x95, 0x11, 0xc1, 0x50, 0x0a, 0x18, 0xe0, 0xd4, 0x44,
		0xc4, 0xc5, 0xb2, 0x71, 0x01, 0xa5, 0x1a, 0x22, 0x1c, 0x96, 0x0e, 0x07, 0x44, 0x75, 0x10, 0x61,
		0x51, 0x46, 0x94, 0x60, 0x84, 0x20, 0x14, 0x40, 0xd5, 0x3e, 0x44, 0xc5, 0xb2, 0x51, 0x81, 0xa9,
		0xea, 0x21, 0x2e, 0x96, 0x8d, 0x0b, 0x50, 0xf5, 0x0e, 0x81, 0xb1, 0x6c, 0x60, 0x60, 0xaa, 0x74,
		0x88, 0x8b, 0xe5, 0x33, 0x4d, 0xc2, 0x81, 0x70, 0x40, 0x57, 0xdd, 0x10, 0x18, 0xcb, 0x06, 0x06,
		0xcb, 0x0f, 0xa2, 0x01, 0x5a, 0x45, 0x23, 0x5b, 0x3d, 0x23, 0x57, 0x35, 0x23, 0x73, 0xdd, 0xe4,
		0x59, 0x25, 0xcb, 0x22, 0x61, 0x21, 0xd0, 0x30, 0xe3, 0x78, 0x98, 0x05, 0x59, 0x38, 0x8c, 0x8d,
		0x5d, 0x81, 0xc1, 0xcf, 0x48, 0xfb, 0x9f, 0xd4, 0x65, 0x30, 0x0a, 0xb2, 0x4f, 0x93, 0x70, 0x57,
		0x1f, 0x8e, 0x54, 0xdc, 0x1f, 0xc6, 0xe7, 0xe1, 0x45, 0x2d, 0x56, 0xd9, 0x97, 0x61, 0xf2, 0xb9,
		0x16, 0xc6, 0x69, 0x16, 0xc4, 0x7d, 0x55, 0xff, 0xfe, 0x8d, 0xf4, 0xc1, 0x3b, 0xf5, 0x51, 0x32,
		0xcc, 0x86, 0xfd, 0x61, 0x94, 0x16, 0xdf, 0xd5, 0xc3, 0x34, 0x4c, 0xeb, 0x91, 0xba, 0x52, 0xd1,
		0xec, 0x4b, 0x3d, 0x0a, 0xe3, 0xcf, 0xb5, 0x34, 0x0b, 0x32, 0x55, 0x1b, 0x04, 0x59, 0x70, 0x16,
		0xa4, 0xaa, 0x1e, 0xa5, 0xa3, 0x7a, 0x16, 0x5d, 0xa5, 0x93, 0xff, 0xd4, 0xc3, 0xd1, 0x55, 0xb3,
		0x96, 0xa8, 0xa0, 0xff, 0x29, 0x38, 0x0b, 0xa3, 0x30, 0xbb, 0xae, 0x8f, 0x12, 0x75, 0x1e, 0x7e,
		0x55, 0xe9, 0xec, 0x9b, 0x7a, 0x3a, 0x3e, 0x9b, 0xfe, 0xed, 0xfc, 0x6b, 0x7d, 0xfa, 0x8f, 0xc9,
		0x8a, 0xc4, 0x72, 0xbc, 0x42, 0x90, 0x47, 0x18, 0x59, 0x70, 0x21, 0xce, 0x0d, 0x8a, 0x5c, 0x3f,
		0x31, 0x4e, 0x58, 0xf4, 0x78, 0x17, 0xc6, 0x03, 0x63, 0x77, 0x6d, 0x43, 0x98, 0x59, 0xfb, 0xd3,
		0x08, 0x61, 0xec, 0xae, 0xad, 0x0b, 0x33, 0xac, 0x3b, 0x0d, 0x0f, 0x32, 0x23, 0xed, 0x2d, 0xcc,
		0x86, 0xfd, 0xda, 0x24, 0x26, 0x0a, 0xbc, 0xba, 0xd1, 0xe8, 0x0d, 0xc7, 0x49, 0x5f, 0x89, 0x5c,
		0xbe, 0xdc, 0x1d, 0xd4, 0xf5, 0x97, 0x61, 0x32, 0xf1, 0x08, 0x23, 0x4f, 0x04, 0x42, 0xef, 0xbf,
		0x34, 0xde, 0x06, 0xa9, 0x99, 0x5c, 0x8c, 0x2f, 0x55, 0x9c, 0x19, 0xbb, 0x6b, 0x59, 0x32, 0x56,
		0x42, 0x0d, 0xbd, 0x67, 0x65, 0x01, 0x4c, 0x32, 0x4c, 0x28, 0x86, 0xd9, 0x0a, 0x13, 0xa1, 0xd4,
		0x72, 0xca, 0xca, 0xc4, 0x06, 0x93, 0xdb, 0x78, 0x9c, 0x9b, 0x29, 0xd4, 0x3f, 0x65, 0x12, 0x00,
		0xf1, 0x44, 0x00, 0x81, 0x10, 0x00, 0x11, 0x03, 0x14, 0x82, 0x00, 0x47, 0x14, 0xe0, 0x08, 0x03,
		0x16, 0x71, 0x90, 0x49, 0x20, 0x84, 0x12, 0x09, 0xf1, 0x84, 0xe2, 0x7e, 0x17, 0xe1, 0xf5, 0xa6,
		0xfc, 0x20, 0x74, 0xaf, 0xaf, 0xf0, 0x7a, 0x53, 0x7a, 0x00, 0x9a, 0x11, 0x8d, 0x75, 0xe1, 0x66,
		0x4a, 0x27, 0x1c, 0x48, 0xc4, 0x03, 0x90, 0x80, 0xa0, 0x11, 0x11, 0x58, 0x42, 0x02, 0x4b, 0x4c,
		0x30, 0x09, 0x8a, 0x6c, 0xa2, 0x22, 0x9c, 0xb0, 0x14, 0x1f, 0xb9, 0x77, 0x3d, 0x52, 0x58, 0x11,
		0x77, 0x1c, 0xc6, 0x99, 0x78, 0x6e, 0x70, 0x9f, 0x1f, 0x6c, 0x03, 0x98, 0xea, 0x06, 0xf1, 0xc5,
		0x64, 0x75, 0x3f, 0x42, 0x04, 0x2a, 0x9c, 0xe3, 0x65, 0x8d, 0xa3, 0x30, 0x86, 0xc9, 0xb8, 0x60,
		0xc4, 0xf6, 0x81, 0xd9, 0x27, 0x41, 0x34, 0x56, 0x80, 0x76, 0x1f, 0x24, 0x41, 0x3f, 0x0b, 0x87,
		0x71, 0x2b, 0xbc, 0x08, 0xb3, 0x74, 0xf2, 0x00, 0x3c, 0x93, 0x7a, 0x19, 0xae, 0x18, 0x7c, 0xa5,
		0x2b, 0x96, 0xec, 0x8a, 0x8d, 0xcd, 0x9d, 0xc6, 0x4e, 0x73, 0x7b, 0x73, 0x67, 0x8b, 0x3e, 0x49,
		0x42, 0x8c, 0x65, 0xe5, 0x29, 0x0b, 0x8b, 0x17, 0x38, 0x90, 0x13, 0xa6, 0x99, 0x99, 0x65, 0x09,
		0x46, 0x71, 0x71, 0x14, 0xc6, 0x56, 0xa4, 0x26, 0xb5, 0x6f, 0x8a, 0x11, 0x6d, 0x27, 0xd9, 0xec,
		0x9e, 0xc5, 0x1b, 0x6f, 0x1a, 0x8d, 0xe6, 0x76, 0xa3, 0xb1, 0xbe, 0xfd, 0x7a, 0x7b, 0x7d, 0x67,
		0x6b, 0x6b, 0xa3, 0xb9, 0x01, 0x10, 0x71, 0x8d, 0x4e, 0x32, 0x50, 0x89, 0x1a, 0xec, 0x5d, 0x1b,
		0xbb, 0x6b, 0xf1, 0x38, 0x8a, 0x7e, 0x63, 0xc4, 0xd2, 0xc7, 0x32, 0xa9, 0x7b, 0x35, 0xc2, 0xc7,
		0x8b, 0x0b, 0x3b, 0xb5, 0x18, 0x33, 0xce, 0x82, 0x0b, 0x89, 0xa3, 0xc6, 0x72, 0x3d, 0x87, 0x83,
		0x5b, 0xc0, 0xbe, 0xab, 0x8d, 0xcf, 0x4a, 0x9c, 0xb4, 0x4d, 0xb3, 0x64, 0xdc, 0xcf, 0xe2, 0x59,
		0x1b, 0xb8, 0x9d, 0x2f, 0x96, 0x3d, 0x5b, 0x2b, 0xbf, 0x3b, 0x5b, 0x21, 0xdf, 0x4e, 0xc3, 0xd4,
		0x77, 0x26, 0x4b, 0xe3, 0x3b, 0xe9, 0xc8, 0xf7, 0xa2, 0x2b, 0xdf, 0x1e, 0x5d, 0x35, 0xdd, 0x7b,
		0x0b, 0xe0, 0xe7, 0x3b, 0x8d, 0x7e, 0x6f, 0xfa, 0xbc, 0xbe, 0x17, 0x5c, 0x50, 0x08, 0x21, 0xde,
		0xff, 0x8d, 0x2c, 0xb8, 0x68, 0x36, 0x44, 0x4b, 0x21, 0x9a, 0x0d, 0x8a, 0x21, 0x7e, 0xc9, 0x2c,
		0x8a, 0x21, 0x5e, 0x00, 0x34, 0x8a, 0x21, 0x9e, 0xef, 0x0e, 0x14, 0x43, 0x2c, 0x9a, 0x90, 0x51,
		0x0c, 0x81, 0xce, 0xa9, 0x29, 0x86, 0x78, 0x59, 0x3c, 0xa6, 0x18, 0x42, 0x3f, 0x22, 0x80, 0x40,
		0x08, 0x80, 0x88, 0x01, 0x0a, 0x41, 0x80, 0x23, 0x0a, 0x70, 0x84, 0x01, 0x8b, 0x38, 0xc8, 0x24,
		0x10, 0x42, 0x89, 0x84, 0x78, 0x42, 0x21, 0xbc, 0x93, 0x00, 0xd5, 0x59, 0x98, 0x47, 0x34, 0x28,
		0x86, 0x58, 0x1d, 0xe2, 0x01, 0x48, 0x40, 0xd0, 0x88, 0x08, 0x2c, 0x21, 0x81, 0x25, 0x26, 0x98,
		0x04, 0x45, 0x36, 0x51, 0x11, 0x4e, 0x58, 0x8a, 0x8f, 0x1c, 0x53, 0x0c, 0x21, 0x9e, 0x1b, 0xdc,
		0xe7, 0x07, 0x6f, 0x28, 0x86, 0x58, 0xf0, 0x8b, 0x62, 0x08, 0x12, 0xdb, 0x1f, 0x98, 0x4d, 0x31,
		0x04, 0xd3, 0xdb, 0xcf, 0x5c, 0x91, 0x62, 0x88, 0xd2, 0x5d, 0x11, 0x73, 0x48, 0x57, 0x1b, 0xef,
		0xa4, 0x2c, 0x62, 0x21, 0x2f, 0xca, 0x22, 0x5e, 0xe2, 0x40, 0x94, 0x45, 0x2c, 0x3d, 0xaf, 0x51,
		0x16, 0xc1, 0x88, 0x25, 0xd8, 0x32, 0xca, 0x22, 0x5e, 0x66, 0xa7, 0x2e, 0x23, 0xd6, 0xcd, 0x06,
		0x85, 0x11, 0xb8, 0x16, 0x51, 0x18, 0xb1, 0xaa, 0x5e, 0xbb, 0x6a, 0xd2, 0x88, 0x66, 0x83, 0xe2,
		0x08, 0xf1, 0x31, 0xc0, 0xc8, 0x24, 0x6e, 0x5d, 0xdc, 0x4d, 0x30, 0x4c, 0xac, 0x93, 0x29, 0x8d,
		0x58, 0xa7, 0x34, 0xe2, 0xd7, 0x0c, 0xa3, 0x34, 0xe2, 0x45, 0x26, 0x52, 0x1a, 0xb1, 0x20, 0x43,
		0x29, 0x8d, 0x20, 0xab, 0x2e, 0xeb, 0x23, 0x14, 0x3b, 0x10, 0x50, 0x44, 0xbc, 0x48, 0x05, 0xe7,
		0x89, 0x3a, 0x97, 0x18, 0xf1, 0x6e, 0xa5, 0x07, 0x02, 0xcf, 0x3f, 0x34, 0xba, 0xb3, 0x42, 0xe4,
		0xd5, 0xab, 0xbc, 0x08, 0xaf, 0x4f, 0x19, 0x0a, 0x79, 0xae, 0x60, 0x4b, 0x84, 0xc4, 0x86, 0x49,
		0xa2, 0x14, 0x46, 0x69, 0x65, 0x6e, 0x2a, 0xc8, 0xdd, 0x3c, 0x80, 0xda, 0x24, 0x90, 0xb9, 0x19,
		0x20, 0xc5, 0x19, 0x85, 0xb6, 0xbd, 0xb4, 0x68, 0x77, 0x09, 0xe2, 0x14, 0x4b, 0x6b, 0x70, 0xc9,
		0x48, 0xf9, 0xd5, 0x27, 0xd8, 0x6a, 0x2d, 0xa8, 0x38, 0x9a, 0x48, 0x8b, 0x22, 0xd8, 0xd1, 0xa3,
		0x5a, 0x97, 0xaa, 0x0e, 0xc8, 0x15, 0x82, 0xd8, 0x18, 0xc7, 0x03, 0x75, 0x1e, 0xc6, 0x6a, 0x50,
		0xbb, 0xfd, 0x10, 0xaa, 0xc6, 0xf1, 0xdd, 0x84, 0xfa, 0x03, 0xd3, 0x2a, 0x76, 0x76, 0x19, 0x8a,
		0x78, 0x31, 0x7d, 0x5e, 0x49, 0x7d, 0x5d, 0x81, 0x7d, 0x5c, 0x69, 0x7d, 0x5b, 0xb1, 0x7d, 0x5a,
		0xb1, 0x7d, 0x59, 0x99, 0x7d, 0xd8, 0xd5, 0x26, 0x5c, 0x52, 0x14, 0xe2, 0x0f, 0xb2, 0x93, 0x1c,
		0x3f, 0x9f, 0x97, 0x3f, 0xa5, 0xb8, 0xbb, 0xac, 0x83, 0x65, 0xc4, 0x6d, 0x9b, 0x4a, 0xdc, 0x2e,
		0x15, 0xbc, 0x4d, 0x2a, 0x75, 0x7b, 0x54, 0xfc, 0xb6, 0xa8, 0xf8, 0xed, 0x50, 0xd9, 0xdb, 0xa0,
		0xdc, 0xda, 0x90, 0x98, 0x96, 0xef, 0x1a, 0x21, 0x22, 0x4f, 0x80, 0x13, 0x7d, 0xf2, 0x1b, 0x8f,
		0x7c, 0xc5, 0x4f, 0xd4, 0x00, 0x09, 0x5b, 0x7a, 0xe2, 0x86, 0x49, 0xe0, 0x30, 0x89, 0x1c, 0x23,
		0xa1, 0xcb, 0x4a, 0xec, 0xc2, 0x12, 0xbc, 0xd8, 0x44, 0x5f, 0x18, 0x16, 0xa9, 0xf8, 0x62, 0xba,
		0xeb, 0x21, 0xfc, 0xcc, 0xd7, 0x99, 0x9d, 0xb2, 0x0f, 0x7d, 0x5d, 0xe7, 0xa1, 0xaf, 0xda, 0x51,
		0x02, 0x20, 0x6a, 0x80, 0x42, 0x11, 0xe0, 0xa8, 0x02, 0x1c, 0x65, 0xc0, 0xa2, 0x0e, 0x32, 0x29,
		0x84, 0x50, 0x2a, 0x51, 0x7c, 0xb4, 0xe2, 0xcf, 0x4e, 0xfb, 0xe6, 0xcc, 0xb4, 0x37, 0x92, 0xe3,
		0xe5, 0x2c, 0x7d, 0x0b, 0x3e, 0xa9, 0x00, 0xe4, 0x88, 0x34, 0x8c, 0x13, 0x36, 0x80, 0x0e, 0x21,
		0x85, 0x3a, 0x7f, 0x09, 0xed, 0x08, 0x34, 0xc4, 0xc3, 0x95, 0x6e, 0x30, 0x8e, 0x84, 0xa1, 0x8b,
		0x2d, 0xd9, 0xc5, 0x36, 0xb7, 0xb6, 0xe8, 0x64, 0xab, 0x45, 0x44, 0xe5, 0x5b, 0x77, 0xca, 0x93,
		0x55, 0x50, 0x83, 0xb8, 0xcc, 0xf3, 0x0c, 0x1e, 0x94, 0x12, 0x02, 0xcf, 0x35, 0x00, 0xc9, 0x24,
		0x6c, 0x02, 0x2e, 0x12, 0x87, 0x6c, 0x02, 0x2e, 0xce, 0x6d, 0xd8, 0x04, 0x5c, 0xb2, 0xc1, 0x6c,
		0x02, 0xea, 0x5a, 0x76, 0xb1, 0x09, 0xb8, 0xf0, 0xf4, 0xcd, 0x26, 0xe0, 0x4b, 0x5f, 0x6c, 0x02,
		0xb2, 0x43, 0xc1, 0x26, 0xe0, 0x0a, 0x66, 0xa3, 0x6f, 0x5d, 0x8c, 0x4d, 0xc0, 0xa5, 0xbb, 0x18,
		0x9b, 0x80, 0x2b, 0x47, 0x44, 0xe5, 0x5b, 0xc7, 0x26, 0x20, 0x6c, 0x10, 0x37, 0xae, 0x66, 0x81,
		0x45, 0x78, 0x17, 0x30, 0x37, 0x93, 0x6d, 0xc0, 0xe7, 0x98, 0xc7, 0x36, 0xe0, 0x02, 0x81, 0xc8,
		0x36, 0xe0, 0xe2, 0xdc, 0x86, 0x6d, 0xc0, 0x25, 0x1b, 0xcc, 0x36, 0xa0, 0xae, 0x85, 0x17, 0x50,
		0x1b, 0xf0, 0x2c, 0x8c, 0x83, 0xe4, 0x1a, 0xa0, 0x0f, 0xb8, 0x43, 0x1a, 0x0b, 0x68, 0x11, 0x6f,
		0x09, 0x79, 0x9a, 0x7d, 0x98, 0x07, 0x9f, 0x3d, 0x38, 0xe2, 0xea, 0xc1, 0x3b, 0x12, 0x6f, 0xfa,
		0xe1, 0x3d, 0x1a, 0x3f, 0x42, 0x20, 0xef, 0xd1, 0xd0, 0xa3, 0xc0, 0xa4, 0xde, 0x5c, 0xcf, 0x42,
		0x92, 0x7a, 0xf3, 0x55, 0x2b, 0x18, 0xa9, 0x37, 0xc7, 0xe7, 0x9d, 0xbc, 0x47, 0xe3, 0xe5, 0x09,
		0x96, 0xf7, 0x68, 0xc0, 0xf3, 0x5c, 0x1e, 0x36, 0xf5, 0x6d, 0xa2, 0xe4, 0x3d, 0x1a, 0xbf, 0x62,
		0x15, 0xef, 0xd1, 0x58, 0x88, 0xb1, 0xbc, 0x47, 0x03, 0xaf, 0x31, 0xa4, 0x6d, 0x43, 0x48, 0xef,
		0xbb, 0x35, 0x8e, 0x6f, 0x9f, 0x96, 0x97, 0x6c, 0xc8, 0xb1, 0x80, 0x97, 0x6c, 0x68, 0x19, 0x5a,
		0x56, 0xf6, 0xba, 0x8d, 0xdf, 0x56, 0xc8, 0x89, 0x6e, 0xc9, 0x72, 0xa5, 0x1d, 0x25, 0x19, 0xf4,
		0x58, 0x0e, 0x1d, 0x16, 0x4d, 0x7f, 0x65, 0xd0, 0xdd, 0xaa, 0xdc, 0x45, 0x48, 0xae, 0xc1, 0xcc,
		0x31, 0x15, 0x72, 0xd3, 0xc5, 0x73, 0xd1, 0x6a, 0xd2, 0x63, 0xf9, 0xc9, 0xa9, 0xdc, 0xdf, 0x58,
		0xb2, 0x5f, 0x57, 0xed, 0xcf, 0x60, 0x7e, 0x5c, 0x2e, 0xe6, 0xcb, 0x43, 0x5e, 0x39, 0xbf, 0xa9,
		0x24, 0x6c, 0x57, 0x85, 0x69, 0x0c, 0x2c, 0x97, 0x98, 0x83, 0x16, 0x98, 0x73, 0xca, 0x71, 0xbc,
		0xe5, 0xbb, 0x41, 0x09, 0x2e, 0x60, 0x4c, 0x3f, 0xf2, 0x34, 0x89, 0x2e, 0xca, 0xbb, 0xab, 0xb0,
		0xd8, 0xec, 0xbb, 0xf7, 0xbb, 0x4b, 0x72, 0xf6, 0x72, 0x2f, 0x65, 0x28, 0x7d, 0xf8, 0xa5, 0x8a,
		0xa1, 0x96, 0x0a, 0x87, 0x55, 0xaa, 0x1a, 0x42, 0xa9, 0x7c, 0xb8, 0xa4, 0xf2, 0xa1, 0x91, 0x6a,
		0x87, 0x41, 0xf4, 0x22, 0x20, 0x65, 0x5f, 0x02, 0x70, 0x17, 0x76, 0xcb, 0x77, 0x9c, 0x07, 0x91,
		0xbf, 0x6c, 0xc7, 0xa9, 0xe6, 0x56, 0x9e, 0xca, 0xa6, 0x20, 0xab, 0x9c, 0x72, 0x14, 0x30, 0xc5,
		0x58, 0xf5, 0x94, 0xa2, 0x98, 0x29, 0x44, 0x31, 0x53, 0x86, 0x32, 0xa6, 0x08, 0xf5, 0xee, 0xd2,
		0x54, 0x75, 0xab, 0x8c, 0x71, 0x5b, 0x8d, 0xd6, 0xe2, 0xf1, 0xe5, 0x99, 0xaa, 0x6e, 0x7f, 0xe2,
		0x2e, 0xcd, 0x7c, 0x67, 0x50, 0x55, 0xbb, 0x46, 0x95, 0x8e, 0xe6, 0x57, 0x3e, 0x82, 0x2f, 0x61,
		0xd4, 0x5e, 0xd0, 0x48, 0xbd, 0x94, 0xd1, 0x79, 0x71, 0x23, 0xf2, 0xe2, 0x46, 0xe1, 0x65, 0x8d,
		0xbc, 0xaf, 0xd6, 0x4e, 0x7b, 0xe5, 0xa3, 0xea, 0x82, 0x46, 0xd2, 0x25, 0x8c, 0x9e, 0x3f, 0x1c,
		0x31, 0xff, 0x3e, 0xb9, 0xae, 0xca, 0x0e, 0x5f, 0x05, 0x65, 0x4c, 0xb5, 0xf7, 0xef, 0x8a, 0xb8,
		0x67, 0xb7, 0xe2, 0xfb, 0x74, 0x49, 0xa2, 0x48, 0xa2, 0x48, 0xa2, 0x48, 0xa2, 0xb0, 0x48, 0x54,
		0xd5, 0xf7, 0xcb, 0x1a, 0xe7, 0x51, 0x50, 0xe2, 0xc6, 0xe2, 0xa3, 0x71, 0x2b, 0x37, 0xa7, 0x62,
		0x7f, 0x90, 0x21, 0xd4, 0x17, 0x23, 0xcc, 0x97, 0x24, 0xc4, 0x17, 0x28, 0xbc, 0x97, 0x26, 0xb4,
		0x17, 0x2b, 0xac, 0x17, 0x2b, 0xa4, 0x97, 0x29, 0x9c, 0x5f, 0x6d, 0x11, 0x8c, 0x18, 0x21, 0x7c,
		0x11, 0x71, 0x54, 0x3c, 0xbe, 0x54, 0x49, 0x3e, 0x87, 0x26, 0x20, 0xea, 0xdc, 0x56, 0x5b, 0x0d,
		0x01, 0xb6, 0x58, 0xf1, 0xf8, 0x72, 0xf2, 0x61, 0xad, 0x36, 0x64, 0x45, 0x89, 0xa2, 0xe5, 0x89,
		0xa1, 0x21, 0x44, 0xd0, 0xb2, 0xc4, 0xcf, 0x15, 0x8a, 0xc6, 0x2a, 0x6c, 0x1c, 0x48, 0xd9, 0xa4,
		0x7c, 0x90, 0x01, 0x64, 0x6c, 0x56, 0xb2, 0x4c, 0x61, 0x99, 0xc2, 0x32, 0x85, 0x65, 0x0a, 0xcb,
		0x14, 0x96, 0x29, 0x3f, 0x88, 0x38, 0xe3, 0x30, 0xce, 0x5e, 0x6f, 0x0a, 0xaa, 0x50, 0x04, 0x9c,
		0xc6, 0x25, 0xec, 0x02, 0x36, 0x59, 0x47, 0x26, 0xc9, 0x3b, 0xc4, 0x55, 0xe8, 0x41, 0xa9, 0x42,
		0x2f, 0x48, 0x93, 0x7c, 0x47, 0xd3, 0x8d, 0xac, 0x33, 0xb8, 0x08, 0xf5, 0x27, 0x42, 0xbd, 0xb1,
		0xb9, 0xd3, 0xd8, 0x69, 0x6e, 0x6f, 0xee, 0x6c, 0x11, 0xf3, 0x18, 0x84, 0x48, 0x8e, 0x15, 0xa7,
		0x6c, 0x9d, 0x94, 0xdf, 0x3a, 0x19, 0x5d, 0x35, 0x6b, 0x61, 0x9c, 0xa9, 0xe4, 0x3c, 0xe8, 0xab,
		0x5a, 0x30, 0x18, 0x24, 0x2a, 0x15, 0xb4, 0xbd, 0x3b, 0xc7, 0x3e, 0x36, 0x52, 0xd8, 0x48, 0x61,
		0x23, 0x85, 0x8d, 0x14, 0x36, 0x52, 0xd8, 0x48, 0x11, 0x13, 0x71, 0xa6, 0xb9, 0x4a, 0x46, 0x86,
		0xba, 0x9f, 0xa5, 0x36, 0xde, 0x08, 0xb0, 0xa5, 0x1b, 0x64, 0x99, 0x4a, 0x62, 0x31, 0x1d, 0x15,
		0xe3, 0x7f, 0xbf, 0xff, 0xfe, 0x71, 0xbd, 0xb6, 0x13, 0xd4, 0xce, 0xcd, 0xda, 0xc1, 0xe9, 0xdf,
		0x1b, 0x7f, 0x36, 0x6e, 0x76, 0xff, 0xf8, 0x7b, 0xfb, 0xe6, 0xfb, 0x37, 0xff, 0xf9, 0xd1, 0x5f,
		0xdb, 0xf8, 0x73, 0xfb, 0x66, 0x77, 0xce, 0xff, 0x69, 0xde, 0xec, 0xfe, 0xe2, 0xbf, 0xb1, 0x75,
		0xf3, 0xfb, 0x83, 0xbf, 0x3a, 0x79, 0x7f, 0x73, 0xde, 0x0f, 0x34, 0xe6, 0xfc, 0xc0, 0xeb, 0x79,
		0x3f, 0xf0, 0x7a, 0xce, 0x0f, 0xcc, 0x35, 0x69, 0x73, 0xce, 0x0f, 0x6c, 0xdd, 0xfc, 0xf3, 0xe0,
		0xef, 0xff, 0xfe, 0xe3, 0xbf, 0xda, 0xbc, 0xf9, 0xe3, 0x9f, 0x79, 0xff, 0x6f, 0xfb, 0xe6, 0x9f,
		0xdd, 0x3f, 0xfe, 0xf8, 0x57, 0xf5, 0xa1, 0xf3, 0x54, 0x82, 0x4b, 0x74, 0x7a, 0xf6, 0x7b, 0xfa,
		0x05, 0xfd, 0x42, 0x92, 0x5f, 0xb0, 0x04, 0xaf, 0xa6, 0x04, 0x8f, 0x55, 0x78, 0xf1, 0xe9, 0x6c,
		0x98, 0x08, 0xad, 0xc0, 0x1f, 0x98, 0xc7, 0x02, 0x9c, 0x05, 0x38, 0x0b, 0x70, 0x16, 0xe0, 0x2c,
		0xc0, 0x59, 0x80, 0xb3, 0x00, 0x67, 0x01, 0xce, 0x42, 0x83, 0x85, 0x06, 0x0b, 0x70, 0xfa, 0x05,
		0xfd, 0x82, 0x05, 0x38, 0x5a, 0x01, 0x3e, 0x4a, 0x63, 0x71, 0xca, 0x81, 0x7b, 0x36, 0xb1, 0xd4,
		0x66, 0xa9, 0xcd, 0x52, 0x9b, 0xa5, 0x36, 0x4b, 0x6d, 0x96, 0xda, 0x62, 0x22, 0xce, 0x38, 0x8c,
		0xb3, 0x37, 0x82, 0x6a, 0xec, 0x2d, 0x6a, 0x06, 0xbe, 0x7b, 0x51, 0x33, 0x80, 0xc0, 0x6b, 0x1e,
		0x98, 0x45, 0xcd, 0x00, 0x5a, 0x74, 0xfe, 0x16, 0xea, 0xd4, 0x0c, 0x3c, 0x19, 0xea, 0x9b, 0x5b,
		0x14, 0x0b, 0x80, 0x10, 0x21, 0x39, 0x56, 0xb0, 0x51, 0x52, 0xbe, 0x5b, 0xa4, 0x49, 0x74, 0x51,
		0xbb, 0x9a, 0x79, 0xad, 0x90, 0x46, 0xc9, 0x3d, 0x9b, 0xd8, 0x28, 0x61, 0xa3, 0x84, 0x8d, 0x12,
		0x36, 0x4a, 0xd8, 0x28, 0x61, 0xa3, 0x44, 0x54, 0xa3, 0x84, 0xa7, 0x2b, 0xb0, 0x53, 0xc2, 0x4e,
		0x09, 0x3b, 0x25, 0xec, 0x94, 0xb0, 0x53, 0xf2, 0x22, 0xa8, 0xf3, 0x74, 0x05, 0x36, 0x4c, 0x40,
		0x1b, 0x26, 0x3c, 0x6a, 0xf5, 0xdb, 0x34, 0xcf, 0xa3, 0x56, 0x9f, 0x6e, 0x24, 0x8f, 0x5a, 0xad,
		0xda, 0x97, 0x8c, 0xf4, 0x3a, 0xcd, 0xd4, 0x65, 0x2d, 0x1c, 0x08, 0xea, 0x00, 0x16, 0x26, 0xb1,
		0x01, 0xc8, 0x06, 0xe0, 0x23, 0x60, 0x61, 0x03, 0x70, 0x3e, 0x7c, 0xd9, 0x00, 0x7c, 0xa2, 0x61,
		0x6c, 0x00, 0x8a, 0xe3, 0x79, 0xf2, 0x1a, 0x80, 0x52, 0xd2, 0xd3, 0x1a, 0x15, 0x49, 0x8f, 0x18,
		0xf4, 0xbf, 0x8f, 0xeb, 0xb5, 0x1d, 0xb3, 0x76, 0x10, 0xd4, 0xce, 0x4f, 0xff, 0x6e, 0xdc, 0xfc,
		0xf5, 0xd7, 0xab, 0x47, 0xde, 0xa0, 0x8e, 0x66, 0x4d, 0xb0, 0x8e, 0x06, 0xf1, 0xd3, 0x5c, 0xd5,
		0x8a, 0x66, 0xa5, 0xae, 0xf0, 0x33, 0xe3, 0x78, 0x98, 0xe5, 0xd7, 0x02, 0x55, 0x7a, 0x93, 0x5f,
		0xda, 0xff, 0xa4, 0x2e, 0x83, 0xd1, 0xec, 0x12, 0xe0, 0xfa, 0x70, 0xa4, 0xe2, 0xfe, 0xb4, 0x76,
		0xa8, 0xc5, 0x2a, 0xfb, 0x32, 0x4c, 0x3e, 0xd7, 0x6e, 0xef, 0xaf, 0xa8, 0x7f, 0xff, 0x46, 0xfa,
		0xe0, 0x9d, 0xfa, 0x28, 0x19, 0x66, 0xc3, 0xfe, 0x30, 0x4a, 0x8b, 0xef, 0xea, 0x13, 0x42, 0x54,
		0x8f, 0xd4, 0x95, 0x8a, 0x66, 0x5f, 0xea, 0x51, 0x18, 0x7f, 0xae, 0x4d, 0xef, 0x9c, 0xad, 0x0d,
		0x82, 0x2c, 0x38, 0x0b, 0x52, 0x55, 0x8f, 0xd2, 0x51, 0x3d, 0x8b, 0xae, 0xd2, 0xc9, 0x7f, 0xea,
		0x53, 0x09, 0x6f, 0x9a, 0x44, 0x17, 0xe9, 0xdd, 0xb7, 0xf9, 0xe5, 0xc4, 0x2b, 0x73, 0x19, 0xf1,
		0x6f, 0x1a, 0xfb, 0xc0, 0xa4, 0xc8, 0xa8, 0xfe, 0x62, 0x94, 0x6a, 0xbb, 0x81, 0xd5, 0x77, 0xff,
		0x44, 0x76, 0xfb, 0xaa, 0xed, 0xee, 0x95, 0xed, 0x07, 0x15, 0xe7, 0x00, 0x98, 0xd8, 0x6f, 0x54,
		0x72, 0x35, 0x7b, 0x32, 0xee, 0x67, 0xf1, 0xac, 0x7e, 0x6b, 0xe7, 0x0f, 0x6b, 0xcf, 0x9e, 0xd5,
		0xef, 0xce, 0x9e, 0xd0, 0xb7, 0xd3, 0x30, 0xf5, 0x9d, 0xc9, 0xa3, 0xf9, 0x4e, 0x3a, 0xf2, 0xbd,
		0xe8, 0xca, 0xb7, 0x47, 0x57, 0xcd, 0xde, 0xc4, 0xea, 0xdf, 0xf4, 0xcc, 0x18, 0xe5, 0xfc, 0xa6,
		0x92, 0x7c, 0xb1, 0x2a, 0x1f, 0x14, 0xee, 0x7b, 0xe5, 0x60, 0x77, 0xf9, 0x48, 0x2a, 0x01, 0x45,
		0xf9, 0x81, 0x33, 0x99, 0xaa, 0x25, 0xc3, 0x71, 0xa6, 0x92, 0x32, 0x77, 0x45, 0xbe, 0x3d, 0xf3,
		0xe6, 0x1b, 0x13, 0x4a, 0xf2, 0x9e, 0xdb, 0x56, 0x52, 0x49, 0xbf, 0xae, 0xec, 0x5d, 0x8d, 0x2a,
		0x76, 0x2f, 0x2a, 0xdc, 0xa5, 0xa8, 0x6a, 0x37, 0xa2, 0xf2, 0x5d, 0x87, 0xca, 0x77, 0x17, 0xaa,
		0xdd, 0x45, 0xd0, 0x2b, 0xa3, 0xb7, 0xc2, 0xa4, 0xe4, 0x54, 0x3e, 0xed, 0x4c, 0x94, 0xee, 0x34,
		0xc5, 0xde, 0xc2, 0xf4, 0xd7, 0x97, 0x5d, 0xc2, 0x97, 0x1a, 0xf8, 0x2b, 0x4b, 0x00, 0x55, 0x26,
		0x02, 0x01, 0x09, 0xa1, 0xea, 0xc4, 0x20, 0x26, 0x41, 0x88, 0x49, 0x14, 0x32, 0x12, 0x46, 0xf9,
		0x45, 0x67, 0x15, 0xed, 0x99, 0xb2, 0x13, 0x49, 0xf1, 0x8b, 0xcb, 0xaf, 0x24, 0xe6, 0xc6, 0x9c,
		0xb2, 0x2b, 0x8a, 0x79, 0x89, 0xa6, 0xa2, 0x31, 0xa6, 0xca, 0xe7, 0xa8, 0x24, 0xcc, 0x4f, 0x09,
		0x9a, 0x9b, 0x92, 0x32, 0x2f, 0x25, 0x6e, 0x4e, 0x4a, 0xdc, 0x7c, 0x94, 0xac, 0xb9, 0xa8, 0xd5,
		0xda, 0x5b, 0xae, 0x7c, 0xfe, 0x49, 0xda, 0x61, 0xcc, 0x12, 0x46, 0x9e, 0xc4, 0x8c, 0x3a, 0xf1,
		0x70, 0xd9, 0x95, 0x3c, 0x5c, 0xf6, 0xb4, 0x4a, 0xe8, 0x4b, 0x1a, 0x0e, 0x23, 0xfe, 0x57, 0x13,
		0xff, 0x2b, 0x45, 0x01, 0x44, 0x48, 0xdd, 0xe4, 0x48, 0xdc, 0x44, 0x4b, 0xdb, 0x64, 0x48, 0xda,
		0x38, 0xe4, 0xb6, 0xe0, 0xfa, 0x87, 0xc3, 0x3d, 0x3f, 0x1e, 0x30, 0xb8, 0xbf, 0x4f, 0x5d, 0xc5,
		0x54, 0x27, 0x27, 0x65, 0xa0, 0x00, 0x8d, 0x01, 0xe4, 0x32, 0x77, 0xe9, 0x5f, 0x36, 0x9a, 0xe6,
		0x29, 0x77, 0x6a, 0xb4, 0x3d, 0xe0, 0x90, 0xcf, 0xaf, 0xaf, 0x79, 0x98, 0xd6, 0x82, 0x28, 0x0c,
		0xd2, 0x6a, 0xc6, 0x7b, 0xee, 0xfd, 0x72, 0x0e, 0xf6, 0x2c, 0xa6, 0x22, 0xe5, 0x60, 0x4f, 0x29,
		0x30, 0xe2, 0x60, 0x0f, 0x07, 0x7b, 0x16, 0xb5, 0x94, 0x1c, 0xec, 0xd1, 0x2e, 0xf0, 0x3f, 0x4c,
		0x00, 0x9b, 0x1c, 0xec, 0x29, 0xd3, 0x04, 0x0e, 0xf6, 0x08, 0x49, 0x14, 0x32, 0x12, 0xc6, 0x6a,
		0xb4, 0x66, 0x2a, 0x1b, 0xec, 0x29, 0xbd, 0x84, 0x98, 0x1b, 0x72, 0x4a, 0xae, 0x27, 0xe6, 0xa5,
		0x19, 0x8e, 0xf5, 0x70, 0xac, 0x87, 0x63, 0x3d, 0x00, 0x69, 0x49, 0x56, 0x7a, 0xaa, 0x26, 0x4d,
		0x55, 0x94, 0xae, 0x8a, 0xa5, 0x97, 0x33, 0xd6, 0x23, 0xe1, 0x38, 0x23, 0xce, 0xf4, 0xdc, 0x37,
		0x04, 0xe9, 0xa0, 0x1b, 0x4e, 0xa2, 0x40, 0x7e, 0x6a, 0xdc, 0x95, 0xd6, 0xa0, 0xf4, 0xe1, 0xae,
		0xf4, 0x0f, 0x36, 0xf3, 0xee, 0xb6, 0x57, 0xb8, 0x1f, 0x0d, 0x03, 0x69, 0xee, 0x47, 0xff, 0x18,
		0xc2, 0x20, 0x3b, 0xd1, 0xa9, 0x39, 0xb1, 0x97, 0x9b, 0xd0, 0x4f, 0x59, 0xee, 0x30, 0xad, 0x25,
		0x2a, 0xe8, 0x7f, 0x0a, 0xce, 0xc2, 0x28, 0xcc, 0xae, 0x2b, 0xd9, 0x88, 0xfe, 0xc6, 0x00, 0x6e,
		0x46, 0xa3, 0x36, 0x83, 0xb8, 0x19, 0xcd, 0xcd, 0x68, 0x6e, 0x46, 0xbf, 0x60, 0x29, 0x4b, 0xdf,
		0x8c, 0x8e, 0x55, 0x78, 0xf1, 0xe9, 0x6c, 0x98, 0xa4, 0xd5, 0x6d, 0x48, 0xdf, 0x99, 0xc0, 0xd3,
		0x26, 0x74, 0x4b, 0x08, 0x02, 0x12, 0x43, 0xd5, 0x09, 0x42, 0x4c, 0xa2, 0x10, 0x93, 0x30, 0x64,
		0x24, 0x8e, 0xd5, 0xe8, 0xcc, 0x54, 0xb6, 0x29, 0x7d, 0x1b, 0xd5, 0xab, 0xdf, 0x94, 0x2e, 0x2c,
		0xa9, 0x76, 0x53, 0x7a, 0x83, 0x9b, 0xd2, 0xdc, 0x94, 0xe6, 0xa6, 0xb4, 0xfc, 0xb4, 0x24, 0x2b,
		0x3d, 0x55, 0x93, 0xa6, 0x2a, 0x4a, 0x57, 0x95, 0xa7, 0xad, 0xc2, 0x80, 0x81, 0x3a, 0x0f, 0xc6,
		0x51, 0x56, 0xbb, 0x54, 0x59, 0x12, 0xf6, 0xe5, 0xdc, 0x48, 0xf7, 0x9d, 0x5d, 0x32, 0xae, 0xa5,
		0xdb, 0xe0, 0xb5, 0x74, 0x62, 0x52, 0x9d, 0xc0, 0x94, 0x27, 0x2d, 0xf5, 0x89, 0x4d, 0x81, 0x62,
		0x53, 0xa1, 0xcc, 0x94, 0x58, 0x6d, 0x6a, 0xac, 0x38, 0x45, 0x8a, 0x49, 0x95, 0x85, 0x21, 0xd5,
		0xe8, 0x5a, 0x1e, 0x8d, 0x7f, 0x55, 0xe8, 0x5d, 0x84, 0x27, 0x4c, 0x71, 0x89, 0x53, 0x62, 0x02,
		0x15, 0x9c, 0x48, 0xa5, 0x26, 0x54, 0xf1, 0x89, 0x55, 0x7c, 0x82, 0x95, 0x9d, 0x68, 0x65, 0x24,
		0x5c, 0x21, 0x89, 0x57, 0x5c, 0x02, 0x2e, 0x0c, 0x3a, 0x8f, 0x82, 0x8b, 0x54, 0x5e, 0x50, 0xb8,
		0x8d, 0xa3, 0xb9, 0x79, 0xc2, 0xfc, 0x4d, 0xc6, 0x05, 0xeb, 0xe2, 0x13, 0xb4, 0xe4, 0x44, 0x0d,
		0x90, 0xb0, 0xa5, 0x27, 0x6e, 0x98, 0x04, 0x0e, 0x93, 0xc8, 0x31, 0x12, 0xba, 0xac, 0xc4, 0x2e,
		0x2c, 0xc1, 0x17, 0x1f, 0xa1, 0x98, 0x0b, 0xe0, 0xe7, 0x46, 0x3c, 0x15, 0x8f, 0x2f, 0x55, 0x92,
		0x4f, 0x2f, 0x0b, 0x8c, 0x7a, 0xb7, 0xd5, 0x6f, 0x43, 0xa0, 0x6d, 0x56, 0x3c, 0xbe, 0x9c, 0x7c,
		0xb8, 0xc2, 0x5c, 0xe0, 0x37, 0x3a, 0xe3, 0xc3, 0xcf, 0x4a, 0xc8, 0xa6, 0xcc, 0x5c, 0x37, 0x14,
		0xb1, 0x39, 0x43, 0x8a, 0x4b, 0x8a, 0x4b, 0x8a, 0x4b, 0x8a, 0x4b, 0x8a, 0x4b, 0x8a, 0xab, 0x11,
		0xc5, 0x8d, 0x83, 0x24, 0x19, 0x7e, 0xa9, 0x89, 0x4c, 0xb1, 0xf7, 0xd3, 0xec, 0x96, 0x40, 0xd3,
		0xdc, 0x20, 0xbe, 0x50, 0x95, 0xeb, 0xd3, 0xe7, 0xbd, 0x64, 0xe6, 0x89, 0xb5, 0xd9, 0x89, 0xf3,
		0x62, 0x13, 0x99, 0x70, 0x7e, 0xf7, 0xc0, 0xcc, 0x93, 0x20, 0x1a, 0x2b, 0x39, 0x7b, 0xa0, 0x73,
		0xed, 0x3c, 0x48, 0x82, 0xfe, 0xa4, 0x90, 0x6e, 0x85, 0x17, 0x61, 0x7e, 0xd1, 0x80, 0x58, 0x7b,
		0x6f, 0xfe, 0x14, 0xec, 0x3a, 0xc1, 0x57, 0xba, 0xce, 0x82, 0x5d, 0xa7, 0xf9, 0x9a, 0xbe, 0xa3,
		0x27, 0x1f, 0x94, 0x6b, 0xd5, 0x29, 0xfb, 0x62, 0x82, 0x2d, 0x91, 0xb2, 0x17, 0x5e, 0xf1, 0x41,
		0x30, 0x73, 0xed, 0x12, 0x7a, 0xba, 0xc6, 0xfd, 0x63, 0x0f, 0xea, 0x85, 0x0e, 0xb6, 0xf8, 0xae,
		0xfe, 0xed, 0xb4, 0x77, 0x15, 0xc7, 0xc8, 0xc8, 0x85, 0xfd, 0x6a, 0x4f, 0x7d, 0x0a, 0x73, 0x34,
		0x3d, 0x1c, 0x4c, 0xc2, 0x8c, 0xfc, 0x4b, 0x0e, 0xbf, 0x71, 0xef, 0x3d, 0xad, 0xdf, 0x9e, 0x3d,
		0xa3, 0xdf, 0xca, 0x9f, 0xf1, 0x28, 0x7f, 0xc4, 0xdf, 0x56, 0xd3, 0x67, 0x2b, 0xf4, 0x57, 0x63,
		0xa0, 0xa2, 0xe0, 0x5a, 0xa0, 0x92, 0xe8, 0x9e, 0x55, 0xd4, 0x11, 0x51, 0x47, 0xf4, 0x08, 0x5e,
		0xa8, 0x23, 0x9a, 0x0f, 0x5f, 0xea, 0x88, 0x9e, 0x4a, 0x5f, 0xa8, 0x23, 0x92, 0xc6, 0x28, 0xa9,
		0x23, 0xfa, 0x79, 0xfc, 0xa3, 0x8e, 0x48, 0x7e, 0xe2, 0x94, 0x98, 0x40, 0x05, 0x27, 0x52, 0xa9,
		0x09, 0x55, 0x7c, 0x62, 0x15, 0x9f, 0x60, 0x65, 0x27, 0x5a, 0x39, 0x4d, 0xa4, 0x35, 0xea, 0x88,
		0xe6, 0x1b, 0x44, 0x1d, 0xd1, 0xb3, 0x13, 0x33, 0x87, 0x2c, 0x71, 0x13, 0x35, 0x40, 0xc2, 0x96,
		0x9e, 0xb8, 0x61, 0x12, 0x38, 0x4c, 0x22, 0xc7, 0x48, 0xe8, 0xb2, 0x12, 0xbb, 0xb0, 0x04, 0x5f,
		0x7c, 0x84, 0xf2, 0x87, 0x2c, 0x27, 0xa8, 0x9a, 0xb5, 0x86, 0x6b, 0x12, 0xd3, 0xec, 0x1a, 0xd5,
		0x44, 0x3a, 0x38, 0x82, 0x13, 0xa6, 0x99, 0x99, 0x65, 0x89, 0x4c, 0x67, 0x38, 0x0a, 0x63, 0x2b,
		0x52, 0x93, 0x58, 0x9b, 0xca, 0x9c, 0x0d, 0x33, 0x8e, 0x82, 0xaf, 0xf7, 0x2c, 0xdc, 0x78, 0xd3,
		0x68, 0x34, 0xb7, 0x1b, 0x8d, 0xf5, 0xed, 0xd7, 0xdb, 0xeb, 0x3b, 0x5b, 0x5b, 0x1b, 0xcd, 0x0d,
		0x89, 0x43, 0xc8, 0x9d, 0x64, 0xa0, 0x12, 0x35, 0xd8, 0xbb, 0x36, 0x76, 0xd7, 0xe2, 0x71, 0x14,
		0x71, 0xae, 0x48, 0xba, 0xaf, 0x52, 0x6f, 0xc7, 0x52, 0x90, 0xa5, 0x20, 0x4b, 0x41, 0x96, 0x82,
		0x2c, 0x05, 0x59, 0x0a, 0xae, 0x58, 0x29, 0x48, 0xbd, 0xdd, 0xf3, 0x4d, 0xa3, 0xde, 0xee, 0xf9,
		0xa5, 0x17, 0x45, 0x43, 0x0b, 0x32, 0x93, 0x7a, 0x3b, 0xdd, 0xb3, 0xc8, 0xf7, 0x3d, 0x01, 0xba,
		0xce, 0x82, 0x5d, 0x87, 0x7a, 0x3b, 0x5d, 0xf9, 0xa0, 0x5c, 0xab, 0xa8, 0xb7, 0x93, 0x6c, 0x09,
		0xf5, 0x76, 0x3f, 0xb7, 0x0b, 0x56, 0x0e, 0x74, 0xa7, 0x89, 0xa0, 0xda, 0x4e, 0x8e, 0x05, 0x54,
		0xdb, 0x69, 0xe7, 0x5e, 0xba, 0x6a, 0xed, 0xa2, 0xe0, 0x9a, 0x4a, 0xbb, 0xaa, 0x3e, 0x50, 0x95,
		0x24, 0xc3, 0x44, 0x9c, 0xd2, 0xee, 0x1b, 0xab, 0xa8, 0xb4, 0xa3, 0xd2, 0xee, 0x11, 0xbc, 0x50,
		0x69, 0x37, 0x1f, 0xbe, 0x54, 0xda, 0x3d, 0x95, 0xba, 0x50, 0x69, 0x27, 0x8d, 0x4d, 0x52, 0x69,
		0xf7, 0xf3, 0xf8, 0x47, 0xa5, 0x9d, 0xfc, 0xc4, 0x29, 0x31, 0x81, 0x0a, 0x4e, 0xa4, 0x52, 0x13,
		0xaa, 0xf8, 0xc4, 0x2a, 0x3e, 0xc1, 0xca, 0x4e, 0xb4, 0x72, 0x1a, 0x48, 0x6b, 0x54, 0xda, 0xcd,
		0x37, 0x88, 0x4a, 0xbb, 0x67, 0x27, 0x66, 0x8e, 0x57, 0xe2, 0x26, 0x6a, 0x80, 0x84, 0x2d, 0x3d,
		0x71, 0xc3, 0x24, 0x70, 0x98, 0x44, 0x8e, 0x91, 0xd0, 0x65, 0x25, 0x76, 0x61, 0x09, 0xbe, 0xf8,
		0x08, 0xa9, 0xb4, 0x5b, 0x68, 0x0d, 0x4c, 0xa5, 0x1d, 0xaa, 0x23, 0x50, 0x69, 0xf7, 0x42, 0x0b,
		0xa9, 0xb4, 0xd3, 0x36, 0x71, 0x51, 0x69, 0xf7, 0xeb, 0xe9, 0x8a, 0x4a, 0x3b, 0x96, 0x82, 0x2c,
		0x05, 0x59, 0x0a, 0xb2, 0x14, 0x64, 0x29, 0xc8, 0x52, 0x70, 0xb1, 0x11, 0x8f, 0x4a, 0xbb, 0xe7,
		0x9b, 0x46, 0xa5, 0xdd, 0xf3, 0x4b, 0x2f, 0xca, 0x85, 0x16, 0x64, 0x26, 0x95, 0x76, 0xba, 0x67,
		0x91, 0xef, 0x7b, 0x02, 0x74, 0x9d, 0x05, 0xbb, 0x0e, 0x95, 0x76, 0xba, 0xf2, 0x41, 0xb9, 0x56,
		0x51, 0x69, 0x27, 0xd9, 0x12, 0x2a, 0xed, 0x7e, 0x6e, 0x17, 0xa8, 0x14, 0xe8, 0xbe, 0x26, 0x82,
		0x4a, 0x3b, 0x39, 0x16, 0x50, 0x69, 0xa7, 0x9d, 0x7b, 0xe9, 0xa9, 0xb4, 0xb3, 0x26, 0x4f, 0x48,
		0xa5, 0x5d, 0x55, 0x1f, 0xa8, 0xfa, 0x3a, 0x52, 0x71, 0xaa, 0xe4, 0x69, 0xed, 0xbe, 0xb5, 0x8b,
		0x6a, 0x3b, 0xaa, 0xed, 0x1e, 0x41, 0x0c, 0xd5, 0x76, 0xf3, 0xe1, 0x4b, 0xb5, 0xdd, 0x53, 0xe9,
		0x0b, 0xd5, 0x76, 0xd2, 0x18, 0x25, 0xd5, 0x76, 0x3f, 0x8f, 0x7f, 0x54, 0xdb, 0xc9, 0x4f, 0x9c,
		0x12, 0x13, 0xa8, 0xe0, 0x44, 0x2a, 0x35, 0xa1, 0x8a, 0x4f, 0xac, 0xe2, 0x13, 0xac, 0xec, 0x44,
		0x2b, 0xa7, 0x89, 0xb4, 0x46, 0xb5, 0xdd, 0x7c, 0x83, 0xa8, 0xb6, 0x7b, 0x76, 0x62, 0xe6, 0x88,
		0x25, 0x6e, 0xa2, 0x06, 0x48, 0xd8, 0xd2, 0x13, 0x37, 0x4c, 0x02, 0x87, 0x49, 0xe4, 0x18, 0x09,
		0x5d, 0x56, 0x62, 0x17, 0x96, 0xe0, 0x8b, 0x8f, 0x90, 0x6a, 0xbb, 0x85, 0xd6, 0xc0, 0x54, 0xdb,
		0xa1, 0x3a, 0x02, 0xd5, 0x76, 0x2f, 0xb4, 0x90, 0x6a, 0x3b, 0x6d, 0x13, 0x17, 0xd5, 0x76, 0xbf,
		0x9e, 0xae, 0xa8, 0xb6, 0x63, 0x29, 0xc8, 0x52, 0x90, 0xa5, 0x20, 0x4b, 0x41, 0x96, 0x82, 0x2c,
		0x05, 0x17, 0x1b, 0xf1, 0xa8, 0xb6, 0x7b, 0xbe, 0x69, 0x54, 0xdb, 0x3d, 0xbf, 0xf4, 0xa2, 0x64,
		0x68, 0x41, 0x66, 0x52, 0x6d, 0xa7, 0x7b, 0x16, 0xf9, 0xbe, 0x27, 0x40, 0xd7, 0x59, 0xb0, 0xeb,
		0x50, 0x6d, 0xa7, 0x2b, 0x1f, 0x94, 0x6b, 0x15, 0xd5, 0x76, 0x92, 0x2d, 0xa1, 0xda, 0xee, 0xe7,
		0x76, 0xa1, 0xca, 0x81, 0xbe, 0x51, 0x45, 0x50, 0x6f, 0x27, 0xc7, 0x02, 0xea, 0xed, 0x34, 0x74,
		0x30, 0x4d, 0x15, 0x77, 0xf9, 0x33, 0x52, 0x73, 0x57, 0xdd, 0x47, 0x2a, 0x41, 0x40, 0x20, 0x4a,
		0x38, 0x40, 0x85, 0xdd, 0x77, 0x86, 0x50, 0x61, 0xf7, 0x53, 0x93, 0xa8, 0xb0, 0xfb, 0x45, 0xc3,
		0xa8, 0xb0, 0x23, 0x87, 0xfc, 0xd5, 0x8f, 0x44, 0x8e, 0xc2, 0xee, 0x3a, 0xcd, 0xd4, 0x65, 0x2d,
		0x1c, 0x08, 0x54, 0xd9, 0x15, 0xa6, 0xc9, 0x52, 0xda, 0xad, 0x53, 0x69, 0x27, 0x3e, 0x91, 0x0a,
		0x4e, 0xa8, 0x52, 0x13, 0xab, 0xf8, 0x04, 0x2b, 0x3e, 0xd1, 0xca, 0x4e, 0xb8, 0x72, 0xda, 0x47,
		0x6b, 0x82, 0xba, 0xa6, 0xe2, 0xa6, 0x2e, 0xc4, 0xa6, 0xbf, 0x6f, 0x6a, 0xc7, 0x37, 0x82, 0x6c,
		0xea, 0x06, 0x59, 0xa6, 0x92, 0x58, 0xdc, 0x70, 0x85, 0xf1, 0xbf, 0x8f, 0xeb, 0xb5, 0x1d, 0xb3,
		0x76, 0x10, 0xd4, 0xce, 0x4f, 0xff, 0x6e, 0xdc, 0xfc, 0xf5, 0xd7, 0xab, 0x47, 0xde, 0xf8, 0x97,
		0x9c, 0x28, 0x71, 0x2a, 0xe9, 0x03, 0xee, 0xf4, 0xec, 0xf7, 0xfc, 0x94, 0x97, 0xf1, 0x29, 0x73,
		0x43, 0x83, 0xc5, 0x28, 0x37, 0x34, 0x16, 0xb3, 0xa1, 0x21, 0x60, 0x8b, 0x70, 0x45, 0x9b, 0xfc,
		0x62, 0x7a, 0x18, 0xe2, 0xc8, 0x9b, 0x90, 0x9e, 0x05, 0x9b, 0xfd, 0x18, 0xbd, 0x09, 0x36, 0xfb,
		0xd1, 0x7b, 0x10, 0x6c, 0xf6, 0xcb, 0xe3, 0x57, 0x62, 0x7a, 0x0c, 0x45, 0xc4, 0x89, 0x54, 0x70,
		0x9e, 0xa8, 0x73, 0x09, 0x11, 0xe7, 0xb6, 0xa3, 0xb0, 0x2d, 0xc0, 0x96, 0xee, 0x8c, 0x72, 0xbe,
		0x7a, 0x95, 0x93, 0xb9, 0xfa, 0x5d, 0x1a, 0x5f, 0x55, 0x5a, 0xf7, 0xdb, 0x0a, 0x39, 0xec, 0x24,
		0xdb, 0x48, 0x20, 0x6f, 0x32, 0x0e, 0x43, 0x90, 0x73, 0xe8, 0x81, 0xe8, 0xc3, 0x0d, 0x64, 0x1c,
		0x62, 0x50, 0x95, 0xc7, 0x08, 0x69, 0x1d, 0x80, 0xb6, 0x0c, 0x8c, 0x4a, 0x27, 0xe3, 0x16, 0x3c,
		0xec, 0x58, 0x4d, 0x8a, 0x2c, 0x3f, 0x41, 0x95, 0xfb, 0x1b, 0x4b, 0x76, 0xec, 0xaa, 0x1d, 0x1a,
		0xcb, 0x91, 0xcb, 0x85, 0x7c, 0x79, 0xc0, 0x2b, 0xe7, 0x37, 0x95, 0x04, 0xed, 0xaa, 0x20, 0x8d,
		0x00, 0xe5, 0x12, 0x13, 0xd0, 0xc2, 0x12, 0x4e, 0x39, 0x4e, 0xb7, 0x7c, 0x17, 0x28, 0x01, 0xfe,
		0xf9, 0xe1, 0x7d, 0xb7, 0xe1, 0xaa, 0x16, 0x64, 0x59, 0x12, 0x9e, 0x8d, 0x4b, 0x1c, 0x88, 0xff,
		0xf6, 0x14, 0xc1, 0x1f, 0x18, 0x52, 0x52, 0x08, 0x28, 0x77, 0xe4, 0xbd, 0xf4, 0x6e, 0x77, 0x15,
		0x5d, 0xed, 0x0a, 0xbb, 0xd7, 0x55, 0x75, 0xa9, 0x2b, 0xef, 0x46, 0x57, 0xde, 0x75, 0xae, 0xb6,
		0xbb, 0xac, 0x17, 0x2d, 0x29, 0x7b, 0x04, 0xdc, 0xb8, 0xa3, 0xad, 0xa5, 0x3b, 0x4e, 0x71, 0x82,
		0x50, 0x61, 0x42, 0xc9, 0xb8, 0xad, 0x46, 0xf3, 0x54, 0xd9, 0xb6, 0x67, 0x95, 0xdb, 0x9c, 0x02,
		0xb6, 0x35, 0xab, 0xde, 0xc6, 0x14, 0xb3, 0x6d, 0x29, 0x66, 0x9b, 0x52, 0xc6, 0xb6, 0xa4, 0xde,
		0xad, 0x9b, 0xaa, 0x34, 0x45, 0x45, 0x54, 0xaf, 0xce, 0xdf, 0xbe, 0xcf, 0x2f, 0x55, 0xb9, 0x5b,
		0xb5, 0xd2, 0xda, 0xca, 0xa7, 0x6c, 0x24, 0x4c, 0xd7, 0x08, 0x9a, 0xaa, 0x91, 0x32, 0x4d, 0x23,
		0x6e, 0x8a, 0x46, 0xdc, 0xf4, 0x8c, 0xac, 0xa9, 0x99, 0xd5, 0xda, 0x74, 0xaf, 0x5a, 0x0a, 0x6b,
		0x14, 0x4d, 0x57, 0x39, 0xe3, 0xa3, 0x77, 0x26, 0xf1, 0xac, 0x08, 0x8e, 0x8f, 0x8a, 0x4f, 0x74,
		0xd2, 0x12, 0x9e, 0xd8, 0xc4, 0x27, 0x36, 0x01, 0xca, 0x4c, 0x84, 0xd5, 0x26, 0xc4, 0x8a, 0x13,
		0xa3, 0x98, 0x04, 0xf9, 0x20, 0x51, 0xca, 0x3b, 0x2a, 0xa2, 0xb0, 0x8c, 0x77, 0x32, 0x4b, 0x4e,
		0x9f, 0x12, 0xd3, 0xa8, 0xe0, 0x74, 0x2a, 0x35, 0xad, 0x8a, 0x4f, 0xaf, 0xe2, 0xd3, 0xac, 0xec,
		0x74, 0x2b, 0x23, 0xed, 0x0a, 0x49, 0xbf, 0xe2, 0xd2, 0xf0, 0x5d, 0x3a, 0x1e, 0xc8, 0xbd, 0x86,
		0x4b, 0xd4, 0xa9, 0x15, 0x6b, 0xbc, 0x82, 0x4b, 0x8b, 0x14, 0x0d, 0x90, 0xaa, 0xa5, 0xa7, 0x6c,
		0x98, 0xd4, 0x0d, 0x93, 0xc2, 0x31, 0x52, 0xb9, 0xac, 0x94, 0x2e, 0x2c, 0xb5, 0x17, 0x1f, 0xa1,
		0xfc, 0x2b, 0xb8, 0xe4, 0x08, 0x37, 0xe7, 0xd6, 0xbc, 0xdb, 0x02, 0x6d, 0x7b, 0x20, 0xec, 0xac,
		0x5a, 0xd1, 0x29, 0xd7, 0x2f, 0x25, 0x5d, 0x36, 0x2b, 0xe3, 0xf4, 0xee, 0xb9, 0xce, 0x28, 0xe1,
		0x34, 0xef, 0xb9, 0x6e, 0x48, 0x9e, 0x4b, 0x9e, 0x4b, 0x9e, 0x4b, 0x9e, 0x4b, 0x9e, 0xcb, 0x9c,
		0xfa, 0xfd, 0x47, 0x28, 0xad, 0x95, 0x55, 0x18, 0x26, 0xb0, 0xa5, 0xf5, 0x20, 0x18, 0x8b, 0x6b,
		0x6d, 0x7d, 0x9f, 0xfa, 0x85, 0x5e, 0xa5, 0x28, 0x96, 0x02, 0x20, 0x50, 0x01, 0x20, 0x4a, 0x80,
		0x42, 0x0d, 0xe0, 0x28, 0x02, 0x1c, 0x55, 0xc0, 0xa2, 0x0c, 0x32, 0xa9, 0x83, 0x50, 0x0a, 0x51,
		0x7c, 0xb4, 0x62, 0x5b, 0x66, 0x0f, 0x22, 0xe6, 0x38, 0x8c, 0xb3, 0x66, 0x43, 0x72, 0xc0, 0x9c,
		0xe5, 0xef, 0x37, 0x82, 0x4d, 0x94, 0x7d, 0x8d, 0xfd, 0xed, 0x4b, 0x76, 0xc2, 0x59, 0x43, 0xb9,
		0xd6, 0x1e, 0x84, 0x58, 0x3e, 0x30, 0xf7, 0xf6, 0xae, 0x6e, 0x14, 0x7b, 0x81, 0xae, 0xec, 0x16,
		0x9e, 0x8e, 0xbe, 0x75, 0x31, 0x80, 0xeb, 0xef, 0xd1, 0x5d, 0x4c, 0xd6, 0x59, 0x7c, 0xda, 0x7b,
		0xdd, 0x6f, 0xb4, 0xee, 0x39, 0xaf, 0xd3, 0xdf, 0xb8, 0x5e, 0xa0, 0x51, 0xdd, 0x98, 0x5d, 0x0f,
		0x2d, 0xbe, 0x2d, 0x28, 0xe6, 0x1a, 0x6b, 0xc0, 0xf4, 0xc2, 0xd6, 0xe0, 0x22, 0x91, 0xc8, 0xd6,
		0xe0, 0xe2, 0xdc, 0x86, 0xad, 0xc1, 0x25, 0x1b, 0xcc, 0xd6, 0xa0, 0xae, 0xb5, 0x18, 0x50, 0x6b,
		0xf0, 0x4b, 0x38, 0x50, 0x35, 0xd1, 0x09, 0xfc, 0x7e, 0x12, 0xdf, 0x66, 0x7f, 0xf0, 0x85, 0x2f,
		0xf6, 0x07, 0xd9, 0xbc, 0x90, 0x37, 0x23, 0xa7, 0x55, 0xa7, 0x82, 0xfd, 0x41, 0xba, 0xd8, 0xc4,
		0xc5, 0x9a, 0xdb, 0xdb, 0xdb, 0x9b, 0xec, 0x09, 0xae, 0x1a, 0x27, 0x95, 0x6f, 0x1d, 0x7b, 0x82,
		0x88, 0x16, 0x49, 0x9b, 0xa4, 0x14, 0x76, 0x75, 0xee, 0x03, 0xfb, 0x64, 0xde, 0x41, 0xf0, 0xc3,
		0xb3, 0xe0, 0x7f, 0x74, 0xa5, 0xee, 0x9d, 0x2d, 0x85, 0x0d, 0x02, 0x6e, 0xd9, 0x95, 0xeb, 0x22,
		0xa2, 0xc4, 0x3b, 0xe3, 0xb3, 0xc9, 0x47, 0x2e, 0x58, 0xbe, 0x33, 0x33, 0x90, 0x02, 0x9e, 0x5f,
		0x31, 0x8b, 0x02, 0x9e, 0x17, 0x40, 0x8d, 0x02, 0x9e, 0xe7, 0xbb, 0x03, 0x05, 0x3c, 0x8b, 0xe6,
		0x2c, 0x14, 0xf0, 0xa0, 0xd3, 0x4e, 0xb1, 0x02, 0x9e, 0x3c, 0xa7, 0xca, 0xdf, 0xad, 0x9f, 0xd9,
		0x29, 0x7b, 0xb7, 0x7e, 0x83, 0xbb, 0xf5, 0xda, 0x51, 0x02, 0x20, 0x6a, 0x80, 0x42, 0x11, 0xe0,
		0xa8, 0x02, 0x1c, 0x65, 0xc0, 0xa2, 0x0e, 0x32, 0x29, 0x84, 0x50, 0x2a, 0x21, 0x9e, 0x52, 0x14,
		0x06, 0x06, 0x83, 0xff, 0x17, 0xf4, 0x55, 0xdc, 0xbf, 0xae, 0xa5, 0xe1, 0x20, 0x95, 0x1f, 0x8d,
		0x6e, 0x03, 0xfc, 0x77, 0x76, 0x0b, 0xf7, 0x70, 0xd9, 0xd4, 0x03, 0x86, 0x82, 0x20, 0x51, 0x11,
		0x40, 0x4a, 0x82, 0x46, 0x4d, 0x60, 0x29, 0x0a, 0x2c, 0x55, 0xc1, 0xa4, 0x2c, 0xb2, 0xa9, 0x8b,
		0x70, 0x0a, 0x03, 0x43, 0x65, 0x7e, 0x4c, 0x69, 0x70, 0x82, 0xd8, 0x0f, 0x99, 0x0d, 0x4a, 0x20,
		0xc3, 0x20, 0x38, 0x70, 0x44, 0x07, 0x91, 0xf0, 0x00, 0x13, 0x1f, 0x54, 0x02, 0x04, 0x4f, 0x84,
		0xe0, 0x09, 0x11, 0x36, 0x31, 0xc2, 0x20, 0x48, 0x20, 0x44, 0x09, 0x8e, 0x30, 0x15, 0x06, 0xcb,
		0x3c, 0x18, 0xf6, 0x97, 0xf3, 0x8c, 0xc4, 0x83, 0x63, 0x35, 0x23, 0x4e, 0xb0, 0x04, 0x0a, 0x99,
		0x48, 0x69, 0x40, 0xa8, 0xd0, 0x89, 0x95, 0x36, 0x04, 0x4b, 0x1b, 0xa2, 0xa5, 0x07, 0xe1, 0xc2,
		0x22, 0x5e, 0x60, 0x04, 0x0c, 0x96, 0x88, 0x15, 0x86, 0x9f, 0x47, 0xc1, 0x45, 0x8a, 0x1b, 0x2c,
		0x6f, 0xf3, 0x55, 0xfe, 0x18, 0xa0, 0xf1, 0x05, 0x4b, 0x22, 0xa6, 0x0d, 0x51, 0xd3, 0x81, 0xb0,
		0x69, 0x44, 0xdc, 0x74, 0x21, 0x70, 0xda, 0x11, 0x39, 0xed, 0x08, 0x9d, 0x5e, 0xc4, 0x0e, 0x93,
		0xe0, 0x81, 0x12, 0xbd, 0x02, 0x3a, 0xe2, 0xcf, 0x48, 0xf9, 0xe5, 0x8c, 0xa1, 0xe2, 0xf1, 0xa5,
		0x4a, 0x72, 0x29, 0x24, 0x70, 0xd6, 0xb8, 0xed, 0x72, 0x35, 0x80, 0x9f, 0xc1, 0x8a, 0xc7, 0x97,
		0x13, 0x50, 0xd1, 0x95, 0xcb, 0x5c, 0x75, 0x27, 0x4c, 0x33, 0x33, 0xcb, 0x12, 0x6c, 0x77, 0x3e,
		0x0a, 0x63, 0x2b, 0x52, 0x93, 0x6c, 0x96, 0xe2, 0x52, 0xf1, 0xb5, 0xd9, 0xf1, 0x1e, 0xf7, 0x9e,
		0x04, 0xf7, 0xa0, 0xda, 0x1f, 0x3e, 0x5c, 0x27, 0x19, 0xa8, 0x44, 0x0d, 0xf6, 0xae, 0x8d, 0xdd,
		0xb5, 0x78, 0x1c, 0x45, 0xbf, 0x91, 0x6a, 0x30, 0x36, 0xfd, 0x18, 0x2a, 0x57, 0xb3, 0xa3, 0x58,
		0xc0, 0x5b, 0x33, 0xf9, 0x63, 0xb0, 0x35, 0x53, 0x85, 0xf9, 0x6c, 0xcd, 0x08, 0x72, 0x04, 0xb6,
		0x66, 0xe4, 0xb8, 0x35, 0x5b, 0x33, 0xc2, 0x1f, 0x88, 0xad, 0x19, 0x72, 0xa6, 0x67, 0x42, 0x47,
		0x9f, 0xd6, 0xcc, 0x38, 0x8c, 0xb3, 0xd7, 0x9b, 0x1a, 0x74, 0x65, 0xb6, 0x81, 0x1f, 0x01, 0xe3,
		0x64, 0xdc, 0xc7, 0x5e, 0xd8, 0x09, 0x7b, 0x0d, 0xed, 0x64, 0x5d, 0xcd, 0x0b, 0x8b, 0x07, 0x8f,
		0x03, 0x76, 0x73, 0xd7, 0xa3, 0xcf, 0x03, 0x78, 0x9e, 0xa8, 0xa6, 0xe9, 0xfc, 0xdb, 0x10, 0x10,
		0x7c, 0x65, 0x08, 0x10, 0x1e, 0x02, 0x1a, 0x9b, 0x3b, 0x8d, 0x9d, 0xe6, 0xf6, 0xe6, 0xce, 0x16,
		0x63, 0x01, 0x0b, 0x12, 0x5a, 0x7f, 0xff, 0x75, 0xca, 0x76, 0x3f, 0x73, 0xdd, 0x9c, 0x30, 0xf3,
		0x45, 0x85, 0x17, 0x9f, 0x32, 0xfc, 0x7e, 0xff, 0xec, 0x39, 0xd8, 0xf0, 0xaf, 0xc2, 0x7c, 0x36,
		0xfc, 0x05, 0x79, 0x02, 0x1b, 0xfe, 0x72, 0xdc, 0x9a, 0x0d, 0x7f, 0xe1, 0x0f, 0xc4, 0x86, 0x3f,
		0x59, 0xd3, 0x33, 0xa1, 0xa3, 0x57, 0xc3, 0xff, 0x8d, 0x06, 0xfd, 0xfe, 0x2d, 0xf6, 0xfb, 0x2b,
		0x7e, 0xb1, 0xdf, 0xcf, 0xba, 0x62, 0x89, 0x8f, 0xc3, 0x7e, 0x3f, 0xb3, 0x79, 0x19, 0x21, 0x80,
		0xfd, 0x7e, 0xf1, 0x21, 0x60, 0x73, 0x8b, 0x8d, 0x7e, 0x16, 0x22, 0xb4, 0xfe, 0x9b, 0x17, 0x1b,
		0xfd, 0xb4, 0x18, 0x3e, 0x25, 0x4b, 0xbf, 0x24, 0xf1, 0x51, 0xfb, 0x35, 0xbc, 0x44, 0x31, 0xbf,
		0xfa, 0x6e, 0xf6, 0xb5, 0xfe, 0xed, 0x11, 0xf5, 0xdf, 0xfe, 0x51, 0xe2, 0x85, 0x8b, 0xfa, 0xb8,
		0x33, 0x90, 0x2b, 0x83, 0x0a, 0x89, 0xa0, 0x05, 0x44, 0xa0, 0x64, 0x9f, 0x87, 0xee, 0x55, 0x09,
		0x74, 0x1e, 0xba, 0x57, 0x9d, 0xbb, 0xf2, 0xd0, 0x3d, 0x69, 0xdc, 0x93, 0x87, 0xee, 0x91, 0xd3,
		0xfc, 0x1c, 0x22, 0xb0, 0xfb, 0x7e, 0x45, 0xc4, 0x8f, 0x54, 0x70, 0x9e, 0xa8, 0x73, 0xc4, 0x88,
		0x7f, 0x7b, 0xde, 0x0a, 0xa0, 0xb4, 0xc7, 0xe8, 0xce, 0x2a, 0xc2, 0x57, 0xaf, 0xf2, 0x22, 0xa9,
		0x9e, 0x53, 0x4c, 0x96, 0x4a, 0x2b, 0x6c, 0x29, 0xca, 0x91, 0xef, 0xef, 0xd4, 0x35, 0x5a, 0x51,
		0x84, 0x79, 0xc2, 0x0e, 0xee, 0x89, 0x3a, 0x5a, 0x9d, 0xa0, 0x83, 0x79, 0x62, 0x0e, 0x4a, 0x34,
		0x01, 0xed, 0xf0, 0xae, 0x76, 0x67, 0x17, 0xe9, 0x9a, 0xa3, 0x34, 0x4b, 0xc6, 0xfd, 0x2c, 0x9e,
		0xf1, 0xdd, 0x76, 0xbe, 0xf2, 0xf6, 0xec, 0xa1, 0xfd, 0xee, 0x6c, 0xb9, 0x7d, 0x3b, 0x0d, 0x53,
		0xdf, 0x99, 0xac, 0xb3, 0xef, 0xa4, 0x23, 0xdf, 0x8b, 0xae, 0xa6, 0x6f, 0xb5, 0x67, 0x0b, 0x66,
		0xde, 0x2e, 0xa6, 0x7f, 0xfb, 0x8e, 0x5f, 0xfc, 0x1b, 0xbd, 0xe9, 0x82, 0xf9, 0xe6, 0xed, 0x0a,
		0xf5, 0xc2, 0x01, 0x06, 0x93, 0xbb, 0xe1, 0x6d, 0x86, 0x3a, 0xc7, 0x58, 0xb4, 0xd8, 0xba, 0x6a,
		0x31, 0x55, 0x76, 0x90, 0x90, 0xeb, 0x7a, 0x82, 0xdd, 0xce, 0x08, 0x06, 0x97, 0x61, 0x5c, 0xbb,
		0x48, 0x86, 0xe3, 0x11, 0xd2, 0x3d, 0xe3, 0x77, 0x46, 0xf3, 0x92, 0xf1, 0x45, 0x98, 0xc9, 0x4b,
		0xc6, 0x97, 0x08, 0x57, 0x5e, 0x32, 0xbe, 0xcc, 0xde, 0x0e, 0x2f, 0x19, 0x2f, 0x97, 0xa3, 0xf1,
		0x92, 0xf1, 0x55, 0xa3, 0xe5, 0x30, 0x97, 0x8c, 0x63, 0xdd, 0x95, 0x09, 0x79, 0x47, 0x26, 0x2f,
		0x15, 0x27, 0xc1, 0xd1, 0x80, 0xe8, 0xa0, 0x12, 0x1e, 0x78, 0xe2, 0x03, 0x4f, 0x80, 0xb0, 0x89,
		0x10, 0x06, 0x21, 0x02, 0x21, 0x46, 0x70, 0x04, 0xa9, 0x30, 0x18, 0xa9, 0xeb, 0x33, 0x37, 0xdb,
		0xe0, 0x74, 0x81, 0xe6, 0x91, 0x28, 0xce, 0x3a, 0x93, 0x54, 0x69, 0x4c, 0xae, 0xd0, 0x49, 0x96,
		0x36, 0x64, 0x4b, 0x1b, 0xd2, 0xa5, 0x07, 0xf9, 0xc2, 0x22, 0x61, 0x60, 0x64, 0xac, 0x80, 0x08,
		0xfe, 0xac, 0x33, 0xec, 0x65, 0x06, 0xc0, 0x97, 0x18, 0x80, 0x1f, 0x66, 0x84, 0x7d, 0x1d, 0xa3,
		0x06, 0xa7, 0x26, 0x6a, 0x71, 0x62, 0x89, 0x2e, 0x87, 0x15, 0xe9, 0x74, 0x3e, 0xc9, 0x0d, 0xf6,
		0xfd, 0xa4, 0x74, 0x6d, 0x61, 0xae, 0xad, 0xcb, 0xa5, 0x03, 0x5a, 0xf9, 0x38, 0xcf, 0xc0, 0x29,
		0xe5, 0x75, 0xca, 0xc2, 0x6b, 0x89, 0x0e, 0x09, 0x7d, 0x3b, 0x38, 0xfe, 0xad, 0xe0, 0x5a, 0xde,
		0x06, 0x8e, 0x7d, 0x0b, 0x38, 0x95, 0xa7, 0x2b, 0x19, 0x11, 0xa9, 0x15, 0x93, 0xab, 0x6b, 0x28,
		0xb6, 0x0e, 0x91, 0x0e, 0xfd, 0xa2, 0xfe, 0x49, 0xeb, 0xb8, 0x41, 0xfd, 0x93, 0xe0, 0x38, 0x81,
		0x30, 0xbd, 0x5f, 0xa2, 0x74, 0xf4, 0x32, 0x8c, 0x0f, 0xa7, 0xcb, 0x42, 0x4d, 0x98, 0x6e, 0xa1,
		0xc8, 0x08, 0xae, 0x82, 0x30, 0x0a, 0xce, 0x22, 0x55, 0x3b, 0x0b, 0xe2, 0xc1, 0x97, 0x70, 0x30,
		0xf5, 0x6f, 0x14, 0x6d, 0xd8, 0x0f, 0x8c, 0xa7, 0x46, 0x6c, 0x11, 0x66, 0x52, 0x23, 0xb6, 0x44,
		0xd8, 0x52, 0x23, 0xb6, 0x3c, 0xf7, 0xa2, 0x46, 0xac, 0x6c, 0x1e, 0x4b, 0x8d, 0xd8, 0xaa, 0x95,
		0x2e, 0xd4, 0x88, 0x2d, 0x37, 0x3f, 0x50, 0x23, 0x46, 0x62, 0x83, 0x48, 0x70, 0x80, 0x89, 0x0e,
		0x2a, 0xe1, 0x81, 0x27, 0x3e, 0xf0, 0x04, 0x08, 0x9b, 0x08, 0x61, 0x10, 0x22, 0x10, 0x62, 0x04,
		0x47, 0x90, 0x0a, 0x83, 0x71, 0x7a, 0x3f, 0x73, 0x73, 0x0d, 0x4a, 0x07, 0x68, 0x1e, 0x81, 0xa2,
		0x3e, 0x8c, 0x84, 0x4a, 0x63, 0x62, 0x85, 0x4e, 0xb0, 0xb4, 0x21, 0x5a, 0xda, 0x10, 0x2e, 0x3d,
		0x88, 0x17, 0x16, 0x01, 0x03, 0x23, 0x62, 0x05, 0x44, 0xf0, 0xf5, 0x61, 0xa1, 0x52, 0xea, 0x3c,
		0x1a, 0x06, 0xd8, 0x22, 0xb1, 0x1d, 0x40, 0xd3, 0x1d, 0x15, 0x5f, 0x4c, 0x89, 0x31, 0x55, 0x62,
		0x25, 0xaf, 0x3c, 0x55, 0x62, 0x72, 0x1e, 0xa3, 0x90, 0x92, 0x50, 0x41, 0xc2, 0x24, 0xbc, 0x00,
		0xd7, 0xa6, 0x4a, 0x8c, 0xae, 0x4d, 0xd7, 0xd6, 0xa3, 0x1a, 0xc0, 0xb5, 0xfa, 0x94, 0xd2, 0x92,
		0x55, 0x4f, 0x4d, 0x46, 0x86, 0x58, 0x1b, 0x16, 0x75, 0xe1, 0xd4, 0x7a, 0x76, 0xbc, 0xcb, 0x30,
		0x9b, 0x1d, 0xef, 0x0a, 0x71, 0xce, 0x8e, 0x77, 0x75, 0xee, 0xca, 0x8e, 0xb7, 0xb0, 0x07, 0x61,
		0xc7, 0x9b, 0x8c, 0xe6, 0x11, 0x88, 0x68, 0xd0, 0xf1, 0x1e, 0xa8, 0x38, 0x0b, 0xb3, 0x6b, 0xf0,
		0x1b, 0xa0, 0x11, 0x05, 0xf8, 0xf6, 0x6c, 0xe9, 0xf7, 0x82, 0x14, 0x38, 0x6f, 0xdd, 0x02, 0xc9,
		0xee, 0xd9, 0x3d, 0xbf, 0x77, 0xbc, 0xe7, 0x39, 0x27, 0xbe, 0xf7, 0xa1, 0x6b, 0xa1, 0xa6, 0xaf,
		0x69, 0x9f, 0x26, 0x85, 0xdd, 0x88, 0x58, 0x83, 0xde, 0x8c, 0xf8, 0x16, 0x51, 0x5d, 0xdf, 0xb5,
		0xcc, 0xfd, 0xb7, 0xe6, 0x9e, 0xed, 0xd8, 0xde, 0x87, 0x19, 0xb8, 0x7a, 0xc8, 0xe8, 0xd2, 0x09,
		0x65, 0x7a, 0xa0, 0xed, 0x51, 0xd4, 0x75, 0x5d, 0xeb, 0xc0, 0x7e, 0xef, 0x1f, 0x38, 0xe6, 0x61,
		0xcf, 0x80, 0x7f, 0xd4, 0x9b, 0x3f, 0x89, 0x37, 0xd9, 0x78, 0xb3, 0xbb, 0x27, 0x0d, 0xdf, 0xed,
		0x1c, 0x7b, 0x96, 0xeb, 0xdb, 0x2d, 0x22, 0x8e, 0x88, 0x5b, 0x36, 0xe2, 0x3c, 0xf3, 0x90, 0x30,
		0x23, 0xcc, 0x4a, 0x80, 0x59, 0xb3, 0x41, 0xa0, 0x11, 0x68, 0x25, 0x64, 0xd0, 0x26, 0x33, 0x28,
		0x11, 0x57, 0x7a, 0x8d, 0xd0, 0xd3, 0x02, 0x6d, 0xd0, 0x4f, 0x70, 0xca, 0x39, 0x33, 0x7a, 0x37,
		0x2b, 0x7f, 0xe2, 0x8a, 0x15, 0x3e, 0x91, 0xb5, 0x72, 0xc8, 0x82, 0xae, 0xe4, 0x09, 0x27, 0x56,
		0xec, 0x04, 0x94, 0xee, 0x99, 0xaf, 0xc9, 0xcc, 0x47, 0x64, 0xb1, 0x02, 0x27, 0xaa, 0x24, 0xa2,
		0x6a, 0x16, 0x9a, 0xf6, 0xcd, 0x2e, 0x67, 0x0e, 0x88, 0xb7, 0x4a, 0x71, 0xe7, 0xfa, 0xa6, 0x73,
		0xd8, 0x71, 0x6d, 0xef, 0xed, 0x11, 0x3b, 0xd8, 0x44, 0x5c, 0x29, 0x88, 0xbb, 0xfb, 0x13, 0xdb,
		0xd8, 0xd5, 0xbe, 0xd8, 0xc6, 0xa6, 0x8b, 0x33, 0x99, 0x10, 0x59, 0x4c, 0x1a, 0x84, 0xd6, 0x6a,
		0xd4, 0xf3, 0x3d, 0xce, 0x7a, 0x13, 0x6d, 0x55, 0xa3, 0xce, 0xb1, 0xdb, 0xef, 0x38, 0x32, 0x44,
		0xa8, 0x95, 0x00, 0xb5, 0xe3, 0xf6, 0x7e, 0xa7, 0xdd, 0xf3, 0x5c, 0xd3, 0x6e, 0x5b, 0x2d, 0xdf,
		0xe9, 0x75, 0x09, 0x3a, 0x82, 0xae, 0x94, 0xf8, 0x66, 0x7a, 0x9e, 0x6b, 0xef, 0x1d, 0x7b, 0x16,
		0xe5, 0x2c, 0x84, 0xdc, 0xd2, 0x21, 0x37, 0xdd, 0xf2, 0x6b, 0x5b, 0xf6, 0xe1, 0xdb, 0xbd, 0x8e,
		0xeb, 0x9b, 0xad, 0x96, 0x6b, 0xf5, 0x08, 0x3c, 0x02, 0xaf, 0x0c, 0xe0, 0x35, 0x7c, 0xbb, 0xed,
		0x59, 0xee, 0x81, 0xb9, 0x6f, 0x11, 0x79, 0x44, 0x5e, 0x69, 0xd4, 0xce, 0xb3, 0x1d, 0xfb, 0xbf,
		0x56, 0xcb, 0xdf, 0x33, 0xdb, 0xad, 0xff, 0xd8, 0x2d, 0xef, 0x2d, 0x51, 0x47, 0xd4, 0x95, 0xc2,
		0xed, 0xba, 0x6e, 0xc7, 0xb3, 0xf6, 0x3d, 0xbb, 0xd3, 0xce, 0x3b, 0x27, 0xc4, 0x1d, 0x71, 0xb7,
		0x64, 0xdc, 0xb9, 0x56, 0xcf, 0x6e, 0x1d, 0x9b, 0x0e, 0xa3, 0x1d, 0x51, 0x57, 0x1e, 0xea, 0x8e,
		0xcc, 0xf7, 0x79, 0xc4, 0x23, 0xea, 0x88, 0xba, 0x72, 0x8b, 0x59, 0xd6, 0x14, 0x44, 0x5e, 0x25,
		0xf1, 0xce, 0xb5, 0x7a, 0x96, 0x7b, 0x62, 0xee, 0x39, 0x16, 0xa3, 0x1e, 0xb1, 0x57, 0x72, 0x65,
		0xe1, 0x74, 0x18, 0xe8, 0x08, 0xb6, 0x92, 0xc0, 0xd6, 0xb2, 0x1c, 0xf3, 0x83, 0x7f, 0x62, 0xba,
		0xb6, 0x39, 0xa9, 0x65, 0x89, 0x3b, 0xe2, 0x6e, 0xd9, 0xb8, 0x33, 0x5b, 0xff, 0xf6, 0x1d, 0xb3,
		0xad, 0xc9, 0x19, 0x0e, 0x84, 0x9b, 0x74, 0xb8, 0x9d, 0x98, 0xb6, 0x43, 0x2a, 0x47, 0xd8, 0x95,
		0x1f, 0xe5, 0x18, 0xe1, 0x08, 0xb5, 0x32, 0x2a, 0x56, 0xbb, 0x7d, 0xd7, 0xa5, 0x9b, 0x12, 0x3a,
		0xa2, 0x8e, 0xa8, 0x5b, 0x36, 0xea, 0x8e, 0xdb, 0x79, 0x97, 0x84, 0xbb, 0xaf, 0xc4, 0x5d, 0x99,
		0xb8, 0x2b, 0xc0, 0xe6, 0x17, 0x63, 0x9d, 0x1e, 0xfb, 0x25, 0x04, 0xde, 0xd2, 0x81, 0x67, 0xbd,
		0xf7, 0xac, 0x76, 0xcb, 0x6a, 0xf9, 0x66, 0x6b, 0x92, 0x71, 0x0f, 0xdd, 0xce, 0x31, 0x47, 0x89,
		0x89, 0xbb, 0x12, 0x2a, 0x09, 0xc2, 0x8d, 0x70, 0x2b, 0x0d, 0x6e, 0xd3, 0x69, 0x4e, 0x8e, 0x11,
		0x13, 0x78, 0x65, 0x03, 0x8f, 0xe5, 0x2b, 0xd1, 0x56, 0x1e, 0xda, 0x3c, 0xcb, 0x6f, 0x59, 0x07,
		0xe6, 0xb1, 0xe3, 0xf9, 0x47, 0x96, 0xe7, 0xda, 0xfb, 0x3c, 0x88, 0xa3, 0xda, 0x17, 0x0f, 0xe2,
		0xa0, 0x93, 0x2f, 0x34, 0x95, 0xf0, 0x80, 0x3a, 0x42, 0x6a, 0x71, 0x90, 0xd2, 0x48, 0x45, 0x4c,
		0x70, 0x89, 0x8c, 0x57, 0x3a, 0xa8, 0x85, 0x09, 0x2d, 0x81, 0xe5, 0xbc, 0x4e, 0xaa, 0x60, 0x02,
		0x4c, 0x20, 0xc0, 0xb4, 0x52, 0xff, 0x12, 0x61, 0xe2, 0xa8, 0x97, 0x46, 0x2a, 0x5f, 0xa2, 0x4b,
		0x24, 0xf7, 0xd2, 0x46, 0xcd, 0x4b, 0x7c, 0x49, 0xc3, 0x97, 0x4e, 0xaa, 0x5d, 0xa2, 0x4b, 0x1a,
		0xba, 0x74, 0x52, 0xe7, 0x12, 0x5d, 0x22, 0x8b, 0x47, 0x72, 0x7b, 0x22, 0x6c, 0xa9, 0xf1, 0x4b,
		0x2f, 0xb5, 0x2d, 0x31, 0x26, 0x92, 0xe1, 0x63, 0xab, 0x6a, 0x09, 0x2a, 0x91, 0xa0, 0xd2, 0x46,
		0x3d, 0x4b, 0x7c, 0x49, 0xc3, 0x97, 0x16, 0x2a, 0x59, 0xc2, 0x4a, 0x1c, 0xac, 0x74, 0x52, 0xc3,
		0x12, 0x5e, 0x12, 0xa3, 0x16, 0x23, 0x16, 0x21, 0xb5, 0xc8, 0x0a, 0x51, 0x23, 0x75, 0x2b, 0xd1,
		0x25, 0x0d, 0x5d, 0x7a, 0xa9, 0x58, 0x89, 0x2f, 0x69, 0xf8, 0xd2, 0x4c, 0xad, 0x4a, 0x80, 0x49,
		0x03, 0x98, 0x5e, 0xaa, 0x54, 0xe2, 0x4b, 0x1e, 0xa3, 0x27, 0xac, 0x08, 0xab, 0x85, 0xc3, 0x4a,
		0x33, 0x95, 0x29, 0x01, 0x26, 0x0d, 0x60, 0x2c, 0x17, 0x89, 0xaa, 0xc5, 0xa3, 0x4a, 0x23, 0xd5,
		0x28, 0xa6, 0x5a, 0x14, 0x4f, 0x25, 0x8a, 0xb5, 0xce, 0x38, 0xd6, 0x62, 0x58, 0x0a, 0x12, 0xc2,
		0x0d, 0x33, 0x8e, 0x87, 0x59, 0x90, 0x85, 0xc3, 0xd8, 0xd8, 0x05, 0x0a, 0xde, 0x46, 0xda, 0xff,
		0xa4, 0x2e, 0x83, 0x51, 0x90, 0x7d, 0x9a, 0x84, 0xeb, 0xfa, 0x70, 0xa4, 0xe2, 0xfe, 0x30, 0x3e,
		0x0f, 0x2f, 0x6a, 0xb1, 0xca, 0xbe, 0x0c, 0x93, 0xcf, 0xb5, 0x30, 0x4e, 0xb3, 0x20, 0xee, 0xab,
		0xfa, 0xf7, 0x6f, 0xa4, 0x0f, 0xde, 0xa9, 0x8f, 0x92, 0x61, 0x36, 0xec, 0x0f, 0xa3, 0xb4, 0xf8,
		0xae, 0x1e, 0xa6, 0x61, 0x5a, 0x8f, 0xd4, 0x95, 0x8a, 0x66, 0x5f, 0xea, 0x51, 0x18, 0x7f, 0xae,
		0xa5, 0x59, 0x90, 0xa9, 0xda, 0x20, 0xc8, 0x82, 0xb3, 0x20, 0x55, 0xf5, 0x28, 0x1d, 0xd5, 0xb3,
		0xe8, 0x2a, 0x9d, 0xfc, 0x67, 0xfa, 0x23, 0xb5, 0x58, 0x85, 0x17, 0x9f, 0xce, 0x86, 0x49, 0x2d,
		0xc8, 0xb2, 0x24, 0x3c, 0x1b, 0x67, 0x13, 0x03, 0xf2, 0xb7, 0xd2, 0xe2, 0xbb, 0xfa, 0x9d, 0x2d,
		0x85, 0x0d, 0xe9, 0xf8, 0x6c, 0xfa, 0x2f, 0xe5, 0x5f, 0xeb, 0xc1, 0x55, 0x10, 0x46, 0xc1, 0x59,
		0xa4, 0x6a, 0x67, 0x41, 0x3c, 0xf8, 0x12, 0x0e, 0xb2, 0x4f, 0xf5, 0xe9, 0x2f, 0xc7, 0xc8, 0x3c,
		0xf2, 0xbd, 0x54, 0xb6, 0x85, 0xc2, 0xe3, 0x07, 0x5a, 0xdc, 0x58, 0xc9, 0x78, 0x01, 0x70, 0xab,
		0xbf, 0x91, 0x66, 0xc9, 0xb8, 0x9f, 0xc5, 0x33, 0xda, 0xdd, 0xce, 0x17, 0xda, 0x9e, 0x3d, 0xa3,
		0xdf, 0x9d, 0xad, 0xae, 0x6f, 0xa7, 0x61, 0xea, 0x3b, 0x93, 0x65, 0xf5, 0x9d, 0x74, 0xe4, 0x7b,
		0xd1, 0xd5, 0xf4, 0xad, 0xf6, 0x6c, 0x7d, 0xcc, 0xdb, 0xb5, 0xf3, 0x6f, 0xdf, 0xf1, 0x8b, 0x7f,
		0xa3, 0x37, 0x5d, 0x1f, 0xdf, 0xbc, 0x5d, 0x9f, 0xbd, 0x62, 0x79, 0x7e, 0x63, 0x78, 0xd2, 0x2c,
		0x34, 0x19, 0x05, 0xf6, 0x6b, 0xfd, 0x61, 0x9c, 0x66, 0x49, 0x10, 0xc6, 0x59, 0x2a, 0x3e, 0x42,
		0x15, 0x65, 0xe7, 0x8f, 0xcd, 0x17, 0x9e, 0x0a, 0xde, 0x85, 0xf1, 0xc0, 0xd8, 0x5d, 0xdb, 0x10,
		0x6e, 0xe6, 0xfe, 0x34, 0xdc, 0x1b, 0xbb, 0x6b, 0xeb, 0xc2, 0x0d, 0xed, 0x26, 0xea, 0x3c, 0xfc,
		0x8a, 0x91, 0x56, 0x6f, 0x81, 0x3b, 0xec, 0xd7, 0x26, 0xd9, 0x0c, 0x21, 0xe3, 0xf4, 0x86, 0xe3,
		0xa4, 0xaf, 0x60, 0xaa, 0x1d, 0xe3, 0x9d, 0xba, 0xfe, 0x32, 0x4c, 0x26, 0x1e, 0x66, 0x8c, 0x72,
		0x64, 0x80, 0x94, 0x96, 0x6f, 0x83, 0xd4, 0x4c, 0x2e, 0xc6, 0x97, 0x2a, 0xce, 0x8c, 0xdd, 0xb5,
		0x2c, 0x19, 0x2b, 0x94, 0x9a, 0xf8, 0xce, 0xea, 0x02, 0xd8, 0x2c, 0x67, 0xb4, 0x2e, 0x67, 0x5a,
		0x61, 0x82, 0x11, 0x70, 0x7f, 0xc4, 0x10, 0x70, 0x62, 0xd9, 0xcf, 0x78, 0x0e, 0x4a, 0x58, 0xc3,
		0xa0, 0x3b, 0x70, 0xb4, 0x07, 0x91, 0xfe, 0x00, 0xd3, 0x20, 0x54, 0x3a, 0x04, 0x4f, 0x8b, 0xe0,
		0xe9, 0x11, 0x36, 0x4d, 0xc2, 0xa0, 0x4b, 0x20, 0xb4, 0x09, 0x8e, 0x3e, 0x15, 0x06, 0x23, 0x75,
		0x87, 0xe6, 0x66, 0x1b, 0x9c, 0x1e, 0x11, 0x38, 0x89, 0x82, 0x25, 0x53, 0xc8, 0xa4, 0x4a, 0x03,
		0x72, 0x85, 0x4e, 0xb2, 0xb4, 0x21, 0x5b, 0xda, 0x90, 0x2e, 0x3d, 0xc8, 0x17, 0x16, 0x09, 0x03,
		0x23, 0x63, 0xb0, 0xa4, 0xec, 0x07, 0xe4, 0x0c, 0x37, 0x62, 0x3e, 0xe4, 0x68, 0xa8, 0x21, 0x13,
		0x93, 0xaa, 0xc1, 0x53, 0x36, 0x1d, 0xa8, 0x9b, 0x46, 0x14, 0x4e, 0x17, 0x2a, 0xa7, 0x1d, 0xa5,
		0xd3, 0x8e, 0xda, 0xe9, 0x45, 0xf1, 0x30, 0xa9, 0x1e, 0x28, 0xe5, 0x83, 0xa7, 0x7e, 0x3f, 0xa0,
		0x80, 0xb5, 0x70, 0x80, 0x1f, 0x6c, 0x1f, 0xb2, 0xc1, 0xc9, 0x63, 0x81, 0xc7, 0xa7, 0x19, 0x31,
		0x5c, 0x07, 0x7f, 0x0c, 0x74, 0x82, 0xa8, 0x13, 0x51, 0xd4, 0x90, 0x30, 0xea, 0x46, 0x1c, 0xb5,
		0x25, 0x90, 0xda, 0x12, 0x49, 0x3d, 0x09, 0x25, 0x36, 0xb1, 0x04, 0x27, 0x98, 0x05, 0xa4, 0xbc,
		0xeb, 0x91, 0xd2, 0x2b, 0xe3, 0x44, 0x2a, 0x38, 0x4f, 0xd4, 0xb9, 0x0e, 0x19, 0xe7, 0xb6, 0x73,
		0xb7, 0xad, 0xc1, 0xb3, 0x74, 0x67, 0xca, 0xad, 0x57, 0xaf, 0x72, 0x15, 0x64, 0xfd, 0x5b, 0x2a,
		0xfd, 0x1b, 0x43, 0x18, 0xc3, 0xd7, 0xd3, 0x10, 0x95, 0x8b, 0x69, 0xb5, 0x29, 0x2d, 0xf3, 0xc7,
		0xd1, 0xa3, 0xa4, 0xdc, 0x60, 0x49, 0xc9, 0x92, 0x92, 0x25, 0x25, 0x4b, 0x4a, 0x96, 0x94, 0x2c,
		0x29, 0xc9, 0xc7, 0x56, 0xab, 0xa4, 0x44, 0xdf, 0xbb, 0x28, 0x1e, 0xe4, 0xee, 0x1c, 0x06, 0x6d,
		0x02, 0xf4, 0x03, 0xfd, 0x96, 0x2e, 0x01, 0x5a, 0x8f, 0xbd, 0x0c, 0xed, 0x08, 0xa8, 0x8e, 0x44,
		0x54, 0x63, 0x42, 0xaa, 0x2b, 0x31, 0xd5, 0x9e, 0xa0, 0x6a, 0x4f, 0x54, 0xf5, 0x26, 0xac, 0x7a,
		0x10, 0x57, 0x4d, 0x08, 0x6c, 0x01, 0x35, 0x6d, 0xf6, 0x46, 0x1e, 0x64, 0xac, 0x50, 0x29, 0x75,
		0x1e, 0x0d, 0x83, 0xec, 0xf5, 0xa6, 0x4e, 0x59, 0x6b, 0x46, 0x02, 0x77, 0x34, 0x7a, 0x24, 0x47,
		0xc5, 0x17, 0xd3, 0x02, 0xe4, 0xa3, 0x56, 0x61, 0x5c, 0x2f, 0x5a, 0x31, 0xfd, 0xa4, 0x8e, 0xc2,
		0x58, 0x3b, 0xbe, 0xa4, 0x69, 0x79, 0xf5, 0xe0, 0xf1, 0x4e, 0x82, 0x68, 0x3c, 0x09, 0x8c, 0x0d,
		0x4d, 0x9f, 0xef, 0x20, 0x09, 0xfa, 0x59, 0x38, 0x8c, 0x5b, 0xe1, 0x45, 0x38, 0x15, 0x4c, 0xaf,
		0x6b, 0xf7, 0x9c, 0x37, 0x7f, 0x6a, 0x18, 0x52, 0x82, 0xaf, 0x0c, 0x29, 0x0c, 0x29, 0x0c, 0x29,
		0xac, 0xc6, 0xf8, 0x34, 0x77, 0xaf, 0xd3, 0xdf, 0xf8, 0x79, 0x30, 0xe5, 0x2e, 0x26, 0x8c, 0xe9,
		0xa5, 0x53, 0x79, 0x50, 0xe8, 0xeb, 0xa4, 0x57, 0xd1, 0x94, 0x39, 0x70, 0xaf, 0x07, 0xc9, 0xa1,
		0xb8, 0xd7, 0x83, 0x13, 0x26, 0xb8, 0xd7, 0x03, 0xfe, 0x80, 0xdc, 0xeb, 0x21, 0x07, 0x2c, 0x09,
		0x6a, 0xfa, 0xee, 0xf5, 0x8c, 0xc3, 0x58, 0xcf, 0x6d, 0x9e, 0x6d, 0x8d, 0x1e, 0xc9, 0x0d, 0xe2,
		0x0b, 0xc5, 0x5d, 0x1e, 0xf9, 0x1f, 0x14, 0x77, 0x79, 0x70, 0x1f, 0xef, 0xb6, 0x25, 0xbb, 0xce,
		0x96, 0x2c, 0xe9, 0x86, 0xa0, 0x90, 0xc2, 0x5d, 0x1e, 0xf8, 0x90, 0xd2, 0xd8, 0xdc, 0x69, 0xec,
		0x34, 0xb7, 0x37, 0x77, 0xb6, 0x18, 0x5b, 0x58, 0x90, 0xf1, 0x69, 0x16, 0xf9, 0xe2, 0x76, 0x0f,
		0x9f, 0x60, 0xe5, 0x99, 0x03, 0xea, 0x3d, 0xdf, 0x73, 0x9f, 0x47, 0xfb, 0xfb, 0x7c, 0x7f, 0x78,
		0x15, 0xe8, 0x0f, 0xdf, 0xad, 0xdf, 0xff, 0x0b, 0xf7, 0xde, 0x06, 0xba, 0x2d, 0x5c, 0xbf, 0x98,
		0xc1, 0xf3, 0x2e, 0x4b, 0x2d, 0x13, 0xd4, 0xb5, 0x2e, 0xdb, 0xd5, 0x86, 0x13, 0xa6, 0x99, 0x99,
		0x65, 0xe0, 0x07, 0x78, 0x1e, 0x85, 0xb1, 0x15, 0xa9, 0x4b, 0x95, 0x5f, 0xb0, 0x03, 0x5c, 0xbf,
		0x4d, 0xea, 0xeb, 0x7b, 0x4f, 0xb2, 0xf1, 0xa6, 0xd1, 0x68, 0x6e, 0x37, 0x1a, 0xeb, 0xdb, 0xaf,
		0xb7, 0xd7, 0x77, 0xb6, 0xb6, 0x36, 0x9a, 0x1b, 0xc0, 0x35, 0x9b, 0xd1, 0x49, 0x06, 0x2a, 0x51,
		0x83, 0xbd, 0x89, 0xfb, 0xc4, 0xe3, 0x28, 0x62, 0xd4, 0x22, 0x27, 0x23, 0x17, 0x5b, 0x38, 0x17,
		0x33, 0xa0, 0xcf, 0xc9, 0x4a, 0xc6, 0xfd, 0x2c, 0x9e, 0x6d, 0x07, 0xb6, 0xf3, 0x8f, 0xcb, 0x9e,
		0xad, 0x94, 0xdf, 0x9d, 0x7d, 0x46, 0xbe, 0x9d, 0x86, 0xa9, 0xef, 0x4c, 0x3e, 0x1c, 0xdf, 0x49,
		0x47, 0xbe, 0x17, 0x5d, 0x4d, 0xdf, 0x6a, 0xcf, 0x56, 0xd9, 0xbc, 0xfd, 0x04, 0xfc, 0xdb, 0x77,
		0xfc, 0xe2, 0xdf, 0xe8, 0x4d, 0x57, 0xd9, 0xdf, 0xbb, 0x5d, 0xcf, 0xfd, 0x62, 0xdd, 0xfc, 0xbb,
		0x6f, 0x31, 0x89, 0xec, 0x0d, 0xef, 0xe4, 0x61, 0xe8, 0xd7, 0x27, 0xe4, 0x33, 0xd4, 0xff, 0x38,
		0xd4, 0x63, 0x05, 0x27, 0x1c, 0x17, 0x07, 0x72, 0x6f, 0xe3, 0x72, 0x38, 0x50, 0x11, 0xe2, 0x14,
		0x78, 0x31, 0xea, 0x53, 0x3c, 0x01, 0xe6, 0x65, 0xa2, 0xeb, 0xbc, 0x4c, 0xb4, 0x1c, 0xc3, 0x79,
		0x99, 0x68, 0xa5, 0x8f, 0xc0, 0xcb, 0x44, 0x85, 0x3c, 0x08, 0x2f, 0x13, 0x25, 0xab, 0x59, 0x95,
		0xc2, 0x05, 0x76, 0xc0, 0x59, 0x83, 0x83, 0xfd, 0x91, 0x0f, 0xf2, 0x7f, 0x78, 0x70, 0x7f, 0xc1,
		0x32, 0x59, 0x33, 0xad, 0x7c, 0xcd, 0x84, 0x79, 0x06, 0x3f, 0xf4, 0x99, 0xfb, 0xa0, 0x67, 0xec,
		0xb3, 0x5a, 0x62, 0xb5, 0xc4, 0x6a, 0x89, 0xd5, 0x12, 0xab, 0x25, 0x56, 0x4b, 0xf2, 0x21, 0x82,
		0x7a, 0x86, 0x3d, 0x6e, 0x13, 0xfb, 0x41, 0xca, 0x02, 0x6d, 0x66, 0x7f, 0x4f, 0xd3, 0x40, 0x27,
		0xa7, 0xe0, 0x4f, 0x25, 0xd1, 0xe1, 0x14, 0x12, 0x8d, 0x4e, 0x1d, 0xd1, 0xe5, 0x94, 0x11, 0xed,
		0x4e, 0x15, 0xd1, 0xee, 0x14, 0x11, 0xbd, 0x4e, 0x0d, 0xe1, 0x18, 0x7a, 0x99, 0xd0, 0x81, 0x3f,
		0x05, 0xe4, 0x9b, 0x53, 0x3f, 0xde, 0x20, 0xe7, 0x8b, 0x19, 0x7d, 0x42, 0x9e, 0xcd, 0xd6, 0xe3,
		0x50, 0x0f, 0x0d, 0xb4, 0x66, 0x3a, 0x1d, 0xda, 0xa1, 0xdb, 0xe9, 0x87, 0x9a, 0x1d, 0xca, 0xa1,
		0xa3, 0x50, 0x5e, 0x87, 0x73, 0x5e, 0x75, 0x3a, 0x64, 0x43, 0xd7, 0x10, 0xb0, 0xb9, 0xb5, 0xc5,
		0x20, 0xc0, 0x42, 0x84, 0xd6, 0xdf, 0x7f, 0x9d, 0x52, 0x36, 0x43, 0x8b, 0xd1, 0x53, 0x32, 0x65,
		0x33, 0x1a, 0xc9, 0x66, 0x00, 0x8f, 0xa5, 0x00, 0x1a, 0xfe, 0xfa, 0x8d, 0xe1, 0x67, 0x81, 0x44,
		0x39, 0x3f, 0x56, 0x02, 0x6c, 0x2b, 0x11, 0xf3, 0x04, 0x09, 0xdc, 0x13, 0x23, 0xb4, 0x3a, 0x21,
		0x02, 0xf3, 0x44, 0x08, 0x94, 0x80, 0x02, 0xca, 0x63, 0xc8, 0x5f, 0x20, 0x8f, 0x72, 0xa8, 0xf4,
		0xe8, 0x06, 0x0c, 0x86, 0x27, 0x9f, 0x2f, 0xc9, 0xb6, 0x50, 0x78, 0xe0, 0x45, 0x0b, 0xb8, 0x2b,
		0x1a, 0x68, 0x65, 0xc7, 0x0a, 0xb9, 0x1e, 0x28, 0xd8, 0xfb, 0x0c, 0xf5, 0x35, 0x53, 0xf1, 0x40,
		0x0d, 0x6a, 0xc1, 0xe0, 0x32, 0x8c, 0x6b, 0x17, 0xc9, 0x70, 0x3c, 0x12, 0xef, 0x83, 0xc5, 0xfc,
		0xc3, 0x0f, 0xad, 0x17, 0x1e, 0xeb, 0x30, 0x84, 0x3d, 0x30, 0x93, 0xa1, 0x48, 0x13, 0xa0, 0x80,
		0x93, 0x9e, 0x68, 0x13, 0x9d, 0xb0, 0x93, 0x9b, 0xb0, 0x13, 0x9a, 0x98, 0x93, 0x98, 0xe4, 0xeb,
		0x2f, 0xf9, 0xc8, 0x51, 0x84, 0x33, 0x60, 0xca, 0x65, 0x48, 0xc5, 0x32, 0x98, 0x52, 0x19, 0x4e,
		0xf2, 0x82, 0x28, 0x71, 0x01, 0x96, 0xb4, 0xa0, 0x4a, 0x58, 0xe0, 0x25, 0x2b, 0xf0, 0x12, 0x15,
		0x6c, 0x49, 0x0a, 0xb7, 0xa4, 0x57, 0x91, 0x20, 0x15, 0x06, 0x43, 0xf6, 0x81, 0xe6, 0xa6, 0x1d,
		0xc0, 0xbe, 0xd0, 0x3c, 0x5a, 0xc5, 0xe3, 0x32, 0x49, 0xb3, 0x34, 0xa6, 0x5b, 0xe8, 0xb4, 0x4b,
		0x1b, 0xfa, 0xa5, 0x0d, 0x0d, 0xd3, 0x83, 0x8e, 0x61, 0xd1, 0x32, 0x30, 0x7a, 0x56, 0x40, 0x04,
		0xff, 0xb8, 0x4c, 0xd8, 0x7b, 0xff, 0x81, 0xef, 0xf7, 0x07, 0x97, 0xfc, 0x62, 0x5f, 0x57, 0xa6,
		0xc1, 0xd9, 0x22, 0x5a, 0xe8, 0xfa, 0x74, 0x91, 0xf4, 0xea, 0xa4, 0xe2, 0xbb, 0xc1, 0xbe, 0xbf,
		0x8f, 0xae, 0x2d, 0xcc, 0xb5, 0x75, 0xb9, 0xef, 0x5e, 0x2b, 0x1f, 0xa7, 0x52, 0xb4, 0x94, 0xd7,
		0x29, 0x0b, 0xaf, 0x25, 0x3a, 0x24, 0xf4, 0xed, 0xb9, 0xf8, 0xb7, 0xe6, 0x6a, 0x79, 0x5b, 0x2e,
		0xf6, 0x2d, 0xb9, 0x14, 0xaf, 0xae, 0x64, 0x44, 0xa4, 0xd6, 0x4c, 0xaa, 0x04, 0xe2, 0x47, 0x7b,
		0x88, 0x48, 0xaa, 0x78, 0x6a, 0xa6, 0xb4, 0x0e, 0x20, 0xd4, 0x4c, 0x21, 0x04, 0x0c, 0x84, 0x09,
		0xff, 0xd2, 0xe4, 0xa7, 0xd6, 0x6c, 0x81, 0xcc, 0xc9, 0xfa, 0x1c, 0x4e, 0x97, 0x87, 0x8a, 0x32,
		0xdd, 0x62, 0x93, 0x11, 0x8e, 0xae, 0x1a, 0xb5, 0x30, 0xce, 0x54, 0x72, 0x1e, 0xf4, 0x55, 0x2d,
		0x18, 0x0c, 0x12, 0x95, 0xa6, 0x38, 0x9a, 0xb2, 0x39, 0xf6, 0x53, 0x55, 0xb6, 0x08, 0x33, 0xa9,
		0x2a, 0x5b, 0x22, 0x72, 0xa9, 0x2a, 0x5b, 0x9e, 0x7b, 0x51, 0x55, 0x56, 0x36, 0xbd, 0xa5, 0xaa,
		0x6c, 0xd5, 0x2a, 0x1a, 0xaa, 0xca, 0x96, 0x9b, 0x1f, 0xa8, 0x2a, 0x23, 0xb1, 0x41, 0x24, 0x38,
		0xc0, 0x44, 0x07, 0x95, 0xf0, 0xc0, 0x13, 0x1f, 0x78, 0x02, 0x84, 0x4d, 0x84, 0x30, 0x08, 0x11,
		0x08, 0x31, 0x82, 0x23, 0x48, 0x85, 0xc1, 0x28, 0xcd, 0x9f, 0xb9, 0x99, 0x06, 0xa3, 0xfb, 0x33,
		0x8f, 0x3c, 0x51, 0x3b, 0x46, 0x32, 0xa5, 0x31, 0xa9, 0x42, 0x27, 0x57, 0xda, 0x90, 0x2c, 0x6d,
		0xc8, 0x96, 0x1e, 0xa4, 0x0b, 0x8b, 0x7c, 0x81, 0x91, 0xb0, 0x02, 0x22, 0xf8, 0xda, 0xb1, 0xe9,
		0x4e, 0x17, 0x26, 0xc3, 0xb9, 0xcf, 0x72, 0x36, 0xde, 0x00, 0xda, 0xde, 0x0d, 0xb2, 0x4c, 0x25,
		0x31, 0xac, 0x88, 0xcc, 0xf8, 0xdf, 0xef, 0xbf, 0x7f, 0x5c, 0xaf, 0xed, 0x9c, 0xfe, 0xf3, 0x71,
		0xa3, 0xb6, 0x73, 0x9a, 0x7f, 0xbb, 0x31, 0xfd, 0x92, 0x7f, 0xbf, 0xf9, 0x71, 0xbd, 0xd6, 0xb8,
		0xfd, 0x7e, 0xeb, 0xe3, 0x7a, 0x6d, 0xeb, 0xf4, 0x8f, 0xbf, 0xfe, 0x7a, 0xf5, 0xc7, 0xdf, 0xaf,
		0x6f, 0x9e, 0xfe, 0x83, 0xff, 0xc2, 0x0b, 0xbe, 0xa7, 0x88, 0xa0, 0xec, 0xf4, 0xec, 0xf7, 0x44,
		0xa6, 0xee, 0xc8, 0x24, 0x2d, 0x58, 0x22, 0xfa, 0xa8, 0x6c, 0xa8, 0xf8, 0x09, 0xa8, 0x6c, 0x60,
		0x19, 0xa2, 0xb5, 0xa5, 0x54, 0x36, 0x2c, 0xd7, 0x6e, 0xed, 0x07, 0x95, 0x7f, 0x3c, 0xe1, 0x48,
		0x6d, 0xc3, 0xea, 0x58, 0x48, 0x6d, 0x03, 0x43, 0xc6, 0x02, 0x42, 0x06, 0xd5, 0x0d, 0xf7, 0xd4,
		0x0d, 0xf6, 0xe8, 0xaa, 0x61, 0xdf, 0xae, 0x90, 0x39, 0x5b, 0x20, 0xea, 0x1b, 0x74, 0x8b, 0x4f,
		0x79, 0xd7, 0xf4, 0xce, 0xaf, 0x20, 0xe5, 0x0d, 0x0f, 0xcc, 0xa7, 0xba, 0x61, 0x11, 0x66, 0x52,
		0xdd, 0xb0, 0x44, 0xe0, 0x52, 0xdd, 0xb0, 0x3c, 0xf7, 0xa2, 0xba, 0xa1, 0x6c, 0x82, 0x4b, 0x75,
		0xc3, 0xaa, 0xd5, 0x34, 0x54, 0x37, 0x2c, 0x37, 0x3f, 0x50, 0xdd, 0x40, 0x62, 0x83, 0x48, 0x70,
		0x80, 0x89, 0x0e, 0x2a, 0xe1, 0x81, 0x27, 0x3e, 0xf0, 0x04, 0x08, 0x9b, 0x08, 0x61, 0x10, 0x22,
		0x10, 0x62, 0x04, 0x47, 0x90, 0x0a, 0x83, 0xa9, 0x6e, 0xa8, 0x94, 0x3c, 0x51, 0xdd, 0x40, 0x32,
		0xa5, 0x31, 0xa9, 0x42, 0x27, 0x57, 0xda, 0x90, 0x2c, 0x6d, 0xc8, 0x96, 0x1e, 0xa4, 0x0b, 0x8b,
		0x7c, 0x81, 0x91, 0xb0, 0x02, 0x22, 0x54, 0x37, 0x08, 0x61, 0x39, 0x54, 0x37, 0x54, 0xf1, 0x00,
		0x9c, 0x21, 0xff, 0xf9, 0x8b, 0xea, 0x06, 0x22, 0x53, 0x28, 0x32, 0x49, 0x0b, 0x96, 0x88, 0x3e,
		0xaa, 0x1b, 0x2a, 0x7e, 0x02, 0xaa, 0x1b, 0x58, 0x86, 0x68, 0x6d, 0x29, 0xd5, 0x0d, 0xcb, 0xb5,
		0x7b, 0x35, 0x46, 0x95, 0xbf, 0x1f, 0x70, 0xa4, 0xb8, 0x61, 0x75, 0x2c, 0xa4, 0xb8, 0x81, 0x11,
		0xe3, 0xe5, 0x11, 0x83, 0xda, 0x86, 0xef, 0xb4, 0x0d, 0xc5, 0x5f, 0xa7, 0xb4, 0x41, 0xd3, 0xe8,
		0x64, 0x84, 0xa3, 0xab, 0x26, 0xf8, 0xd5, 0x0d, 0x4d, 0x5e, 0xdd, 0xb0, 0x24, 0x33, 0x29, 0x6e,
		0x58, 0x22, 0x72, 0x29, 0x6e, 0x58, 0x9e, 0x7b, 0x51, 0xdc, 0x50, 0x36, 0xc1, 0xa5, 0xb8, 0x61,
		0xd5, 0x6a, 0x1a, 0x8a, 0x1b, 0x96, 0x9b, 0x1f, 0x28, 0x6e, 0x20, 0xb1, 0x41, 0x24, 0x38, 0xc0,
		0x44, 0x07, 0x95, 0xf0, 0xc0, 0x13, 0x1f, 0x78, 0x02, 0x84, 0x4d, 0x84, 0x30, 0x08, 0x11, 0x08,
		0x31, 0x82, 0x23, 0x48, 0x85, 0xc1, 0x14, 0x37, 0x54, 0x4a, 0x9e, 0x28, 0x6e, 0x20, 0x99, 0xd2,
		0x98, 0x54, 0xa1, 0x93, 0x2b, 0x6d, 0x48, 0x96, 0x36, 0x64, 0x4b, 0x0f, 0xd2, 0x85, 0x45, 0xbe,
		0xc0, 0x48, 0x58, 0x01, 0x11, 0x2d, 0xc4, 0x0d, 0x4d, 0x8a, 0x1b, 0x2a, 0x62, 0x0c, 0x9a, 0x8c,
		0x90, 0x07, 0xb5, 0x73, 0xb3, 0x76, 0x70, 0xfa, 0xf7, 0xc6, 0x9f, 0x8d, 0x9b, 0xdd, 0x3f, 0xfe,
		0xde, 0xbe, 0xf9, 0xfe, 0xcd, 0x7f, 0x7e, 0xf4, 0xd7, 0x36, 0xfe, 0xdc, 0xbe, 0xd9, 0x9d, 0xf3,
		0x7f, 0x9a, 0x37, 0xbb, 0xbf, 0xf8, 0x6f, 0x6c, 0xdd, 0xfc, 0xfe, 0xe0, 0xaf, 0x4e, 0xde, 0xdf,
		0x9c, 0xf7, 0x03, 0x8d, 0x39, 0x3f, 0xf0, 0x7a, 0xde, 0x0f, 0xbc, 0x9e, 0xf3, 0x03, 0x73, 0x4d,
		0xda, 0x9c, 0xf3, 0x03, 0x5b, 0x37, 0xff, 0x3c, 0xf8, 0xfb, 0xbf, 0xff, 0xf8, 0xaf, 0x36, 0x6f,
		0xfe, 0xf8, 0x67, 0xde, 0xff, 0xdb, 0xbe, 0xf9, 0x67, 0xf7, 0x0f, 0x4a, 0x3d, 0x4a, 0x72, 0x51,
		0x9d, 0xa4, 0x1e, 0xf4, 0x53, 0xfa, 0xe9, 0xaf, 0xf8, 0x29, 0x29, 0xe3, 0x12, 0x7d, 0x91, 0xc2,
		0x97, 0x8a, 0x9f, 0x80, 0xc2, 0x17, 0x96, 0xa8, 0x5a, 0x5b, 0x4a, 0xe1, 0xcb, 0x72, 0xed, 0x5e,
		0x85, 0x31, 0xf6, 0x26, 0xaf, 0xf5, 0x58, 0x65, 0x0b, 0xa9, 0x7c, 0x61, 0xc8, 0x58, 0x40, 0xc8,
		0xa0, 0xf4, 0xe5, 0x5b, 0xe9, 0x4b, 0x93, 0xd7, 0x7a, 0x68, 0x1f, 0x9f, 0xf2, 0x8e, 0x3a, 0xf4,
		0xb5, 0x1e, 0x4d, 0x5e, 0xeb, 0xb1, 0x1c, 0x33, 0xa9, 0x7c, 0x59, 0x22, 0x70, 0xa9, 0x7c, 0x59,
		0x9e, 0x7b, 0x51, 0xf9, 0x52, 0x36, 0xc1, 0xa5, 0xf2, 0x65, 0xd5, 0x6a, 0x1a, 0x2a, 0x5f, 0x96,
		0x9b, 0x1f, 0xa8, 0x7c, 0x21, 0xb1, 0x41, 0x24, 0x38, 0xc0, 0x44, 0x07, 0x95, 0xf0, 0xc0, 0x13,
		0x1f, 0x78, 0x02, 0x84, 0x4d, 0x84, 0x30, 0x08, 0x11, 0x08, 0x31, 0x82, 0x23, 0x48, 0x85, 0xc1,
		0x54, 0xbe, 0x54, 0x4a, 0x9e, 0xa8, 0x7c, 0x21, 0x99, 0xd2, 0x98, 0x54, 0xa1, 0x93, 0x2b, 0x6d,
		0x48, 0x96, 0x36, 0x64, 0x4b, 0x0f, 0xd2, 0x85, 0x45, 0xbe, 0xc0, 0x48, 0x58, 0x01, 0x11, 0x2a,
		0x5f, 0x84, 0xb0, 0x1c, 0x2a, 0x5f, 0xaa, 0x78, 0x00, 0x4e, 0xd4, 0x73, 0xa2, 0xfe, 0xd7, 0x5f,
		0x54, 0xbe, 0xd0, 0x4f, 0xe9, 0xa7, 0x00, 0x7e, 0x4a, 0xca, 0xb8, 0x44, 0x5f, 0xa4, 0xf2, 0xa5,
		0xe2, 0x27, 0xa0, 0xf2, 0x85, 0x25, 0xaa, 0xd6, 0x96, 0x52, 0xf9, 0xb2, 0x5c, 0xbb, 0x57, 0x63,
		0x8c, 0x9d, 0x57, 0xbe, 0xac, 0xae, 0x85, 0x14, 0xbe, 0x30, 0x62, 0xbc, 0x3c, 0x62, 0x50, 0xf7,
		0xf2, 0x9d, 0xee, 0x85, 0x57, 0xbe, 0xe8, 0x1e, 0x9d, 0x8c, 0x28, 0x88, 0x6b, 0xc1, 0xe0, 0xff,
		0x05, 0x7d, 0x15, 0xf7, 0xaf, 0x6b, 0x69, 0x38, 0x00, 0xd2, 0xbc, 0xfc, 0xc0, 0x76, 0x0a, 0x5e,
		0x16, 0x61, 0x26, 0x05, 0x2f, 0x4b, 0x44, 0x2d, 0x05, 0x2f, 0xcb, 0x73, 0x2f, 0x0a, 0x5e, 0xca,
		0x26, 0xb6, 0x14, 0xbc, 0xac, 0x5a, 0x2d, 0x03, 0x23, 0x78, 0x79, 0x40, 0x0f, 0xf0, 0xc4, 0x2f,
		0x0f, 0x1f, 0x81, 0x42, 0x98, 0x55, 0x26, 0x3c, 0x88, 0xc4, 0x07, 0x98, 0x00, 0xa1, 0x12, 0x21,
		0x78, 0x42, 0x04, 0x4f, 0x8c, 0xb0, 0x09, 0x12, 0x06, 0x51, 0x02, 0x21, 0x4c, 0x70, 0xc4, 0xa9,
		0x30, 0x18, 0x4b, 0x31, 0xfc, 0x20, 0xcf, 0x20, 0x29, 0x87, 0x41, 0x89, 0x13, 0x2c, 0x81, 0x42,
		0x26, 0x52, 0x1a, 0x10, 0x2a, 0x74, 0x62, 0xa5, 0x0d, 0xc1, 0xd2, 0x86, 0x68, 0xe9, 0x41, 0xb8,
		0xb0, 0x88, 0x17, 0x18, 0x01, 0x83, 0x25, 0x62, 0x85, 0xe1, 0xe7, 0x51, 0x70, 0x91, 0xe2, 0x06,
		0xcb, 0xdb, 0x7c, 0x95, 0x3f, 0x06, 0x68, 0x7c, 0xc1, 0x54, 0x29, 0xc3, 0x13, 0x35, 0x1d, 0x08,
		0x9b, 0x46, 0xc4, 0x4d, 0x17, 0x02, 0xa7, 0x1d, 0x91, 0xd3, 0x8e, 0xd0, 0xe9, 0x45, 0xec, 0x30,
		0x09, 0x1e, 0x28, 0xd1, 0x2b, 0xa0, 0x03, 0xab, 0x7a, 0x7e, 0x90, 0x31, 0x54, 0x3c, 0xbe, 0x54,
		0x49, 0x3e, 0x49, 0x0a, 0x9c, 0x35, 0x6e, 0xbb, 0x5c, 0x0d, 0xe0, 0x67, 0xb0, 0xe2, 0xf1, 0xe5,
		0x04, 0x54, 0x74, 0xe5, 0x32, 0x57, 0x1d, 0x5a, 0x8d, 0x56, 0x3c, 0x05, 0xbc, 0x2a, 0xed, 0xee,
		0x49, 0x34, 0x54, 0xa7, 0x15, 0x0f, 0x07, 0xad, 0x52, 0xc3, 0xa5, 0x1a, 0x80, 0xb1, 0xc9, 0x28,
		0xb4, 0x04, 0x40, 0x63, 0x46, 0x73, 0x59, 0xc6, 0xfd, 0x87, 0x61, 0x9b, 0xa6, 0x0a, 0xf3, 0xd9,
		0xa6, 0x11, 0xe4, 0x0e, 0x6c, 0xd3, 0xc8, 0x71, 0x6b, 0xb6, 0x69, 0x84, 0x3f, 0x10, 0xdb, 0x34,
		0xe4, 0x4f, 0xcf, 0x84, 0x8e, 0x3e, 0x6d, 0x9a, 0xf4, 0x3a, 0xcd, 0xd4, 0x25, 0x2e, 0x7d, 0x5a,
		0x03, 0x3f, 0xa9, 0xee, 0x8e, 0x86, 0x80, 0x9f, 0x84, 0x55, 0x3c, 0xc8, 0xff, 0x3e, 0xae, 0xd7,
		0x76, 0xcc, 0xda, 0x41, 0x50, 0x3b, 0x3f, 0xfd, 0xbb, 0x71, 0xf3, 0xd7, 0x5f, 0xaf, 0x1e, 0x79,
		0xe3, 0x5f, 0xb8, 0x51, 0xf7, 0x14, 0x19, 0x70, 0x3a, 0x9c, 0xbf, 0xb6, 0x9a, 0xa8, 0x63, 0x77,
		0x87, 0xec, 0x64, 0x8e, 0x1f, 0x5c, 0x05, 0xd1, 0x58, 0xe1, 0xf7, 0x75, 0xf2, 0xc7, 0x60, 0x47,
		0xa7, 0x0a, 0xf3, 0xd9, 0xd1, 0x11, 0xe4, 0x08, 0xec, 0xe8, 0xc8, 0x71, 0x6b, 0x76, 0x74, 0x84,
		0x3f, 0x10, 0x3b, 0x3a, 0xe4, 0x4c, 0xcf, 0x84, 0x8e, 0x3e, 0x1d, 0x9d, 0x71, 0x18, 0x67, 0xaf,
		0x37, 0x35, 0x68, 0xe7, 0x6c, 0x03, 0x3f, 0x82, 0x1b, 0xc4, 0x17, 0x0a, 0xbe, 0xaa, 0xc6, 0x4e,
		0xd8, 0x6b, 0xb3, 0xf9, 0x15, 0x78, 0xe6, 0xa1, 0x49, 0x61, 0xf1, 0xe0, 0x71, 0x4e, 0x66, 0xb5,
		0xaa, 0x2e, 0xcf, 0x73, 0x90, 0x04, 0xfd, 0x2c, 0x1c, 0xc6, 0xad, 0xf0, 0x22, 0xcc, 0xc7, 0xa5,
		0xe0, 0x9f, 0xeb, 0xe6, 0x4f, 0x0d, 0x42, 0x40, 0xf0, 0x95, 0x21, 0x40, 0x78, 0x08, 0x68, 0x6c,
		0xee, 0x34, 0x76, 0x9a, 0xdb, 0x9b, 0x3b, 0x5b, 0x8c, 0x05, 0x2c, 0x48, 0x68, 0xfd, 0xfd, 0x17,
		0xdb, 0xfd, 0xcc, 0x75, 0xf3, 0xc2, 0xcc, 0x17, 0x15, 0x5e, 0x7c, 0xca, 0xf0, 0xfb, 0xfd, 0xb3,
		0xe7, 0x60, 0xc3, 0xbf, 0x0a, 0xf3, 0xd9, 0xf0, 0x17, 0xe4, 0x09, 0x6c, 0xf8, 0xcb, 0x71, 0x6b,
		0x36, 0xfc, 0x85, 0x3f, 0x10, 0x1b, 0xfe, 0x64, 0x4d, 0xcf, 0x84, 0x8e, 0x5e, 0x0d, 0xff, 0x37,
		0x1a, 0xf4, 0xfb, 0xb7, 0xd8, 0xef, 0xaf, 0xf8, 0xc5, 0x7e, 0x3f, 0xeb, 0x8a, 0x25, 0x3e, 0x0e,
		0xfb, 0xfd, 0xcc, 0xe6, 0x65, 0x84, 0x00, 0xf6, 0xfb, 0xc5, 0x87, 0x80, 0xcd, 0x2d, 0x36, 0xfa,
		0x59, 0x88, 0xd0, 0xfa, 0x6f, 0x5e, 0x6c, 0xf4, 0xd3, 0x62, 0xf8, 0x94, 0x8c, 0x7a, 0xf7, 0x70,
		0x61, 0xbf, 0xf6, 0x37, 0x8a, 0x3e, 0xbc, 0x8c, 0xf0, 0xe1, 0x5b, 0x48, 0x57, 0x12, 0xe3, 0xb9,
		0x35, 0x90, 0x4b, 0x83, 0x0a, 0x8a, 0xa0, 0x85, 0x44, 0xa0, 0xa4, 0x9f, 0x57, 0x2b, 0x54, 0x09,
		0x74, 0x5e, 0xad, 0x50, 0x9d, 0xbb, 0xf2, 0x6a, 0x05, 0x69, 0x1c, 0x94, 0x57, 0x2b, 0x90, 0xd3,
		0xfc, 0x1c, 0x22, 0xb0, 0xfb, 0x7f, 0x77, 0x57, 0x6e, 0xaa, 0xe0, 0x3c, 0x51, 0xe7, 0x88, 0x11,
		0xff, 0xf6, 0xc0, 0x16, 0x40, 0x89, 0x8f, 0xd1, 0x9d, 0x55, 0x86, 0xaf, 0x5e, 0xe5, 0x45, 0x52,
		0x3d, 0xa7, 0x98, 0x2c, 0x95, 0x56, 0xd8, 0x52, 0x94, 0x8b, 0xfd, 0xde, 0xa9, 0x6b, 0xb4, 0xa2,
		0x08, 0xf3, 0x1c, 0x65, 0xdc, 0x73, 0x93, 0xb5, 0x3a, 0x27, 0x19, 0xf3, 0x5c, 0x64, 0x94, 0x68,
		0x02, 0xda, 0xe9, 0x65, 0x87, 0x17, 0xe8, 0x7e, 0xf6, 0xfc, 0x03, 0xcb, 0x92, 0x71, 0x3f, 0x8b,
		0x67, 0xbc, 0xb7, 0x9d, 0x7f, 0x02, 0xf6, 0xec, 0xe1, 0xfd, 0xee, 0x6c, 0xd9, 0x7d, 0x3b, 0x0d,
		0x53, 0xdf, 0x99, 0xac, 0xb7, 0xef, 0xa4, 0x23, 0xdf, 0x8b, 0xae, 0xa6, 0x6f, 0xb5, 0x67, 0x0b,
		0x67, 0xde, 0x2e, 0xaa, 0x7f, 0xfb, 0x8e, 0x5f, 0xfc, 0x1b, 0xbd, 0xe9, 0xc2, 0xf9, 0x4e, 0x10,
		0x9b, 0xb7, 0x8b, 0xd4, 0x0b, 0x07, 0x18, 0xa4, 0x4e, 0x3e, 0x45, 0x92, 0x6d, 0xa1, 0xf0, 0x70,
		0x8b, 0x16, 0x66, 0x57, 0x31, 0xbc, 0xca, 0x0e, 0x14, 0x72, 0xdd, 0x4f, 0xb0, 0xeb, 0x19, 0x53,
		0x4c, 0x15, 0x48, 0x91, 0x7f, 0x99, 0xe5, 0x5d, 0x5f, 0xe8, 0x3b, 0xc3, 0x85, 0x87, 0x37, 0x8c,
		0x7b, 0xc4, 0x61, 0x36, 0xb7, 0x90, 0x36, 0xb3, 0x00, 0x37, 0xaf, 0xd0, 0x36, 0xab, 0x60, 0x37,
		0xa7, 0x60, 0x37, 0xa3, 0x30, 0x37, 0x9f, 0x48, 0xd1, 0x5f, 0xf2, 0x91, 0xa3, 0xdc, 0xd3, 0x6d,
		0xe4, 0x63, 0x5d, 0x30, 0xc1, 0xab, 0xb8, 0xa5, 0x60, 0x6a, 0x36, 0x4a, 0x93, 0x1d, 0x82, 0xd0,
		0xc0, 0x11, 0x1b, 0x44, 0x82, 0x03, 0x4c, 0x74, 0x50, 0x09, 0x0f, 0x3c, 0xf1, 0x81, 0x27, 0x40,
		0xd8, 0x44, 0x08, 0x83, 0x10, 0x81, 0x10, 0x23, 0x38, 0x82, 0x54, 0x18, 0x1c, 0x0d, 0xfb, 0x41,
		0x54, 0x1b, 0x25, 0xc3, 0x4c, 0xf5, 0x21, 0xb5, 0x0c, 0x77, 0xed, 0xa0, 0xef, 0x9f, 0x84, 0xc3,
		0xd0, 0xa4, 0x55, 0x7a, 0xd1, 0x2b, 0x0d, 0x68, 0x16, 0x3a, 0xdd, 0xd2, 0x86, 0x76, 0x69, 0x43,
		0xbf, 0xf4, 0xa0, 0x61, 0x58, 0x74, 0x0c, 0x8c, 0x96, 0x15, 0x10, 0xc1, 0x1f, 0x86, 0x56, 0xf1,
		0xf8, 0x52, 0x25, 0x01, 0x20, 0xc1, 0xb9, 0x4f, 0x72, 0x36, 0x1a, 0x80, 0xb6, 0x5b, 0xf1, 0xf8,
		0x72, 0x02, 0x1e, 0xba, 0xe8, 0x32, 0x57, 0x19, 0x72, 0x0c, 0xb6, 0xb0, 0x1e, 0x76, 0x1c, 0xf6,
		0xee, 0x09, 0x34, 0x1a, 0x8b, 0x2d, 0x1e, 0x0a, 0x72, 0x3c, 0x16, 0x8f, 0x12, 0xb0, 0x97, 0xb4,
		0x50, 0x3e, 0xcb, 0xb1, 0x63, 0xa1, 0x73, 0x71, 0xdf, 0x0e, 0x1e, 0x21, 0x9d, 0x21, 0xc1, 0x19,
		0x5a, 0xad, 0x63, 0x07, 0x67, 0x68, 0x85, 0xc7, 0x0a, 0x84, 0xc9, 0xaf, 0xf2, 0x54, 0x08, 0x61,
		0xfc, 0xd9, 0xbc, 0x5b, 0x1a, 0xce, 0x16, 0xeb, 0x16, 0x92, 0xf2, 0x11, 0xdd, 0x81, 0x8a, 0x82,
		0x6b, 0xb0, 0xb1, 0xe2, 0xdc, 0x66, 0x4e, 0x14, 0x2f, 0xc2, 0x4c, 0x4e, 0x14, 0x2f, 0x11, 0xad,
		0x9c, 0x28, 0x5e, 0x9e, 0x7b, 0x71, 0xa2, 0xb8, 0x6c, 0xf6, 0xca, 0x89, 0xe2, 0x55, 0x2b, 0x58,
		0x38, 0x51, 0xbc, 0xdc, 0xfc, 0xc0, 0x89, 0x62, 0x12, 0x1b, 0x44, 0x82, 0x03, 0x4c, 0x74, 0x50,
		0x09, 0x0f, 0x3c, 0xf1, 0x81, 0x27, 0x40, 0xd8, 0x44, 0x08, 0x83, 0x10, 0x81, 0x10, 0x23, 0x38,
		0x82, 0x54, 0x18, 0x1c, 0xd4, 0xce, 0xc2, 0x0c, 0x77, 0x8c, 0x38, 0x37, 0x9f, 0xb3, 0xc3, 0x24,
		0x50, 0x7a, 0x11, 0x29, 0x0d, 0x08, 0x15, 0x3a, 0xb1, 0xd2, 0x86, 0x60, 0x69, 0x43, 0xb4, 0xf4,
		0x20, 0x5c, 0x58, 0xc4, 0x0b, 0x8c, 0x80, 0x15, 0x10, 0xc1, 0x9f, 0x1d, 0x3e, 0x1b, 0x0e, 0x23,
		0x15, 0x40, 0xcf, 0x0d, 0x6f, 0x70, 0x72, 0x6f, 0xd5, 0x9d, 0xd1, 0xc0, 0xd8, 0x4f, 0x9e, 0xeb,
		0x85, 0x08, 0x5b, 0xcb, 0x2c, 0x30, 0x58, 0x60, 0xb0, 0xc0, 0x60, 0x81, 0xc1, 0x02, 0x83, 0x05,
		0x06, 0x0b, 0x0c, 0x16, 0x18, 0xbf, 0x18, 0xf1, 0xc7, 0x61, 0x9c, 0xbd, 0xde, 0x04, 0xae, 0x2f,
		0x10, 0xef, 0x69, 0x71, 0x83, 0xf8, 0x62, 0xb2, 0xfa, 0x1f, 0x21, 0x03, 0x23, 0xee, 0xf5, 0xe5,
		0xc6, 0x51, 0x18, 0xc3, 0xdf, 0xbf, 0xae, 0xc9, 0xbd, 0xeb, 0xc5, 0x7d, 0xeb, 0xe8, 0xcf, 0xa1,
		0xd1, 0x2d, 0xeb, 0x37, 0x7f, 0x02, 0xbb, 0x76, 0xf0, 0x95, 0xae, 0x2d, 0xcc, 0xb5, 0x1b, 0x9b,
		0x3b, 0x8d, 0x9d, 0xe6, 0xf6, 0xe6, 0xce, 0x16, 0x7d, 0x9c, 0x05, 0xc1, 0x6a, 0x59, 0x7d, 0xca,
		0xb6, 0xf7, 0x0a, 0x5b, 0x4a, 0xc1, 0xfa, 0x72, 0xed, 0x5e, 0x0d, 0x11, 0xea, 0x74, 0xdf, 0x81,
		0x5a, 0xf5, 0xd5, 0xb1, 0x90, 0x5a, 0x75, 0x86, 0x89, 0x67, 0x86, 0x09, 0xca, 0xd4, 0xbf, 0x93,
		0xa9, 0xb7, 0xa6, 0xab, 0x42, 0x85, 0xba, 0x6e, 0x81, 0xe8, 0x9e, 0xda, 0xbb, 0x76, 0x15, 0x24,
		0x21, 0x46, 0x38, 0xfa, 0x81, 0x56, 0xfd, 0x9e, 0xf5, 0x54, 0xad, 0x2f, 0xc2, 0x4c, 0xaa, 0xd6,
		0x97, 0x88, 0x5b, 0xaa, 0xd6, 0x97, 0xe7, 0x5e, 0x54, 0xad, 0x97, 0xcd, 0x63, 0xa9, 0x5a, 0x5f,
		0xb5, 0xd2, 0x85, 0xaa, 0xf5, 0xe5, 0xe6, 0x07, 0xaa, 0xd6, 0x49, 0x6c, 0x10, 0x09, 0x0e, 0x30,
		0xd1, 0x41, 0x25, 0x3c, 0xf0, 0xc4, 0x07, 0x9e, 0x00, 0x61, 0x13, 0x21, 0x0c, 0x42, 0x04, 0x42,
		0x8c, 0xe0, 0x08, 0x52, 0x61, 0x30, 0x45, 0x25, 0x95, 0x11, 0x27, 0x8a, 0x4a, 0x48, 0xa4, 0x34,
		0x26, 0x54, 0xe8, 0xc4, 0x4a, 0x1b, 0x82, 0xa5, 0x0d, 0xd1, 0xd2, 0x83, 0x70, 0x61, 0x11, 0x2f,
		0x30, 0x02, 0x56, 0x40, 0x84, 0xa2, 0x92, 0xca, 0xf9, 0x0d, 0x45, 0x25, 0x65, 0xbf, 0x28, 0x2a,
		0x21, 0xb1, 0x5f, 0xc0, 0x63, 0x50, 0x54, 0xc2, 0xf4, 0xbb, 0x48, 0xd7, 0xa6, 0xa8, 0x44, 0x9c,
		0x6b, 0x53, 0x54, 0xc2, 0x82, 0x60, 0x55, 0xad, 0xa6, 0xa8, 0x64, 0x95, 0x2d, 0xa5, 0xa8, 0x64,
		0xb9, 0x76, 0xaf, 0xd0, 0xb4, 0xf8, 0xdd, 0xec, 0x29, 0xe5, 0x25, 0xab, 0x63, 0x21, 0xe5, 0x25,
		0x0c, 0x18, 0x2f, 0x0e, 0x18, 0x14, 0x9a, 0xfc, 0x48, 0x68, 0x72, 0x52, 0x2c, 0x0f, 0x15, 0x27,
		0xba, 0xc5, 0xa6, 0x5c, 0xb3, 0x11, 0x0e, 0xc0, 0x44, 0x26, 0xe1, 0x80, 0xba, 0x92, 0x85, 0x98,
		0x49, 0x5d, 0xc9, 0x12, 0xa1, 0x4a, 0x5d, 0xc9, 0xf2, 0xdc, 0x8b, 0xba, 0x92, 0xb2, 0x09, 0x2c,
		0x75, 0x25, 0xab, 0x56, 0xb3, 0x50, 0x57, 0xb2, 0xdc, 0xfc, 0x40, 0x5d, 0x09, 0x89, 0x0d, 0x22,
		0xc1, 0x01, 0x26, 0x3a, 0xa8, 0x84, 0x07, 0x9e, 0xf8, 0xc0, 0x13, 0x20, 0x6c, 0x22, 0x84, 0x41,
		0x88, 0x40, 0x88, 0x11, 0x1c, 0x41, 0x2a, 0x0c, 0x8e, 0x86, 0xfd, 0x20, 0xc2, 0xd5, 0x95, 0xe4,
		0xe6, 0x53, 0x57, 0x42, 0x02, 0xa5, 0x17, 0x91, 0xd2, 0x80, 0x50, 0xa1, 0x13, 0x2b, 0x6d, 0x08,
		0x96, 0x36, 0x44, 0x4b, 0x0f, 0xc2, 0x85, 0x45, 0xbc, 0xc0, 0x08, 0x58, 0x01, 0x11, 0xea, 0x4a,
		0x2a, 0xe7, 0x37, 0xd4, 0x95, 0x94, 0xfd, 0xa2, 0xae, 0x84, 0xc4, 0x7e, 0x01, 0x8f, 0x41, 0x5d,
		0x09, 0xd3, 0xef, 0x22, 0x5d, 0x9b, 0xba, 0x12, 0x71, 0xae, 0x4d, 0x5d, 0x09, 0x0b, 0x82, 0x55,
		0xb5, 0x9a, 0xba, 0x92, 0x95, 0xcf, 0x51, 0x46, 0xa2, 0x2e, 0x87, 0x99, 0xc2, 0xed, 0x7b, 0xcf,
		0xec, 0x67, 0xe3, 0xbb, 0x0c, 0xb3, 0xd9, 0xf8, 0xae, 0x10, 0xe9, 0x6c, 0x7c, 0x57, 0xe7, 0xae,
		0x6c, 0x7c, 0x0b, 0x7b, 0x10, 0x36, 0xbe, 0xc9, 0x6a, 0x1e, 0x81, 0x08, 0x1b, 0xdf, 0x95, 0xf3,
		0x1b, 0x36, 0xbe, 0xcb, 0x7e, 0xb1, 0xf1, 0x4d, 0x62, 0xbf, 0x80, 0xc7, 0x60, 0xe3, 0x9b, 0xe9,
		0x77, 0x91, 0xae, 0xcd, 0xc6, 0xb7, 0x38, 0xd7, 0x66, 0xe3, 0x9b, 0x05, 0xc1, 0xaa, 0x5a, 0xcd,
		0xc6, 0xf7, 0x2a, 0x5b, 0xca, 0x03, 0x95, 0x96, 0x6b, 0xf7, 0x6a, 0x9c, 0x8f, 0x12, 0x0e, 0x78,
		0x86, 0xd2, 0xea, 0x58, 0xc8, 0x33, 0x94, 0x18, 0x23, 0x9e, 0x13, 0x23, 0x78, 0x6c, 0xd2, 0x77,
		0xc7, 0x26, 0xd9, 0x03, 0x1e, 0x95, 0xa4, 0x5d, 0x08, 0xca, 0x4f, 0x1e, 0x8a, 0x86, 0x69, 0x0a,
		0x76, 0x58, 0xd2, 0xd4, 0x64, 0x1e, 0x97, 0xb4, 0x08, 0x33, 0x79, 0x5c, 0xd2, 0x12, 0xc1, 0xca,
		0xe3, 0x92, 0x96, 0xe7, 0x5e, 0x3c, 0x2e, 0xa9, 0x6c, 0xae, 0xca, 0xe3, 0x92, 0x56, 0xad, 0x3c,
		0xe1, 0x71, 0x49, 0xcb, 0xcd, 0x0f, 0x3c, 0x2e, 0x89, 0xc4, 0x06, 0x91, 0xe0, 0x00, 0x13, 0x1d,
		0x54, 0xc2, 0x03, 0x4f, 0x7c, 0xe0, 0x09, 0x10, 0x36, 0x11, 0xc2, 0x20, 0x44, 0x20, 0xc4, 0x08,
		0x8e, 0x20, 0x15, 0x06, 0x07, 0xb5, 0xb3, 0x30, 0xc3, 0x95, 0x8d, 0xe4, 0xe6, 0x53, 0x35, 0x42,
		0x02, 0xa5, 0x17, 0x91, 0xd2, 0x80, 0x50, 0xa1, 0x13, 0x2b, 0x6d, 0x08, 0x96, 0x36, 0x44, 0x4b,
		0x0f, 0xc2, 0x85, 0x45, 0xbc, 0xc0, 0x08, 0x58, 0x01, 0x11, 0x7c, 0xd5, 0xc8, 0xd9, 0x70, 0x18,
		0xa9, 0x20, 0x06, 0x96, 0x8d, 0x6c, 0x6c, 0x70, 0x3e, 0x6f, 0xd5, 0x9d, 0x11, 0x68, 0x4b, 0x79,
		0xae, 0x27, 0xa2, 0x6c, 0x31, 0xb3, 0xd0, 0x60, 0xa1, 0xc1, 0x42, 0x83, 0x85, 0x06, 0x0b, 0x0d,
		0x16, 0x1a, 0x2c, 0x34, 0x58, 0x68, 0xfc, 0x62, 0xc4, 0xa7, 0x3c, 0xbd, 0x02, 0xd3, 0x29, 0x4f,
		0xaf, 0x68, 0xe1, 0x29, 0x4f, 0x97, 0xf3, 0x18, 0x94, 0xa7, 0x33, 0xfd, 0x2e, 0xd2, 0xb5, 0x29,
		0x4f, 0x17, 0xe7, 0xda, 0x94, 0xa7, 0xb3, 0x20, 0x58, 0x55, 0xab, 0x29, 0x4f, 0x5f, 0x65, 0x4b,
		0x29, 0x4f, 0x5f, 0xae, 0xdd, 0xab, 0x21, 0x3d, 0x8d, 0x86, 0x69, 0x4a, 0x81, 0xfa, 0xea, 0x58,
		0x48, 0x81, 0x3a, 0xa3, 0xc4, 0xf3, 0xa2, 0x04, 0x25, 0xea, 0xdf, 0x49, 0xd4, 0x9d, 0xc9, 0xa2,
		0x50, 0xa4, 0xae, 0x5b, 0x18, 0xca, 0xb7, 0xe3, 0x27, 0xfe, 0xa7, 0xa6, 0x05, 0x59, 0x2d, 0x43,
		0xe8, 0xc0, 0x7f, 0x3b, 0x4c, 0xf0, 0xbd, 0xf5, 0x94, 0xae, 0x2f, 0xc2, 0x4c, 0x4a, 0xd7, 0x97,
		0x88, 0x5b, 0x4a, 0xd7, 0x97, 0xe7, 0x5e, 0x94, 0xae, 0x97, 0xcd, 0x62, 0x29, 0x5d, 0x5f, 0xb5,
		0xc2, 0x85, 0xd2, 0xf5, 0xe5, 0xe6, 0x07, 0x4a, 0xd7, 0x49, 0x6c, 0x10, 0x09, 0x0e, 0x30, 0xd1,
		0x41, 0x25, 0x3c, 0xf0, 0xc4, 0x07, 0x9e, 0x00, 0x61, 0x13, 0x21, 0x0c, 0x42, 0x04, 0x42, 0x8c,
		0xe0, 0x08, 0x52, 0x61, 0x70, 0x86, 0x38, 0x79, 0x59, 0xa4, 0x19, 0x80, 0xbe, 0xcf, 0x3c, 0xda,
		0x44, 0x3d, 0x09, 0x69, 0x94, 0xc6, 0x74, 0x0a, 0x9d, 0x56, 0x69, 0x43, 0xaf, 0xb4, 0xa1, 0x59,
		0x7a, 0xd0, 0x2d, 0x2c, 0xda, 0x05, 0x46, 0xbf, 0x0a, 0x88, 0xe0, 0xeb, 0x49, 0x54, 0x3c, 0xbe,
		0x54, 0x49, 0x3e, 0x23, 0x00, 0x2c, 0x5e, 0x6f, 0x00, 0xda, 0x6e, 0xc5, 0xe3, 0xcb, 0x09, 0x78,
		0xe8, 0xa2, 0xcb, 0x5c, 0x65, 0x27, 0x4c, 0x33, 0x33, 0xcb, 0x12, 0x4c, 0x37, 0x3d, 0x0a, 0x63,
		0x2b, 0x52, 0x93, 0x2c, 0x94, 0x62, 0xce, 0x99, 0x1b, 0x47, 0xc1, 0xd7, 0x7b, 0x4f, 0xb0, 0xf1,
		0xa6, 0xd1, 0x68, 0x6e, 0x37, 0x1a, 0xeb, 0xdb, 0xaf, 0xb7, 0xd7, 0x77, 0xb6, 0xb6, 0x36, 0x9a,
		0x1b, 0x80, 0xb3, 0xe6, 0x46, 0x27, 0x19, 0xa8, 0x44, 0x0d, 0xf6, 0xae, 0x8d, 0xdd, 0xb5, 0x78,
		0x1c, 0x45, 0x9c, 0x1d, 0x5e, 0x61, 0x4b, 0x39, 0x3b, 0xbc, 0x5c, 0xbb, 0x57, 0x63, 0x2a, 0xf0,
		0xbb, 0x29, 0x23, 0x8e, 0x11, 0xaf, 0x8e, 0x85, 0x1c, 0x23, 0x66, 0xc0, 0x78, 0x71, 0xc0, 0xe0,
		0x44, 0xf1, 0x77, 0x13, 0xc5, 0xdd, 0x62, 0x7d, 0xa6, 0x55, 0x3a, 0x67, 0x8b, 0x75, 0x8b, 0x4d,
		0xc6, 0x65, 0xf0, 0xb5, 0x36, 0x75, 0x85, 0xb3, 0x20, 0x1e, 0x7c, 0x09, 0x07, 0x53, 0x7f, 0x07,
		0x99, 0x2c, 0xfe, 0x81, 0xed, 0x9c, 0x2b, 0x5e, 0x84, 0x99, 0x9c, 0x2b, 0x5e, 0x22, 0x6a, 0x39,
		0x57, 0xbc, 0x3c, 0xf7, 0xe2, 0x5c, 0x71, 0xd9, 0xb4, 0x96, 0x73, 0xc5, 0xab, 0x56, 0xc9, 0x70,
		0xae, 0x78, 0xb9, 0xf9, 0x81, 0x73, 0xc5, 0x24, 0x36, 0x88, 0x04, 0x07, 0x98, 0xe8, 0xa0, 0x12,
		0x1e, 0x78, 0xe2, 0x03, 0x4f, 0x80, 0xb0, 0x89, 0x10, 0x06, 0x21, 0x02, 0x21, 0x46, 0x70, 0x04,
		0xa9, 0x30, 0x18, 0xa7, 0xf5, 0x33, 0x37, 0xd7, 0xa0, 0x74, 0x80, 0xe6, 0x11, 0x28, 0x4e, 0x18,
		0x93, 0x50, 0x69, 0x4c, 0xac, 0xd0, 0x09, 0x96, 0x36, 0x44, 0x4b, 0x1b, 0xc2, 0xa5, 0x07, 0xf1,
		0xc2, 0x22, 0x60, 0x60, 0x44, 0xac, 0x80, 0x08, 0xfe, 0x84, 0x71, 0xa8, 0x94, 0x3a, 0x8f, 0x86,
		0x01, 0xf6, 0xb1, 0xf5, 0x3b, 0x80, 0xa6, 0x3b, 0x2a, 0xbe, 0x98, 0x12, 0x63, 0x9e, 0x5b, 0x5f,
		0xf2, 0xca, 0xf3, 0xdc, 0x7a, 0x39, 0x8f, 0x51, 0x1c, 0x6e, 0xcd, 0x33, 0xad, 0x99, 0x84, 0x17,
		0xe0, 0xda, 0x3c, 0xb7, 0x9e, 0xae, 0x4d, 0xd7, 0xd6, 0xa3, 0x1a, 0xc0, 0xb5, 0x9a, 0xc7, 0xd5,
		0xaf, 0xb2, 0xa5, 0x94, 0x9c, 0x2c, 0xd7, 0x6e, 0xed, 0x27, 0xc8, 0x1f, 0x8e, 0x9f, 0x52, 0x70,
		0xb2, 0x3a, 0x16, 0x52, 0x70, 0xc2, 0x70, 0xf1, 0xc2, 0x70, 0x41, 0xb9, 0xc9, 0x3d, 0xb9, 0xc9,
		0x51, 0xf0, 0xd5, 0x09, 0xe3, 0xcf, 0x7b, 0xc5, 0xe2, 0x50, 0x6c, 0xa2, 0x5b, 0x5c, 0x9a, 0x0a,
		0x36, 0x12, 0x95, 0xaa, 0xe4, 0x2a, 0x38, 0x8b, 0x14, 0xb4, 0xee, 0x64, 0xfe, 0x63, 0x50, 0x82,
		0xb2, 0x08, 0x33, 0x29, 0x41, 0x59, 0x22, 0x80, 0x29, 0x41, 0x59, 0x9e, 0x7b, 0x51, 0x82, 0x52,
		0x36, 0xd1, 0xa5, 0x04, 0x65, 0xd5, 0x6a, 0x1b, 0x4a, 0x50, 0x96, 0x9b, 0x1f, 0x28, 0x41, 0x21,
		0xb1, 0x41, 0x24, 0x38, 0xc0, 0x44, 0x07, 0x95, 0xf0, 0xc0, 0x13, 0x1f, 0x78, 0x02, 0x84, 0x4d,
		0x84, 0x30, 0x08, 0x11, 0x08, 0x31, 0x82, 0x23, 0x48, 0x85, 0xc1, 0x94, 0xa0, 0x54, 0x4e, 0xa0,
		0x28, 0x41, 0x21, 0xa1, 0xd2, 0x98, 0x58, 0xa1, 0x13, 0x2c, 0x6d, 0x88, 0x96, 0x36, 0x84, 0x4b,
		0x0f, 0xe2, 0x85, 0x45, 0xc0, 0xc0, 0x88, 0x58, 0x01, 0x11, 0x4a, 0x50, 0x64, 0x90, 0x1c, 0x4a,
		0x50, 0x4a, 0x7f, 0x51, 0x82, 0x42, 0x7a, 0xbf, 0x80, 0xc7, 0xe0, 0x9c, 0x3a, 0x93, 0xf0, 0x22,
		0x5d, 0x9b, 0x12, 0x14, 0xba, 0x36, 0x5d, 0x5b, 0x8f, 0x6a, 0x00, 0xd7, 0x6a, 0x4a, 0x50, 0x56,
		0xd9, 0x52, 0x4a, 0x50, 0x96, 0x6b, 0xf7, 0x4a, 0xcc, 0x94, 0xcf, 0x9d, 0x44, 0xa5, 0x1a, 0x65,
		0x75, 0x2c, 0xa4, 0x1a, 0x85, 0x91, 0x63, 0x71, 0x91, 0x83, 0xc2, 0x94, 0x6f, 0x85, 0x29, 0x6e,
		0xb1, 0x50, 0x94, 0xa8, 0xe8, 0x1d, 0xac, 0x8c, 0xcb, 0x30, 0xae, 0x15, 0x4a, 0xad, 0x81, 0x8a,
		0x82, 0x6b, 0x20, 0x5d, 0xca, 0x43, 0xdb, 0x29, 0x46, 0x59, 0x84, 0x99, 0x14, 0xa3, 0x2c, 0x11,
		0xb5, 0x14, 0xa3, 0x2c, 0xcf, 0xbd, 0x28, 0x46, 0x29, 0x9b, 0xe7, 0x52, 0x8c, 0xb2, 0x6a, 0xa5,
		0x0d, 0xc5, 0x28, 0xcb, 0xcd, 0x0f, 0x14, 0xa3, 0x90, 0xd8, 0x20, 0x12, 0x1c, 0x60, 0xa2, 0x83,
		0x4a, 0x78, 0xe0, 0x89, 0x0f, 0x3c, 0x01, 0xc2, 0x26, 0x42, 0x18, 0x84, 0x08, 0x84, 0x18, 0xc1,
		0x11, 0xa4, 0xc2, 0xe0, 0xa0, 0x76, 0x16, 0x66, 0xb8, 0x42, 0x94, 0xdc, 0x7c, 0x8a, 0x50, 0x48,
		0xa0, 0xf4, 0x22, 0x52, 0x1a, 0x10, 0x2a, 0x74, 0x62, 0xa5, 0x0d, 0xc1, 0xd2, 0x86, 0x68, 0xe9,
		0x41, 0xb8, 0xb0, 0x88, 0x17, 0x18, 0x01, 0x2b, 0x20, 0x82, 0x2f, 0x42, 0x39, 0x1b, 0x0e, 0x23,
		0x15, 0xc4, 0xc0, 0x02, 0x94, 0x8d, 0x0d, 0x4e, 0xfc, 0xad, 0xba, 0x33, 0x4e, 0x0f, 0x10, 0xc4,
		0xd8, 0x5b, 0x9e, 0xeb, 0x89, 0x77, 0x8f, 0xc0, 0x42, 0x83, 0x85, 0x06, 0x0b, 0x0d, 0x16, 0x1a,
		0x2c, 0x34, 0x58, 0x68, 0x90, 0xd7, 0xb0, 0xd0, 0xd0, 0xa2, 0xd0, 0x18, 0x87, 0x31, 0xb6, 0xd0,
		0x7d, 0x1b, 0xd0, 0x74, 0x37, 0x88, 0x2f, 0x14, 0x75, 0xee, 0xe5, 0x2f, 0x3c, 0x75, 0xee, 0x72,
		0x1e, 0xe3, 0x56, 0x0c, 0xbb, 0x4e, 0x31, 0x2c, 0xd3, 0xef, 0x02, 0x5c, 0x9b, 0x3a, 0x77, 0x71,
		0xae, 0xdd, 0xd8, 0xdc, 0x69, 0xec, 0x34, 0xb7, 0x37, 0x77, 0xb6, 0xe8, 0xe3, 0x2c, 0x08, 0x56,
		0xcb, 0x6a, 0x0a, 0xde, 0x57, 0x3e, 0x47, 0x4d, 0x75, 0x4a, 0xe8, 0xed, 0xef, 0xe2, 0x11, 0xd8,
		0xfe, 0x2e, 0xc3, 0x6c, 0xb6, 0xbf, 0x2b, 0x04, 0x3b, 0xdb, 0xdf, 0xd5, 0xb9, 0x2b, 0xdb, 0xdf,
		0xc2, 0x1e, 0x84, 0xed, 0x6f, 0x72, 0x9b, 0x47, 0x20, 0xc2, 0xf6, 0x77, 0xe5, 0xfc, 0x86, 0xed,
		0xef, 0xb2, 0x5f, 0x6c, 0x7f, 0x93, 0xd8, 0x2f, 0xe0, 0x31, 0xd8, 0xfe, 0x66, 0xfa, 0x5d, 0xa4,
		0x6b, 0xb3, 0xfd, 0x2d, 0xce, 0xb5, 0xd9, 0xfe, 0x66, 0x41, 0xb0, 0xaa, 0x56, 0xb3, 0xfd, 0xbd,
		0xca, 0x96, 0xf2, 0xbc, 0xd7, 0xe5, 0xda, 0xad, 0xff, 0xa9, 0x8d, 0x0f, 0x4e, 0x78, 0xe3, 0x21,
		0xaf, 0xab, 0x63, 0x21, 0x0f, 0x79, 0x65, 0xb8, 0x78, 0x61, 0xb8, 0xe0, 0xc9, 0xae, 0xf7, 0x4f,
		0x76, 0x0d, 0xe3, 0xa3, 0xe0, 0xab, 0x13, 0xc6, 0x9f, 0x5b, 0xd3, 0xb5, 0xe1, 0x71, 0xae, 0xba,
		0x85, 0x25, 0x23, 0x51, 0x69, 0x38, 0x18, 0x07, 0x51, 0x0d, 0xe7, 0x82, 0xd9, 0xa2, 0x09, 0xff,
		0x03, 0xdb, 0x79, 0x9c, 0xeb, 0x22, 0xcc, 0xe4, 0x71, 0xae, 0x4b, 0x44, 0x2d, 0x8f, 0x73, 0x5d,
		0x9e, 0x7b, 0xf1, 0x38, 0xd7, 0xb2, 0x19, 0x2d, 0x8f, 0x73, 0x5d, 0xb5, 0x22, 0x86, 0xc7, 0xb9,
		0x2e, 0x37, 0x3f, 0xf0, 0x38, 0x57, 0x12, 0x1b, 0x44, 0x82, 0x03, 0x4c, 0x74, 0x50, 0x09, 0x0f,
		0x3c, 0xf1, 0x81, 0x27, 0x40, 0xd8, 0x44, 0x08, 0x83, 0x10, 0x81, 0x10, 0x23, 0x38, 0x82, 0x54,
		0x18, 0x8c, 0xd3, 0xfa, 0x99, 0x9b, 0x6b, 0x90, 0x6e, 0xe6, 0xfa, 0x11, 0x81, 0xa2, 0xdc, 0x84,
		0x84, 0x4a, 0x63, 0x62, 0x85, 0x4e, 0xb0, 0xb4, 0x21, 0x5a, 0xda, 0x10, 0x2e, 0x3d, 0x88, 0x17,
		0x16, 0x01, 0x03, 0x23, 0x62, 0x05, 0x44, 0xf0, 0xe5, 0x26, 0xa1, 0x52, 0xea, 0x3c, 0x1a, 0x06,
		0xd8, 0x9a, 0x93, 0x1d, 0x40, 0xd3, 0x1d, 0x15, 0x5f, 0x4c, 0x89, 0x31, 0x45, 0x27, 0x25, 0xaf,
		0x3c, 0x45, 0x27, 0x72, 0x1e, 0xa3, 0x98, 0x4c, 0xe7, 0x40, 0x3a, 0x93, 0xf0, 0x02, 0x5c, 0x9b,
		0xa2, 0x13, 0xba, 0x36, 0x5d, 0x5b, 0x8f, 0x6a, 0x00, 0xd7, 0x6a, 0x6a, 0x4d, 0x56, 0xd9, 0x52,
		0x6a, 0x4d, 0x96, 0x6b, 0xb7, 0xf6, 0xc3, 0xe3, 0x0f, 0xc7, 0x4f, 0xa9, 0x35, 0x59, 0x1d, 0x0b,
		0xa9, 0x35, 0x61, 0xb8, 0x78, 0x61, 0xb8, 0xa0, 0xd6, 0xe4, 0x9e, 0xd6, 0xc4, 0x9d, 0x2d, 0xcf,
		0x5e, 0xb1, 0x3a, 0x54, 0x9b, 0xe8, 0x16, 0x98, 0x40, 0x46, 0x32, 0xa1, 0x46, 0x31, 0xa9, 0x29,
		0x59, 0xb0, 0xa1, 0xd4, 0x94, 0x2c, 0xd5, 0x64, 0x6a, 0x4a, 0x4a, 0x32, 0x9c, 0x9a, 0x12, 0xf2,
		0x01, 0x94, 0x62, 0x05, 0x46, 0x53, 0x92, 0x21, 0x8d, 0x12, 0x14, 0xe9, 0x61, 0x6a, 0x35, 0x96,
		0xa2, 0x64, 0x9d, 0x8a, 0x92, 0x95, 0xa7, 0x37, 0xc0, 0x34, 0x07, 0x95, 0xee, 0xc0, 0xd3, 0x1e,
		0x78, 0xfa, 0x83, 0x4d, 0x83, 0x30, 0xe8, 0x10, 0x08, 0x2d, 0x2a, 0xa0, 0x00, 0x37, 0xc0, 0x78,
		0x37, 0xb8, 0x38, 0x50, 0x71, 0x16, 0x66, 0xd7, 0x89, 0x3a, 0x47, 0x8a, 0xda, 0xb7, 0x3d, 0x15,
		0xa0, 0x03, 0x38, 0x0d, 0x7b, 0xb6, 0xd4, 0x7b, 0x41, 0xaa, 0x70, 0x85, 0x3c, 0x76, 0xcf, 0xee,
		0xf9, 0xbd, 0xe3, 0x3d, 0xcf, 0x39, 0xf1, 0xbd, 0x0f, 0x5d, 0x0b, 0x2d, 0xed, 0x4c, 0xc7, 0x69,
		0x52, 0xc8, 0x79, 0x51, 0x50, 0x49, 0x46, 0x81, 0x9c, 0xae, 0xef, 0x5a, 0xe6, 0xfe, 0x5b, 0x73,
		0xcf, 0x76, 0x6c, 0xef, 0xc3, 0x0c, 0x44, 0x3d, 0x44, 0x14, 0xe9, 0x80, 0x26, 0x6c, 0x54, 0x3d,
		0x8a, 0xae, 0xae, 0x6b, 0x1d, 0xd8, 0xef, 0xfd, 0x03, 0xc7, 0x3c, 0xec, 0x19, 0x1c, 0x22, 0x25,
		0xae, 0x16, 0x84, 0x2b, 0xbb, 0x7b, 0xd2, 0xf0, 0xdd, 0xce, 0xb1, 0x67, 0xb9, 0xbe, 0xdd, 0x22,
		0xb2, 0x88, 0xac, 0x45, 0x21, 0xcb, 0x33, 0x0f, 0x09, 0x27, 0xc2, 0x69, 0x81, 0x70, 0x6a, 0x36,
		0x08, 0x28, 0x02, 0x6a, 0x81, 0x99, 0xaf, 0xc9, 0xcc, 0x47, 0x64, 0x2d, 0x8d, 0xab, 0xf7, 0xa0,
		0x51, 0x05, 0x69, 0xf9, 0xe9, 0x6f, 0xf4, 0x5e, 0x7a, 0xed, 0x2a, 0x55, 0xd6, 0xc4, 0x0f, 0x2b,
		0x68, 0x22, 0x88, 0x95, 0x32, 0x61, 0xb3, 0x8a, 0xb0, 0x41, 0xac, 0x88, 0x09, 0x1c, 0x56, 0xbe,
		0x44, 0x10, 0x2b, 0x5c, 0xa2, 0x67, 0x55, 0xd0, 0x33, 0x0b, 0x35, 0xfb, 0x66, 0x97, 0x7b, 0xe5,
		0xc4, 0x55, 0x29, 0xf8, 0x72, 0x7d, 0xd3, 0x39, 0xec, 0xb8, 0xb6, 0xf7, 0xf6, 0x88, 0x9d, 0x5d,
		0x22, 0x6b, 0xa1, 0xc8, 0xba, 0xfb, 0x13, 0xdb, 0xbb, 0xe5, 0xbe, 0xd8, 0xde, 0xa5, 0xeb, 0xae,
		0x5a, 0x32, 0x20, 0x82, 0x18, 0xf4, 0x09, 0x21, 0xb4, 0x7a, 0xb9, 0xc7, 0xd9, 0x60, 0xa2, 0xaa,
		0x2c, 0x74, 0x39, 0x76, 0xfb, 0x1d, 0x47, 0x58, 0x08, 0xa9, 0x05, 0x42, 0xea, 0xb8, 0xbd, 0xdf,
		0x69, 0xf7, 0x3c, 0xd7, 0xb4, 0xdb, 0x56, 0xcb, 0x77, 0x7a, 0x5d, 0x82, 0x8b, 0xe0, 0x5a, 0x68,
		0xbc, 0x32, 0x3d, 0xcf, 0xb5, 0xf7, 0x8e, 0x3d, 0x8b, 0x72, 0x06, 0x42, 0x6b, 0x61, 0xd0, 0x9a,
		0x6e, 0x6d, 0xb5, 0x2d, 0xfb, 0xf0, 0xed, 0x5e, 0xc7, 0xf5, 0xcd, 0x56, 0xcb, 0xb5, 0x7a, 0x04,
		0x18, 0x01, 0xb6, 0x48, 0x80, 0x35, 0x7c, 0xbb, 0xed, 0x59, 0xee, 0x81, 0xb9, 0x6f, 0x11, 0x61,
		0x44, 0xd8, 0xc2, 0xa9, 0x97, 0x67, 0x3b, 0xf6, 0x7f, 0xad, 0x96, 0xbf, 0x67, 0xb6, 0x5b, 0xff,
		0xb1, 0x5b, 0xde, 0x5b, 0xa2, 0x8b, 0xe8, 0x5a, 0x28, 0xf7, 0xea, 0xba, 0x1d, 0xcf, 0xda, 0xf7,
		0xec, 0x4e, 0x3b, 0xef, 0x48, 0x10, 0x5f, 0xc4, 0xd7, 0x82, 0xf0, 0xe5, 0x5a, 0x3d, 0xbb, 0x75,
		0x6c, 0x3a, 0x8c, 0x5e, 0x44, 0xd7, 0xe2, 0xd1, 0x75, 0x64, 0xbe, 0xcf, 0x23, 0x18, 0xd1, 0x45,
		0x74, 0x2d, 0xa7, 0x78, 0x24, 0xb7, 0x27, 0xc2, 0x96, 0x1a, 0xbf, 0x5c, 0xab, 0x67, 0xb9, 0x27,
		0xe6, 0x9e, 0x63, 0x31, 0x8a, 0x11, 0x63, 0x4b, 0x62, 0xf8, 0x4e, 0x87, 0x81, 0x8b, 0xa0, 0x5a,
		0x30, 0xa8, 0x5a, 0x96, 0x63, 0x7e, 0xf0, 0x4f, 0x4c, 0xd7, 0x36, 0x27, 0xb5, 0x23, 0xf1, 0x45,
		0x7c, 0x2d, 0x0a, 0x5f, 0x66, 0xeb, 0xdf, 0xbe, 0x63, 0xb6, 0xc1, 0x35, 0xf3, 0x84, 0x95, 0x34,
		0x58, 0x9d, 0x98, 0xb6, 0x43, 0xaa, 0x45, 0x78, 0x2d, 0x2f, 0x6a, 0x31, 0x62, 0x11, 0x52, 0x8b,
		0xac, 0x10, 0xed, 0xf6, 0x5d, 0x97, 0x6b, 0x4a, 0xb8, 0x88, 0x2e, 0xa2, 0x6b, 0x51, 0xe8, 0x3a,
		0x6e, 0xe7, 0xdd, 0x07, 0xee, 0x2e, 0x12, 0x5f, 0xcb, 0xc0, 0x57, 0x01, 0x2a, 0xbf, 0x18, 0x1f,
		0xf4, 0xd8, 0x87, 0x20, 0xc0, 0x16, 0x06, 0x30, 0xeb, 0xbd, 0x67, 0xb5, 0x5b, 0x56, 0xcb, 0x37,
		0x5b, 0x93, 0x4c, 0x79, 0xe8, 0x76, 0x8e, 0x39, 0x9a, 0x4a, 0x7c, 0x2d, 0x90, 0xd1, 0x13, 0x56,
		0x84, 0xd5, 0xc2, 0x61, 0x35, 0x9d, 0x1a, 0xe4, 0x58, 0x2a, 0x01, 0xb6, 0x2c, 0x80, 0xb1, 0x5c,
		0x24, 0xaa, 0x16, 0x8f, 0x2a, 0xcf, 0xf2, 0x5b, 0xd6, 0x81, 0x79, 0xec, 0x78, 0xfe, 0x91, 0xe5,
		0xb9, 0xf6, 0x3e, 0x0f, 0x3c, 0x28, 0xf7, 0xc5, 0x03, 0x0f, 0xe8, 0xbc, 0xcf, 0x4a, 0x05, 0x3c,
		0x98, 0x8b, 0xd0, 0x79, 0x3a, 0x74, 0x34, 0x50, 0x7d, 0x12, 0x44, 0x22, 0xe2, 0x0f, 0xb2, 0xba,
		0x93, 0x10, 0x12, 0x50, 0x2e, 0xeb, 0xa0, 0xe2, 0x24, 0x90, 0x44, 0xf4, 0x5d, 0x34, 0x98, 0xe8,
		0x26, 0x92, 0x2a, 0xa7, 0x46, 0x1a, 0xa8, 0x32, 0x89, 0x22, 0x11, 0xdc, 0x08, 0x5e, 0x7d, 0x49,
		0x1c, 0x55, 0x8d, 0x23, 0x1d, 0x54, 0x96, 0x44, 0x51, 0xd5, 0x28, 0xd2, 0x41, 0x4d, 0x49, 0x14,
		0x89, 0x28, 0xd6, 0xc8, 0xb1, 0x89, 0xa4, 0x85, 0xc4, 0x23, 0x3d, 0xd4, 0x91, 0xc4, 0x92, 0x08,
		0xa6, 0x8d, 0xa9, 0x82, 0x24, 0x78, 0x44, 0x80, 0x07, 0x5e, 0xed, 0x48, 0x1c, 0x55, 0x8d, 0x23,
		0x68, 0x55, 0x23, 0xe1, 0x53, 0x39, 0x7c, 0x74, 0x50, 0x2f, 0x12, 0x46, 0x12, 0xa2, 0x10, 0x23,
		0x10, 0xa1, 0xf3, 0x9c, 0x8a, 0x4c, 0x03, 0x35, 0x22, 0x51, 0x54, 0x35, 0x8a, 0xf4, 0x50, 0x1d,
		0x12, 0x47, 0x55, 0xe3, 0x48, 0x13, 0x75, 0x21, 0x81, 0x54, 0x35, 0x90, 0xf4, 0x50, 0x11, 0x12,
		0x47, 0xd5, 0x33, 0x6b, 0xc2, 0x87, 0xf0, 0x79, 0x36, 0x7c, 0x34, 0x51, 0x05, 0x12, 0x48, 0x55,
		0x03, 0x89, 0xe5, 0x19, 0xd1, 0xf3, 0x7c, 0xf4, 0x68, 0xa0, 0xf2, 0xc3, 0x52, 0xf7, 0xe1, 0xa8,
		0xfa, 0x30, 0xd6, 0x55, 0xbe, 0x95, 0xb2, 0x2d, 0x14, 0x1e, 0x82, 0x0d, 0x33, 0x8e, 0x87, 0x59,
		0x90, 0x85, 0xc3, 0xd8, 0xd8, 0x05, 0x08, 0xbe, 0x46, 0xda, 0xff, 0xa4, 0x2e, 0x83, 0x51, 0x90,
		0x7d, 0x9a, 0x84, 0xdb, 0xfa, 0x70, 0xa4, 0xe2, 0xfe, 0x30, 0x3e, 0x0f, 0x2f, 0x6a, 0xb1, 0xca,
		0xbe, 0x0c, 0x93, 0xcf, 0xb5, 0x30, 0x4e, 0xb3, 0x20, 0xee, 0xab, 0xfa, 0xf7, 0x6f, 0xa4, 0x0f,
		0xde, 0xa9, 0x8f, 0x92, 0x61, 0x36, 0xec, 0x0f, 0xa3, 0xb4, 0xf8, 0xae, 0x1e, 0xa6, 0x61, 0x5a,
		0x8f, 0xd4, 0x95, 0x8a, 0x66, 0x5f, 0xea, 0x51, 0x18, 0x7f, 0xae, 0xa5, 0x59, 0x90, 0xa9, 0xda,
		0x20, 0xc8, 0x82, 0xb3, 0x20, 0x55, 0xf5, 0x28, 0x1d, 0xd5, 0xb3, 0xe8, 0x2a, 0x9d, 0xfc, 0x67,
		0xfa, 0x23, 0xb5, 0x58, 0x85, 0x17, 0x9f, 0xce, 0x86, 0x49, 0x2d, 0xc8, 0xb2, 0x24, 0x3c, 0x1b,
		0x67, 0x13, 0x03, 0xf2, 0xb7, 0xd2, 0xe2, 0xbb, 0xfa, 0x9d, 0x2d, 0x85, 0x0d, 0xe9, 0xf8, 0x6c,
		0xfa, 0x2f, 0xe5, 0x5f, 0xeb, 0xd3, 0x5f, 0x24, 0x3b, 0x4b, 0xc8, 0xf5, 0x38, 0xc1, 0xde, 0x66,
		0x4c, 0xe0, 0xa3, 0xce, 0x83, 0x71, 0x94, 0xd5, 0x2e, 0x55, 0x96, 0x84, 0x7d, 0xf1, 0x0e, 0x57,
		0xb0, 0x9a, 0x87, 0xa6, 0x0b, 0x8f, 0x6a, 0xef, 0xc2, 0x78, 0x60, 0xec, 0xae, 0x6d, 0x08, 0x37,
		0x73, 0x7f, 0x1a, 0xb9, 0x8c, 0xdd, 0xb5, 0x75, 0xe1, 0x86, 0x76, 0x13, 0x75, 0x1e, 0x7e, 0xc5,
		0xc8, 0x10, 0xb7, 0xa0, 0x1d, 0xf6, 0x6b, 0x93, 0xc0, 0x0c, 0x70, 0x25, 0xb8, 0xd1, 0x1b, 0x8e,
		0x93, 0xbe, 0x82, 0x58, 0xde, 0xdc, 0xbd, 0xd4, 0xf5, 0x97, 0x61, 0x32, 0xf1, 0x30, 0x63, 0x94,
		0x23, 0x03, 0xa3, 0xd0, 0x34, 0xde, 0x06, 0xa9, 0x99, 0x5c, 0x8c, 0x2f, 0x55, 0x9c, 0x19, 0xbb,
		0x6b, 0x59, 0x32, 0x56, 0x20, 0x86, 0xdf, 0xb3, 0xba, 0x00, 0x36, 0x99, 0xb9, 0xd6, 0xcc, 0xbc,
		0x15, 0x26, 0x20, 0x94, 0x7c, 0xca, 0x58, 0x61, 0x82, 0xd7, 0x6d, 0x7e, 0xc8, 0xcd, 0x06, 0xf1,
		0x7f, 0x0c, 0x42, 0x03, 0x47, 0x6c, 0x10, 0x09, 0x0e, 0x30, 0xd1, 0x41, 0x25, 0x3c, 0xf0, 0xc4,
		0x07, 0x9e, 0x00, 0x61, 0x13, 0x21, 0x0c, 0x42, 0x04, 0x42, 0x8c, 0xe0, 0x08, 0x52, 0x61, 0x30,
		0x48, 0xdb, 0x67, 0x6e, 0xa2, 0x81, 0xe8, 0xfd, 0xcc, 0xa3, 0x4e, 0xeb, 0x60, 0x66, 0xa3, 0x51,
		0x28, 0x64, 0x2a, 0xa5, 0x01, 0xa5, 0x42, 0xa7, 0x56, 0xda, 0x50, 0x2c, 0x6d, 0xa8, 0x96, 0x1e,
		0x94, 0x0b, 0x8b, 0x7a, 0x81, 0x51, 0xb0, 0x02, 0x22, 0xde, 0xf5, 0x48, 0x61, 0x47, 0xfc, 0x71,
		0x18, 0x67, 0xaf, 0x37, 0x11, 0x03, 0xfe, 0x8c, 0xdf, 0x6c, 0x03, 0x9a, 0xee, 0x06, 0xf1, 0xc5,
		0x64, 0xf5, 0x3f, 0x42, 0x06, 0x46, 0xdc, 0x83, 0xe9, 0x8d, 0xa3, 0x30, 0x86, 0x65, 0x08, 0xe0,
		0xc4, 0xfe, 0xc1, 0x63, 0x9c, 0x04, 0xd1, 0x58, 0x69, 0xf0, 0x1c, 0x07, 0x49, 0xd0, 0xcf, 0xc2,
		0x61, 0xdc, 0x0a, 0x2f, 0xc2, 0x2c, 0x9d, 0x3c, 0x10, 0x6f, 0xcb, 0xa8, 0xc2, 0xb5, 0x83, 0xaf,
		0x74, 0x6d, 0x61, 0xae, 0xdd, 0xd8, 0xdc, 0x69, 0xec, 0x34, 0xb7, 0x37, 0x77, 0xb6, 0xe8, 0xe3,
		0x2c, 0x08, 0x56, 0xcb, 0x6a, 0xac, 0x6b, 0x56, 0x6e, 0xb8, 0x97, 0xb0, 0x8a, 0x99, 0x14, 0x6d,
		0x0c, 0xba, 0xb0, 0x5b, 0xfb, 0x71, 0xe8, 0x07, 0xa3, 0xa7, 0x08, 0x03, 0xd2, 0x38, 0x3e, 0xca,
		0x11, 0xad, 0x15, 0x8a, 0x1a, 0x2b, 0x18, 0x2d, 0x10, 0xa6, 0x7f, 0xd3, 0x2c, 0x19, 0xf7, 0xb3,
		0x78, 0xd6, 0x88, 0x6c, 0xe7, 0xcb, 0x6c, 0xcf, 0x9e, 0xd0, 0xef, 0xce, 0xd6, 0xd6, 0xb7, 0xd3,
		0x30, 0xf5, 0x9d, 0xc9, 0xa2, 0xfa, 0x4e, 0x3a, 0xf2, 0xbd, 0xe8, 0x6a, 0xfa, 0x56, 0x7b, 0xb6,
		0x3a, 0xe6, 0xed, 0xca, 0xf9, 0xb7, 0xef, 0xf8, 0xc5, 0xbf, 0xd1, 0x9b, 0xae, 0x8e, 0xef, 0xa9,
		0x56, 0xbe, 0x38, 0x47, 0xf9, 0xda, 0x50, 0x64, 0xa2, 0x5b, 0x54, 0x32, 0x32, 0x84, 0x46, 0xfc,
		0x9d, 0xae, 0x64, 0x62, 0x2d, 0x86, 0x94, 0x64, 0x9d, 0x52, 0x92, 0xc5, 0x18, 0x4a, 0x29, 0xc9,
		0x52, 0x4d, 0xa6, 0x94, 0xa4, 0x24, 0xc3, 0x29, 0x25, 0x21, 0x1b, 0x40, 0xa9, 0x53, 0x60, 0xb6,
		0xe7, 0x8b, 0x88, 0x1b, 0xa9, 0xe0, 0x3c, 0x51, 0xe7, 0x08, 0x11, 0xf7, 0x56, 0x9a, 0x01, 0xb0,
		0x01, 0x6f, 0x74, 0x67, 0xa5, 0xdf, 0xab, 0x57, 0x79, 0x1b, 0xa5, 0x3e, 0x65, 0x60, 0xac, 0x03,
		0xb4, 0xab, 0x03, 0xc6, 0x93, 0xc2, 0x3e, 0xcd, 0x92, 0x20, 0x8c, 0xd5, 0xa0, 0x16, 0xa5, 0x23,
		0x9c, 0xa2, 0xe0, 0xa1, 0xe9, 0x14, 0x9b, 0xb3, 0x42, 0x60, 0x85, 0xc0, 0x0a, 0x81, 0x15, 0x02,
		0x2b, 0x04, 0x56, 0x08, 0x4b, 0xf9, 0xc8, 0x29, 0x36, 0x5f, 0x6e, 0x7e, 0xa0, 0xd8, 0x9c, 0xc4,
		0x06, 0x91, 0xe0, 0x00, 0x13, 0x1d, 0x54, 0xc2, 0x03, 0x4f, 0x7c, 0xe0, 0x09, 0x10, 0x36, 0x11,
		0xc2, 0x20, 0x44, 0x20, 0xc4, 0x08, 0x8e, 0x20, 0x15, 0x06, 0xf7, 0x87, 0xe3, 0x29, 0x70, 0x41,
		0xb5, 0xe6, 0xb9, 0xf9, 0x94, 0x9a, 0x93, 0x40, 0xe9, 0x45, 0xa4, 0x34, 0x20, 0x54, 0xe8, 0xc4,
		0x4a, 0x1b, 0x82, 0xa5, 0x0d, 0xd1, 0xd2, 0x83, 0x70, 0x61, 0x11, 0x2f, 0x30, 0x02, 0x56, 0x40,
		0x44, 0x0f, 0xa9, 0xf9, 0x46, 0x13, 0x58, 0x6a, 0xde, 0xa4, 0xd4, 0xbc, 0xe4, 0x17, 0xa5, 0xe6,
		0x24, 0xf6, 0x0b, 0x78, 0x0c, 0x4a, 0xcd, 0x99, 0x7e, 0x17, 0xe9, 0xda, 0x94, 0x9a, 0x8b, 0x73,
		0xed, 0xe6, 0xd6, 0xd6, 0x6b, 0xaa, 0xcc, 0x59, 0x0b, 0xac, 0x98, 0xd5, 0x54, 0x99, 0xaf, 0x7c,
		0x7a, 0xc2, 0xd0, 0x3e, 0xcd, 0xad, 0x0a, 0x01, 0xb4, 0x50, 0x9a, 0xe4, 0x4e, 0xf6, 0xbb, 0xab,
		0xc4, 0x39, 0xfb, 0xdd, 0xd5, 0xb9, 0x2b, 0xfb, 0xdd, 0xc2, 0x1e, 0x84, 0xfd, 0x6e, 0x32, 0x9a,
		0x47, 0x20, 0x82, 0xdf, 0xef, 0x0e, 0x07, 0x2a, 0xce, 0xc2, 0xec, 0x1a, 0x43, 0xcf, 0x35, 0x8f,
		0xe4, 0x6c, 0x00, 0x56, 0xd5, 0x86, 0x3d, 0x5b, 0xfa, 0xbd, 0x20, 0x05, 0xce, 0x5b, 0x77, 0x97,
		0x6b, 0xdb, 0x3d, 0xbf, 0x77, 0xbc, 0xe7, 0x39, 0x27, 0xbe, 0xf7, 0xa1, 0x6b, 0xa1, 0xa6, 0xaf,
		0x69, 0xaf, 0x26, 0x85, 0xdd, 0x8c, 0x58, 0x83, 0xde, 0x90, 0xf8, 0x16, 0x51, 0xdd, 0x6f, 0xaf,
		0x6b, 0xcf, 0xc1, 0xd5, 0x43, 0x46, 0x97, 0x4e, 0x28, 0xd3, 0x03, 0x6d, 0x8f, 0xa2, 0xae, 0xeb,
		0x5a, 0x07, 0xf6, 0x7b, 0xff, 0xc0, 0x31, 0x0f, 0x7b, 0x06, 0xfc, 0xa3, 0xde, 0xfc, 0x49, 0xbc,
		0xc9, 0xc6, 0x9b, 0xdd, 0x3d, 0x69, 0xf8, 0x6e, 0xe7, 0xd8, 0xb3, 0x5c, 0xdf, 0x6e, 0x11, 0x71,
		0x44, 0xdc, 0xb2, 0x11, 0xe7, 0x99, 0x87, 0x84, 0x19, 0x61, 0x56, 0x02, 0xcc, 0x9a, 0x0d, 0x02,
		0x8d, 0x40, 0x2b, 0x21, 0x83, 0x36, 0x99, 0x41, 0x89, 0xb8, 0xd2, 0x6b, 0x84, 0x9e, 0x16, 0x68,
		0x83, 0x7e, 0x82, 0x53, 0xce, 0x9a, 0xd1, 0xbb, 0x59, 0xf9, 0x13, 0x57, 0xac, 0xf0, 0x89, 0xac,
		0x95, 0x43, 0x16, 0x74, 0x25, 0x4f, 0x38, 0xb1, 0x62, 0x27, 0xa0, 0x74, 0xcf, 0x7c, 0x4d, 0x66,
		0x3e, 0x22, 0x8b, 0x15, 0x38, 0x51, 0x25, 0x11, 0x55, 0xb3, 0xd0, 0xb4, 0x6f, 0x76, 0x39, 0x73,
		0x40, 0xbc, 0x55, 0x8a, 0x3b, 0xd7, 0x37, 0x9d, 0xc3, 0x8e, 0x6b, 0x7b, 0x6f, 0x8f, 0xd8, 0xc1,
		0x26, 0xe2, 0x4a, 0x41, 0xdc, 0xdd, 0x9f, 0xd8, 0xc6, 0xae, 0xf6, 0xc5, 0x36, 0x36, 0x5d, 0x9c,
		0xc9, 0x84, 0xc8, 0x62, 0xd2, 0x20, 0xb4, 0x56, 0xa3, 0x9e, 0xef, 0x71, 0xd6, 0x9b, 0x68, 0xab,
		0x1a, 0x75, 0x8e, 0xdd, 0x7e, 0xc7, 0x91, 0x21, 0x42, 0xad, 0x04, 0xa8, 0x1d, 0xb7, 0xf7, 0x3b,
		0xed, 0x9e, 0xe7, 0x9a, 0x76, 0xdb, 0x6a, 0xf9, 0x4e, 0xaf, 0x4b, 0xd0, 0x11, 0x74, 0xa5, 0xc4,
		0x37, 0xd3, 0xf3, 0x5c, 0x7b, 0xef, 0xd8, 0xb3, 0x28, 0x67, 0x21, 0xe4, 0x96, 0x0e, 0xb9, 0xe9,
		0x96, 0x5f, 0xdb, 0xb2, 0x0f, 0xdf, 0xee, 0x75, 0x5c, 0xdf, 0x6c, 0xb5, 0x5c, 0xab, 0x47, 0xe0,
		0x11, 0x78, 0x65, 0x00, 0xaf, 0xe1, 0xdb, 0x6d, 0xcf, 0x72, 0x0f, 0xcc, 0x7d, 0x8b, 0xc8, 0x23,
		0xf2, 0x4a, 0xa3, 0x76, 0x9e, 0xed, 0xd8, 0xff, 0xb5, 0x5a, 0xfe, 0x9e, 0xd9, 0x6e, 0xfd, 0xc7,
		0x6e, 0x79, 0x6f, 0x89, 0x3a, 0xa2, 0xae, 0x14, 0x6e, 0xd7, 0x75, 0x3b, 0x9e, 0xb5, 0xef, 0xd9,
		0x9d, 0x76, 0xde, 0x39, 0x21, 0xee, 0x88, 0xbb, 0x25, 0xe3, 0xce, 0xb5, 0x7a, 0x76, 0xeb, 0xd8,
		0x74, 0x18, 0xed, 0x88, 0xba, 0xf2, 0x50, 0x77, 0x64, 0xbe, 0xcf, 0x23, 0x1e, 0x51, 0x47, 0xd4,
		0x95, 0x5b, 0xcc, 0xb2, 0xa6, 0x20, 0xf2, 0x2a, 0x89, 0x77, 0xae, 0xd5, 0xb3, 0xdc, 0x13, 0x73,
		0xcf, 0xb1, 0x18, 0xf5, 0x88, 0xbd, 0x92, 0x2b, 0x0b, 0xa7, 0xc3, 0x40, 0x47, 0xb0, 0x95, 0x04,
		0xb6, 0x96, 0xe5, 0x98, 0x1f, 0xfc, 0x13, 0xd3, 0xb5, 0xcd, 0x49, 0x2d, 0x4b, 0xdc, 0x11, 0x77,
		0xcb, 0xc6, 0x9d, 0xd9, 0xfa, 0xb7, 0xef, 0x98, 0x6d, 0x4d, 0xce, 0x70, 0x20, 0xdc, 0xa4, 0xc3,
		0xed, 0xc4, 0xb4, 0x1d, 0x52, 0x39, 0xc2, 0xae, 0xfc, 0x28, 0xc7, 0x08, 0x47, 0xa8, 0x95, 0x51,
		0xb1, 0xda, 0xed, 0xbb, 0x2e, 0xdd, 0x94, 0xd0, 0x11, 0x75, 0x44, 0xdd, 0xb2, 0x51, 0x77, 0xdc,
		0xce, 0xbb, 0x24, 0xdc, 0x7d, 0x25, 0xee, 0xca, 0xc4, 0x5d, 0x01, 0x36, 0xbf, 0x18, 0xeb, 0xf4,
		0xd8, 0x2f, 0x21, 0xf0, 0x96, 0x0e, 0x3c, 0xeb, 0xbd, 0x67, 0xb5, 0x5b, 0x56, 0xcb, 0x37, 0x5b,
		0x93, 0x8c, 0x7b, 0xe8, 0x76, 0x8e, 0x39, 0x4a, 0x4c, 0xdc, 0x95, 0x50, 0x49, 0x10, 0x6e, 0x84,
		0x5b, 0x69, 0x70, 0x9b, 0x4e, 0x73, 0x72, 0x8c, 0x98, 0xc0, 0x2b, 0x1b, 0x78, 0x2c, 0x5f, 0x89,
		0xb6, 0xf2, 0xd0, 0xe6, 0x59, 0x7e, 0xcb, 0x3a, 0x30, 0x8f, 0x1d, 0xcf, 0x3f, 0xb2, 0x3c, 0xd7,
		0xde, 0xe7, 0x41, 0x1c, 0xd5, 0xbe, 0x78, 0x10, 0x07, 0x9d, 0x7c, 0xa1, 0xa9, 0x84, 0x07, 0xd4,
		0x11, 0x52, 0x8b, 0x83, 0x94, 0x46, 0x2a, 0x62, 0x82, 0x4b, 0x64, 0xbc, 0xd2, 0x41, 0x2d, 0x4c,
		0x68, 0x09, 0x2c, 0xe7, 0x75, 0x52, 0x05, 0x13, 0x60, 0x02, 0x01, 0xa6, 0x95, 0xfa, 0x97, 0x08,
		0x13, 0x47, 0xbd, 0x34, 0x52, 0xf9, 0x12, 0x5d, 0x22, 0xb9, 0x97, 0x36, 0x6a, 0x5e, 0xe2, 0x4b,
		0x1a, 0xbe, 0x74, 0x52, 0xed, 0x12, 0x5d, 0xd2, 0xd0, 0xa5, 0x93, 0x3a, 0x97, 0xe8, 0x12, 0x59,
		0x3c, 0x92, 0xdb, 0x13, 0x61, 0x4b, 0x8d, 0x5f, 0x7a, 0xa9, 0x6d, 0x89, 0x31, 0x91, 0x0c, 0x1f,
		0x5b, 0x55, 0x4b, 0x50, 0x89, 0x04, 0x95, 0x36, 0xea, 0x59, 0xe2, 0x4b, 0x1a, 0xbe, 0xb4, 0x50,
		0xc9, 0x12, 0x56, 0xe2, 0x60, 0xa5, 0x93, 0x1a, 0x96, 0xf0, 0x92, 0x18, 0xb5, 0x18, 0xb1, 0x08,
		0xa9, 0x45, 0x56, 0x88, 0x1a, 0xa9, 0x5b, 0x89, 0x2e, 0x69, 0xe8, 0xd2, 0x4b, 0xc5, 0x4a, 0x7c,
		0x49, 0xc3, 0x97, 0x66, 0x6a, 0x55, 0x02, 0x4c, 0x1a, 0xc0, 0xf4, 0x52, 0xa5, 0x12, 0x5f, 0xf2,
		0x18, 0x3d, 0x61, 0x45, 0x58, 0x2d, 0x1c, 0x56, 0x9a, 0xa9, 0x4c, 0x09, 0x30, 0x69, 0x00, 0x63,
		0xb9, 0x48, 0x54, 0x2d, 0x1e, 0x55, 0x1a, 0xa9, 0x46, 0x31, 0xd5, 0xa2, 0x78, 0x2a, 0x51, 0xac,
		0x75, 0xc6, 0xb1, 0x16, 0xc3, 0x52, 0x90, 0x10, 0x6e, 0x98, 0x71, 0x3c, 0xcc, 0x82, 0x2c, 0x1c,
		0xc6, 0xc6, 0x2e, 0x50, 0xf0, 0x36, 0xd2, 0xfe, 0x27, 0x75, 0x19, 0x8c, 0x82, 0xec, 0xd3, 0x24,
		0x5c, 0xd7, 0x87, 0x23, 0x15, 0xf7, 0x87, 0xf1, 0x79, 0x78, 0x51, 0x8b, 0x55, 0xf6, 0x65, 0x98,
		0x7c, 0xae, 0x85, 0x71, 0x9a, 0x05, 0x71, 0x5f, 0xd5, 0xbf, 0x7f, 0x23, 0x7d, 0xf0, 0x4e, 0x7d,
		0x94, 0x0c, 0xb3, 0x61, 0x7f, 0x18, 0xa5, 0xc5, 0x77, 0xf5, 0x30, 0x0d, 0xd3, 0x7a, 0xa4, 0xae,
		0x54, 0x34, 0xfb, 0x52, 0x8f, 0xc2, 0xf8, 0x73, 0x2d, 0xcd, 0x82, 0x4c, 0xd5, 0x06, 0x41, 0x16,
		0x9c, 0x05, 0xa9, 0xaa, 0x47, 0xe9, 0xa8, 0x9e, 0x45, 0x57, 0xe9, 0xe4, 0x3f, 0xd3, 0x1f, 0xa9,
		0xc5, 0x2a, 0xbc, 0xf8, 0x74, 0x36, 0x4c, 0x6a, 0x41, 0x96, 0x25, 0xe1, 0xd9, 0x38, 0x9b, 0x18,
		0x90, 0xbf, 0x95, 0x16, 0xdf, 0xd5, 0xef, 0x6c, 0x29, 0x6c, 0x48, 0xc7, 0x67, 0xd3, 0x7f, 0x29,
		0xff, 0x5a, 0x1f, 0x4f, 0x9e, 0x27, 0xcd, 0x92, 0x20, 0x8c, 0xd5, 0xa0, 0x36, 0xf9, 0x3d, 0xd3,
		0x5f, 0x8d, 0x91, 0x77, 0xe4, 0xfb, 0xa8, 0x6c, 0x0b, 0x85, 0x47, 0x0f, 0xb4, 0xa8, 0xb1, 0x82,
		0xd1, 0x02, 0xe0, 0x46, 0x7f, 0x23, 0xcd, 0x92, 0x71, 0x3f, 0x8b, 0x67, 0x94, 0xbb, 0x9d, 0x2f,
		0xb3, 0x3d, 0x7b, 0x42, 0xbf, 0x3b, 0x5b, 0x5b, 0xdf, 0x4e, 0xc3, 0xd4, 0x77, 0x26, 0x8b, 0xea,
		0x3b, 0xe9, 0xc8, 0xf7, 0xa2, 0xab, 0xe9, 0x5b, 0xed, 0xd9, 0xea, 0x98, 0xb7, 0x2b, 0xe7, 0xdf,
		0xbe, 0xe3, 0x17, 0xff, 0x46, 0x6f, 0xba, 0x3a, 0xfe, 0xf1, 0xfd, 0xd5, 0x71, 0xd2, 0x91, 0xec,
		0x20, 0x2a, 0x37, 0x34, 0x09, 0x0e, 0x4b, 0xc6, 0x38, 0x4e, 0x54, 0xaa, 0x92, 0x2b, 0x35, 0xa8,
		0x9d, 0x05, 0xf1, 0xe0, 0x4b, 0x38, 0x98, 0x3a, 0xbb, 0xec, 0xe0, 0x54, 0xd4, 0x9b, 0x3f, 0xb4,
		0x5e, 0x78, 0x12, 0x78, 0x17, 0xc6, 0x03, 0x63, 0x77, 0x6d, 0x43, 0xb8, 0x99, 0xfb, 0xd3, 0x40,
		0x6f, 0xec, 0xae, 0xad, 0x0b, 0x37, 0xb4, 0x9b, 0xa8, 0xf3, 0xf0, 0x2b, 0x46, 0x42, 0xbd, 0xc5,
		0xed, 0xb0, 0x5f, 0x9b, 0xe4, 0x31, 0x84, 0x6c, 0xd3, 0x1b, 0x8e, 0x93, 0xbe, 0x82, 0xa9, 0x72,
		0x8c, 0x77, 0xea, 0xfa, 0xcb, 0x30, 0x99, 0x78, 0x98, 0x31, 0xca, 0x91, 0x01, 0x52, 0x52, 0xbe,
		0x0d, 0x52, 0x33, 0xb9, 0x18, 0x5f, 0xaa, 0x38, 0x33, 0x76, 0xd7, 0xb2, 0x64, 0xac, 0x50, 0x6a,
		0xe1, 0x3b, 0xab, 0x0b, 0x60, 0xb3, 0x90, 0xd1, 0xba, 0x90, 0x69, 0x85, 0x09, 0x48, 0x05, 0xa3,
		0xb2, 0xf1, 0xa8, 0x36, 0x4a, 0xc2, 0x61, 0x12, 0x66, 0xd7, 0x38, 0x51, 0xec, 0x36, 0x51, 0x7c,
		0x67, 0x3f, 0x48, 0x44, 0xc0, 0xa0, 0x38, 0x70, 0x54, 0x07, 0x91, 0xf2, 0x00, 0x53, 0x1f, 0x54,
		0x0a, 0x04, 0x4f, 0x85, 0xe0, 0x29, 0x11, 0x36, 0x35, 0xc2, 0xa0, 0x48, 0x20, 0x54, 0x09, 0x8e,
		0x32, 0x15, 0x06, 0xc3, 0x91, 0xa6, 0x07, 0xa9, 0x06, 0x8c, 0x36, 0x7d, 0x4f, 0x9f, 0xd6, 0xc1,
		0xcc, 0x46, 0xa3, 0x51, 0xc8, 0x74, 0x4a, 0x03, 0x5a, 0x85, 0x4e, 0xaf, 0xb4, 0xa1, 0x59, 0xda,
		0xd0, 0x2d, 0x3d, 0x68, 0x17, 0x16, 0xfd, 0x02, 0xa3, 0x61, 0x05, 0x44, 0xbc, 0xeb, 0x91, 0xc2,
		0x8e, 0xf8, 0x91, 0x0a, 0xce, 0x13, 0x75, 0x8e, 0x18, 0xf1, 0x6f, 0xfb, 0x43, 0xdb, 0x80, 0xb6,
		0x77, 0x67, 0xd3, 0x10, 0xaf, 0x5e, 0xe5, 0x93, 0x45, 0xf5, 0x82, 0x65, 0x72, 0x70, 0x71, 0xd5,
		0x23, 0x8b, 0x91, 0xcf, 0x9a, 0xc1, 0x16, 0x4c, 0xb9, 0xf9, 0x98, 0xd5, 0xd2, 0x06, 0xab, 0x25,
		0x56, 0x4b, 0xac, 0x96, 0x58, 0x2d, 0xb1, 0x5a, 0x62, 0xb5, 0x44, 0x4e, 0xb3, 0x58, 0x88, 0xa0,
		0x35, 0xaf, 0x0b, 0xc3, 0x71, 0x66, 0x1a, 0x1f, 0xcd, 0x59, 0x28, 0x03, 0x8e, 0x8f, 0x11, 0xb5,
		0x75, 0x50, 0xf3, 0x51, 0x09, 0x9b, 0x0e, 0xc4, 0x4d, 0x23, 0x02, 0xa7, 0x0b, 0x91, 0xd3, 0x8e,
		0xd0, 0x69, 0x47, 0xec, 0xf4, 0x22, 0x78, 0x98, 0x44, 0x0f, 0x94, 0xf0, 0x15, 0xd0, 0x81, 0x6d,
		0x93, 0x3f, 0xc8, 0x18, 0xa1, 0x52, 0xea, 0x3c, 0x1a, 0x06, 0xd9, 0xeb, 0x4d, 0xe4, 0xac, 0x31,
		0x23, 0x51, 0x3b, 0xc0, 0x8f, 0xe0, 0xa8, 0xf8, 0x62, 0x4a, 0xc8, 0x3f, 0x42, 0x87, 0x55, 0xfc,
		0x0b, 0xdf, 0x8d, 0xa3, 0x30, 0x86, 0xe7, 0x1f, 0x9a, 0x94, 0x17, 0x0f, 0x1e, 0xe7, 0x24, 0x88,
		0xc6, 0x93, 0xc0, 0xd5, 0xd0, 0xe4, 0x79, 0x0e, 0x92, 0xa0, 0x9f, 0x85, 0xc3, 0xb8, 0x15, 0x5e,
		0x84, 0x59, 0x3a, 0xf9, 0xa0, 0xe0, 0x9f, 0xeb, 0xe6, 0x4f, 0x0d, 0x42, 0x40, 0xf0, 0x95, 0x21,
		0x80, 0x21, 0x80, 0x21, 0x60, 0x95, 0xaa, 0x11, 0x7c, 0xeb, 0x4f, 0x7f, 0xe3, 0x7a, 0x33, 0xc5,
		0xfd, 0x38, 0xcc, 0xc0, 0x0e, 0xae, 0x3f, 0xa8, 0x59, 0x41, 0x07, 0xd8, 0x35, 0xc9, 0xc7, 0xec,
		0xf8, 0x4b, 0xf2, 0x05, 0x76, 0xfc, 0xe5, 0xb8, 0x35, 0x3b, 0xfe, 0xc2, 0x1f, 0x88, 0x1d, 0x7f,
		0x32, 0xa7, 0x67, 0x42, 0x47, 0x9f, 0x8e, 0xff, 0x38, 0x8c, 0xb3, 0x37, 0x1a, 0xf4, 0xfa, 0xb7,
		0x80, 0x1f, 0xc1, 0x0d, 0xe2, 0x0b, 0xc5, 0x56, 0x7f, 0xf5, 0x1f, 0x04, 0x5b, 0xfd, 0x72, 0x1f,
		0xe7, 0xb6, 0xcf, 0xb7, 0xce, 0x3e, 0x1f, 0xb3, 0xf9, 0x12, 0x43, 0x00, 0x5b, 0xfd, 0xe2, 0x43,
		0xc0, 0x36, 0x43, 0x00, 0xcb, 0x10, 0x5a, 0x7f, 0xff, 0xc5, 0x56, 0x3f, 0x2d, 0x86, 0x4f, 0xc8,
		0xa8, 0x17, 0x46, 0x14, 0xf6, 0xaf, 0xc0, 0x51, 0xf0, 0x0f, 0x8f, 0x92, 0xae, 0x7f, 0x7b, 0xfc,
		0x22, 0xd2, 0x55, 0x12, 0x78, 0x5e, 0xcd, 0xe3, 0xc6, 0x16, 0xca, 0x8f, 0xd5, 0x35, 0xe0, 0x0e,
		0xa2, 0xe1, 0x84, 0x69, 0x66, 0x66, 0x19, 0xd8, 0x51, 0x69, 0x47, 0x61, 0x6c, 0x45, 0xea, 0x52,
		0xc5, 0x39, 0xd5, 0x05, 0x3a, 0xb0, 0xe0, 0x28, 0xf8, 0x7a, 0xcf, 0xf2, 0x8d, 0x37, 0x8d, 0x46,
		0x73, 0xbb, 0xd1, 0x58, 0xdf, 0x7e, 0xbd, 0xbd, 0xbe, 0xb3, 0xb5, 0xb5, 0xd1, 0xdc, 0x00, 0x6a,
		0x3e, 0x1a, 0x9d, 0x64, 0xa0, 0x12, 0x35, 0xd8, 0x9b, 0x20, 0x3f, 0x1e, 0x47, 0x11, 0x03, 0x0a,
		0x09, 0x0c, 0x89, 0x0b, 0xd6, 0xfc, 0x48, 0x79, 0xb7, 0xdb, 0xf4, 0x26, 0x4b, 0xd4, 0x85, 0x3a,
		0xbc, 0x87, 0xf7, 0x83, 0x69, 0x1d, 0x6b, 0x79, 0x3f, 0x18, 0x42, 0x6c, 0xe5, 0x2d, 0x58, 0xda,
		0x39, 0x9f, 0x31, 0xce, 0xc2, 0x28, 0xfc, 0x3f, 0xd0, 0x3b, 0xb0, 0x1e, 0xda, 0xce, 0x1b, 0xb0,
		0x16, 0x61, 0x26, 0x6f, 0xc0, 0x5a, 0x22, 0x6a, 0x79, 0x03, 0xd6, 0x32, 0x5b, 0x3f, 0xbc, 0x01,
		0xab, 0x5c, 0xde, 0xc6, 0x1b, 0xb0, 0x56, 0x8d, 0xaa, 0xe3, 0xdc, 0x80, 0x05, 0x75, 0x24, 0x29,
		0xe4, 0x51, 0xa4, 0xbc, 0xef, 0x8a, 0x04, 0x47, 0x03, 0xa2, 0x83, 0x4a, 0x78, 0xe0, 0x89, 0x0f,
		0x3c, 0x01, 0xc2, 0x26, 0x42, 0x18, 0x84, 0x08, 0x84, 0x18, 0xc1, 0x11, 0xa4, 0xc2, 0x60, 0xdc,
		0xa3, 0x42, 0xe1, 0x8f, 0x08, 0xe5, 0x8d, 0x57, 0x24, 0x54, 0x2b, 0x40, 0xac, 0xd0, 0x09, 0x96,
		0x36, 0x44, 0x4b, 0x1b, 0xc2, 0xa5, 0x07, 0xf1, 0xc2, 0x22, 0x60, 0x60, 0x44, 0xac, 0x80, 0x08,
		0xfe, 0x8d, 0x57, 0xd8, 0x47, 0x78, 0x02, 0x1f, 0xdd, 0x89, 0x7e, 0x64, 0x27, 0xb0, 0x98, 0x5d,
		0x07, 0xdd, 0xae, 0x26, 0x62, 0x3d, 0x5d, 0xce, 0xe3, 0xd3, 0x49, 0x9c, 0x07, 0xac, 0xcb, 0xd5,
		0x42, 0x8f, 0x4b, 0xd7, 0xa6, 0x6b, 0xb3, 0x1a, 0x80, 0xb6, 0xfa, 0x94, 0x7a, 0xb6, 0x55, 0x4f,
		0x4d, 0x46, 0x86, 0x58, 0x1b, 0x16, 0x75, 0xe1, 0xd4, 0x7a, 0x76, 0xbc, 0xcb, 0x30, 0x9b, 0x1d,
		0xef, 0x0a, 0x71, 0xce, 0x8e, 0x77, 0x75, 0xee, 0xca, 0x8e, 0xb7, 0xb0, 0x07, 0x61, 0xc7, 0x9b,
		0x8c, 0xe6, 0x11, 0x88, 0x68, 0xd0, 0xf1, 0x1e, 0xa8, 0x38, 0x0b, 0xb3, 0xeb, 0x44, 0x9d, 0x03,
		0x77, 0xbc, 0x37, 0x00, 0x4f, 0xb0, 0x34, 0xec, 0xd9, 0xd2, 0xef, 0x05, 0xa9, 0xc2, 0x3f, 0x49,
		0xde, 0xee, 0xd9, 0x3d, 0xbf, 0x77, 0xbc, 0xe7, 0x39, 0x27, 0xbe, 0xf7, 0xa1, 0x6b, 0xa1, 0xa6,
		0xaf, 0x69, 0x9f, 0x26, 0x85, 0x3e, 0x50, 0x14, 0xbc, 0xe1, 0x57, 0x20, 0xaa, 0xeb, 0xbb, 0x96,
		0xb9, 0xff, 0xd6, 0xdc, 0xb3, 0x1d, 0xdb, 0xfb, 0x30, 0x03, 0x57, 0x0f, 0x19, 0x5d, 0x3a, 0xa1,
		0x4c, 0x0f, 0xb4, 0x3d, 0x8a, 0xba, 0xae, 0x6b, 0x1d, 0xd8, 0xef, 0xfd, 0x03, 0xc7, 0x3c, 0xec,
		0x19, 0x3c, 0x65, 0x94, 0x78, 0x5b, 0x32, 0xde, 0xec, 0xee, 0x49, 0xc3, 0x77, 0x3b, 0xc7, 0x9e,
		0xe5, 0xfa, 0x76, 0x8b, 0x88, 0x23, 0xe2, 0x96, 0x8d, 0x38, 0xcf, 0x3c, 0x24, 0xcc, 0x08, 0xb3,
		0x12, 0x60, 0xd6, 0x6c, 0x10, 0x68, 0x04, 0x5a, 0x09, 0x19, 0xb4, 0xc9, 0x0c, 0x4a, 0xc4, 0x95,
		0x5e, 0x23, 0xf4, 0xb4, 0x40, 0x1b, 0xf4, 0x13, 0x9c, 0x72, 0xce, 0x8c, 0xde, 0xcd, 0xca, 0x9f,
		0xb8, 0x62, 0x85, 0x4f, 0x64, 0xad, 0x1c, 0xb2, 0xa0, 0x2b, 0x79, 0xc2, 0x89, 0x15, 0x3b, 0x01,
		0xa5, 0x7b, 0xe6, 0x6b, 0x32, 0xf3, 0x11, 0x59, 0xac, 0xc0, 0x89, 0x2a, 0x89, 0xa8, 0x9a, 0x85,
		0xa6, 0x7d, 0xb3, 0xcb, 0x99, 0x03, 0xe2, 0xad, 0x52, 0xdc, 0xb9, 0xbe, 0xe9, 0x1c, 0x76, 0x5c,
		0xdb, 0x7b, 0x7b, 0xc4, 0x0e, 0x36, 0x11, 0x57, 0x0a, 0xe2, 0xee, 0xfe, 0xc4, 0x36, 0x76, 0xb5,
		0x2f, 0xb6, 0xb1, 0xe9, 0xe2, 0x4c, 0x26, 0x44, 0x16, 0x93, 0x06, 0xa1, 0xb5, 0x1a, 0xf5, 0x7c,
		0x8f, 0xb3, 0xde, 0x44, 0x5b, 0xd5, 0xa8, 0x73, 0xec, 0xf6, 0x3b, 0x8e, 0x0c, 0x11, 0x6a, 0x25,
		0x40, 0xed, 0xb8, 0xbd, 0xdf, 0x69, 0xf7, 0x3c, 0xd7, 0xb4, 0xdb, 0x56, 0xcb, 0x77, 0x7a, 0x5d,
		0x82, 0x8e, 0xa0, 0x2b, 0x25, 0xbe, 0x99, 0x9e, 0xe7, 0xda, 0x7b, 0xc7, 0x9e, 0x45, 0x39, 0x0b,
		0x21, 0xb7, 0x74, 0xc8, 0x4d, 0xb7, 0xfc, 0xda, 0x96, 0x7d, 0xf8, 0x76, 0xaf, 0xe3, 0xfa, 0x66,
		0xab, 0xe5, 0x5a, 0x3d, 0x02, 0x8f, 0xc0, 0x2b, 0x03, 0x78, 0x0d, 0xdf, 0x6e, 0x7b, 0x96, 0x7b,
		0x60, 0xee, 0x5b, 0x44, 0x1e, 0x91, 0x57, 0x1a, 0xb5, 0xf3, 0x6c, 0xc7, 0xfe, 0xaf, 0xd5, 0xf2,
		0xf7, 0xcc, 0x76, 0xeb, 0x3f, 0x76, 0xcb, 0x7b, 0x4b, 0xd4, 0x11, 0x75, 0xa5, 0x70, 0xbb, 0xae,
		0xdb, 0xf1, 0xac, 0x7d, 0xcf, 0xee, 0xb4, 0xf3, 0xce, 0x09, 0x71, 0x47, 0xdc, 0x2d, 0x19, 0x77,
		0xae, 0xd5, 0xb3, 0x5b, 0xc7, 0xa6, 0xc3, 0x68, 0x47, 0xd4, 0x95, 0x87, 0xba, 0x23, 0xf3, 0x7d,
		0x1e, 0xf1, 0x88, 0x3a, 0xa2, 0xae, 0xdc, 0x62, 0x96, 0x35, 0x05, 0x91, 0x57, 0x49, 0xbc, 0x73,
		0xad, 0x9e, 0xe5, 0x9e, 0x98, 0x7b, 0x8e, 0xc5, 0xa8, 0x47, 0xec, 0x95, 0x5c, 0x59, 0x38, 0x1d,
		0x06, 0x3a, 0x82, 0xad, 0x24, 0xb0, 0xb5, 0x2c, 0xc7, 0xfc, 0xe0, 0x9f, 0x98, 0xae, 0x6d, 0x4e,
		0x6a, 0x59, 0xe2, 0x8e, 0xb8, 0x5b, 0x36, 0xee, 0xcc, 0xd6, 0xbf, 0x7d, 0xc7, 0x6c, 0x6b, 0x72,
		0x86, 0x03, 0xe1, 0x26, 0x1d, 0x6e, 0x27, 0xa6, 0xed, 0x90, 0xca, 0x11, 0x76, 0xe5, 0x47, 0x39,
		0x46, 0x38, 0x42, 0xad, 0x8c, 0x8a, 0xd5, 0x6e, 0xdf, 0x75, 0xe9, 0xa6, 0x84, 0x8e, 0xa8, 0x23,
		0xea, 0x96, 0x8d, 0xba, 0xe3, 0x76, 0xde, 0x25, 0xe1, 0xee, 0x2b, 0x71, 0x57, 0x26, 0xee, 0x0a,
		0xb0, 0xf9, 0xc5, 0x58, 0xa7, 0xc7, 0x7e, 0x09, 0x81, 0xb7, 0x74, 0xe0, 0x59, 0xef, 0x3d, 0xab,
		0xdd, 0xb2, 0x5a, 0xbe, 0xd9, 0x9a, 0x64, 0xdc, 0x43, 0xb7, 0x73, 0xcc, 0x51, 0x62, 0xe2, 0xae,
		0x84, 0x4a, 0x82, 0x70, 0x23, 0xdc, 0x4a, 0x83, 0xdb, 0x74, 0x9a, 0x93, 0x63, 0xc4, 0x04, 0x5e,
		0xd9, 0xc0, 0x63, 0xf9, 0x4a, 0xb4, 0x95, 0x87, 0x36, 0xcf, 0xf2, 0x5b, 0xd6, 0x81, 0x79, 0xec,
		0x78, 0xfe, 0x91, 0xe5, 0xb9, 0xf6, 0x3e, 0x0f, 0xe2, 0xa8, 0xf6, 0xc5, 0x83, 0x38, 0xe8, 0xe4,
		0x0b, 0x4d, 0x25, 0x3c, 0xa0, 0x8e, 0x90, 0x5a, 0x1c, 0xa4, 0x34, 0x52, 0x11, 0x13, 0x5c, 0x22,
		0xe3, 0x95, 0x0e, 0x6a, 0x61, 0x42, 0x4b, 0x60, 0x39, 0xaf, 0x93, 0x2a, 0x98, 0x00, 0x13, 0x08,
		0x30, 0xad, 0xd4, 0xbf, 0x44, 0x98, 0x38, 0xea, 0xa5, 0x91, 0xca, 0x97, 0xe8, 0x12, 0xc9, 0xbd,
		0xb4, 0x51, 0xf3, 0x12, 0x5f, 0xd2, 0xf0, 0xa5, 0x93, 0x6a, 0x97, 0xe8, 0x92, 0x86, 0x2e, 0x9d,
		0xd4, 0xb9, 0x44, 0x97, 0xc8, 0xe2, 0x91, 0xdc, 0x9e, 0x08, 0x5b, 0x6a, 0xfc, 0xd2, 0x4b, 0x6d,
		0x4b, 0x8c, 0x89, 0x64, 0xf8, 0xd8, 0xaa, 0x5a, 0x82, 0x4a, 0x24, 0xa8, 0xb4, 0x51, 0xcf, 0x12,
		0x5f, 0xd2, 0xf0, 0xa5, 0x85, 0x4a, 0x96, 0xb0, 0x12, 0x07, 0x2b, 0x9d, 0xd4, 0xb0, 0x84, 0x97,
		0xc4, 0xa8, 0xc5, 0x88, 0x45, 0x48, 0x2d, 0xb2, 0x42, 0xd4, 0x48, 0xdd, 0x4a, 0x74, 0x49, 0x43,
		0x97, 0x5e, 0x2a, 0x56, 0xe2, 0x4b, 0x1a, 0xbe, 0x34, 0x53, 0xab, 0x12, 0x60, 0xd2, 0x00, 0xa6,
		0x97, 0x2a, 0x95, 0xf8, 0x92, 0xc7, 0xe8, 0x09, 0x2b, 0xc2, 0x6a, 0xe1, 0xb0, 0xd2, 0x4c, 0x65,
		0x4a, 0x80, 0x49, 0x03, 0x18, 0xcb, 0x45, 0xa2, 0x6a, 0xf1, 0xa8, 0xd2, 0x48, 0x35, 0x8a, 0xa9,
		0x16, 0xc5, 0x53, 0x89, 0x62, 0xad, 0x33, 0x8e, 0xb5, 0x18, 0x96, 0x82, 0x84, 0x70, 0xc3, 0x8c,
		0xe3, 0x61, 0x16, 0x64, 0xe1, 0x30, 0x36, 0x76, 0x81, 0x82, 0xb7, 0x91, 0xf6, 0x3f, 0xa9, 0xcb,
		0x60, 0x14, 0x64, 0x9f, 0x26, 0xe1, 0xba, 0x3e, 0x1c, 0xa9, 0xb8, 0x3f, 0x8c, 0xcf, 0xc3, 0x8b,
		0x5a, 0xac, 0xb2, 0x2f, 0xc3, 0xe4, 0x73, 0x2d, 0x8c, 0xd3, 0x2c, 0x88, 0xfb, 0xaa, 0xfe, 0xfd,
		0x1b, 0xe9, 0x83, 0x77, 0xea, 0xa3, 0x64, 0x98, 0x0d, 0xfb, 0xc3, 0x28, 0x2d, 0xbe, 0xab, 0x87,
		0x69, 0x98, 0xd6, 0x23, 0x75, 0xa5, 0xa2, 0xd9, 0x97, 0x7a, 0x14, 0xc6, 0x9f, 0x6b, 0x69, 0x16,
		0x64, 0xaa, 0x36, 0x08, 0xb2, 0xe0, 0x2c, 0x48, 0x55, 0x3d, 0x4a, 0x47, 0xf5, 0x2c, 0xba, 0x4a,
		0x27, 0xff, 0x99, 0xfe, 0x48, 0x2d, 0x56, 0xe1, 0xc5, 0xa7, 0xb3, 0x61, 0x52, 0x0b, 0xb2, 0x2c,
		0x09, 0xcf, 0xc6, 0xd9, 0xc4, 0x80, 0xfc, 0xad, 0xb4, 0xf8, 0xae, 0x7e, 0x67, 0x4b, 0x61, 0x43,
		0x3a, 0x3e, 0x9b, 0xfe, 0x4b, 0xf9, 0xd7, 0xfa, 0x38, 0x0b, 0xa3, 0xf0, 0xff, 0xd4, 0xa0, 0x76,
		0x16, 0xc4, 0x83, 0x2f, 0xe1, 0x20, 0xfb, 0x54, 0x9f, 0xfe, 0x6e, 0x8c, 0xc4, 0x23, 0xdf, 0x49,
		0x65, 0x5b, 0x28, 0x3c, 0x7c, 0xa0, 0x85, 0x8d, 0x55, 0x0c, 0x17, 0x00, 0x77, 0xfa, 0x1b, 0x69,
		0x96, 0x8c, 0xfb, 0x59, 0x3c, 0x23, 0xdd, 0xed, 0x7c, 0x9d, 0xed, 0xd9, 0x23, 0xfa, 0xdd, 0xd9,
		0xe2, 0xfa, 0x76, 0x1a, 0xa6, 0xbe, 0x33, 0x59, 0x55, 0xdf, 0x49, 0x47, 0xbe, 0x17, 0x5d, 0x4d,
		0xdf, 0x6a, 0xcf, 0x96, 0xc7, 0xbc, 0x5d, 0x3a, 0xff, 0xf6, 0x1d, 0xbf, 0xf8, 0x37, 0x7a, 0xd3,
		0xe5, 0xf1, 0x8f, 0x67, 0xcb, 0xb3, 0x57, 0xac, 0xce, 0x6f, 0x0c, 0x4e, 0xfa, 0x58, 0x26, 0x34,
		0x5c, 0x1a, 0xef, 0xd4, 0xf5, 0x04, 0xd8, 0xd9, 0xf5, 0x48, 0x09, 0x75, 0x47, 0xc3, 0x09, 0xd3,
		0x6c, 0xe2, 0x40, 0xa2, 0xe3, 0xb8, 0x71, 0x14, 0xc6, 0x56, 0xa4, 0x2e, 0x55, 0x9c, 0xa5, 0xc6,
		0xee, 0xda, 0xfa, 0x9f, 0x82, 0x2d, 0x0d, 0xbe, 0xde, 0xb3, 0x74, 0xe3, 0x4d, 0xa3, 0xd1, 0xdc,
		0x6e, 0x34, 0xd6, 0xb7, 0x5f, 0x6f, 0xaf, 0xef, 0x6c, 0x6d, 0x6d, 0x34, 0x37, 0xb6, 0x04, 0x1b,
		0xdf, 0x49, 0x06, 0x2a, 0x51, 0x83, 0xbd, 0x09, 0x6a, 0xe3, 0x71, 0x14, 0xd1, 0xd9, 0xf5, 0xe3,
		0x44, 0xda, 0x73, 0x21, 0xc1, 0xc4, 0xa7, 0x34, 0xc2, 0x23, 0x93, 0xde, 0xc8, 0x23, 0x0f, 0xb2,
		0x2c, 0x12, 0x16, 0xd9, 0xa4, 0x47, 0x34, 0x7d, 0x23, 0x99, 0x2c, 0xf7, 0x95, 0xe3, 0x24, 0x82,
		0x1c, 0xc4, 0x18, 0xc7, 0x03, 0x75, 0x1e, 0xc6, 0x6a, 0x50, 0xbb, 0xfd, 0xd0, 0xa4, 0xf9, 0x48,
		0xb1, 0x9b, 0xf5, 0xd0, 0x54, 0x61, 0x81, 0xe6, 0x5d, 0x18, 0x0f, 0x26, 0x6c, 0x59, 0x98, 0x59,
		0xfb, 0xd3, 0x60, 0x22, 0xaf, 0xe0, 0x30, 0xba, 0x89, 0x3a, 0x0f, 0xbf, 0xca, 0x0c, 0xca, 0xb7,
		0xa0, 0x1b, 0xf6, 0x6b, 0x93, 0x58, 0x28, 0x90, 0x8d, 0x19, 0xbd, 0xe1, 0x38, 0xe9, 0x2b, 0xb1,
		0x2c, 0xdd, 0x78, 0xa7, 0xae, 0xbf, 0x0c, 0x93, 0x89, 0x47, 0x18, 0xa3, 0xfc, 0x93, 0x16, 0x5a,
		0xf2, 0xbc, 0x0d, 0x52, 0x33, 0xb9, 0x18, 0x4f, 0xaa, 0x5d, 0x63, 0x77, 0x2d, 0x4b, 0xc6, 0x4a,
		0x6a, 0x6d, 0x76, 0x67, 0x65, 0x01, 0x4c, 0x92, 0x51, 0x28, 0x32, 0xda, 0x0a, 0x65, 0xf6, 0xa8,
		0x1e, 0x64, 0x57, 0xb9, 0x71, 0x65, 0x1e, 0x1f, 0x90, 0x1a, 0x5e, 0x64, 0xd2, 0x02, 0xf1, 0xf4,
		0x00, 0x81, 0x26, 0x00, 0xd1, 0x05, 0x14, 0xda, 0x00, 0x47, 0x1f, 0xe0, 0x68, 0x04, 0x16, 0x9d,
		0x90, 0x49, 0x2b, 0x84, 0xd2, 0x0b, 0xf1, 0x34, 0xa3, 0x30, 0x30, 0x9f, 0x02, 0x12, 0x1f, 0x84,
		0x6e, 0xe3, 0x7a, 0x6e, 0xae, 0x70, 0x7f, 0x96, 0x4d, 0x34, 0x60, 0x08, 0x07, 0x12, 0xf1, 0x00,
		0x24, 0x20, 0x68, 0x44, 0x04, 0x96, 0x90, 0xc0, 0x12, 0x13, 0x4c, 0x82, 0x22, 0x9b, 0xa8, 0x08,
		0x27, 0x2c, 0x30, 0xc4, 0xa5, 0x30, 0x34, 0x52, 0xf1, 0xc5, 0x74, 0xc7, 0x0e, 0x24, 0x7a, 0xdd,
		0x26, 0x88, 0x99, 0xdd, 0x20, 0x11, 0x60, 0x46, 0x69, 0xd6, 0x41, 0xcc, 0x45, 0xa1, 0x36, 0x88,
		0x14, 0x07, 0x98, 0xea, 0xa0, 0x52, 0x1e, 0x78, 0xea, 0x03, 0x4f, 0x81, 0xb0, 0xa9, 0x10, 0x06,
		0x25, 0x02, 0xa1, 0x46, 0x05, 0x14, 0xbc, 0xeb, 0x91, 0xc2, 0x8c, 0xd8, 0xe3, 0x30, 0xce, 0xde,
		0x20, 0xc5, 0xeb, 0x19, 0xfd, 0xd8, 0x02, 0x32, 0xd9, 0x0d, 0xe2, 0x8b, 0xc9, 0x62, 0x7f, 0x84,
		0x8a, 0x6f, 0x78, 0x82, 0x7b, 0xe3, 0x28, 0x8c, 0xe1, 0x12, 0x39, 0x28, 0xaf, 0x7e, 0x60, 0xfe,
		0x49, 0x10, 0x8d, 0x15, 0xb0, 0xfd, 0x07, 0x49, 0xd0, 0xcf, 0xc2, 0x61, 0xdc, 0x0a, 0x2f, 0xc2,
		0x5c, 0x0b, 0x82, 0x77, 0x30, 0xc0, 0x9f, 0x80, 0x2e, 0x1b, 0x7c, 0xa5, 0xcb, 0x56, 0xec, 0xb2,
		0x9b, 0x5b, 0x5b, 0x74, 0x5a, 0x12, 0x71, 0xbd, 0xac, 0x3d, 0xe5, 0x71, 0x06, 0xab, 0x92, 0x54,
		0x72, 0x19, 0x2c, 0x5c, 0xdb, 0x57, 0xb0, 0x78, 0x17, 0x3c, 0xd3, 0xb1, 0xe9, 0x5b, 0x26, 0x8e,
		0xd9, 0xf4, 0x2d, 0xcf, 0x0d, 0xd9, 0xf4, 0xad, 0xf8, 0x01, 0xd8, 0xf4, 0x25, 0xe3, 0x98, 0x41,
		0x81, 0x4d, 0xdf, 0xb2, 0xe9, 0x07, 0x9b, 0xbe, 0xcb, 0x7e, 0xb1, 0xe9, 0x4b, 0x5e, 0xfd, 0x04,
		0xf3, 0xd9, 0xf4, 0x65, 0xb6, 0x7c, 0x8e, 0xcb, 0xb2, 0xe9, 0x5b, 0xb9, 0xcb, 0xb2, 0xe9, 0x4b,
		0x22, 0xae, 0x9d, 0xb5, 0x6c, 0xfa, 0xae, 0x4c, 0x52, 0x31, 0xae, 0x66, 0x81, 0x0c, 0xac, 0xeb,
		0x9b, 0x9b, 0xcd, 0xb6, 0xef, 0x32, 0xcc, 0x65, 0xdb, 0xb7, 0x44, 0x20, 0xb3, 0xed, 0x5b, 0x9e,
		0x1b, 0xb2, 0xed, 0x5b, 0xf1, 0x03, 0xb0, 0xed, 0x4b, 0xce, 0x31, 0x83, 0x02, 0x6e, 0xdb, 0xf7,
		0x2c, 0x8c, 0x83, 0xe4, 0x1a, 0xb0, 0xef, 0xbb, 0x43, 0x5a, 0xbf, 0x02, 0x16, 0xf2, 0x6a, 0x8a,
		0xc5, 0xda, 0xab, 0xdf, 0x21, 0xa6, 0x0f, 0x8e, 0x9b, 0x7c, 0xf0, 0x0e, 0xc2, 0x55, 0x36, 0x82,
		0xef, 0x60, 0x10, 0x7c, 0x46, 0x12, 0xc4, 0x8c, 0x17, 0xd2, 0x6c, 0x17, 0x48, 0x71, 0xcf, 0xb3,
		0x49, 0x58, 0xc4, 0xaf, 0xf1, 0x6c, 0x12, 0x16, 0xeb, 0x9a, 0x16, 0xe9, 0xe4, 0xe4, 0x2b, 0x51,
		0x8c, 0xdf, 0x3b, 0xec, 0x23, 0x38, 0x4f, 0xd4, 0x39, 0x42, 0xc4, 0xbd, 0x3d, 0xbc, 0x6c, 0x1b,
		0xc0, 0xd6, 0xee, 0xac, 0xcc, 0x79, 0xf5, 0x2a, 0x2f, 0x01, 0xea, 0x53, 0x06, 0xc6, 0x3a, 0x40,
		0x23, 0xcb, 0x78, 0x17, 0xdb, 0xb3, 0x4d, 0xe4, 0x5d, 0x6c, 0x0b, 0xb6, 0x94, 0x77, 0xb1, 0xad,
		0xa8, 0xb3, 0xf3, 0x2e, 0x36, 0xb9, 0xcd, 0xbf, 0xd5, 0xbe, 0x9f, 0xed, 0xf8, 0x76, 0x35, 0x78,
		0x51, 0x1b, 0xae, 0x45, 0xbc, 0xa8, 0x8d, 0x61, 0xee, 0xfb, 0x2b, 0xb5, 0x78, 0x65, 0x9b, 0x60,
		0x4b, 0x84, 0x38, 0xec, 0x6d, 0x11, 0x12, 0x0e, 0x84, 0x24, 0x41, 0x99, 0x25, 0x87, 0xdc, 0x12,
		0x03, 0xaa, 0xa4, 0x90, 0x59, 0x42, 0x48, 0x71, 0x45, 0xa1, 0x39, 0x53, 0xbf, 0x5c, 0x29, 0x88,
		0xef, 0x2f, 0x9f, 0xdf, 0xcb, 0xa0, 0x01, 0xd5, 0x27, 0xdd, 0x6a, 0x2d, 0xa8, 0x38, 0xc6, 0x48,
		0x8b, 0x2d, 0xda, 0xc4, 0x94, 0x6a, 0xbd, 0xab, 0x3a, 0x4c, 0x57, 0x88, 0x67, 0x21, 0xf7, 0x0d,
		0x89, 0xba, 0x4f, 0x48, 0xc8, 0x7d, 0x41, 0x62, 0x66, 0x6e, 0x24, 0xcd, 0xd4, 0x08, 0x9c, 0x99,
		0x91, 0x36, 0x13, 0x23, 0x76, 0xe6, 0x45, 0xec, 0x4c, 0x8b, 0xcc, 0x99, 0x95, 0xd5, 0xe6, 0x58,
		0x52, 0xee, 0xbb, 0x31, 0xd2, 0xeb, 0x34, 0x53, 0x97, 0xb5, 0x70, 0x20, 0xc7, 0xc1, 0x8b, 0x64,
		0x59, 0x98, 0x26, 0xa5, 0xff, 0x25, 0x6a, 0x98, 0x55, 0xdc, 0xd0, 0xaa, 0xc4, 0xe1, 0x54, 0xc1,
		0x43, 0xa8, 0x52, 0x87, 0x4d, 0xc5, 0x0f, 0x95, 0x8a, 0x1f, 0x1e, 0x95, 0x3d, 0x24, 0xca, 0x3d,
		0x8d, 0xfb, 0x1f, 0x95, 0xb8, 0xe1, 0x4e, 0xb1, 0xe9, 0xef, 0x9b, 0xda, 0xf1, 0x8d, 0x20, 0x9b,
		0xba, 0x41, 0x96, 0xa9, 0x24, 0x16, 0x77, 0x0e, 0x9e, 0xf1, 0xbf, 0x8f, 0xeb, 0xb5, 0x1d, 0xb3,
		0x76, 0x10, 0xd4, 0xce, 0x4f, 0xff, 0x6e, 0xdc, 0xfc, 0xf5, 0xd7, 0xab, 0x47, 0xde, 0xf8, 0x97,
		0x9c, 0x28, 0x71, 0x2a, 0xe9, 0x03, 0xee, 0xf4, 0xec, 0xf7, 0xfc, 0x94, 0x97, 0xf1, 0x29, 0xb3,
		0xe1, 0xcf, 0x62, 0x94, 0x0d, 0xff, 0xc5, 0x36, 0xfc, 0x05, 0xc8, 0x83, 0x57, 0xb4, 0xd9, 0x2f,
		0xa6, 0x97, 0x21, 0x8e, 0xc4, 0x09, 0xe9, 0x5d, 0xb0, 0xe9, 0x8f, 0xd1, 0xa3, 0x60, 0xd3, 0x1f,
		0xbd, 0x17, 0xc1, 0xa6, 0xbf, 0x3c, 0x9e, 0x25, 0xa6, 0xd7, 0x20, 0x50, 0x28, 0x2a, 0x49, 0x08,
		0xfa, 0x50, 0xe8, 0x79, 0x97, 0xc6, 0x57, 0x95, 0xd6, 0xfd, 0xb6, 0x42, 0x0e, 0x7b, 0x3b, 0xe8,
		0x5c, 0x35, 0x79, 0x93, 0x31, 0xdf, 0x2c, 0x67, 0x9e, 0x59, 0xf4, 0xfc, 0xb2, 0x8c, 0x79, 0xe5,
		0xaa, 0x3c, 0x46, 0x48, 0x0b, 0x01, 0xbc, 0x75, 0x60, 0x54, 0x3a, 0x29, 0xb7, 0x9c, 0xe1, 0xe2,
		0x6a, 0x32, 0x66, 0xf9, 0xf9, 0xaa, 0xdc, 0xdf, 0x58, 0xb2, 0x9f, 0x57, 0xed, 0xdf, 0x98, 0x7e,
		0x5d, 0x2e, 0xf4, 0xcb, 0x03, 0x60, 0x39, 0xbf, 0xa9, 0x24, 0x88, 0x57, 0x05, 0x6d, 0x24, 0x48,
		0x97, 0x98, 0x97, 0x16, 0x9d, 0x87, 0xca, 0xf1, 0xc1, 0xe5, 0x7b, 0x44, 0x09, 0xde, 0x60, 0x44,
		0xe9, 0xa8, 0x76, 0x36, 0x3e, 0x3f, 0x57, 0x49, 0x2d, 0x0d, 0xff, 0xaf, 0xbc, 0x56, 0xc5, 0x5d,
		0x3b, 0xe2, 0x3b, 0x03, 0x4a, 0x8a, 0x00, 0xe5, 0x0e, 0xc4, 0x97, 0xde, 0x03, 0xaf, 0xa2, 0xd7,
		0x5d, 0x61, 0x4f, 0xbb, 0xaa, 0xde, 0x75, 0xe5, 0x3d, 0xea, 0xca, 0x7b, 0xd1, 0xd5, 0xf6, 0x9c,
		0xf5, 0x62, 0x25, 0x65, 0x0f, 0x88, 0x57, 0xa4, 0x94, 0xaa, 0x54, 0x19, 0x55, 0x91, 0x12, 0xaa,
		0xb2, 0x4d, 0xd0, 0x2a, 0x37, 0x3d, 0x05, 0x6c, 0x72, 0x56, 0xbd, 0xa9, 0x29, 0x66, 0x13, 0x53,
		0xcc, 0xa6, 0xa5, 0x8c, 0x4d, 0x4a, 0xbd, 0x3b, 0x37, 0x55, 0x29, 0x8d, 0x8c, 0x52, 0x4b, 0x88,
		0xf9, 0x79, 0xa5, 0xbc, 0x3a, 0x62, 0x5e, 0x7a, 0xa9, 0x68, 0xc7, 0xa4, 0xf2, 0x59, 0x1b, 0x09,
		0x33, 0x36, 0x82, 0x66, 0x6b, 0xa4, 0xcc, 0xd4, 0x88, 0x9b, 0xa5, 0x11, 0x37, 0x43, 0x23, 0x6b,
		0x76, 0x66, 0xb5, 0xb6, 0xde, 0x2b, 0x9f, 0x91, 0x29, 0x22, 0xc6, 0x38, 0x8c, 0xb3, 0x8d, 0x66,
		0x95, 0x01, 0x63, 0x96, 0x3f, 0x9a, 0x15, 0x9a, 0xe0, 0x06, 0xf1, 0x85, 0xaa, 0x5c, 0x73, 0x21,
		0x60, 0x62, 0xea, 0x28, 0x8c, 0x05, 0x4d, 0x43, 0xca, 0x12, 0x22, 0xdf, 0x5e, 0xf7, 0x2e, 0xc5,
		0x1e, 0x81, 0x97, 0xb7, 0x0b, 0x90, 0x3b, 0x1a, 0x47, 0xc1, 0x57, 0x42, 0xf8, 0x11, 0x08, 0x37,
		0xb7, 0xb6, 0x5e, 0x6f, 0x11, 0xc6, 0xb2, 0xb8, 0x48, 0xf5, 0xbf, 0xfd, 0x94, 0x43, 0x2c, 0x1a,
		0xb4, 0x42, 0x38, 0xc4, 0xf2, 0x70, 0xc7, 0xff, 0xbb, 0x2d, 0xd7, 0x2a, 0xc4, 0x6b, 0x1c, 0x5c,
		0x81, 0x82, 0x33, 0x02, 0x8c, 0x31, 0x06, 0x56, 0x9c, 0x74, 0xb4, 0x37, 0xb5, 0xb9, 0x37, 0x31,
		0x99, 0x83, 0x2a, 0xbf, 0xbc, 0xe4, 0x97, 0x59, 0x2d, 0x1c, 0x5d, 0x35, 0x6a, 0x89, 0x0a, 0xfa,
		0x9f, 0x82, 0xb3, 0x30, 0x0a, 0xb3, 0xeb, 0xf2, 0xa7, 0x55, 0x7e, 0x68, 0x05, 0x47, 0x56, 0x16,
		0xf2, 0x0b, 0x39, 0xb2, 0x52, 0x0e, 0x8c, 0x38, 0xb2, 0xc2, 0x91, 0x95, 0x45, 0x2d, 0x65, 0xe9,
		0x23, 0x2b, 0x39, 0x64, 0x55, 0x5a, 0xdd, 0xd4, 0x4a, 0x61, 0x01, 0x07, 0x57, 0x74, 0x4b, 0x07,
		0x02, 0xd2, 0x42, 0xd5, 0xe9, 0x41, 0x4c, 0x9a, 0x10, 0x93, 0x2e, 0x64, 0xa4, 0x8d, 0xd5, 0xe8,
		0xd6, 0x54, 0x36, 0xb8, 0x32, 0xaa, 0x76, 0x6c, 0xe1, 0xbb, 0xe4, 0x52, 0xf1, 0xf0, 0xca, 0x06,
		0x87, 0x57, 0x38, 0xbc, 0xc2, 0xe1, 0x15, 0xf9, 0x29, 0x49, 0x56, 0x6a, 0xaa, 0x26, 0x45, 0x55,
		0x94, 0xaa, 0x2a, 0x4f, 0x59, 0x85, 0x01, 0x97, 0x99, 0xa8, 0xd3, 0xcf, 0x72, 0x73, 0x78, 0xf2,
		0x19, 0x4f, 0x3e, 0x13, 0x9f, 0xe0, 0xa4, 0x25, 0x3a, 0xb1, 0x09, 0x4f, 0x6c, 0xe2, 0x93, 0x99,
		0x00, 0xab, 0x4d, 0x84, 0x15, 0x27, 0xc4, 0xe2, 0x23, 0xe1, 0xc9, 0x67, 0xbf, 0x50, 0x69, 0x89,
		0x3c, 0xf9, 0x2c, 0x4f, 0xe1, 0x3c, 0xcc, 0x76, 0xd5, 0xba, 0x10, 0xb2, 0xba, 0x11, 0x24, 0x73,
		0x24, 0x73, 0x24, 0x73, 0x24, 0x73, 0x24, 0x73, 0x24, 0x73, 0x24, 0x73, 0xcf, 0x26, 0x73, 0xb3,
		0x98, 0x43, 0x36, 0x57, 0xfa, 0x47, 0xc1, 0x7b, 0x88, 0xe7, 0xbb, 0x0a, 0xb9, 0x1c, 0xb9, 0x1c,
		0xb9, 0x1c, 0xb9, 0x1c, 0xb9, 0x5c, 0xf9, 0x1f, 0x89, 0x98, 0x7b, 0x88, 0x2f, 0x55, 0x96, 0x84,
		0x7d, 0x79, 0x97, 0x10, 0xcf, 0xec, 0xe2, 0x0d, 0xc4, 0x92, 0x53, 0xa7, 0xc4, 0x14, 0x2a, 0x38,
		0x95, 0x4a, 0x4d, 0xa9, 0xe2, 0x53, 0xab, 0xf8, 0x14, 0x2b, 0x3b, 0xd5, 0xca, 0x48, 0xb9, 0x42,
		0x52, 0xaf, 0xbc, 0x76, 0xca, 0x83, 0x88, 0xf5, 0x25, 0x1c, 0xa8, 0x9a, 0xa8, 0x04, 0x78, 0x3f,
		0x09, 0x6e, 0x0b, 0x32, 0x49, 0xc6, 0x31, 0x29, 0xdf, 0xbf, 0x64, 0x45, 0xf5, 0x35, 0x69, 0xc7,
		0xa8, 0x08, 0x67, 0x57, 0x0f, 0xcc, 0xbb, 0x3d, 0xa3, 0x62, 0x43, 0xa8, 0x7d, 0x02, 0xcf, 0xab,
		0x10, 0x1a, 0xf3, 0xbf, 0x75, 0x89, 0xe0, 0x2b, 0x5d, 0xe2, 0xa5, 0x2e, 0xd1, 0xdc, 0xde, 0xde,
		0xde, 0xdc, 0xd8, 0xa2, 0x67, 0x60, 0x73, 0x32, 0x79, 0xd6, 0xf0, 0x86, 0x74, 0x31, 0x91, 0x53,
		0xc8, 0x74, 0xf3, 0x03, 0x9a, 0x2c, 0x61, 0xca, 0x59, 0x68, 0xc0, 0x66, 0x87, 0xe8, 0x29, 0x40,
		0x62, 0x87, 0xe8, 0xd7, 0x61, 0xce, 0x0e, 0xd1, 0x0b, 0x0d, 0x64, 0x87, 0x08, 0xa5, 0x5a, 0x10,
		0xdc, 0x21, 0xaa, 0xfc, 0x8c, 0xdc, 0x79, 0xf9, 0xaf, 0xc9, 0xe6, 0xd0, 0x23, 0x2f, 0x36, 0x87,
		0xb4, 0xac, 0x84, 0xd7, 0x59, 0x02, 0x83, 0x87, 0xfb, 0x6f, 0x5d, 0x82, 0xcd, 0xa1, 0x17, 0xbb,
		0x44, 0x63, 0x7d, 0x87, 0x8d, 0x21, 0x0d, 0x5a, 0x31, 0x6b, 0x6c, 0x0c, 0x09, 0x5c, 0x0f, 0x09,
		0x8d, 0xa1, 0x91, 0xac, 0xa2, 0x5e, 0x96, 0x66, 0x4a, 0x68, 0xb8, 0x66, 0x6b, 0xe8, 0x29, 0x48,
		0x62, 0x6b, 0xe8, 0xd7, 0x61, 0xce, 0xd6, 0xd0, 0x0b, 0x0d, 0x64, 0x6b, 0x08, 0xa5, 0x56, 0x10,
		0xdc, 0x1a, 0x9a, 0x1e, 0x8d, 0x2c, 0xce, 0x01, 0x0b, 0xd1, 0xc9, 0x1b, 0x41, 0x36, 0x75, 0x83,
		0x2c, 0x53, 0x49, 0x2c, 0xae, 0x45, 0x64, 0xfc, 0xef, 0xf7, 0xdf, 0x3f, 0xae, 0xd7, 0x76, 0x4e,
		0xff, 0xf9, 0xb8, 0x51, 0xdb, 0x39, 0xcd, 0xbf, 0xdd, 0x98, 0x7e, 0xc9, 0xbf, 0xdf, 0xfc, 0xb8,
		0x5e, 0x6b, 0xdc, 0x7e, 0xbf, 0xf5, 0x71, 0xbd, 0xb6, 0x75, 0xfa, 0xc7, 0x5f, 0x7f, 0xbd, 0xfa,
		0xe3, 0xef, 0xd7, 0x37, 0x4f, 0xff, 0xc1, 0xfa, 0xec, 0x97, 0xfd, 0xf1, 0xcf, 0xef, 0x1f, 0x37,
		0x6a, 0x9b, 0xa7, 0xb7, 0x7f, 0x78, 0xfd, 0x71, 0xbd, 0xb6, 0x79, 0xfa, 0xc7, 0x1f, 0xff, 0x92,
		0x13, 0x83, 0x4e, 0x25, 0x81, 0xa7, 0xd3, 0xb3, 0xdf, 0x13, 0x41, 0x68, 0x08, 0x62, 0xf5, 0x28,
		0xa6, 0x7a, 0x4c, 0x6b, 0x67, 0x61, 0x26, 0xaf, 0x78, 0xcc, 0xcd, 0x62, 0xed, 0xc8, 0xda, 0x91,
		0xb5, 0x23, 0x6b, 0x47, 0xd6, 0x8e, 0xac, 0x1d, 0x57, 0xa6, 0x76, 0x3c, 0x1b, 0x0e, 0x23, 0x15,
		0xc4, 0x12, 0xeb, 0xc6, 0x0d, 0x12, 0x37, 0x31, 0xc4, 0x6d, 0x3c, 0xaa, 0x0d, 0x86, 0x5f, 0x62,
		0x79, 0xd4, 0xed, 0xd6, 0x30, 0x92, 0x37, 0x92, 0x37, 0x92, 0x37, 0x92, 0x37, 0x92, 0x37, 0x92,
		0x37, 0x92, 0x37, 0x92, 0x37, 0x31, 0xe4, 0x6d, 0xa5, 0xcf, 0xbc, 0xa9, 0xf8, 0x1a, 0xe8, 0x07,
		0xf6, 0x48, 0xbc, 0x4f, 0xf7, 0x47, 0x77, 0x9b, 0xd6, 0x6f, 0x6f, 0xbb, 0x9b, 0x7d, 0x53, 0xc5,
		0x5d, 0xd1, 0x72, 0x90, 0x5c, 0xe9, 0x69, 0x82, 0xe3, 0xb3, 0xc9, 0x27, 0x25, 0xe8, 0x3c, 0xc1,
		0x99, 0x41, 0x3c, 0x51, 0x90, 0x27, 0x0a, 0xc2, 0x14, 0x34, 0x3c, 0x51, 0x10, 0xbd, 0x70, 0xe1,
		0x89, 0x82, 0xf2, 0xd8, 0x95, 0x98, 0x13, 0x05, 0xf3, 0x9c, 0x24, 0x70, 0x5f, 0x37, 0xb7, 0x4b,
		0x56, 0x6f, 0x70, 0x83, 0xbd, 0x41, 0xf1, 0x29, 0x54, 0x70, 0x2a, 0x95, 0x9a, 0x52, 0xc5, 0xa7,
		0x56, 0xf1, 0x29, 0x56, 0x76, 0xaa, 0x95, 0xd3, 0x52, 0x59, 0x13, 0xd4, 0x1b, 0x94, 0x92, 0x82,
		0x0b, 0x83, 0xce, 0xa3, 0xe0, 0x22, 0x95, 0x17, 0x14, 0x6e, 0xe3, 0x68, 0x6e, 0x9e, 0x30, 0x7f,
		0x93, 0x95, 0x98, 0xc5, 0x26, 0x68, 0xc9, 0x89, 0x1a, 0x20, 0x61, 0x4b, 0x4f, 0xdc, 0x30, 0x09,
		0x1c, 0x26, 0x91, 0x63, 0x24, 0x74, 0x59, 0x89, 0x5d, 0x58, 0x82, 0x17, 0x9b, 0xe8, 0xef, 0x6a,
		0x6f, 0x11, 0xd7, 0xdd, 0x3c, 0x5e, 0x8a, 0x0b, 0xb8, 0x06, 0x07, 0x8c, 0x00, 0x88, 0x27, 0x02,
		0x08, 0x84, 0x00, 0x88, 0x18, 0xa0, 0x10, 0x04, 0x38, 0xa2, 0x00, 0x47, 0x18, 0xb0, 0x88, 0x83,
		0x4c, 0x02, 0x21, 0x94, 0x48, 0x88, 0x27, 0x14, 0xc2, 0x3b, 0x09, 0x50, 0x9d, 0x85, 0x79, 0x44,
		0x63, 0x5d, 0xb8, 0x99, 0xd2, 0x09, 0x07, 0x12, 0xf1, 0x00, 0x24, 0x20, 0x68, 0x44, 0x04, 0x96,
		0x90, 0xc0, 0x12, 0x13, 0x4c, 0x82, 0x22, 0x9b, 0xa8, 0x08, 0x27, 0x2c, 0xc5, 0x47, 0x2e, 0x6e,
		0x1c, 0xfa, 0xd1, 0x88, 0xab, 0xe2, 0xf1, 0xa5, 0x4a, 0xf2, 0x31, 0x54, 0x80, 0xa8, 0x7b, 0xdb,
		0x8d, 0x68, 0x00, 0xd8, 0x6a, 0xc5, 0xe3, 0xcb, 0x09, 0x18, 0xe8, 0x52, 0x2f, 0x59, 0x45, 0x27,
		0x4c, 0x33, 0x33, 0xcb, 0x12, 0x0c, 0xb7, 0x3a, 0x0a, 0x63, 0x2b, 0x52, 0x93, 0xa8, 0x9f, 0xca,
		0xa7, 0x88, 0x6b, 0xb3, 0xa3, 0x5d, 0xef, 0x59, 0xbc, 0xf1, 0xa6, 0xd1, 0x68, 0x6e, 0x37, 0x1a,
		0xeb, 0xdb, 0xaf, 0xb7, 0xd7, 0x77, 0xb6, 0xb6, 0x36, 0x9a, 0x52, 0x6f, 0xb3, 0xf9, 0xe6, 0x21,
		0x3a, 0xc9, 0x40, 0x25, 0x6a, 0xb0, 0x77, 0x6d, 0xec, 0xae, 0xc5, 0xe3, 0x28, 0xfa, 0x8d, 0x29,
		0x56, 0xb3, 0x58, 0x60, 0x64, 0x08, 0xa9, 0xb5, 0x48, 0xab, 0x53, 0x6b, 0x59, 0x70, 0xb3, 0xe0,
		0x66, 0xc1, 0xcd, 0x82, 0x9b, 0x05, 0x37, 0x0b, 0x6e, 0x16, 0xdc, 0x2c, 0xb8, 0xf3, 0x03, 0x49,
		0x07, 0x2a, 0xce, 0xc2, 0xec, 0x3a, 0x51, 0xe7, 0x48, 0x05, 0x37, 0x42, 0x15, 0x60, 0xcf, 0x96,
		0x76, 0x2f, 0x48, 0x81, 0xf2, 0xc4, 0x2d, 0x30, 0xec, 0x9e, 0xdd, 0xf3, 0x7b, 0xc7, 0x7b, 0x9e,
		0x73, 0xe2, 0x7b, 0x1f, 0xba, 0x16, 0x4a, 0xba, 0x98, 0xde, 0x6f, 0x91, 0x8a, 0x3b, 0xf3, 0xf3,
		0x67, 0xaf, 0xbf, 0x61, 0x2c, 0xfd, 0x16, 0x21, 0x5d, 0xdf, 0xb5, 0xcc, 0xfd, 0xb7, 0xe6, 0x9e,
		0xed, 0xd8, 0xde, 0x87, 0x19, 0x58, 0x7a, 0x48, 0x68, 0x41, 0x46, 0x0d, 0x26, 0x7a, 0x1e, 0x45,
		0x51, 0xd7, 0xb5, 0x0e, 0xec, 0xf7, 0xfe, 0x81, 0x63, 0x1e, 0xf6, 0x0c, 0xb8, 0x47, 0xbb, 0xf9,
		0x93, 0xf8, 0xa9, 0x16, 0x3f, 0x76, 0xf7, 0xa4, 0xe1, 0xbb, 0x9d, 0x63, 0xcf, 0x72, 0x7d, 0xbb,
		0x45, 0x04, 0x11, 0x41, 0x4f, 0x45, 0x90, 0x67, 0x1e, 0x12, 0x36, 0x84, 0xcd, 0x33, 0x60, 0xd3,
		0x6c, 0x10, 0x38, 0x04, 0xce, 0x33, 0x32, 0x56, 0x93, 0x19, 0x8b, 0x08, 0x7a, 0x31, 0x67, 0xee,
		0x41, 0xa2, 0x07, 0xca, 0xe2, 0xd3, 0xdf, 0xe8, 0x95, 0xec, 0x7f, 0xe8, 0x54, 0xb9, 0x12, 0x27,
		0xac, 0x50, 0x89, 0x14, 0x56, 0xa2, 0x84, 0x07, 0x2b, 0x4e, 0x02, 0x44, 0xbb, 0x4c, 0xd3, 0x64,
		0xa6, 0x21, 0x52, 0xf4, 0xac, 0x20, 0x89, 0x92, 0x65, 0xa3, 0x64, 0x16, 0x3a, 0xf6, 0xcd, 0x2e,
		0xf7, 0x78, 0x89, 0x9f, 0x85, 0xe2, 0xc8, 0xf5, 0x4d, 0xe7, 0xb0, 0xe3, 0xda, 0xde, 0xdb, 0x23,
		0x76, 0x3c, 0x89, 0xa0, 0x67, 0x21, 0xe8, 0xee, 0x4f, 0x6c, 0x7b, 0x2e, 0xf7, 0xc5, 0xb6, 0x27,
		0x49, 0x81, 0x6e, 0xc1, 0x9c, 0x48, 0x61, 0xd0, 0x26, 0x54, 0xa4, 0xd4, 0xa3, 0x3d, 0xce, 0x92,
		0x12, 0x3d, 0x8b, 0x46, 0x91, 0x63, 0xb7, 0xdf, 0x71, 0xa4, 0x82, 0xd0, 0x79, 0x06, 0x74, 0x8e,
		0xdb, 0xfb, 0x9d, 0x76, 0xcf, 0x73, 0x4d, 0xbb, 0x6d, 0xb5, 0x7c, 0xa7, 0xd7, 0x25, 0x88, 0x08,
		0xa2, 0x67, 0xc5, 0x1f, 0xd3, 0xf3, 0x5c, 0x7b, 0xef, 0xd8, 0xb3, 0x38, 0xce, 0x4e, 0x08, 0x3d,
		0x19, 0x42, 0xd3, 0x2d, 0x9c, 0xb6, 0x65, 0x1f, 0xbe, 0xdd, 0xeb, 0xb8, 0xbe, 0xd9, 0x6a, 0xb9,
		0x56, 0x8f, 0x40, 0x22, 0x90, 0x9e, 0x03, 0xa4, 0x86, 0x6f, 0xb7, 0x3d, 0xcb, 0x3d, 0x30, 0xf7,
		0x2d, 0x22, 0x89, 0x48, 0x7a, 0x36, 0x35, 0xf2, 0x6c, 0xc7, 0xfe, 0xaf, 0xd5, 0xf2, 0xf7, 0xcc,
		0x76, 0xeb, 0x3f, 0x76, 0xcb, 0x7b, 0x4b, 0x14, 0x11, 0x45, 0xcf, 0xe2, 0x46, 0x5d, 0xb7, 0xe3,
		0x59, 0xfb, 0x9e, 0xdd, 0x69, 0xe7, 0x95, 0x3e, 0x71, 0x44, 0x1c, 0x3d, 0x11, 0x47, 0xae, 0xd5,
		0xb3, 0x5b, 0xc7, 0xa6, 0xc3, 0x68, 0x44, 0x14, 0x3d, 0x1f, 0x45, 0x47, 0xe6, 0xfb, 0x3c, 0x22,
		0x11, 0x45, 0x44, 0xd1, 0xcb, 0x8a, 0x35, 0x72, 0x6c, 0x22, 0x69, 0x21, 0xf1, 0xc8, 0xb5, 0x7a,
		0x96, 0x7b, 0x62, 0xee, 0x39, 0x16, 0xa3, 0x12, 0xb1, 0xf4, 0x42, 0xa6, 0xed, 0x74, 0x18, 0x88,
		0x08, 0x9e, 0x67, 0x82, 0xa7, 0x65, 0x39, 0xe6, 0x07, 0xff, 0xc4, 0x74, 0x6d, 0x73, 0x52, 0xab,
		0x11, 0x47, 0xc4, 0xd1, 0x53, 0x71, 0x64, 0xb6, 0xfe, 0xed, 0x3b, 0x66, 0x1b, 0x54, 0xa3, 0x4c,
		0xf8, 0x54, 0x0d, 0x9f, 0x13, 0xd3, 0x76, 0x48, 0x85, 0x08, 0xa3, 0x97, 0x47, 0x21, 0x46, 0x20,
		0x42, 0xe7, 0x39, 0x15, 0x99, 0xdd, 0xbe, 0xeb, 0x12, 0x4d, 0x09, 0x11, 0x51, 0x44, 0x14, 0x3d,
		0x15, 0x45, 0xc7, 0xed, 0xbc, 0xaa, 0xe7, 0xee, 0x19, 0x71, 0xf4, 0x12, 0x1c, 0x15, 0xe0, 0xf1,
		0x8b, 0x31, 0x35, 0x8f, 0xf5, 0x3d, 0x81, 0xf4, 0x64, 0x20, 0x59, 0xef, 0x3d, 0xab, 0xdd, 0xb2,
		0x5a, 0xbe, 0xd9, 0x9a, 0x64, 0xb8, 0x43, 0xb7, 0x73, 0xcc, 0x51, 0x47, 0xe2, 0xe8, 0x19, 0xcc,
		0x9a, 0xf0, 0x21, 0x7c, 0x9e, 0x0d, 0x9f, 0xe9, 0x74, 0x1a, 0xc7, 0x1c, 0x09, 0xa4, 0x97, 0x02,
		0x89, 0xe5, 0x19, 0xd1, 0xf3, 0x7c, 0xf4, 0x78, 0x96, 0xdf, 0xb2, 0x0e, 0xcc, 0x63, 0xc7, 0xf3,
		0x8f, 0x2c, 0xcf, 0xb5, 0xf7, 0x29, 0x2c, 0x5f, 0xee, 0x8b, 0xc2, 0xf2, 0x95, 0x77, 0x4a, 0x7d,
		0xd4, 0x7b, 0x84, 0x48, 0xd9, 0x10, 0x01, 0x56, 0xe9, 0x11, 0x2c, 0x95, 0xc4, 0x13, 0x44, 0x35,
		0x1e, 0xa1, 0x52, 0x41, 0x39, 0x8a, 0xac, 0xba, 0x23, 0x60, 0x2a, 0xe9, 0x5f, 0x00, 0x4f, 0xfe,
		0x12, 0x31, 0xa5, 0x53, 0x17, 0x60, 0x15, 0x1d, 0xd1, 0x52, 0x09, 0x77, 0x81, 0x55, 0xcb, 0x11,
		0x2f, 0x65, 0xe3, 0x05, 0x59, 0x15, 0x47, 0xb4, 0x94, 0x8d, 0x16, 0x64, 0xf5, 0x1b, 0xd1, 0x52,
		0x49, 0x71, 0x44, 0xae, 0x4b, 0xc4, 0x3c, 0x29, 0xbe, 0x60, 0xab, 0xd9, 0x88, 0x99, 0x4a, 0x18,
		0x2f, 0x96, 0x6a, 0x8d, 0x20, 0xa9, 0x04, 0x24, 0xb0, 0xea, 0x34, 0xe2, 0xa5, 0x6c, 0xbc, 0x40,
		0xaa, 0xd0, 0x08, 0x93, 0xd2, 0x61, 0x82, 0xac, 0x36, 0x23, 0x5c, 0xaa, 0x88, 0x2a, 0x8c, 0x28,
		0x84, 0x88, 0xa6, 0xea, 0x31, 0xa2, 0xa5, 0x6c, 0xb4, 0x60, 0xab, 0xc4, 0x88, 0x97, 0xb2, 0xf1,
		0x02, 0xae, 0x06, 0x23, 0x60, 0xca, 0x06, 0x0c, 0xb6, 0xea, 0x8b, 0x78, 0x29, 0x9f, 0xe1, 0x12,
		0x26, 0x84, 0xc9, 0xa3, 0x30, 0x01, 0x57, 0x71, 0x11, 0x30, 0x65, 0x03, 0x86, 0xe5, 0x10, 0x51,
		0xf2, 0x38, 0x4a, 0x80, 0x55, 0x59, 0x18, 0x6a, 0x2c, 0xf9, 0x2a, 0x2c, 0xd9, 0xeb, 0x28, 0xd7,
		0x3a, 0x99, 0x96, 0x09, 0x0d, 0xa1, 0x86, 0x19, 0xc7, 0xc3, 0x2c, 0xc8, 0xc2, 0x61, 0x6c, 0xec,
		0x0a, 0x0e, 0x9e, 0x46, 0xda, 0xff, 0xa4, 0x2e, 0x83, 0x51, 0x90, 0x7d, 0x9a, 0x84, 0xcb, 0xfa,
		0x70, 0xa4, 0xe2, 0xfe, 0x30, 0x3e, 0x0f, 0x2f, 0x6a, 0xb1, 0xca, 0xbe, 0x0c, 0x93, 0xcf, 0xb5,
		0x30, 0x4e, 0xb3, 0x20, 0xee, 0xab, 0xfa, 0xf7, 0x6f, 0xa4, 0x0f, 0xde, 0xa9, 0x8f, 0x92, 0x61,
		0x36, 0xec, 0x0f, 0xa3, 0xb4, 0xf8, 0xae, 0x1e, 0xa6, 0x61, 0x5a, 0x8f, 0xd4, 0x95, 0x8a, 0x66,
		0x5f, 0xea, 0x51, 0x18, 0x7f, 0xae, 0xa5, 0x59, 0x90, 0xa9, 0xda, 0x20, 0xc8, 0x82, 0xb3, 0x20,
		0x55, 0xf5, 0x28, 0x1d, 0xd5, 0xb3, 0xe8, 0x2a, 0x9d, 0xfc, 0xa7, 0x7e, 0x99, 0xd5, 0xc2, 0xd1,
		0x55, 0xa3, 0x96, 0xa8, 0xa0, 0xff, 0x29, 0x38, 0x0b, 0xa3, 0x30, 0xbb, 0xae, 0x8f, 0x12, 0x75,
		0x1e, 0x7e, 0x55, 0xe9, 0xec, 0x9b, 0x7a, 0x3a, 0x3e, 0x9b, 0xfe, 0x40, 0xfe, 0xb5, 0x7e, 0x1e,
		0x05, 0x17, 0x69, 0x7d, 0xfa, 0xaf, 0xca, 0x0c, 0xe9, 0xf2, 0xdc, 0x47, 0x96, 0x45, 0xc2, 0x1c,
		0x59, 0xba, 0x03, 0xeb, 0xe5, 0xb8, 0x02, 0xef, 0x65, 0x35, 0xd2, 0x2c, 0x19, 0xf7, 0xb3, 0x78,
		0x46, 0x24, 0xdb, 0xf9, 0x8a, 0xd9, 0xb3, 0x05, 0xf3, 0xbb, 0xb3, 0x65, 0xf2, 0xed, 0x34, 0x4c,
		0x7d, 0x67, 0xb2, 0x3e, 0xbe, 0x93, 0x8e, 0x7c, 0x2f, 0xba, 0xf2, 0x8f, 0x32, 0x7b, 0x74, 0xd5,
		0x70, 0xef, 0x2d, 0x82, 0xdf, 0x9d, 0x3e, 0xbb, 0xdf, 0x9b, 0x3e, 0xb3, 0x7f, 0x30, 0x7d, 0xe6,
		0xdf, 0x18, 0x0c, 0x84, 0x07, 0x02, 0x63, 0x8a, 0xe6, 0x74, 0x38, 0x4e, 0xfa, 0xaa, 0x96, 0x0c,
		0xc7, 0x99, 0x4a, 0x6a, 0xe1, 0x40, 0x5c, 0x3c, 0x28, 0xaa, 0x9d, 0x1f, 0x9b, 0x2b, 0x2c, 0xb0,
		0xbe, 0x0b, 0xe3, 0xc9, 0x12, 0x6e, 0x08, 0x33, 0x6b, 0x7f, 0x1a, 0x3c, 0x8d, 0xdd, 0xb5, 0x75,
		0x61, 0x86, 0xe5, 0xa1, 0x43, 0x66, 0x12, 0xba, 0x05, 0xde, 0xb0, 0x5f, 0x9b, 0xa4, 0x0b, 0x89,
		0x61, 0xbc, 0x37, 0x75, 0x07, 0xb1, 0x24, 0xdc, 0x78, 0xa7, 0xae, 0xbf, 0x0c, 0x93, 0x89, 0x47,
		0x18, 0x79, 0x82, 0x14, 0x7a, 0x47, 0xb9, 0xf1, 0x36, 0x48, 0xcd, 0xe4, 0x62, 0x7c, 0xa9, 0xe2,
		0xcc, 0xd8, 0x5d, 0xcb, 0x92, 0xb1, 0x92, 0x5a, 0x7a, 0xdd, 0x59, 0x59, 0x00, 0x93, 0xe4, 0x1b,
		0x8a, 0x7c, 0xb7, 0xc2, 0x44, 0x28, 0xeb, 0x9e, 0x16, 0x98, 0x62, 0x83, 0xc9, 0x6d, 0x3c, 0xce,
		0xcd, 0x14, 0xea, 0x9f, 0x32, 0x09, 0x80, 0x78, 0x22, 0x80, 0x40, 0x08, 0x80, 0x88, 0x01, 0x0a,
		0x41, 0x80, 0x23, 0x0a, 0x70, 0x84, 0x01, 0x8b, 0x38, 0xc8, 0x24, 0x10, 0x42, 0x89, 0x84, 0x78,
		0x42, 0x51, 0x18, 0x28, 0xb7, 0xbb, 0x30, 0x37, 0xb6, 0x4b, 0xed, 0x30, 0xcc, 0x23, 0x1c, 0xeb,
		0xc2, 0xcd, 0x94, 0x4e, 0x3c, 0x90, 0x08, 0x08, 0x20, 0x11, 0x41, 0x23, 0x24, 0xb0, 0xc4, 0x04,
		0x96, 0xa0, 0x60, 0x12, 0x15, 0xd9, 0x84, 0x45, 0x38, 0x71, 0x29, 0x3e, 0x72, 0xef, 0x7a, 0xa4,
		0xb0, 0x22, 0xee, 0x74, 0x33, 0x22, 0x18, 0x0c, 0x12, 0x95, 0x42, 0x84, 0xdd, 0xdb, 0xb6, 0xc4,
		0x1b, 0x00, 0x5b, 0xbb, 0x41, 0x96, 0xa9, 0x24, 0x36, 0x76, 0xd7, 0x3e, 0x62, 0x44, 0xac, 0xff,
		0xfd, 0xfe, 0xfb, 0xc7, 0xf5, 0xda, 0xce, 0xe9, 0x3f, 0x1f, 0x37, 0x6a, 0x3b, 0xa7, 0xf9, 0xb7,
		0x1b, 0xd3, 0x2f, 0xf9, 0xf7, 0x9b, 0x1f, 0xd7, 0x6b, 0x8d, 0xdb, 0xef, 0xb7, 0x3e, 0xae, 0xd7,
		0xb6, 0x4e, 0xff, 0xf8, 0xeb, 0xaf, 0x57, 0x7f, 0xfc, 0xfd, 0xfa, 0xe6, 0xe9, 0x3f, 0xf8, 0x2f,
		0xf9, 0xc1, 0xf0, 0x14, 0x01, 0x64, 0x9d, 0x9e, 0xfd, 0x9e, 0x48, 0x43, 0x47, 0x1a, 0xc7, 0x1d,
		0x75, 0x23, 0x04, 0x46, 0x86, 0x40, 0x06, 0x0a, 0x22, 0x30, 0xb5, 0x96, 0x2d, 0x02, 0xb6, 0x08,
		0xd8, 0x22, 0x60, 0x8b, 0x80, 0x2d, 0x02, 0xb6, 0x08, 0xd8, 0x22, 0x60, 0x8b, 0x20, 0x6f, 0x11,
		0x0c, 0x54, 0x9c, 0x85, 0xd9, 0x75, 0xa2, 0xce, 0x91, 0x3a, 0x04, 0x5b, 0x00, 0xb6, 0xda, 0xb3,
		0xa5, 0xdd, 0x0b, 0x52, 0xa0, 0x3c, 0x71, 0x27, 0xdb, 0xb3, 0x7b, 0x7e, 0xef, 0x78, 0xcf, 0x73,
		0x4e, 0xf2, 0xf3, 0xc9, 0x41, 0xa2, 0xee, 0x49, 0x10, 0x8d, 0x55, 0x0a, 0x53, 0x2c, 0xaf, 0x01,
		0x0b, 0x3b, 0xbb, 0xdf, 0x0a, 0x3b, 0x73, 0xb0, 0xf4, 0x90, 0xd0, 0x82, 0x8c, 0x1a, 0x4c, 0xf4,
		0x3c, 0x8a, 0xa2, 0xae, 0x6b, 0x1d, 0xd8, 0xef, 0xfd, 0x03, 0xc7, 0x3c, 0xe4, 0x95, 0xb1, 0xc4,
		0xcf, 0x93, 0xf1, 0x33, 0x3d, 0xb5, 0xc2, 0xed, 0x1c, 0x7b, 0x96, 0x0b, 0x75, 0xdd, 0x20, 0x11,
		0x24, 0x05, 0x41, 0x9e, 0x79, 0x48, 0xd8, 0x10, 0x36, 0xcf, 0x80, 0x4d, 0xb3, 0x41, 0xe0, 0x10,
		0x38, 0xcf, 0xc8, 0x58, 0x4d, 0x66, 0x2c, 0x22, 0xe8, 0xc5, 0x9c, 0xb9, 0x07, 0x89, 0x1e, 0xde,
		0x70, 0xbe, 0xea, 0x5e, 0xa9, 0x49, 0xff, 0x03, 0xb3, 0x72, 0x25, 0x4e, 0x58, 0xa1, 0x12, 0x29,
		0xac, 0x44, 0x09, 0x0f, 0x56, 0x9c, 0x04, 0x88, 0x76, 0x99, 0xa6, 0xc9, 0x4c, 0x43, 0xa4, 0xe8,
		0x59, 0x41, 0x12, 0x25, 0xcb, 0x46, 0xc9, 0x2c, 0x74, 0xec, 0x9b, 0x5d, 0xee, 0xf1, 0x12, 0x3f,
		0x0b, 0xc5, 0x91, 0xeb, 0x9b, 0xce, 0x61, 0xc7, 0xb5, 0xbd, 0xb7, 0x47, 0xec, 0x78, 0x12, 0x41,
		0xcf, 0x42, 0xd0, 0xdd, 0x9f, 0xd8, 0xf6, 0x5c, 0xee, 0x8b, 0x6d, 0x4f, 0x92, 0x02, 0xdd, 0x82,
		0x39, 0x91, 0xc2, 0xa0, 0x4d, 0xa8, 0x48, 0xa9, 0x47, 0x7b, 0x9c, 0x25, 0x25, 0x7a, 0x16, 0x8d,
		0xa2, 0xe9, 0x85, 0x44, 0x1c, 0xa9, 0x20, 0x74, 0x9e, 0x0e, 0x9d, 0xe3, 0x76, 0x71, 0xf9, 0xa6,
		0xd5, 0xf2, 0x9d, 0x5e, 0x97, 0x20, 0x22, 0x88, 0x9e, 0x15, 0x7f, 0x4c, 0xcf, 0x73, 0xed, 0xbd,
		0x63, 0xcf, 0xe2, 0x38, 0x3b, 0x21, 0xf4, 0x64, 0x08, 0x4d, 0xb7, 0x70, 0x70, 0x2f, 0x61, 0x24,
		0x90, 0x04, 0x01, 0xa9, 0xe1, 0xdb, 0x6d, 0xcf, 0x72, 0x0f, 0xcc, 0x7d, 0x8b, 0x48, 0x22, 0x92,
		0x9e, 0x4d, 0x8d, 0x3c, 0xdb, 0xb1, 0xff, 0x8b, 0x79, 0x9b, 0x3d, 0x51, 0x24, 0x8a, 0x1b, 0x75,
		0xdd, 0x8e, 0x67, 0xed, 0x7b, 0x76, 0xa7, 0x9d, 0x57, 0xfa, 0xc4, 0x11, 0x71, 0xf4, 0x44, 0x1c,
		0xb9, 0x56, 0xcf, 0x6e, 0x1d, 0x9b, 0x0e, 0xa3, 0x11, 0x51, 0xf4, 0x7c, 0x14, 0x1d, 0x99, 0xef,
		0xf3, 0x88, 0x44, 0x14, 0x11, 0x45, 0x2f, 0x2b, 0xd6, 0xc8, 0xb1, 0x89, 0xa4, 0x85, 0xc4, 0x23,
		0xd7, 0xea, 0x59, 0xee, 0x89, 0xb9, 0xe7, 0x58, 0x8c, 0x4a, 0xc4, 0xd2, 0x0b, 0x99, 0xb6, 0xd3,
		0x61, 0x20, 0x22, 0x78, 0x9e, 0x09, 0x9e, 0x96, 0xe5, 0x98, 0x1f, 0xfc, 0x13, 0xd3, 0xb5, 0xcd,
		0x49, 0xad, 0x46, 0x1c, 0x11, 0x47, 0x4f, 0xc5, 0x91, 0xd9, 0xfa, 0xb7, 0xef, 0x98, 0x6d, 0x50,
		0x8d, 0x32, 0xe1, 0x53, 0x35, 0x7c, 0x4e, 0x4c, 0xdb, 0x21, 0x15, 0x22, 0x8c, 0x5e, 0x1e, 0x85,
		0x18, 0x81, 0x08, 0x9d, 0xe7, 0x54, 0x64, 0x76, 0xfb, 0xae, 0x4b, 0x34, 0x25, 0x44, 0x44, 0x11,
		0x51, 0xf4, 0x54, 0x14, 0x1d, 0xb7, 0xf3, 0xaa, 0x9e, 0xbb, 0x67, 0xc4, 0xd1, 0x4b, 0x70, 0x54,
		0x80, 0xc7, 0x2f, 0xc6, 0xd4, 0x3c, 0xd6, 0xf7, 0x04, 0xd2, 0x93, 0x81, 0x64, 0xbd, 0xf7, 0xac,
		0x76, 0xcb, 0x6a, 0xf9, 0x66, 0x6b, 0x92, 0xe1, 0x0e, 0xdd, 0xce, 0x31, 0x47, 0x1d, 0x89, 0xa3,
		0x67, 0x30, 0x6b, 0xc2, 0x87, 0xf0, 0x79, 0x36, 0x7c, 0xa6, 0xd3, 0x69, 0x1c, 0x73, 0x24, 0x90,
		0x5e, 0x0a, 0x24, 0x96, 0x67, 0x44, 0xcf, 0xf3, 0xd1, 0xe3, 0x59, 0x7e, 0xcb, 0x3a, 0x30, 0x8f,
		0x1d, 0xcf, 0x3f, 0xb2, 0x3c, 0xd7, 0xde, 0xa7, 0xb0, 0x7c, 0xb9, 0x2f, 0x0a, 0xcb, 0x57, 0xde,
		0x29, 0xf5, 0x51, 0xef, 0x11, 0x22, 0x65, 0x43, 0x04, 0x58, 0xa5, 0x47, 0xb0, 0x54, 0x12, 0x4f,
		0x10, 0xd5, 0x78, 0x84, 0x4a, 0x05, 0xe5, 0x28, 0xb2, 0xea, 0x8e, 0x80, 0xa9, 0xa4, 0x7f, 0x01,
		0x3c, 0xf9, 0x4b, 0xc4, 0x94, 0x4e, 0x5d, 0x80, 0x55, 0x74, 0x44, 0x4b, 0x25, 0xdc, 0x05, 0x56,
		0x2d, 0x47, 0xbc, 0x94, 0x8d, 0x17, 0x64, 0x55, 0x1c, 0xd1, 0x52, 0x36, 0x5a, 0x90, 0xd5, 0x6f,
		0x44, 0x4b, 0x25, 0xc5, 0x11, 0xb9, 0x2e, 0x11, 0xf3, 0xa4, 0xf8, 0x82, 0xad, 0x66, 0x23, 0x66,
		0x2a, 0x61, 0xbc, 0x58, 0xaa, 0x35, 0x82, 0xa4, 0x12, 0x90, 0xc0, 0xaa, 0xd3, 0x88, 0x97, 0xb2,
		0xf1, 0x02, 0xa9, 0x42, 0x23, 0x4c, 0x4a, 0x87, 0x09, 0xb2, 0xda, 0x8c, 0x70, 0xa9, 0x22, 0xaa,
		0x30, 0xa2, 0x10, 0x22, 0x9a, 0xaa, 0xc7, 0x88, 0x96, 0xb2, 0xd1, 0x82, 0xad, 0x12, 0x23, 0x5e,
		0xca, 0xc6, 0x0b, 0xb8, 0x1a, 0x8c, 0x80, 0x29, 0x1b, 0x30, 0xd8, 0xaa, 0x2f, 0xe2, 0xa5, 0x7c,
		0x86, 0x4b, 0x98, 0x10, 0x26, 0x8f, 0xc2, 0x04, 0x5c, 0xc5, 0x45, 0xc0, 0x94, 0x0d, 0x18, 0x96,
		0x43, 0x44, 0xc9, 0xe3, 0x28, 0x01, 0x56, 0x65, 0x61, 0xa8, 0xb1, 0xe4, 0xab, 0xb0, 0x64, 0xaf,
		0xa3, 0x5c, 0xeb, 0x64, 0x5a, 0x26, 0x34, 0x84, 0x1a, 0x66, 0x1c, 0x0f, 0xb3, 0x20, 0x0b, 0x87,
		0xb1, 0xb1, 0x2b, 0x38, 0x78, 0x1a, 0x69, 0xff, 0x93, 0xba, 0x0c, 0x46, 0x41, 0xf6, 0x69, 0x12,
		0x2e, 0xeb, 0xc3, 0x91, 0x8a, 0xfb, 0xc3, 0xf8, 0x3c, 0xbc, 0xa8, 0xc5, 0x2a, 0xfb, 0x32, 0x4c,
		0x3e, 0xd7, 0xc2, 0x38, 0xcd, 0x82, 0xb8, 0xaf, 0xea, 0xdf, 0xbf, 0x91, 0x3e, 0x78, 0xa7, 0x3e,
		0x4a, 0x86, 0xd9, 0xb0, 0x3f, 0x8c, 0xd2, 0xe2, 0xbb, 0x7a, 0x98, 0x86, 0x69, 0x3d, 0x52, 0x57,
		0x2a, 0x9a, 0x7d, 0xa9, 0x47, 0x61, 0xfc, 0xb9, 0x96, 0x66, 0x41, 0xa6, 0x6a, 0x83, 0x20, 0x0b,
		0xce, 0x82, 0x54, 0xd5, 0xa3, 0x74, 0x54, 0xcf, 0xa2, 0xab, 0x74, 0xf2, 0x9f, 0xfa, 0x65, 0x56,
		0x0b, 0x47, 0x57, 0x8d, 0x5a, 0xa2, 0x82, 0xfe, 0xa7, 0xe0, 0x2c, 0x8c, 0xc2, 0xec, 0xba, 0x3e,
		0x4a, 0xd4, 0x79, 0xf8, 0x55, 0xa5, 0xb3, 0x6f, 0xea, 0xe9, 0xf8, 0x6c, 0xfa, 0x03, 0xf9, 0xd7,
		0xfa, 0xf4, 0x07, 0xd2, 0xe1, 0x38, 0xe9, 0xab, 0x5a, 0x32, 0x1c, 0x67, 0x2a, 0xa9, 0x85, 0x83,
		0xfa, 0xf4, 0xb7, 0xc8, 0x0c, 0xf1, 0xf2, 0xdc, 0x49, 0x96, 0x45, 0xc2, 0x1c, 0x5b, 0xba, 0x43,
		0xeb, 0xed, 0xc8, 0x02, 0xef, 0x6d, 0x35, 0xd2, 0x2c, 0x19, 0xf7, 0xb3, 0x78, 0x46, 0x34, 0xdb,
		0xf9, 0x0a, 0xda, 0xb3, 0x05, 0xf4, 0xbb, 0xb3, 0x65, 0xf3, 0xed, 0x34, 0x4c, 0x7d, 0x67, 0xb2,
		0x5e, 0xbe, 0x93, 0x8e, 0x7c, 0x2f, 0xba, 0xf2, 0x8f, 0x32, 0x7b, 0x74, 0xd5, 0x70, 0xef, 0x2d,
		0x8a, 0xdf, 0x9d, 0xae, 0x85, 0xdf, 0x9b, 0xae, 0x81, 0x3f, 0xf9, 0xdf, 0xbd, 0xe9, 0x12, 0xb8,
		0xd3, 0x15, 0xb0, 0x07, 0xb2, 0x62, 0x98, 0x9c, 0x48, 0x21, 0x28, 0x4a, 0x18, 0xe1, 0xe8, 0xaa,
		0xf9, 0x10, 0xb9, 0xd2, 0x82, 0x45, 0x51, 0x1a, 0xfd, 0xd8, 0x5c, 0x61, 0x51, 0xf7, 0x5d, 0x18,
		0x4f, 0x96, 0x70, 0x43, 0x98, 0x59, 0xfb, 0xd3, 0xc8, 0x6a, 0xec, 0xae, 0xad, 0x0b, 0x33, 0x2c,
		0x8f, 0x23, 0x32, 0x33, 0xd4, 0x2d, 0xf0, 0x86, 0xfd, 0xda, 0x24, 0x97, 0x48, 0x8c, 0xe9, 0x79,
		0xd0, 0x15, 0xcb, 0xd8, 0x8d, 0x77, 0xea, 0xfa, 0xcb, 0x30, 0x99, 0x78, 0x84, 0x91, 0x67, 0x4f,
		0xa1, 0x17, 0x9a, 0x1b, 0x6f, 0x83, 0xd4, 0x4c, 0x2e, 0xc6, 0x97, 0x2a, 0xce, 0x8c, 0xdd, 0xb5,
		0x2c, 0x19, 0x2b, 0xa9, 0x75, 0xda, 0x9d, 0x95, 0x05, 0x30, 0xc9, 0xcc, 0xa1, 0x98, 0x79, 0x2b,
		0x4c, 0x84, 0x52, 0xf2, 0x69, 0xf5, 0x29, 0x36, 0x98, 0xdc, 0xc6, 0xe3, 0xdc, 0x4c, 0xa1, 0xfe,
		0x29, 0x93, 0x00, 0x88, 0x27, 0x02, 0x08, 0x84, 0x00, 0x88, 0x18, 0xa0, 0x10, 0x04, 0x38, 0xa2,
		0x00, 0x47, 0x18, 0xb0, 0x88, 0x83, 0x4c, 0x02, 0x21, 0x94, 0x48, 0x88, 0x27, 0x14, 0x85, 0x81,
		0x72, 0xbb, 0x0b, 0x73, 0x63, 0xbb, 0xe4, 0x56, 0xde, 0x8f, 0x08, 0xc7, 0xba, 0x70, 0x33, 0xa5,
		0x13, 0x0f, 0x24, 0x02, 0x02, 0x48, 0x44, 0xd0, 0x08, 0x09, 0x2c, 0x31, 0x81, 0x25, 0x28, 0x98,
		0x44, 0x45, 0x36, 0x61, 0x11, 0x4e, 0x5c, 0x8a, 0x8f, 0xdc, 0xbb, 0x1e, 0x29, 0xac, 0x88, 0x3b,
		0xdd, 0x8c, 0x08, 0x06, 0x83, 0x44, 0xa5, 0x10, 0x61, 0xf7, 0xb6, 0x2d, 0xf1, 0x06, 0xc0, 0xd6,
		0x6e, 0x90, 0x65, 0x2a, 0x89, 0x8d, 0xdd, 0xb5, 0x8f, 0x18, 0x11, 0xeb, 0x7f, 0xbf, 0xff, 0xfe,
		0x71, 0xbd, 0xb6, 0x13, 0xd4, 0xce, 0xcd, 0xda, 0xc1, 0xe9, 0xdf, 0x1b, 0x7f, 0x36, 0x6e, 0x76,
		0xff, 0xf8, 0x7b, 0xfb, 0xe6, 0xfb, 0x37, 0xff, 0xf9, 0xd1, 0x5f, 0xdb, 0xf8, 0x73, 0xfb, 0x66,
		0x77, 0xce, 0xff, 0x69, 0xde, 0xec, 0xfe, 0xe2, 0xbf, 0xb1, 0x75, 0xf3, 0xfb, 0x83, 0xbf, 0x3a,
		0x79, 0x7f, 0x73, 0xde, 0x0f, 0x34, 0xe6, 0xfc, 0xc0, 0xeb, 0x79, 0x3f, 0xf0, 0x7a, 0xce, 0x0f,
		0xcc, 0x35, 0x69, 0x73, 0xce, 0x0f, 0x6c, 0xdd, 0xfc, 0xf3, 0xe0, 0xef, 0xff, 0xfe, 0xe3, 0xbf,
		0xda, 0xbc, 0xf9, 0xe3, 0x9f, 0x79, 0xff, 0x6f, 0xfb, 0xe6, 0x9f, 0xdd, 0x3f, 0xfe, 0xf8, 0x97,
		0xfc, 0xd4, 0x70, 0x8a, 0xe0, 0x72, 0x9d, 0x9e, 0xfd, 0x9e, 0x7e, 0x47, 0xbf, 0xd3, 0xc9, 0xef,
		0x38, 0x37, 0xab, 0x1b, 0x59, 0x34, 0x32, 0x04, 0xa2, 0x58, 0x90, 0xc4, 0xa9, 0xb5, 0x6c, 0x1f,
		0xb1, 0x7d, 0xc4, 0xf6, 0x11, 0xdb, 0x47, 0x6c, 0x1f, 0xb1, 0x7d, 0xc4, 0xf6, 0x11, 0xdb, 0x47,
		0x79, 0xfb, 0x68, 0xa0, 0xe2, 0x2c, 0xcc, 0xae, 0x13, 0x75, 0x8e, 0xd4, 0x3d, 0xda, 0x02, 0xb0,
		0xd5, 0x9e, 0x2d, 0xed, 0x5e, 0x90, 0x02, 0xe5, 0x89, 0x3b, 0xfd, 0xa7, 0xdd, 0xf3, 0x7b, 0xc7,
		0x7b, 0x9e, 0x73, 0x92, 0x1f, 0x74, 0x0f, 0x12, 0x75, 0x4f, 0x82, 0x68, 0xac, 0x52, 0x98, 0xd6,
		0xc1, 0x1a, 0xb0, 0x42, 0xb8, 0xfb, 0xad, 0x42, 0x38, 0x07, 0x4b, 0x0f, 0x09, 0x2d, 0xc8, 0xa8,
		0xc1, 0x44, 0xcf, 0xa3, 0x28, 0xea, 0xba, 0xd6, 0x81, 0xfd, 0xde, 0x3f, 0x70, 0xcc, 0x43, 0xde,
		0x3d, 0x4c, 0xfc, 0x3c, 0x19, 0x3f, 0xd3, 0xe3, 0x4f, 0xdc, 0xce, 0xb1, 0x67, 0xb9, 0x50, 0xf7,
		0x56, 0x12, 0x41, 0x52, 0x10, 0xe4, 0x99, 0x87, 0x84, 0x0d, 0x61, 0xf3, 0x0c, 0xd8, 0x34, 0x1b,
		0x04, 0x0e, 0x81, 0xf3, 0x8c, 0x8c, 0xd5, 0x64, 0xc6, 0x22, 0x82, 0x5e, 0xcc, 0x99, 0x7b, 0x90,
		0xe8, 0xe1, 0x55, 0xf9, 0xab, 0xee, 0x95, 0x9a, 0xf4, 0x3f, 0x30, 0x2b, 0x57, 0xe2, 0x84, 0x15,
		0x2a, 0x91, 0xc2, 0x4a, 0x94, 0xf0, 0x60, 0xc5, 0x49, 0x80, 0x68, 0x97, 0x69, 0x9a, 0xcc, 0x34,
		0x44, 0x8a, 0x9e, 0x15, 0x24, 0x51, 0xb2, 0x6c, 0x94, 0xcc, 0x42, 0xc7, 0xbe, 0xd9, 0xe5, 0x1e,
		0x2f, 0xf1, 0xb3, 0x50, 0x1c, 0xb9, 0xbe, 0xe9, 0x1c, 0x76, 0x5c, 0xdb, 0x7b, 0x7b, 0xc4, 0x8e,
		0x27, 0x11, 0xf4, 0x2c, 0x04, 0xdd, 0xfd, 0x89, 0x6d, 0xcf, 0xe5, 0xbe, 0xd8, 0xf6, 0x24, 0x29,
		0xd0, 0x2d, 0x98, 0x13, 0x29, 0x0c, 0xda, 0x84, 0x8a, 0x94, 0x7a, 0xb4, 0xc7, 0x59, 0x52, 0xa2,
		0x67, 0xd1, 0x28, 0x9a, 0xde, 0x6c, 0xc5, 0x91, 0x0a, 0x42, 0xe7, 0xe9, 0xd0, 0x39, 0x6e, 0x17,
		0xb7, 0xb8, 0x5a, 0x2d, 0xdf, 0xe9, 0x75, 0x09, 0x22, 0x82, 0xe8, 0x59, 0xf1, 0xc7, 0xf4, 0x3c,
		0xd7, 0xde, 0x3b, 0xf6, 0x2c, 0x8e, 0xb3, 0x13, 0x42, 0x4f, 0x86, 0xd0, 0x74, 0x0b, 0x07, 0xf7,
		0x36, 0x4f, 0x02, 0x49, 0x10, 0x90, 0x1a, 0xbe, 0xdd, 0xf6, 0x2c, 0xf7, 0xc0, 0xdc, 0xb7, 0x88,
		0x24, 0x22, 0xe9, 0xd9, 0xd4, 0xc8, 0xb3, 0x1d, 0xfb, 0xbf, 0x56, 0xeb, 0xee, 0xc6, 0x7b, 0xa2,
		0x88, 0x28, 0x7a, 0x16, 0x37, 0xea, 0xba, 0x1d, 0xcf, 0xda, 0xf7, 0xec, 0x4e, 0x3b, 0xaf, 0xf4,
		0x89, 0x23, 0xe2, 0xe8, 0x89, 0x38, 0x72, 0xad, 0x9e, 0xdd, 0x3a, 0x36, 0x1d, 0x46, 0x23, 0xa2,
		0xe8, 0xf9, 0x28, 0x3a, 0x32, 0xdf, 0xe7, 0x11, 0x89, 0x28, 0x22, 0x8a, 0x5e, 0x56, 0xac, 0x91,
		0x63, 0x13, 0x49, 0x0b, 0x89, 0x47, 0xae, 0xd5, 0xb3, 0xdc, 0x13, 0x73, 0xcf, 0xb1, 0x18, 0x95,
		0x88, 0xa5, 0x17, 0x32, 0x6d, 0xa7, 0xc3, 0x40, 0x44, 0xf0, 0x3c, 0x13, 0x3c, 0x2d, 0xcb, 0x31,
		0x3f, 0xf8, 0x27, 0xa6, 0x6b, 0x9b, 0x93, 0x5a, 0x8d, 0x38, 0x22, 0x8e, 0x9e, 0x8a, 0x23, 0xb3,
		0xf5, 0x6f, 0xdf, 0x31, 0xdb, 0xa0, 0x1a, 0x65, 0xc2, 0xa7, 0x6a, 0xf8, 0x9c, 0x98, 0xb6, 0x43,
		0x2a, 0x44, 0x18, 0xbd, 0x3c, 0x0a, 0x31, 0x02, 0x11, 0x3a, 0xcf, 0xa9, 0xc8, 0xec, 0xf6, 0x5d,
		0x97, 0x68, 0x4a, 0x88, 0x88, 0x22, 0xa2, 0xe8, 0xa9, 0x28, 0x3a, 0x6e, 0xe7, 0x55, 0x3d, 0x77,
		0xcf, 0x88, 0xa3, 0x97, 0xe0, 0xa8, 0x00, 0x8f, 0x5f, 0x8c, 0xa9, 0x79, 0xac, 0xef, 0x09, 0xa4,
		0x27, 0x03, 0xc9, 0x7a, 0xef, 0x59, 0xed, 0x96, 0xd5, 0xf2, 0xcd, 0xd6, 0x24, 0xc3, 0x1d, 0xba,
		0x9d, 0x63, 0x8e, 0x3a, 0x12, 0x47, 0xcf, 0x60, 0xd6, 0x84, 0x0f, 0xe1, 0xf3, 0x6c, 0xf8, 0x4c,
		0xa7, 0xd3, 0x38, 0xe6, 0x48, 0x20, 0xbd, 0x14, 0x48, 0x2c, 0xcf, 0x88, 0x9e, 0xe7, 0xa3, 0xc7,
		0xb3, 0xfc, 0x96, 0x75, 0x60, 0x1e, 0x3b, 0x9e, 0x7f, 0x64, 0x79, 0xae, 0xbd, 0x4f, 0x61, 0xf9,
		0x72, 0x5f, 0x14, 0x96, 0xaf, 0xbc, 0x53, 0xea, 0xa3, 0xde, 0x23, 0x44, 0xca, 0x86, 0x08, 0xb0,
		0x4a, 0x8f, 0x60, 0xa9, 0x24, 0x9e, 0x20, 0xaa, 0xf1, 0x08, 0x95, 0x0a, 0xca, 0x51, 0x64, 0xd5,
		0x1d, 0x01, 0x53, 0x49, 0xff, 0x02, 0x78, 0xf2, 0x97, 0x88, 0x29, 0x9d, 0xba, 0x00, 0xab, 0xe8,
		0x88, 0x96, 0x4a, 0xb8, 0x0b, 0xac, 0x5a, 0x8e, 0x78, 0x29, 0x1b, 0x2f, 0xc8, 0xaa, 0x38, 0xa2,
		0xa5, 0x6c, 0xb4, 0x20, 0xab, 0xdf, 0x88, 0x96, 0x4a, 0x8a, 0x23, 0x72, 0x5d, 0x22, 0xe6, 0x49,
		0xf1, 0x05, 0x5b, 0xcd, 0x46, 0xcc, 0x54, 0xc2, 0x78, 0xb1, 0x54, 0x6b, 0x04, 0x49, 0x25, 0x20,
		0x81, 0x55, 0xa7, 0x11, 0x2f, 0x65, 0xe3, 0x05, 0x52, 0x85, 0x46, 0x98, 0x94, 0x0e, 0x13, 0x64,
		0xb5, 0x19, 0xe1, 0x52, 0x45, 0x54, 0x61, 0x44, 0x21, 0x44, 0x34, 0x55, 0x8f, 0x11, 0x2d, 0x65,
		0xa3, 0x05, 0x5b, 0x25, 0x46, 0xbc, 0x94, 0x8d, 0x17, 0x70, 0x35, 0x18, 0x01, 0x53, 0x36, 0x60,
		0xb0, 0x55, 0x5f, 0xc4, 0x4b, 0xf9, 0x0c, 0x97, 0x30, 0x21, 0x4c, 0x1e, 0x85, 0x09, 0xb8, 0x8a,
		0x8b, 0x80, 0x29, 0x1b, 0x30, 0x2c, 0x87, 0x88, 0x92, 0xc7, 0x51, 0x02, 0xac, 0xca, 0xc2, 0x50,
		0x63, 0xc9, 0x57, 0x61, 0xc9, 0x5e, 0x47, 0xb9, 0xd6, 0xc9, 0xb4, 0x4c, 0x68, 0x08, 0x35, 0xcc,
		0x38, 0x1e, 0x66, 0x41, 0x16, 0x0e, 0x63, 0x63, 0x57, 0x70, 0xf0, 0x34, 0xd2, 0xfe, 0x27, 0x75,
		0x19, 0x8c, 0x82, 0xec, 0xd3, 0x24, 0x5c, 0xd6, 0x87, 0x23, 0x15, 0xf7, 0x87, 0xf1, 0x79, 0x78,
		0x51, 0x8b, 0x55, 0xf6, 0x65, 0x98, 0x7c, 0xae, 0x85, 0x71, 0x9a, 0x05, 0x71, 0x5f, 0xd5, 0xbf,
		0x7f, 0x23, 0x7d, 0xf0, 0x4e, 0x7d, 0x94, 0x0c, 0xb3, 0x61, 0x7f, 0x18, 0xa5, 0xc5, 0x77, 0xf5,
		0x30, 0x0d, 0xd3, 0x7a, 0xa4, 0xae, 0x54, 0x34, 0xfb, 0x52, 0x8f, 0xc2, 0xf8, 0x73, 0x2d, 0xcd,
		0x82, 0x4c, 0xd5, 0x06, 0x41, 0x16, 0x9c, 0x05, 0xa9, 0xaa, 0x47, 0xe9, 0xa8, 0x9e, 0x45, 0x57,
		0xe9, 0xe4, 0x3f, 0xf5, 0xcb, 0xac, 0x16, 0x8e, 0xae, 0x1a, 0xb5, 0x44, 0x05, 0xfd, 0x4f, 0xc1,
		0x59, 0x18, 0x85, 0xd9, 0x75, 0x7d, 0x94, 0xa8, 0xf3, 0xf0, 0xab, 0x4a, 0x67, 0xdf, 0xd4, 0xd3,
		0xf1, 0xd9, 0xf4, 0x07, 0xf2, 0xaf, 0xf5, 0x70, 0x74, 0xd5, 0xac, 0xa5, 0xc3, 0x71, 0xd2, 0x57,
		0xb5, 0x64, 0x38, 0xce, 0x54, 0x52, 0x0b, 0x07, 0xf5, 0xe9, 0x6f, 0x91, 0x19, 0xe2, 0xe5, 0xb9,
		0x93, 0x2c, 0x8b, 0x84, 0x39, 0xb6, 0x74, 0x87, 0xd6, 0xdb, 0x91, 0x05, 0xde, 0xdb, 0x6a, 0xa4,
		0x59, 0x32, 0xee, 0x67, 0xf1, 0x8c, 0x68, 0xb6, 0xf3, 0x15, 0xb4, 0x67, 0x0b, 0xe8, 0x77, 0x67,
		0xcb, 0xe6, 0xdb, 0x69, 0x98, 0xfa, 0xce, 0x64, 0xbd, 0x7c, 0x27, 0x1d, 0xf9, 0x5e, 0x74, 0xe5,
		0x1f, 0x65, 0xf6, 0xe8, 0xaa, 0xe1, 0xde, 0x5b, 0x14, 0xbf, 0x3b, 0x5d, 0x0b, 0xbf, 0x37, 0x5d,
		0x03, 0xdf, 0x1e, 0x5d, 0x35, 0x7b, 0xd3, 0x25, 0x70, 0xa7, 0x2b, 0x60, 0x0f, 0x64, 0xc5, 0x30,
		0x39, 0x91, 0x42, 0x50, 0x94, 0x30, 0x72, 0x3c, 0xd7, 0xd2, 0x70, 0x90, 0x8a, 0x0b, 0x11, 0x45,
		0x41, 0x74, 0xdf, 0x48, 0x61, 0x11, 0xf6, 0x5d, 0x18, 0x0f, 0x8c, 0xdd, 0xb5, 0x0d, 0x61, 0x66,
		0xed, 0x4f, 0xa3, 0xa8, 0xb1, 0xbb, 0xb6, 0x2e, 0xcc, 0xb0, 0x3c, 0x66, 0xc8, 0xcc, 0x46, 0xb7,
		0x70, 0x1b, 0xf6, 0x6b, 0x93, 0xbc, 0x21, 0x31, 0x7e, 0xe7, 0x01, 0x56, 0x2c, 0x3b, 0x37, 0xde,
		0xa9, 0xeb, 0x2f, 0xc3, 0x64, 0x70, 0xe7, 0xb4, 0x42, 0x2f, 0x2f, 0x37, 0xde, 0x06, 0xa9, 0x99,
		0x5c, 0x8c, 0x2f, 0x55, 0x9c, 0x19, 0xbb, 0x6b, 0x59, 0x32, 0x56, 0x52, 0x6b, 0xb2, 0x3b, 0x2b,
		0x0b, 0x60, 0x92, 0x85, 0x43, 0xb1, 0xf0, 0x56, 0x98, 0xc8, 0x0c, 0x78, 0x77, 0x79, 0x55, 0x6e,
		0x44, 0x79, 0xc8, 0x01, 0xa4, 0x86, 0x14, 0x99, 0x54, 0x40, 0x3c, 0x25, 0x40, 0xa0, 0x06, 0x40,
		0x14, 0x01, 0x85, 0x2a, 0xc0, 0x51, 0x06, 0x38, 0xea, 0x80, 0x45, 0x21, 0x64, 0x52, 0x09, 0xa1,
		0x94, 0x42, 0x3c, 0xb5, 0x28, 0x0c, 0xcc, 0x9b, 0xd9, 0xe2, 0x83, 0xd0, 0x6d, 0x5c, 0xcf, 0xcd,
		0x15, 0xee, 0xcf, 0xb2, 0x89, 0x06, 0x0c, 0xe1, 0x40, 0x22, 0x1e, 0x80, 0x04, 0x04, 0x8d, 0x88,
		0xc0, 0x12, 0x12, 0x58, 0x62, 0x82, 0x49, 0x50, 0x64, 0x13, 0x15, 0xe1, 0x84, 0x05, 0x86, 0xb8,
		0x14, 0x86, 0x06, 0xd1, 0xc5, 0x30, 0x09, 0xb3, 0x4f, 0x97, 0x38, 0x01, 0xec, 0x36, 0x47, 0xdc,
		0x99, 0x0e, 0x12, 0x07, 0x66, 0xc4, 0x66, 0x1d, 0xc4, 0x5c, 0x14, 0x82, 0x83, 0x48, 0x74, 0x80,
		0x09, 0x0f, 0x2a, 0xf1, 0x81, 0x27, 0x40, 0xf0, 0x44, 0x08, 0x9b, 0x10, 0x61, 0x10, 0x23, 0x10,
		0x82, 0x54, 0x40, 0xc1, 0xbb, 0x1e, 0x29, 0xcc, 0x88, 0x3d, 0x0e, 0xe3, 0xec, 0x0d, 0x52, 0xbc,
		0x9e, 0xd1, 0x8f, 0x2d, 0x20, 0x93, 0xdd, 0x20, 0xbe, 0x98, 0x2c, 0xf6, 0x47, 0xa8, 0xf8, 0x86,
		0x77, 0x6b, 0x8e, 0x71, 0x14, 0xc6, 0x70, 0x89, 0x1c, 0x94, 0x57, 0x3f, 0x30, 0xff, 0x24, 0x88,
		0xc6, 0x0a, 0xd8, 0xfe, 0x83, 0x24, 0xe8, 0x67, 0xe1, 0x30, 0x6e, 0x85, 0x17, 0x61, 0x96, 0x4e,
		0x1e, 0x84, 0x57, 0x73, 0x95, 0xe1, 0xb2, 0xc1, 0x57, 0xba, 0x6c, 0xc5, 0x2e, 0xbb, 0xb9, 0xb5,
		0x45, 0xa7, 0x25, 0x11, 0xd7, 0xcb, 0x5a, 0x8c, 0x4b, 0xdb, 0xe4, 0xaf, 0x27, 0x40, 0x52, 0x31,
		0xce, 0xa3, 0xe0, 0x22, 0xc5, 0x6b, 0xfd, 0xe6, 0x66, 0xb3, 0xed, 0xbb, 0x0c, 0x73, 0xd9, 0xf6,
		0x2d, 0x11, 0xc8, 0x6c, 0xfb, 0x96, 0xe7, 0x86, 0x6c, 0xfb, 0x56, 0xfc, 0x00, 0x6c, 0xfb, 0x92,
		0x73, 0xcc, 0xa0, 0x80, 0xdb, 0xf6, 0x55, 0xf1, 0xf8, 0x52, 0x25, 0xb9, 0xe8, 0x18, 0xaf, 0xf9,
		0xbb, 0xd1, 0x00, 0xb2, 0xd9, 0x8a, 0xc7, 0xd3, 0xb1, 0x04, 0xba, 0xde, 0x22, 0x57, 0xd5, 0x09,
		0xd3, 0xcc, 0xcc, 0xb2, 0x04, 0xcb, 0xfd, 0x8e, 0xc2, 0xd8, 0x8a, 0xd4, 0x24, 0x7b, 0xa4, 0x58,
		0x7d, 0x23, 0xe3, 0x28, 0xf8, 0x7a, 0xcf, 0xf2, 0x8d, 0x37, 0x8d, 0x46, 0x73, 0xbb, 0xd1, 0x58,
		0xdf, 0x7e, 0xbd, 0xbd, 0xbe, 0xb3, 0xb5, 0xb5, 0xd1, 0xdc, 0x40, 0xda, 0x90, 0xe9, 0x24, 0x03,
		0x95, 0xa8, 0xc1, 0xde, 0xb5, 0xb1, 0xbb, 0x16, 0x8f, 0xa3, 0x88, 0xad, 0x82, 0x95, 0x69, 0x15,
		0x5c, 0xcd, 0x7a, 0x9e, 0x60, 0xad, 0x82, 0xdc, 0x6c, 0xb6, 0x0a, 0xd8, 0x2a, 0x60, 0xab, 0x80,
		0xad, 0x02, 0xb6, 0x0a, 0xd8, 0x2a, 0x20, 0xdf, 0x60, 0xab, 0xa0, 0x94, 0x88, 0x3d, 0x0e, 0xe3,
		0xec, 0xf5, 0x26, 0x60, 0x97, 0x60, 0x9b, 0x23, 0x62, 0x4b, 0x7e, 0x71, 0x44, 0x8c, 0xc4, 0xfa,
		0x09, 0xe6, 0x73, 0x44, 0x8c, 0xe9, 0xf2, 0x39, 0x2e, 0xcb, 0x11, 0xb1, 0xca, 0x5d, 0xb6, 0xb1,
		0xb9, 0xd3, 0xd8, 0x69, 0x6e, 0x6f, 0xee, 0x70, 0x52, 0x8c, 0x84, 0x5c, 0x33, 0x6b, 0x39, 0x29,
		0xb6, 0x0a, 0x16, 0x4a, 0xd7, 0x5a, 0x83, 0x1c, 0xeb, 0x5e, 0xd8, 0xab, 0xcb, 0xa9, 0xd0, 0xf7,
		0x8e, 0xad, 0xbd, 0xf7, 0xbd, 0xe4, 0xf3, 0xdd, 0xe5, 0xfb, 0x9b, 0x60, 0x5f, 0x03, 0xd9, 0x00,
		0x82, 0xda, 0xf8, 0x01, 0x21, 0xb9, 0x3c, 0xeb, 0x68, 0x99, 0x40, 0xe5, 0x59, 0x47, 0xcb, 0x73,
		0x2f, 0x9e, 0x75, 0x54, 0x36, 0x19, 0xe3, 0x59, 0x47, 0xab, 0xc6, 0xbf, 0x61, 0x36, 0x68, 0x8a,
		0x88, 0x1b, 0xa9, 0xe0, 0x3c, 0x51, 0xe7, 0x08, 0x11, 0xf7, 0x76, 0x6e, 0x13, 0x60, 0x4b, 0xc6,
		0xe8, 0xce, 0x4a, 0x9a, 0x57, 0xaf, 0xf2, 0x22, 0xa0, 0x9e, 0x53, 0x30, 0x96, 0x02, 0x1a, 0x59,
		0x26, 0xf5, 0xa4, 0xd8, 0x77, 0xea, 0x5a, 0x3a, 0xe9, 0xc7, 0x98, 0xbc, 0xc5, 0x99, 0xb4, 0x85,
		0x9e, 0xac, 0xc5, 0x98, 0xa4, 0xe5, 0x4d, 0x8e, 0x2f, 0xb3, 0x53, 0xef, 0x56, 0x9f, 0xe4, 0xeb,
		0x01, 0x96, 0x78, 0x13, 0x5c, 0xfe, 0xa7, 0x5e, 0x38, 0xe0, 0x25, 0x96, 0x88, 0x16, 0xf1, 0x12,
		0xcb, 0x95, 0x8f, 0x61, 0xbc, 0xb9, 0x51, 0xbc, 0x6b, 0x08, 0xbd, 0x59, 0x41, 0xf4, 0x4d, 0x0a,
		0xbc, 0xad, 0xf1, 0xa9, 0x0d, 0x0b, 0xde, 0xd6, 0xf8, 0x12, 0x13, 0x79, 0x5b, 0xe3, 0x82, 0x0c,
		0xe5, 0x6d, 0x8d, 0xa4, 0x9b, 0x65, 0x7d, 0x84, 0x62, 0x6f, 0x6b, 0xcc, 0x24, 0x6f, 0x23, 0x14,
		0xe1, 0x78, 0x6a, 0xa5, 0xec, 0x1b, 0x1a, 0xd7, 0x79, 0x43, 0xa3, 0x76, 0x74, 0x00, 0x88, 0x16,
		0xa0, 0xd0, 0x03, 0x38, 0x9a, 0x00, 0x47, 0x17, 0xb0, 0x68, 0x83, 0x4c, 0xfa, 0x20, 0x94, 0x46,
		0x14, 0x1f, 0xad, 0xf8, 0xcd, 0xff, 0x22, 0x62, 0x86, 0x03, 0x15, 0x67, 0x61, 0x76, 0x2d, 0x7b,
		0xe3, 0xbf, 0xa8, 0xe1, 0x25, 0xef, 0x5d, 0xd9, 0xb3, 0xa5, 0xdc, 0x0b, 0x52, 0xa0, 0x81, 0x50,
		0xbb, 0x67, 0xf7, 0xfc, 0xde, 0xf1, 0x9e, 0xe7, 0x9c, 0xf8, 0xde, 0x87, 0xae, 0x25, 0x3d, 0xcc,
		0x4f, 0x15, 0x44, 0x29, 0x84, 0xb4, 0x15, 0xec, 0x4c, 0x18, 0xbb, 0xeb, 0xbb, 0x96, 0xb9, 0xff,
		0xd6, 0xdc, 0xb3, 0x1d, 0xdb, 0xfb, 0x30, 0x03, 0x45, 0x0f, 0x01, 0x15, 0x88, 0xe8, 0xc0, 0x42,
		0xc9, 0xa3, 0x68, 0xe9, 0xba, 0xd6, 0x81, 0xfd, 0xde, 0x3f, 0x70, 0xcc, 0xc3, 0x1e, 0xd0, 0xa1,
		0x14, 0x7f, 0x12, 0x27, 0xe5, 0xe2, 0xc4, 0xee, 0x9e, 0x34, 0x7c, 0xb7, 0x73, 0xec, 0x59, 0xae,
		0x6f, 0xb7, 0x88, 0x14, 0x22, 0x65, 0x1e, 0x52, 0x3c, 0xf3, 0x90, 0xf0, 0x20, 0x3c, 0x7e, 0x02,
		0x8f, 0x66, 0x83, 0x00, 0x21, 0x40, 0x7e, 0x92, 0x69, 0x9a, 0xcc, 0x34, 0x44, 0xca, 0x2f, 0x73,
		0xd7, 0x1e, 0x14, 0x4a, 0x20, 0x2c, 0x3d, 0xe5, 0x21, 0xb3, 0x2b, 0xdf, 0x47, 0xc0, 0xaa, 0x0c,
		0x89, 0x07, 0x56, 0x80, 0x44, 0x04, 0x2b, 0x3d, 0xc2, 0x80, 0x15, 0x1d, 0x81, 0xc0, 0xca, 0x8d,
		0x88, 0x60, 0x85, 0x46, 0x34, 0x54, 0x8b, 0x86, 0x59, 0x28, 0xd8, 0x37, 0xbb, 0xdc, 0x9b, 0x24,
		0x4e, 0x9e, 0x85, 0x17, 0xd7, 0x37, 0x9d, 0xc3, 0x8e, 0x6b, 0x7b, 0x6f, 0x8f, 0xd8, 0x09, 0x24,
		0x52, 0x7e, 0x8a, 0x94, 0xbb, 0x3f, 0xb1, 0x1d, 0xb8, 0xd8, 0x17, 0xdb, 0x81, 0x4c, 0xde, 0x68,
		0xc1, 0x98, 0x88, 0x60, 0xd0, 0x25, 0x24, 0x96, 0x5d, 0xef, 0xf5, 0x38, 0x7b, 0x48, 0x94, 0x3c,
		0x17, 0x2d, 0x8e, 0xdd, 0x7e, 0xc7, 0x2d, 0x7e, 0x42, 0xe4, 0x27, 0x10, 0x39, 0x6e, 0xef, 0x77,
		0xda, 0x3d, 0xcf, 0x35, 0xed, 0xb6, 0xd5, 0xf2, 0x9d, 0x5e, 0x97, 0x60, 0x21, 0x58, 0x7e, 0x1a,
		0x4f, 0x4c, 0xcf, 0x73, 0xed, 0xbd, 0x63, 0xcf, 0xe2, 0x38, 0x33, 0xa1, 0x32, 0x17, 0x2a, 0xd3,
		0xad, 0x8a, 0xb6, 0x65, 0x1f, 0xbe, 0xdd, 0xeb, 0xb8, 0xbe, 0xd9, 0x6a, 0xb9, 0x56, 0x8f, 0x80,
		0x21, 0x60, 0x7e, 0x06, 0x98, 0x86, 0x6f, 0xb7, 0x3d, 0xcb, 0x3d, 0x30, 0xf7, 0x2d, 0x22, 0x86,
		0x88, 0x79, 0x94, 0xba, 0x78, 0xb6, 0x63, 0xff, 0xd7, 0x6a, 0xf9, 0x7b, 0x66, 0xbb, 0xf5, 0x1f,
		0xbb, 0xe5, 0xbd, 0x25, 0x5a, 0x88, 0x96, 0x9f, 0x72, 0x97, 0xae, 0xdb, 0xf1, 0xac, 0x7d, 0xcf,
		0xee, 0xb4, 0xf3, 0x0a, 0x9a, 0x78, 0x21, 0x5e, 0xe6, 0xe0, 0xc5, 0xb5, 0x7a, 0x76, 0xeb, 0xd8,
		0x74, 0x18, 0x5d, 0x88, 0x96, 0xc7, 0xd1, 0x72, 0x64, 0xbe, 0xcf, 0x23, 0x0c, 0xd1, 0x42, 0xb4,
		0xfc, 0x5a, 0x71, 0x44, 0xae, 0x4b, 0xc4, 0x3c, 0x29, 0xbe, 0xb8, 0x56, 0xcf, 0x72, 0x4f, 0xcc,
		0x3d, 0xc7, 0x62, 0x94, 0x21, 0x66, 0x7e, 0x91, 0xf1, 0x3a, 0x1d, 0x06, 0x16, 0x82, 0xe4, 0x11,
		0x90, 0xb4, 0x2c, 0xc7, 0xfc, 0xe0, 0x9f, 0x98, 0xae, 0x6d, 0x4e, 0x6a, 0x23, 0xe2, 0x85, 0x78,
		0x99, 0x87, 0x17, 0xb3, 0xf5, 0x6f, 0xdf, 0x31, 0xdb, 0x60, 0x9a, 0x50, 0xc2, 0xa4, 0x6c, 0x98,
		0x9c, 0x98, 0xb6, 0x43, 0xaa, 0x42, 0xb8, 0xfc, 0x7a, 0x54, 0x61, 0x44, 0x21, 0x44, 0x7e, 0x56,
		0x01, 0xd9, 0xed, 0xbb, 0x2e, 0xcb, 0x94, 0xb0, 0x10, 0x2d, 0x44, 0xcb, 0xfc, 0xb1, 0x96, 0xbc,
		0x5a, 0xe6, 0xee, 0x10, 0xf1, 0xf2, 0x2b, 0x78, 0x29, 0x40, 0xe2, 0x17, 0xe3, 0x50, 0x1e, 0xeb,
		0x66, 0x02, 0x66, 0x2e, 0x60, 0xac, 0xf7, 0x9e, 0xd5, 0x6e, 0x59, 0x2d, 0xdf, 0x6c, 0x4d, 0x32,
		0xd3, 0xa1, 0xdb, 0x39, 0xe6, 0xe8, 0x1c, 0xf1, 0xf2, 0x13, 0x86, 0x4b, 0x98, 0x10, 0x26, 0x8f,
		0xc2, 0x64, 0x3a, 0x05, 0xc5, 0xb1, 0x39, 0x02, 0xe6, 0x57, 0x01, 0xc3, 0x72, 0x88, 0x28, 0x79,
		0x1c, 0x25, 0x9e, 0xe5, 0xb7, 0xac, 0x03, 0xf3, 0xd8, 0xf1, 0xfc, 0x23, 0xcb, 0x73, 0xed, 0x7d,
		0x0a, 0x78, 0x17, 0xfb, 0xa2, 0x80, 0x77, 0x65, 0x9c, 0x0d, 0x5f, 0x6d, 0x45, 0x28, 0x2c, 0x1b,
		0x0a, 0x80, 0xaa, 0x2a, 0x82, 0xa2, 0x94, 0xf8, 0x80, 0xa4, 0x9e, 0x22, 0x24, 0x4a, 0x28, 0xf7,
		0x10, 0x55, 0x52, 0x04, 0x46, 0x29, 0x7d, 0x00, 0xc0, 0x09, 0x51, 0x22, 0x63, 0xe9, 0xd4, 0x02,
		0x50, 0xf5, 0x44, 0x54, 0x94, 0xc2, 0x2d, 0xe0, 0xd4, 0x4d, 0xc4, 0xc5, 0xb2, 0x71, 0x81, 0xa8,
		0x62, 0x22, 0x2a, 0x96, 0x8d, 0x0a, 0x44, 0xb5, 0x12, 0x51, 0x51, 0x4a, 0x31, 0x42, 0xce, 0x49,
		0x64, 0x68, 0xa4, 0x3e, 0x22, 0x36, 0x4a, 0x61, 0x9e, 0x18, 0x2a, 0x23, 0x82, 0xa1, 0x14, 0x30,
		0xc0, 0xa9, 0x89, 0x88, 0x8b, 0x65, 0xe3, 0x02, 0x4a, 0x35, 0x44, 0x38, 0x2c, 0x1d, 0x0e, 0x88,
		0xea, 0x20, 0xc2, 0xa2, 0x8c, 0x28, 0xc1, 0x08, 0x41, 0x28, 0x80, 0xaa, 0x7d, 0x88, 0x8a, 0x65,
		0xa3, 0x02, 0x53, 0xd5, 0x43, 0x5c, 0x2c, 0x1b, 0x17, 0xa0, 0xea, 0x1d, 0x02, 0x63, 0xd9, 0xc0,
		0xc0, 0x54, 0xe9, 0x10, 0x17, 0xcb, 0x67, 0x9a, 0x84, 0x03, 0xe1, 0x80, 0xae, 0xba, 0x21, 0x30,
		0x96, 0x0d, 0x0c, 0x96, 0x1f, 0x44, 0x03, 0xb4, 0x8a, 0x46, 0xb6, 0x7a, 0x46, 0xae, 0x6a, 0x46,
		0xe6, 0xba, 0xc9, 0xb3, 0x4a, 0x96, 0x45, 0xc2, 0x42, 0xa0, 0x61, 0xc6, 0xf1, 0x30, 0x0b, 0xb2,
		0x70, 0x18, 0x1b, 0xbb, 0x02, 0x83, 0x9f, 0x91, 0xf6, 0x3f, 0xa9, 0xcb, 0x60, 0x14, 0x64, 0x9f,
		0x26, 0xe1, 0xee, 0xff, 0xb3, 0x77, 0x46, 0x4b, 0x6d, 0x23, 0xdb, 0xd7, 0xbf, 0x9f, 0xa7, 0xa0,
		0x54, 0xe7, 0x62, 0xa6, 0x6a, 0x1c, 0x03, 0x31, 0x26, 0x70, 0x27, 0xb0, 0x20, 0x3a, 0x31, 0xc6,
		0x65, 0x0b, 0x4e, 0xe6, 0x64, 0x38, 0x2a, 0x61, 0x37, 0x44, 0xff, 0x08, 0xd9, 0x25, 0xc9, 0x24,
		0x7c, 0x33, 0xbc, 0xfb, 0x57, 0xb6, 0x6c, 0x41, 0x62, 0x3c, 0x49, 0xc0, 0x92, 0xf6, 0x6a, 0x2d,
		0x5f, 0x04, 0xe2, 0x84, 0x64, 0x4b, 0x5e, 0xbd, 0xfb, 0xb7, 0xb7, 0x7a, 0x75, 0xd7, 0x47, 0x63,
		0x15, 0x0e, 0x46, 0xe1, 0x95, 0x7f, 0x5d, 0x0b, 0x55, 0xf2, 0x79, 0x14, 0x7d, 0xaa, 0xf9, 0x61,
		0x9c, 0x78, 0xe1, 0x40, 0xd5, 0xbf, 0x7d, 0x23, 0x5e, 0x7a, 0xa7, 0x3e, 0x8e, 0x46, 0xc9, 0x68,
		0x30, 0x0a, 0xe2, 0xec, 0xbb, 0xba, 0x1f, 0xfb, 0x71, 0x3d, 0x50, 0xb7, 0x2a, 0x98, 0x7f, 0xa9,
		0x07, 0x7e, 0xf8, 0xa9, 0x16, 0x27, 0x5e, 0xa2, 0x6a, 0x43, 0x2f, 0xf1, 0x2e, 0xbd, 0x58, 0xd5,
		0x83, 0x78, 0x5c, 0x4f, 0x82, 0xdb, 0x78, 0xfa, 0x4b, 0xfd, 0x26, 0xa9, 0xf9, 0xe3, 0xdb, 0x46,
		0x2d, 0x52, 0xde, 0xe0, 0xa3, 0x77, 0xe9, 0x07, 0x7e, 0x72, 0x57, 0x1f, 0x47, 0xea, 0xca, 0xff,
		0xa2, 0xe2, 0xf9, 0x37, 0xf5, 0x78, 0x72, 0x39, 0xfb, 0x81, 0xf4, 0x6b, 0x7d, 0xf6, 0xef, 0xc9,
		0x4a, 0xc6, 0x72, 0x06, 0x86, 0xa0, 0x41, 0x61, 0x24, 0xde, 0xb5, 0xb8, 0x91, 0x90, 0x4d, 0xf7,
		0xd3, 0xe0, 0x84, 0x25, 0x90, 0x77, 0x7e, 0x38, 0x34, 0xf6, 0x37, 0xb6, 0x84, 0x85, 0x75, 0x38,
		0x4b, 0x12, 0xc6, 0xfe, 0xc6, 0xa6, 0xb0, 0xc0, 0xba, 0xb3, 0xf4, 0x20, 0x33, 0xd9, 0x2e, 0x64,
		0x36, 0x1a, 0xd4, 0xa6, 0x69, 0x51, 0xe0, 0xe9, 0x8d, 0x46, 0x7f, 0x34, 0x89, 0x06, 0x4a, 0xe4,
		0xed, 0x4b, 0x87, 0x83, 0xba, 0xfb, 0x3c, 0x8a, 0xa6, 0x23, 0xc2, 0x48, 0x27, 0x02, 0xa1, 0x47,
		0x60, 0x1a, 0x6f, 0xbd, 0xd8, 0x8c, 0xae, 0x27, 0x37, 0x2a, 0x4c, 0x8c, 0xfd, 0x8d, 0x24, 0x9a,
		0x28, 0xa1, 0x81, 0x3e, 0x8a, 0x32, 0x13, 0x26, 0x21, 0x13, 0x0a, 0x32, 0x5b, 0x7e, 0x24, 0x94,
		0x2e, 0x67, 0x54, 0x26, 0x36, 0x99, 0x2c, 0xf2, 0x71, 0x1a, 0xa6, 0xd0, 0xf1, 0x29, 0x13, 0x00,
		0xc4, 0x83, 0x00, 0x02, 0x10, 0x00, 0x81, 0x01, 0x0a, 0x20, 0xc0, 0x81, 0x02, 0x1c, 0x30, 0x60,
		0x81, 0x83, 0x4c, 0x80, 0x10, 0x0a, 0x12, 0xe2, 0x81, 0xe2, 0x71, 0x17, 0xe1, 0xf5, 0xb6, 0xfc,
		0x24, 0xf4, 0xa8, 0xaf, 0xf0, 0x7a, 0x5b, 0x7a, 0x02, 0x9a, 0x83, 0xc6, 0xa6, 0xf0, 0x30, 0xa5,
		0x03, 0x07, 0x12, 0x78, 0x00, 0x02, 0x08, 0x1a, 0x88, 0xc0, 0x02, 0x09, 0x2c, 0x98, 0x60, 0x02,
		0x8a, 0x6c, 0x50, 0x11, 0x0e, 0x2c, 0xd9, 0x47, 0xee, 0xdc, 0x8d, 0x15, 0x56, 0xc6, 0x9d, 0xf8,
		0x61, 0x22, 0x9e, 0x0d, 0x1e, 0xf3, 0xc1, 0x2e, 0x40, 0xa8, 0x3d, 0x2f, 0xbc, 0x9e, 0xde, 0xdd,
		0x0f, 0x10, 0x89, 0x0a, 0x67, 0x87, 0x59, 0xe3, 0xc4, 0x0f, 0x61, 0x66, 0x5c, 0x30, 0xb0, 0x5d,
		0x0a, 0xfb, 0xdc, 0x0b, 0x26, 0x0a, 0x30, 0xee, 0xa3, 0xc8, 0x1b, 0x24, 0xfe, 0x28, 0x6c, 0xf9,
		0xd7, 0x7e, 0x12, 0x4f, 0x2f, 0x80, 0xdb, 0x52, 0xe7, 0x31, 0x14, 0xbd, 0x2f, 0x1c, 0x8a, 0x05,
		0x0f, 0xc5, 0xc6, 0xf6, 0x5e, 0x63, 0xaf, 0xb9, 0xbb, 0xbd, 0xb7, 0xc3, 0x31, 0x49, 0x20, 0xc6,
		0x8a, 0xf2, 0x82, 0x85, 0xc5, 0x0b, 0x06, 0x50, 0xdb, 0x8f, 0x13, 0x33, 0x49, 0x22, 0x8c, 0xe2,
		0xe2, 0xc4, 0x0f, 0xad, 0x40, 0x4d, 0x6b, 0xdf, 0x18, 0x23, 0xdb, 0x4e, 0x67, 0xb3, 0x47, 0x11,
		0x6f, 0xbd, 0x69, 0x34, 0x9a, 0xbb, 0x8d, 0xc6, 0xe6, 0xee, 0xeb, 0xdd, 0xcd, 0xbd, 0x9d, 0x9d,
		0xad, 0xe6, 0x16, 0x40, 0xc6, 0x35, 0x4e, 0xa3, 0xa1, 0x8a, 0xd4, 0xf0, 0xe0, 0xce, 0xd8, 0xdf,
		0x08, 0x27, 0x41, 0xf0, 0x0b, 0x33, 0x96, 0x3e, 0x91, 0x49, 0x7d, 0x56, 0x23, 0x7c, 0x85, 0x71,
		0x16, 0xa7, 0x2e, 0x2b, 0x8d, 0x13, 0xef, 0x5a, 0xe2, 0x6a, 0x63, 0xb9, 0x83, 0x87, 0x6b, 0xb7,
		0x80, 0x87, 0xaf, 0x4e, 0xc3, 0x56, 0xe2, 0x7a, 0xdb, 0x38, 0x89, 0x26, 0x83, 0x24, 0x9c, 0x37,
		0x83, 0x3b, 0xe9, 0xfd, 0xb2, 0xe7, 0xb7, 0xcb, 0xed, 0xce, 0x6f, 0x92, 0x6b, 0xc7, 0x7e, 0xec,
		0xb6, 0xa7, 0x77, 0xc7, 0x6d, 0xc7, 0x63, 0xd7, 0x09, 0x6e, 0xdd, 0x93, 0xc4, 0x1e, 0xdf, 0x36,
		0x7a, 0x8f, 0x6e, 0x81, 0x9b, 0x3e, 0x71, 0x74, 0xfb, 0xb3, 0x2b, 0x76, 0x1d, 0xef, 0x9a, 0x86,
		0x08, 0xf1, 0x49, 0xc0, 0x48, 0xbc, 0xeb, 0x66, 0x43, 0xb4, 0x25, 0xa2, 0xd9, 0xa0, 0x29, 0xe2,
		0x87, 0xc2, 0xa2, 0x29, 0xe2, 0x05, 0x42, 0xa3, 0x29, 0xe2, 0xf9, 0xc3, 0x81, 0xa6, 0x88, 0x75,
		0x53, 0x19, 0x4d, 0x11, 0xe8, 0x60, 0x4d, 0x53, 0xc4, 0xcb, 0xf2, 0x31, 0x4d, 0x11, 0xfa, 0x81,
		0x00, 0x02, 0x10, 0x00, 0x81, 0x01, 0x0a, 0x20, 0xc0, 0x81, 0x02, 0x1c, 0x30, 0x60, 0x81, 0x83,
		0x4c, 0x80, 0x10, 0x0a, 0x12, 0xe2, 0x81, 0x42, 0x78, 0x27, 0x01, 0xaa, 0xb3, 0xb0, 0x0a, 0x34,
		0x68, 0x8a, 0xa8, 0x0e, 0x78, 0x00, 0x02, 0x08, 0x1a, 0x88, 0xc0, 0x02, 0x09, 0x2c, 0x98, 0x60,
		0x02, 0x8a, 0x6c, 0x50, 0x11, 0x0e, 0x2c, 0xd9, 0x47, 0x8e, 0x69, 0x8a, 0x10, 0xcf, 0x06, 0x8f,
		0xf9, 0xe0, 0x0d, 0x4d, 0x11, 0x6b, 0x7e, 0xd1, 0x14, 0x41, 0xb0, 0x7d, 0x22, 0x6c, 0x9a, 0x22,
		0x38, 0xbd, 0xfd, 0xd3, 0x50, 0xa4, 0x29, 0xa2, 0xf0, 0xa1, 0x88, 0xb9, 0x58, 0x57, 0x9b, 0xd1,
		0x49, 0x7b, 0xc4, 0x5a, 0x5e, 0xb4, 0x47, 0xbc, 0x64, 0x00, 0xd1, 0x1e, 0x91, 0xfb, 0xbc, 0x46,
		0x7b, 0x04, 0x33, 0x96, 0xe0, 0xc8, 0x68, 0x8f, 0x78, 0x59, 0x9c, 0x1a, 0xad, 0xb3, 0x6e, 0x36,
		0x68, 0x90, 0xc0, 0x8d, 0x88, 0x06, 0x89, 0x0a, 0x0f, 0xdc, 0xea, 0x59, 0x24, 0x9a, 0x0d, 0x9a,
		0x24, 0xc4, 0x27, 0x02, 0x23, 0x91, 0xf8, 0x08, 0xe3, 0x61, 0x25, 0xc3, 0x34, 0x3a, 0x99, 0x16,
		0x89, 0x4d, 0x5a, 0x24, 0x7e, 0x2c, 0x30, 0x5a, 0x24, 0x5e, 0x14, 0x22, 0x2d, 0x12, 0x6b, 0x0a,
		0x94, 0x16, 0x09, 0xa2, 0x75, 0x51, 0x1f, 0xa1, 0xd8, 0x85, 0x01, 0x59, 0xc6, 0x0b, 0x94, 0x77,
		0x15, 0xa9, 0x2b, 0x89, 0x19, 0x6f, 0x61, 0x41, 0x10, 0xb8, 0x1f, 0xa2, 0xd1, 0x9d, 0x57, 0x23,
		0xaf, 0x5e, 0xa5, 0x95, 0x78, 0x7d, 0x46, 0x28, 0xe4, 0x5c, 0xc1, 0x91, 0x08, 0xc9, 0x0d, 0xd3,
		0x89, 0x52, 0x18, 0xd2, 0xca, 0x7c, 0xb8, 0x20, 0xf7, 0x21, 0x02, 0xd4, 0xc3, 0x02, 0x99, 0x0f,
		0x05, 0xa4, 0x0c, 0x46, 0xa1, 0xbd, 0x2f, 0x5d, 0x7a, 0x5e, 0x82, 0xb0, 0x22, 0xc7, 0x2e, 0x97,
		0x8c, 0x79, 0xbf, 0xfc, 0x59, 0xb6, 0xdc, 0x08, 0x4a, 0x4e, 0x29, 0xd2, 0x52, 0x09, 0x7c, 0x0a,
		0x29, 0x77, 0x54, 0x95, 0xa7, 0xe5, 0x12, 0x75, 0x6c, 0x4c, 0xc2, 0xa1, 0xba, 0xf2, 0x43, 0x35,
		0xac, 0x2d, 0x3e, 0x84, 0xb2, 0xa5, 0xfc, 0xb0, 0x62, 0x7d, 0x29, 0xb4, 0x92, 0xc7, 0xbb, 0x0c,
		0x87, 0xbc, 0x98, 0x7e, 0xaf, 0xa4, 0xfe, 0xae, 0xc0, 0x7e, 0xae, 0xb4, 0xfe, 0xad, 0xd8, 0x7e,
		0xad, 0xd8, 0xfe, 0xac, 0xcc, 0x7e, 0x6c, 0xb5, 0x99, 0x4b, 0x8a, 0x63, 0x7c, 0x69, 0x76, 0x92,
		0x33, 0xce, 0x57, 0xcd, 0x9f, 0x52, 0x86, 0xbb, 0xac, 0x8d, 0x66, 0xc4, 0x3d, 0x3e, 0x95, 0xf8,
		0xd8, 0x54, 0xf0, 0xe3, 0x52, 0xa9, 0x8f, 0x49, 0xc5, 0x3f, 0x1e, 0x15, 0xff, 0x58, 0x54, 0xf6,
		0xe3, 0x50, 0x3e, 0xe2, 0x90, 0x38, 0x2d, 0x3f, 0xf4, 0x42, 0x44, 0xee, 0x08, 0x27, 0x7a, 0x27,
		0x38, 0x6e, 0x01, 0x8b, 0x3f, 0x51, 0x03, 0x4c, 0xd8, 0xd2, 0x27, 0x6e, 0x98, 0x09, 0x1c, 0x66,
		0x22, 0xc7, 0x98, 0xd0, 0x65, 0x4d, 0xec, 0xc2, 0x26, 0x78, 0xb1, 0x13, 0x7d, 0x16, 0x58, 0xa0,
		0xc2, 0xeb, 0xd9, 0x83, 0x0f, 0xe1, 0x7b, 0xc0, 0xce, 0xe3, 0x94, 0xbd, 0x09, 0xec, 0x26, 0x37,
		0x81, 0xd5, 0x0e, 0x09, 0x80, 0xd0, 0x00, 0x05, 0x11, 0xe0, 0x50, 0x01, 0x0e, 0x19, 0xb0, 0xd0,
		0x41, 0x26, 0x42, 0x08, 0x45, 0x89, 0xec, 0xa3, 0x15, 0xbf, 0x97, 0xda, 0x57, 0x7b, 0xa8, 0xbd,
		0x91, 0x9c, 0x2f, 0xe7, 0xd3, 0xb7, 0xe0, 0x9d, 0x0b, 0x40, 0xb6, 0x4c, 0xc3, 0xd8, 0x71, 0x03,
		0x68, 0x53, 0x52, 0xa8, 0xfd, 0x98, 0xd0, 0xb6, 0x44, 0x43, 0xdc, 0x6c, 0xe9, 0x1e, 0x63, 0x8b,
		0x18, 0x0e, 0xb1, 0x9c, 0x87, 0xd8, 0xf6, 0xce, 0x0e, 0x07, 0x59, 0xb5, 0x40, 0x54, 0x7e, 0x74,
		0x17, 0xdc, 0x66, 0x05, 0x35, 0x89, 0xcb, 0xdc, 0xd7, 0x60, 0xa9, 0x94, 0x10, 0xb8, 0xbf, 0x01,
		0xc8, 0x4c, 0xc2, 0x26, 0xe0, 0x3a, 0x75, 0xc8, 0x26, 0xe0, 0xfa, 0x86, 0x0d, 0x9b, 0x80, 0x39,
		0x07, 0xcc, 0x26, 0xa0, 0xae, 0x65, 0x17, 0x9b, 0x80, 0x6b, 0x9f, 0xbe, 0xd9, 0x04, 0x7c, 0xe9,
		0x8b, 0x4d, 0x40, 0x76, 0x28, 0xd8, 0x04, 0xac, 0xe0, 0x6c, 0xf4, 0xf5, 0x10, 0x63, 0x13, 0x30,
		0xf7, 0x21, 0xc6, 0x26, 0x60, 0xe5, 0x40, 0x54, 0x7e, 0x74, 0x6c, 0x02, 0xc2, 0x26, 0x71, 0xe3,
		0x76, 0x9e, 0x58, 0x84, 0x77, 0x01, 0xd3, 0x30, 0xd9, 0x06, 0x7c, 0x4e, 0x78, 0x6c, 0x03, 0xae,
		0x51, 0x88, 0x6c, 0x03, 0xae, 0x6f, 0xd8, 0xb0, 0x0d, 0x98, 0x73, 0xc0, 0x6c, 0x03, 0xea, 0x5a,
		0x78, 0x01, 0xb5, 0x01, 0x2f, 0xfd, 0xd0, 0x8b, 0xee, 0x00, 0xfa, 0x80, 0x7b, 0xc4, 0x58, 0xc0,
		0x88, 0x78, 0x64, 0xc8, 0xcf, 0xc5, 0x07, 0xbb, 0xf7, 0xd9, 0xd2, 0x2e, 0x57, 0x4b, 0xef, 0x48,
		0x3c, 0xf9, 0x87, 0x47, 0x6a, 0x3c, 0x25, 0x42, 0x1e, 0xa9, 0xa1, 0x47, 0x8d, 0x49, 0xcb, 0xb9,
		0x9e, 0xb5, 0x24, 0x2d, 0xe7, 0x55, 0xab, 0x19, 0x69, 0x39, 0xc7, 0x47, 0x4f, 0x1e, 0xa9, 0xf1,
		0xf2, 0x09, 0x96, 0x47, 0x6a, 0xc0, 0x73, 0x2e, 0xf7, 0x9b, 0xfa, 0x7a, 0xa2, 0xe4, 0x91, 0x1a,
		0x3f, 0x12, 0x15, 0x8f, 0xd4, 0x58, 0x4b, 0xb0, 0x3c, 0x52, 0x03, 0xaf, 0x37, 0xa4, 0x73, 0x4f,
		0x48, 0xf7, 0x63, 0x36, 0xce, 0x16, 0xd7, 0xcb, 0xf3, 0x36, 0xe4, 0x44, 0xc0, 0xf3, 0x36, 0x74,
		0xcd, 0x2f, 0x95, 0x3d, 0x79, 0xe3, 0x97, 0x0a, 0x8d, 0xa3, 0x05, 0x34, 0x4f, 0x25, 0x32, 0xdc,
		0x28, 0xb5, 0xbf, 0x24, 0x03, 0x96, 0xe5, 0xc0, 0xb1, 0x68, 0x18, 0x96, 0x01, 0xbf, 0x65, 0x0d,
		0x1a, 0x21, 0x93, 0x0e, 0xec, 0x64, 0x53, 0x22, 0xa9, 0xe6, 0x41, 0xa6, 0xe5, 0xcc, 0x94, 0xc5,
		0xcf, 0x53, 0xc5, 0xfe, 0x8f, 0x05, 0x0f, 0xee, 0xb2, 0x07, 0x35, 0xde, 0x60, 0x2e, 0x56, 0xf6,
		0xc5, 0x89, 0xaf, 0x98, 0xff, 0xa9, 0x20, 0x79, 0x97, 0x25, 0x6b, 0x18, 0x39, 0x17, 0x38, 0x17,
		0xad, 0x75, 0xee, 0x29, 0x66, 0xf4, 0xe5, 0x3f, 0x16, 0x0a, 0x18, 0x07, 0x46, 0xfa, 0xb9, 0x37,
		0xbf, 0xfe, 0xdc, 0x8b, 0x1a, 0x0d, 0xd9, 0x13, 0xc1, 0x27, 0xa3, 0x28, 0x28, 0x0b, 0x14, 0x7b,
		0x8c, 0x43, 0xe1, 0x6b, 0x65, 0xca, 0x58, 0x03, 0x53, 0xe2, 0xda, 0x96, 0xb2, 0xd6, 0xac, 0x94,
		0xbe, 0x16, 0xa5, 0xf4, 0x35, 0x26, 0xe5, 0xae, 0x1d, 0xd1, 0x8b, 0x4c, 0x8a, 0x3e, 0x36, 0xc0,
		0xc8, 0xc0, 0xb5, 0xf0, 0x71, 0xb3, 0x48, 0x15, 0x59, 0x04, 0x05, 0xab, 0xb6, 0x9c, 0x53, 0x7c,
		0x4a, 0x5b, 0x32, 0x59, 0xe6, 0x92, 0x48, 0x01, 0x4b, 0x1e, 0xcb, 0x5e, 0xd2, 0x28, 0x66, 0xc9,
		0xa2, 0x98, 0x25, 0x89, 0x32, 0x96, 0x1c, 0xea, 0xdd, 0xbf, 0x29, 0xeb, 0x14, 0x9a, 0x85, 0xc4,
		0x4b, 0x1b, 0x6d, 0x5f, 0x4f, 0x2e, 0x65, 0x0d, 0xb5, 0x72, 0x0f, 0x8a, 0x2b, 0x7d, 0x75, 0xbe,
		0x84, 0x55, 0xf8, 0x82, 0x56, 0xdb, 0x4b, 0x59, 0x55, 0x2f, 0x6e, 0xf5, 0xbc, 0xb8, 0x55, 0xf2,
		0xb2, 0x56, 0xc3, 0x57, 0xeb, 0xe1, 0x7b, 0xd9, 0x07, 0xa7, 0xa5, 0x8f, 0xfd, 0xcb, 0x1f, 0xa4,
		0x8f, 0x3b, 0x64, 0xc3, 0xb2, 0x07, 0xa8, 0x0c, 0xfb, 0x99, 0x18, 0xbb, 0x99, 0x24, 0x7b, 0x99,
		0x40, 0x3b, 0x99, 0x34, 0xfb, 0x98, 0x58, 0xbb, 0x98, 0x58, 0x7b, 0x98, 0x4c, 0x3b, 0x58, 0xb5,
		0x57, 0x75, 0x8a, 0xb1, 0x77, 0x09, 0xb4, 0x73, 0x49, 0xb2, 0x6f, 0x2d, 0xdb, 0xb5, 0xd2, 0x29,
		0xbc, 0xaa, 0x4b, 0x47, 0x4b, 0x2c, 0xb8, 0xc6, 0x32, 0xa6, 0x69, 0x19, 0xdd, 0x08, 0xc2, 0x1c,
		0x61, 0x8e, 0x30, 0x47, 0x98, 0x23, 0xcc, 0x11, 0xe6, 0x08, 0x73, 0xcf, 0x86, 0xb9, 0x71, 0x89,
		0xcb, 0x9b, 0xab, 0x4d, 0x73, 0xe9, 0xf6, 0x5e, 0x62, 0x60, 0x2e, 0x0d, 0x47, 0x06, 0xcb, 0x6d,
		0x91, 0xe5, 0xc8, 0x72, 0x64, 0x39, 0xb2, 0x1c, 0x59, 0xae, 0xf8, 0x8f, 0xa4, 0xec, 0x27, 0x56,
		0x59, 0x20, 0x37, 0x2a, 0x89, 0xfc, 0x81, 0x9c, 0xd1, 0x9d, 0x3d, 0xc2, 0x4a, 0xe3, 0x92, 0xb2,
		0x25, 0x8e, 0xa8, 0xad, 0x14, 0xc5, 0x6d, 0xa1, 0x28, 0x71, 0xeb, 0x44, 0xc1, 0x5b, 0x26, 0x4a,
		0xdd, 0x2a, 0x51, 0xfc, 0x16, 0x89, 0xe2, 0xb7, 0x46, 0x94, 0xbd, 0x25, 0x22, 0xb7, 0x39, 0x13,
		0xd9, 0x4e, 0x59, 0xca, 0x58, 0x9f, 0xfd, 0xa1, 0xaa, 0x89, 0x9a, 0x00, 0x1f, 0x4f, 0x82, 0x82,
		0x76, 0x3b, 0x14, 0x7a, 0xd6, 0xa5, 0xc0, 0xdd, 0x34, 0x25, 0x9f, 0x65, 0x29, 0xfd, 0x30, 0xa4,
		0xc5, 0x41, 0x7a, 0x5b, 0x42, 0xe3, 0x03, 0x38, 0x36, 0x4f, 0xe2, 0x31, 0x66, 0x92, 0xcf, 0x9e,
		0x84, 0x19, 0x12, 0xcd, 0xdd, 0xdd, 0xdd, 0xed, 0xad, 0x1d, 0x8e, 0x0c, 0x6c, 0x26, 0x93, 0x17,
		0xcd, 0x05, 0x77, 0x25, 0x94, 0x92, 0x39, 0x85, 0xac, 0x6e, 0x5e, 0xc2, 0x64, 0x09, 0xab, 0x9c,
		0x85, 0x26, 0x6c, 0x76, 0x88, 0x7e, 0x46, 0x48, 0xec, 0x10, 0xfd, 0xb8, 0xcc, 0xd9, 0x21, 0x7a,
		0x61, 0x80, 0xec, 0x10, 0xa1, 0x54, 0x0b, 0x82, 0x3b, 0x44, 0x13, 0x3f, 0x4c, 0xb6, 0x9a, 0x02,
		0x9b, 0x43, 0x4d, 0x36, 0x87, 0xbe, 0xf3, 0x62, 0x73, 0x48, 0xcb, 0x4a, 0x78, 0x93, 0x25, 0x30,
		0x78, 0xba, 0xff, 0x7a, 0x48, 0xb0, 0x39, 0xf4, 0xe2, 0x21, 0xd1, 0xd8, 0xdc, 0x63, 0x63, 0x48,
		0x83, 0x56, 0xcc, 0x06, 0x1b, 0x43, 0x02, 0xef, 0x87, 0x84, 0xc6, 0xd0, 0x58, 0x56, 0x51, 0x2f,
		0xcb, 0x33, 0x25, 0x34, 0x5d, 0xb3, 0x35, 0xf4, 0x33, 0x4a, 0x62, 0x6b, 0xe8, 0xc7, 0x65, 0xce,
		0xd6, 0xd0, 0x0b, 0x03, 0x64, 0x6b, 0x08, 0xa5, 0x56, 0x10, 0xdc, 0x1a, 0x9a, 0x6d, 0x8d, 0x2c,
		0x6e, 0x00, 0x66, 0xa6, 0x93, 0x37, 0x82, 0x62, 0xea, 0x7a, 0x49, 0xa2, 0xa2, 0x50, 0x5c, 0x8b,
		0xc8, 0xf8, 0xdf, 0xaf, 0xbf, 0x7e, 0xd8, 0xac, 0xed, 0x79, 0xb5, 0x2b, 0xb3, 0x76, 0x74, 0xf1,
		0xd7, 0xd6, 0xef, 0x8d, 0xfb, 0xfd, 0xdf, 0xfe, 0xda, 0xbd, 0xff, 0xf6, 0xcd, 0xbf, 0x9f, 0xfa,
		0x6b, 0x5b, 0xbf, 0xef, 0xde, 0xef, 0xaf, 0xf8, 0x93, 0xe6, 0xfd, 0xfe, 0x0f, 0xfe, 0x1b, 0x3b,
		0xf7, 0xbf, 0x2e, 0xfd, 0xd5, 0xe9, 0xfb, 0xdb, 0xab, 0x7e, 0xa0, 0xb1, 0xe2, 0x07, 0x5e, 0xaf,
		0xfa, 0x81, 0xd7, 0x2b, 0x7e, 0x60, 0x65, 0x48, 0xdb, 0x2b, 0x7e, 0x60, 0xe7, 0xfe, 0xef, 0xa5,
		0xbf, 0xff, 0xeb, 0xd3, 0x7f, 0xb5, 0x79, 0xff, 0xdb, 0xdf, 0xab, 0xfe, 0x6c, 0xf7, 0xfe, 0xef,
		0xfd, 0xdf, 0x7e, 0xab, 0xff, 0xba, 0xb5, 0xfd, 0x61, 0xb3, 0xf6, 0xe6, 0xe2, 0xef, 0xad, 0x0f,
		0x9b, 0xb5, 0xad, 0x8b, 0xe9, 0xdf, 0xbc, 0xf8, 0xfb, 0xc3, 0x56, 0x6d, 0x6f, 0xf1, 0xed, 0xf4,
		0xd7, 0xdf, 0xfe, 0x25, 0x27, 0x31, 0x5f, 0x48, 0x1a, 0x51, 0xa7, 0x7d, 0xfb, 0x3d, 0x87, 0x15,
		0x87, 0x95, 0x06, 0xc3, 0x8a, 0x7d, 0x06, 0x31, 0x7d, 0x86, 0xb8, 0x76, 0xe9, 0x27, 0xf2, 0xda,
		0x0c, 0x69, 0x58, 0xec, 0x32, 0xb0, 0xcb, 0xc0, 0x2e, 0x03, 0xbb, 0x0c, 0xec, 0x32, 0xb0, 0xcb,
		0x50, 0x99, 0x2e, 0xc3, 0xe5, 0x68, 0x14, 0x28, 0x2f, 0x94, 0xd8, 0x61, 0xd8, 0x22, 0xb8, 0x89,
		0x01, 0xb7, 0xc9, 0xb8, 0x36, 0x1c, 0x7d, 0x0e, 0xe5, 0xa1, 0xdb, 0x22, 0x30, 0xc2, 0x1b, 0xe1,
		0x8d, 0xf0, 0x46, 0x78, 0x23, 0xbc, 0x11, 0xde, 0x08, 0x6f, 0x84, 0x37, 0xc2, 0xdb, 0xc3, 0x67,
		0xf2, 0x45, 0x66, 0xd7, 0xed, 0x0b, 0xbb, 0x6e, 0x04, 0x37, 0x82, 0x1b, 0xc1, 0x8d, 0xe0, 0x46,
		0x70, 0x23, 0xb8, 0x11, 0xdc, 0x64, 0x81, 0x5b, 0xa5, 0xb7, 0xb5, 0x34, 0xc3, 0x70, 0x94, 0x78,
		0x89, 0x3f, 0x92, 0xd1, 0xf2, 0x33, 0xe2, 0xc1, 0x47, 0x75, 0xe3, 0x8d, 0xe7, 0xfb, 0x71, 0xd7,
		0x47, 0x63, 0x15, 0x0e, 0x66, 0x88, 0x54, 0x0b, 0x55, 0xf2, 0x79, 0x14, 0x7d, 0xaa, 0xf9, 0x61,
		0x9c, 0x78, 0xe1, 0x40, 0xd5, 0xbf, 0x7d, 0x23, 0x5e, 0x7a, 0xa7, 0x3e, 0x8e, 0x46, 0xc9, 0x68,
		0x30, 0x0a, 0xe2, 0xec, 0xbb, 0xfa, 0x34, 0x8f, 0xd7, 0x03, 0x75, 0xab, 0x82, 0xf9, 0x97, 0x7a,
		0xe0, 0x87, 0x9f, 0x6a, 0xb3, 0x7d, 0x9e, 0x6b, 0x43, 0x2f, 0xf1, 0x2e, 0xbd, 0x58, 0xd5, 0x83,
		0x78, 0x5c, 0x4f, 0x82, 0xdb, 0x78, 0xfa, 0xcb, 0xec, 0x64, 0x97, 0xf1, 0x6d, 0xb3, 0x16, 0x29,
		0x6f, 0xf0, 0xd1, 0xbb, 0xf4, 0x03, 0x3f, 0xb9, 0xab, 0x2f, 0x0e, 0xb4, 0x9e, 0x7f, 0x93, 0xee,
		0x1b, 0xce, 0x0d, 0xc3, 0x4b, 0x50, 0xcc, 0xe4, 0x72, 0xfa, 0x49, 0x09, 0xda, 0x32, 0x7c, 0x1e,
		0x10, 0x37, 0x0d, 0xe7, 0xa6, 0xe1, 0x30, 0x05, 0x0d, 0x37, 0x0d, 0x47, 0x2f, 0x5c, 0xb8, 0x69,
		0xb8, 0x3c, 0xba, 0x12, 0xb3, 0x69, 0x78, 0x3a, 0x27, 0x09, 0x5c, 0x90, 0x97, 0xc6, 0x25, 0xab,
		0x37, 0xb8, 0xc5, 0xde, 0xa0, 0xf8, 0x29, 0x54, 0xf0, 0x54, 0x2a, 0x75, 0x4a, 0x15, 0x3f, 0xb5,
		0x8a, 0x9f, 0x62, 0x65, 0x4f, 0xb5, 0x72, 0x5a, 0x2a, 0x1b, 0x82, 0x7a, 0x83, 0x52, 0xa6, 0xe0,
		0x2c, 0xa0, 0xab, 0xc0, 0xbb, 0x8e, 0xe5, 0x25, 0x85, 0x45, 0x1e, 0x4d, 0xc3, 0x13, 0x36, 0xde,
		0x64, 0x4d, 0xcc, 0x62, 0x27, 0x68, 0xc9, 0x13, 0x35, 0xc0, 0x84, 0x2d, 0x7d, 0xe2, 0x86, 0x99,
		0xc0, 0x61, 0x26, 0x72, 0x8c, 0x09, 0x5d, 0xd6, 0xc4, 0x2e, 0x6c, 0x82, 0x17, 0x3b, 0xd1, 0x3f,
		0xd4, 0xde, 0x22, 0x4e, 0xb4, 0xfc, 0x7e, 0x29, 0x2e, 0xe0, 0xa4, 0x4b, 0x30, 0x00, 0x10, 0x0f,
		0x02, 0x08, 0x40, 0x00, 0x04, 0x06, 0x28, 0x80, 0x00, 0x07, 0x0a, 0x70, 0xc0, 0x80, 0x05, 0x0e,
		0x32, 0x01, 0x42, 0x28, 0x48, 0x88, 0x07, 0x0a, 0xe1, 0x9d, 0x04, 0xa8, 0xce, 0xc2, 0x2a, 0xd0,
		0xd8, 0x14, 0x1e, 0xa6, 0x74, 0xe0, 0x40, 0x02, 0x0f, 0x40, 0x00, 0x41, 0x03, 0x11, 0x58, 0x20,
		0x81, 0x05, 0x13, 0x4c, 0x40, 0x91, 0x0d, 0x2a, 0xc2, 0x81, 0x25, 0xfb, 0xc8, 0xc5, 0x2d, 0x87,
		0xfe, 0x6e, 0xc6, 0x55, 0xe1, 0xe4, 0x46, 0x45, 0xe9, 0x32, 0x54, 0x80, 0xac, 0xbb, 0xe8, 0x46,
		0x34, 0x00, 0x62, 0xb5, 0xc2, 0xc9, 0xcd, 0x54, 0x0c, 0x1c, 0x52, 0x2f, 0xb9, 0x8b, 0x6d, 0x3f,
		0x4e, 0xcc, 0x24, 0x89, 0x30, 0x86, 0xd5, 0x89, 0x1f, 0x5a, 0x81, 0x9a, 0x66, 0xfd, 0x58, 0x3e,
		0x22, 0x6e, 0xcc, 0x4f, 0x6f, 0x78, 0x14, 0xf1, 0xd6, 0x9b, 0x46, 0xa3, 0xb9, 0xdb, 0x68, 0x6c,
		0xee, 0xbe, 0xde, 0xdd, 0xdc, 0xdb, 0xd9, 0xd9, 0x6a, 0x4a, 0x3d, 0xb0, 0xf2, 0xab, 0x8b, 0x38,
		0x8d, 0x86, 0x2a, 0x52, 0xc3, 0x83, 0x3b, 0x63, 0x7f, 0x23, 0x9c, 0x04, 0xc1, 0x2f, 0x9c, 0x62,
		0x35, 0xcb, 0x05, 0x46, 0x82, 0x30, 0xb5, 0x66, 0xd3, 0xea, 0x2c, 0x5a, 0x16, 0xdc, 0x2c, 0xb8,
		0x59, 0x70, 0xb3, 0xe0, 0x66, 0xc1, 0xcd, 0x82, 0x9b, 0x05, 0x37, 0x0b, 0xee, 0xf4, 0xcc, 0x81,
		0xa1, 0x0a, 0x13, 0x3f, 0xb9, 0x8b, 0xd4, 0x15, 0x52, 0xc1, 0x8d, 0x50, 0x05, 0xd8, 0xf3, 0x5b,
		0x7b, 0xe0, 0xc5, 0x40, 0xf3, 0xc4, 0x42, 0x18, 0x76, 0xdf, 0xee, 0xbb, 0xfd, 0xb3, 0x03, 0xa7,
		0x7d, 0xee, 0x3a, 0x7f, 0x74, 0x2d, 0x94, 0xe9, 0x62, 0x76, 0x84, 0x5d, 0x2c, 0x6e, 0x07, 0xfb,
		0x7f, 0x7a, 0xfd, 0x05, 0x13, 0xe9, 0xd7, 0x0a, 0xe9, 0xba, 0x3d, 0xcb, 0x3c, 0x7c, 0x6b, 0x1e,
		0xd8, 0x6d, 0xdb, 0xf9, 0x63, 0x2e, 0x96, 0x3e, 0x92, 0x5a, 0x90, 0x55, 0x83, 0xa9, 0x9e, 0xef,
		0xaa, 0xa8, 0xdb, 0xb3, 0x8e, 0xec, 0xf7, 0xee, 0x51, 0xdb, 0x3c, 0xee, 0x1b, 0x70, 0x97, 0x76,
		0xff, 0x3b, 0xf5, 0x53, 0xae, 0x7e, 0xec, 0xee, 0x79, 0xc3, 0xed, 0x9d, 0x9e, 0x39, 0x56, 0xcf,
		0xb5, 0x5b, 0x54, 0x10, 0x15, 0xf4, 0xb3, 0x0a, 0x72, 0xcc, 0x63, 0xca, 0x86, 0xb2, 0x79, 0x86,
		0x6c, 0x9a, 0x0d, 0x0a, 0x87, 0xc2, 0x79, 0xc6, 0x8c, 0xd5, 0xe4, 0x8c, 0x45, 0x05, 0xbd, 0x98,
		0x99, 0xfb, 0x90, 0xea, 0x81, 0x8a, 0xf8, 0xe2, 0x17, 0x8e, 0x4a, 0xf6, 0x3f, 0x74, 0xaa, 0x5c,
		0xa9, 0x13, 0x56, 0xa8, 0x54, 0x0a, 0x2b, 0x51, 0xca, 0x83, 0x15, 0x27, 0x05, 0xa2, 0xdd, 0x4c,
		0xd3, 0xe4, 0x4c, 0x43, 0xa5, 0xe8, 0x59, 0x41, 0x52, 0x25, 0x79, 0xab, 0x64, 0x9e, 0x3a, 0x0e,
		0xcd, 0x2e, 0x9f, 0xf1, 0x52, 0x3f, 0x6b, 0xd5, 0x51, 0xcf, 0x35, 0xdb, 0xc7, 0xa7, 0x3d, 0xdb,
		0x79, 0x7b, 0xc2, 0x8e, 0x27, 0x15, 0xf4, 0x2c, 0x05, 0x3d, 0xfc, 0x8e, 0x6d, 0xcf, 0x7c, 0x5f,
		0x6c, 0x7b, 0x12, 0x0a, 0x74, 0x4b, 0xe6, 0x54, 0x0a, 0x93, 0x36, 0xa5, 0x22, 0xa5, 0x1e, 0xed,
		0x73, 0x2d, 0x29, 0xd5, 0xb3, 0x6e, 0x15, 0xb5, 0xed, 0xce, 0x3b, 0x2e, 0xa9, 0xa0, 0x74, 0x9e,
		0x21, 0x9d, 0xb3, 0xce, 0xe1, 0x69, 0xa7, 0xef, 0xf4, 0x4c, 0xbb, 0x63, 0xb5, 0xdc, 0x76, 0xbf,
		0x4b, 0x11, 0x51, 0x44, 0xcf, 0xca, 0x3f, 0xa6, 0xe3, 0xf4, 0xec, 0x83, 0x33, 0xc7, 0xe2, 0x72,
		0x76, 0x4a, 0xe8, 0xa7, 0x25, 0x34, 0x7b, 0x84, 0xd3, 0xb1, 0xec, 0xe3, 0xb7, 0x07, 0xa7, 0x3d,
		0xd7, 0x6c, 0xb5, 0x7a, 0x56, 0x9f, 0x42, 0xa2, 0x90, 0x9e, 0x23, 0xa4, 0x86, 0x6b, 0x77, 0x1c,
		0xab, 0x77, 0x64, 0x1e, 0x5a, 0x54, 0x12, 0x95, 0xf4, 0x6c, 0x34, 0x72, 0xec, 0xb6, 0xfd, 0x5f,
		0xab, 0xe5, 0x1e, 0x98, 0x9d, 0xd6, 0x7f, 0xec, 0x96, 0xf3, 0x96, 0x2a, 0xa2, 0x8a, 0x9e, 0xc5,
		0x46, 0xdd, 0xde, 0xa9, 0x63, 0x1d, 0x3a, 0xf6, 0x69, 0x27, 0xad, 0xf4, 0xa9, 0x23, 0xea, 0xe8,
		0x27, 0x75, 0xd4, 0xb3, 0xfa, 0x76, 0xeb, 0xcc, 0x6c, 0x33, 0x1b, 0x51, 0x45, 0xcf, 0x57, 0xd1,
		0x89, 0xf9, 0x3e, 0xcd, 0x48, 0x54, 0x11, 0x55, 0xf4, 0xb2, 0x62, 0x8d, 0x8c, 0x4d, 0x25, 0xad,
		0x25, 0x1f, 0xf5, 0xac, 0xbe, 0xd5, 0x3b, 0x37, 0x0f, 0xda, 0x16, 0xb3, 0x12, 0xb5, 0xf4, 0x42,
		0xd2, 0x6e, 0x9f, 0x32, 0x11, 0x51, 0x3c, 0xcf, 0x14, 0x4f, 0xcb, 0x6a, 0x9b, 0x7f, 0xb8, 0xe7,
		0x66, 0xcf, 0x36, 0xa7, 0xb5, 0x1a, 0x75, 0x44, 0x1d, 0xfd, 0xac, 0x8e, 0xcc, 0xd6, 0xbf, 0xdd,
		0xb6, 0xd9, 0x01, 0xf5, 0x28, 0x53, 0x3e, 0x65, 0xcb, 0xe7, 0xdc, 0xb4, 0xdb, 0x44, 0x21, 0xca,
		0xe8, 0xe5, 0x59, 0x88, 0x19, 0x88, 0xd2, 0x79, 0x4e, 0x45, 0x66, 0x77, 0x1e, 0xba, 0x44, 0x33,
		0x20, 0xa2, 0x8a, 0xa8, 0xa2, 0x9f, 0x55, 0xd1, 0x59, 0x27, 0xad, 0xea, 0xf9, 0xf4, 0x8c, 0x3a,
		0x7a, 0x89, 0x8e, 0x32, 0xf1, 0xb8, 0xd9, 0x32, 0x35, 0x87, 0xf5, 0x3d, 0x85, 0xf4, 0xd3, 0x42,
		0xb2, 0xde, 0x3b, 0x56, 0xa7, 0x65, 0xb5, 0x5c, 0xb3, 0x35, 0x9d, 0xe1, 0x8e, 0x7b, 0xa7, 0x67,
		0x5c, 0xea, 0x48, 0x1d, 0x3d, 0x83, 0xac, 0x29, 0x1f, 0xca, 0xe7, 0xd9, 0xf2, 0x99, 0xad, 0x4e,
		0xe3, 0x32, 0x47, 0x0a, 0xe9, 0xa5, 0x42, 0x62, 0x79, 0x46, 0xf5, 0x3c, 0x5f, 0x3d, 0x8e, 0xe5,
		0xb6, 0xac, 0x23, 0xf3, 0xac, 0xed, 0xb8, 0x27, 0x96, 0xd3, 0xb3, 0x0f, 0x69, 0x2c, 0xcf, 0xf7,
		0x45, 0x63, 0x79, 0xe5, 0x07, 0xa5, 0x3e, 0xee, 0x3d, 0x4a, 0xa4, 0x68, 0x89, 0x00, 0xbb, 0xf4,
		0x28, 0x96, 0x52, 0xf2, 0x09, 0xa2, 0x1b, 0x8f, 0x52, 0x29, 0xa1, 0x1c, 0x45, 0x76, 0xdd, 0x51,
		0x30, 0xa5, 0xf4, 0x2f, 0x80, 0x57, 0xfe, 0x52, 0x31, 0x85, 0xa3, 0x0b, 0xb0, 0x8b, 0x8e, 0x6a,
		0x29, 0x85, 0x5d, 0x60, 0xdd, 0x72, 0xd4, 0x4b, 0xd1, 0x7a, 0x41, 0x76, 0xc5, 0x51, 0x2d, 0x45,
		0xab, 0x05, 0xd9, 0xfd, 0x46, 0xb5, 0x94, 0x52, 0x1c, 0x91, 0x75, 0xa9, 0x98, 0x9f, 0xca, 0x2f,
		0xd8, 0x6e, 0x36, 0x6a, 0xa6, 0x14, 0xe2, 0xc5, 0x72, 0xad, 0x51, 0x24, 0xa5, 0x88, 0x04, 0xd6,
		0x9d, 0x46, 0xbd, 0x14, 0xad, 0x17, 0x48, 0x17, 0x1a, 0x65, 0x52, 0xb8, 0x4c, 0x90, 0xdd, 0x66,
		0x94, 0x4b, 0x19, 0x59, 0x85, 0x19, 0x85, 0x12, 0xd1, 0xd4, 0x3d, 0x46, 0xb5, 0x14, 0xad, 0x16,
		0x6c, 0x97, 0x18, 0xf5, 0x52, 0xb4, 0x5e, 0xc0, 0xdd, 0x60, 0x14, 0x4c, 0xd1, 0x82, 0xc1, 0x76,
		0x7d, 0x51, 0x2f, 0xc5, 0x13, 0x2e, 0x65, 0x42, 0x99, 0x7c, 0x57, 0x26, 0xe0, 0x2e, 0x2e, 0x0a,
		0xa6, 0x68, 0xc1, 0xb0, 0x1c, 0xa2, 0x4a, 0xbe, 0xaf, 0x12, 0x60, 0x57, 0x16, 0x86, 0x1b, 0x4b,
		0xbe, 0x0b, 0x4b, 0xf6, 0x7d, 0x94, 0x1b, 0x9d, 0xcc, 0xc8, 0x84, 0xa6, 0x50, 0xc3, 0x0c, 0xc3,
		0x51, 0xe2, 0x25, 0xfe, 0x28, 0x34, 0xf6, 0x05, 0x27, 0x4f, 0x23, 0x1e, 0x7c, 0x54, 0x37, 0xde,
		0xd8, 0x4b, 0x3e, 0x4e, 0xd3, 0x65, 0x7d, 0x34, 0x56, 0xe1, 0x60, 0x14, 0x5e, 0xf9, 0xd7, 0xb5,
		0x50, 0x25, 0x9f, 0x47, 0xd1, 0xa7, 0x9a, 0x1f, 0xc6, 0x89, 0x17, 0x0e, 0x54, 0xfd, 0xdb, 0x37,
		0xe2, 0xa5, 0x77, 0xea, 0xe3, 0x68, 0x94, 0x8c, 0x06, 0xa3, 0x20, 0xce, 0xbe, 0xab, 0xfb, 0xb1,
		0x1f, 0xd7, 0x03, 0x75, 0xab, 0x82, 0xf9, 0x97, 0x7a, 0xe0, 0x87, 0x9f, 0x6a, 0x71, 0xe2, 0x25,
		0xaa, 0x36, 0xf4, 0x12, 0xef, 0xd2, 0x8b, 0x55, 0x3d, 0x88, 0xc7, 0xf5, 0x24, 0xb8, 0x8d, 0xa7,
		0xbf, 0xd4, 0x6f, 0x92, 0x9a, 0x3f, 0xbe, 0x6d, 0xd6, 0x22, 0xe5, 0x0d, 0x3e, 0x7a, 0x97, 0x7e,
		0xe0, 0x27, 0x77, 0xf5, 0x71, 0xa4, 0xae, 0xfc, 0x2f, 0x2a, 0x9e, 0x7f, 0x53, 0x8f, 0x27, 0x97,
		0xb3, 0x1f, 0x48, 0xbf, 0xd6, 0xaf, 0x02, 0xef, 0x3a, 0xae, 0xcf, 0xfe, 0x55, 0x99, 0x29, 0x5d,
		0xde, 0xf0, 0x91, 0x15, 0x91, 0xb0, 0x81, 0x2c, 0x7d, 0x00, 0xeb, 0x35, 0x70, 0x05, 0x9e, 0xcb,
		0x6a, 0xc4, 0x49, 0x34, 0x19, 0x24, 0xe1, 0x1c, 0x24, 0x3b, 0xe9, 0x1d, 0xb3, 0xe7, 0x37, 0xcc,
		0xed, 0xce, 0x6f, 0x93, 0x6b, 0xc7, 0x7e, 0xec, 0xb6, 0xa7, 0xf7, 0xc7, 0x6d, 0xc7, 0x63, 0xd7,
		0x09, 0x6e, 0xdd, 0x93, 0xc4, 0x1e, 0xdf, 0x36, 0x7b, 0x8f, 0x6e, 0x82, 0xdb, 0x9d, 0x5d, 0xbb,
		0xdb, 0x9f, 0x5d, 0xb3, 0x7b, 0x34, 0xbb, 0xe6, 0x5f, 0x98, 0x0c, 0x84, 0x27, 0x02, 0xc3, 0x1f,
		0xdf, 0x36, 0x6a, 0xf1, 0x68, 0x12, 0x0d, 0x54, 0x2d, 0x1a, 0x4d, 0x12, 0x15, 0xd5, 0xfc, 0xa1,
		0xb8, 0x7c, 0x90, 0x55, 0x3b, 0x4f, 0x87, 0x2b, 0x2c, 0xb1, 0xbe, 0xf3, 0xc3, 0xe9, 0x2d, 0xdc,
		0x12, 0x16, 0xd6, 0xe1, 0x2c, 0x79, 0x1a, 0xfb, 0x1b, 0x9b, 0xc2, 0x02, 0x4b, 0x53, 0x87, 0xcc,
		0x49, 0x68, 0x21, 0xbc, 0xd1, 0xa0, 0x36, 0x9d, 0x2e, 0x24, 0xa6, 0xf1, 0xfe, 0x6c, 0x38, 0x88,
		0x85, 0x70, 0xe3, 0x9d, 0xba, 0xfb, 0x3c, 0x8a, 0xa6, 0x23, 0xc2, 0x48, 0x27, 0x48, 0xa1, 0x67,
		0x94, 0x1b, 0x6f, 0xbd, 0xd8, 0x8c, 0xae, 0x27, 0x37, 0x2a, 0x4c, 0x8c, 0xfd, 0x8d, 0x24, 0x9a,
		0x28, 0xa9, 0xa5, 0xd7, 0x43, 0x94, 0x99, 0x30, 0x09, 0xdf, 0x50, 0xf0, 0xdd, 0xf2, 0x23, 0xa1,
		0xd4, 0x3d, 0x2b, 0x30, 0xc5, 0x26, 0x93, 0x45, 0x3e, 0x4e, 0xc3, 0x14, 0x3a, 0x3e, 0x65, 0x02,
		0x80, 0x78, 0x10, 0x40, 0x00, 0x02, 0x20, 0x30, 0x40, 0x01, 0x04, 0x38, 0x50, 0x80, 0x03, 0x06,
		0x2c, 0x70, 0x90, 0x09, 0x10, 0x42, 0x41, 0x42, 0x3c, 0x50, 0x64, 0x01, 0xca, 0xed, 0x2e, 0xac,
		0xcc, 0xed, 0x52, 0x3b, 0x0c, 0xab, 0x80, 0x63, 0x53, 0x78, 0x98, 0xd2, 0xc1, 0x03, 0x09, 0x40,
		0x00, 0x41, 0x04, 0x0d, 0x48, 0x60, 0xc1, 0x04, 0x16, 0x50, 0x30, 0x41, 0x45, 0x36, 0xb0, 0x08,
		0x07, 0x97, 0xec, 0x23, 0x77, 0xee, 0xc6, 0x0a, 0x2b, 0xe3, 0xce, 0x1e, 0x46, 0x78, 0xc3, 0x61,
		0xa4, 0x62, 0x88, 0xb4, 0xbb, 0x68, 0x4b, 0xbc, 0x01, 0x88, 0xb5, 0xeb, 0x25, 0x89, 0x8a, 0x42,
		0x63, 0x7f, 0xe3, 0x03, 0x46, 0xc6, 0xfa, 0xdf, 0xaf, 0xbf, 0x7e, 0xd8, 0xac, 0xed, 0x5d, 0xfc,
		0xfd, 0x61, 0xab, 0xb6, 0x77, 0x91, 0x7e, 0xbb, 0x35, 0xfb, 0x92, 0x7e, 0xbf, 0xfd, 0x61, 0xb3,
		0xd6, 0x58, 0x7c, 0xbf, 0xf3, 0x61, 0xb3, 0xb6, 0x73, 0xf1, 0xdb, 0x9f, 0x7f, 0xbe, 0xfa, 0xed,
		0xaf, 0xd7, 0xf7, 0x3f, 0xff, 0x83, 0xff, 0x92, 0x9f, 0x0c, 0x2f, 0x10, 0x44, 0x76, 0xda, 0xb7,
		0xdf, 0x53, 0x69, 0xe8, 0x4a, 0xe3, 0x72, 0x47, 0xdd, 0x80, 0xc0, 0x48, 0x10, 0x60, 0x20, 0x03,
		0x81, 0x59, 0xb4, 0x6c, 0x11, 0xb0, 0x45, 0xc0, 0x16, 0x01, 0x5b, 0x04, 0x6c, 0x11, 0xb0, 0x45,
		0xc0, 0x16, 0x01, 0x5b, 0x04, 0x69, 0x8b, 0x60, 0xa8, 0xc2, 0xc4, 0x4f, 0xee, 0x22, 0x75, 0x85,
		0xd4, 0x21, 0xd8, 0x01, 0x88, 0xd5, 0x9e, 0xdf, 0xda, 0x03, 0x2f, 0x06, 0x9a, 0x27, 0x1e, 0x6c,
		0x7b, 0x76, 0xdf, 0xed, 0x9f, 0x1d, 0x38, 0xed, 0xf3, 0x74, 0x7f, 0x72, 0x90, 0xac, 0x7b, 0xee,
		0x05, 0x13, 0x15, 0xc3, 0x14, 0xcb, 0x1b, 0xc0, 0xc6, 0xce, 0xee, 0xd7, 0xc6, 0xce, 0x54, 0x2c,
		0x7d, 0x24, 0xb5, 0x20, 0xab, 0x06, 0x53, 0x3d, 0xdf, 0x55, 0x51, 0xb7, 0x67, 0x1d, 0xd9, 0xef,
		0xdd, 0xa3, 0xb6, 0x79, 0xcc, 0x23, 0x63, 0xa9, 0x9f, 0x9f, 0xd6, 0xcf, 0x6c, 0xd7, 0x8a, 0xde,
		0xe9, 0x99, 0x63, 0xf5, 0xa0, 0x8e, 0x1b, 0xa4, 0x82, 0xa4, 0x28, 0xc8, 0x31, 0x8f, 0x29, 0x1b,
		0xca, 0xe6, 0x19, 0xb2, 0x69, 0x36, 0x28, 0x1c, 0x0a, 0xe7, 0x19, 0x33, 0x56, 0x93, 0x33, 0x16,
		0x15, 0xf4, 0x62, 0x66, 0xee, 0x43, 0xaa, 0x87, 0x27, 0x9c, 0x57, 0x7d, 0x54, 0x6a, 0xd2, 0xff,
		0xc0, 0xac, 0x5c, 0xa9, 0x13, 0x56, 0xa8, 0x54, 0x0a, 0x2b, 0x51, 0xca, 0x83, 0x15, 0x27, 0x05,
		0xa2, 0xdd, 0x4c, 0xd3, 0xe4, 0x4c, 0x43, 0xa5, 0xe8, 0x59, 0x41, 0x52, 0x25, 0x79, 0xab, 0x64,
		0x9e, 0x3a, 0x0e, 0xcd, 0x2e, 0x9f, 0xf1, 0x52, 0x3f, 0x6b, 0xd5, 0x51, 0xcf, 0x35, 0xdb, 0xc7,
		0xa7, 0x3d, 0xdb, 0x79, 0x7b, 0xc2, 0x8e, 0x27, 0x15, 0xf4, 0x2c, 0x05, 0x3d, 0xfc, 0x8e, 0x6d,
		0xcf, 0x7c, 0x5f, 0x6c, 0x7b, 0x12, 0x0a, 0x74, 0x4b, 0xe6, 0x54, 0x0a, 0x93, 0x36, 0xa5, 0x22,
		0xa5, 0x1e, 0xed, 0x73, 0x2d, 0x29, 0xd5, 0xb3, 0x6e, 0x15, 0xcd, 0x0e, 0x24, 0xe2, 0x92, 0x0a,
		0x4a, 0xe7, 0xe7, 0xa5, 0x73, 0xd6, 0xc9, 0x0e, 0xdf, 0xb4, 0x5a, 0x6e, 0xbb, 0xdf, 0xa5, 0x88,
		0x28, 0xa2, 0x67, 0xe5, 0x1f, 0xd3, 0x71, 0x7a, 0xf6, 0xc1, 0x99, 0x63, 0x71, 0x39, 0x3b, 0x25,
		0xf4, 0xd3, 0x12, 0x9a, 0x3d, 0xc2, 0xc1, 0x3d, 0x84, 0x91, 0x42, 0x12, 0x24, 0xa4, 0x86, 0x6b,
		0x77, 0x1c, 0xab, 0x77, 0x64, 0x1e, 0x5a, 0x54, 0x12, 0x95, 0xf4, 0x6c, 0x34, 0x72, 0xec, 0xb6,
		0xfd, 0x5f, 0xcc, 0xd3, 0xec, 0xa9, 0x22, 0x51, 0x6c, 0xd4, 0xed, 0x9d, 0x3a, 0xd6, 0xa1, 0x63,
		0x9f, 0x76, 0xd2, 0x4a, 0x9f, 0x3a, 0xa2, 0x8e, 0x7e, 0x52, 0x47, 0x3d, 0xab, 0x6f, 0xb7, 0xce,
		0xcc, 0x36, 0xb3, 0x11, 0x55, 0xf4, 0x7c, 0x15, 0x9d, 0x98, 0xef, 0xd3, 0x8c, 0x44, 0x15, 0x51,
		0x45, 0x2f, 0x2b, 0xd6, 0xc8, 0xd8, 0x54, 0xd2, 0x5a, 0xf2, 0x51, 0xcf, 0xea, 0x5b, 0xbd, 0x73,
		0xf3, 0xa0, 0x6d, 0x31, 0x2b, 0x51, 0x4b, 0x2f, 0x24, 0xed, 0xf6, 0x29, 0x13, 0x11, 0xc5, 0xf3,
		0x4c, 0xf1, 0xb4, 0xac, 0xb6, 0xf9, 0x87, 0x7b, 0x6e, 0xf6, 0x6c, 0x73, 0x5a, 0xab, 0x51, 0x47,
		0xd4, 0xd1, 0xcf, 0xea, 0xc8, 0x6c, 0xfd, 0xdb, 0x6d, 0x9b, 0x1d, 0x50, 0x8f, 0x32, 0xe5, 0x53,
		0xb6, 0x7c, 0xce, 0x4d, 0xbb, 0x4d, 0x14, 0xa2, 0x8c, 0x5e, 0x9e, 0x85, 0x98, 0x81, 0x28, 0x9d,
		0xe7, 0x54, 0x64, 0x76, 0xe7, 0xa1, 0x4b, 0x34, 0x03, 0x22, 0xaa, 0x88, 0x2a, 0xfa, 0x59, 0x15,
		0x9d, 0x75, 0xd2, 0xaa, 0x9e, 0x4f, 0xcf, 0xa8, 0xa3, 0x97, 0xe8, 0x28, 0x13, 0x8f, 0x9b, 0x2d,
		0x53, 0x73, 0x58, 0xdf, 0x53, 0x48, 0x3f, 0x2d, 0x24, 0xeb, 0xbd, 0x63, 0x75, 0x5a, 0x56, 0xcb,
		0x35, 0x5b, 0xd3, 0x19, 0xee, 0xb8, 0x77, 0x7a, 0xc6, 0xa5, 0x8e, 0xd4, 0xd1, 0x33, 0xc8, 0x9a,
		0xf2, 0xa1, 0x7c, 0x9e, 0x2d, 0x9f, 0xd9, 0xea, 0x34, 0x2e, 0x73, 0xa4, 0x90, 0x5e, 0x2a, 0x24,
		0x96, 0x67, 0x54, 0xcf, 0xf3, 0xd5, 0xe3, 0x58, 0x6e, 0xcb, 0x3a, 0x32, 0xcf, 0xda, 0x8e, 0x7b,
		0x62, 0x39, 0x3d, 0xfb, 0x90, 0xc6, 0xf2, 0x7c, 0x5f, 0x34, 0x96, 0x57, 0x7e, 0x50, 0xea, 0xe3,
		0xde, 0xa3, 0x44, 0x8a, 0x96, 0x08, 0xb0, 0x4b, 0x8f, 0x62, 0x29, 0x25, 0x9f, 0x20, 0xba, 0xf1,
		0x28, 0x95, 0x12, 0xca, 0x51, 0x64, 0xd7, 0x1d, 0x05, 0x53, 0x4a, 0xff, 0x02, 0x78, 0xe5, 0x2f,
		0x15, 0x53, 0x38, 0xba, 0x00, 0xbb, 0xe8, 0xa8, 0x96, 0x52, 0xd8, 0x05, 0xd6, 0x2d, 0x47, 0xbd,
		0x14, 0xad, 0x17, 0x64, 0x57, 0x1c, 0xd5, 0x52, 0xb4, 0x5a, 0x90, 0xdd, 0x6f, 0x54, 0x4b, 0x29,
		0xc5, 0x11, 0x59, 0x97, 0x8a, 0xf9, 0xa9, 0xfc, 0x82, 0xed, 0x66, 0xa3, 0x66, 0x4a, 0x21, 0x5e,
		0x2c, 0xd7, 0x1a, 0x45, 0x52, 0x8a, 0x48, 0x60, 0xdd, 0x69, 0xd4, 0x4b, 0xd1, 0x7a, 0x81, 0x74,
		0xa1, 0x51, 0x26, 0x85, 0xcb, 0x04, 0xd9, 0x6d, 0x46, 0xb9, 0x94, 0x91, 0x55, 0x98, 0x51, 0x28,
		0x11, 0x4d, 0xdd, 0x63, 0x54, 0x4b, 0xd1, 0x6a, 0xc1, 0x76, 0x89, 0x51, 0x2f, 0x45, 0xeb, 0x05,
		0xdc, 0x0d, 0x46, 0xc1, 0x14, 0x2d, 0x18, 0x6c, 0xd7, 0x17, 0xf5, 0x52, 0x3c, 0xe1, 0x52, 0x26,
		0x94, 0xc9, 0x77, 0x65, 0x02, 0xee, 0xe2, 0xa2, 0x60, 0x8a, 0x16, 0x0c, 0xcb, 0x21, 0xaa, 0xe4,
		0xfb, 0x2a, 0x01, 0x76, 0x65, 0x61, 0xb8, 0xb1, 0xe4, 0xbb, 0xb0, 0x64, 0xdf, 0x47, 0xb9, 0xd1,
		0xc9, 0x8c, 0x4c, 0x68, 0x0a, 0x35, 0xcc, 0x30, 0x1c, 0x25, 0x5e, 0xe2, 0x8f, 0x42, 0x63, 0x5f,
		0x70, 0xf2, 0x34, 0xe2, 0xc1, 0x47, 0x75, 0xe3, 0x8d, 0xbd, 0xe4, 0xe3, 0x34, 0x5d, 0xd6, 0x47,
		0x63, 0x15, 0x0e, 0x46, 0xe1, 0x95, 0x7f, 0x5d, 0x0b, 0x55, 0xf2, 0x79, 0x14, 0x7d, 0xaa, 0xf9,
		0x61, 0x9c, 0x78, 0xe1, 0x40, 0xd5, 0xbf, 0x7d, 0x23, 0x5e, 0x7a, 0xa7, 0x3e, 0x8e, 0x46, 0xc9,
		0x68, 0x30, 0x0a, 0xe2, 0xec, 0xbb, 0xba, 0x1f, 0xfb, 0x71, 0x3d, 0x50, 0xb7, 0x2a, 0x98, 0x7f,
		0xa9, 0x07, 0x7e, 0xf8, 0xa9, 0x16, 0x27, 0x5e, 0xa2, 0x6a, 0x43, 0x2f, 0xf1, 0x2e, 0xbd, 0x58,
		0xd5, 0x83, 0x78, 0x5c, 0x4f, 0x82, 0xdb, 0x78, 0xfa, 0x4b, 0xfd, 0x26, 0xa9, 0xf9, 0xe3, 0xdb,
		0x66, 0x2d, 0x52, 0xde, 0xe0, 0xa3, 0x77, 0xe9, 0x07, 0x7e, 0x72, 0x57, 0x1f, 0x47, 0xea, 0xca,
		0xff, 0xa2, 0xe2, 0xf9, 0x37, 0xf5, 0x78, 0x72, 0x39, 0xfb, 0x81, 0xf4, 0x6b, 0xdd, 0x1f, 0xdf,
		0x36, 0x6a, 0xf1, 0x68, 0x12, 0x0d, 0x54, 0x2d, 0x1a, 0x4d, 0x12, 0x15, 0xd5, 0xfc, 0x61, 0x7d,
		0xf6, 0xbf, 0xc8, 0x4c, 0xf1, 0xf2, 0x86, 0x93, 0xac, 0x88, 0x84, 0x0d, 0x6c, 0xe9, 0x03, 0x5a,
		0xef, 0x81, 0x2c, 0xf0, 0xdc, 0x56, 0x23, 0x4e, 0xa2, 0xc9, 0x20, 0x09, 0xe7, 0xa0, 0xd9, 0x49,
		0xef, 0xa0, 0x3d, 0xbf, 0x81, 0x6e, 0x77, 0x7e, 0xdb, 0x5c, 0x3b, 0xf6, 0x63, 0xb7, 0x3d, 0xbd,
		0x5f, 0x6e, 0x3b, 0x1e, 0xbb, 0x4e, 0x70, 0xeb, 0x9e, 0x24, 0xf6, 0xf8, 0xb6, 0xd9, 0x7b, 0x74,
		0x53, 0xdc, 0xee, 0xec, 0x5e, 0xb8, 0xfd, 0xd9, 0x3d, 0x70, 0xed, 0xf1, 0x6d, 0xa3, 0x3f, 0xbb,
		0x05, 0xbd, 0xd9, 0x1d, 0xb0, 0x87, 0xb2, 0x72, 0x98, 0x9c, 0x4c, 0x21, 0x28, 0x4b, 0x18, 0x33,
		0xa9, 0x2f, 0x29, 0x57, 0x5a, 0xb2, 0xc8, 0x4a, 0xa3, 0xa7, 0xc3, 0x15, 0x96, 0x75, 0xdf, 0xf9,
		0xe1, 0xf4, 0x16, 0x6e, 0x09, 0x0b, 0xeb, 0x70, 0x96, 0x59, 0x8d, 0xfd, 0x8d, 0x4d, 0x61, 0x81,
		0xa5, 0x79, 0x44, 0xe6, 0x0c, 0xb5, 0x10, 0xde, 0x68, 0x50, 0x9b, 0xce, 0x25, 0x12, 0x73, 0x7a,
		0x9a, 0x74, 0xc5, 0x12, 0xbb, 0xf1, 0x4e, 0xdd, 0x7d, 0x1e, 0x45, 0xd3, 0x11, 0x61, 0xa4, 0xb3,
		0xa7, 0xd0, 0x03, 0xcd, 0x8d, 0xb7, 0x5e, 0x6c, 0x46, 0xd7, 0x93, 0x1b, 0x15, 0x26, 0xc6, 0xfe,
		0x46, 0x12, 0x4d, 0x94, 0xd4, 0x3a, 0xed, 0x21, 0xca, 0x4c, 0x98, 0x24, 0x73, 0x28, 0x32, 0x6f,
		0xf9, 0x91, 0x50, 0x24, 0x9f, 0x55, 0x9f, 0x62, 0x93, 0xc9, 0x22, 0x1f, 0xa7, 0x61, 0x0a, 0x1d,
		0x9f, 0x32, 0x01, 0x40, 0x3c, 0x08, 0x20, 0x00, 0x01, 0x10, 0x18, 0xa0, 0x00, 0x02, 0x1c, 0x28,
		0xc0, 0x01, 0x03, 0x16, 0x38, 0xc8, 0x04, 0x08, 0xa1, 0x20, 0x21, 0x1e, 0x28, 0xb2, 0x00, 0xe5,
		0x76, 0x17, 0x56, 0xe6, 0x76, 0xc9, 0xad, 0xbc, 0xa7, 0x80, 0x63, 0x53, 0x78, 0x98, 0xd2, 0xc1,
		0x03, 0x09, 0x40, 0x00, 0x41, 0x04, 0x0d, 0x48, 0x60, 0xc1, 0x04, 0x16, 0x50, 0x30, 0x41, 0x45,
		0x36, 0xb0, 0x08, 0x07, 0x97, 0xec, 0x23, 0x77, 0xee, 0xc6, 0x0a, 0x2b, 0xe3, 0xce, 0x1e, 0x46,
		0x78, 0xc3, 0x61, 0xa4, 0x62, 0x88, 0xb4, 0xbb, 0x68, 0x4b, 0xbc, 0x01, 0x88, 0xb5, 0xeb, 0x25,
		0x89, 0x8a, 0x42, 0x63, 0x7f, 0xe3, 0x03, 0x46, 0xc6, 0xfa, 0xdf, 0xaf, 0xbf, 0x7e, 0xd8, 0xac,
		0xed, 0x79, 0xb5, 0x2b, 0xb3, 0x76, 0x74, 0xf1, 0xd7, 0xd6, 0xef, 0x8d, 0xfb, 0xfd, 0xdf, 0xfe,
		0xda, 0xbd, 0xff, 0xf6, 0xcd, 0xbf, 0x9f, 0xfa, 0x6b, 0x5b, 0xbf, 0xef, 0xde, 0xef, 0xaf, 0xf8,
		0x93, 0xe6, 0xfd, 0xfe, 0x0f, 0xfe, 0x1b, 0x3b, 0xf7, 0xbf, 0x2e, 0xfd, 0xd5, 0xe9, 0xfb, 0xdb,
		0xab, 0x7e, 0xa0, 0xb1, 0xe2, 0x07, 0x5e, 0xaf, 0xfa, 0x81, 0xd7, 0x2b, 0x7e, 0x60, 0x65, 0x48,
		0xdb, 0x2b, 0x7e, 0x60, 0xe7, 0xfe, 0xef, 0xa5, 0xbf, 0xff, 0xeb, 0xd3, 0x7f, 0xb5, 0x79, 0xff,
		0xdb, 0xdf, 0xab, 0xfe, 0x6c, 0xf7, 0xfe, 0xef, 0xfd, 0xdf, 0x7e, 0xfb, 0x97, 0xfc, 0xa9, 0xe1,
		0x02, 0x61, 0xc8, 0x9d, 0xf6, 0xed, 0xf7, 0x1c, 0x77, 0x1c, 0x77, 0x3a, 0x8d, 0x3b, 0xae, 0x9b,
		0xd5, 0x0d, 0x16, 0x8d, 0x04, 0x01, 0x14, 0x33, 0x48, 0x9c, 0x45, 0xcb, 0xf6, 0x11, 0xdb, 0x47,
		0x6c, 0x1f, 0xb1, 0x7d, 0xc4, 0xf6, 0x11, 0xdb, 0x47, 0x6c, 0x1f, 0xb1, 0x7d, 0x94, 0xb6, 0x8f,
		0x86, 0x2a, 0x4c, 0xfc, 0xe4, 0x2e, 0x52, 0x57, 0x48, 0xdd, 0xa3, 0x1d, 0x80, 0x58, 0xed, 0xf9,
		0xad, 0x3d, 0xf0, 0x62, 0xa0, 0x79, 0xe2, 0xc1, 0xff, 0x69, 0xf7, 0xdd, 0xfe, 0xd9, 0x81, 0xd3,
		0x3e, 0x4f, 0x37, 0xba, 0x07, 0xc9, 0xba, 0xe7, 0x5e, 0x30, 0x51, 0x31, 0x4c, 0xeb, 0x60, 0x03,
		0xd8, 0x21, 0xdc, 0xfd, 0xda, 0x21, 0x9c, 0x8a, 0xa5, 0x8f, 0xa4, 0x16, 0x64, 0xd5, 0x60, 0xaa,
		0xe7, 0xbb, 0x2a, 0xea, 0xf6, 0xac, 0x23, 0xfb, 0xbd, 0x7b, 0xd4, 0x36, 0x8f, 0x79, 0xf6, 0x30,
		0xf5, 0xf3, 0xd3, 0xfa, 0x99, 0x6d, 0x7f, 0xd2, 0x3b, 0x3d, 0x73, 0xac, 0x1e, 0xd4, 0xb9, 0x95,
		0x54, 0x90, 0x14, 0x05, 0x39, 0xe6, 0x31, 0x65, 0x43, 0xd9, 0x3c, 0x43, 0x36, 0xcd, 0x06, 0x85,
		0x43, 0xe1, 0x3c, 0x63, 0xc6, 0x6a, 0x72, 0xc6, 0xa2, 0x82, 0x5e, 0xcc, 0xcc, 0x7d, 0x48, 0xf5,
		0xf0, 0xa8, 0xfc, 0xaa, 0x8f, 0x4a, 0x4d, 0xfa, 0x1f, 0x98, 0x95, 0x2b, 0x75, 0xc2, 0x0a, 0x95,
		0x4a, 0x61, 0x25, 0x4a, 0x79, 0xb0, 0xe2, 0xa4, 0x40, 0xb4, 0x9b, 0x69, 0x9a, 0x9c, 0x69, 0xa8,
		0x14, 0x3d, 0x2b, 0x48, 0xaa, 0x24, 0x6f, 0x95, 0xcc, 0x53, 0xc7, 0xa1, 0xd9, 0xe5, 0x33, 0x5e,
		0xea, 0x67, 0xad, 0x3a, 0xea, 0xb9, 0x66, 0xfb, 0xf8, 0xb4, 0x67, 0x3b, 0x6f, 0x4f, 0xd8, 0xf1,
		0xa4, 0x82, 0x9e, 0xa5, 0xa0, 0x87, 0xdf, 0xb1, 0xed, 0x99, 0xef, 0x8b, 0x6d, 0x4f, 0x42, 0x81,
		0x6e, 0xc9, 0x9c, 0x4a, 0x61, 0xd2, 0xa6, 0x54, 0xa4, 0xd4, 0xa3, 0x7d, 0xae, 0x25, 0xa5, 0x7a,
		0xd6, 0xad, 0xa2, 0xd9, 0xc9, 0x56, 0x5c, 0x52, 0x41, 0xe9, 0xfc, 0xbc, 0x74, 0xce, 0x3a, 0xd9,
		0x29, 0xae, 0x56, 0xcb, 0x6d, 0xf7, 0xbb, 0x14, 0x11, 0x45, 0xf4, 0xac, 0xfc, 0x63, 0x3a, 0x4e,
		0xcf, 0x3e, 0x38, 0x73, 0x2c, 0x2e, 0x67, 0xa7, 0x84, 0x7e, 0x5a, 0x42, 0xb3, 0x47, 0x38, 0xb8,
		0xa7, 0x79, 0x52, 0x48, 0x82, 0x84, 0xd4, 0x70, 0xed, 0x8e, 0x63, 0xf5, 0x8e, 0xcc, 0x43, 0x8b,
		0x4a, 0xa2, 0x92, 0x9e, 0x8d, 0x46, 0x8e, 0xdd, 0xb6, 0xff, 0x6b, 0xb5, 0x1e, 0x4e, 0xbc, 0xa7,
		0x8a, 0xa8, 0xa2, 0x67, 0xb1, 0x51, 0xb7, 0x77, 0xea, 0x58, 0x87, 0x8e, 0x7d, 0xda, 0x49, 0x2b,
		0x7d, 0xea, 0x88, 0x3a, 0xfa, 0x49, 0x1d, 0xf5, 0xac, 0xbe, 0xdd, 0x3a, 0x33, 0xdb, 0xcc, 0x46,
		0x54, 0xd1, 0xf3, 0x55, 0x74, 0x62, 0xbe, 0x4f, 0x33, 0x12, 0x55, 0x44, 0x15, 0xbd, 0xac, 0x58,
		0x23, 0x63, 0x53, 0x49, 0x6b, 0xc9, 0x47, 0x3d, 0xab, 0x6f, 0xf5, 0xce, 0xcd, 0x83, 0xb6, 0xc5,
		0xac, 0x44, 0x2d, 0xbd, 0x90, 0xb4, 0xdb, 0xa7, 0x4c, 0x44, 0x14, 0xcf, 0x33, 0xc5, 0xd3, 0xb2,
		0xda, 0xe6, 0x1f, 0xee, 0xb9, 0xd9, 0xb3, 0xcd, 0x69, 0xad, 0x46, 0x1d, 0x51, 0x47, 0x3f, 0xab,
		0x23, 0xb3, 0xf5, 0x6f, 0xb7, 0x6d, 0x76, 0x40, 0x3d, 0xca, 0x94, 0x4f, 0xd9, 0xf2, 0x39, 0x37,
		0xed, 0x36, 0x51, 0x88, 0x32, 0x7a, 0x79, 0x16, 0x62, 0x06, 0xa2, 0x74, 0x9e, 0x53, 0x91, 0xd9,
		0x9d, 0x87, 0x2e, 0xd1, 0x0c, 0x88, 0xa8, 0x22, 0xaa, 0xe8, 0x67, 0x55, 0x74, 0xd6, 0x49, 0xab,
		0x7a, 0x3e, 0x3d, 0xa3, 0x8e, 0x5e, 0xa2, 0xa3, 0x4c, 0x3c, 0x6e, 0xb6, 0x4c, 0xcd, 0x61, 0x7d,
		0x4f, 0x21, 0xfd, 0xb4, 0x90, 0xac, 0xf7, 0x8e, 0xd5, 0x69, 0x59, 0x2d, 0xd7, 0x6c, 0x4d, 0x67,
		0xb8, 0xe3, 0xde, 0xe9, 0x19, 0x97, 0x3a, 0x52, 0x47, 0xcf, 0x20, 0x6b, 0xca, 0x87, 0xf2, 0x79,
		0xb6, 0x7c, 0x66, 0xab, 0xd3, 0xb8, 0xcc, 0x91, 0x42, 0x7a, 0xa9, 0x90, 0x58, 0x9e, 0x51, 0x3d,
		0xcf, 0x57, 0x8f, 0x63, 0xb9, 0x2d, 0xeb, 0xc8, 0x3c, 0x6b, 0x3b, 0xee, 0x89, 0xe5, 0xf4, 0xec,
		0x43, 0x1a, 0xcb, 0xf3, 0x7d, 0xd1, 0x58, 0x5e, 0xf9, 0x41, 0xa9, 0x8f, 0x7b, 0x8f, 0x12, 0x29,
		0x5a, 0x22, 0xc0, 0x2e, 0x3d, 0x8a, 0xa5, 0x94, 0x7c, 0x82, 0xe8, 0xc6, 0xa3, 0x54, 0x4a, 0x28,
		0x47, 0x91, 0x5d, 0x77, 0x14, 0x4c, 0x29, 0xfd, 0x0b, 0xe0, 0x95, 0xbf, 0x54, 0x4c, 0xe1, 0xe8,
		0x02, 0xec, 0xa2, 0xa3, 0x5a, 0x4a, 0x61, 0x17, 0x58, 0xb7, 0x1c, 0xf5, 0x52, 0xb4, 0x5e, 0x90,
		0x5d, 0x71, 0x54, 0x4b, 0xd1, 0x6a, 0x41, 0x76, 0xbf, 0x51, 0x2d, 0xa5, 0x14, 0x47, 0x64, 0x5d,
		0x2a, 0xe6, 0xa7, 0xf2, 0x0b, 0xb6, 0x9b, 0x8d, 0x9a, 0x29, 0x85, 0x78, 0xb1, 0x5c, 0x6b, 0x14,
		0x49, 0x29, 0x22, 0x81, 0x75, 0xa7, 0x51, 0x2f, 0x45, 0xeb, 0x05, 0xd2, 0x85, 0x46, 0x99, 0x14,
		0x2e, 0x13, 0x64, 0xb7, 0x19, 0xe5, 0x52, 0x46, 0x56, 0x61, 0x46, 0xa1, 0x44, 0x34, 0x75, 0x8f,
		0x51, 0x2d, 0x45, 0xab, 0x05, 0xdb, 0x25, 0x46, 0xbd, 0x14, 0xad, 0x17, 0x70, 0x37, 0x18, 0x05,
		0x53, 0xb4, 0x60, 0xb0, 0x5d, 0x5f, 0xd4, 0x4b, 0xf1, 0x84, 0x4b, 0x99, 0x50, 0x26, 0xdf, 0x95,
		0x09, 0xb8, 0x8b, 0x8b, 0x82, 0x29, 0x5a, 0x30, 0x2c, 0x87, 0xa8, 0x92, 0xef, 0xab, 0x04, 0xd8,
		0x95, 0x85, 0xe1, 0xc6, 0x92, 0xef, 0xc2, 0x92, 0x7d, 0x1f, 0xe5, 0x46, 0x27, 0x33, 0x32, 0xa1,
		0x29, 0xd4, 0x30, 0xc3, 0x70, 0x94, 0x78, 0x89, 0x3f, 0x0a, 0x8d, 0x7d, 0xc1, 0xc9, 0xd3, 0x88,
		0x07, 0x1f, 0xd5, 0x8d, 0x37, 0xf6, 0x92, 0x8f, 0xd3, 0x74, 0x59, 0x1f, 0x8d, 0x55, 0x38, 0x18,
		0x85, 0x57, 0xfe, 0x75, 0x2d, 0x54, 0xc9, 0xe7, 0x51, 0xf4, 0xa9, 0xe6, 0x87, 0x71, 0xe2, 0x85,
		0x03, 0x55, 0xff, 0xf6, 0x8d, 0x78, 0xe9, 0x9d, 0xfa, 0x38, 0x1a, 0x25, 0xa3, 0xc1, 0x28, 0x88,
		0xb3, 0xef, 0xea, 0x7e, 0xec, 0xc7, 0xf5, 0x40, 0xdd, 0xaa, 0x60, 0xfe, 0xa5, 0x1e, 0xf8, 0xe1,
		0xa7, 0x5a, 0x9c, 0x78, 0x89, 0xaa, 0x0d, 0xbd, 0xc4, 0xbb, 0xf4, 0x62, 0x55, 0x0f, 0xe2, 0x71,
		0x3d, 0x09, 0x6e, 0xe3, 0xe9, 0x2f, 0xf5, 0x9b, 0xa4, 0xe6, 0x8f, 0x6f, 0x9b, 0xb5, 0x48, 0x79,
		0x83, 0x8f, 0xde, 0xa5, 0x1f, 0xf8, 0xc9, 0x5d, 0x7d, 0x1c, 0xa9, 0x2b, 0xff, 0x8b, 0x8a, 0xe7,
		0xdf, 0xd4, 0xe3, 0xc9, 0xe5, 0xec, 0x07, 0xd2, 0xaf, 0xf5, 0xd9, 0x0f, 0xc4, 0xa3, 0x49, 0x34,
		0x50, 0xb5, 0x68, 0x34, 0x49, 0x54, 0x54, 0xf3, 0x87, 0xf5, 0xd9, 0xff, 0x22, 0x33, 0xc5, 0xcb,
		0x1b, 0x4e, 0xb2, 0x22, 0x12, 0x36, 0xb0, 0xa5, 0x0f, 0x68, 0xbd, 0x07, 0xb2, 0xc0, 0x73, 0x5b,
		0x8d, 0x38, 0x89, 0x26, 0x83, 0x24, 0x9c, 0x83, 0x66, 0x27, 0xbd, 0x83, 0xf6, 0xfc, 0x06, 0xba,
		0xdd, 0xf9, 0x6d, 0x73, 0xed, 0xd8, 0x8f, 0xdd, 0xf6, 0xf4, 0x7e, 0xb9, 0xed, 0x78, 0xec, 0x3a,
		0xc1, 0xad, 0x7b, 0x92, 0xd8, 0xe3, 0xdb, 0x66, 0xef, 0xd1, 0x4d, 0x71, 0xbb, 0xb3, 0x7b, 0xe1,
		0xf6, 0x67, 0xf7, 0xc0, 0x9d, 0xfe, 0x71, 0x7f, 0x76, 0x0b, 0x7a, 0xb3, 0x3b, 0x60, 0x0f, 0x65,
		0xe5, 0x30, 0x39, 0x99, 0x42, 0x50, 0x96, 0x30, 0x52, 0x3d, 0xd7, 0x62, 0x7f, 0x18, 0x8b, 0x4b,
		0x11, 0x59, 0x41, 0xf4, 0x38, 0x48, 0x61, 0x19, 0xf6, 0x9d, 0x1f, 0x0e, 0x8d, 0xfd, 0x8d, 0x2d,
		0x61, 0x61, 0x1d, 0xce, 0xb2, 0xa8, 0xb1, 0xbf, 0xb1, 0x29, 0x2c, 0xb0, 0x34, 0x67, 0xc8, 0x9c,
		0x8d, 0x16, 0x72, 0x1b, 0x0d, 0x6a, 0xd3, 0x79, 0x43, 0x62, 0xfe, 0x4e, 0x13, 0xac, 0x58, 0x3a,
		0x37, 0xde, 0xa9, 0xbb, 0xcf, 0xa3, 0x68, 0xf8, 0x30, 0x68, 0x85, 0x1e, 0x5e, 0x6e, 0xbc, 0xf5,
		0x62, 0x33, 0xba, 0x9e, 0xdc, 0xa8, 0x30, 0x31, 0xf6, 0x37, 0x92, 0x68, 0xa2, 0xa4, 0xd6, 0x64,
		0x0f, 0x51, 0x66, 0xc2, 0x24, 0x85, 0x43, 0x51, 0x78, 0xcb, 0x8f, 0x64, 0x26, 0xbc, 0x87, 0x79,
		0x55, 0x6e, 0x46, 0x59, 0x66, 0x00, 0xa9, 0x29, 0x45, 0x26, 0x0a, 0x88, 0x47, 0x02, 0x04, 0x34,
		0x00, 0x42, 0x04, 0x14, 0x54, 0x80, 0x43, 0x06, 0x38, 0x74, 0xc0, 0x42, 0x08, 0x99, 0x28, 0x21,
		0x14, 0x29, 0xc4, 0xa3, 0x45, 0x16, 0x60, 0xda, 0xcc, 0x16, 0x9f, 0x84, 0x16, 0x79, 0x3d, 0x0d,
		0x57, 0xf8, 0x78, 0x96, 0x0d, 0x1a, 0x30, 0xc0, 0x81, 0x04, 0x1e, 0x80, 0x00, 0x82, 0x06, 0x22,
		0xb0, 0x40, 0x02, 0x0b, 0x26, 0x98, 0x80, 0x22, 0x1b, 0x54, 0x84, 0x03, 0x0b, 0x0c, 0xb8, 0x64,
		0x81, 0x7a, 0xc1, 0xf5, 0x28, 0xf2, 0x93, 0x8f, 0x37, 0x38, 0x09, 0x6c, 0x31, 0x47, 0x3c, 0x84,
		0x0e, 0x92, 0x07, 0xe6, 0x60, 0xb3, 0x09, 0x12, 0x2e, 0x0a, 0xe0, 0x20, 0x82, 0x0e, 0x30, 0xf0,
		0xa0, 0x82, 0x0f, 0x3c, 0x00, 0xc1, 0x83, 0x10, 0x36, 0x10, 0x61, 0x80, 0x11, 0x08, 0x20, 0x65,
		0x52, 0x70, 0xee, 0xc6, 0x0a, 0x33, 0x63, 0x4f, 0xfc, 0x30, 0x79, 0x83, 0x94, 0xaf, 0xe7, 0xf8,
		0xb1, 0x03, 0x14, 0x72, 0xcf, 0x0b, 0xaf, 0xa7, 0x37, 0xfb, 0x03, 0x54, 0x7e, 0xc3, 0x3b, 0x35,
		0xc7, 0x38, 0xf1, 0x43, 0xb8, 0x89, 0x1c, 0x94, 0xab, 0x97, 0xc2, 0x3f, 0xf7, 0x82, 0x89, 0x02,
		0x8e, 0xff, 0x28, 0xf2, 0x06, 0x89, 0x3f, 0x0a, 0x5b, 0xfe, 0xb5, 0x9f, 0xc4, 0xd3, 0x0b, 0xe1,
		0xd1, 0x5c, 0x45, 0x0c, 0x59, 0xef, 0x0b, 0x87, 0x6c, 0xc9, 0x43, 0x76, 0x7b, 0x67, 0x87, 0x83,
		0x96, 0x20, 0xae, 0x57, 0xb4, 0x18, 0x87, 0xb6, 0xc9, 0xbf, 0x9f, 0x00, 0x93, 0x8a, 0x71, 0x15,
		0x78, 0xd7, 0x31, 0x5e, 0xeb, 0x37, 0x0d, 0x9b, 0x6d, 0xdf, 0x3c, 0xc2, 0x65, 0xdb, 0xb7, 0x40,
		0x21, 0xb3, 0xed, 0x5b, 0xdc, 0x30, 0x64, 0xdb, 0xb7, 0xe4, 0x0b, 0x60, 0xdb, 0x97, 0xcc, 0x31,
		0x97, 0x02, 0x6e, 0xdb, 0x57, 0x85, 0x93, 0x1b, 0x15, 0xa5, 0xa6, 0x63, 0xbc, 0xe6, 0xef, 0x56,
		0x03, 0x28, 0x66, 0x2b, 0x9c, 0xcc, 0x96, 0x25, 0x70, 0xe8, 0xad, 0xf3, 0xae, 0xb6, 0xfd, 0x38,
		0x31, 0x93, 0x24, 0xc2, 0x1a, 0x7e, 0x27, 0x7e, 0x68, 0x05, 0x6a, 0x3a, 0x7b, 0xc4, 0x58, 0x7d,
		0x23, 0xe3, 0xc4, 0xfb, 0xf2, 0x28, 0xf2, 0xad, 0x37, 0x8d, 0x46, 0x73, 0xb7, 0xd1, 0xd8, 0xdc,
		0x7d, 0xbd, 0xbb, 0xb9, 0xb7, 0xb3, 0xb3, 0xd5, 0xdc, 0x42, 0x7a, 0x20, 0x73, 0x1a, 0x0d, 0x55,
		0xa4, 0x86, 0x07, 0x77, 0xc6, 0xfe, 0x46, 0x38, 0x09, 0x02, 0xb6, 0x0a, 0x2a, 0xd3, 0x2a, 0xb8,
		0x9d, 0xf7, 0x3c, 0xc1, 0x5a, 0x05, 0x69, 0xd8, 0x6c, 0x15, 0xb0, 0x55, 0xc0, 0x56, 0x01, 0x5b,
		0x05, 0x6c, 0x15, 0xb0, 0x55, 0x40, 0xde, 0x60, 0xab, 0xa0, 0x90, 0x8c, 0x3d, 0xf1, 0xc3, 0xe4,
		0xf5, 0x36, 0x60, 0x97, 0x60, 0x97, 0x4b, 0xc4, 0x72, 0x7e, 0x71, 0x89, 0x18, 0xc1, 0xfa, 0x27,
		0xc2, 0xe7, 0x12, 0x31, 0x4e, 0x97, 0xcf, 0x19, 0xb2, 0x5c, 0x22, 0x56, 0xfa, 0x90, 0x6d, 0x6c,
		0xef, 0x35, 0xf6, 0x9a, 0xbb, 0xdb, 0x7b, 0x5c, 0x29, 0x46, 0x20, 0xd7, 0x2c, 0x5a, 0xae, 0x14,
		0xab, 0x42, 0x84, 0xd2, 0xbd, 0xd6, 0x20, 0xdb, 0xba, 0x67, 0xf1, 0xea, 0xb2, 0x2b, 0xf4, 0xa3,
		0x6d, 0x6b, 0x1f, 0x7d, 0x2f, 0x79, 0x7f, 0x77, 0xf9, 0xe3, 0x4d, 0xf0, 0x58, 0x03, 0x79, 0x00,
		0x04, 0xf5, 0xe0, 0x07, 0x04, 0x72, 0xb9, 0xd7, 0x51, 0x9e, 0x42, 0xe5, 0x5e, 0x47, 0xf9, 0x0d,
		0x2f, 0xee, 0x75, 0x54, 0x34, 0x8c, 0x71, 0xaf, 0xa3, 0xaa, 0xf1, 0x37, 0xcc, 0x03, 0x9a, 0x2c,
		0xe3, 0x06, 0xca, 0xbb, 0x8a, 0xd4, 0x15, 0x42, 0xc6, 0x5d, 0xac, 0xdb, 0x04, 0x78, 0x24, 0x63,
		0x74, 0xe7, 0x25, 0xcd, 0xab, 0x57, 0x69, 0x11, 0x50, 0x4f, 0x11, 0x8c, 0xa5, 0x80, 0x46, 0x91,
		0x49, 0xdd, 0x29, 0xf6, 0x9d, 0xba, 0x93, 0x0e, 0xfd, 0x18, 0x2b, 0x6f, 0x71, 0x56, 0xda, 0x42,
		0xaf, 0xac, 0xc5, 0x58, 0x49, 0xcb, 0x93, 0x1c, 0x5f, 0x16, 0xa7, 0xde, 0xad, 0x3e, 0xc9, 0xc7,
		0x03, 0xe4, 0x78, 0x12, 0x5c, 0xfa, 0xbb, 0xbe, 0x3f, 0xe4, 0x21, 0x96, 0x88, 0x11, 0xf1, 0x10,
		0xcb, 0xca, 0xe7, 0x30, 0x9e, 0xdc, 0x28, 0x7e, 0x68, 0x08, 0x3d, 0x59, 0x41, 0xf4, 0x49, 0x0a,
		0x3c, 0xad, 0xf1, 0x67, 0x1b, 0x16, 0x3c, 0xad, 0xf1, 0x25, 0x21, 0xf2, 0xb4, 0xc6, 0x35, 0x05,
		0xca, 0xd3, 0x1a, 0x89, 0x9b, 0x45, 0x7d, 0x84, 0x62, 0x4f, 0x6b, 0x4c, 0x24, 0x3f, 0x46, 0xc8,
		0xd2, 0xf1, 0x2c, 0x4a, 0xd9, 0x27, 0x34, 0x6e, 0xf2, 0x84, 0x46, 0xed, 0x70, 0x00, 0x08, 0x0b,
		0x50, 0xf0, 0x00, 0x0e, 0x13, 0xe0, 0x70, 0x01, 0x0b, 0x1b, 0x64, 0xe2, 0x83, 0x50, 0x8c, 0xc8,
		0x3e, 0x5a, 0xf1, 0x0f, 0xff, 0xb3, 0x8c, 0xe9, 0x0f, 0x55, 0x98, 0xf8, 0xc9, 0x9d, 0xec, 0x07,
		0xff, 0x59, 0x0d, 0x2f, 0xf9, 0xd9, 0x95, 0x3d, 0xbf, 0x95, 0x07, 0x5e, 0x0c, 0xb4, 0x20, 0xd4,
		0xee, 0xdb, 0x7d, 0xb7, 0x7f, 0x76, 0xe0, 0xb4, 0xcf, 0x5d, 0xe7, 0x8f, 0xae, 0x25, 0x3d, 0xcd,
		0xcf, 0x1c, 0x44, 0x31, 0x84, 0xb5, 0x15, 0x6c, 0x4f, 0x18, 0xbb, 0xeb, 0xf6, 0x2c, 0xf3, 0xf0,
		0xad, 0x79, 0x60, 0xb7, 0x6d, 0xe7, 0x8f, 0xb9, 0x28, 0xfa, 0x08, 0xaa, 0x40, 0x54, 0x07, 0x96,
		0x4a, 0xbe, 0xab, 0x96, 0x6e, 0xcf, 0x3a, 0xb2, 0xdf, 0xbb, 0x47, 0x6d, 0xf3, 0xb8, 0x0f, 0xb4,
		0x29, 0xc5, 0xef, 0xd4, 0x49, 0xb1, 0x3a, 0xb1, 0xbb, 0xe7, 0x0d, 0xb7, 0x77, 0x7a, 0xe6, 0x58,
		0x3d, 0xd7, 0x6e, 0x51, 0x29, 0x54, 0xca, 0x2a, 0xa5, 0x38, 0xe6, 0x31, 0xe5, 0x41, 0x79, 0xfc,
		0x83, 0x3c, 0x9a, 0x0d, 0x0a, 0x84, 0x02, 0xf9, 0x87, 0x99, 0xa6, 0xc9, 0x99, 0x86, 0x4a, 0xf9,
		0x61, 0x76, 0xed, 0x43, 0xa9, 0x04, 0x22, 0xd2, 0x0b, 0x6e, 0x32, 0x5b, 0xf9, 0x3e, 0x02, 0x56,
		0x65, 0x48, 0x3d, 0xb0, 0x02, 0xa4, 0x22, 0x58, 0xe9, 0x51, 0x06, 0xac, 0xe8, 0x28, 0x04, 0x56,
		0x6e, 0x54, 0x04, 0x2b, 0x34, 0xaa, 0xa1, 0x5c, 0x35, 0xcc, 0x53, 0xc1, 0xa1, 0xd9, 0xe5, 0xb3,
		0x49, 0xea, 0xe4, 0x59, 0x7a, 0xe9, 0xb9, 0x66, 0xfb, 0xf8, 0xb4, 0x67, 0x3b, 0x6f, 0x4f, 0xd8,
		0x09, 0xa4, 0x52, 0xfe, 0x51, 0x29, 0x0f, 0xbf, 0x63, 0x3b, 0x70, 0xbd, 0x2f, 0xb6, 0x03, 0x39,
		0x79, 0xa3, 0x25, 0x63, 0x2a, 0x82, 0x49, 0x97, 0x92, 0xc8, 0xbb, 0xde, 0xeb, 0x73, 0xed, 0x21,
		0x55, 0xf2, 0x5c, 0xb5, 0xb4, 0xed, 0xce, 0x3b, 0x3e, 0xe2, 0xa7, 0x44, 0xfe, 0x41, 0x22, 0x67,
		0x9d, 0xc3, 0xd3, 0x4e, 0xdf, 0xe9, 0x99, 0x76, 0xc7, 0x6a, 0xb9, 0xed, 0x7e, 0x97, 0x62, 0xa1,
		0x58, 0xfe, 0x31, 0x9f, 0x98, 0x8e, 0xd3, 0xb3, 0x0f, 0xce, 0x1c, 0x8b, 0xcb, 0x99, 0x29, 0x95,
		0x95, 0x52, 0x99, 0x3d, 0xaa, 0xe8, 0x58, 0xf6, 0xf1, 0xdb, 0x83, 0xd3, 0x9e, 0x6b, 0xb6, 0x5a,
		0x3d, 0xab, 0x4f, 0xc1, 0x50, 0x30, 0xff, 0x24, 0x98, 0x86, 0x6b, 0x77, 0x1c, 0xab, 0x77, 0x64,
		0x1e, 0x5a, 0x54, 0x0c, 0x15, 0xf3, 0x5d, 0x74, 0x71, 0xec, 0xb6, 0xfd, 0x5f, 0xab, 0xe5, 0x1e,
		0x98, 0x9d, 0xd6, 0x7f, 0xec, 0x96, 0xf3, 0x96, 0x6a, 0xa1, 0x5a, 0xfe, 0x91, 0x5d, 0xba, 0xbd,
		0x53, 0xc7, 0x3a, 0x74, 0xec, 0xd3, 0x4e, 0x5a, 0x41, 0x53, 0x2f, 0xd4, 0xcb, 0x0a, 0xbd, 0xf4,
		0xac, 0xbe, 0xdd, 0x3a, 0x33, 0xdb, 0xcc, 0x2e, 0x54, 0xcb, 0xf7, 0xd5, 0x72, 0x62, 0xbe, 0x4f,
		0x33, 0x0c, 0xd5, 0x42, 0xb5, 0xfc, 0x58, 0x71, 0x44, 0xd6, 0xa5, 0x62, 0x7e, 0x2a, 0xbf, 0xf4,
		0xac, 0xbe, 0xd5, 0x3b, 0x37, 0x0f, 0xda, 0x16, 0xb3, 0x0c, 0x35, 0xf3, 0x83, 0xc4, 0xdb, 0x3e,
		0x65, 0x62, 0xa1, 0x48, 0xbe, 0x23, 0x92, 0x96, 0xd5, 0x36, 0xff, 0x70, 0xcf, 0xcd, 0x9e, 0x6d,
		0x4e, 0x6b, 0x23, 0xea, 0x85, 0x7a, 0x59, 0xa5, 0x17, 0xb3, 0xf5, 0x6f, 0xb7, 0x6d, 0x76, 0xc0,
		0x3c, 0xa1, 0x94, 0x49, 0xd1, 0x32, 0x39, 0x37, 0xed, 0x36, 0x51, 0x85, 0x72, 0xf9, 0xf1, 0xac,
		0xc2, 0x8c, 0x42, 0x89, 0xfc, 0x53, 0x05, 0x64, 0x77, 0x1e, 0xba, 0x2c, 0x33, 0x60, 0xa1, 0x5a,
		0xa8, 0x96, 0xd5, 0xcb, 0x5a, 0xd2, 0x6a, 0x99, 0x4f, 0x87, 0xa8, 0x97, 0x1f, 0xd1, 0x4b, 0x26,
		0x12, 0x37, 0x5b, 0x0e, 0xe5, 0xb0, 0x6e, 0xa6, 0x60, 0x56, 0x0a, 0xc6, 0x7a, 0xef, 0x58, 0x9d,
		0x96, 0xd5, 0x72, 0xcd, 0xd6, 0x74, 0x66, 0x3a, 0xee, 0x9d, 0x9e, 0x71, 0xe9, 0x1c, 0xf5, 0xf2,
		0x0f, 0x84, 0x4b, 0x99, 0x50, 0x26, 0xdf, 0x95, 0xc9, 0x6c, 0x15, 0x14, 0x97, 0xcd, 0x51, 0x30,
		0x3f, 0x2a, 0x18, 0x96, 0x43, 0x54, 0xc9, 0xf7, 0x55, 0xe2, 0x58, 0x6e, 0xcb, 0x3a, 0x32, 0xcf,
		0xda, 0x8e, 0x7b, 0x62, 0x39, 0x3d, 0xfb, 0x90, 0x06, 0xde, 0xf5, 0xbe, 0x68, 0xe0, 0xad, 0xcc,
		0x60, 0xc3, 0x77, 0x5b, 0x51, 0x0a, 0x79, 0x4b, 0x01, 0xd0, 0x55, 0x45, 0x51, 0x14, 0x92, 0x1f,
		0x90, 0xdc, 0x53, 0x94, 0x44, 0x01, 0xe5, 0x1e, 0xa2, 0x4b, 0x8a, 0xc2, 0x28, 0xa4, 0x0f, 0x00,
		0xb8, 0x42, 0x94, 0xca, 0xc8, 0x1d, 0x2d, 0x00, 0x5d, 0x4f, 0x54, 0x45, 0x21, 0x6c, 0x01, 0xe7,
		0x6e, 0xa2, 0x2e, 0xf2, 0xd6, 0x05, 0xa2, 0x8b, 0x89, 0xaa, 0xc8, 0x5b, 0x15, 0x88, 0x6e, 0x25,
		0xaa, 0xa2, 0x90, 0x62, 0x84, 0xcc, 0x49, 0x65, 0x68, 0xe4, 0x3e, 0xa2, 0x36, 0x0a, 0x21, 0x4f,
		0x0c, 0x97, 0x11, 0xc5, 0x50, 0x88, 0x18, 0xe0, 0xdc, 0x44, 0xd4, 0x45, 0xde, 0xba, 0x80, 0x72,
		0x0d, 0x51, 0x0e, 0xb9, 0xcb, 0x01, 0xd1, 0x1d, 0x44, 0x59, 0x14, 0x91, 0x25, 0x98, 0x21, 0x28,
		0x05, 0x50, 0xb7, 0x0f, 0x55, 0x91, 0xb7, 0x2a, 0x30, 0x5d, 0x3d, 0xd4, 0x45, 0xde, 0xba, 0x00,
		0x75, 0xef, 0x50, 0x18, 0x79, 0x0b, 0x03, 0xd3, 0xa5, 0x43, 0x5d, 0xe4, 0x4f, 0x9a, 0x94, 0x03,
		0xe5, 0x80, 0xee, 0xba, 0xa1, 0x30, 0xf2, 0x16, 0x06, 0xcb, 0x0f, 0xaa, 0x01, 0xda, 0x45, 0x23,
		0xdb, 0x3d, 0x23, 0xd7, 0x35, 0x23, 0xf3, 0xbe, 0xc9, 0x8b, 0x4a, 0x56, 0x44, 0xc2, 0x52, 0xa0,
		0x61, 0x86, 0xe1, 0x28, 0xf1, 0x12, 0x7f, 0x14, 0x1a, 0xfb, 0x02, 0x93, 0x9f, 0x11, 0x0f, 0x3e,
		0xaa, 0x1b, 0x6f, 0xec, 0x25, 0x1f, 0xa7, 0xe9, 0xae, 0x3e, 0x1a, 0xab, 0x70, 0x30, 0x0a, 0xaf,
		0xfc, 0xeb, 0x5a, 0xa8, 0x92, 0xcf, 0xa3, 0xe8, 0x53, 0xcd, 0x0f, 0xe3, 0xc4, 0x0b, 0x07, 0xaa,
		0xfe, 0xed, 0x1b, 0xf1, 0xd2, 0x3b, 0xf5, 0x71, 0x34, 0x4a, 0x46, 0x83, 0x51, 0x10, 0x67, 0xdf,
		0xd5, 0xfd, 0xd8, 0x8f, 0xeb, 0x81, 0xba, 0x55, 0xc1, 0xfc, 0x4b, 0x3d, 0xf0, 0xc3, 0x4f, 0xb5,
		0x38, 0xf1, 0x12, 0x55, 0x1b, 0x7a, 0x89, 0x77, 0xe9, 0xc5, 0xaa, 0x1e, 0xc4, 0xe3, 0x7a, 0x12,
		0xdc, 0xc6, 0xd3, 0x5f, 0xea, 0x37, 0x49, 0xcd, 0x1f, 0xdf, 0x36, 0x6b, 0x91, 0xf2, 0x06, 0x1f,
		0xbd, 0x4b, 0x3f, 0xf0, 0x93, 0xbb, 0xfa, 0x38, 0x52, 0x57, 0xfe, 0x17, 0x15, 0xcf, 0xbf, 0xa9,
		0xc7, 0x93, 0xcb, 0xd9, 0x0f, 0xa4, 0x5f, 0xeb, 0xb3, 0x7f, 0x4f, 0x56, 0x32, 0x96, 0x33, 0x30,
		0x04, 0x0d, 0x0a, 0x23, 0xf1, 0xae, 0xc5, 0x8d, 0x84, 0x6c, 0xba, 0x9f, 0x06, 0x27, 0x2c, 0x81,
		0xbc, 0xf3, 0xc3, 0xa1, 0xb1, 0xbf, 0xb1, 0x25, 0x2c, 0xac, 0xc3, 0x59, 0x92, 0x30, 0xf6, 0x37,
		0x36, 0x85, 0x05, 0xd6, 0x9d, 0xa5, 0x07, 0x99, 0xc9, 0x76, 0x21, 0xb3, 0xd1, 0xa0, 0x36, 0x4d,
		0x8b, 0x02, 0x4f, 0x6f, 0x34, 0xfa, 0xa3, 0x49, 0x34, 0x50, 0x22, 0x6f, 0x5f, 0x3a, 0x1c, 0xd4,
		0xdd, 0xe7, 0x51, 0x34, 0x1d, 0x11, 0x46, 0x3a, 0x11, 0x08, 0x3d, 0x02, 0xd3, 0x78, 0xeb, 0xc5,
		0x66, 0x74, 0x3d, 0xb9, 0x51, 0x61, 0x62, 0xec, 0x6f, 0x24, 0xd1, 0x44, 0x09, 0x0d, 0xf4, 0x51,
		0x94, 0x99, 0x30, 0x09, 0x99, 0x50, 0x90, 0xd9, 0xf2, 0x23, 0xa1, 0x74, 0x39, 0xa3, 0x32, 0xb1,
		0xc9, 0x64, 0x91, 0x8f, 0xd3, 0x30, 0x85, 0x8e, 0x4f, 0x99, 0x00, 0x20, 0x1e, 0x04, 0x10, 0x80,
		0x00, 0x08, 0x0c, 0x50, 0x00, 0x01, 0x0e, 0x14, 0xe0, 0x80, 0x01, 0x0b, 0x1c, 0x64, 0x02, 0x84,
		0x50, 0x90, 0x10, 0x0f, 0x14, 0x8f, 0xbb, 0x08, 0xaf, 0xb7, 0xe5, 0x27, 0xa1, 0x47, 0x7d, 0x85,
		0xd7, 0xdb, 0xd2, 0x13, 0xd0, 0x1c, 0x34, 0x36, 0x85, 0x87, 0x29, 0x1d, 0x38, 0x90, 0xc0, 0x03,
		0x10, 0x40, 0xd0, 0x40, 0x04, 0x16, 0x48, 0x60, 0xc1, 0x04, 0x13, 0x50, 0x64, 0x83, 0x8a, 0x70,
		0x60, 0xc9, 0x3e, 0x72, 0xe7, 0x6e, 0xac, 0xb0, 0x32, 0xee, 0xc4, 0x0f, 0x13, 0xf1, 0x6c, 0xf0,
		0x98, 0x0f, 0x76, 0x01, 0x42, 0xed, 0x79, 0xe1, 0xf5, 0xf4, 0xee, 0x7e, 0x80, 0x48, 0x54, 0x38,
		0x3b, 0xcc, 0x1a, 0x27, 0x7e, 0x08, 0x33, 0xe3, 0x82, 0x81, 0xed, 0x52, 0xd8, 0xe7, 0x5e, 0x30,
		0x51, 0x80, 0x71, 0x1f, 0x45, 0xde, 0x20, 0xf1, 0x47, 0x61, 0xcb, 0xbf, 0xf6, 0x93, 0x78, 0x7a,
		0x01, 0xdc, 0x96, 0x3a, 0x8f, 0xa1, 0xe8, 0x7d, 0xe1, 0x50, 0x2c, 0x78, 0x28, 0x36, 0xb6, 0xf7,
		0x1a, 0x7b, 0xcd, 0xdd, 0xed, 0xbd, 0x1d, 0x8e, 0x49, 0x02, 0x31, 0x56, 0x94, 0x17, 0x2c, 0x2c,
		0x5e, 0x30, 0x80, 0xda, 0x7e, 0x9c, 0x98, 0x49, 0x12, 0x61, 0x14, 0x17, 0x27, 0x7e, 0x68, 0x05,
		0x6a, 0x5a, 0xfb, 0xc6, 0x18, 0xd9, 0x76, 0x3a, 0x9b, 0x3d, 0x8a, 0x78, 0xeb, 0x4d, 0xa3, 0xd1,
		0xdc, 0x6d, 0x34, 0x36, 0x77, 0x5f, 0xef, 0x6e, 0xee, 0xed, 0xec, 0x6c, 0x35, 0xb7, 0x00, 0x32,
		0xae, 0x71, 0x1a, 0x0d, 0x55, 0xa4, 0x86, 0x07, 0x77, 0xc6, 0xfe, 0x46, 0x38, 0x09, 0x82, 0x5f,
		0x98, 0xb1, 0xf4, 0x89, 0x4c, 0xea, 0xb3, 0x1a, 0xe1, 0x2b, 0x8c, 0xb3, 0x38, 0x75, 0x59, 0x69,
		0x9c, 0x78, 0xd7, 0x12, 0x57, 0x1b, 0xcb, 0x1d, 0x3c, 0x5c, 0xbb, 0x05, 0x3c, 0x7c, 0x75, 0x1a,
		0xb6, 0x12, 0xd7, 0xdb, 0xc6, 0x49, 0x34, 0x19, 0x24, 0xe1, 0xbc, 0x19, 0xdc, 0x49, 0xef, 0x97,
		0x3d, 0xbf, 0x5d, 0x6e, 0x77, 0x7e, 0x93, 0x5c, 0x3b, 0xf6, 0x63, 0xb7, 0x3d, 0xbd, 0x3b, 0x6e,
		0x3b, 0x1e, 0xbb, 0x4e, 0x70, 0xeb, 0x9e, 0x24, 0xf6, 0xf8, 0xb6, 0xd9, 0x7b, 0x74, 0x0b, 0xdc,
		0xf4, 0x89, 0xa3, 0xdb, 0x9f, 0x5d, 0xb1, 0xeb, 0x78, 0xd7, 0x34, 0x44, 0x88, 0x4f, 0x02, 0x46,
		0xe2, 0x5d, 0x37, 0x1b, 0xa2, 0x2d, 0x11, 0xcd, 0x06, 0x4d, 0x11, 0x3f, 0x14, 0x16, 0x4d, 0x11,
		0x2f, 0x10, 0x1a, 0x4d, 0x11, 0xcf, 0x1f, 0x0e, 0x34, 0x45, 0xac, 0x9b, 0xca, 0x68, 0x8a, 0x40,
		0x07, 0x6b, 0x9a, 0x22, 0x5e, 0x96, 0x8f, 0x69, 0x8a, 0xd0, 0x0f, 0x04, 0x10, 0x80, 0x00, 0x08,
		0x0c, 0x50, 0x00, 0x01, 0x0e, 0x14, 0xe0, 0x80, 0x01, 0x0b, 0x1c, 0x64, 0x02, 0x84, 0x50, 0x90,
		0x10, 0x0f, 0x14, 0xc2, 0x3b, 0x09, 0x50, 0x9d, 0x85, 0x55, 0xa0, 0x41, 0x53, 0x44, 0x75, 0xc0,
		0x03, 0x10, 0x40, 0xd0, 0x40, 0x04, 0x16, 0x48, 0x60, 0xc1, 0x04, 0x13, 0x50, 0x64, 0x83, 0x8a,
		0x70, 0x60, 0xc9, 0x3e, 0x72, 0x4c, 0x53, 0x84, 0x78, 0x36, 0x78, 0xcc, 0x07, 0x6f, 0x68, 0x8a,
		0x58, 0xf3, 0x8b, 0xa6, 0x08, 0x82, 0xed, 0x13, 0x61, 0xd3, 0x14, 0xc1, 0xe9, 0xed, 0x9f, 0x86,
		0x22, 0x4d, 0x11, 0x85, 0x0f, 0x45, 0xcc, 0xc5, 0xba, 0xda, 0x8c, 0x4e, 0xda, 0x23, 0xd6, 0xf2,
		0xa2, 0x3d, 0xe2, 0x25, 0x03, 0x88, 0xf6, 0x88, 0xdc, 0xe7, 0x35, 0xda, 0x23, 0x98, 0xb1, 0x04,
		0x47, 0x46, 0x7b, 0xc4, 0xcb, 0xe2, 0xd4, 0x68, 0x9d, 0x75, 0xb3, 0x41, 0x83, 0x04, 0x6e, 0x44,
		0x34, 0x48, 0x54, 0x78, 0xe0, 0x56, 0xcf, 0x22, 0xd1, 0x6c, 0xd0, 0x24, 0x21, 0x3e, 0x11, 0x18,
		0x89, 0xc4, 0x47, 0x18, 0x0f, 0x2b, 0x19, 0xa6, 0xd1, 0xc9, 0xb4, 0x48, 0x6c, 0xd2, 0x22, 0xf1,
		0x63, 0x81, 0xd1, 0x22, 0xf1, 0xa2, 0x10, 0x69, 0x91, 0x58, 0x53, 0xa0, 0xb4, 0x48, 0x10, 0xad,
		0x8b, 0xfa, 0x08, 0xc5, 0x2e, 0x0c, 0xc8, 0x32, 0x5e, 0xa0, 0xbc, 0xab, 0x48, 0x5d, 0x49, 0xcc,
		0x78, 0x0b, 0x0b, 0x82, 0xc0, 0xfd, 0x10, 0x8d, 0xee, 0xbc, 0x1a, 0x79, 0xf5, 0x2a, 0xad, 0xc4,
		0xeb, 0x33, 0x42, 0x21, 0xe7, 0x0a, 0x8e, 0x44, 0x48, 0x6e, 0x98, 0x4e, 0x94, 0xc2, 0x90, 0x56,
		0xe6, 0xc3, 0x05, 0xb9, 0x0f, 0x11, 0xa0, 0x1e, 0x16, 0xc8, 0x7c, 0x28, 0x20, 0x65, 0x30, 0x0a,
		0xed, 0x7d, 0xe9, 0xd2, 0xf3, 0x12, 0x84, 0x15, 0x39, 0x76, 0xb9, 0x64, 0xcc, 0xfb, 0xe5, 0xcf,
		0xb2, 0xe5, 0x46, 0x50, 0x72, 0x4a, 0x91, 0x96, 0x4a, 0xe0, 0x53, 0x48, 0xb9, 0xa3, 0xaa, 0x3c,
		0x2d, 0x97, 0xa8, 0x63, 0x63, 0x12, 0x0e, 0xd5, 0x95, 0x1f, 0xaa, 0x61, 0x6d, 0xf1, 0x21, 0x94,
		0x2d, 0xe5, 0x87, 0x15, 0xeb, 0x4b, 0xa1, 0x95, 0x3c, 0xde, 0x65, 0x38, 0xe4, 0xc5, 0xf4, 0x7b,
		0x25, 0xf5, 0x77, 0x05, 0xf6, 0x73, 0xa5, 0xf5, 0x6f, 0xc5, 0xf6, 0x6b, 0xc5, 0xf6, 0x67, 0x65,
		0xf6, 0x63, 0xab, 0xcd, 0x5c, 0x52, 0x1c, 0xe3, 0x4b, 0xb3, 0x93, 0x9c, 0x71, 0xbe, 0x6a, 0xfe,
		0x94, 0x32, 0xdc, 0x65, 0x6d, 0x34, 0x23, 0xee, 0xf1, 0xa9, 0xc4, 0xc7, 0xa6, 0x82, 0x1f, 0x97,
		0x4a, 0x7d, 0x4c, 0x2a, 0xfe, 0xf1, 0xa8, 0xf8, 0xc7, 0xa2, 0xb2, 0x1f, 0x87, 0xf2, 0x11, 0x87,
		0xc4, 0x69, 0xf9, 0xa1, 0x17, 0x22, 0x72, 0x47, 0x38, 0xd1, 0x3b, 0xc1, 0x71, 0x0b, 0x58, 0xfc,
		0x89, 0x1a, 0x60, 0xc2, 0x96, 0x3e, 0x71, 0xc3, 0x4c, 0xe0, 0x30, 0x13, 0x39, 0xc6, 0x84, 0x2e,
		0x6b, 0x62, 0x17, 0x36, 0xc1, 0x8b, 0x9d, 0xe8, 0xb3, 0xc0, 0x02, 0x15, 0x5e, 0xcf, 0x1e, 0x7c,
		0x08, 0xdf, 0x03, 0x76, 0x1e, 0xa7, 0xec, 0x4d, 0x60, 0x37, 0xb9, 0x09, 0xac, 0x76, 0x48, 0x00,
		0x84, 0x06, 0x28, 0x88, 0x00, 0x87, 0x0a, 0x70, 0xc8, 0x80, 0x85, 0x0e, 0x32, 0x11, 0x42, 0x28,
		0x4a, 0x64, 0x1f, 0xad, 0xf8, 0xbd, 0xd4, 0xbe, 0xda, 0x43, 0xed, 0x8d, 0xe4, 0x7c, 0x39, 0x9f,
		0xbe, 0x05, 0xef, 0x5c, 0x00, 0xb2, 0x65, 0x1a, 0xc6, 0x8e, 0x1b, 0x40, 0x9b, 0x92, 0x42, 0xed,
		0xc7, 0x84, 0xb6, 0x25, 0x1a, 0xe2, 0x66, 0x4b, 0xf7, 0x18, 0x5b, 0xc4, 0x70, 0x88, 0xe5, 0x3c,
		0xc4, 0xb6, 0x77, 0x76, 0x38, 0xc8, 0xaa, 0x05, 0xa2, 0xf2, 0xa3, 0xbb, 0xe0, 0x36, 0x2b, 0xa8,
		0x49, 0x5c, 0xe6, 0xbe, 0x06, 0x4b, 0xa5, 0x84, 0xc0, 0xfd, 0x0d, 0x40, 0x66, 0x12, 0x36, 0x01,
		0xd7, 0xa9, 0x43, 0x36, 0x01, 0xd7, 0x37, 0x6c, 0xd8, 0x04, 0xcc, 0x39, 0x60, 0x36, 0x01, 0x75,
		0x2d, 0xbb, 0xd8, 0x04, 0x5c, 0xfb, 0xf4, 0xcd, 0x26, 0xe0, 0x4b, 0x5f, 0x6c, 0x02, 0xb2, 0x43,
		0xc1, 0x26, 0x60, 0x05, 0x67, 0xa3, 0xaf, 0x87, 0x18, 0x9b, 0x80, 0xb9, 0x0f, 0x31, 0x36, 0x01,
		0x2b, 0x07, 0xa2, 0xf2, 0xa3, 0x63, 0x13, 0x10, 0x36, 0x89, 0x1b, 0xb7, 0xf3, 0xc4, 0x22, 0xbc,
		0x0b, 0x98, 0x86, 0xc9, 0x36, 0xe0, 0x73, 0xc2, 0x63, 0x1b, 0x70, 0x8d, 0x42, 0x64, 0x1b, 0x70,
		0x7d, 0xc3, 0x86, 0x6d, 0xc0, 0x9c, 0x03, 0x66, 0x1b, 0x50, 0xd7, 0xc2, 0x0b, 0xa8, 0x0d, 0x78,
		0xe9, 0x87, 0x5e, 0x74, 0x07, 0xd0, 0x07, 0xdc, 0x23, 0xc6, 0x02, 0x46, 0xc4, 0x23, 0x43, 0x7e,
		0x2e, 0x3e, 0xd8, 0xbd, 0xcf, 0x96, 0x76, 0xb9, 0x5a, 0x7a, 0x47, 0xe2, 0xc9, 0x3f, 0x3c, 0x52,
		0xe3, 0x29, 0x11, 0xf2, 0x48, 0x0d, 0x3d, 0x6a, 0x4c, 0x5a, 0xce, 0xf5, 0xac, 0x25, 0x69, 0x39,
		0xaf, 0x5a, 0xcd, 0x48, 0xcb, 0x39, 0x3e, 0x7a, 0xf2, 0x48, 0x8d, 0x97, 0x4f, 0xb0, 0x3c, 0x52,
		0x03, 0x9e, 0x73, 0xb9, 0xdf, 0xd4, 0xd7, 0x13, 0x25, 0x8f, 0xd4, 0xf8, 0x91, 0xa8, 0x78, 0xa4,
		0xc6, 0x5a, 0x82, 0xe5, 0x91, 0x1a, 0x78, 0xbd, 0x21, 0x9d, 0x7b, 0x42, 0xba, 0x1f, 0xb3, 0x71,
		0xb6, 0xb8, 0x5e, 0x9e, 0xb7, 0x21, 0x27, 0x02, 0x9e, 0xb7, 0xa1, 0x6b, 0x7e, 0xa9, 0xec, 0xc9,
		0x1b, 0xbf, 0x54, 0x68, 0x1c, 0x2d, 0xa0, 0x39, 0x15, 0xc1, 0xc6, 0x54, 0x29, 0xc3, 0x92, 0xe6,
		0x11, 0x19, 0xb0, 0x2c, 0x07, 0x8e, 0x45, 0xc3, 0xb0, 0x0c, 0xf8, 0x2d, 0x6b, 0xd0, 0x08, 0x99,
		0x74, 0x60, 0x27, 0x9b, 0x12, 0x49, 0x35, 0x0f, 0x32, 0x2d, 0x67, 0xa6, 0x2c, 0x7e, 0x9e, 0x2a,
		0xf6, 0x7f, 0x2c, 0x78, 0x70, 0x97, 0x3d, 0xa8, 0xf1, 0x06, 0x73, 0xb1, 0xb2, 0x2f, 0x4e, 0x7c,
		0xc5, 0xfc, 0x4f, 0x05, 0xc9, 0xbb, 0x2c, 0x59, 0xc3, 0xc8, 0xb9, 0xc0, 0xb9, 0x68, 0xad, 0x73,
		0x4f, 0x31, 0xa3, 0x2f, 0xff, 0xb1, 0x50, 0xc0, 0x38, 0x30, 0xa6, 0x9f, 0x7b, 0xec, 0xc7, 0xb5,
		0x50, 0xf9, 0xd7, 0x1f, 0x2f, 0x47, 0x51, 0xcd, 0x4b, 0x92, 0xc8, 0xbf, 0x9c, 0x14, 0x78, 0x1a,
		0x44, 0xf6, 0x5c, 0xf0, 0x1f, 0x62, 0x29, 0x28, 0x23, 0x14, 0x7b, 0xa4, 0x43, 0xe1, 0xeb, 0x66,
		0xca, 0x58, 0x0f, 0x53, 0xe2, 0x3a, 0x97, 0xb2, 0xd6, 0xaf, 0x94, 0xbe, 0x2e, 0xa5, 0xf4, 0xf5,
		0x26, 0xe5, 0xae, 0x23, 0xd1, 0x8b, 0x52, 0x8a, 0x3e, 0x42, 0xc0, 0x58, 0xa4, 0xdf, 0xe2, 0xcf,
		0xb6, 0xcd, 0x72, 0xc5, 0x43, 0x08, 0x05, 0xeb, 0xb6, 0x9c, 0x33, 0x7d, 0x4a, 0x5b, 0x40, 0x59,
		0xe6, 0x02, 0x49, 0x01, 0x0b, 0x20, 0xcb, 0x5e, 0xe0, 0x28, 0x66, 0x01, 0xa3, 0x98, 0x05, 0x8a,
		0x32, 0x16, 0x20, 0xea, 0xdd, 0xcd, 0x29, 0xeb, 0x4c, 0x9a, 0x2c, 0xab, 0x97, 0x37, 0xde, 0xbe,
		0x9d, 0x5f, 0xca, 0x1a, 0x6e, 0xe5, 0x1e, 0x1d, 0x57, 0xfa, 0x7a, 0x7d, 0x09, 0xeb, 0xf2, 0x05,
		0xad, 0xbf, 0x97, 0xb2, 0xce, 0x5e, 0xdc, 0x7a, 0x7a, 0x71, 0xeb, 0xe6, 0x65, 0xad, 0x8f, 0xaf,
		0xd6, 0xe3, 0xf8, 0xb2, 0x8f, 0x52, 0x33, 0xb2, 0x1e, 0x6c, 0xf9, 0x03, 0x75, 0x91, 0xbb, 0x1e,
		0x42, 0x2a, 0x79, 0x5c, 0xc8, 0x38, 0x0b, 0x55, 0x8c, 0x11, 0x4d, 0x92, 0xf1, 0x4c, 0xa0, 0xd1,
		0x4c, 0x9a, 0xb1, 0x4c, 0xac, 0x91, 0x4c, 0xac, 0x71, 0x4c, 0xa6, 0x51, 0xac, 0xda, 0xeb, 0x3d,
		0xa5, 0x9c, 0x35, 0x9a, 0xcd, 0x4a, 0x72, 0xc6, 0xf7, 0xb7, 0xf3, 0xa5, 0x94, 0xe1, 0x2d, 0xeb,
		0x08, 0x71, 0x71, 0x3e, 0x6e, 0x89, 0xfe, 0x6d, 0xc1, 0xbe, 0x6d, 0xa9, 0x7e, 0x6d, 0xf1, 0x3e,
		0x6d, 0xf1, 0xfe, 0x6c, 0xd9, 0xbe, 0x6c, 0x7a, 0x2d, 0x25, 0x4e, 0xc3, 0x0f, 0xd3, 0xf1, 0x50,
		0xee, 0x26, 0x2b, 0xa5, 0x2d, 0xa9, 0xff, 0xde, 0x94, 0xcc, 0x2d, 0x56, 0x70, 0xa7, 0x68, 0x80,
		0xa9, 0x5a, 0xfa, 0x94, 0x0d, 0x33, 0x75, 0xc3, 0x4c, 0xe1, 0x18, 0x53, 0xb9, 0xac, 0x29, 0x5d,
		0xd8, 0xd4, 0x9e, 0x7d, 0x84, 0xdc, 0x62, 0x65, 0x0d, 0x35, 0x2f, 0xc4, 0x16, 0x2b, 0xfe, 0x90,
		0x1b, 0xac, 0x88, 0x1f, 0x93, 0x46, 0xba, 0xe3, 0xa3, 0x58, 0xc8, 0x4d, 0xc3, 0x93, 0xc9, 0xb9,
		0x5b, 0xe4, 0x5c, 0x72, 0x2e, 0x39, 0x97, 0x9c, 0x4b, 0xce, 0xe5, 0x9c, 0xfa, 0xed, 0x47, 0x28,
		0xad, 0x95, 0x95, 0x05, 0x26, 0xb0, 0xa5, 0xb5, 0x94, 0x8c, 0xc5, 0xb5, 0xb6, 0xbe, 0x9d, 0xfa,
		0x79, 0x52, 0x8d, 0x7e, 0x28, 0x00, 0x84, 0x04, 0x28, 0x68, 0x00, 0x87, 0x08, 0x70, 0xa8, 0x80,
		0x85, 0x0c, 0x32, 0xd1, 0x41, 0x28, 0x42, 0x64, 0x1f, 0x2d, 0xd6, 0x81, 0xd5, 0xcd, 0x06, 0xc0,
		0x49, 0x35, 0x6f, 0x78, 0x62, 0xf5, 0x0b, 0x5f, 0x3c, 0xb1, 0xba, 0x4a, 0x60, 0xb9, 0x14, 0x2e,
		0x4f, 0xac, 0xae, 0xea, 0x74, 0xf4, 0xf5, 0x10, 0xe3, 0x89, 0xd5, 0xb9, 0x0f, 0x31, 0xd9, 0xfb,
		0x55, 0x6b, 0x37, 0xea, 0x78, 0x84, 0xf5, 0xb3, 0x5e, 0x3c, 0xc2, 0x1a, 0x36, 0xab, 0x1b, 0x37,
		0x2a, 0x89, 0xfc, 0x81, 0xfc, 0xb6, 0xe0, 0x3c, 0x4e, 0xb6, 0x06, 0x9f, 0x13, 0x1e, 0x5b, 0x83,
		0x6b, 0x54, 0x22, 0x5b, 0x83, 0xeb, 0x1b, 0x36, 0x6c, 0x0d, 0xe6, 0x1c, 0x30, 0x5b, 0x83, 0xba,
		0xd6, 0x62, 0x40, 0xad, 0xc1, 0xcf, 0xfe, 0x50, 0xd5, 0x44, 0x4f, 0xe0, 0x8f, 0x27, 0xf1, 0x5d,
		0xf6, 0x07, 0x5f, 0xf8, 0x62, 0x7f, 0x90, 0xcd, 0x0b, 0x79, 0x6b, 0xe4, 0xb4, 0xea, 0x54, 0xb0,
		0x3f, 0xc8, 0x21, 0x36, 0x1d, 0x62, 0xcd, 0xdd, 0xdd, 0xdd, 0x6d, 0xf6, 0x04, 0xab, 0xc6, 0xa4,
		0xf2, 0xa3, 0x63, 0x4f, 0x10, 0x31, 0x22, 0x69, 0x2b, 0x29, 0x85, 0x9e, 0xf9, 0x98, 0xc5, 0x27,
		0xf5, 0x48, 0x82, 0xa7, 0xb7, 0x83, 0xaf, 0x67, 0xfb, 0x03, 0x67, 0xdf, 0xd5, 0x1f, 0xc2, 0xc9,
		0xc2, 0x48, 0x7d, 0x17, 0xf4, 0xef, 0x48, 0x1f, 0x21, 0xc6, 0xe2, 0x58, 0x3d, 0xb9, 0x0e, 0x9e,
		0x79, 0x80, 0xf4, 0xf0, 0xfc, 0x48, 0x58, 0xf4, 0xf0, 0xbc, 0x40, 0x6a, 0xf4, 0xf0, 0x3c, 0x7f,
		0x38, 0xd0, 0xc3, 0xb3, 0x6e, 0x6c, 0xa1, 0x87, 0x07, 0x9d, 0x3c, 0xc5, 0x7a, 0x78, 0xe6, 0x27,
		0x73, 0x8b, 0x7f, 0x60, 0x2f, 0xee, 0x04, 0x71, 0x00, 0x04, 0x10, 0x8f, 0x02, 0x08, 0x48, 0x00,
		0x84, 0x06, 0x28, 0x88, 0x00, 0x87, 0x0a, 0x70, 0xc8, 0x80, 0x85, 0x0e, 0x32, 0x11, 0x42, 0x28,
		0x4a, 0x88, 0x47, 0x8a, 0x2c, 0x40, 0x6f, 0xf8, 0x7f, 0xde, 0x40, 0x85, 0x83, 0xbb, 0x5a, 0xec,
		0x0f, 0x63, 0xf9, 0xd9, 0x68, 0x91, 0xe0, 0xbf, 0x89, 0x5b, 0xf8, 0x08, 0x97, 0x8d, 0x1e, 0x30,
		0x08, 0x82, 0x84, 0x22, 0x80, 0x48, 0x82, 0x86, 0x26, 0xb0, 0x88, 0x02, 0x8b, 0x2a, 0x98, 0xc8,
		0x22, 0x1b, 0x5d, 0x84, 0x23, 0x0c, 0x0c, 0xca, 0x3c, 0x8d, 0x34, 0x38, 0x49, 0xec, 0x49, 0xb2,
		0x41, 0x49, 0x64, 0x18, 0x80, 0x03, 0x07, 0x3a, 0x88, 0xc0, 0x03, 0x0c, 0x3e, 0xa8, 0x00, 0x04,
		0x0f, 0x42, 0xf0, 0x40, 0x84, 0x0d, 0x46, 0x18, 0x80, 0x04, 0x02, 0x4a, 0x70, 0xc0, 0x94, 0x05,
		0x2c, 0x73, 0x6f, 0xd8, 0x1f, 0x9e, 0x67, 0x24, 0xee, 0x1d, 0xab, 0x19, 0x38, 0xc1, 0x02, 0x14,
		0x32, 0x48, 0x69, 0x00, 0x54, 0xe8, 0x60, 0xa5, 0x0d, 0x60, 0x69, 0x03, 0x5a, 0x7a, 0x00, 0x17,
		0x16, 0x78, 0x81, 0x01, 0x18, 0x2c, 0x88, 0x65, 0x81, 0x5f, 0x05, 0xde, 0x75, 0x8c, 0x9b, 0x2c,
		0x17, 0xf3, 0x55, 0x7a, 0x19, 0xa0, 0xf9, 0x05, 0xcb, 0x25, 0xa6, 0x0d, 0xa8, 0xe9, 0x00, 0x6c,
		0x1a, 0x81, 0x9b, 0x2e, 0x00, 0xa7, 0x1d, 0xc8, 0x69, 0x07, 0x74, 0x7a, 0x81, 0x1d, 0x26, 0xe0,
		0x81, 0x82, 0x5e, 0x26, 0x1d, 0xf1, 0xdb, 0xa4, 0xfc, 0xf0, 0x8c, 0xa1, 0xc2, 0xc9, 0x8d, 0x8a,
		0x52, 0x37, 0x24, 0xf0, 0xac, 0xb1, 0xe8, 0x72, 0x35, 0x80, 0xaf, 0xc1, 0x0a, 0x27, 0x37, 0x53,
		0x51, 0x71, 0x28, 0x17, 0x79, 0xd7, 0xdb, 0x7e, 0x9c, 0x98, 0x49, 0x12, 0x61, 0x0f, 0xe7, 0x13,
		0x3f, 0xb4, 0x02, 0x35, 0x9d, 0xcd, 0x62, 0x5c, 0x14, 0xdf, 0x98, 0xef, 0xf0, 0xf1, 0xe8, 0x4a,
		0x70, 0xf7, 0xaa, 0x7d, 0xf2, 0xe2, 0x4e, 0xa3, 0xa1, 0x8a, 0xd4, 0xf0, 0xe0, 0xce, 0xd8, 0xdf,
		0x08, 0x27, 0x41, 0xf0, 0x0b, 0x51, 0x83, 0xb9, 0xe9, 0x69, 0xa9, 0xdc, 0xce, 0x77, 0x63, 0x01,
		0x6f, 0xcd, 0xa4, 0x97, 0xc1, 0xd6, 0x4c, 0x19, 0xe1, 0xb3, 0x35, 0x23, 0x68, 0x20, 0xb0, 0x35,
		0x23, 0x67, 0x58, 0xb3, 0x35, 0x23, 0xfc, 0x82, 0xd8, 0x9a, 0x21, 0x33, 0x3d, 0x53, 0x3a, 0xfa,
		0xb4, 0x66, 0x26, 0x7e, 0x98, 0xbc, 0xde, 0xd6, 0xa0, 0x2b, 0xb3, 0x0b, 0x7c, 0x09, 0x18, 0x9b,
		0xe3, 0x7e, 0xef, 0x85, 0x3d, 0x61, 0x6f, 0xa0, 0x6d, 0xae, 0xab, 0x79, 0x61, 0xb1, 0x74, 0x39,
		0x60, 0x87, 0x77, 0x7d, 0xf7, 0x7a, 0x00, 0xb7, 0x14, 0xd5, 0x74, 0x3a, 0xff, 0x3a, 0x05, 0x78,
		0x5f, 0x98, 0x02, 0x84, 0xa7, 0x80, 0xc6, 0xf6, 0x5e, 0x63, 0xaf, 0xb9, 0xbb, 0xbd, 0xb7, 0xc3,
		0x5c, 0xc0, 0x82, 0x84, 0xd1, 0x3f, 0x7e, 0x5d, 0xb0, 0xdd, 0xcf, 0xb9, 0x6e, 0x45, 0x9a, 0xf9,
		0xac, 0xfc, 0xeb, 0x8f, 0x09, 0x7e, 0xbf, 0x7f, 0x7e, 0x1d, 0x6c, 0xf8, 0x97, 0x11, 0x3e, 0x1b,
		0xfe, 0x82, 0x46, 0x02, 0x1b, 0xfe, 0x72, 0x86, 0x35, 0x1b, 0xfe, 0xc2, 0x2f, 0x88, 0x0d, 0x7f,
		0x52, 0xd3, 0x33, 0xa5, 0xa3, 0x57, 0xc3, 0xff, 0x8d, 0x06, 0xfd, 0xfe, 0x1d, 0xf6, 0xfb, 0x4b,
		0x7e, 0xb1, 0xdf, 0xcf, 0xba, 0x22, 0xc7, 0xcb, 0x61, 0xbf, 0x9f, 0xb3, 0x79, 0x11, 0x29, 0x80,
		0xfd, 0x7e, 0xf1, 0x29, 0x60, 0x7b, 0x87, 0x8d, 0x7e, 0x16, 0x22, 0x8c, 0xfe, 0xab, 0x17, 0x1b,
		0xfd, 0x8c, 0x18, 0x7e, 0x4a, 0x96, 0x7e, 0x4e, 0xe2, 0x77, 0xe3, 0xd7, 0xf3, 0x1c, 0xc5, 0xf4,
		0xf4, 0xbb, 0xf9, 0xd7, 0xfa, 0xd7, 0xbb, 0xd4, 0x7f, 0xfd, 0x5b, 0x89, 0x67, 0x2e, 0xea, 0x33,
		0xa2, 0x81, 0x46, 0x33, 0xa8, 0x97, 0x08, 0xda, 0x43, 0x04, 0xca, 0xfb, 0xdc, 0x77, 0xaf, 0x4c,
		0xa1, 0x73, 0xdf, 0xbd, 0xf2, 0x86, 0x2b, 0xf7, 0xdd, 0x93, 0x86, 0x9f, 0xdc, 0x77, 0x8f, 0x4c,
		0xf3, 0xcf, 0x12, 0x81, 0x7d, 0xf4, 0x97, 0x65, 0xfc, 0x40, 0x79, 0x57, 0x91, 0xba, 0x42, 0xcc,
		0xf8, 0x8b, 0x2d, 0x57, 0x00, 0xdd, 0x3d, 0x46, 0x77, 0x5e, 0x14, 0xbe, 0x7a, 0x95, 0x16, 0x49,
		0xf5, 0x14, 0x31, 0x59, 0x2a, 0x55, 0x38, 0x52, 0x94, 0x5d, 0xdf, 0xdf, 0xa9, 0x3b, 0xb4, 0xa2,
		0x08, 0x73, 0x93, 0x1d, 0xdc, 0x4d, 0x75, 0xb4, 0xda, 0x44, 0x07, 0x73, 0xd3, 0x1c, 0x94, 0x6c,
		0x02, 0xda, 0xe4, 0xad, 0x7c, 0x73, 0x17, 0xe9, 0xb0, 0xa3, 0x38, 0x89, 0x26, 0x83, 0x24, 0x9c,
		0x23, 0x6f, 0x27, 0xbd, 0xf9, 0xf6, 0xfc, 0xa2, 0xdd, 0xee, 0xfc, 0x8e, 0xbb, 0x76, 0xec, 0xc7,
		0x6e, 0x7b, 0x7a, 0xab, 0xdd, 0x76, 0x3c, 0x76, 0x9d, 0xe0, 0xd6, 0x3d, 0x49, 0xa6, 0x6f, 0x76,
		0xe6, 0xb7, 0xcc, 0x5c, 0xdc, 0x4e, 0x77, 0xf1, 0x8e, 0x9b, 0xfd, 0x2b, 0xfd, 0xd9, 0x2d, 0x73,
		0xcd, 0xc5, 0x3d, 0xea, 0xfb, 0x43, 0x0c, 0x9c, 0xbb, 0xe7, 0xa9, 0x86, 0x3a, 0x27, 0x5a, 0xb4,
		0x04, 0x5b, 0xc1, 0xc4, 0x2a, 0x3b, 0x4f, 0xc8, 0x1d, 0x7d, 0x82, 0x47, 0x9e, 0xe1, 0x0d, 0x6f,
		0xfc, 0xb0, 0x76, 0x1d, 0x8d, 0x26, 0x63, 0xa4, 0x23, 0xc7, 0x1f, 0x82, 0xe6, 0x79, 0xe3, 0xeb,
		0x08, 0x93, 0xe7, 0x8d, 0xe7, 0x28, 0x57, 0x9e, 0x37, 0x9e, 0x67, 0x8f, 0x87, 0xe7, 0x8d, 0x17,
		0x8b, 0x69, 0x3c, 0x6f, 0xbc, 0x6a, 0x64, 0x0e, 0x73, 0xde, 0x38, 0xd6, 0xb1, 0x99, 0x90, 0xc7,
		0x65, 0xf2, 0x7c, 0x71, 0x02, 0x8e, 0x06, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40,
		0xd8, 0x20, 0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x59, 0xc0, 0x48, 0x5d, 0x9f, 0x95,
		0xb3, 0x0d, 0x4e, 0x17, 0x68, 0x15, 0x44, 0x71, 0xcd, 0x33, 0xa1, 0x4a, 0x63, 0xb8, 0x42, 0x87,
		0x2c, 0x6d, 0x60, 0x4b, 0x1b, 0xe8, 0xd2, 0x03, 0xbe, 0xb0, 0x20, 0x0c, 0x0c, 0xc6, 0x32, 0x89,
		0xe0, 0xaf, 0x79, 0x86, 0x3d, 0xd7, 0x00, 0xf8, 0x3c, 0x03, 0xf0, 0x7d, 0x8d, 0xb0, 0x4f, 0x66,
		0xd4, 0x60, 0x03, 0x45, 0x2d, 0x36, 0x2f, 0xd1, 0x65, 0xdf, 0x22, 0x9d, 0xb6, 0x2a, 0xb9, 0xc7,
		0x3e, 0xaa, 0x94, 0x43, 0x5b, 0xd8, 0xd0, 0xd6, 0xe5, 0xfc, 0x01, 0xad, 0xc6, 0x38, 0xb7, 0xc3,
		0x29, 0xe4, 0x75, 0xc1, 0xc2, 0x2b, 0xc7, 0x01, 0x09, 0x7d, 0x50, 0x38, 0xfe, 0x01, 0xe1, 0x5a,
		0x1e, 0x0c, 0x8e, 0x7d, 0x20, 0x38, 0x1d, 0xa8, 0x95, 0xcc, 0x88, 0xf4, 0x8c, 0x89, 0xb6, 0x36,
		0x64, 0x4f, 0x0f, 0x91, 0xf6, 0xff, 0xa2, 0x0b, 0x4a, 0xeb, 0xd4, 0x41, 0x17, 0x94, 0xec, 0x54,
		0x81, 0xb0, 0x86, 0xbf, 0x50, 0x17, 0xe9, 0x8d, 0x1f, 0x1e, 0xcf, 0x6e, 0x0c, 0xbd, 0x61, 0xba,
		0xe5, 0x23, 0xc3, 0xbb, 0xf5, 0xfc, 0xc0, 0xbb, 0x0c, 0x54, 0xed, 0xd2, 0x0b, 0x87, 0x9f, 0xfd,
		0xe1, 0x6c, 0x90, 0xa3, 0x78, 0xc4, 0x9e, 0x08, 0x9e, 0x5e, 0xb1, 0x75, 0x84, 0x49, 0xaf, 0x58,
		0x8e, 0xb2, 0xa5, 0x57, 0x2c, 0xbf, 0xe1, 0x45, 0xaf, 0x58, 0xd1, 0x30, 0x4b, 0xaf, 0x58, 0xd5,
		0xea, 0x17, 0x7a, 0xc5, 0xf2, 0x9d, 0x1f, 0xe8, 0x15, 0x23, 0xd8, 0x20, 0x02, 0x0e, 0x30, 0xe8,
		0xa0, 0x02, 0x0f, 0x3c, 0xf8, 0xc0, 0x03, 0x10, 0x36, 0x08, 0x61, 0x00, 0x11, 0x08, 0x18, 0xc1,
		0x01, 0x52, 0x16, 0x30, 0x4e, 0xef, 0x67, 0xe5, 0x5c, 0x83, 0xd2, 0x01, 0x5a, 0x05, 0x50, 0xf4,
		0x89, 0x11, 0xa8, 0x34, 0x06, 0x2b, 0x74, 0xc0, 0xd2, 0x06, 0xb4, 0xb4, 0x01, 0x2e, 0x3d, 0xc0,
		0x0b, 0x0b, 0xc0, 0xc0, 0x40, 0x2c, 0x93, 0x08, 0xbe, 0x4f, 0xcc, 0x57, 0x4a, 0x5d, 0x05, 0x23,
		0x0f, 0xdb, 0x2c, 0xb6, 0x07, 0x18, 0x7a, 0x5b, 0x85, 0xd7, 0x33, 0x30, 0xa6, 0x5b, 0xac, 0xe0,
		0x3b, 0x4f, 0xb7, 0x98, 0x9c, 0xcb, 0xc8, 0x2c, 0x25, 0x74, 0x92, 0x70, 0x12, 0x5e, 0xc3, 0xd0,
		0xa6, 0x5b, 0x8c, 0x43, 0x9b, 0x43, 0x5b, 0x8f, 0x6a, 0x00, 0x37, 0xea, 0x0b, 0x5a, 0x4c, 0xaa,
		0x3e, 0x35, 0x19, 0x09, 0x62, 0x6d, 0x98, 0xd5, 0x85, 0xb3, 0xe8, 0xd9, 0xf1, 0x2e, 0x22, 0x6c,
		0x76, 0xbc, 0x4b, 0xd4, 0x39, 0x3b, 0xde, 0xe5, 0x0d, 0x57, 0x76, 0xbc, 0x85, 0x5d, 0x08, 0x3b,
		0xde, 0x24, 0x9a, 0xef, 0x48, 0x44, 0x83, 0x8e, 0xf7, 0x50, 0x85, 0x89, 0x9f, 0xdc, 0x81, 0x9f,
		0x08, 0x8d, 0x68, 0xc4, 0xb7, 0xe7, 0xb7, 0xfe, 0xc0, 0x8b, 0x81, 0xe7, 0xad, 0x85, 0x90, 0xec,
		0xbe, 0xdd, 0x77, 0xfb, 0x67, 0x07, 0x4e, 0xfb, 0xdc, 0x75, 0xfe, 0xe8, 0x5a, 0xa8, 0xd3, 0xd7,
		0xac, 0x4f, 0x13, 0xc3, 0x3e, 0x88, 0xd8, 0x80, 0x7e, 0x18, 0xf1, 0xb5, 0xa2, 0xba, 0x6e, 0xcf,
		0x32, 0x0f, 0xdf, 0x9a, 0x07, 0x76, 0xdb, 0x76, 0xfe, 0x98, 0x8b, 0xab, 0x8f, 0xac, 0x2e, 0x9d,
		0x54, 0xa6, 0x87, 0xda, 0xbe, 0xab, 0xba, 0x6e, 0xcf, 0x3a, 0xb2, 0xdf, 0xbb, 0x47, 0x6d, 0xf3,
		0xb8, 0x6f, 0xc0, 0x5f, 0xea, 0xfd, 0xef, 0xd4, 0x9b, 0x6c, 0xbd, 0xd9, 0xdd, 0xf3, 0x86, 0xdb,
		0x3b, 0x3d, 0x73, 0xac, 0x9e, 0x6b, 0xb7, 0xa8, 0x38, 0x2a, 0x2e, 0x6f, 0xc5, 0x39, 0xe6, 0x31,
		0x65, 0x46, 0x99, 0x15, 0x20, 0xb3, 0x66, 0x83, 0x42, 0xa3, 0xd0, 0x0a, 0x98, 0x41, 0x9b, 0x9c,
		0x41, 0xa9, 0xb8, 0xc2, 0x6b, 0x84, 0xbe, 0x16, 0x6a, 0x83, 0xbe, 0x82, 0x0b, 0xae, 0x33, 0xe3,
		0xe8, 0x66, 0xe5, 0x4f, 0x5d, 0xb1, 0xc2, 0xa7, 0xb2, 0x2a, 0xa7, 0x2c, 0xe8, 0x4a, 0x9e, 0x72,
		0x62, 0xc5, 0x4e, 0x41, 0xe9, 0x3e, 0xf3, 0x35, 0x39, 0xf3, 0x51, 0x59, 0xac, 0xc0, 0xa9, 0x2a,
		0x89, 0xaa, 0x9a, 0xa7, 0xa6, 0x43, 0xb3, 0xcb, 0x35, 0x07, 0xd4, 0x5b, 0xa9, 0xba, 0xeb, 0xb9,
		0x66, 0xfb, 0xf8, 0xb4, 0x67, 0x3b, 0x6f, 0x4f, 0xd8, 0xc1, 0xa6, 0xe2, 0x0a, 0x51, 0xdc, 0xc3,
		0xef, 0xd8, 0xc6, 0x2e, 0xf7, 0xc5, 0x36, 0x36, 0x87, 0x38, 0x27, 0x13, 0x2a, 0x8b, 0x93, 0x06,
		0xa5, 0x55, 0x8d, 0x7a, 0xbe, 0xcf, 0xb5, 0xde, 0x54, 0x5b, 0xd9, 0xaa, 0x6b, 0xdb, 0x9d, 0x77,
		0x5c, 0x32, 0x44, 0xa9, 0x15, 0x20, 0xb5, 0xb3, 0xce, 0xe1, 0x69, 0xa7, 0xef, 0xf4, 0x4c, 0xbb,
		0x63, 0xb5, 0xdc, 0x76, 0xbf, 0x4b, 0xd1, 0x51, 0x74, 0x85, 0xe4, 0x37, 0xd3, 0x71, 0x7a, 0xf6,
		0xc1, 0x99, 0x63, 0xd1, 0xce, 0x42, 0xc9, 0xe5, 0x2e, 0xb9, 0xd9, 0x23, 0xbf, 0x8e, 0x65, 0x1f,
		0xbf, 0x3d, 0x38, 0xed, 0xb9, 0x66, 0xab, 0xd5, 0xb3, 0xfa, 0x14, 0x1e, 0x85, 0x57, 0x84, 0xf0,
		0x1a, 0xae, 0xdd, 0x71, 0xac, 0xde, 0x91, 0x79, 0x68, 0x51, 0x79, 0x54, 0x5e, 0x61, 0x68, 0xe7,
		0xd8, 0x6d, 0xfb, 0xbf, 0x56, 0xcb, 0x3d, 0x30, 0x3b, 0xad, 0xff, 0xd8, 0x2d, 0xe7, 0x2d, 0x55,
		0x47, 0xd5, 0x15, 0xc2, 0x76, 0xdd, 0xde, 0xa9, 0x63, 0x1d, 0x3a, 0xf6, 0x69, 0x27, 0xed, 0x9c,
		0x50, 0x77, 0xd4, 0x5d, 0xce, 0xba, 0xeb, 0x59, 0x7d, 0xbb, 0x75, 0x66, 0xb6, 0x99, 0xed, 0xa8,
		0xba, 0xe2, 0x54, 0x77, 0x62, 0xbe, 0x4f, 0x33, 0x1e, 0x55, 0x47, 0xd5, 0x15, 0x5b, 0xcc, 0xb2,
		0xa6, 0xa0, 0xf2, 0x4a, 0xc9, 0x77, 0x3d, 0xab, 0x6f, 0xf5, 0xce, 0xcd, 0x83, 0xb6, 0xc5, 0xac,
		0x47, 0xed, 0x15, 0x5c, 0x59, 0xb4, 0x4f, 0x99, 0xe8, 0x28, 0xb6, 0x82, 0xc4, 0xd6, 0xb2, 0xda,
		0xe6, 0x1f, 0xee, 0xb9, 0xd9, 0xb3, 0xcd, 0x69, 0x2d, 0x4b, 0xdd, 0x51, 0x77, 0x79, 0xeb, 0xce,
		0x6c, 0xfd, 0xdb, 0x6d, 0x9b, 0x1d, 0x4d, 0xf6, 0x70, 0xa0, 0xdc, 0xa4, 0xcb, 0xed, 0xdc, 0xb4,
		0xdb, 0x44, 0x39, 0xca, 0xae, 0xf8, 0x2c, 0xc7, 0x0c, 0x47, 0xa9, 0x15, 0x51, 0xb1, 0xda, 0x9d,
		0x87, 0x2e, 0xdd, 0x0c, 0xe8, 0xa8, 0x3a, 0xaa, 0x2e, 0x6f, 0xd5, 0x9d, 0x75, 0xd2, 0x2e, 0x09,
		0x9f, 0xbe, 0x52, 0x77, 0x45, 0xea, 0x2e, 0x13, 0x9b, 0x9b, 0x2d, 0xeb, 0x74, 0xd8, 0x2f, 0xa1,
		0xf0, 0x72, 0x17, 0x9e, 0xf5, 0xde, 0xb1, 0x3a, 0x2d, 0xab, 0xe5, 0x9a, 0xad, 0xe9, 0x8c, 0x7b,
		0xdc, 0x3b, 0x3d, 0xe3, 0x52, 0x62, 0xea, 0xae, 0x80, 0x4a, 0x82, 0x72, 0xa3, 0xdc, 0x0a, 0x93,
		0xdb, 0x6c, 0x35, 0x27, 0x97, 0x11, 0x53, 0x78, 0x45, 0x0b, 0x8f, 0xe5, 0x2b, 0xd5, 0x56, 0x9c,
		0xda, 0x1c, 0xcb, 0x6d, 0x59, 0x47, 0xe6, 0x59, 0xdb, 0x71, 0x4f, 0x2c, 0xa7, 0x67, 0x1f, 0x72,
		0x23, 0x8e, 0x72, 0x5f, 0xdc, 0x88, 0x83, 0x83, 0x7c, 0xad, 0x53, 0x09, 0x37, 0xa8, 0xa3, 0xa4,
		0xd6, 0x27, 0x29, 0x8d, 0x5c, 0xc4, 0x14, 0x97, 0xc8, 0x7c, 0xa5, 0x83, 0x5b, 0x98, 0xd2, 0x12,
		0x58, 0xce, 0xeb, 0xe4, 0x0a, 0xa6, 0xc0, 0x04, 0x0a, 0x4c, 0x2b, 0xf7, 0x2f, 0x15, 0x26, 0x0e,
		0xbd, 0x34, 0x72, 0xf9, 0x52, 0x5d, 0x22, 0xd9, 0x4b, 0x1b, 0x37, 0x2f, 0xf5, 0x25, 0x4d, 0x5f,
		0x3a, 0xb9, 0x76, 0xa9, 0x2e, 0x69, 0xea, 0xd2, 0xc9, 0x9d, 0x4b, 0x75, 0x89, 0x2c, 0x1e, 0xc9,
		0xf6, 0x54, 0x58, 0xae, 0xf9, 0x4b, 0x2f, 0xb7, 0x2d, 0x35, 0x26, 0x92, 0xf0, 0xb1, 0x5d, 0xb5,
		0x14, 0x95, 0x48, 0x51, 0x69, 0xe3, 0x9e, 0xa5, 0xbe, 0xa4, 0xe9, 0x4b, 0x0b, 0x97, 0x2c, 0x65,
		0x25, 0x4e, 0x56, 0x3a, 0xb9, 0x61, 0x29, 0x2f, 0x89, 0x59, 0x8b, 0x19, 0x8b, 0x92, 0x5a, 0x67,
		0x85, 0xa8, 0x91, 0xbb, 0x95, 0xea, 0x92, 0xa6, 0x2e, 0xbd, 0x5c, 0xac, 0xd4, 0x97, 0x34, 0x7d,
		0x69, 0xe6, 0x56, 0xa5, 0xc0, 0xa4, 0x09, 0x4c, 0x2f, 0x57, 0x2a, 0xf5, 0x25, 0x8f, 0xe8, 0x29,
		0x2b, 0xca, 0x6a, 0xed, 0xb2, 0xd2, 0xcc, 0x65, 0x4a, 0x81, 0x49, 0x13, 0x18, 0xcb, 0x45, 0xaa,
		0x6a, 0xfd, 0xaa, 0xd2, 0xc8, 0x35, 0x8a, 0xe9, 0x16, 0xc5, 0x73, 0x89, 0x62, 0xdd, 0x67, 0x9c,
		0x68, 0x31, 0x22, 0x05, 0x49, 0xe1, 0x86, 0x19, 0x86, 0xa3, 0xc4, 0x4b, 0xfc, 0x51, 0x68, 0xec,
		0x03, 0x25, 0x6f, 0x23, 0x1e, 0x7c, 0x54, 0x37, 0xde, 0xd8, 0x4b, 0x3e, 0x4e, 0xd3, 0x75, 0x7d,
		0x34, 0x56, 0xe1, 0x60, 0x14, 0x5e, 0xf9, 0xd7, 0xb5, 0x50, 0x25, 0x9f, 0x47, 0xd1, 0xa7, 0x9a,
		0x1f, 0xc6, 0x89, 0x17, 0x0e, 0x54, 0xfd, 0xdb, 0x37, 0xe2, 0xa5, 0x77, 0xea, 0xe3, 0x68, 0x94,
		0x8c, 0x06, 0xa3, 0x20, 0xce, 0xbe, 0xab, 0xfb, 0xb1, 0x1f, 0xd7, 0x03, 0x75, 0xab, 0x82, 0xf9,
		0x97, 0x7a, 0xe0, 0x87, 0x9f, 0x6a, 0x71, 0xe2, 0x25, 0xaa, 0x36, 0xf4, 0x12, 0xef, 0xd2, 0x8b,
		0x55, 0x3d, 0x88, 0xc7, 0xf5, 0x24, 0xb8, 0x8d, 0xa7, 0xbf, 0xd4, 0x6f, 0x92, 0xda, 0xf4, 0xa7,
		0x6a, 0xa1, 0xf2, 0xaf, 0x3f, 0x5e, 0x8e, 0xa2, 0x9a, 0x97, 0x24, 0x91, 0x7f, 0x39, 0x49, 0xa6,
		0x31, 0xa4, 0x6f, 0xc5, 0xd9, 0x77, 0xf5, 0x87, 0x70, 0xb2, 0x30, 0xe2, 0xc9, 0xe5, 0xec, 0x1f,
		0x4b, 0xbf, 0xd6, 0xbd, 0x5b, 0xcf, 0x0f, 0xbc, 0xcb, 0x40, 0xd5, 0x2e, 0xbd, 0x70, 0xf8, 0xd9,
		0x1f, 0x26, 0x1f, 0xeb, 0xb3, 0xff, 0x1f, 0x63, 0xf2, 0x91, 0x3f, 0x50, 0x65, 0x47, 0x28, 0x3c,
		0x85, 0xa0, 0xa5, 0x8e, 0xaa, 0xa6, 0x0c, 0x80, 0xb3, 0xfd, 0x8d, 0x38, 0x89, 0x26, 0x83, 0x24,
		0x9c, 0xc3, 0x77, 0x27, 0xbd, 0xd7, 0xf6, 0xfc, 0x1a, 0xdd, 0xee, 0xfc, 0x06, 0xbb, 0x76, 0xec,
		0xc7, 0x6e, 0x7b, 0x7a, 0x67, 0xdd, 0x76, 0x3c, 0x76, 0x9d, 0xe0, 0xd6, 0x3d, 0x49, 0xa6, 0x6f,
		0x76, 0xe6, 0x77, 0xc8, 0x5c, 0xdc, 0x3d, 0x77, 0xf1, 0x8e, 0x9b, 0xfd, 0x2b, 0xfd, 0xd9, 0x1d,
		0x72, 0xcd, 0xc5, 0x1d, 0x3a, 0xc8, 0x6e, 0xd0, 0x2f, 0xcc, 0x51, 0x9a, 0xe5, 0x27, 0x23, 0x53,
		0x7f, 0x6d, 0x30, 0x0a, 0xe3, 0x24, 0xf2, 0xfc, 0x30, 0x89, 0xc5, 0xa7, 0xa9, 0xac, 0xfc, 0x7c,
		0x3a, 0x7c, 0xe1, 0xf3, 0xc1, 0x3b, 0x3f, 0x1c, 0x1a, 0xfb, 0x1b, 0x5b, 0xc2, 0xc3, 0x3c, 0x9c,
		0xe5, 0x7c, 0x63, 0x7f, 0x63, 0x53, 0x78, 0xa0, 0xdd, 0x48, 0x5d, 0xf9, 0x5f, 0x30, 0xe6, 0xd6,
		0x85, 0x70, 0x47, 0x83, 0xd9, 0x7c, 0x86, 0x30, 0xe7, 0xf4, 0x47, 0x93, 0x68, 0xa0, 0x60, 0xaa,
		0x1e, 0xe3, 0x9d, 0xba, 0xfb, 0x3c, 0x8a, 0xa6, 0x23, 0xcc, 0x18, 0xa7, 0xca, 0x00, 0x29, 0x31,
		0xdf, 0x7a, 0xb1, 0x19, 0x5d, 0x4f, 0x6e, 0x54, 0x98, 0x18, 0xfb, 0x1b, 0x49, 0x34, 0x51, 0x28,
		0xb5, 0xf1, 0x43, 0xd4, 0x99, 0xb0, 0x59, 0xd3, 0x68, 0x5d, 0xd3, 0xb4, 0xfc, 0x08, 0x23, 0xe1,
		0x3e, 0x45, 0x08, 0x38, 0xb9, 0xec, 0x9f, 0x38, 0x07, 0x25, 0xad, 0x61, 0xe0, 0x0e, 0x1c, 0xf6,
		0x20, 0xe2, 0x0f, 0x30, 0x06, 0xa1, 0xe2, 0x10, 0x3c, 0x16, 0xc1, 0xe3, 0x11, 0x36, 0x26, 0x61,
		0xe0, 0x12, 0x08, 0x36, 0xc1, 0xe1, 0x53, 0x16, 0x30, 0x52, 0x77, 0x68, 0xe5, 0x6c, 0x83, 0xd3,
		0x23, 0x02, 0x87, 0x28, 0x58, 0x98, 0x42, 0x86, 0x2a, 0x0d, 0xe0, 0x0a, 0x1d, 0xb2, 0xb4, 0x81,
		0x2d, 0x6d, 0xa0, 0x4b, 0x0f, 0xf8, 0xc2, 0x82, 0x30, 0x30, 0x18, 0x83, 0x85, 0xb2, 0x27, 0xe0,
		0x0c, 0x37, 0x63, 0x2e, 0x33, 0x1a, 0x6a, 0xca, 0xc4, 0x44, 0x35, 0x78, 0x64, 0xd3, 0x01, 0xdd,
		0x34, 0x42, 0x38, 0x5d, 0x50, 0x4e, 0x3b, 0xa4, 0xd3, 0x0e, 0xed, 0xf4, 0x42, 0x3c, 0x4c, 0xd4,
		0x03, 0x45, 0x3e, 0x78, 0xf4, 0x7b, 0x02, 0x01, 0x6b, 0xfe, 0x10, 0x3f, 0xd9, 0x2e, 0xd3, 0xe0,
		0xf4, 0xb2, 0xc0, 0xf3, 0xd3, 0x1c, 0x0c, 0x37, 0xc1, 0x2f, 0x03, 0x1d, 0x10, 0x75, 0x02, 0x45,
		0x0d, 0x81, 0x51, 0x37, 0x70, 0xd4, 0x16, 0x20, 0xb5, 0x05, 0x49, 0x3d, 0x81, 0x12, 0x1b, 0x2c,
		0xc1, 0x01, 0x33, 0x93, 0x94, 0x73, 0x37, 0x56, 0x7a, 0xcd, 0x38, 0x81, 0xf2, 0xae, 0x22, 0x75,
		0xa5, 0xc3, 0x8c, 0xb3, 0xe8, 0xdc, 0xed, 0x6a, 0x70, 0x2d, 0xdd, 0xb9, 0x7d, 0xeb, 0xd5, 0xab,
		0xd4, 0x0a, 0x59, 0xff, 0x1a, 0xa5, 0x7f, 0x61, 0x0a, 0x63, 0xfa, 0xfa, 0x39, 0x45, 0xa5, 0x8e,
		0x5a, 0x6d, 0x4a, 0xcb, 0xf4, 0x72, 0xf4, 0x28, 0x29, 0xb7, 0x58, 0x52, 0xb2, 0xa4, 0x64, 0x49,
		0xc9, 0x92, 0x92, 0x25, 0x25, 0x4b, 0x4a, 0xf2, 0x58, 0xb5, 0x4a, 0x4a, 0xf4, 0x67, 0x17, 0xd9,
		0x85, 0x3c, 0xec, 0xc4, 0xa0, 0x4d, 0x82, 0x5e, 0xf2, 0x6f, 0xe9, 0x92, 0xa0, 0xf5, 0x78, 0x96,
		0xa1, 0x1d, 0x80, 0xea, 0x08, 0xa2, 0x1a, 0x03, 0xa9, 0xae, 0x60, 0xaa, 0x3d, 0xa0, 0x6a, 0x0f,
		0xaa, 0x7a, 0x03, 0xab, 0x1e, 0xe0, 0xaa, 0x09, 0xc0, 0x66, 0x52, 0xd3, 0xe6, 0xd9, 0xc8, 0xd2,
		0x8c, 0xe5, 0x2b, 0xa5, 0xae, 0x82, 0x91, 0x97, 0xbc, 0xde, 0xd6, 0x69, 0xd6, 0x9a, 0x43, 0xe0,
		0x9e, 0x46, 0x97, 0xd4, 0x56, 0xe1, 0xf5, 0xac, 0x00, 0xf9, 0xa0, 0x55, 0x1a, 0xd7, 0x0b, 0x2b,
		0x66, 0x9f, 0xd4, 0x89, 0x1f, 0x6a, 0xc7, 0x4b, 0x9a, 0x96, 0x57, 0x4b, 0x97, 0x77, 0xee, 0x05,
		0x93, 0x69, 0x62, 0x6c, 0x68, 0x7a, 0x7d, 0x47, 0x91, 0x37, 0x48, 0xfc, 0x51, 0xd8, 0xf2, 0xaf,
		0xfd, 0x99, 0x61, 0x7a, 0x53, 0xbb, 0xeb, 0xbc, 0xff, 0x5d, 0xc3, 0x94, 0xe2, 0x7d, 0x61, 0x4a,
		0x61, 0x4a, 0x61, 0x4a, 0x61, 0x35, 0xc6, 0xab, 0x79, 0x78, 0x5d, 0xfc, 0xc2, 0xcf, 0x83, 0x53,
		0xee, 0x7a, 0xd2, 0x98, 0x5e, 0x3e, 0x95, 0xa5, 0x42, 0x5f, 0x27, 0xbf, 0x8a, 0xa6, 0xe4, 0xc0,
		0x67, 0x3d, 0x48, 0x03, 0x8a, 0xcf, 0x7a, 0x70, 0xd2, 0x04, 0x9f, 0xf5, 0x80, 0x5f, 0x20, 0x9f,
		0xf5, 0x90, 0x01, 0x0b, 0x92, 0x9a, 0xbe, 0xcf, 0x7a, 0x26, 0x7e, 0xa8, 0xe7, 0x63, 0x9e, 0x5d,
		0x8d, 0x2e, 0xa9, 0xe7, 0x85, 0xd7, 0x8a, 0x4f, 0x79, 0xe4, 0x7f, 0x50, 0x7c, 0xca, 0x83, 0x7b,
		0x79, 0x8b, 0x96, 0xec, 0x26, 0x5b, 0xb2, 0xc4, 0x0d, 0x41, 0x29, 0x85, 0x4f, 0x79, 0xe0, 0x53,
		0x4a, 0x63, 0x7b, 0xaf, 0xb1, 0xd7, 0xdc, 0xdd, 0xde, 0xdb, 0x61, 0x6e, 0x61, 0x41, 0xc6, 0xab,
		0x59, 0xe7, 0x8b, 0x8f, 0x7b, 0x78, 0x05, 0x95, 0x27, 0x07, 0xd4, 0xf3, 0xbe, 0x57, 0x5e, 0x4f,
		0x15, 0x0e, 0xf5, 0x7d, 0xf2, 0x34, 0xd0, 0x27, 0xdf, 0xad, 0x3f, 0xfe, 0x0b, 0x8f, 0xde, 0x06,
		0x3a, 0x35, 0x5c, 0xbf, 0xb4, 0xc1, 0x2d, 0x2f, 0x0b, 0xad, 0x14, 0xd4, 0x9d, 0x2e, 0x4f, 0xac,
		0x8d, 0xb6, 0x1f, 0x27, 0x66, 0x92, 0x80, 0xef, 0xe1, 0x79, 0xe2, 0x87, 0x56, 0xa0, 0x6e, 0x54,
		0x7a, 0xc6, 0x0e, 0x70, 0x09, 0x37, 0x2d, 0xb1, 0x1f, 0x5d, 0xc9, 0xd6, 0x9b, 0x46, 0xa3, 0xb9,
		0xdb, 0x68, 0x6c, 0xee, 0xbe, 0xde, 0xdd, 0xdc, 0xdb, 0xd9, 0xd9, 0x6a, 0x6e, 0x01, 0x97, 0x6d,
		0xc6, 0x69, 0x34, 0x54, 0x91, 0x1a, 0x1e, 0x4c, 0x87, 0x4f, 0x38, 0x09, 0x02, 0x66, 0x2d, 0x62,
		0x19, 0x71, 0x2c, 0x0f, 0x1c, 0x33, 0xa0, 0x77, 0xcb, 0x8a, 0x26, 0x83, 0x24, 0x9c, 0x3f, 0x14,
		0xec, 0xa4, 0x9f, 0x98, 0x3d, 0xbf, 0x53, 0x6e, 0x77, 0xfe, 0x31, 0xb9, 0x76, 0xec, 0xc7, 0x6e,
		0x7b, 0xfa, 0xf9, 0xb8, 0xed, 0x78, 0xec, 0x3a, 0xc1, 0xad, 0x7b, 0x92, 0x4c, 0xdf, 0xec, 0xcc,
		0xef, 0xb3, 0xb9, 0xf8, 0x0c, 0xdc, 0xc5, 0x3b, 0x6e, 0xf6, 0xaf, 0xf4, 0x67, 0xf7, 0xd9, 0x3d,
		0x58, 0xdc, 0xd1, 0xc3, 0xec, 0xce, 0xb9, 0x0f, 0xdf, 0x62, 0xd2, 0xec, 0x3d, 0xcf, 0xe6, 0x61,
		0xfe, 0xd7, 0x27, 0xef, 0x33, 0xdf, 0xaf, 0xcc, 0xf7, 0x58, 0xf9, 0x09, 0x67, 0x94, 0x03, 0x8d,
		0x70, 0xe3, 0x66, 0x34, 0x54, 0x01, 0xe2, 0x82, 0xf0, 0x6c, 0xd5, 0x4f, 0x76, 0x05, 0x98, 0xe7,
		0x8a, 0x6e, 0xf2, 0x5c, 0xd1, 0x62, 0x02, 0xe7, 0xb9, 0xa2, 0xa5, 0x5e, 0x02, 0xcf, 0x15, 0x15,
		0x72, 0x21, 0x3c, 0x57, 0x94, 0x54, 0x53, 0x95, 0xda, 0x05, 0x76, 0xad, 0xb3, 0x06, 0x7b, 0xfc,
		0x23, 0xef, 0xe9, 0xbf, 0xbc, 0x87, 0x7f, 0x46, 0x99, 0xac, 0x99, 0x2a, 0x5f, 0x33, 0x61, 0x6e,
		0xc7, 0x0f, 0xbd, 0xfd, 0x3e, 0xe8, 0x76, 0xfb, 0xac, 0x96, 0x58, 0x2d, 0xb1, 0x5a, 0x62, 0xb5,
		0xc4, 0x6a, 0x89, 0xd5, 0x92, 0x7c, 0x89, 0xa0, 0x6e, 0x67, 0x8f, 0xdb, 0xc4, 0x5e, 0x9a, 0xb2,
		0x40, 0x9b, 0xd9, 0xdf, 0x62, 0x1a, 0xe8, 0x0a, 0x2a, 0xf8, 0x0d, 0x4a, 0x74, 0xd8, 0x90, 0x44,
		0xa3, 0x0d, 0x48, 0x74, 0xd9, 0x70, 0x44, 0xbb, 0x0d, 0x46, 0xb4, 0xdb, 0x50, 0x44, 0xaf, 0x0d,
		0x44, 0xb8, 0x1c, 0xbd, 0x48, 0xe9, 0xc0, 0x6f, 0x08, 0xf2, 0xd5, 0x06, 0x20, 0x6f, 0x90, 0xe7,
		0x8b, 0x39, 0x3e, 0x21, 0xaf, 0xd1, 0xd6, 0x63, 0x7f, 0x0f, 0x0d, 0x6c, 0x67, 0x3a, 0xed, 0xdf,
		0xa1, 0xdb, 0x46, 0x88, 0x9a, 0xed, 0xcf, 0xa1, 0xa3, 0x67, 0x5e, 0x87, 0x2d, 0x5f, 0x75, 0xda,
		0x6f, 0x43, 0xd7, 0x14, 0xb0, 0xbd, 0xb3, 0xc3, 0x24, 0xc0, 0x42, 0x84, 0xd1, 0x3f, 0x7e, 0x5d,
		0xd0, 0x39, 0xc3, 0x88, 0xd1, 0xa7, 0x64, 0x3a, 0x67, 0xf4, 0x72, 0xce, 0x00, 0xee, 0x50, 0x01,
		0xb4, 0xfe, 0xeb, 0x17, 0x66, 0xa0, 0x35, 0xb2, 0x72, 0xba, 0xc3, 0x04, 0xd8, 0xd3, 0x44, 0xcc,
		0xcd, 0x24, 0x70, 0x37, 0x8f, 0xd0, 0x6a, 0xb3, 0x08, 0xcc, 0xcd, 0x21, 0x50, 0x12, 0x0a, 0x28,
		0xca, 0x10, 0x61, 0xbe, 0x7a, 0xd7, 0x80, 0x5a, 0x64, 0x5d, 0xe6, 0x2e, 0x0e, 0x18, 0x98, 0x27,
		0x1f, 0x9a, 0x64, 0x47, 0x28, 0x3c, 0xfb, 0xa2, 0x65, 0xdd, 0xea, 0x66, 0x5b, 0xd9, 0xe9, 0x42,
		0xee, 0x20, 0x14, 0x3c, 0x00, 0x0d, 0xf5, 0x25, 0x51, 0xe1, 0x50, 0x0d, 0x6b, 0xde, 0xf0, 0xc6,
		0x0f, 0x6b, 0xd7, 0xd1, 0x68, 0x32, 0x16, 0x3f, 0x0c, 0xb3, 0xa5, 0x10, 0x4f, 0x46, 0x2f, 0x3c,
		0xdd, 0x61, 0x78, 0x7c, 0x60, 0x16, 0x89, 0x22, 0x2d, 0x06, 0x05, 0x5c, 0xf4, 0x89, 0xb6, 0xb8,
		0x13, 0x76, 0x11, 0x27, 0xec, 0x62, 0x4d, 0xcc, 0x45, 0x99, 0x44, 0xf6, 0x97, 0x7c, 0xe4, 0x28,
		0x1e, 0x1a, 0x30, 0x13, 0x33, 0xa4, 0x79, 0x19, 0xcc, 0xb4, 0x0c, 0xe7, 0x7e, 0x41, 0x74, 0xbb,
		0x00, 0xbb, 0x5b, 0x50, 0xdd, 0x2c, 0xf0, 0xee, 0x15, 0x78, 0xb7, 0x0a, 0xb6, 0x3b, 0x85, 0x8f,
		0xa6, 0xab, 0x08, 0x48, 0x59, 0xc0, 0x90, 0x7d, 0xa0, 0x95, 0xd3, 0x0e, 0x60, 0x5f, 0x68, 0x15,
		0x56, 0x71, 0xe7, 0x4c, 0x62, 0x96, 0xc6, 0xb8, 0x85, 0x8e, 0x5d, 0xda, 0xe0, 0x97, 0x36, 0x18,
		0xa6, 0x07, 0x8e, 0x61, 0x61, 0x19, 0x18, 0x9e, 0x65, 0x12, 0xc1, 0xdf, 0x39, 0x73, 0xe2, 0x87,
		0xc9, 0xeb, 0x6d, 0xe0, 0x8d, 0x33, 0x11, 0xf7, 0xcd, 0xc4, 0x76, 0xff, 0x62, 0x9f, 0x60, 0xa6,
		0xc1, 0x36, 0x23, 0x5a, 0x58, 0xfc, 0x74, 0x71, 0xf7, 0xea, 0x64, 0xe8, 0xbb, 0xc7, 0x3e, 0xd2,
		0x8f, 0x43, 0x5b, 0xd8, 0xd0, 0xd6, 0xe5, 0x14, 0x7c, 0xad, 0xc6, 0x38, 0x4d, 0xa3, 0x85, 0xbc,
		0x2e, 0x58, 0x78, 0xe5, 0x38, 0x20, 0xa1, 0x0f, 0xd4, 0xc5, 0x3f, 0x48, 0x57, 0xcb, 0x03, 0x74,
		0xb1, 0x0f, 0xce, 0xa5, 0x89, 0xb5, 0x92, 0x19, 0x91, 0x9e, 0x33, 0xc1, 0x2e, 0x88, 0xa7, 0x1e,
		0x23, 0x22, 0x19, 0xe4, 0xe9, 0x9c, 0xd2, 0x3a, 0x87, 0xd0, 0x39, 0x05, 0x92, 0x33, 0x10, 0xd6,
		0xf9, 0x17, 0xe8, 0x44, 0xb5, 0xe6, 0xb7, 0xc8, 0x9c, 0xde, 0xa1, 0xe3, 0xd9, 0x0d, 0xa2, 0xb3,
		0x4c, 0xb7, 0x04, 0x65, 0xf8, 0xe3, 0xdb, 0x46, 0xcd, 0x0f, 0x13, 0x15, 0x5d, 0x79, 0x03, 0x55,
		0xf3, 0x86, 0xc3, 0x48, 0xc5, 0x31, 0x8e, 0xb7, 0x6c, 0x45, 0xfc, 0x74, 0x97, 0xad, 0x23, 0x4c,
		0xba, 0xcb, 0x72, 0x54, 0x2e, 0xdd, 0x65, 0xf9, 0x0d, 0x2f, 0xba, 0xcb, 0x8a, 0x66, 0x5c, 0xba,
		0xcb, 0xaa, 0x56, 0xd6, 0xd0, 0x5d, 0x96, 0xef, 0xfc, 0x40, 0x77, 0x19, 0xc1, 0x06, 0x11, 0x70,
		0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40,
		0xc0, 0x08, 0x0e, 0x90, 0xb2, 0x80, 0x51, 0x9a, 0x3f, 0x2b, 0x67, 0x1a, 0x8c, 0xee, 0xcf, 0x2a,
		0x78, 0xa2, 0x87, 0x8c, 0x30, 0xa5, 0x31, 0x54, 0xa1, 0xc3, 0x95, 0x36, 0x90, 0xa5, 0x0d, 0x6c,
		0xe9, 0x01, 0x5d, 0x58, 0xf0, 0x05, 0x06, 0x61, 0x99, 0x44, 0xf0, 0x3d, 0x64, 0xb3, 0x27, 0x5d,
		0x98, 0x84, 0xf3, 0x98, 0x72, 0xb6, 0xde, 0x00, 0xc6, 0xde, 0xf5, 0x92, 0x44, 0x45, 0x21, 0xac,
		0x99, 0xcc, 0xf8, 0xdf, 0xaf, 0xbf, 0x7e, 0xd8, 0xac, 0xed, 0x5d, 0xfc, 0xfd, 0x61, 0xab, 0xb6,
		0x77, 0x91, 0x7e, 0xbb, 0x35, 0xfb, 0x92, 0x7e, 0xbf, 0xfd, 0x61, 0xb3, 0xd6, 0x58, 0x7c, 0xbf,
		0xf3, 0x61, 0xb3, 0xb6, 0x73, 0xf1, 0xdb, 0x9f, 0x7f, 0xbe, 0xfa, 0xed, 0xaf, 0xd7, 0xf7, 0x3f,
		0xff, 0x83, 0xff, 0xc2, 0x4b, 0xbe, 0x17, 0x88, 0xa2, 0x3c, 0xed, 0xdb, 0xef, 0xa9, 0x4c, 0xdd,
		0x95, 0x49, 0x2c, 0xc8, 0x51, 0x7d, 0x74, 0x38, 0x94, 0x7c, 0x05, 0x74, 0x38, 0xb0, 0x0c, 0xd1,
		0x3a, 0x52, 0x3a, 0x1c, 0xf2, 0x8d, 0xbb, 0x0a, 0xab, 0x95, 0x9f, 0x5e, 0xe4, 0x48, 0x8f, 0x43,
		0x75, 0x22, 0xa4, 0xc7, 0x81, 0x59, 0x63, 0x3d, 0x59, 0x83, 0x2e, 0x87, 0xaf, 0x5c, 0x0e, 0xf6,
		0xf8, 0xb6, 0x61, 0x2f, 0xee, 0x91, 0x39, 0xbf, 0x45, 0xf4, 0x39, 0xe8, 0x96, 0xa4, 0xd2, 0xee,
		0xe9, 0xc3, 0xc8, 0x82, 0xb4, 0x39, 0x2c, 0x85, 0x4f, 0x97, 0xc3, 0x3a, 0xc2, 0xa4, 0xcb, 0x21,
		0x47, 0xe1, 0xd2, 0xe5, 0x90, 0xdf, 0xf0, 0xa2, 0xcb, 0xa1, 0x68, 0xca, 0xa5, 0xcb, 0xa1, 0x6a,
		0x85, 0x0d, 0x5d, 0x0e, 0xf9, 0xce, 0x0f, 0x74, 0x39, 0x10, 0x6c, 0x10, 0x01, 0x07, 0x18, 0x74,
		0x50, 0x81, 0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08, 0x1b, 0x84, 0x30, 0x80, 0x08, 0x04, 0x8c, 0xe0,
		0x00, 0x29, 0x0b, 0x98, 0x2e, 0x87, 0x52, 0xe1, 0x89, 0x2e, 0x07, 0xc2, 0x94, 0xc6, 0x50, 0x85,
		0x0e, 0x57, 0xda, 0x40, 0x96, 0x36, 0xb0, 0xa5, 0x07, 0x74, 0x61, 0xc1, 0x17, 0x18, 0x84, 0x65,
		0x12, 0xa1, 0xcb, 0x41, 0x08, 0xe5, 0xd0, 0xe5, 0x50, 0xc6, 0x05, 0x70, 0x2d, 0xf9, 0x3f, 0xbf,
		0xe8, 0x72, 0xa0, 0x32, 0x85, 0x2a, 0x93, 0x58, 0x90, 0xa3, 0xfa, 0xe8, 0x72, 0x28, 0xf9, 0x0a,
		0xe8, 0x72, 0x60, 0x19, 0xa2, 0x75, 0xa4, 0x74, 0x39, 0xe4, 0x1b, 0x77, 0x65, 0xd6, 0x2b, 0x7f,
		0xbb, 0xc6, 0x91, 0x26, 0x87, 0xea, 0x44, 0x48, 0x93, 0x03, 0x93, 0xc6, 0x5a, 0x92, 0x06, 0x3d,
		0x0e, 0x4b, 0x1e, 0x87, 0xec, 0xaf, 0xd3, 0xe2, 0xa0, 0x69, 0x8a, 0x32, 0xfc, 0xf1, 0x6d, 0x13,
		0xfc, 0x28, 0x87, 0x26, 0x8f, 0x72, 0xc8, 0x29, 0x4c, 0x9a, 0x1c, 0x72, 0x54, 0x2e, 0x4d, 0x0e,
		0xf9, 0x0d, 0x2f, 0x9a, 0x1c, 0x8a, 0xa6, 0x5c, 0x9a, 0x1c, 0xaa, 0x56, 0xd8, 0xd0, 0xe4, 0x90,
		0xef, 0xfc, 0x40, 0x93, 0x03, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1,
		0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0xb2, 0x80, 0x69,
		0x72, 0x28, 0x15, 0x9e, 0x68, 0x72, 0x20, 0x4c, 0x69, 0x0c, 0x55, 0xe8, 0x70, 0xa5, 0x0d, 0x64,
		0x69, 0x03, 0x5b, 0x7a, 0x40, 0x17, 0x16, 0x7c, 0x81, 0x41, 0x58, 0x26, 0x11, 0x2d, 0x4c, 0x0e,
		0x4d, 0x9a, 0x1c, 0x4a, 0x22, 0x06, 0x4d, 0x96, 0x92, 0x7b, 0xb5, 0x2b, 0xb3, 0x76, 0x74, 0xf1,
		0xd7, 0xd6, 0xef, 0x8d, 0xfb, 0xfd, 0xdf, 0xfe, 0xda, 0xbd, 0xff, 0xf6, 0xcd, 0xbf, 0x9f, 0xfa,
		0x6b, 0x5b, 0xbf, 0xef, 0xde, 0xef, 0xaf, 0xf8, 0x93, 0xe6, 0xfd, 0xfe, 0x0f, 0xfe, 0x1b, 0x3b,
		0xf7, 0xbf, 0x2e, 0xfd, 0xd5, 0xe9, 0xfb, 0xdb, 0xab, 0x7e, 0xa0, 0xb1, 0xe2, 0x07, 0x5e, 0xaf,
		0xfa, 0x81, 0xd7, 0x2b, 0x7e, 0x60, 0x65, 0x48, 0xdb, 0x2b, 0x7e, 0x60, 0xe7, 0xfe, 0xef, 0xa5,
		0xbf, 0xff, 0xeb, 0xd3, 0x7f, 0xb5, 0x79, 0xff, 0xdb, 0xdf, 0xab, 0xfe, 0x6c, 0xf7, 0xfe, 0xef,
		0xfd, 0xdf, 0x68, 0xf9, 0x28, 0x68, 0x88, 0xea, 0x64, 0xf9, 0xe0, 0x38, 0xe5, 0x38, 0xfd, 0x91,
		0x71, 0x4a, 0x64, 0xcc, 0x71, 0x2c, 0xd2, 0x00, 0x53, 0xf2, 0x15, 0xd0, 0x00, 0xc3, 0x12, 0x55,
		0xeb, 0x48, 0x69, 0x80, 0xc9, 0x37, 0xee, 0x8a, 0xac, 0x65, 0x6f, 0xf2, 0x98, 0x8f, 0x2a, 0x47,
		0x48, 0x07, 0x0c, 0xb3, 0xc6, 0x7a, 0xb2, 0x06, 0x2d, 0x30, 0xdf, 0x5a, 0x60, 0x9a, 0x3c, 0xe6,
		0x43, 0xfb, 0x24, 0x95, 0x76, 0xd6, 0xa1, 0x8f, 0xf9, 0x68, 0xf2, 0x98, 0x8f, 0x7c, 0xc2, 0xa4,
		0x03, 0x26, 0x47, 0xe1, 0xd2, 0x01, 0x93, 0xdf, 0xf0, 0xa2, 0x03, 0xa6, 0x68, 0xca, 0xa5, 0x03,
		0xa6, 0x6a, 0x85, 0x0d, 0x1d, 0x30, 0xf9, 0xce, 0x0f, 0x74, 0xc0, 0x10, 0x6c, 0x10, 0x01, 0x07,
		0x18, 0x74, 0x50, 0x81, 0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08, 0x1b, 0x84, 0x30, 0x80, 0x08, 0x04,
		0x8c, 0xe0, 0x00, 0x29, 0x0b, 0x98, 0x0e, 0x98, 0x52, 0xe1, 0x89, 0x0e, 0x18, 0xc2, 0x94, 0xc6,
		0x50, 0x85, 0x0e, 0x57, 0xda, 0x40, 0x96, 0x36, 0xb0, 0xa5, 0x07, 0x74, 0x61, 0xc1, 0x17, 0x18,
		0x84, 0x65, 0x12, 0xa1, 0x03, 0x46, 0x08, 0xe5, 0xd0, 0x01, 0x53, 0xc6, 0x05, 0x70, 0x65, 0x3d,
		0x57, 0xd6, 0xff, 0xf8, 0x8b, 0x0e, 0x18, 0x8e, 0x53, 0x8e, 0x53, 0x80, 0x71, 0x4a, 0x64, 0xcc,
		0x71, 0x2c, 0xd2, 0x01, 0x53, 0xf2, 0x15, 0xd0, 0x01, 0xc3, 0x12, 0x55, 0xeb, 0x48, 0xe9, 0x80,
		0xc9, 0x37, 0xee, 0xca, 0xac, 0x65, 0xe7, 0x11, 0x30, 0xd5, 0x8d, 0x90, 0x06, 0x18, 0x26, 0x8d,
		0xb5, 0x24, 0x0d, 0xfa, 0x5f, 0x96, 0xfc, 0x2f, 0x3c, 0x02, 0x46, 0xf7, 0x14, 0x65, 0x04, 0x5e,
		0x58, 0xf3, 0x86, 0xff, 0xe7, 0x0d, 0x54, 0x38, 0xb8, 0xab, 0xc5, 0xfe, 0x10, 0xc8, 0xfb, 0xf2,
		0x44, 0xec, 0x34, 0xbe, 0xac, 0x23, 0x4c, 0x1a, 0x5f, 0x72, 0x54, 0x2d, 0x8d, 0x2f, 0xf9, 0x0d,
		0x2f, 0x1a, 0x5f, 0x8a, 0xa6, 0x5b, 0x1a, 0x5f, 0xaa, 0x56, 0xd0, 0xc0, 0x18, 0x5f, 0x96, 0xf0,
		0x00, 0xcf, 0x04, 0xb3, 0x7c, 0x09, 0x34, 0xc4, 0x54, 0x19, 0x78, 0x10, 0xc1, 0x07, 0x18, 0x80,
		0x50, 0x41, 0x08, 0x1e, 0x88, 0xe0, 0xc1, 0x08, 0x1b, 0x90, 0x30, 0x40, 0x09, 0x04, 0x98, 0xe0,
		0xc0, 0x29, 0x0b, 0x18, 0xcb, 0x39, 0xbc, 0x34, 0xcf, 0x20, 0x39, 0x88, 0x41, 0xc1, 0x09, 0x16,
		0xa0, 0x90, 0x41, 0x4a, 0x03, 0xa0, 0x42, 0x07, 0x2b, 0x6d, 0x00, 0x4b, 0x1b, 0xd0, 0xd2, 0x03,
		0xb8, 0xb0, 0xc0, 0x0b, 0x0c, 0xc0, 0x60, 0x41, 0x2c, 0x0b, 0xfc, 0x2a, 0xf0, 0xae, 0x63, 0xdc,
		0x64, 0xb9, 0x98, 0xaf, 0xd2, 0xcb, 0x00, 0xcd, 0x2f, 0x98, 0x6e, 0x65, 0x78, 0x50, 0xd3, 0x01,
		0xd8, 0x34, 0x02, 0x37, 0x5d, 0x00, 0x4e, 0x3b, 0x90, 0xd3, 0x0e, 0xe8, 0xf4, 0x02, 0x3b, 0x4c,
		0xc0, 0x03, 0x05, 0xbd, 0x4c, 0x3a, 0xb0, 0xee, 0xe7, 0xa5, 0x19, 0x43, 0x85, 0x93, 0x1b, 0x15,
		0xa5, 0xcb, 0x49, 0x81, 0x67, 0x8d, 0x45, 0x97, 0xab, 0x01, 0x7c, 0x0d, 0x56, 0x38, 0xb9, 0x99,
		0x8a, 0x8a, 0x43, 0xb9, 0xc8, 0xbb, 0x0e, 0xed, 0x4a, 0xcb, 0xae, 0x02, 0xde, 0x9d, 0xf6, 0x70,
		0x25, 0x1a, 0xba, 0xd4, 0xb2, 0x8b, 0x83, 0x76, 0xab, 0xe1, 0xa2, 0x06, 0x60, 0x6e, 0x32, 0x32,
		0x37, 0x01, 0xd0, 0x32, 0xa3, 0x95, 0x94, 0xf1, 0xf8, 0x62, 0xd8, 0xa6, 0x29, 0x23, 0x7c, 0xb6,
		0x69, 0x04, 0x0d, 0x07, 0xb6, 0x69, 0xe4, 0x0c, 0x6b, 0xb6, 0x69, 0x84, 0x5f, 0x10, 0xdb, 0x34,
		0xe4, 0xa7, 0x67, 0x4a, 0x47, 0x9f, 0x36, 0x4d, 0x7c, 0x17, 0x27, 0xea, 0x06, 0x17, 0x9f, 0x36,
		0xc0, 0x77, 0xac, 0x7b, 0xc0, 0x10, 0xf0, 0x1d, 0xb1, 0xb2, 0x0b, 0xf9, 0xdf, 0x87, 0xcd, 0xda,
		0x9e, 0x59, 0x3b, 0xf2, 0x6a, 0x57, 0x17, 0x7f, 0x35, 0xee, 0xff, 0xfc, 0xf3, 0xd5, 0x77, 0xde,
		0xf8, 0x17, 0x6e, 0xd6, 0xbd, 0x40, 0x16, 0x9c, 0x0e, 0xfb, 0xb0, 0x55, 0x53, 0x75, 0xec, 0xee,
		0x90, 0x4e, 0x56, 0x8c, 0x83, 0x5b, 0x2f, 0x98, 0x28, 0xfc, 0xbe, 0x4e, 0x7a, 0x19, 0xec, 0xe8,
		0x94, 0x11, 0x3e, 0x3b, 0x3a, 0x82, 0x06, 0x02, 0x3b, 0x3a, 0x72, 0x86, 0x35, 0x3b, 0x3a, 0xc2,
		0x2f, 0x88, 0x1d, 0x1d, 0x32, 0xd3, 0x33, 0xa5, 0xa3, 0x4f, 0x47, 0x67, 0xe2, 0x87, 0xc9, 0xeb,
		0x6d, 0x0d, 0xda, 0x39, 0xbb, 0xc0, 0x97, 0xd0, 0xf3, 0xc2, 0x6b, 0x05, 0x5f, 0x55, 0x63, 0x4f,
		0xd8, 0x1b, 0xf3, 0xf5, 0x2b, 0xf0, 0xe4, 0xa1, 0x49, 0x61, 0xb1, 0x74, 0x39, 0xe7, 0xf3, 0x5a,
		0x55, 0x97, 0xeb, 0x39, 0x8a, 0xbc, 0x41, 0xe2, 0x8f, 0xc2, 0x96, 0x7f, 0xed, 0xa7, 0xcb, 0xa5,
		0xe0, 0xaf, 0xeb, 0xfe, 0x77, 0x0d, 0x52, 0x80, 0xf7, 0x85, 0x29, 0x40, 0x78, 0x0a, 0x68, 0x6c,
		0xef, 0x35, 0xf6, 0x9a, 0xbb, 0xdb, 0x7b, 0x3b, 0xcc, 0x05, 0x2c, 0x48, 0x18, 0xfd, 0xe3, 0x17,
		0xdb, 0xfd, 0x9c, 0xeb, 0x56, 0xa5, 0x99, 0xcf, 0xca, 0xbf, 0xfe, 0x98, 0xe0, 0xf7, 0xfb, 0xe7,
		0xd7, 0xc1, 0x86, 0x7f, 0x19, 0xe1, 0xb3, 0xe1, 0x2f, 0x68, 0x24, 0xb0, 0xe1, 0x2f, 0x67, 0x58,
		0xb3, 0xe1, 0x2f, 0xfc, 0x82, 0xd8, 0xf0, 0x27, 0x35, 0x3d, 0x53, 0x3a, 0x7a, 0x35, 0xfc, 0xdf,
		0x68, 0xd0, 0xef, 0xdf, 0x61, 0xbf, 0xbf, 0xe4, 0x17, 0xfb, 0xfd, 0xac, 0x2b, 0x72, 0xbc, 0x1c,
		0xf6, 0xfb, 0x39, 0x9b, 0x17, 0x91, 0x02, 0xd8, 0xef, 0x17, 0x9f, 0x02, 0xb6, 0x77, 0xd8, 0xe8,
		0x67, 0x21, 0xc2, 0xe8, 0xbf, 0x7a, 0xb1, 0xd1, 0xcf, 0x88, 0xe1, 0xa7, 0x64, 0xd4, 0x33, 0x88,
		0xb3, 0xf8, 0xab, 0x70, 0xac, 0xe8, 0xf2, 0x79, 0x84, 0xcb, 0x6f, 0x21, 0x1d, 0x4d, 0x8c, 0x37,
		0xb2, 0x81, 0x46, 0x35, 0xa8, 0xa7, 0x08, 0xda, 0x4b, 0x04, 0xca, 0xfd, 0x3c, 0x5d, 0xa1, 0x4c,
		0xa1, 0xf3, 0x74, 0x85, 0xf2, 0x86, 0x2b, 0x4f, 0x57, 0x90, 0x86, 0xa1, 0x3c, 0x5d, 0x81, 0x4c,
		0xf3, 0xcf, 0x12, 0x81, 0x7d, 0x04, 0xf8, 0x70, 0xea, 0xa6, 0xf2, 0xae, 0x22, 0x75, 0x85, 0x98,
		0xf1, 0x17, 0x7b, 0xb6, 0x00, 0xba, 0x7c, 0x8c, 0xee, 0xbc, 0x38, 0x7c, 0xf5, 0x2a, 0x2d, 0x92,
		0xea, 0x29, 0x62, 0xb2, 0x54, 0xaa, 0x70, 0xa4, 0x28, 0x67, 0xfb, 0xbd, 0x53, 0x77, 0x68, 0x45,
		0x11, 0xe6, 0x56, 0xca, 0xb8, 0x5b, 0x27, 0x6b, 0xb5, 0x55, 0x32, 0xe6, 0xd6, 0xc8, 0x28, 0xd9,
		0x04, 0xb4, 0xd9, 0xcb, 0x26, 0x2f, 0xd6, 0x29, 0xed, 0xe9, 0x67, 0x96, 0x44, 0x93, 0x41, 0x12,
		0xce, 0xd1, 0xb7, 0x93, 0x7e, 0x08, 0xf6, 0xfc, 0xe2, 0xdd, 0xee, 0xfc, 0xce, 0xbb, 0x76, 0xec,
		0xc7, 0x6e, 0x7b, 0x7a, 0xcb, 0xdd, 0x76, 0x3c, 0x76, 0x9d, 0xe0, 0xd6, 0x3d, 0x49, 0xa6, 0x6f,
		0x76, 0xe6, 0xb7, 0xce, 0x5c, 0xdc, 0x56, 0x77, 0xf1, 0x8e, 0x9b, 0xfd, 0x2b, 0xfd, 0xd9, 0xad,
		0x73, 0xdb, 0x5e, 0x68, 0x2e, 0x6e, 0x53, 0xdf, 0x1f, 0x62, 0x90, 0x9d, 0x7c, 0x4e, 0x92, 0x1d,
		0xa1, 0xf0, 0x9c, 0x8b, 0x96, 0x6b, 0x2b, 0x9a, 0x63, 0x65, 0xe7, 0x0a, 0xb9, 0x23, 0x50, 0xf0,
		0xe8, 0x33, 0x66, 0xb2, 0xca, 0x94, 0x22, 0xff, 0x5c, 0xcb, 0x87, 0xfe, 0xd0, 0x37, 0x81, 0x0b,
		0xcf, 0x70, 0x18, 0x47, 0x8a, 0xc3, 0x3c, 0xe4, 0x42, 0x7a, 0xa8, 0x05, 0xf8, 0x10, 0x0b, 0xed,
		0xa1, 0x15, 0xec, 0x43, 0x2a, 0xd8, 0x87, 0x52, 0x98, 0x0f, 0xa1, 0x48, 0xe9, 0x2f, 0xf9, 0xc8,
		0x51, 0x8e, 0xec, 0x36, 0xd2, 0xe5, 0x5d, 0x30, 0xc9, 0x2b, 0x3b, 0xb0, 0x60, 0x16, 0x36, 0x4a,
		0xb3, 0x1d, 0x02, 0x68, 0xe0, 0xc0, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1,
		0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0xb2, 0x80, 0x83,
		0xd1, 0xc0, 0x0b, 0x6a, 0xe3, 0x68, 0x94, 0xa8, 0x01, 0xa4, 0xad, 0xe1, 0xa1, 0x1d, 0xf4, 0xed,
		0x95, 0x70, 0x51, 0x34, 0xb1, 0x4a, 0x2f, 0xbc, 0xd2, 0x00, 0xb3, 0xd0, 0x71, 0x4b, 0x1b, 0xec,
		0xd2, 0x06, 0xbf, 0xf4, 0xc0, 0x30, 0x2c, 0x1c, 0x03, 0xc3, 0xb2, 0x4c, 0x22, 0xf8, 0x8b, 0xa2,
		0x55, 0x38, 0xb9, 0x51, 0x91, 0x07, 0x08, 0x38, 0x8f, 0x21, 0x67, 0xab, 0x01, 0x18, 0xbb, 0x15,
		0x4e, 0x6e, 0xa6, 0xe2, 0xe1, 0x10, 0xcd, 0xf3, 0x2e, 0x43, 0x2e, 0x87, 0xcd, 0xa2, 0x87, 0x5d,
		0x16, 0xfb, 0x70, 0x05, 0x1a, 0x2d, 0x8f, 0xcd, 0x2e, 0x0a, 0x72, 0x99, 0x2c, 0x1e, 0x12, 0xb0,
		0x97, 0xb4, 0x56, 0x9e, 0xe5, 0xf2, 0x63, 0xb9, 0x4b, 0xe3, 0xbe, 0x5e, 0x7b, 0x84, 0xb4, 0x9d,
		0x04, 0x57, 0xd2, 0x6a, 0x9d, 0x3e, 0xb8, 0x92, 0x56, 0x7e, 0xba, 0x40, 0x58, 0xff, 0x55, 0xa4,
		0x21, 0xc1, 0x0f, 0x3f, 0x99, 0x0f, 0x37, 0x87, 0x6b, 0x8c, 0x75, 0xcb, 0x4b, 0xe9, 0x52, 0xdd,
		0xa1, 0x0a, 0xbc, 0x3b, 0xb0, 0xe5, 0xc5, 0x69, 0xcc, 0x5c, 0x59, 0xbc, 0x8e, 0x30, 0xb9, 0xb2,
		0x38, 0x47, 0xb5, 0x72, 0x65, 0x71, 0x7e, 0xc3, 0x8b, 0x2b, 0x8b, 0x8b, 0x46, 0x58, 0xae, 0x2c,
		0xae, 0x5a, 0xd5, 0xc2, 0x95, 0xc5, 0xf9, 0xce, 0x0f, 0x5c, 0x59, 0x4c, 0xb0, 0x41, 0x04, 0x1c,
		0x60, 0xd0, 0x41, 0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07, 0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10,
		0x30, 0x82, 0x03, 0xa4, 0x2c, 0x60, 0xaf, 0x76, 0xe9, 0x27, 0xb8, 0xcb, 0x89, 0xd3, 0xf0, 0xb9,
		0x86, 0x98, 0x00, 0xa5, 0x17, 0x48, 0x69, 0x00, 0x54, 0xe8, 0x60, 0xa5, 0x0d, 0x60, 0x69, 0x03,
		0x5a, 0x7a, 0x00, 0x17, 0x16, 0x78, 0x81, 0x01, 0x58, 0x26, 0x11, 0xfc, 0x35, 0xc4, 0x97, 0xa3,
		0x51, 0xa0, 0x3c, 0xe8, 0xf5, 0xc3, 0x5b, 0x5c, 0xc1, 0x57, 0xf5, 0xc1, 0x68, 0x60, 0x3c, 0x4f,
		0x5e, 0x39, 0x0a, 0x11, 0x1e, 0x2d, 0xb3, 0xc0, 0x60, 0x81, 0xc1, 0x02, 0x83, 0x05, 0x06, 0x0b,
		0x0c, 0x16, 0x18, 0x2c, 0x30, 0x58, 0x60, 0xfc, 0x60, 0xc6, 0x9f, 0xf8, 0x61, 0xf2, 0x7a, 0x1b,
		0xb8, 0xbe, 0x40, 0x3c, 0xb7, 0xa5, 0xe7, 0x85, 0xd7, 0xd3, 0xbb, 0xff, 0x01, 0x32, 0x31, 0xe2,
		0x9e, 0x68, 0x6e, 0x9c, 0xf8, 0x21, 0xfc, 0x91, 0xec, 0x9a, 0x1c, 0xc5, 0x9e, 0x1d, 0xc1, 0x8e,
		0x7e, 0x1d, 0x1a, 0x1d, 0xbc, 0x7e, 0xff, 0x3b, 0xf0, 0xd0, 0xf6, 0xbe, 0x70, 0x68, 0x0b, 0x1b,
		0xda, 0x8d, 0xed, 0xbd, 0xc6, 0x5e, 0x73, 0x77, 0x7b, 0x6f, 0x87, 0x63, 0x9c, 0x05, 0x41, 0xb5,
		0xa2, 0xbe, 0x60, 0xdb, 0xbb, 0xc2, 0x91, 0xd2, 0xb8, 0x9e, 0x6f, 0xdc, 0x95, 0x71, 0xa2, 0xce,
		0x1e, 0x3d, 0xd0, 0xb3, 0x5e, 0x9d, 0x08, 0xe9, 0x59, 0x67, 0xa6, 0x78, 0x7e, 0xa6, 0xa0, 0x5d,
		0x7d, 0xc9, 0xae, 0xde, 0x9a, 0xdd, 0x17, 0x3a, 0xd5, 0x75, 0xcb, 0x46, 0x8f, 0x5c, 0xdf, 0xb5,
		0x5b, 0x2f, 0xf2, 0x31, 0x72, 0xd2, 0x13, 0x9e, 0xf5, 0x47, 0xd1, 0xd3, 0xbd, 0xbe, 0x8e, 0x30,
		0xe9, 0x5e, 0xcf, 0x51, 0xb7, 0x74, 0xaf, 0xe7, 0x37, 0xbc, 0xe8, 0x5e, 0x2f, 0x1a, 0x66, 0xe9,
		0x5e, 0xaf, 0x5a, 0xfd, 0x42, 0xf7, 0x7a, 0xbe, 0xf3, 0x03, 0xdd, 0xeb, 0x04, 0x1b, 0x44, 0xc0,
		0x01, 0x06, 0x1d, 0x54, 0xe0, 0x81, 0x07, 0x1f, 0x78, 0x00, 0xc2, 0x06, 0x21, 0x0c, 0x20, 0x02,
		0x01, 0x23, 0x38, 0x40, 0xca, 0x02, 0xa6, 0xb9, 0xa4, 0x34, 0x70, 0xa2, 0xb9, 0x84, 0x20, 0xa5,
		0x31, 0x50, 0xa1, 0x83, 0x95, 0x36, 0x80, 0xa5, 0x0d, 0x68, 0xe9, 0x01, 0x5c, 0x58, 0xe0, 0x05,
		0x06, 0x60, 0x99, 0x44, 0x68, 0x2e, 0x29, 0x9d, 0x6f, 0x68, 0x2e, 0x29, 0xfa, 0x45, 0x73, 0x09,
		0xc1, 0x7e, 0x0d, 0x97, 0x41, 0x73, 0x09, 0xa7, 0xdf, 0x75, 0x0e, 0x6d, 0x9a, 0x4b, 0xc4, 0x0d,
		0x6d, 0x9a, 0x4b, 0x58, 0x10, 0x54, 0x35, 0x6a, 0x9a, 0x4b, 0xaa, 0x1c, 0x29, 0xcd, 0x25, 0xf9,
		0xc6, 0x5d, 0xad, 0x25, 0xe3, 0x0f, 0xcb, 0x4f, 0x69, 0x33, 0xa9, 0x4e, 0x84, 0xb4, 0x99, 0x30,
		0x67, 0xac, 0x23, 0x67, 0xd0, 0x70, 0xf2, 0xb4, 0xe1, 0xe4, 0x3c, 0xbb, 0x41, 0x74, 0x9e, 0xe8,
		0x96, 0xa0, 0x52, 0xef, 0x86, 0x3f, 0x04, 0x33, 0x9b, 0xf8, 0x43, 0xfa, 0x4b, 0xd6, 0x12, 0x26,
		0xfd, 0x25, 0x39, 0x4a, 0x95, 0xfe, 0x92, 0xfc, 0x86, 0x17, 0xfd, 0x25, 0x45, 0x53, 0x2c, 0xfd,
		0x25, 0x55, 0x2b, 0x5c, 0xe8, 0x2f, 0xc9, 0x77, 0x7e, 0xa0, 0xbf, 0x84, 0x60, 0x83, 0x08, 0x38,
		0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8, 0x20, 0x84, 0x01, 0x44, 0x20,
		0x60, 0x04, 0x07, 0x48, 0x59, 0xc0, 0xc1, 0x68, 0xe0, 0x05, 0xb8, 0xfe, 0x92, 0x34, 0x7c, 0xfa,
		0x4b, 0x08, 0x50, 0x7a, 0x81, 0x94, 0x06, 0x40, 0x85, 0x0e, 0x56, 0xda, 0x00, 0x96, 0x36, 0xa0,
		0xa5, 0x07, 0x70, 0x61, 0x81, 0x17, 0x18, 0x80, 0x65, 0x12, 0xa1, 0xbf, 0xa4, 0x74, 0xbe, 0xa1,
		0xbf, 0xa4, 0xe8, 0x17, 0xfd, 0x25, 0x04, 0xfb, 0x35, 0x5c, 0x06, 0xfd, 0x25, 0x9c, 0x7e, 0xd7,
		0x39, 0xb4, 0xe9, 0x2f, 0x11, 0x37, 0xb4, 0xe9, 0x2f, 0x61, 0x41, 0x50, 0xd5, 0xa8, 0xe9, 0x2f,
		0xa9, 0xfc, 0x1c, 0x65, 0x44, 0xea, 0x66, 0x94, 0x28, 0xdc, 0xbe, 0xf7, 0x3c, 0x7e, 0x36, 0xbe,
		0x8b, 0x08, 0x9b, 0x8d, 0xef, 0x12, 0x95, 0xce, 0xc6, 0x77, 0x79, 0xc3, 0x95, 0x8d, 0x6f, 0x61,
		0x17, 0xc2, 0xc6, 0x37, 0xa9, 0xe6, 0x3b, 0x12, 0x61, 0xe3, 0xbb, 0x74, 0xbe, 0x61, 0xe3, 0xbb,
		0xe8, 0x17, 0x1b, 0xdf, 0x04, 0xfb, 0x35, 0x5c, 0x06, 0x1b, 0xdf, 0x9c, 0x7e, 0xd7, 0x39, 0xb4,
		0xd9, 0xf8, 0x16, 0x37, 0xb4, 0xd9, 0xf8, 0x66, 0x41, 0x50, 0xd5, 0xa8, 0xd9, 0xf8, 0xae, 0x72,
		0xa4, 0xdc, 0x58, 0x29, 0xdf, 0xb8, 0x2b, 0xb3, 0x49, 0x8a, 0x3f, 0xe4, 0x5e, 0x4a, 0xd5, 0x89,
		0x90, 0x7b, 0x29, 0x31, 0x4d, 0x3c, 0x33, 0x4d, 0x70, 0xfb, 0xa4, 0xa5, 0xed, 0x93, 0xec, 0x21,
		0xb7, 0x4c, 0xd2, 0x2e, 0x0f, 0xa5, 0x3b, 0x10, 0x05, 0xa3, 0x38, 0x06, 0xdb, 0x34, 0x69, 0x16,
		0x32, 0xb7, 0x4d, 0x5a, 0x47, 0x98, 0xdc, 0x36, 0x29, 0x47, 0xb1, 0x72, 0xdb, 0xa4, 0xfc, 0x86,
		0x17, 0xb7, 0x4d, 0x2a, 0x1a, 0x58, 0xb9, 0x6d, 0x52, 0xd5, 0x6a, 0x14, 0x6e, 0x9b, 0x94, 0xef,
		0xfc, 0xc0, 0x6d, 0x93, 0x08, 0x36, 0x88, 0x80, 0x03, 0x0c, 0x3a, 0xa8, 0xc0, 0x03, 0x0f, 0x3e,
		0xf0, 0x00, 0x84, 0x0d, 0x42, 0x18, 0x40, 0x04, 0x02, 0x46, 0x70, 0x80, 0x94, 0x05, 0xec, 0xd5,
		0x2e, 0xfd, 0x04, 0xd7, 0x3e, 0x92, 0x86, 0x4f, 0xf7, 0x08, 0x01, 0x4a, 0x2f, 0x90, 0xd2, 0x00,
		0xa8, 0xd0, 0xc1, 0x4a, 0x1b, 0xc0, 0xd2, 0x06, 0xb4, 0xf4, 0x00, 0x2e, 0x2c, 0xf0, 0x02, 0x03,
		0xb0, 0x4c, 0x22, 0xf8, 0xee, 0x91, 0xcb, 0xd1, 0x28, 0x50, 0x5e, 0x08, 0x6c, 0x1f, 0xd9, 0xda,
		0xe2, 0x3a, 0xbd, 0xaa, 0x0f, 0x46, 0xa0, 0x47, 0xca, 0x2b, 0x47, 0x22, 0xca, 0x23, 0x66, 0x16,
		0x1a, 0x2c, 0x34, 0x58, 0x68, 0xb0, 0xd0, 0x60, 0xa1, 0xc1, 0x42, 0x83, 0x85, 0x06, 0x0b, 0x8d,
		0x1f, 0xcc, 0xf8, 0xb4, 0xa9, 0x97, 0x10, 0x3a, 0x6d, 0xea, 0x25, 0xdd, 0x78, 0xda, 0xd4, 0xe5,
		0x5c, 0x06, 0x6d, 0xea, 0x9c, 0x7e, 0xd7, 0x39, 0xb4, 0x69, 0x53, 0x17, 0x37, 0xb4, 0x69, 0x53,
		0x67, 0x41, 0x50, 0xd5, 0xa8, 0x69, 0x53, 0xaf, 0x72, 0xa4, 0xb4, 0xa9, 0xe7, 0x1b, 0x77, 0x65,
		0xfc, 0xa7, 0xc1, 0x28, 0x8e, 0x69, 0x54, 0xaf, 0x4e, 0x84, 0x34, 0xaa, 0x33, 0x51, 0x3c, 0x3b,
		0x51, 0xd0, 0xaa, 0xbe, 0x64, 0x55, 0x6f, 0x4f, 0x6f, 0x0b, 0xcd, 0xea, 0xba, 0xe5, 0xa2, 0xf4,
		0xb1, 0xfc, 0x74, 0x10, 0xaa, 0x59, 0x61, 0x56, 0x4b, 0x10, 0x3a, 0xf1, 0x5f, 0x2f, 0x2a, 0xf8,
		0x36, 0x7a, 0x5a, 0xd8, 0xd7, 0x11, 0x26, 0x2d, 0xec, 0x39, 0xea, 0x96, 0x16, 0xf6, 0xfc, 0x86,
		0x17, 0x2d, 0xec, 0x45, 0xa3, 0x2c, 0x2d, 0xec, 0x55, 0xab, 0x5e, 0x68, 0x61, 0xcf, 0x77, 0x7e,
		0xa0, 0x85, 0x9d, 0x60, 0x83, 0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f,
		0x40, 0xd8, 0x20, 0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x59, 0xc0, 0x09, 0xe2, 0x0a,
		0xcc, 0x6c, 0x9a, 0x01, 0xe8, 0xfb, 0xac, 0xc2, 0x26, 0xfa, 0x4a, 0x88, 0x51, 0x1a, 0xe3, 0x14,
		0x3a, 0x56, 0x69, 0x83, 0x57, 0xda, 0x60, 0x96, 0x1e, 0xb8, 0x85, 0x85, 0x5d, 0x60, 0xf8, 0x95,
		0x49, 0x04, 0xdf, 0x57, 0xa2, 0xc2, 0xc9, 0x8d, 0x8a, 0xd2, 0x85, 0x02, 0xc0, 0x26, 0xf6, 0x06,
		0x60, 0xec, 0x56, 0x38, 0xb9, 0x99, 0x8a, 0x87, 0x43, 0x34, 0xcf, 0xbb, 0xdc, 0xf6, 0xe3, 0xc4,
		0x4c, 0x92, 0x08, 0x73, 0x98, 0x9e, 0xf8, 0xa1, 0x15, 0xa8, 0xe9, 0x2c, 0x14, 0x63, 0xae, 0x37,
		0x37, 0x4e, 0xbc, 0x2f, 0x8f, 0xae, 0x60, 0xeb, 0x4d, 0xa3, 0xd1, 0xdc, 0x6d, 0x34, 0x36, 0x77,
		0x5f, 0xef, 0x6e, 0xee, 0xed, 0xec, 0x6c, 0x35, 0xb7, 0x00, 0xd7, 0x9c, 0x1b, 0xa7, 0xd1, 0x50,
		0x45, 0x6a, 0x78, 0x70, 0x67, 0xec, 0x6f, 0x84, 0x93, 0x20, 0xe0, 0x1a, 0xe2, 0x0a, 0x47, 0xca,
		0x35, 0xc4, 0xf9, 0xc6, 0x5d, 0x99, 0xa5, 0x81, 0xdf, 0x2c, 0x34, 0xe2, 0x72, 0xe2, 0xea, 0x44,
		0xc8, 0xe5, 0xc4, 0xcc, 0x19, 0xeb, 0xc8, 0x19, 0x5c, 0x59, 0xbc, 0xb4, 0xb2, 0xb8, 0x9b, 0xdd,
		0xa1, 0x59, 0xb5, 0xce, 0x35, 0xc6, 0xba, 0x25, 0x28, 0xe3, 0xc6, 0xfb, 0x52, 0x9b, 0x0d, 0x86,
		0x4b, 0x2f, 0x1c, 0x7e, 0xf6, 0x87, 0xb3, 0x41, 0x0f, 0xb2, 0xc2, 0xf8, 0x89, 0xd8, 0xb9, 0xbe,
		0x78, 0x1d, 0x61, 0x72, 0x7d, 0x71, 0x8e, 0xaa, 0xe5, 0xfa, 0xe2, 0xfc, 0x86, 0x17, 0xd7, 0x17,
		0x17, 0xcd, 0xb6, 0x5c, 0x5f, 0x5c, 0xb5, 0x72, 0x86, 0xeb, 0x8b, 0xf3, 0x9d, 0x1f, 0xb8, 0xbe,
		0x98, 0x60, 0x83, 0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8,
		0x20, 0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x59, 0xc0, 0x38, 0xad, 0x9f, 0x95, 0x73,
		0x0d, 0x4a, 0x07, 0x68, 0x15, 0x40, 0x71, 0xa5, 0x31, 0x81, 0x4a, 0x63, 0xb0, 0x42, 0x07, 0x2c,
		0x6d, 0x40, 0x4b, 0x1b, 0xe0, 0xd2, 0x03, 0xbc, 0xb0, 0x00, 0x0c, 0x0c, 0xc4, 0x32, 0x89, 0xe0,
		0xaf, 0x34, 0xf6, 0x95, 0x52, 0x57, 0xc1, 0xc8, 0xc3, 0xde, 0xc6, 0x7e, 0x0f, 0x30, 0xf4, 0xb6,
		0x0a, 0xaf, 0x67, 0x60, 0xcc, 0x7d, 0xec, 0x0b, 0xbe, 0xf3, 0xdc, 0xc7, 0x5e, 0xce, 0x65, 0x64,
		0x9b, 0x5d, 0x73, 0x8f, 0x6b, 0x4e, 0xc2, 0x6b, 0x18, 0xda, 0xdc, 0xc7, 0x9e, 0x43, 0x9b, 0x43,
		0x5b, 0x8f, 0x6a, 0x00, 0x37, 0x6a, 0x6e, 0x5f, 0x5f, 0xe5, 0x48, 0x69, 0x3d, 0xc9, 0x37, 0xee,
		0x2a, 0x2c, 0x23, 0x5f, 0x5e, 0x81, 0x4a, 0xe3, 0x49, 0x75, 0x22, 0xa4, 0xf1, 0x84, 0x19, 0xe3,
		0xe5, 0x19, 0x83, 0xb6, 0x93, 0xaf, 0x6c, 0x27, 0x27, 0xde, 0x97, 0xb6, 0x1f, 0x7e, 0x3a, 0xc8,
		0x6e, 0x0f, 0x4d, 0x27, 0xba, 0x25, 0xa7, 0x99, 0x71, 0x23, 0x52, 0xb1, 0x8a, 0x6e, 0xbd, 0xcb,
		0x40, 0x41, 0xfb, 0x4f, 0x56, 0x5f, 0x06, 0xad, 0x28, 0xeb, 0x08, 0x93, 0x56, 0x94, 0x1c, 0x05,
		0x4c, 0x2b, 0x4a, 0x7e, 0xc3, 0x8b, 0x56, 0x94, 0xa2, 0x69, 0x97, 0x56, 0x94, 0xaa, 0x15, 0x38,
		0xb4, 0xa2, 0xe4, 0x3b, 0x3f, 0xd0, 0x8a, 0x42, 0xb0, 0x41, 0x04, 0x1c, 0x60, 0xd0, 0x41, 0x05,
		0x1e, 0x78, 0xf0, 0x81, 0x07, 0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10, 0x30, 0x82, 0x03, 0xa4,
		0x2c, 0x60, 0x5a, 0x51, 0x4a, 0x07, 0x28, 0x5a, 0x51, 0x08, 0x54, 0x1a, 0x83, 0x15, 0x3a, 0x60,
		0x69, 0x03, 0x5a, 0xda, 0x00, 0x97, 0x1e, 0xe0, 0x85, 0x05, 0x60, 0x60, 0x20, 0x96, 0x49, 0x84,
		0x56, 0x14, 0x19, 0x90, 0x43, 0x2b, 0x4a, 0xe1, 0x2f, 0x5a, 0x51, 0x88, 0xf7, 0x6b, 0xb8, 0x0c,
		0xae, 0x57, 0xe7, 0x24, 0xbc, 0xce, 0xa1, 0x4d, 0x2b, 0x0a, 0x87, 0x36, 0x87, 0xb6, 0x1e, 0xd5,
		0x00, 0x6e, 0xd4, 0xb4, 0xa2, 0x54, 0x39, 0x52, 0x5a, 0x51, 0xf2, 0x8d, 0xbb, 0x2a, 0x0b, 0xcb,
		0x57, 0x2e, 0x46, 0xa5, 0x2b, 0xa5, 0x3a, 0x11, 0xd2, 0x95, 0xc2, 0xe4, 0xb1, 0xd6, 0xe4, 0x41,
		0x83, 0xca, 0xb7, 0x06, 0x95, 0x5e, 0x76, 0xab, 0x68, 0x55, 0xd1, 0x3b, 0x63, 0x19, 0x37, 0x7e,
		0x58, 0xcb, 0x3c, 0x5b, 0x43, 0x15, 0x78, 0x77, 0x40, 0xfe, 0x94, 0xe5, 0xd8, 0x69, 0x4a, 0x59,
		0x47, 0x98, 0x34, 0xa5, 0xe4, 0xa8, 0x5a, 0x9a, 0x52, 0xf2, 0x1b, 0x5e, 0x34, 0xa5, 0x14, 0x0d,
		0xbb, 0x34, 0xa5, 0x54, 0xad, 0xbe, 0xa1, 0x29, 0x25, 0xdf, 0xf9, 0x81, 0xa6, 0x14, 0x82, 0x0d,
		0x22, 0xe0, 0x00, 0x83, 0x0e, 0x2a, 0xf0, 0xc0, 0x83, 0x0f, 0x3c, 0x00, 0x61, 0x83, 0x10, 0x06,
		0x10, 0x81, 0x80, 0x11, 0x1c, 0x20, 0x65, 0x01, 0x7b, 0xb5, 0x4b, 0x3f, 0xc1, 0x35, 0xa4, 0xa4,
		0xe1, 0xd3, 0x8c, 0x42, 0x80, 0xd2, 0x0b, 0xa4, 0x34, 0x00, 0x2a, 0x74, 0xb0, 0xd2, 0x06, 0xb0,
		0xb4, 0x01, 0x2d, 0x3d, 0x80, 0x0b, 0x0b, 0xbc, 0xc0, 0x00, 0x2c, 0x93, 0x08, 0xbe, 0x19, 0xe5,
		0x72, 0x34, 0x0a, 0x94, 0x17, 0x02, 0x1b, 0x51, 0xb6, 0xb6, 0xb8, 0xf2, 0xaf, 0xea, 0x83, 0x71,
		0xb6, 0x91, 0x20, 0xc6, 0xb3, 0xe5, 0x95, 0x23, 0xf1, 0xe1, 0x12, 0x58, 0x68, 0xb0, 0xd0, 0x60,
		0xa1, 0xc1, 0x42, 0x83, 0x85, 0x06, 0x0b, 0x0d, 0x72, 0x0d, 0x0b, 0x0d, 0x2d, 0x0a, 0x8d, 0x89,
		0x1f, 0x62, 0x1b, 0xde, 0x77, 0x01, 0x43, 0xef, 0x79, 0xe1, 0xb5, 0xa2, 0xdf, 0xbd, 0xf8, 0x1b,
		0x4f, 0xbf, 0xbb, 0x9c, 0xcb, 0x58, 0x98, 0x62, 0x37, 0x69, 0x8a, 0xe5, 0xf4, 0xbb, 0x86, 0xa1,
		0x4d, 0xbf, 0xbb, 0xb8, 0xa1, 0xdd, 0xd8, 0xde, 0x6b, 0xec, 0x35, 0x77, 0xb7, 0xf7, 0x76, 0x38,
		0xc6, 0x59, 0x10, 0x54, 0x2b, 0x6a, 0x1a, 0xdf, 0x2b, 0x3f, 0x47, 0xcd, 0x7c, 0x4a, 0xe8, 0xed,
		0xef, 0xec, 0x12, 0xd8, 0xfe, 0x2e, 0x22, 0x6c, 0xb6, 0xbf, 0x4b, 0x14, 0x3b, 0xdb, 0xdf, 0xe5,
		0x0d, 0x57, 0xb6, 0xbf, 0x85, 0x5d, 0x08, 0xdb, 0xdf, 0x64, 0x9b, 0xef, 0x48, 0x84, 0xed, 0xef,
		0xd2, 0xf9, 0x86, 0xed, 0xef, 0xa2, 0x5f, 0x6c, 0x7f, 0x13, 0xec, 0xd7, 0x70, 0x19, 0x6c, 0x7f,
		0x73, 0xfa, 0x5d, 0xe7, 0xd0, 0x66, 0xfb, 0x5b, 0xdc, 0xd0, 0x66, 0xfb, 0x9b, 0x05, 0x41, 0x55,
		0xa3, 0x66, 0xfb, 0xbb, 0xca, 0x91, 0x72, 0xdf, 0xd7, 0x7c, 0xe3, 0xae, 0xc4, 0xd6, 0x8d, 0x4b,
		0x9b, 0xbc, 0x71, 0xb3, 0xd7, 0xea, 0x44, 0xc8, 0xcd, 0x5e, 0x99, 0x31, 0x5e, 0x9e, 0x31, 0xb8,
		0xc3, 0xeb, 0xd7, 0x3b, 0xbc, 0xfa, 0xe1, 0x89, 0xf7, 0xa5, 0xed, 0x87, 0x9f, 0x5a, 0xb3, 0xbb,
		0xc3, 0x6d, 0x5d, 0x75, 0xcb, 0x4d, 0x46, 0xa4, 0x62, 0x7f, 0x38, 0xf1, 0x82, 0x1a, 0xce, 0x81,
		0xb3, 0x59, 0x33, 0xfe, 0x89, 0xd8, 0xb9, 0xad, 0xeb, 0x3a, 0xc2, 0xe4, 0xb6, 0xae, 0x39, 0xaa,
		0x96, 0xdb, 0xba, 0xe6, 0x37, 0xbc, 0xb8, 0xad, 0x6b, 0xd1, 0x58, 0xcb, 0x6d, 0x5d, 0xab, 0x56,
		0xc9, 0x70, 0x5b, 0xd7, 0x7c, 0xe7, 0x07, 0x6e, 0xeb, 0x4a, 0xb0, 0x41, 0x04, 0x1c, 0x60, 0xd0,
		0x41, 0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07, 0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10, 0x30, 0x82,
		0x03, 0xa4, 0x2c, 0x60, 0x9c, 0xd6, 0xcf, 0xca, 0xb9, 0x06, 0xe9, 0x8c, 0xae, 0xa7, 0x00, 0x8a,
		0xb6, 0x13, 0x02, 0x95, 0xc6, 0x60, 0x85, 0x0e, 0x58, 0xda, 0x80, 0x96, 0x36, 0xc0, 0xa5, 0x07,
		0x78, 0x61, 0x01, 0x18, 0x18, 0x88, 0x65, 0x12, 0xc1, 0xb7, 0x9d, 0xf8, 0x4a, 0xa9, 0xab, 0x60,
		0xe4, 0x61, 0x7b, 0x4f, 0xf6, 0x00, 0x43, 0x6f, 0xab, 0xf0, 0x7a, 0x06, 0xc6, 0x34, 0x9f, 0x14,
		0x7c, 0xe7, 0x69, 0x3e, 0x91, 0x73, 0x19, 0xd9, 0x0a, 0x75, 0x2e, 0x4c, 0xe7, 0x24, 0xbc, 0x86,
		0xa1, 0x4d, 0xf3, 0x09, 0x87, 0x36, 0x87, 0xb6, 0x1e, 0xd5, 0x00, 0x6e, 0xd4, 0xf4, 0x9c, 0x54,
		0x39, 0x52, 0x7a, 0x4e, 0xf2, 0x8d, 0xbb, 0x0a, 0x2b, 0xc8, 0x97, 0x57, 0xa0, 0xd2, 0x73, 0x52,
		0x9d, 0x08, 0xe9, 0x39, 0x61, 0xc6, 0x78, 0x79, 0xc6, 0xa0, 0xe7, 0xe4, 0x2b, 0xcf, 0x49, 0x6f,
		0x7e, 0x83, 0x0e, 0xb2, 0xfb, 0x43, 0xd7, 0x89, 0x6e, 0xd9, 0x09, 0x64, 0x69, 0x26, 0xd4, 0x92,
		0x4c, 0x7a, 0x4b, 0xd6, 0x1c, 0x28, 0xbd, 0x25, 0xb9, 0x86, 0x4c, 0x6f, 0x49, 0x41, 0x81, 0xd3,
		0x5b, 0x42, 0x1e, 0x40, 0xa9, 0x58, 0x60, 0xbc, 0x25, 0x09, 0xd2, 0x92, 0x82, 0x6c, 0x7a, 0x98,
		0x45, 0x8d, 0xe5, 0x2c, 0xd9, 0xa4, 0xb3, 0xa4, 0xf2, 0x78, 0x03, 0x8c, 0x39, 0xa8, 0xb8, 0x03,
		0x8f, 0x3d, 0xf0, 0xf8, 0x83, 0x8d, 0x41, 0x18, 0x38, 0x04, 0x82, 0x45, 0x99, 0x14, 0xe0, 0x16,
		0x32, 0x3e, 0x2c, 0x60, 0x1c, 0xaa, 0x30, 0xf1, 0x93, 0xbb, 0x48, 0x5d, 0x21, 0x65, 0xed, 0x45,
		0x4f, 0x05, 0x68, 0x43, 0x4e, 0xc3, 0x9e, 0xdf, 0xea, 0x03, 0x2f, 0x56, 0xb8, 0x86, 0x1e, 0xbb,
		0x6f, 0xf7, 0xdd, 0xfe, 0xd9, 0x81, 0xd3, 0x3e, 0x77, 0x9d, 0x3f, 0xba, 0x16, 0xda, 0xb4, 0x33,
		0x5b, 0x56, 0x13, 0x43, 0xae, 0x1b, 0x05, 0xb5, 0x66, 0x64, 0xca, 0xe9, 0xba, 0x3d, 0xcb, 0x3c,
		0x7c, 0x6b, 0x1e, 0xd8, 0x6d, 0xdb, 0xf9, 0x63, 0x2e, 0xa2, 0x3e, 0xa2, 0x8a, 0x74, 0x50, 0x13,
		0xb6, 0xaa, 0xbe, 0xab, 0xae, 0x6e, 0xcf, 0x3a, 0xb2, 0xdf, 0xbb, 0x47, 0x6d, 0xf3, 0xb8, 0x6f,
		0x70, 0x31, 0x29, 0x75, 0xb5, 0x26, 0x5d, 0xd9, 0xdd, 0xf3, 0x86, 0xdb, 0x3b, 0x3d, 0x73, 0xac,
		0x9e, 0x6b, 0xb7, 0xa8, 0x2c, 0x2a, 0x6b, 0x5d, 0xca, 0x72, 0xcc, 0x63, 0xca, 0x89, 0x72, 0x5a,
		0xa3, 0x9c, 0x9a, 0x0d, 0x0a, 0x8a, 0x82, 0x5a, 0xe3, 0xcc, 0xd7, 0xe4, 0xcc, 0x47, 0x65, 0xe5,
		0xc6, 0xea, 0x7d, 0x68, 0x55, 0x41, 0x46, 0x7e, 0xf1, 0x0b, 0x47, 0x2f, 0x47, 0x6d, 0x95, 0x2a,
		0x6b, 0xea, 0x87, 0x15, 0x34, 0x15, 0xc4, 0x4a, 0x99, 0xb2, 0xa9, 0xa2, 0x6c, 0x10, 0x2b, 0x62,
		0x0a, 0x87, 0x95, 0x2f, 0x15, 0xc4, 0x0a, 0x97, 0xea, 0xa9, 0x8a, 0x7a, 0xe6, 0xa9, 0xe6, 0xd0,
		0xec, 0xf2, 0x59, 0x39, 0x75, 0x55, 0x88, 0xbe, 0x7a, 0xae, 0xd9, 0x3e, 0x3e, 0xed, 0xd9, 0xce,
		0xdb, 0x13, 0x76, 0x76, 0xa9, 0xac, 0xb5, 0x2a, 0xeb, 0xe1, 0x77, 0x6c, 0xef, 0x16, 0xfb, 0x62,
		0x7b, 0x97, 0x43, 0xb7, 0x6a, 0x93, 0x01, 0x15, 0xc4, 0xa4, 0x4f, 0x09, 0xa1, 0xd5, 0xcb, 0x7d,
		0xae, 0x0d, 0xa6, 0xaa, 0x8a, 0x52, 0x57, 0xdb, 0xee, 0xbc, 0xe3, 0x12, 0x16, 0x4a, 0x6a, 0x8d,
		0x92, 0x3a, 0xeb, 0x1c, 0x9e, 0x76, 0xfa, 0x4e, 0xcf, 0xb4, 0x3b, 0x56, 0xcb, 0x6d, 0xf7, 0xbb,
		0x14, 0x17, 0xc5, 0xb5, 0xd6, 0x7c, 0x65, 0x3a, 0x4e, 0xcf, 0x3e, 0x38, 0x73, 0x2c, 0xda, 0x19,
		0x28, 0xad, 0xb5, 0x49, 0x6b, 0xf6, 0x68, 0xab, 0x63, 0xd9, 0xc7, 0x6f, 0x0f, 0x4e, 0x7b, 0xae,
		0xd9, 0x6a, 0xf5, 0xac, 0x3e, 0x05, 0x46, 0x81, 0xad, 0x53, 0x60, 0x0d, 0xd7, 0xee, 0x38, 0x56,
		0xef, 0xc8, 0x3c, 0xb4, 0xa8, 0x30, 0x2a, 0x6c, 0xed, 0xe8, 0xe5, 0xd8, 0x6d, 0xfb, 0xbf, 0x56,
		0xcb, 0x3d, 0x30, 0x3b, 0xad, 0xff, 0xd8, 0x2d, 0xe7, 0x2d, 0xd5, 0x45, 0x75, 0xad, 0x95, 0xbd,
		0xba, 0xbd, 0x53, 0xc7, 0x3a, 0x74, 0xec, 0xd3, 0x4e, 0xda, 0x91, 0xa0, 0xbe, 0xa8, 0xaf, 0x35,
		0xe9, 0xab, 0x67, 0xf5, 0xed, 0xd6, 0x99, 0xd9, 0x66, 0xf6, 0xa2, 0xba, 0xd6, 0xaf, 0xae, 0x13,
		0xf3, 0x7d, 0x9a, 0xc1, 0xa8, 0x2e, 0xaa, 0x2b, 0x9f, 0xe2, 0x91, 0x6c, 0x4f, 0x85, 0xe5, 0x9a,
		0xbf, 0x7a, 0x56, 0xdf, 0xea, 0x9d, 0x9b, 0x07, 0x6d, 0x8b, 0x59, 0x8c, 0x1a, 0xcb, 0x89, 0xf0,
		0xdb, 0xa7, 0x4c, 0x5c, 0x14, 0xd5, 0x9a, 0x45, 0xd5, 0xb2, 0xda, 0xe6, 0x1f, 0xee, 0xb9, 0xd9,
		0xb3, 0xcd, 0x69, 0xed, 0x48, 0x7d, 0x51, 0x5f, 0xeb, 0xd2, 0x97, 0xd9, 0xfa, 0xb7, 0xdb, 0x36,
		0x3b, 0xe0, 0x9e, 0x79, 0xca, 0x4a, 0x9a, 0xac, 0xce, 0x4d, 0xbb, 0x4d, 0xd4, 0xa2, 0xbc, 0xf2,
		0xcb, 0x5a, 0xcc, 0x58, 0x94, 0xd4, 0x3a, 0x2b, 0x44, 0xbb, 0xf3, 0xd0, 0xe5, 0x9a, 0x01, 0x17,
		0xd5, 0x45, 0x75, 0xad, 0x4b, 0x5d, 0x67, 0x9d, 0xb4, 0xfb, 0xc0, 0xa7, 0x8b, 0xd4, 0x57, 0x1e,
		0xfa, 0xca, 0x44, 0xe5, 0x66, 0xcb, 0x07, 0x1d, 0xf6, 0x21, 0x28, 0xb0, 0xb5, 0x09, 0xcc, 0x7a,
		0xef, 0x58, 0x9d, 0x96, 0xd5, 0x72, 0xcd, 0xd6, 0x74, 0xa6, 0x3c, 0xee, 0x9d, 0x9e, 0x71, 0x69,
		0x2a, 0xf5, 0xb5, 0x46, 0xa2, 0xa7, 0xac, 0x28, 0xab, 0xb5, 0xcb, 0x6a, 0xb6, 0x6a, 0x90, 0xcb,
		0x52, 0x29, 0xb0, 0xbc, 0x04, 0xc6, 0x72, 0x91, 0xaa, 0x5a, 0xbf, 0xaa, 0x1c, 0xcb, 0x6d, 0x59,
		0x47, 0xe6, 0x59, 0xdb, 0x71, 0x4f, 0x2c, 0xa7, 0x67, 0x1f, 0x72, 0xc3, 0x83, 0x62, 0x5f, 0xdc,
		0xf0, 0x80, 0x83, 0xf7, 0x59, 0x53, 0x01, 0x37, 0xe6, 0xa2, 0x74, 0x7e, 0x5e, 0x3a, 0x1a, 0xb8,
		0x3e, 0x29, 0x22, 0x11, 0xf9, 0x07, 0xd9, 0xdd, 0x49, 0x09, 0x09, 0x28, 0x97, 0x75, 0x70, 0x71,
		0x52, 0x48, 0x22, 0xfa, 0x2e, 0x1a, 0xac, 0xe8, 0xa6, 0x92, 0x4a, 0x47, 0x23, 0x0d, 0x5c, 0x99,
		0x54, 0x91, 0x08, 0x36, 0x82, 0x77, 0x5f, 0x52, 0x47, 0x65, 0xeb, 0x48, 0x07, 0x97, 0x25, 0x55,
		0x54, 0xb6, 0x8a, 0x74, 0x70, 0x53, 0x52, 0x45, 0x22, 0x8a, 0x35, 0x32, 0x36, 0x95, 0xb4, 0x96,
		0x7c, 0xa4, 0x87, 0x3b, 0x92, 0x5a, 0x12, 0x41, 0xda, 0x98, 0x2e, 0x48, 0x8a, 0x47, 0x84, 0x78,
		0xe0, 0xdd, 0x8e, 0xd4, 0x51, 0xd9, 0x3a, 0x82, 0x76, 0x35, 0x52, 0x3e, 0xa5, 0xcb, 0x47, 0x07,
		0xf7, 0x22, 0x65, 0x24, 0x21, 0x0b, 0x31, 0x03, 0x51, 0x3a, 0xcf, 0xa9, 0xc8, 0x34, 0x70, 0x23,
		0x52, 0x45, 0x65, 0xab, 0x48, 0x0f, 0xd7, 0x21, 0x75, 0x54, 0xb6, 0x8e, 0x34, 0x71, 0x17, 0x52,
		0x48, 0x65, 0x0b, 0x49, 0x0f, 0x17, 0x21, 0x75, 0x54, 0x3e, 0x59, 0x53, 0x3e, 0x94, 0xcf, 0xb3,
		0xe5, 0xa3, 0x89, 0x2b, 0x90, 0x42, 0x2a, 0x5b, 0x48, 0x2c, 0xcf, 0xa8, 0x9e, 0xe7, 0xab, 0x47,
		0x03, 0x97, 0x1f, 0x96, 0xbb, 0x0f, 0xc7, 0xd5, 0x87, 0x71, 0x5f, 0xe5, 0x47, 0x29, 0x3b, 0x42,
		0xe1, 0x29, 0xd8, 0x30, 0xc3, 0x70, 0x94, 0x78, 0x89, 0x3f, 0x0a, 0x8d, 0x7d, 0x80, 0xe4, 0x6b,
		0xc4, 0x83, 0x8f, 0xea, 0xc6, 0x1b, 0x7b, 0xc9, 0xc7, 0x69, 0xba, 0xad, 0x8f, 0xc6, 0x2a, 0x1c,
		0x8c, 0xc2, 0x2b, 0xff, 0xba, 0x16, 0xaa, 0xe4, 0xf3, 0x28, 0xfa, 0x54, 0xf3, 0xc3, 0x38, 0xf1,
		0xc2, 0x81, 0xaa, 0x7f, 0xfb, 0x46, 0xbc, 0xf4, 0x4e, 0x7d, 0x1c, 0x8d, 0x92, 0xd1, 0x60, 0x14,
		0xc4, 0xd9, 0x77, 0x75, 0x3f, 0xf6, 0xe3, 0x7a, 0xa0, 0x6e, 0x55, 0x30, 0xff, 0x52, 0x0f, 0xfc,
		0xf0, 0x53, 0x2d, 0x4e, 0xbc, 0x44, 0xd5, 0x86, 0x5e, 0xe2, 0x5d, 0x7a, 0xb1, 0xaa, 0x07, 0xf1,
		0xb8, 0x9e, 0x04, 0xb7, 0xf1, 0xf4, 0x97, 0xfa, 0x4d, 0x52, 0x9b, 0xfe, 0x54, 0x2d, 0x54, 0xfe,
		0xf5, 0xc7, 0xcb, 0x51, 0x54, 0xf3, 0x92, 0x24, 0xf2, 0x2f, 0x27, 0xc9, 0x34, 0x86, 0xf4, 0xad,
		0x38, 0xfb, 0xae, 0xfe, 0x10, 0x4e, 0x16, 0x46, 0x3c, 0xb9, 0x9c, 0xfd, 0x63, 0xe9, 0xd7, 0xfa,
		0xec, 0xff, 0x92, 0x3d, 0x51, 0xc8, 0x1d, 0x74, 0x82, 0x07, 0x9c, 0x31, 0x55, 0x90, 0xba, 0xf2,
		0x26, 0x41, 0x52, 0xbb, 0x51, 0x49, 0xe4, 0x0f, 0xc4, 0x8f, 0xb9, 0x0c, 0x6c, 0x96, 0x43, 0x17,
		0x9e, 0xd8, 0xde, 0xf9, 0xe1, 0xd0, 0xd8, 0xdf, 0xd8, 0x12, 0x1e, 0xe6, 0xe1, 0x2c, 0x79, 0x19,
		0xfb, 0x1b, 0x9b, 0xc2, 0x03, 0xed, 0x46, 0xea, 0xca, 0xff, 0x82, 0x31, 0x49, 0x2c, 0x44, 0x3b,
		0x1a, 0xcc, 0x12, 0x33, 0xc0, 0xa9, 0xe0, 0x46, 0x7f, 0x34, 0x89, 0x06, 0x0a, 0xe2, 0xf6, 0xa6,
		0xc3, 0x4b, 0xdd, 0x7d, 0x1e, 0x45, 0xd3, 0x11, 0x66, 0x8c, 0x53, 0x65, 0x60, 0xd4, 0x9a, 0xc6,
		0x5b, 0x2f, 0x36, 0xa3, 0xeb, 0xc9, 0x8d, 0x0a, 0x13, 0x63, 0x7f, 0x23, 0x89, 0x26, 0x0a, 0x24,
		0xf0, 0x47, 0x51, 0x67, 0xc2, 0x26, 0x9c, 0x6b, 0x0d, 0xe7, 0x2d, 0x3f, 0x02, 0xa1, 0xf2, 0x19,
		0xb1, 0xc2, 0x24, 0xaf, 0xc5, 0xfc, 0x90, 0x86, 0x0d, 0x32, 0xfe, 0x31, 0x80, 0x06, 0x0e, 0x6c,
		0x10, 0x01, 0x07, 0x18, 0x74, 0x50, 0x81, 0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08, 0x1b, 0x84, 0x30,
		0x80, 0x08, 0x04, 0x8c, 0xe0, 0x00, 0x29, 0x0b, 0x18, 0xa4, 0xed, 0xb3, 0x72, 0xa2, 0x81, 0xe8,
		0xfd, 0xac, 0x42, 0xa7, 0x4d, 0xb0, 0xb0, 0xd1, 0x10, 0x0a, 0x19, 0xa5, 0x34, 0x40, 0x2a, 0x74,
		0xb4, 0xd2, 0x06, 0xb1, 0xb4, 0x41, 0x2d, 0x3d, 0x90, 0x0b, 0x0b, 0xbd, 0xc0, 0x10, 0x2c, 0x93,
		0x88, 0x73, 0x37, 0x56, 0xd8, 0x19, 0x7f, 0xe2, 0x87, 0xc9, 0xeb, 0x6d, 0xc4, 0x84, 0x3f, 0xe7,
		0x9b, 0x5d, 0xc0, 0xd0, 0x7b, 0x5e, 0x78, 0x3d, 0xbd, 0xfb, 0x1f, 0x20, 0x13, 0x23, 0xee, 0xde,
		0xf4, 0xc6, 0x89, 0x1f, 0xc2, 0x12, 0x02, 0x38, 0xd8, 0x2f, 0x5d, 0xc6, 0xb9, 0x17, 0x4c, 0x94,
		0x06, 0xd7, 0x71, 0x14, 0x79, 0x83, 0xc4, 0x1f, 0x85, 0x2d, 0xff, 0xda, 0x4f, 0xe2, 0xe9, 0x05,
		0xf1, 0xc0, 0x8c, 0x32, 0x86, 0xb6, 0xf7, 0x85, 0x43, 0x5b, 0xd8, 0xd0, 0x6e, 0x6c, 0xef, 0x35,
		0xf6, 0x9a, 0xbb, 0xdb, 0x7b, 0x3b, 0x1c, 0xe3, 0x2c, 0x08, 0xaa, 0x15, 0x35, 0xd6, 0x49, 0x2b,
		0xf7, 0x7c, 0x96, 0x50, 0xc5, 0x99, 0x14, 0x6d, 0x25, 0x74, 0x16, 0x77, 0x15, 0x56, 0x44, 0x2f,
		0xad, 0x3e, 0x45, 0x58, 0x23, 0x8d, 0x33, 0x4c, 0xb9, 0x4a, 0xab, 0x42, 0x89, 0xa3, 0x9a, 0x09,
		0x03, 0x61, 0x0d, 0x70, 0x9c, 0x44, 0x93, 0x41, 0x12, 0xce, 0xdb, 0x91, 0x9d, 0xf4, 0x4e, 0xdb,
		0xf3, 0x2b, 0x74, 0xbb, 0xf3, 0xdb, 0xeb, 0xda, 0xb1, 0x1f, 0xbb, 0xed, 0xe9, 0x7d, 0x75, 0xdb,
		0xf1, 0xd8, 0x75, 0x82, 0x5b, 0xf7, 0x24, 0x99, 0xbe, 0xd9, 0x99, 0xdf, 0x1f, 0x73, 0x71, 0xef,
		0xdc, 0xc5, 0x3b, 0x6e, 0xf6, 0xaf, 0xf4, 0x67, 0xf7, 0xc7, 0x75, 0x54, 0x2b, 0xbd, 0x3d, 0x27,
		0xe9, 0xdd, 0xa1, 0xd9, 0x44, 0xb7, 0xd4, 0x64, 0x24, 0x08, 0x0d, 0xf9, 0x07, 0x7f, 0xc9, 0x34,
		0x5a, 0x0c, 0x4b, 0xc9, 0x26, 0x2d, 0x25, 0xeb, 0x09, 0x94, 0x96, 0x92, 0x5c, 0x43, 0xa6, 0xa5,
		0xa4, 0xa0, 0xc0, 0x69, 0x29, 0x21, 0x0d, 0xa0, 0x14, 0x2b, 0x30, 0x8f, 0xe9, 0xb3, 0x8c, 0x1b,
		0x28, 0xef, 0x2a, 0x52, 0x57, 0x08, 0x19, 0x77, 0x61, 0xd1, 0x00, 0x78, 0x10, 0x6f, 0x74, 0xe7,
		0xf5, 0xdf, 0xab, 0x57, 0x69, 0x2f, 0xa5, 0x3e, 0x23, 0x30, 0xd6, 0x01, 0xda, 0xd5, 0x01, 0x93,
		0x69, 0x75, 0x1f, 0x27, 0x91, 0xe7, 0x87, 0x6a, 0x58, 0x0b, 0xe2, 0x31, 0x4e, 0x51, 0xb0, 0x1c,
		0x3a, 0x4d, 0xe7, 0xac, 0x10, 0x58, 0x21, 0xb0, 0x42, 0x60, 0x85, 0xc0, 0x0a, 0x81, 0x15, 0x42,
		0x2e, 0x1f, 0x39, 0x4d, 0xe7, 0xf9, 0xce, 0x0f, 0x34, 0x9d, 0x13, 0x6c, 0x10, 0x01, 0x07, 0x18,
		0x74, 0x50, 0x81, 0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08, 0x1b, 0x84, 0x30, 0x80, 0x08, 0x04, 0x8c,
		0xe0, 0x00, 0x29, 0x0b, 0x78, 0x30, 0x9a, 0xcc, 0x84, 0x0b, 0xea, 0x39, 0x4f, 0xc3, 0xa7, 0xe5,
		0x9c, 0x00, 0xa5, 0x17, 0x48, 0x69, 0x00, 0x54, 0xe8, 0x60, 0xa5, 0x0d, 0x60, 0x69, 0x03, 0x5a,
		0x7a, 0x00, 0x17, 0x16, 0x78, 0x81, 0x01, 0x58, 0x26, 0x11, 0x3d, 0x2c, 0xe7, 0x5b, 0x4d, 0x60,
		0xcb, 0x79, 0x93, 0x96, 0xf3, 0x82, 0x5f, 0xb4, 0x9c, 0x13, 0xec, 0xd7, 0x70, 0x19, 0xb4, 0x9c,
		0x73, 0xfa, 0x5d, 0xe7, 0xd0, 0xa6, 0xe5, 0x5c, 0xdc, 0xd0, 0x6e, 0xee, 0xec, 0xbc, 0xa6, 0xdb,
		0x9c, 0xb5, 0x40, 0xc5, 0xa2, 0xa6, 0xdb, 0xbc, 0xf2, 0xd3, 0x13, 0x86, 0xf7, 0x69, 0x65, 0x55,
		0x08, 0xe0, 0x85, 0xd2, 0x64, 0xee, 0x64, 0xbf, 0xbb, 0x4c, 0x9d, 0xb3, 0xdf, 0x5d, 0xde, 0x70,
		0x65, 0xbf, 0x5b, 0xd8, 0x85, 0xb0, 0xdf, 0x4d, 0xa2, 0xf9, 0x8e, 0x44, 0xf0, 0xfb, 0xdd, 0xfe,
		0x50, 0x85, 0x89, 0x9f, 0xdc, 0x61, 0xf8, 0xb9, 0x56, 0x41, 0xce, 0x16, 0x60, 0x55, 0x6d, 0xd8,
		0xf3, 0x5b, 0x7f, 0xe0, 0xc5, 0xc0, 0xf3, 0xd6, 0xc3, 0x39, 0xdb, 0x76, 0xdf, 0xed, 0x9f, 0x1d,
		0x38, 0xed, 0x73, 0xd7, 0xf9, 0xa3, 0x6b, 0xa1, 0x4e, 0x5f, 0xb3, 0x5e, 0x4d, 0x0c, 0xfb, 0x30,
		0x62, 0x03, 0xfa, 0x81, 0xc4, 0xd7, 0x8a, 0xea, 0x7e, 0x7d, 0x72, 0x7b, 0x2a, 0xae, 0x3e, 0xb2,
		0xba, 0x74, 0x52, 0x99, 0x1e, 0x6a, 0xfb, 0xae, 0xea, 0xba, 0x3d, 0xeb, 0xc8, 0x7e, 0xef, 0x1e,
		0xb5, 0xcd, 0xe3, 0xbe, 0x01, 0x7f, 0xa9, 0xf7, 0xbf, 0x53, 0x6f, 0xb2, 0xf5, 0x66, 0x77, 0xcf,
		0x1b, 0x6e, 0xef, 0xf4, 0xcc, 0xb1, 0x7a, 0xae, 0xdd, 0xa2, 0xe2, 0xa8, 0xb8, 0xbc, 0x15, 0xe7,
		0x98, 0xc7, 0x94, 0x19, 0x65, 0x56, 0x80, 0xcc, 0x9a, 0x0d, 0x0a, 0x8d, 0x42, 0x2b, 0x60, 0x06,
		0x6d, 0x72, 0x06, 0xa5, 0xe2, 0x0a, 0xaf, 0x11, 0xfa, 0x5a, 0xa8, 0x0d, 0xfa, 0x0a, 0x2e, 0xb8,
		0xd6, 0x8c, 0xa3, 0x9b, 0x95, 0x3f, 0x75, 0xc5, 0x0a, 0x9f, 0xca, 0xaa, 0x9c, 0xb2, 0xa0, 0x2b,
		0x79, 0xca, 0x89, 0x15, 0x3b, 0x05, 0xa5, 0xfb, 0xcc, 0xd7, 0xe4, 0xcc, 0x47, 0x65, 0xb1, 0x02,
		0xa7, 0xaa, 0x24, 0xaa, 0x6a, 0x9e, 0x9a, 0x0e, 0xcd, 0x2e, 0xd7, 0x1c, 0x50, 0x6f, 0xa5, 0xea,
		0xae, 0xe7, 0x9a, 0xed, 0xe3, 0xd3, 0x9e, 0xed, 0xbc, 0x3d, 0x61, 0x07, 0x9b, 0x8a, 0x2b, 0x44,
		0x71, 0x0f, 0xbf, 0x63, 0x1b, 0xbb, 0xdc, 0x17, 0xdb, 0xd8, 0x1c, 0xe2, 0x9c, 0x4c, 0xa8, 0x2c,
		0x4e, 0x1a, 0x94, 0x56, 0x35, 0xea, 0xf9, 0x3e, 0xd7, 0x7a, 0x53, 0x6d, 0x65, 0xab, 0xae, 0x6d,
		0x77, 0xde, 0x71, 0xc9, 0x10, 0xa5, 0x56, 0x80, 0xd4, 0xce, 0x3a, 0x87, 0xa7, 0x9d, 0xbe, 0xd3,
		0x33, 0xed, 0x8e, 0xd5, 0x72, 0xdb, 0xfd, 0x2e, 0x45, 0x47, 0xd1, 0x15, 0x92, 0xdf, 0x4c, 0xc7,
		0xe9, 0xd9, 0x07, 0x67, 0x8e, 0x45, 0x3b, 0x0b, 0x25, 0x97, 0xbb, 0xe4, 0x66, 0x8f, 0xfc, 0x3a,
		0x96, 0x7d, 0xfc, 0xf6, 0xe0, 0xb4, 0xe7, 0x9a, 0xad, 0x56, 0xcf, 0xea, 0x53, 0x78, 0x14, 0x5e,
		0x11, 0xc2, 0x6b, 0xb8, 0x76, 0xc7, 0xb1, 0x7a, 0x47, 0xe6, 0xa1, 0x45, 0xe5, 0x51, 0x79, 0x85,
		0xa1, 0x9d, 0x63, 0xb7, 0xed, 0xff, 0x5a, 0x2d, 0xf7, 0xc0, 0xec, 0xb4, 0xfe, 0x63, 0xb7, 0x9c,
		0xb7, 0x54, 0x1d, 0x55, 0x57, 0x08, 0xdb, 0x75, 0x7b, 0xa7, 0x8e, 0x75, 0xe8, 0xd8, 0xa7, 0x9d,
		0xb4, 0x73, 0x42, 0xdd, 0x51, 0x77, 0x39, 0xeb, 0xae, 0x67, 0xf5, 0xed, 0xd6, 0x99, 0xd9, 0x66,
		0xb6, 0xa3, 0xea, 0x8a, 0x53, 0xdd, 0x89, 0xf9, 0x3e, 0xcd, 0x78, 0x54, 0x1d, 0x55, 0x57, 0x6c,
		0x31, 0xcb, 0x9a, 0x82, 0xca, 0x2b, 0x25, 0xdf, 0xf5, 0xac, 0xbe, 0xd5, 0x3b, 0x37, 0x0f, 0xda,
		0x16, 0xb3, 0x1e, 0xb5, 0x57, 0x70, 0x65, 0xd1, 0x3e, 0x65, 0xa2, 0xa3, 0xd8, 0x0a, 0x12, 0x5b,
		0xcb, 0x6a, 0x9b, 0x7f, 0xb8, 0xe7, 0x66, 0xcf, 0x36, 0xa7, 0xb5, 0x2c, 0x75, 0x47, 0xdd, 0xe5,
		0xad, 0x3b, 0xb3, 0xf5, 0x6f, 0xb7, 0x6d, 0x76, 0x34, 0xd9, 0xc3, 0x81, 0x72, 0x93, 0x2e, 0xb7,
		0x73, 0xd3, 0x6e, 0x13, 0xe5, 0x28, 0xbb, 0xe2, 0xb3, 0x1c, 0x33, 0x1c, 0xa5, 0x56, 0x44, 0xc5,
		0x6a, 0x77, 0x1e, 0xba, 0x74, 0x33, 0xa0, 0xa3, 0xea, 0xa8, 0xba, 0xbc, 0x55, 0x77, 0xd6, 0x49,
		0xbb, 0x24, 0x7c, 0xfa, 0x4a, 0xdd, 0x15, 0xa9, 0xbb, 0x4c, 0x6c, 0x6e, 0xb6, 0xac, 0xd3, 0x61,
		0xbf, 0x84, 0xc2, 0xcb, 0x5d, 0x78, 0xd6, 0x7b, 0xc7, 0xea, 0xb4, 0xac, 0x96, 0x6b, 0xb6, 0xa6,
		0x33, 0xee, 0x71, 0xef, 0xf4, 0x8c, 0x4b, 0x89, 0xa9, 0xbb, 0x02, 0x2a, 0x09, 0xca, 0x8d, 0x72,
		0x2b, 0x4c, 0x6e, 0xb3, 0xd5, 0x9c, 0x5c, 0x46, 0x4c, 0xe1, 0x15, 0x2d, 0x3c, 0x96, 0xaf, 0x54,
		0x5b, 0x71, 0x6a, 0x73, 0x2c, 0xb7, 0x65, 0x1d, 0x99, 0x67, 0x6d, 0xc7, 0x3d, 0xb1, 0x9c, 0x9e,
		0x7d, 0xc8, 0x8d, 0x38, 0xca, 0x7d, 0x71, 0x23, 0x0e, 0x0e, 0xf2, 0xb5, 0x4e, 0x25, 0xdc, 0xa0,
		0x8e, 0x92, 0x5a, 0x9f, 0xa4, 0x34, 0x72, 0x11, 0x53, 0x5c, 0x22, 0xf3, 0x95, 0x0e, 0x6e, 0x61,
		0x4a, 0x4b, 0x60, 0x39, 0xaf, 0x93, 0x2b, 0x98, 0x02, 0x13, 0x28, 0x30, 0xad, 0xdc, 0xbf, 0x54,
		0x98, 0x38, 0xf4, 0xd2, 0xc8, 0xe5, 0x4b, 0x75, 0x89, 0x64, 0x2f, 0x6d, 0xdc, 0xbc, 0xd4, 0x97,
		0x34, 0x7d, 0xe9, 0xe4, 0xda, 0xa5, 0xba, 0xa4, 0xa9, 0x4b, 0x27, 0x77, 0x2e, 0xd5, 0x25, 0xb2,
		0x78, 0x24, 0xdb, 0x53, 0x61, 0xb9, 0xe6, 0x2f, 0xbd, 0xdc, 0xb6, 0xd4, 0x98, 0x48, 0xc2, 0xc7,
		0x76, 0xd5, 0x52, 0x54, 0x22, 0x45, 0xa5, 0x8d, 0x7b, 0x96, 0xfa, 0x92, 0xa6, 0x2f, 0x2d, 0x5c,
		0xb2, 0x94, 0x95, 0x38, 0x59, 0xe9, 0xe4, 0x86, 0xa5, 0xbc, 0x24, 0x66, 0x2d, 0x66, 0x2c, 0x4a,
		0x6a, 0x9d, 0x15, 0xa2, 0x46, 0xee, 0x56, 0xaa, 0x4b, 0x9a, 0xba, 0xf4, 0x72, 0xb1, 0x52, 0x5f,
		0xd2, 0xf4, 0xa5, 0x99, 0x5b, 0x95, 0x02, 0x93, 0x26, 0x30, 0xbd, 0x5c, 0xa9, 0xd4, 0x97, 0x3c,
		0xa2, 0xa7, 0xac, 0x28, 0xab, 0xb5, 0xcb, 0x4a, 0x33, 0x97, 0x29, 0x05, 0x26, 0x4d, 0x60, 0x2c,
		0x17, 0xa9, 0xaa, 0xf5, 0xab, 0x4a, 0x23, 0xd7, 0x28, 0xa6, 0x5b, 0x14, 0xcf, 0x25, 0x8a, 0x75,
		0x9f, 0x71, 0xa2, 0xc5, 0x88, 0x14, 0x24, 0x85, 0x1b, 0x66, 0x18, 0x8e, 0x12, 0x2f, 0xf1, 0x47,
		0xa1, 0xb1, 0x0f, 0x94, 0xbc, 0x8d, 0x78, 0xf0, 0x51, 0xdd, 0x78, 0x63, 0x2f, 0xf9, 0x38, 0x4d,
		0xd7, 0xf5, 0xd1, 0x58, 0x85, 0x83, 0x51, 0x78, 0xe5, 0x5f, 0xd7, 0x42, 0x95, 0x7c, 0x1e, 0x45,
		0x9f, 0x6a, 0x7e, 0x18, 0x27, 0x5e, 0x38, 0x50, 0xf5, 0x6f, 0xdf, 0x88, 0x97, 0xde, 0xa9, 0x8f,
		0xa3, 0x51, 0x32, 0x1a, 0x8c, 0x82, 0x38, 0xfb, 0xae, 0xee, 0xc7, 0x7e, 0x5c, 0x0f, 0xd4, 0xad,
		0x0a, 0xe6, 0x5f, 0xea, 0x81, 0x1f, 0x7e, 0xaa, 0xc5, 0x89, 0x97, 0xa8, 0xda, 0xd0, 0x4b, 0xbc,
		0x4b, 0x2f, 0x56, 0xf5, 0x20, 0x1e, 0xd7, 0x93, 0xe0, 0x36, 0x9e, 0xfe, 0x52, 0xbf, 0x49, 0x6a,
		0xd3, 0x9f, 0xaa, 0x85, 0xca, 0xbf, 0xfe, 0x78, 0x39, 0x8a, 0x6a, 0x5e, 0x92, 0x44, 0xfe, 0xe5,
		0x24, 0x99, 0xc6, 0x90, 0xbe, 0x15, 0x67, 0xdf, 0xd5, 0x1f, 0xc2, 0xc9, 0xc2, 0x88, 0x27, 0x97,
		0xb3, 0x7f, 0x2c, 0xfd, 0x5a, 0x9f, 0x4c, 0x2f, 0x29, 0x4e, 0x22, 0xcf, 0x0f, 0xd5, 0xb0, 0x36,
		0xfd, 0xaf, 0x66, 0xff, 0x3b, 0xc6, 0xd4, 0x23, 0x7f, 0x98, 0xca, 0x8e, 0x50, 0x78, 0x02, 0x41,
		0x4b, 0x1c, 0xd5, 0x4c, 0x18, 0x00, 0xe7, 0xfa, 0x1b, 0x71, 0x12, 0x4d, 0x06, 0x49, 0x38, 0x07,
		0xef, 0x4e, 0x7a, 0xa7, 0xed, 0xf9, 0x15, 0xba, 0xdd, 0xf9, 0xed, 0x75, 0xed, 0xd8, 0x8f, 0xdd,
		0xf6, 0xf4, 0xbe, 0xba, 0xed, 0x78, 0xec, 0x3a, 0xc1, 0xad, 0x7b, 0x92, 0x4c, 0xdf, 0xec, 0xcc,
		0xef, 0x8f, 0xb9, 0xb8, 0x77, 0xee, 0xe2, 0x1d, 0x37, 0xfb, 0x57, 0xfa, 0xb3, 0xfb, 0xe3, 0x9e,
		0x3d, 0xbe, 0x3f, 0xed, 0x78, 0x2c, 0x3b, 0x93, 0xca, 0xcd, 0x4f, 0x82, 0x73, 0x93, 0x31, 0x09,
		0x23, 0x15, 0xab, 0xe8, 0x56, 0x0d, 0x6b, 0x97, 0x5e, 0x38, 0xfc, 0xec, 0x0f, 0x67, 0x23, 0x5e,
		0x76, 0x86, 0xca, 0xea, 0xce, 0x27, 0xa3, 0x17, 0x3e, 0x13, 0xbc, 0xf3, 0xc3, 0xa1, 0xb1, 0xbf,
		0xb1, 0x25, 0x3c, 0xcc, 0xc3, 0x59, 0xb6, 0x37, 0xf6, 0x37, 0x36, 0x85, 0x07, 0xda, 0x8d, 0xd4,
		0x95, 0xff, 0x05, 0x63, 0x56, 0x5d, 0xe8, 0x76, 0x34, 0x98, 0xcd, 0x64, 0x08, 0xf3, 0x4d, 0x7f,
		0x34, 0x89, 0x06, 0x0a, 0xa6, 0xda, 0x31, 0xde, 0xa9, 0xbb, 0xcf, 0xa3, 0x68, 0x3a, 0xc2, 0x8c,
		0x71, 0xaa, 0x0c, 0x90, 0xd2, 0xf2, 0xad, 0x17, 0x9b, 0xd1, 0xf5, 0xe4, 0x46, 0x85, 0x89, 0xb1,
		0xbf, 0x91, 0x44, 0x13, 0x85, 0x52, 0x13, 0x3f, 0x44, 0x9d, 0x09, 0x9b, 0xd5, 0x8c, 0xd6, 0xd5,
		0x4c, 0xcb, 0x8f, 0x40, 0xca, 0x18, 0x95, 0x4c, 0xc6, 0xb5, 0x71, 0xe4, 0x8f, 0x22, 0x3f, 0xb9,
		0xc3, 0xc9, 0x62, 0x8b, 0x89, 0xe2, 0x9b, 0xf8, 0x41, 0x32, 0x02, 0x06, 0xe2, 0xc0, 0xa1, 0x0e,
		0x22, 0xf2, 0x00, 0xa3, 0x0f, 0x2a, 0x02, 0xc1, 0xa3, 0x10, 0x3c, 0x12, 0x61, 0xa3, 0x11, 0x06,
		0x22, 0x81, 0xa0, 0x12, 0x1c, 0x32, 0x65, 0x01, 0xc3, 0x41, 0xd3, 0xd2, 0x54, 0x03, 0x86, 0x4d,
		0xdf, 0xe2, 0xd3, 0x26, 0x58, 0xd8, 0x68, 0x18, 0x85, 0x8c, 0x53, 0x1a, 0x60, 0x15, 0x3a, 0x5e,
		0x69, 0x83, 0x59, 0xda, 0xe0, 0x96, 0x1e, 0xd8, 0x85, 0x85, 0x5f, 0x60, 0x18, 0x96, 0x49, 0xc4,
		0xb9, 0x1b, 0x2b, 0xec, 0x8c, 0x1f, 0x28, 0xef, 0x2a, 0x52, 0x57, 0x88, 0x19, 0x7f, 0xd1, 0x1f,
		0xda, 0x05, 0x8c, 0xbd, 0x3b, 0x5f, 0x12, 0xf1, 0xea, 0x55, 0xba, 0xbc, 0xa8, 0x9e, 0x51, 0x26,
		0x17, 0x30, 0x56, 0x3d, 0xb3, 0x18, 0xe9, 0x82, 0x33, 0xd8, 0x82, 0x29, 0x0d, 0x1f, 0xb3, 0x5a,
		0xda, 0x62, 0xb5, 0xc4, 0x6a, 0x89, 0xd5, 0x12, 0xab, 0x25, 0x56, 0x4b, 0xac, 0x96, 0xc8, 0x34,
		0xeb, 0x95, 0x08, 0x5a, 0xf3, 0x3a, 0x0b, 0x1c, 0x67, 0x4d, 0xe3, 0x77, 0xe7, 0x2c, 0x94, 0x05,
		0x8e, 0xdf, 0x03, 0xb5, 0x4d, 0xd0, 0xf0, 0x51, 0x81, 0x4d, 0x07, 0x70, 0xd3, 0x08, 0xe0, 0x74,
		0x01, 0x39, 0xed, 0x80, 0x4e, 0x3b, 0xb0, 0xd3, 0x0b, 0xf0, 0x30, 0x41, 0x0f, 0x14, 0xf8, 0x32,
		0xe9, 0xc0, 0xb6, 0xc9, 0x97, 0x66, 0x0c, 0x5f, 0x29, 0x75, 0x15, 0x8c, 0xbc, 0xe4, 0xf5, 0x36,
		0xf2, 0xac, 0x31, 0x87, 0xa8, 0x3d, 0xe0, 0x4b, 0x68, 0xab, 0xf0, 0x7a, 0x06, 0xe4, 0x1f, 0xa0,
		0xd3, 0x2a, 0xfe, 0xc1, 0xef, 0xc6, 0x89, 0x1f, 0xc2, 0xf3, 0x87, 0x26, 0xe5, 0xc5, 0xd2, 0xe5,
		0x9c, 0x7b, 0xc1, 0x64, 0x9a, 0xb8, 0x1a, 0x9a, 0x5c, 0xcf, 0x51, 0xe4, 0x0d, 0x12, 0x7f, 0x14,
		0xb6, 0xfc, 0x6b, 0x3f, 0x89, 0xa7, 0x1f, 0x14, 0xfc, 0x75, 0xdd, 0xff, 0xae, 0x41, 0x0a, 0xf0,
		0xbe, 0x30, 0x05, 0x30, 0x05, 0x30, 0x05, 0x54, 0xa9, 0x1a, 0xc1, 0x8f, 0xfe, 0xe2, 0x17, 0xde,
		0x6f, 0x4e, 0x71, 0x4f, 0xa7, 0x19, 0xd8, 0x85, 0xeb, 0x4b, 0x35, 0x2b, 0xe8, 0x02, 0x76, 0x4d,
		0xe6, 0x63, 0x76, 0xfc, 0x25, 0x8d, 0x05, 0x76, 0xfc, 0xe5, 0x0c, 0x6b, 0x76, 0xfc, 0x85, 0x5f,
		0x10, 0x3b, 0xfe, 0x24, 0xa7, 0x67, 0x4a, 0x47, 0x9f, 0x8e, 0xff, 0xc4, 0x0f, 0x93, 0x37, 0x1a,
		0xf4, 0xfa, 0x77, 0x80, 0x2f, 0xa1, 0xe7, 0x85, 0xd7, 0x8a, 0xad, 0xfe, 0xf2, 0x3f, 0x08, 0xb6,
		0xfa, 0xe5, 0x5e, 0xce, 0xa2, 0xcf, 0xb7, 0xc9, 0x3e, 0x1f, 0x67, 0xf3, 0x1c, 0x53, 0x00, 0x5b,
		0xfd, 0xe2, 0x53, 0xc0, 0x2e, 0x53, 0x00, 0xcb, 0x10, 0x46, 0xff, 0xf8, 0xc5, 0x56, 0x3f, 0x23,
		0x86, 0x9f, 0x90, 0x51, 0x0f, 0x8e, 0xc8, 0xe2, 0xaf, 0xc6, 0x7e, 0xf0, 0xcb, 0xbb, 0x49, 0xd7,
		0xbf, 0xde, 0x81, 0x11, 0xe9, 0x48, 0x09, 0xbc, 0x81, 0xcd, 0x1d, 0xc7, 0xd6, 0x8a, 0xc8, 0xea,
		0x0e, 0xf0, 0x21, 0xa2, 0xd1, 0xf6, 0xe3, 0xc4, 0x4c, 0x12, 0xb0, 0xdd, 0xd2, 0x4e, 0xfc, 0xd0,
		0x0a, 0xd4, 0x8d, 0x0a, 0x53, 0xda, 0x05, 0xda, 0xb3, 0xe0, 0xc4, 0xfb, 0xf2, 0x28, 0xf2, 0xad,
		0x37, 0x8d, 0x46, 0x73, 0xb7, 0xd1, 0xd8, 0xdc, 0x7d, 0xbd, 0xbb, 0xb9, 0xb7, 0xb3, 0xb3, 0xd5,
		0xdc, 0x02, 0xea, 0x3f, 0x1a, 0xa7, 0xd1, 0x50, 0x45, 0x6a, 0x78, 0x30, 0x55, 0x7e, 0x38, 0x09,
		0x02, 0x26, 0x14, 0x32, 0x0c, 0xd9, 0x05, 0x6e, 0x15, 0x49, 0x91, 0xa7, 0xdc, 0xf4, 0xa7, 0x37,
		0xa9, 0x0b, 0xb5, 0x89, 0x0f, 0x0f, 0x0b, 0xd3, 0x3a, 0xe1, 0xf2, 0xb0, 0x30, 0x90, 0x04, 0xcb,
		0x03, 0xb1, 0xb4, 0x1b, 0x7f, 0xc6, 0x24, 0xf1, 0x03, 0xff, 0xff, 0x81, 0x1e, 0x87, 0xb5, 0x1c,
		0x3b, 0x0f, 0xc3, 0x5a, 0x47, 0x98, 0x3c, 0x0c, 0x2b, 0x47, 0xd5, 0xf2, 0x30, 0xac, 0x3c, 0x5b,
		0x40, 0x3c, 0x0c, 0xab, 0x58, 0x74, 0xe3, 0x61, 0x58, 0x55, 0xa3, 0x75, 0x9c, 0xc3, 0xb0, 0xa0,
		0x76, 0x27, 0x85, 0xdc, 0x95, 0x94, 0x47, 0x5f, 0x11, 0x70, 0x34, 0x00, 0x1d, 0x54, 0xe0, 0x81,
		0x07, 0x1f, 0x78, 0x00, 0xc2, 0x06, 0x21, 0x0c, 0x20, 0x02, 0x01, 0x23, 0x38, 0x40, 0xca, 0x02,
		0xc6, 0xdd, 0x35, 0x14, 0x7e, 0xb7, 0x50, 0x1e, 0x7e, 0x45, 0xa0, 0xaa, 0x00, 0x58, 0xa1, 0x03,
		0x96, 0x36, 0xa0, 0xa5, 0x0d, 0x70, 0xe9, 0x01, 0x5e, 0x58, 0x00, 0x06, 0x06, 0x62, 0x99, 0x44,
		0xf0, 0x0f, 0xbf, 0xc2, 0xde, 0xcd, 0x13, 0x78, 0x17, 0x4f, 0xf4, 0xdd, 0x3b, 0x81, 0x7d, 0xed,
		0x3a, 0x58, 0x78, 0x35, 0xf1, 0xed, 0xe9, 0xb2, 0x35, 0x9f, 0x4e, 0x3e, 0x3d, 0x60, 0x8b, 0xae,
		0x16, 0xd6, 0x5c, 0x0e, 0x6d, 0x0e, 0x6d, 0x56, 0x03, 0xd0, 0x51, 0x5f, 0xd0, 0xd7, 0x56, 0xf5,
		0xa9, 0xc9, 0x48, 0x10, 0x6b, 0xc3, 0xac, 0x2e, 0x9c, 0x45, 0xcf, 0x8e, 0x77, 0x11, 0x61, 0xb3,
		0xe3, 0x5d, 0xa2, 0xce, 0xd9, 0xf1, 0x2e, 0x6f, 0xb8, 0xb2, 0xe3, 0x2d, 0xec, 0x42, 0xd8, 0xf1,
		0x26, 0xd1, 0x7c, 0x47, 0x22, 0x1a, 0x74, 0xbc, 0x87, 0x2a, 0x4c, 0xfc, 0xe4, 0x2e, 0x52, 0x57,
		0xc0, 0x1d, 0xef, 0x2d, 0xc0, 0xcd, 0x2c, 0x0d, 0x7b, 0x7e, 0xeb, 0x0f, 0xbc, 0x58, 0xe1, 0x6f,
		0x2a, 0x6f, 0xf7, 0xed, 0xbe, 0xdb, 0x3f, 0x3b, 0x70, 0xda, 0xe7, 0xae, 0xf3, 0x47, 0xd7, 0x42,
		0x9d, 0xbe, 0x66, 0x7d, 0x9a, 0x18, 0x7a, 0x6f, 0x51, 0xf0, 0x86, 0x5f, 0xa6, 0xa8, 0xae, 0xdb,
		0xb3, 0xcc, 0xc3, 0xb7, 0xe6, 0x81, 0xdd, 0xb6, 0x9d, 0x3f, 0xe6, 0xe2, 0xea, 0x23, 0xab, 0x4b,
		0x27, 0x95, 0xe9, 0xa1, 0xb6, 0xef, 0xaa, 0xae, 0xdb, 0xb3, 0x8e, 0xec, 0xf7, 0xee, 0x51, 0xdb,
		0x3c, 0xee, 0x1b, 0xdc, 0x70, 0x94, 0x7a, 0xcb, 0x59, 0x6f, 0x76, 0xf7, 0xbc, 0xe1, 0xf6, 0x4e,
		0xcf, 0x1c, 0xab, 0xe7, 0xda, 0x2d, 0x2a, 0x8e, 0x8a, 0xcb, 0x5b, 0x71, 0x8e, 0x79, 0x4c, 0x99,
		0x51, 0x66, 0x05, 0xc8, 0xac, 0xd9, 0xa0, 0xd0, 0x28, 0xb4, 0x02, 0x66, 0xd0, 0x26, 0x67, 0x50,
		0x2a, 0xae, 0xf0, 0x1a, 0xa1, 0xaf, 0x85, 0xda, 0xa0, 0xaf, 0xe0, 0x82, 0xeb, 0xcc, 0x38, 0xba,
		0x59, 0xf9, 0x53, 0x57, 0xac, 0xf0, 0xa9, 0xac, 0xca, 0x29, 0x0b, 0xba, 0x92, 0xa7, 0x9c, 0x58,
		0xb1, 0x53, 0x50, 0xba, 0xcf, 0x7c, 0x4d, 0xce, 0x7c, 0x54, 0x16, 0x2b, 0x70, 0xaa, 0x4a, 0xa2,
		0xaa, 0xe6, 0xa9, 0xe9, 0xd0, 0xec, 0x72, 0xcd, 0x01, 0xf5, 0x56, 0xaa, 0xee, 0x7a, 0xae, 0xd9,
		0x3e, 0x3e, 0xed, 0xd9, 0xce, 0xdb, 0x13, 0x76, 0xb0, 0xa9, 0xb8, 0x42, 0x14, 0xf7, 0xf0, 0x3b,
		0xb6, 0xb1, 0xcb, 0x7d, 0xb1, 0x8d, 0xcd, 0x21, 0xce, 0xc9, 0x84, 0xca, 0xe2, 0xa4, 0x41, 0x69,
		0x55, 0xa3, 0x9e, 0xef, 0x73, 0xad, 0x37, 0xd5, 0x56, 0xb6, 0xea, 0xda, 0x76, 0xe7, 0x1d, 0x97,
		0x0c, 0x51, 0x6a, 0x05, 0x48, 0xed, 0xac, 0x73, 0x78, 0xda, 0xe9, 0x3b, 0x3d, 0xd3, 0xee, 0x58,
		0x2d, 0xb7, 0xdd, 0xef, 0x52, 0x74, 0x14, 0x5d, 0x21, 0xf9, 0xcd, 0x74, 0x9c, 0x9e, 0x7d, 0x70,
		0xe6, 0x58, 0xb4, 0xb3, 0x50, 0x72, 0xb9, 0x4b, 0x6e, 0xf6, 0xc8, 0xaf, 0x63, 0xd9, 0xc7, 0x6f,
		0x0f, 0x4e, 0x7b, 0xae, 0xd9, 0x6a, 0xf5, 0xac, 0x3e, 0x85, 0x47, 0xe1, 0x15, 0x21, 0xbc, 0x86,
		0x6b, 0x77, 0x1c, 0xab, 0x77, 0x64, 0x1e, 0x5a, 0x54, 0x1e, 0x95, 0x57, 0x18, 0xda, 0x39, 0x76,
		0xdb, 0xfe, 0xaf, 0xd5, 0x72, 0x0f, 0xcc, 0x4e, 0xeb, 0x3f, 0x76, 0xcb, 0x79, 0x4b, 0xd5, 0x51,
		0x75, 0x85, 0xb0, 0x5d, 0xb7, 0x77, 0xea, 0x58, 0x87, 0x8e, 0x7d, 0xda, 0x49, 0x3b, 0x27, 0xd4,
		0x1d, 0x75, 0x97, 0xb3, 0xee, 0x7a, 0x56, 0xdf, 0x6e, 0x9d, 0x99, 0x6d, 0x66, 0x3b, 0xaa, 0xae,
		0x38, 0xd5, 0x9d, 0x98, 0xef, 0xd3, 0x8c, 0x47, 0xd5, 0x51, 0x75, 0xc5, 0x16, 0xb3, 0xac, 0x29,
		0xa8, 0xbc, 0x52, 0xf2, 0x5d, 0xcf, 0xea, 0x5b, 0xbd, 0x73, 0xf3, 0xa0, 0x6d, 0x31, 0xeb, 0x51,
		0x7b, 0x05, 0x57, 0x16, 0xed, 0x53, 0x26, 0x3a, 0x8a, 0xad, 0x20, 0xb1, 0xb5, 0xac, 0xb6, 0xf9,
		0x87, 0x7b, 0x6e, 0xf6, 0x6c, 0x73, 0x5a, 0xcb, 0x52, 0x77, 0xd4, 0x5d, 0xde, 0xba, 0x33, 0x5b,
		0xff, 0x76, 0xdb, 0x66, 0x47, 0x93, 0x3d, 0x1c, 0x28, 0x37, 0xe9, 0x72, 0x3b, 0x37, 0xed, 0x36,
		0x51, 0x8e, 0xb2, 0x2b, 0x3e, 0xcb, 0x31, 0xc3, 0x51, 0x6a, 0x45, 0x54, 0xac, 0x76, 0xe7, 0xa1,
		0x4b, 0x37, 0x03, 0x3a, 0xaa, 0x8e, 0xaa, 0xcb, 0x5b, 0x75, 0x67, 0x9d, 0xb4, 0x4b, 0xc2, 0xa7,
		0xaf, 0xd4, 0x5d, 0x91, 0xba, 0xcb, 0xc4, 0xe6, 0x66, 0xcb, 0x3a, 0x1d, 0xf6, 0x4b, 0x28, 0xbc,
		0xdc, 0x85, 0x67, 0xbd, 0x77, 0xac, 0x4e, 0xcb, 0x6a, 0xb9, 0x66, 0x6b, 0x3a, 0xe3, 0x1e, 0xf7,
		0x4e, 0xcf, 0xb8, 0x94, 0x98, 0xba, 0x2b, 0xa0, 0x92, 0xa0, 0xdc, 0x28, 0xb7, 0xc2, 0xe4, 0x36,
		0x5b, 0xcd, 0xc9, 0x65, 0xc4, 0x14, 0x5e, 0xd1, 0xc2, 0x63, 0xf9, 0x4a, 0xb5, 0x15, 0xa7, 0x36,
		0xc7, 0x72, 0x5b, 0xd6, 0x91, 0x79, 0xd6, 0x76, 0xdc, 0x13, 0xcb, 0xe9, 0xd9, 0x87, 0xdc, 0x88,
		0xa3, 0xdc, 0x17, 0x37, 0xe2, 0xe0, 0x20, 0x5f, 0xeb, 0x54, 0xc2, 0x0d, 0xea, 0x28, 0xa9, 0xf5,
		0x49, 0x4a, 0x23, 0x17, 0x31, 0xc5, 0x25, 0x32, 0x5f, 0xe9, 0xe0, 0x16, 0xa6, 0xb4, 0x04, 0x96,
		0xf3, 0x3a, 0xb9, 0x82, 0x29, 0x30, 0x81, 0x02, 0xd3, 0xca, 0xfd, 0x4b, 0x85, 0x89, 0x43, 0x2f,
		0x8d, 0x5c, 0xbe, 0x54, 0x97, 0x48, 0xf6, 0xd2, 0xc6, 0xcd, 0x4b, 0x7d, 0x49, 0xd3, 0x97, 0x4e,
		0xae, 0x5d, 0xaa, 0x4b, 0x9a, 0xba, 0x74, 0x72, 0xe7, 0x52, 0x5d, 0x22, 0x8b, 0x47, 0xb2, 0x3d,
		0x15, 0x96, 0x6b, 0xfe, 0xd2, 0xcb, 0x6d, 0x4b, 0x8d, 0x89, 0x24, 0x7c, 0x6c, 0x57, 0x2d, 0x45,
		0x25, 0x52, 0x54, 0xda, 0xb8, 0x67, 0xa9, 0x2f, 0x69, 0xfa, 0xd2, 0xc2, 0x25, 0x4b, 0x59, 0x89,
		0x93, 0x95, 0x4e, 0x6e, 0x58, 0xca, 0x4b, 0x62, 0xd6, 0x62, 0xc6, 0xa2, 0xa4, 0xd6, 0x59, 0x21,
		0x6a, 0xe4, 0x6e, 0xa5, 0xba, 0xa4, 0xa9, 0x4b, 0x2f, 0x17, 0x2b, 0xf5, 0x25, 0x4d, 0x5f, 0x9a,
		0xb9, 0x55, 0x29, 0x30, 0x69, 0x02, 0xd3, 0xcb, 0x95, 0x4a, 0x7d, 0xc9, 0x23, 0x7a, 0xca, 0x8a,
		0xb2, 0x5a, 0xbb, 0xac, 0x34, 0x73, 0x99, 0x52, 0x60, 0xd2, 0x04, 0xc6, 0x72, 0x91, 0xaa, 0x5a,
		0xbf, 0xaa, 0x34, 0x72, 0x8d, 0x62, 0xba, 0x45, 0xf1, 0x5c, 0xa2, 0x58, 0xf7, 0x19, 0x27, 0x5a,
		0x8c, 0x48, 0x41, 0x52, 0xb8, 0x61, 0x86, 0xe1, 0x28, 0xf1, 0x12, 0x7f, 0x14, 0x1a, 0xfb, 0x40,
		0xc9, 0xdb, 0x88, 0x07, 0x1f, 0xd5, 0x8d, 0x37, 0xf6, 0x92, 0x8f, 0xd3, 0x74, 0x5d, 0x1f, 0x8d,
		0x55, 0x38, 0x18, 0x85, 0x57, 0xfe, 0x75, 0x2d, 0x54, 0xc9, 0xe7, 0x51, 0xf4, 0xa9, 0xe6, 0x87,
		0x71, 0xe2, 0x85, 0x03, 0x55, 0xff, 0xf6, 0x8d, 0x78, 0xe9, 0x9d, 0xfa, 0x38, 0x1a, 0x25, 0xa3,
		0xc1, 0x28, 0x88, 0xb3, 0xef, 0xea, 0x7e, 0xec, 0xc7, 0xf5, 0x40, 0xdd, 0xaa, 0x60, 0xfe, 0xa5,
		0x1e, 0xf8, 0xe1, 0xa7, 0x5a, 0x9c, 0x78, 0x89, 0xaa, 0x0d, 0xbd, 0xc4, 0xbb, 0xf4, 0x62, 0x55,
		0x0f, 0xe2, 0x71, 0x3d, 0x09, 0x6e, 0xe3, 0xe9, 0x2f, 0xf5, 0x9b, 0xa4, 0x36, 0xfd, 0xa9, 0x5a,
		0xa8, 0xfc, 0xeb, 0x8f, 0x97, 0xa3, 0xa8, 0xe6, 0x25, 0x49, 0xe4, 0x5f, 0x4e, 0x92, 0x69, 0x0c,
		0xe9, 0x5b, 0x71, 0xf6, 0x5d, 0xfd, 0x21, 0x9c, 0x2c, 0x8c, 0x78, 0x72, 0x39, 0xfb, 0xc7, 0xd2,
		0xaf, 0xf5, 0x49, 0xe2, 0x07, 0xfe, 0xff, 0x53, 0xc3, 0xda, 0xa5, 0x17, 0x0e, 0x3f, 0xfb, 0xc3,
		0xe4, 0x63, 0x7d, 0xf6, 0xdf, 0x63, 0xcc, 0x3d, 0xf2, 0xc7, 0xa9, 0xec, 0x08, 0x85, 0x67, 0x10,
		0xb4, 0xcc, 0x51, 0xd1, 0x8c, 0x01, 0x70, 0xb2, 0xbf, 0x11, 0x27, 0xd1, 0x64, 0x90, 0x84, 0x73,
		0xf4, 0xee, 0xa4, 0xb7, 0xda, 0x9e, 0x5f, 0xa2, 0xdb, 0x9d, 0xdf, 0x5f, 0xd7, 0x8e, 0xfd, 0xd8,
		0x6d, 0x4f, 0x6f, 0xac, 0xdb, 0x8e, 0xc7, 0xae, 0x13, 0xdc, 0xba, 0x27, 0xc9, 0xf4, 0xcd, 0xce,
		0xfc, 0x06, 0x99, 0x8b, 0x9b, 0xe7, 0x2e, 0xde, 0x71, 0xb3, 0x7f, 0xa5, 0x3f, 0xbb, 0x41, 0xee,
		0xd9, 0xfc, 0x06, 0x1d, 0x64, 0xf7, 0xe7, 0x17, 0x66, 0x28, 0x7d, 0x22, 0x13, 0x9a, 0x33, 0x8d,
		0x77, 0xea, 0x6e, 0x2a, 0xed, 0xe4, 0x6e, 0xac, 0x84, 0x0e, 0x48, 0xa3, 0xed, 0xc7, 0xc9, 0x74,
		0x00, 0x89, 0x4e, 0xe6, 0xc6, 0x89, 0x1f, 0x5a, 0x81, 0xba, 0x51, 0x61, 0x12, 0x1b, 0xfb, 0x1b,
		0x9b, 0xbf, 0x0b, 0x8e, 0xd4, 0xfb, 0xf2, 0x28, 0xd2, 0xad, 0x37, 0x8d, 0x46, 0x73, 0xb7, 0xd1,
		0xd8, 0xdc, 0x7d, 0xbd, 0xbb, 0xb9, 0xb7, 0xb3, 0xb3, 0xd5, 0xdc, 0xda, 0x11, 0x1c, 0xfc, 0x69,
		0x34, 0x54, 0x91, 0x1a, 0x1e, 0x4c, 0x55, 0x1b, 0x4e, 0x82, 0x80, 0x83, 0x5d, 0x3f, 0x30, 0xaa,
		0x02, 0x10, 0x09, 0xa6, 0x9f, 0x02, 0xa9, 0x47, 0x26, 0xe3, 0xc8, 0x23, 0x08, 0x59, 0x11, 0x09,
		0x4b, 0x6f, 0xd2, 0xd3, 0x9a, 0xd6, 0xe9, 0x4c, 0xd6, 0x08, 0x96, 0x33, 0x4e, 0x04, 0x8d, 0x11,
		0x63, 0x12, 0x0e, 0xd5, 0x95, 0x1f, 0xaa, 0x61, 0x6d, 0xf1, 0xa1, 0x49, 0x1b, 0x26, 0xd9, 0xd3,
		0xad, 0xe5, 0x50, 0x85, 0xe5, 0x9a, 0x77, 0x7e, 0x38, 0x9c, 0x52, 0xb3, 0xb0, 0xb0, 0x0e, 0x67,
		0xf9, 0x44, 0x5e, 0xe1, 0x61, 0x74, 0x23, 0x75, 0xe5, 0x7f, 0x91, 0x99, 0x97, 0x17, 0xa2, 0x1b,
		0x0d, 0x66, 0xb9, 0x50, 0x20, 0x92, 0x19, 0xfd, 0xd1, 0x24, 0x1a, 0x28, 0xb1, 0xb4, 0x6e, 0xbc,
		0x53, 0x77, 0x9f, 0x47, 0xd1, 0x74, 0x44, 0x18, 0xe3, 0xf4, 0x93, 0x16, 0x5a, 0xfa, 0xbc, 0xf5,
		0x62, 0x33, 0xba, 0x9e, 0x4c, 0xab, 0x5e, 0x63, 0x7f, 0x23, 0x89, 0x26, 0x4a, 0x6a, 0x8d, 0xf6,
		0x10, 0x65, 0x26, 0x4c, 0xf2, 0x28, 0x14, 0x8f, 0xb6, 0x7c, 0x99, 0xbd, 0xaa, 0xa5, 0xd9, 0x55,
		0x6e, 0x5e, 0x59, 0xc5, 0x03, 0x52, 0xd3, 0x8b, 0x4c, 0x2c, 0x10, 0x8f, 0x07, 0x08, 0x98, 0x00,
		0x84, 0x0b, 0x28, 0xd8, 0x00, 0x87, 0x0f, 0x70, 0x18, 0x81, 0x85, 0x13, 0x32, 0xb1, 0x42, 0x28,
		0x5e, 0x88, 0xc7, 0x8c, 0x2c, 0xc0, 0x74, 0x49, 0x90, 0xf8, 0x24, 0xb4, 0xc8, 0xeb, 0x69, 0xb8,
		0xc2, 0xc7, 0xb3, 0x6c, 0xd0, 0x80, 0x01, 0x0e, 0x24, 0xf0, 0x00, 0x04, 0x10, 0x34, 0x10, 0x81,
		0x05, 0x12, 0x58, 0x30, 0xc1, 0x04, 0x14, 0xd9, 0xa0, 0x22, 0x1c, 0x58, 0x60, 0xc0, 0x25, 0x0b,
		0x34, 0x50, 0xe1, 0xf5, 0xec, 0xa1, 0x1d, 0x48, 0xf6, 0x5a, 0x4c, 0x10, 0xf3, 0xb8, 0x41, 0x32,
		0xc0, 0x1c, 0x69, 0x36, 0x41, 0xc2, 0x45, 0x41, 0x1b, 0x44, 0xc4, 0x01, 0x46, 0x1d, 0x54, 0xe4,
		0x81, 0x47, 0x1f, 0x78, 0x04, 0xc2, 0x46, 0x21, 0x0c, 0x24, 0x02, 0x41, 0xa3, 0x4c, 0x0a, 0xce,
		0xdd, 0x58, 0x61, 0x66, 0xec, 0x89, 0x1f, 0x26, 0x6f, 0x90, 0xf2, 0xf5, 0x1c, 0x3f, 0x76, 0x80,
		0x42, 0xee, 0x79, 0xe1, 0xf5, 0xf4, 0x66, 0x7f, 0x80, 0xca, 0x6f, 0x78, 0x06, 0x7c, 0xe3, 0xc4,
		0x0f, 0xe1, 0x26, 0x72, 0x50, 0xae, 0x5e, 0x0a, 0xff, 0xdc, 0x0b, 0x26, 0x0a, 0x38, 0xfe, 0xa3,
		0xc8, 0x1b, 0x24, 0xfe, 0x28, 0x6c, 0xf9, 0xd7, 0x7e, 0xea, 0x09, 0xc1, 0xdb, 0x28, 0xe0, 0x77,
		0xc0, 0x21, 0xeb, 0x7d, 0xe1, 0x90, 0x2d, 0x79, 0xc8, 0x6e, 0xef, 0xec, 0x70, 0xd0, 0x12, 0xc4,
		0xf5, 0x8a, 0xf6, 0x82, 0x7b, 0x1b, 0x54, 0x65, 0x52, 0x49, 0xed, 0xb0, 0x70, 0x6d, 0x5f, 0xc1,
		0x26, 0x5e, 0xf0, 0x99, 0x8e, 0x4d, 0xdf, 0x22, 0x75, 0xcc, 0xa6, 0x6f, 0x71, 0xc3, 0x90, 0x4d,
		0xdf, 0x92, 0x2f, 0x80, 0x4d, 0x5f, 0x12, 0xc7, 0x5c, 0x0a, 0x6c, 0xfa, 0x16, 0x8d, 0x1f, 0x6c,
		0xfa, 0xe6, 0xfd, 0x62, 0xd3, 0x97, 0x5c, 0xfd, 0x13, 0xe1, 0xb3, 0xe9, 0xcb, 0xd9, 0xf2, 0x39,
		0x43, 0x96, 0x4d, 0xdf, 0xd2, 0x87, 0x2c, 0x9b, 0xbe, 0x04, 0x71, 0xed, 0xa2, 0x65, 0xd3, 0xb7,
		0x32, 0x93, 0x8a, 0x71, 0x3b, 0x4f, 0x64, 0x60, 0x5d, 0xdf, 0x34, 0x6c, 0xb6, 0x7d, 0xf3, 0x08,
		0x97, 0x6d, 0xdf, 0x02, 0x85, 0xcc, 0xb6, 0x6f, 0x71, 0xc3, 0x90, 0x6d, 0xdf, 0x92, 0x2f, 0x80,
		0x6d, 0x5f, 0x32, 0xc7, 0x5c, 0x0a, 0xb8, 0x6d, 0xdf, 0x4b, 0x3f, 0xf4, 0xa2, 0x3b, 0xc0, 0xbe,
		0xef, 0x1e, 0xb1, 0xbe, 0x02, 0x11, 0xf2, 0x9c, 0x8a, 0xf5, 0xc6, 0xab, 0xe5, 0x3e, 0xa6, 0x4b,
		0x3b, 0x4e, 0x2e, 0xbd, 0x83, 0x70, 0xb4, 0x8d, 0xe0, 0xe3, 0x18, 0x04, 0x6f, 0x93, 0x04, 0xb1,
		0xcc, 0x0b, 0x69, 0x79, 0x17, 0x48, 0x7d, 0xcf, 0xed, 0x49, 0x58, 0xc7, 0x6f, 0x70, 0x7b, 0x12,
		0xd6, 0xeb, 0x9a, 0xd6, 0xe9, 0xc4, 0xf2, 0x4a, 0xd4, 0xe3, 0x8f, 0xf6, 0xfb, 0xf0, 0xae, 0x22,
		0x75, 0x85, 0x90, 0x71, 0x17, 0xfb, 0x97, 0xed, 0x02, 0xc4, 0xda, 0x9d, 0x57, 0x3a, 0xaf, 0x5e,
		0xa5, 0x25, 0x40, 0x7d, 0x46, 0x60, 0xac, 0x03, 0x34, 0x8a, 0x8c, 0xc7, 0xb2, 0x3d, 0x3b, 0x44,
		0x1e, 0xcb, 0xb6, 0xe6, 0x48, 0x79, 0x2c, 0x5b, 0x45, 0x07, 0x3b, 0x8f, 0x65, 0x13, 0xdd, 0xff,
		0xab, 0xfa, 0x51, 0x6d, 0x67, 0x8b, 0xfb, 0xc1, 0x33, 0xdb, 0x70, 0x23, 0xe2, 0x99, 0x6d, 0xcc,
		0x75, 0xcb, 0xb9, 0x8e, 0xa7, 0xb7, 0x49, 0x8e, 0x44, 0xc8, 0x98, 0x5d, 0x14, 0x23, 0xfe, 0x50,
		0xc8, 0x4c, 0x28, 0xb3, 0xf4, 0x90, 0x5b, 0x6a, 0x40, 0x95, 0x16, 0x32, 0x4b, 0x09, 0x29, 0x43,
		0x51, 0xe8, 0xb4, 0xa9, 0xe5, 0x74, 0x29, 0x88, 0xfb, 0x8b, 0xe0, 0x7c, 0x19, 0x2c, 0x50, 0xfe,
		0xcc, 0x5b, 0x6e, 0x04, 0x25, 0x27, 0x1a, 0x69, 0x09, 0x46, 0xa7, 0xc4, 0x52, 0xee, 0x00, 0x2b,
		0x4f, 0xd6, 0x25, 0x4a, 0xda, 0x98, 0x7e, 0x54, 0xc3, 0xd2, 0x95, 0x9c, 0x3d, 0xa8, 0x4b, 0xc3,
		0x29, 0x79, 0x88, 0xcb, 0x58, 0xa3, 0x23, 0x66, 0x0d, 0x8e, 0xa4, 0x35, 0x36, 0x02, 0xd7, 0xd0,
		0x48, 0x5b, 0x23, 0x23, 0x76, 0x0d, 0x8c, 0xd8, 0x35, 0x2e, 0x32, 0xd7, 0xb0, 0x54, 0x1b, 0xb3,
		0xc4, 0xac, 0x31, 0x11, 0xb8, 0x86, 0x44, 0xd2, 0x1a, 0x91, 0xe5, 0x35, 0x20, 0xe9, 0x14, 0x4e,
		0x94, 0x2b, 0xa1, 0x04, 0x96, 0x70, 0x9a, 0xa4, 0xa8, 0xd3, 0x22, 0x85, 0x9c, 0x06, 0x49, 0x94,
		0x23, 0xca, 0x11, 0xe5, 0x88, 0x72, 0xd5, 0x44, 0x39, 0x29, 0xa7, 0x19, 0x0a, 0xe9, 0x75, 0x88,
		0xec, 0x79, 0x08, 0xeb, 0x7d, 0x88, 0x9b, 0x38, 0x25, 0x4e, 0xa0, 0x82, 0x27, 0x52, 0xa9, 0x13,
		0xaa, 0xf8, 0x89, 0x55, 0xfc, 0x04, 0x2b, 0x7b, 0xa2, 0x95, 0x31, 0xe1, 0x0a, 0x99, 0x78, 0xe5,
		0xf5, 0x52, 0x96, 0x32, 0xd6, 0xc4, 0x0f, 0x93, 0xad, 0xa6, 0xa4, 0x84, 0x35, 0x9f, 0xff, 0x9a,
		0x82, 0x42, 0x92, 0xb9, 0xaf, 0xb1, 0xc0, 0x25, 0x89, 0x92, 0xf7, 0x25, 0x16, 0x6e, 0xfc, 0x96,
		0xbe, 0xaf, 0x30, 0xc2, 0x16, 0xa4, 0x02, 0xdd, 0x13, 0xa2, 0xf7, 0xfd, 0x45, 0x19, 0x12, 0x8d,
		0xcd, 0xbd, 0x1d, 0x8e, 0x0a, 0x6c, 0x14, 0x93, 0x17, 0xcd, 0x05, 0x57, 0x93, 0x49, 0xc9, 0x9a,
		0x46, 0x7c, 0x17, 0x27, 0xea, 0x46, 0x64, 0x73, 0xe8, 0x21, 0x34, 0x36, 0x88, 0x9e, 0x0a, 0x87,
		0x0d, 0xa2, 0x9f, 0x10, 0x13, 0x1b, 0x44, 0x3f, 0x2e, 0x73, 0x36, 0x88, 0x5e, 0x18, 0x20, 0x1b,
		0x44, 0x28, 0x15, 0x83, 0xe0, 0x06, 0x91, 0xb4, 0xe9, 0xef, 0xf1, 0x14, 0xb8, 0xf5, 0x46, 0x50,
		0x4c, 0x5d, 0x2f, 0x49, 0x54, 0x14, 0x8a, 0x6b, 0x13, 0x19, 0xff, 0xfb, 0xb0, 0x59, 0xdb, 0x33,
		0x6b, 0x47, 0x5e, 0xed, 0xea, 0xe2, 0xaf, 0xc6, 0xfd, 0x9f, 0x7f, 0xbe, 0xfa, 0xce, 0x1b, 0xff,
		0x92, 0x93, 0x25, 0x2e, 0x24, 0x7d, 0xc0, 0xa7, 0x7d, 0xfb, 0x3d, 0x3f, 0x65, 0x56, 0x62, 0x9a,
		0x46, 0x40, 0x5f, 0xcf, 0x37, 0x35, 0x29, 0xbc, 0xaf, 0x47, 0xc0, 0xae, 0xc0, 0x15, 0x5d, 0x08,
		0x2a, 0xa6, 0x9d, 0x21, 0x8e, 0xe3, 0xe8, 0xed, 0x91, 0xdb, 0xae, 0xe0, 0x82, 0x50, 0xdc, 0xb6,
		0x04, 0x17, 0x84, 0x12, 0xb5, 0xf0, 0xda, 0x0d, 0xf4, 0xf6, 0x7c, 0xb7, 0xa9, 0xf0, 0xb5, 0xb7,
		0xe7, 0x61, 0x1a, 0xaf, 0x2a, 0xd6, 0xfd, 0x52, 0xa1, 0x01, 0xbb, 0xd8, 0xd7, 0x68, 0xb6, 0x40,
		0x79, 0xa3, 0x6c, 0x84, 0x93, 0xb1, 0xa9, 0x91, 0x9c, 0x4d, 0x8c, 0x44, 0x6f, 0x5a, 0x24, 0x63,
		0x93, 0xa2, 0xb2, 0xc6, 0x8d, 0x90, 0x5e, 0x02, 0x7e, 0x0f, 0xc1, 0x28, 0xd5, 0x4e, 0x99, 0xd7,
		0x8e, 0x42, 0xe5, 0x4c, 0x9e, 0xc5, 0x4f, 0x5d, 0xc5, 0xfe, 0x8f, 0x05, 0x0f, 0xf6, 0xb2, 0x07,
		0x39, 0xec, 0xe0, 0x2e, 0x56, 0xfd, 0xc5, 0x69, 0xb0, 0x98, 0xff, 0xa9, 0x20, 0x95, 0x97, 0xa5,
		0x6e, 0x30, 0x55, 0x17, 0x38, 0x3f, 0xad, 0x7f, 0x3e, 0x2a, 0x66, 0x20, 0xe6, 0x3f, 0x2c, 0x0a,
		0x18, 0x12, 0xb3, 0x12, 0x28, 0x2e, 0x6e, 0x28, 0x7c, 0xe5, 0x0d, 0x8d, 0xc3, 0x82, 0x64, 0x56,
		0xf0, 0x6e, 0x09, 0x85, 0x37, 0xc1, 0xcb, 0x68, 0x76, 0x97, 0xd8, 0xd4, 0x2e, 0xab, 0x79, 0x5d,
		0x7a, 0x93, 0xba, 0xf4, 0x66, 0x74, 0xb9, 0x4d, 0x67, 0xbd, 0x40, 0xa4, 0xe8, 0xdd, 0x03, 0x8c,
		0x07, 0x50, 0x2d, 0x7c, 0xe0, 0x2c, 0x72, 0xc5, 0x43, 0x08, 0x05, 0xeb, 0xb6, 0x9c, 0xed, 0x72,
		0x4a, 0x7b, 0x1a, 0x5a, 0xe6, 0xd3, 0x4f, 0x01, 0x4f, 0x3b, 0xcb, 0x7e, 0xba, 0x29, 0xe6, 0x69,
		0xa6, 0x98, 0xa7, 0x97, 0x32, 0x9e, 0x56, 0xea, 0xdd, 0xb7, 0x29, 0x6b, 0x3b, 0x9a, 0x2c, 0xab,
		0x97, 0x37, 0xde, 0xbe, 0x9d, 0x5f, 0xca, 0x1a, 0x6e, 0xe5, 0xee, 0xca, 0x56, 0xfa, 0xe2, 0x1b,
		0x09, 0x8b, 0x6e, 0x04, 0x2d, 0xb6, 0x91, 0xb2, 0xc8, 0x46, 0xdc, 0xe2, 0x1a, 0x71, 0x8b, 0x6a,
		0x64, 0x2d, 0xa6, 0xa9, 0xd6, 0xb3, 0xf8, 0xb2, 0x77, 0x51, 0x33, 0x1e, 0xb6, 0xe9, 0x17, 0xb3,
		0xaa, 0xf4, 0x21, 0x24, 0x6e, 0x33, 0xca, 0x55, 0xa5, 0xe2, 0x27, 0x3a, 0x69, 0x13, 0x9e, 0xd8,
		0x89, 0x4f, 0xec, 0x04, 0x28, 0x73, 0x22, 0x2c, 0x77, 0x42, 0x2c, 0x79, 0x62, 0x14, 0x33, 0x41,
		0x2e, 0x4d, 0x94, 0xf2, 0x36, 0x93, 0x10, 0x76, 0x70, 0x97, 0x90, 0x69, 0x53, 0xdc, 0xf4, 0x29,
		0x71, 0x1a, 0x15, 0x3c, 0x9d, 0x4a, 0x9d, 0x56, 0xc5, 0x4f, 0xaf, 0xe2, 0xa7, 0x59, 0xd9, 0xd3,
		0xad, 0x8c, 0x69, 0x57, 0xc8, 0xf4, 0x2b, 0x6e, 0x1a, 0x7e, 0x98, 0x8e, 0x87, 0xf2, 0x32, 0x42,
		0x36, 0x21, 0x0f, 0xa5, 0xa5, 0x02, 0x99, 0x7b, 0xf2, 0x89, 0x9b, 0x9a, 0x25, 0x4f, 0xd1, 0x00,
		0x53, 0xb5, 0xf4, 0x29, 0x1b, 0x66, 0xea, 0x86, 0x99, 0xc2, 0x31, 0xa6, 0x72, 0x59, 0x53, 0xba,
		0xb0, 0xa9, 0x3d, 0xfb, 0x08, 0xc5, 0x6d, 0x17, 0xb5, 0x94, 0xf1, 0xe4, 0xf8, 0x39, 0x57, 0xd6,
		0xbc, 0xbb, 0x02, 0x63, 0x5b, 0xf2, 0x7b, 0x96, 0x6d, 0xf4, 0x94, 0x3b, 0x2e, 0xef, 0x45, 0x9d,
		0x7d, 0x2e, 0xe1, 0xe0, 0xb7, 0x95, 0x83, 0x51, 0xc2, 0x41, 0x70, 0x2b, 0x87, 0x21, 0x39, 0x97,
		0x9c, 0x4b, 0xce, 0x25, 0xe7, 0x92, 0x73, 0x39, 0xa7, 0x7e, 0xfb, 0x11, 0x4a, 0x6b, 0x65, 0x65,
		0x81, 0x09, 0x6c, 0x69, 0x2d, 0x25, 0x63, 0x71, 0xad, 0xad, 0x6f, 0xa7, 0x7e, 0xa9, 0xc7, 0x4e,
		0x48, 0x45, 0x00, 0x04, 0x14, 0x00, 0x42, 0x02, 0x14, 0x34, 0x80, 0x43, 0x04, 0x38, 0x54, 0xc0,
		0x42, 0x06, 0x99, 0xe8, 0x20, 0x14, 0x21, 0xb2, 0x8f, 0x56, 0x6c, 0xcb, 0x6c, 0x29, 0x63, 0x4e,
		0xfc, 0x30, 0x69, 0x36, 0x24, 0x27, 0xcc, 0xf9, 0xfc, 0xfd, 0x46, 0x70, 0x88, 0x32, 0x8f, 0xec,
		0xfb, 0xf6, 0x25, 0x7b, 0xc2, 0xd9, 0x90, 0x7e, 0xa4, 0x1f, 0x18, 0x58, 0x2e, 0x85, 0x2b, 0xfc,
		0xc8, 0xbf, 0xa5, 0x78, 0x01, 0x0e, 0x3b, 0x03, 0x99, 0x8e, 0xbe, 0x1e, 0x62, 0xde, 0x17, 0x0e,
		0xb1, 0x9c, 0x87, 0x98, 0xac, 0xcd, 0xf9, 0xb4, 0x1f, 0x75, 0xbf, 0x30, 0xba, 0xe7, 0xbc, 0x2e,
		0x7e, 0xe1, 0xfd, 0x02, 0xcd, 0xea, 0xc6, 0x8d, 0x4a, 0x22, 0x7f, 0x20, 0xbf, 0x2d, 0x38, 0x8f,
		0x93, 0xad, 0xc1, 0xe7, 0x84, 0xc7, 0xd6, 0xe0, 0x1a, 0x95, 0xc8, 0xd6, 0xe0, 0xfa, 0x86, 0x0d,
		0x5b, 0x83, 0x39, 0x07, 0xcc, 0xd6, 0xa0, 0xae, 0xb5, 0x18, 0x50, 0x6b, 0xf0, 0xb3, 0x3f, 0x54,
		0x35, 0xd1, 0x13, 0xf8, 0xe3, 0x49, 0x7c, 0x97, 0xfd, 0xc1, 0x17, 0xbe, 0xd8, 0x1f, 0x64, 0xf3,
		0x42, 0xde, 0x1a, 0x39, 0xad, 0x3a, 0x15, 0xec, 0x0f, 0x72, 0x88, 0x4d, 0x87, 0x58, 0x73, 0x77,
		0x77, 0x77, 0x9b, 0x3d, 0xc1, 0xaa, 0x31, 0xa9, 0xfc, 0xe8, 0xd8, 0x13, 0x44, 0x8c, 0x48, 0xda,
		0x4a, 0x4a, 0x61, 0x87, 0xeb, 0x2e, 0xc5, 0x27, 0xf6, 0xd4, 0x81, 0xf0, 0xa9, 0x83, 0x75, 0x1f,
		0xfe, 0xeb, 0xec, 0xbf, 0x14, 0x70, 0xd6, 0xae, 0xdc, 0x11, 0x21, 0xca, 0xab, 0x33, 0xb9, 0x9c,
		0x7e, 0xc2, 0x82, 0xdd, 0x3a, 0xf3, 0x00, 0xe9, 0xd7, 0xf9, 0x91, 0xb0, 0xe8, 0xd7, 0x79, 0x81,
		0xd4, 0xe8, 0xd7, 0x79, 0xfe, 0x70, 0xa0, 0x5f, 0x67, 0xdd, 0x88, 0x42, 0xbf, 0x0e, 0x3a, 0x65,
		0x8a, 0xf5, 0xeb, 0xa4, 0x73, 0xaa, 0xfc, 0x87, 0xf3, 0xf3, 0x38, 0x65, 0x3f, 0x9c, 0xdf, 0xe2,
		0xc3, 0x79, 0xed, 0x90, 0x00, 0x08, 0x0d, 0x50, 0x10, 0x01, 0x0e, 0x15, 0xe0, 0x90, 0x01, 0x0b,
		0x1d, 0x64, 0x22, 0x84, 0x50, 0x94, 0x10, 0x8f, 0x14, 0x59, 0x80, 0xde, 0xf0, 0xff, 0xbc, 0x81,
		0x0a, 0x07, 0x77, 0xb5, 0xd8, 0x1f, 0xc6, 0xf2, 0xb3, 0xd1, 0x22, 0xc1, 0x7f, 0x13, 0xb7, 0xf0,
		0x11, 0x2e, 0x1b, 0x3d, 0x60, 0x10, 0x04, 0x09, 0x45, 0x00, 0x91, 0x04, 0x0d, 0x4d, 0x60, 0x11,
		0x05, 0x16, 0x55, 0x30, 0x91, 0x45, 0x36, 0xba, 0x08, 0x47, 0x18, 0x18, 0x94, 0x79, 0x1a, 0x69,
		0x70, 0x92, 0xd8, 0x93, 0x64, 0x83, 0x92, 0xc8, 0x30, 0x00, 0x07, 0x0e, 0x74, 0x10, 0x81, 0x07,
		0x18, 0x7c, 0x50, 0x01, 0x08, 0x1e, 0x84, 0xe0, 0x81, 0x08, 0x1b, 0x8c, 0x30, 0x00, 0x09, 0x04,
		0x94, 0xe0, 0x80, 0x29, 0x0b, 0x58, 0xe6, 0x3e, 0xb0, 0x3f, 0x3c, 0xcf, 0x48, 0xdc, 0x27, 0x56,
		0x33, 0x70, 0x82, 0x05, 0x28, 0x64, 0x90, 0xd2, 0x00, 0xa8, 0xd0, 0xc1, 0x4a, 0x1b, 0xc0, 0xd2,
		0x06, 0xb4, 0xf4, 0x00, 0x2e, 0x2c, 0xf0, 0x02, 0x03, 0x30, 0x58, 0x10, 0xcb, 0x02, 0xbf, 0x0a,
		0xbc, 0xeb, 0x18, 0x37, 0x59, 0x2e, 0xe6, 0xab, 0xf4, 0x32, 0x40, 0xf3, 0x0b, 0x96, 0x23, 0x4c,
		0x1b, 0x50, 0xd3, 0x01, 0xd8, 0x34, 0x02, 0x37, 0x5d, 0x00, 0x4e, 0x3b, 0x90, 0xd3, 0x0e, 0xe8,
		0xf4, 0x02, 0x3b, 0x4c, 0xc0, 0x03, 0x05, 0xbd, 0x4c, 0x3a, 0xe2, 0xb7, 0x44, 0xf9, 0xe1, 0x19,
		0x43, 0x85, 0x93, 0x1b, 0x15, 0xa5, 0xce, 0x47, 0xe0, 0x59, 0x63, 0xd1, 0xe5, 0x6a, 0x00, 0x5f,
		0x83, 0x15, 0x4e, 0x6e, 0xa6, 0xa2, 0xe2, 0x50, 0x2e, 0xf2, 0xae, 0xb7, 0xfd, 0x38, 0x31, 0x93,
		0x24, 0xc2, 0x1e, 0xce, 0x27, 0x7e, 0x68, 0x05, 0x6a, 0x3a, 0x9b, 0xc5, 0xb8, 0x28, 0xbe, 0x31,
		0xdf, 0xcd, 0xe3, 0xd1, 0x95, 0xe0, 0xee, 0x4b, 0xfb, 0xe4, 0xc5, 0x9d, 0x46, 0x43, 0x15, 0xa9,
		0xe1, 0xc1, 0x9d, 0xb1, 0xbf, 0x11, 0x4e, 0x82, 0xe0, 0x17, 0xa2, 0x06, 0x73, 0xd3, 0xd3, 0x52,
		0xb9, 0x9d, 0xef, 0xbc, 0x02, 0xde, 0x9a, 0x49, 0x2f, 0x83, 0xad, 0x99, 0x32, 0xc2, 0x67, 0x6b,
		0x46, 0xd0, 0x40, 0x60, 0x6b, 0x46, 0xce, 0xb0, 0x66, 0x6b, 0x46, 0xf8, 0x05, 0xb1, 0x35, 0x43,
		0x66, 0x7a, 0xa6, 0x74, 0xf4, 0x69, 0xcd, 0x4c, 0xfc, 0x30, 0x79, 0xbd, 0xad, 0x41, 0x57, 0x66,
		0x17, 0xf8, 0x12, 0x30, 0x36, 0xc2, 0xfd, 0xde, 0x0b, 0x7b, 0xc2, 0xde, 0x40, 0xdb, 0x48, 0x57,
		0xf3, 0xc2, 0x62, 0xe9, 0x72, 0xc0, 0x0e, 0xea, 0xfa, 0xee, 0xf5, 0x00, 0x6e, 0x1f, 0xaa, 0xe9,
		0x74, 0xfe, 0x75, 0x0a, 0xf0, 0xbe, 0x30, 0x05, 0x08, 0x4f, 0x01, 0x8d, 0xed, 0xbd, 0xc6, 0x5e,
		0x73, 0x77, 0x7b, 0x6f, 0x87, 0xb9, 0x80, 0x05, 0x09, 0xa3, 0x7f, 0xfc, 0xba, 0x60, 0xbb, 0x9f,
		0x73, 0xdd, 0x8a, 0x34, 0xf3, 0x59, 0xf9, 0xd7, 0x1f, 0x13, 0xfc, 0x7e, 0xff, 0xfc, 0x3a, 0xd8,
		0xf0, 0x2f, 0x23, 0x7c, 0x36, 0xfc, 0x05, 0x8d, 0x04, 0x36, 0xfc, 0xe5, 0x0c, 0x6b, 0x36, 0xfc,
		0x85, 0x5f, 0x10, 0x1b, 0xfe, 0xa4, 0xa6, 0x67, 0x4a, 0x47, 0xaf, 0x86, 0xff, 0x1b, 0x0d, 0xfa,
		0xfd, 0x3b, 0xec, 0xf7, 0x97, 0xfc, 0x62, 0xbf, 0x9f, 0x75, 0x45, 0x8e, 0x97, 0xc3, 0x7e, 0x3f,
		0x67, 0xf3, 0x22, 0x52, 0x00, 0xfb, 0xfd, 0xe2, 0x53, 0xc0, 0xf6, 0x0e, 0x1b, 0xfd, 0x2c, 0x44,
		0x18, 0xfd, 0x57, 0x2f, 0x36, 0xfa, 0x19, 0x31, 0xfc, 0x94, 0x2c, 0xfd, 0x4c, 0xc4, 0xef, 0xc6,
		0x8f, 0x7f, 0x66, 0x62, 0x7a, 0xd2, 0xdd, 0xfc, 0x6b, 0xfd, 0xeb, 0x1d, 0xe9, 0xbf, 0xfe, 0xad,
		0xc4, 0xf3, 0x15, 0xf5, 0x19, 0xbd, 0x40, 0x23, 0x17, 0xd4, 0x37, 0x04, 0xed, 0x17, 0x02, 0x65,
		0x7b, 0xee, 0xb1, 0x57, 0xa6, 0xd0, 0xb9, 0xc7, 0x5e, 0x79, 0xc3, 0x95, 0x7b, 0xec, 0x49, 0x43,
		0x4d, 0xee, 0xb1, 0x47, 0xa6, 0xf9, 0x67, 0x89, 0xc0, 0x3e, 0xe6, 0xcb, 0x32, 0x7e, 0xa0, 0xbc,
		0xab, 0x48, 0x5d, 0x21, 0x66, 0xfc, 0xc5, 0xf6, 0x2a, 0x80, 0x4e, 0x1e, 0xa3, 0x3b, 0x2f, 0x00,
		0x5f, 0xbd, 0x4a, 0x8b, 0xa4, 0x7a, 0x8a, 0x98, 0x2c, 0x95, 0x2a, 0x1c, 0x29, 0xca, 0x0e, 0xef,
		0xef, 0xd4, 0x1d, 0x5a, 0x51, 0x84, 0xb9, 0xa1, 0x0e, 0xee, 0x06, 0x3a, 0x5a, 0x6d, 0x98, 0x83,
		0xb9, 0x41, 0x0e, 0x4a, 0x36, 0x01, 0x6d, 0xe8, 0x56, 0xaa, 0x91, 0x8b, 0x74, 0x88, 0x51, 0x9c,
		0x44, 0x93, 0x41, 0x12, 0xce, 0xf1, 0xb6, 0x93, 0xde, 0x68, 0x7b, 0x7e, 0xd1, 0x6e, 0x77, 0x7e,
		0x77, 0x5d, 0x3b, 0xf6, 0x63, 0xb7, 0x3d, 0xbd, 0xad, 0x6e, 0x3b, 0x1e, 0xbb, 0x4e, 0x70, 0xeb,
		0x9e, 0x24, 0x76, 0x1c, 0xba, 0x9d, 0xf9, 0x2d, 0x73, 0xb3, 0x9f, 0xe9, 0xcf, 0x6e, 0x90, 0x6b,
		0x2e, 0xee, 0x48, 0xdf, 0x1f, 0x62, 0x80, 0xda, 0x3d, 0xcf, 0x26, 0xd4, 0x39, 0x85, 0xa2, 0xa5,
		0x4e, 0xcd, 0x53, 0xa6, 0xec, 0x9c, 0x20, 0x77, 0xa4, 0x09, 0x1e, 0x65, 0x86, 0x37, 0xbc, 0xf1,
		0xc3, 0xda, 0x75, 0x34, 0x9a, 0x8c, 0x91, 0x0e, 0x09, 0x7f, 0x08, 0x9a, 0x27, 0x84, 0xaf, 0x23,
		0x4c, 0x9e, 0x10, 0x9e, 0xa3, 0x5c, 0x79, 0x42, 0x78, 0x9e, 0x9d, 0x1a, 0x9e, 0x10, 0x5e, 0x2c,
		0x92, 0xf1, 0x84, 0xf0, 0xaa, 0x51, 0x38, 0xcc, 0x09, 0xe1, 0x58, 0x07, 0x5d, 0x42, 0x1e, 0x70,
		0xc9, 0x13, 0xc1, 0x09, 0x38, 0x1a, 0x80, 0x0e, 0x2a, 0xf0, 0xc0, 0x83, 0x0f, 0x3c, 0x00, 0x61,
		0x83, 0x10, 0x06, 0x10, 0x81, 0x80, 0x11, 0x1c, 0x20, 0x65, 0x01, 0x23, 0x75, 0x7d, 0x56, 0xce,
		0x36, 0x38, 0x5d, 0xa0, 0x55, 0x10, 0xc5, 0x95, 0xcb, 0x84, 0x2a, 0x8d, 0xe1, 0x0a, 0x1d, 0xb2,
		0xb4, 0x81, 0x2d, 0x6d, 0xa0, 0x4b, 0x0f, 0xf8, 0xc2, 0x82, 0x30, 0x30, 0x18, 0xcb, 0x24, 0x82,
		0xbf, 0x72, 0x19, 0xf6, 0x24, 0x02, 0xe0, 0x13, 0x08, 0xc0, 0x77, 0x22, 0xc2, 0x3e, 0x4b, 0x51,
		0x83, 0x2d, 0x0f, 0xb5, 0xd8, 0x6e, 0x44, 0x97, 0x9d, 0x86, 0x74, 0xda, 0x5c, 0xe4, 0x1e, 0xfb,
		0x70, 0x51, 0x0e, 0x6d, 0x61, 0x43, 0x5b, 0x97, 0x13, 0x03, 0xb4, 0x1a, 0xe3, 0xdc, 0xc0, 0xa6,
		0x90, 0xd7, 0x05, 0x0b, 0xaf, 0x1c, 0x07, 0x24, 0xf4, 0xd1, 0xde, 0xf8, 0x47, 0x7a, 0x6b, 0x79,
		0x94, 0x37, 0xf6, 0x11, 0xde, 0xf4, 0x91, 0x56, 0x32, 0x23, 0xd2, 0xf9, 0x25, 0xc6, 0xc6, 0x90,
		0x3d, 0x29, 0x44, 0xda, 0xb1, 0x8b, 0xee, 0x26, 0xad, 0xd3, 0x04, 0xdd, 0x4d, 0x72, 0xd2, 0x02,
		0xc2, 0xda, 0xfc, 0x1c, 0x7d, 0x9f, 0x37, 0x7e, 0x78, 0x3c, 0xbb, 0x0d, 0x74, 0x78, 0xe9, 0x96,
		0x69, 0x0c, 0xef, 0xd6, 0xf3, 0x03, 0xef, 0x32, 0x50, 0xb5, 0x4b, 0x2f, 0x1c, 0x7e, 0xf6, 0x87,
		0xb3, 0xe1, 0x8b, 0xe2, 0xf4, 0x7a, 0x22, 0x78, 0x3a, 0xbe, 0xd6, 0x11, 0x26, 0x1d, 0x5f, 0x39,
		0xca, 0x96, 0x8e, 0xaf, 0xfc, 0x86, 0x17, 0x1d, 0x5f, 0x45, 0x63, 0x2a, 0x1d, 0x5f, 0x55, 0xab,
		0x4c, 0xe8, 0xf8, 0xca, 0x77, 0x7e, 0xa0, 0xe3, 0x8b, 0x60, 0x83, 0x08, 0x38, 0xc0, 0xa0, 0x83,
		0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8, 0x20, 0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07,
		0x48, 0x59, 0xc0, 0x38, 0xbd, 0x9f, 0x95, 0x73, 0x0d, 0x4a, 0x07, 0x68, 0x15, 0x40, 0xd1, 0xed,
		0x45, 0xa0, 0xd2, 0x18, 0xac, 0xd0, 0x01, 0x4b, 0x1b, 0xd0, 0xd2, 0x06, 0xb8, 0xf4, 0x00, 0x2f,
		0x2c, 0x00, 0x03, 0x03, 0xb1, 0x4c, 0x22, 0xf8, 0x6e, 0x2f, 0x5f, 0x29, 0x75, 0x15, 0x8c, 0x3c,
		0x6c, 0xcb, 0xd7, 0x1e, 0x60, 0xe8, 0x6d, 0x15, 0x5e, 0xcf, 0xc0, 0x98, 0x9e, 0xaf, 0x82, 0xef,
		0x3c, 0x3d, 0x5f, 0x72, 0x2e, 0x23, 0x33, 0x86, 0xd0, 0x0f, 0xc2, 0x49, 0x78, 0x0d, 0x43, 0x9b,
		0x9e, 0x2f, 0x0e, 0x6d, 0x0e, 0x6d, 0x3d, 0xaa, 0x01, 0xdc, 0xa8, 0x2f, 0x68, 0x14, 0xa9, 0xfa,
		0xd4, 0x64, 0x24, 0x88, 0xb5, 0x61, 0x56, 0x17, 0xce, 0xa2, 0x67, 0xc7, 0xbb, 0x88, 0xb0, 0xd9,
		0xf1, 0x2e, 0x51, 0xe7, 0xec, 0x78, 0x97, 0x37, 0x5c, 0xd9, 0xf1, 0x16, 0x76, 0x21, 0xec, 0x78,
		0x93, 0x68, 0xbe, 0x23, 0x11, 0x0d, 0x3a, 0xde, 0x43, 0x15, 0x26, 0x7e, 0x72, 0x07, 0x7e, 0x3a,
		0x33, 0xa2, 0x9d, 0xde, 0x9e, 0xdf, 0xfa, 0x03, 0x2f, 0x06, 0x9e, 0xb7, 0x16, 0x42, 0xb2, 0xfb,
		0x76, 0xdf, 0xed, 0x9f, 0x1d, 0x38, 0xed, 0x73, 0xd7, 0xf9, 0xa3, 0x6b, 0xa1, 0x4e, 0x5f, 0xb3,
		0x3e, 0x4d, 0x0c, 0xfb, 0x20, 0x62, 0x03, 0xfa, 0x61, 0xc4, 0xd7, 0x8a, 0xea, 0xba, 0x3d, 0xcb,
		0x3c, 0x7c, 0x6b, 0x1e, 0xd8, 0x6d, 0xdb, 0xf9, 0x63, 0x2e, 0xae, 0x3e, 0xb2, 0xba, 0x74, 0x52,
		0x99, 0x1e, 0x6a, 0xfb, 0xae, 0xea, 0xba, 0x3d, 0xeb, 0xc8, 0x7e, 0xef, 0x1e, 0xb5, 0xcd, 0xe3,
		0xbe, 0x01, 0x7f, 0xa9, 0xf7, 0xbf, 0x53, 0x6f, 0xb2, 0xf5, 0x66, 0x77, 0xcf, 0x1b, 0x6e, 0xef,
		0xf4, 0xcc, 0xb1, 0x7a, 0xae, 0xdd, 0xa2, 0xe2, 0xa8, 0xb8, 0xbc, 0x15, 0xe7, 0x98, 0xc7, 0x94,
		0x19, 0x65, 0x56, 0x80, 0xcc, 0x9a, 0x0d, 0x0a, 0x8d, 0x42, 0x2b, 0x60, 0x06, 0x6d, 0x72, 0x06,
		0xa5, 0xe2, 0x0a, 0xaf, 0x11, 0xfa, 0x5a, 0xa8, 0x0d, 0xfa, 0x0a, 0x2e, 0xb8, 0xce, 0x8c, 0xa3,
		0x9b, 0x95, 0x3f, 0x75, 0xc5, 0x0a, 0x9f, 0xca, 0xaa, 0x9c, 0xb2, 0xa0, 0x2b, 0x79, 0xca, 0x89,
		0x15, 0x3b, 0x05, 0xa5, 0xfb, 0xcc, 0xd7, 0xe4, 0xcc, 0x47, 0x65, 0xb1, 0x02, 0xa7, 0xaa, 0x24,
		0xaa, 0x6a, 0x9e, 0x9a, 0x0e, 0xcd, 0x2e, 0xd7, 0x1c, 0x50, 0x6f, 0xa5, 0xea, 0xae, 0xe7, 0x9a,
		0xed, 0xe3, 0xd3, 0x9e, 0xed, 0xbc, 0x3d, 0x61, 0x07, 0x9b, 0x8a, 0x2b, 0x44, 0x71, 0x0f, 0xbf,
		0x63, 0x1b, 0xbb, 0xdc, 0x17, 0xdb, 0xd8, 0x1c, 0xe2, 0x9c, 0x4c, 0xa8, 0x2c, 0x4e, 0x1a, 0x94,
		0x56, 0x35, 0xea, 0xf9, 0x3e, 0xd7, 0x7a, 0x53, 0x6d, 0x65, 0xab, 0xae, 0x6d, 0x77, 0xde, 0x71,
		0xc9, 0x10, 0xa5, 0x56, 0x80, 0xd4, 0xce, 0x3a, 0x87, 0xa7, 0x9d, 0xbe, 0xd3, 0x33, 0xed, 0x8e,
		0xd5, 0x72, 0xdb, 0xfd, 0x2e, 0x45, 0x47, 0xd1, 0x15, 0x92, 0xdf, 0x4c, 0xc7, 0xe9, 0xd9, 0x07,
		0x67, 0x8e, 0x45, 0x3b, 0x0b, 0x25, 0x97, 0xbb, 0xe4, 0x66, 0x8f, 0xfc, 0x3a, 0x96, 0x7d, 0xfc,
		0xf6, 0xe0, 0xb4, 0xe7, 0x9a, 0xad, 0x56, 0xcf, 0xea, 0x53, 0x78, 0x14, 0x5e, 0x11, 0xc2, 0x6b,
		0xb8, 0x76, 0xc7, 0xb1, 0x7a, 0x47, 0xe6, 0xa1, 0x45, 0xe5, 0x51, 0x79, 0x85, 0xa1, 0x9d, 0x63,
		0xb7, 0xed, 0xff, 0x5a, 0x2d, 0xf7, 0xc0, 0xec, 0xb4, 0xfe, 0x63, 0xb7, 0x9c, 0xb7, 0x54, 0x1d,
		0x55, 0x57, 0x08, 0xdb, 0x75, 0x7b, 0xa7, 0x8e, 0x75, 0xe8, 0xd8, 0xa7, 0x9d, 0xb4, 0x73, 0x42,
		0xdd, 0x51, 0x77, 0x39, 0xeb, 0xae, 0x67, 0xf5, 0xed, 0xd6, 0x99, 0xd9, 0x66, 0xb6, 0xa3, 0xea,
		0x8a, 0x53, 0xdd, 0x89, 0xf9, 0x3e, 0xcd, 0x78, 0x54, 0x1d, 0x55, 0x57, 0x6c, 0x31, 0xcb, 0x9a,
		0x82, 0xca, 0x2b, 0x25, 0xdf, 0xf5, 0xac, 0xbe, 0xd5, 0x3b, 0x37, 0x0f, 0xda, 0x16, 0xb3, 0x1e,
		0xb5, 0x57, 0x70, 0x65, 0xd1, 0x3e, 0x65, 0xa2, 0xa3, 0xd8, 0x0a, 0x12, 0x5b, 0xcb, 0x6a, 0x9b,
		0x7f, 0xb8, 0xe7, 0x66, 0xcf, 0x36, 0xa7, 0xb5, 0x2c, 0x75, 0x47, 0xdd, 0xe5, 0xad, 0x3b, 0xb3,
		0xf5, 0x6f, 0xb7, 0x6d, 0x76, 0x34, 0xd9, 0xc3, 0x81, 0x72, 0x93, 0x2e, 0xb7, 0x73, 0xd3, 0x6e,
		0x13, 0xe5, 0x28, 0xbb, 0xe2, 0xb3, 0x1c, 0x33, 0x1c, 0xa5, 0x56, 0x44, 0xc5, 0x6a, 0x77, 0x1e,
		0xba, 0x74, 0x33, 0xa0, 0xa3, 0xea, 0xa8, 0xba, 0xbc, 0x55, 0x77, 0xd6, 0x49, 0xbb, 0x24, 0x7c,
		0xfa, 0x4a, 0xdd, 0x15, 0xa9, 0xbb, 0x4c, 0x6c, 0x6e, 0xb6, 0xac, 0xd3, 0x61, 0xbf, 0x84, 0xc2,
		0xcb, 0x5d, 0x78, 0xd6, 0x7b, 0xc7, 0xea, 0xb4, 0xac, 0x96, 0x6b, 0xb6, 0xa6, 0x33, 0xee, 0x71,
		0xef, 0xf4, 0x8c, 0x4b, 0x89, 0xa9, 0xbb, 0x02, 0x2a, 0x09, 0xca, 0x8d, 0x72, 0x2b, 0x4c, 0x6e,
		0xb3, 0xd5, 0x9c, 0x5c, 0x46, 0x4c, 0xe1, 0x15, 0x2d, 0x3c, 0x96, 0xaf, 0x54, 0x5b, 0x71, 0x6a,
		0x73, 0x2c, 0xb7, 0x65, 0x1d, 0x99, 0x67, 0x6d, 0xc7, 0x3d, 0xb1, 0x9c, 0x9e, 0x7d, 0xc8, 0x8d,
		0x38, 0xca, 0x7d, 0x71, 0x23, 0x0e, 0x0e, 0xf2, 0xb5, 0x4e, 0x25, 0xdc, 0xa0, 0x8e, 0x92, 0x5a,
		0x9f, 0xa4, 0x34, 0x72, 0x11, 0x53, 0x5c, 0x22, 0xf3, 0x95, 0x0e, 0x6e, 0x61, 0x4a, 0x4b, 0x60,
		0x39, 0xaf, 0x93, 0x2b, 0x98, 0x02, 0x13, 0x28, 0x30, 0xad, 0xdc, 0xbf, 0x54, 0x98, 0x38, 0xf4,
		0xd2, 0xc8, 0xe5, 0x4b, 0x75, 0x89, 0x64, 0x2f, 0x6d, 0xdc, 0xbc, 0xd4, 0x97, 0x34, 0x7d, 0xe9,
		0xe4, 0xda, 0xa5, 0xba, 0xa4, 0xa9, 0x4b, 0x27, 0x77, 0x2e, 0xd5, 0x25, 0xb2, 0x78, 0x24, 0xdb,
		0x53, 0x61, 0xb9, 0xe6, 0x2f, 0xbd, 0xdc, 0xb6, 0xd4, 0x98, 0x48, 0xc2, 0xc7, 0x76, 0xd5, 0x52,
		0x54, 0x22, 0x45, 0xa5, 0x8d, 0x7b, 0x96, 0xfa, 0x92, 0xa6, 0x2f, 0x2d, 0x5c, 0xb2, 0x94, 0x95,
		0x38, 0x59, 0xe9, 0xe4, 0x86, 0xa5, 0xbc, 0x24, 0x66, 0x2d, 0x66, 0x2c, 0x4a, 0x6a, 0x9d, 0x15,
		0xa2, 0x46, 0xee, 0x56, 0xaa, 0x4b, 0x9a, 0xba, 0xf4, 0x72, 0xb1, 0x52, 0x5f, 0xd2, 0xf4, 0xa5,
		0x99, 0x5b, 0x95, 0x02, 0x93, 0x26, 0x30, 0xbd, 0x5c, 0xa9, 0xd4, 0x97, 0x3c, 0xa2, 0xa7, 0xac,
		0x28, 0xab, 0xb5, 0xcb, 0x4a, 0x33, 0x97, 0x29, 0x05, 0x26, 0x4d, 0x60, 0x2c, 0x17, 0xa9, 0xaa,
		0xf5, 0xab, 0x4a, 0x23, 0xd7, 0x28, 0xa6, 0x5b, 0x14, 0xcf, 0x25, 0x8a, 0x75, 0x9f, 0x71, 0xa2,
		0xc5, 0x88, 0x14, 0x24, 0x85, 0x1b, 0x66, 0x18, 0x8e, 0x12, 0x2f, 0xf1, 0x47, 0xa1, 0xb1, 0x0f,
		0x94, 0xbc, 0x8d, 0x78, 0xf0, 0x51, 0xdd, 0x78, 0x63, 0x2f, 0xf9, 0x38, 0x4d, 0xd7, 0xf5, 0xd1,
		0x58, 0x85, 0x83, 0x51, 0x78, 0xe5, 0x5f, 0xd7, 0x42, 0x95, 0x7c, 0x1e, 0x45, 0x9f, 0x6a, 0x7e,
		0x18, 0x27, 0x5e, 0x38, 0x50, 0xf5, 0x6f, 0xdf, 0x88, 0x97, 0xde, 0xa9, 0x8f, 0xa3, 0x51, 0x32,
		0x1a, 0x8c, 0x82, 0x38, 0xfb, 0xae, 0xee, 0xc7, 0x7e, 0x5c, 0x0f, 0xd4, 0xad, 0x0a, 0xe6, 0x5f,
		0xea, 0x81, 0x1f, 0x7e, 0xaa, 0xc5, 0x89, 0x97, 0xa8, 0xda, 0xd0, 0x4b, 0xbc, 0x4b, 0x2f, 0x56,
		0xf5, 0x20, 0x1e, 0xd7, 0x93, 0xe0, 0x36, 0x9e, 0xfe, 0x52, 0xbf, 0x49, 0x6a, 0x7e, 0x1c, 0xd6,
		0x43, 0xe5, 0x5f, 0x7f, 0xbc, 0x1c, 0x45, 0x71, 0xf6, 0x5d, 0xfd, 0xe1, 0xbf, 0xce, 0xfe, 0xcb,
		0x78, 0x72, 0x39, 0xfb, 0xc1, 0xf4, 0x6b, 0xdd, 0xbb, 0xf5, 0xfc, 0xc0, 0xbb, 0x0c, 0x54, 0xed,
		0xd2, 0x0b, 0x87, 0x9f, 0xfd, 0x61, 0xf2, 0xb1, 0x3e, 0xfb, 0xbf, 0x30, 0x26, 0x1a, 0xf9, 0x83,
		0x52, 0x76, 0x84, 0xc2, 0xd3, 0x05, 0x5a, 0x9a, 0xa8, 0x42, 0x7a, 0x00, 0x38, 0xb3, 0xdf, 0x88,
		0x93, 0x68, 0x32, 0x48, 0xc2, 0x39, 0x54, 0x77, 0xd2, 0xfb, 0x6a, 0xcf, 0xaf, 0xd1, 0xed, 0xce,
		0x6f, 0xa6, 0x6b, 0xc7, 0x7e, 0xec, 0xb6, 0xa7, 0x77, 0xd1, 0x6d, 0xc7, 0x63, 0xd7, 0x09, 0x6e,
		0xdd, 0x93, 0xc4, 0x8e, 0x43, 0xb7, 0x33, 0xbf, 0x43, 0x6e, 0xf6, 0x33, 0xfd, 0xd9, 0xfd, 0x70,
		0xcd, 0xc5, 0xfd, 0x38, 0xc8, 0x6e, 0xc7, 0x2f, 0xcc, 0x3e, 0x9a, 0x65, 0x1e, 0x23, 0xd3, 0x7a,
		0x6d, 0x30, 0x0a, 0xe3, 0x24, 0xf2, 0xfc, 0x30, 0x89, 0xc5, 0x27, 0xa0, 0xac, 0x88, 0x7c, 0x3a,
		0x7c, 0xe1, 0x99, 0xfe, 0x9d, 0x1f, 0x0e, 0x8d, 0xfd, 0x8d, 0x2d, 0xe1, 0x61, 0x1e, 0xce, 0xb2,
		0xb9, 0xb1, 0xbf, 0xb1, 0x29, 0x3c, 0xd0, 0x6e, 0xa4, 0xae, 0xfc, 0x2f, 0x18, 0xb3, 0xe6, 0x42,
		0xb8, 0xa3, 0x41, 0x6d, 0x3a, 0xbf, 0x21, 0xcc, 0x30, 0xfd, 0xd1, 0x24, 0x1a, 0x28, 0x98, 0xda,
		0xc5, 0x78, 0xa7, 0xee, 0x3e, 0x8f, 0xa2, 0xe9, 0x08, 0x33, 0xc6, 0xa9, 0x32, 0x40, 0x0a, 0xc5,
		0xb7, 0x5e, 0x6c, 0x46, 0xd7, 0x93, 0x1b, 0x15, 0x26, 0xc6, 0xfe, 0x46, 0x12, 0x4d, 0x14, 0x4a,
		0x85, 0xfb, 0x10, 0x75, 0x26, 0x6c, 0x56, 0x2b, 0x5a, 0x57, 0x2b, 0x2d, 0x3f, 0xc2, 0x48, 0xb8,
		0x4f, 0x11, 0x02, 0x4e, 0x2e, 0xfb, 0x27, 0xce, 0x41, 0x49, 0x6b, 0x18, 0xb8, 0x03, 0x87, 0x3d,
		0x88, 0xf8, 0x03, 0x8c, 0x41, 0xa8, 0x38, 0x04, 0x8f, 0x45, 0xf0, 0x78, 0x84, 0x8d, 0x49, 0x18,
		0xb8, 0x04, 0x82, 0x4d, 0x70, 0xf8, 0x94, 0x05, 0x8c, 0xd4, 0x1d, 0x5a, 0x39, 0xdb, 0xe0, 0xf4,
		0x88, 0xc0, 0x21, 0x0a, 0x16, 0xa6, 0x90, 0xa1, 0x4a, 0x03, 0xb8, 0x42, 0x87, 0x2c, 0x6d, 0x60,
		0x4b, 0x1b, 0xe8, 0xd2, 0x03, 0xbe, 0xb0, 0x20, 0x0c, 0x0c, 0xc6, 0x60, 0xa1, 0xec, 0x09, 0x38,
		0xc3, 0xcd, 0x98, 0xcb, 0x8c, 0x86, 0x9a, 0x32, 0x31, 0x51, 0x0d, 0x1e, 0xd9, 0x74, 0x40, 0x37,
		0x8d, 0x10, 0x4e, 0x17, 0x94, 0xd3, 0x0e, 0xe9, 0xb4, 0x43, 0x3b, 0xbd, 0x10, 0x0f, 0x13, 0xf5,
		0x40, 0x91, 0x0f, 0x1e, 0xfd, 0x9e, 0x40, 0xc0, 0x9a, 0x3f, 0xc4, 0x4f, 0xb6, 0xcb, 0x34, 0x38,
		0xbd, 0x2c, 0xf0, 0xfc, 0x34, 0x07, 0xc3, 0x4d, 0xf0, 0xcb, 0x40, 0x07, 0x44, 0x9d, 0x40, 0x51,
		0x43, 0x60, 0xd4, 0x0d, 0x1c, 0xb5, 0x05, 0x48, 0x6d, 0x41, 0x52, 0x4f, 0xa0, 0xc4, 0x06, 0x4b,
		0x70, 0xc0, 0xcc, 0x24, 0xe5, 0xdc, 0x8d, 0x95, 0x5e, 0x33, 0x4e, 0xa0, 0xbc, 0xab, 0x48, 0x5d,
		0xe9, 0x30, 0xe3, 0x2c, 0x3a, 0x77, 0xbb, 0x1a, 0x5c, 0x4b, 0x77, 0x6e, 0xcc, 0x7a, 0xf5, 0x2a,
		0x35, 0x39, 0xd6, 0xbf, 0x46, 0xe9, 0x5f, 0x98, 0xc2, 0x98, 0xbe, 0x7e, 0x4e, 0x51, 0xa9, 0x57,
		0x56, 0x9b, 0xd2, 0x32, 0xbd, 0x1c, 0x3d, 0x4a, 0xca, 0x2d, 0x96, 0x94, 0x2c, 0x29, 0x59, 0x52,
		0xb2, 0xa4, 0x64, 0x49, 0xc9, 0x92, 0x92, 0x3c, 0x56, 0xad, 0x92, 0x12, 0xfd, 0xd9, 0x45, 0x76,
		0x21, 0x0f, 0xfb, 0x2e, 0x68, 0x93, 0xa0, 0x97, 0xfc, 0x5b, 0xba, 0x24, 0x68, 0x3d, 0x9e, 0x65,
		0x68, 0x07, 0xa0, 0x3a, 0x82, 0xa8, 0xc6, 0x40, 0xaa, 0x2b, 0x98, 0x6a, 0x0f, 0xa8, 0xda, 0x83,
		0xaa, 0xde, 0xc0, 0xaa, 0x07, 0xb8, 0x6a, 0x02, 0xb0, 0x99, 0xd4, 0xb4, 0x79, 0x36, 0xb2, 0x34,
		0x63, 0xf9, 0x4a, 0xa9, 0xab, 0x60, 0xe4, 0x25, 0xaf, 0xb7, 0x75, 0x9a, 0xb5, 0xe6, 0x10, 0xb8,
		0xa7, 0xd1, 0x25, 0xb5, 0x55, 0x78, 0x3d, 0x2b, 0x40, 0x3e, 0x68, 0x95, 0xc6, 0xf5, 0xc2, 0x8a,
		0xd9, 0x27, 0x75, 0xe2, 0x87, 0xda, 0xf1, 0x92, 0xa6, 0xe5, 0xd5, 0xd2, 0xe5, 0x9d, 0x7b, 0xc1,
		0x64, 0x9a, 0x18, 0x1b, 0x9a, 0x5e, 0xdf, 0x51, 0xe4, 0x0d, 0x12, 0x7f, 0x14, 0xb6, 0xfc, 0x6b,
		0x7f, 0x66, 0x98, 0xde, 0xd4, 0xee, 0x3a, 0xef, 0x7f, 0xd7, 0x30, 0xa5, 0x78, 0x5f, 0x98, 0x52,
		0x98, 0x52, 0x98, 0x52, 0x58, 0x8d, 0xf1, 0x6a, 0x1e, 0x5e, 0x17, 0xbf, 0xf0, 0xf3, 0xe0, 0x94,
		0xbb, 0x9e, 0x34, 0xa6, 0x97, 0x4f, 0x65, 0xa9, 0xd0, 0xd7, 0xc9, 0xaf, 0xa2, 0x29, 0x39, 0xf0,
		0x59, 0x0f, 0xd2, 0x80, 0xe2, 0xb3, 0x1e, 0x9c, 0x34, 0xc1, 0x67, 0x3d, 0xe0, 0x17, 0xc8, 0x67,
		0x3d, 0x64, 0xc0, 0x82, 0xa4, 0xa6, 0xef, 0xb3, 0x9e, 0x89, 0x1f, 0xea, 0xf9, 0x98, 0x67, 0x57,
		0xa3, 0x4b, 0xea, 0x79, 0xe1, 0xb5, 0xe2, 0x53, 0x1e, 0xf9, 0x1f, 0x14, 0x9f, 0xf2, 0xe0, 0x5e,
		0xde, 0xa2, 0x25, 0xbb, 0xc9, 0x96, 0x2c, 0x71, 0x43, 0x50, 0x4a, 0xe1, 0x53, 0x1e, 0xf8, 0x94,
		0xd2, 0xd8, 0xde, 0x6b, 0xec, 0x35, 0x77, 0xb7, 0xf7, 0x76, 0x98, 0x5b, 0x58, 0x90, 0xf1, 0x6a,
		0xd6, 0xf9, 0xe2, 0xe3, 0x1e, 0x5e, 0x41, 0xe5, 0xc9, 0x01, 0xf5, 0xd4, 0xee, 0x95, 0xd7, 0xa3,
		0xdb, 0x71, 0xbd, 0x4f, 0x9e, 0xfc, 0xf9, 0xe4, 0xbb, 0xf5, 0xc7, 0x7f, 0xe1, 0xd1, 0xdb, 0x40,
		0x67, 0x7f, 0xeb, 0x97, 0x22, 0xb8, 0xbd, 0x65, 0xa1, 0x55, 0x81, 0xba, 0xd3, 0xe5, 0xe9, 0xb4,
		0xd1, 0xf6, 0xe3, 0xc4, 0x4c, 0x12, 0xf0, 0xfd, 0x3a, 0x4f, 0xfc, 0xd0, 0x0a, 0xd4, 0x8d, 0x4a,
		0xcf, 0xd3, 0x01, 0x2e, 0xd7, 0xa6, 0xe5, 0xf4, 0xa3, 0x2b, 0xd9, 0x7a, 0xd3, 0x68, 0x34, 0x77,
		0x1b, 0x8d, 0xcd, 0xdd, 0xd7, 0xbb, 0x9b, 0x7b, 0x3b, 0x3b, 0x5b, 0xcd, 0x2d, 0xe0, 0x12, 0xcd,
		0x38, 0x8d, 0x86, 0x2a, 0x52, 0xc3, 0x83, 0xe9, 0xf0, 0x09, 0x27, 0x41, 0xc0, 0xac, 0x45, 0x04,
		0x23, 0x7a, 0xbd, 0x14, 0xbd, 0x0c, 0xe8, 0x5d, 0xb0, 0xa2, 0xc9, 0x20, 0x09, 0xe7, 0x0f, 0xfb,
		0x3a, 0xe9, 0xa7, 0x63, 0xcf, 0xef, 0x94, 0xdb, 0x9d, 0x7f, 0x24, 0xae, 0x1d, 0xfb, 0xb1, 0xdb,
		0x9e, 0x7e, 0x16, 0x6e, 0x3b, 0x1e, 0xbb, 0x4e, 0x70, 0xeb, 0x9e, 0x24, 0x76, 0x1c, 0xba, 0x9d,
		0xf9, 0x7d, 0x76, 0xb3, 0x9f, 0xe9, 0xcf, 0xee, 0xaa, 0x7b, 0xb0, 0xb8, 0x7f, 0x87, 0xd9, 0x7d,
		0x72, 0x1f, 0xbe, 0xc5, 0xe4, 0xd4, 0x7b, 0x9e, 0xb0, 0xc3, 0xcc, 0xae, 0x4f, 0x46, 0x67, 0x26,
		0x4f, 0xcf, 0x4e, 0xfc, 0x85, 0x23, 0xba, 0xe2, 0xa3, 0xd9, 0xb8, 0x19, 0x0d, 0x55, 0x80, 0xb8,
		0x84, 0x3b, 0x5b, 0xa7, 0x93, 0x5d, 0x01, 0xe6, 0x49, 0xa0, 0x9b, 0x3c, 0x09, 0xb4, 0x98, 0xc0,
		0x79, 0x12, 0x68, 0xa9, 0x97, 0xc0, 0x93, 0x40, 0x85, 0x5c, 0x08, 0x4f, 0x02, 0x25, 0xd5, 0x54,
		0xa5, 0x4e, 0x81, 0x5d, 0x9d, 0xac, 0xc1, 0xae, 0xfc, 0xc8, 0xbb, 0xf0, 0x2f, 0xef, 0xba, 0x9f,
		0x51, 0x26, 0x6b, 0xa6, 0xca, 0xd7, 0x4c, 0x98, 0x1b, 0xe8, 0x43, 0x6f, 0x98, 0x0f, 0xba, 0x41,
		0x3e, 0xab, 0x25, 0x56, 0x4b, 0xac, 0x96, 0x58, 0x2d, 0xb1, 0x5a, 0x62, 0xb5, 0x24, 0x5f, 0x22,
		0xa8, 0x1b, 0xd0, 0xe3, 0x36, 0xb1, 0x97, 0xa6, 0x2c, 0xd0, 0x66, 0xf6, 0xb7, 0x98, 0x06, 0xba,
		0x0e, 0x0a, 0x7e, 0x4b, 0x11, 0x1d, 0xb6, 0x10, 0xd1, 0x68, 0xcb, 0x10, 0x5d, 0xb6, 0x08, 0xd1,
		0x6e, 0x4b, 0x10, 0xed, 0xb6, 0x00, 0xd1, 0x6b, 0xcb, 0x0f, 0x2e, 0x2a, 0x2f, 0x52, 0x3a, 0xf0,
		0x5b, 0x78, 0x7c, 0xb5, 0x65, 0xc7, 0x1b, 0xe4, 0xf9, 0x62, 0x8e, 0x4f, 0xc8, 0x2b, 0xad, 0xf5,
		0xd8, 0x91, 0x43, 0x03, 0xa3, 0x98, 0x4e, 0x3b, 0x6e, 0xe8, 0xb6, 0x75, 0xa1, 0x66, 0x3b, 0x6a,
		0xe8, 0xe8, 0x72, 0xd7, 0x61, 0x93, 0x56, 0x9d, 0x76, 0xc8, 0xd0, 0x35, 0x05, 0x6c, 0xef, 0xec,
		0x30, 0x09, 0xb0, 0x10, 0x61, 0xf4, 0x8f, 0x5f, 0x17, 0x74, 0xc9, 0x30, 0x62, 0xf4, 0x29, 0x99,
		0x2e, 0x19, 0x5c, 0x97, 0x0c, 0xe0, 0x9e, 0x12, 0x40, 0x6b, 0xbd, 0x7e, 0x61, 0xb6, 0x59, 0x23,
		0x17, 0xa7, 0x7b, 0x42, 0x80, 0x3d, 0x39, 0xc4, 0xdc, 0xfe, 0x01, 0x77, 0xbb, 0x07, 0xad, 0xb6,
		0x77, 0xc0, 0xdc, 0xce, 0x01, 0x25, 0xa1, 0x80, 0x62, 0x4b, 0x85, 0x71, 0xc5, 0x80, 0x5a, 0x3c,
		0x5d, 0xdc, 0xbe, 0x0b, 0x18, 0x00, 0x27, 0x1f, 0x87, 0x64, 0x47, 0x28, 0x3c, 0xaf, 0xa2, 0xe5,
		0xd3, 0x6a, 0xe4, 0x51, 0xd9, 0xa9, 0x41, 0xee, 0x80, 0x13, 0x3c, 0xd8, 0x0c, 0xf5, 0x25, 0x51,
		0xe1, 0x50, 0x0d, 0x6b, 0xde, 0xf0, 0xc6, 0x0f, 0x6b, 0xd7, 0xd1, 0x68, 0x32, 0x16, 0x3f, 0xe4,
		0xb2, 0xc5, 0x0b, 0x4f, 0x46, 0x2f, 0x3c, 0xb5, 0x61, 0xb8, 0x72, 0x60, 0x96, 0x75, 0x22, 0x2d,
		0xdf, 0x04, 0x5c, 0xa6, 0x89, 0xb6, 0x1c, 0x13, 0x76, 0xd9, 0x25, 0xec, 0xf2, 0x4a, 0xcc, 0x65,
		0x94, 0xc4, 0xf3, 0x97, 0x7c, 0xe4, 0x28, 0xae, 0x17, 0x30, 0xdb, 0x31, 0xa4, 0xdd, 0x18, 0xcc,
		0x66, 0x0c, 0xe7, 0x57, 0x41, 0xf4, 0xa7, 0x00, 0xfb, 0x51, 0x50, 0xfd, 0x27, 0xf0, 0x7e, 0x13,
		0x78, 0x7f, 0x09, 0xb6, 0x9f, 0x84, 0x0f, 0x98, 0xab, 0x08, 0x48, 0x59, 0xc0, 0x90, 0x7d, 0xa0,
		0x95, 0xd3, 0x0e, 0x60, 0x5f, 0x68, 0x15, 0x56, 0x71, 0xaf, 0x4b, 0x62, 0x96, 0xc6, 0xb8, 0x85,
		0x8e, 0x5d, 0xda, 0xe0, 0x97, 0x36, 0x18, 0xa6, 0x07, 0x8e, 0x61, 0x61, 0x19, 0x18, 0x9e, 0x65,
		0x12, 0xc1, 0xdf, 0xeb, 0x12, 0xf6, 0xc4, 0x7d, 0xe0, 0x93, 0xf5, 0xc1, 0xfd, 0xba, 0xd8, 0x27,
		0x87, 0x69, 0xb0, 0x31, 0x88, 0x16, 0xa6, 0x3c, 0x5d, 0xfc, 0xb8, 0x3a, 0x59, 0xf0, 0xee, 0xb1,
		0x8f, 0xd2, 0xe3, 0xd0, 0x16, 0x36, 0xb4, 0x75, 0x39, 0x69, 0x5e, 0xab, 0x31, 0x4e, 0x9b, 0x67,
		0x21, 0xaf, 0x0b, 0x16, 0x5e, 0x39, 0x0e, 0x48, 0xe8, 0x83, 0x6c, 0xf1, 0x0f, 0xb0, 0xd5, 0xf2,
		0xe0, 0x5a, 0xec, 0x03, 0x6b, 0x69, 0x45, 0xad, 0x64, 0x46, 0xa4, 0x73, 0x4c, 0x88, 0xe3, 0xe1,
		0xa9, 0x47, 0x86, 0x48, 0x96, 0x76, 0x3a, 0xa2, 0xb4, 0xce, 0x17, 0x74, 0x44, 0x09, 0xcc, 0x0f,
		0x08, 0xeb, 0xf7, 0x73, 0xf3, 0x8e, 0x5a, 0xf3, 0x1b, 0x62, 0x4e, 0xef, 0xc7, 0xf1, 0xec, 0x76,
		0xd0, 0x1f, 0xa6, 0x5b, 0xea, 0x31, 0xfc, 0xf1, 0x6d, 0xa3, 0xe6, 0x87, 0x89, 0x8a, 0xae, 0xbc,
		0x81, 0xaa, 0x79, 0xc3, 0x61, 0xa4, 0xe2, 0x18, 0xc7, 0x21, 0xb6, 0x22, 0x7e, 0x7a, 0xc4, 0xd6,
		0x11, 0x26, 0x3d, 0x62, 0x39, 0x2a, 0x97, 0x1e, 0xb1, 0xfc, 0x86, 0x17, 0x3d, 0x62, 0x45, 0xd3,
		0x2b, 0x3d, 0x62, 0x55, 0x2b, 0x58, 0xe8, 0x11, 0xcb, 0x77, 0x7e, 0xa0, 0x47, 0x8c, 0x60, 0x83,
		0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8, 0x20, 0x84, 0x01,
		0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x59, 0xc0, 0x28, 0xcd, 0x9f, 0x95, 0x33, 0x0d, 0x46, 0xf7,
		0x67, 0x15, 0x3c, 0xd1, 0x09, 0x46, 0x98, 0xd2, 0x18, 0xaa, 0xd0, 0xe1, 0x4a, 0x1b, 0xc8, 0xd2,
		0x06, 0xb6, 0xf4, 0x80, 0x2e, 0x2c, 0xf8, 0x02, 0x83, 0xb0, 0x4c, 0x22, 0xf8, 0x4e, 0xb0, 0xd9,
		0x93, 0x2e, 0x4c, 0xc2, 0x79, 0x4c, 0x39, 0x5b, 0x6f, 0x00, 0x63, 0xef, 0x7a, 0x49, 0xa2, 0xa2,
		0x10, 0xd6, 0x12, 0x66, 0xfc, 0xef, 0xd7, 0x5f, 0x3f, 0x6c, 0xd6, 0xf6, 0x2e, 0xfe, 0xfe, 0xb0,
		0x55, 0xdb, 0xbb, 0x48, 0xbf, 0xdd, 0x9a, 0x7d, 0x49, 0xbf, 0xdf, 0xfe, 0xb0, 0x59, 0x6b, 0x2c,
		0xbe, 0xdf, 0xf9, 0xb0, 0x59, 0xdb, 0xb9, 0xf8, 0xed, 0xcf, 0x3f, 0x5f, 0xfd, 0xf6, 0xd7, 0xeb,
		0xfb, 0x9f, 0xff, 0xc1, 0x7f, 0xe1, 0x25, 0xdf, 0x0b, 0x44, 0x51, 0x9e, 0xf6, 0xed, 0xf7, 0x54,
		0xa6, 0xee, 0xca, 0x24, 0x16, 0xe4, 0xa8, 0x3e, 0xfa, 0x14, 0x4a, 0xbe, 0x02, 0xfa, 0x14, 0x58,
		0x86, 0x68, 0x1d, 0x29, 0x7d, 0x0a, 0xf9, 0xc6, 0xad, 0xdb, 0x3a, 0xe4, 0xa7, 0x17, 0x34, 0xd2,
		0xa9, 0x50, 0x9d, 0x08, 0xe9, 0x54, 0x60, 0x86, 0xf8, 0xf9, 0x0c, 0x51, 0x69, 0xaf, 0x82, 0x3d,
		0xbe, 0x6d, 0xd8, 0x8b, 0x3b, 0x62, 0xce, 0x6f, 0x08, 0xdd, 0x0a, 0xba, 0xa5, 0x9f, 0xb4, 0x07,
		0xba, 0x18, 0x2a, 0xa0, 0x66, 0x85, 0xa5, 0xf0, 0xe9, 0x55, 0x58, 0x47, 0x98, 0xf4, 0x2a, 0xe4,
		0x28, 0x5c, 0x7a, 0x15, 0xf2, 0x1b, 0x5e, 0xf4, 0x2a, 0x14, 0xcd, 0xaf, 0xf4, 0x2a, 0x54, 0xad,
		0x64, 0xa1, 0x57, 0x21, 0xdf, 0xf9, 0x81, 0x5e, 0x05, 0x82, 0x0d, 0x22, 0xe0, 0x00, 0x83, 0x0e,
		0x2a, 0xf0, 0xc0, 0x83, 0x0f, 0x3c, 0x00, 0x61, 0x83, 0x10, 0x06, 0x10, 0x81, 0x80, 0x11, 0x1c,
		0x20, 0x65, 0x01, 0xd3, 0xab, 0x50, 0x2a, 0x3c, 0xd1, 0xab, 0x40, 0x98, 0xd2, 0x18, 0xaa, 0xd0,
		0xe1, 0x4a, 0x1b, 0xc8, 0xd2, 0x06, 0xb6, 0xf4, 0x80, 0x2e, 0x2c, 0xf8, 0x02, 0x83, 0xb0, 0x4c,
		0x22, 0xf4, 0x2a, 0x08, 0xa1, 0x1c, 0x7a, 0x15, 0xca, 0xb8, 0x00, 0xae, 0x08, 0xff, 0xe7, 0x17,
		0xbd, 0x0a, 0x54, 0xa6, 0x50, 0x65, 0x12, 0x0b, 0x72, 0x54, 0x1f, 0xbd, 0x0a, 0x25, 0x5f, 0x01,
		0xbd, 0x0a, 0x2c, 0x43, 0xb4, 0x8e, 0x94, 0x5e, 0x85, 0x7c, 0xe3, 0xd6, 0x72, 0x25, 0xf2, 0xb7,
		0xeb, 0x19, 0x69, 0x55, 0xa8, 0x4e, 0x84, 0xb4, 0x2a, 0x30, 0x41, 0xfc, 0x74, 0x82, 0xa8, 0xbc,
		0x53, 0x61, 0xf1, 0x87, 0x34, 0x2a, 0xe8, 0x9a, 0x7c, 0x0c, 0x7f, 0x7c, 0xdb, 0x04, 0x3f, 0x56,
		0xa1, 0xc9, 0x63, 0x15, 0x72, 0x0a, 0x93, 0x56, 0x85, 0x1c, 0x95, 0x4b, 0xab, 0x42, 0x7e, 0xc3,
		0x8b, 0x56, 0x85, 0xa2, 0xf9, 0x95, 0x56, 0x85, 0xaa, 0x95, 0x2c, 0xb4, 0x2a, 0xe4, 0x3b, 0x3f,
		0xd0, 0xaa, 0x40, 0xb0, 0x41, 0x04, 0x1c, 0x60, 0xd0, 0x41, 0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07,
		0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10, 0x30, 0x82, 0x03, 0xa4, 0x2c, 0x60, 0x5a, 0x15, 0x4a,
		0x85, 0x27, 0x5a, 0x15, 0x08, 0x53, 0x1a, 0x43, 0x15, 0x3a, 0x5c, 0x69, 0x03, 0x59, 0xda, 0xc0,
		0x96, 0x1e, 0xd0, 0x85, 0x05, 0x5f, 0x60, 0x10, 0x96, 0x49, 0x44, 0x0b, 0xab, 0x42, 0x93, 0x56,
		0x85, 0x92, 0x88, 0x41, 0x93, 0x05, 0xe1, 0x5e, 0xed, 0xca, 0xac, 0x1d, 0x5d, 0xfc, 0xb5, 0xf5,
		0x7b, 0xe3, 0x7e, 0xff, 0xb7, 0xbf, 0x76, 0xef, 0xbf, 0x7d, 0xf3, 0xef, 0xa7, 0xfe, 0xda, 0xd6,
		0xef, 0xbb, 0xf7, 0xfb, 0x2b, 0xfe, 0xa4, 0x79, 0xbf, 0xff, 0x83, 0xff, 0xc6, 0xce, 0xfd, 0xaf,
		0x4b, 0x7f, 0x75, 0xfa, 0xfe, 0xf6, 0xaa, 0x1f, 0x68, 0xac, 0xf8, 0x81, 0xd7, 0xab, 0x7e, 0xe0,
		0xf5, 0x8a, 0x1f, 0x58, 0x19, 0xd2, 0xf6, 0x8a, 0x1f, 0xd8, 0xb9, 0xff, 0x7b, 0xe9, 0xef, 0xff,
		0xfa, 0xf4, 0x5f, 0x6d, 0xde, 0xff, 0xf6, 0xf7, 0xaa, 0x3f, 0xdb, 0xbd, 0xff, 0x7b, 0xff, 0x37,
		0x1a, 0x37, 0x0a, 0x1a, 0xa2, 0x3a, 0x19, 0x37, 0x38, 0x4e, 0x39, 0x4e, 0x7f, 0x64, 0x9c, 0x12,
		0x19, 0x73, 0x1c, 0x8b, 0xb4, 0xb1, 0x94, 0x7c, 0x05, 0xb4, 0xb1, 0xb0, 0x44, 0xd5, 0x3a, 0x52,
		0xda, 0x58, 0xf2, 0x8d, 0x5b, 0xc3, 0x55, 0xea, 0x4d, 0x1e, 0xb9, 0x51, 0xe5, 0x08, 0xe9, 0x63,
		0x61, 0x86, 0xf8, 0xf9, 0x0c, 0x51, 0x75, 0x23, 0x4b, 0x93, 0x47, 0x6e, 0x68, 0x9f, 0x7e, 0xd2,
		0xfe, 0x38, 0xf4, 0x91, 0x1b, 0x4d, 0x1e, 0xb9, 0x91, 0x4f, 0x98, 0xf4, 0xb1, 0xe4, 0x28, 0x5c,
		0xfa, 0x58, 0xf2, 0x1b, 0x5e, 0xf4, 0xb1, 0x14, 0xcd, 0xaf, 0xf4, 0xb1, 0x54, 0xad, 0x64, 0xa1,
		0x8f, 0x25, 0xdf, 0xf9, 0x81, 0x3e, 0x16, 0x82, 0x0d, 0x22, 0xe0, 0x00, 0x83, 0x0e, 0x2a, 0xf0,
		0xc0, 0x83, 0x0f, 0x3c, 0x00, 0x61, 0x83, 0x10, 0x06, 0x10, 0x81, 0x80, 0x11, 0x1c, 0x20, 0x65,
		0x01, 0xd3, 0xc7, 0x52, 0x2a, 0x3c, 0xd1, 0xc7, 0x42, 0x98, 0xd2, 0x18, 0xaa, 0xd0, 0xe1, 0x4a,
		0x1b, 0xc8, 0xd2, 0x06, 0xb6, 0xf4, 0x80, 0x2e, 0x2c, 0xf8, 0x02, 0x83, 0xb0, 0x4c, 0x22, 0xf4,
		0xb1, 0x08, 0xa1, 0x1c, 0xfa, 0x58, 0xca, 0xb8, 0x00, 0xae, 0x8f, 0xe7, 0xfa, 0xf8, 0x1f, 0x7f,
		0xd1, 0xc7, 0xc2, 0x71, 0xca, 0x71, 0x0a, 0x30, 0x4e, 0x89, 0x8c, 0x39, 0x8e, 0x45, 0xfa, 0x58,
		0x4a, 0xbe, 0x02, 0xfa, 0x58, 0x58, 0xa2, 0x6a, 0x1d, 0x29, 0x7d, 0x2c, 0xf9, 0xc6, 0xad, 0xe5,
		0x2a, 0x75, 0x1e, 0xc7, 0x52, 0xdd, 0x08, 0x69, 0x63, 0x61, 0x82, 0xf8, 0xe9, 0x04, 0x51, 0x79,
		0x17, 0x0b, 0x8f, 0x63, 0xd1, 0x3d, 0xf9, 0x18, 0x81, 0x17, 0xd6, 0xbc, 0xe1, 0xff, 0x79, 0x03,
		0x15, 0x0e, 0xee, 0x6a, 0xb1, 0x3f, 0x04, 0x72, 0xb0, 0x3c, 0x11, 0x3b, 0xed, 0x2b, 0xeb, 0x08,
		0x93, 0xf6, 0x95, 0x1c, 0x55, 0x4b, 0xfb, 0x4a, 0x7e, 0xc3, 0x8b, 0xf6, 0x95, 0xa2, 0xb9, 0x95,
		0xf6, 0x95, 0xaa, 0x95, 0x2a, 0x30, 0xf6, 0x95, 0x25, 0x3c, 0xc0, 0xb3, 0xb2, 0x2c, 0x5f, 0x02,
		0x6d, 0x2d, 0x55, 0x06, 0x1e, 0x44, 0xf0, 0x01, 0x06, 0x20, 0x54, 0x10, 0x82, 0x07, 0x22, 0x78,
		0x30, 0xc2, 0x06, 0x24, 0x0c, 0x50, 0x02, 0x01, 0x26, 0x38, 0x70, 0xca, 0x02, 0xc6, 0xf2, 0xff,
		0x2e, 0xcd, 0x33, 0x48, 0x3e, 0x60, 0x50, 0x70, 0x82, 0x05, 0x28, 0x64, 0x90, 0xd2, 0x00, 0xa8,
		0xd0, 0xc1, 0x4a, 0x1b, 0xc0, 0xd2, 0x06, 0xb4, 0xf4, 0x00, 0x2e, 0x2c, 0xf0, 0x02, 0x03, 0x30,
		0x58, 0x10, 0xcb, 0x02, 0xbf, 0x0a, 0xbc, 0xeb, 0x18, 0x37, 0x59, 0x2e, 0xe6, 0xab, 0xf4, 0x32,
		0x40, 0xf3, 0x0b, 0xa6, 0xe7, 0x18, 0x1e, 0xd4, 0x74, 0x00, 0x36, 0x8d, 0xc0, 0x4d, 0x17, 0x80,
		0xd3, 0x0e, 0xe4, 0xb4, 0x03, 0x3a, 0xbd, 0xc0, 0x0e, 0x13, 0xf0, 0x40, 0x41, 0x2f, 0x93, 0x0e,
		0xac, 0x87, 0x79, 0x69, 0xc6, 0x50, 0xe1, 0xe4, 0x46, 0x45, 0xe9, 0x42, 0x51, 0xe0, 0x59, 0x63,
		0xd1, 0xe5, 0x6a, 0x00, 0x5f, 0x83, 0x15, 0x4e, 0x6e, 0xa6, 0xa2, 0xe2, 0x50, 0x2e, 0xf2, 0xae,
		0x43, 0x7b, 0xcb, 0xb2, 0xab, 0x80, 0xf7, 0x98, 0x3d, 0x5c, 0x89, 0x86, 0x5e, 0xb3, 0xec, 0xe2,
		0xa0, 0x3d, 0x67, 0xb8, 0xa8, 0x01, 0x98, 0x9b, 0x8c, 0xcc, 0x3b, 0x00, 0xb4, 0xcc, 0x68, 0x25,
		0x65, 0x3c, 0xbe, 0x18, 0xb6, 0x69, 0xca, 0x08, 0x9f, 0x6d, 0x1a, 0x41, 0xc3, 0x81, 0x6d, 0x1a,
		0x39, 0xc3, 0x9a, 0x6d, 0x1a, 0xe1, 0x17, 0xc4, 0x36, 0x0d, 0xf9, 0xe9, 0x99, 0xd2, 0xd1, 0xa7,
		0x4d, 0x13, 0xdf, 0xc5, 0x89, 0xba, 0xc1, 0xc5, 0xa7, 0x0d, 0xf0, 0x7d, 0xe7, 0x1e, 0x30, 0x04,
		0x7c, 0x5f, 0xab, 0xec, 0x42, 0xfe, 0xf7, 0x61, 0xb3, 0xb6, 0x67, 0xd6, 0x8e, 0xbc, 0xda, 0xd5,
		0xc5, 0x5f, 0x8d, 0xfb, 0x3f, 0xff, 0x7c, 0xf5, 0x9d, 0x37, 0xfe, 0x85, 0x9b, 0x75, 0x2f, 0x90,
		0x05, 0xa7, 0xc3, 0x6e, 0x6a, 0xd5, 0x54, 0x1d, 0xbb, 0x3b, 0xa4, 0x93, 0x15, 0xe3, 0xe0, 0xd6,
		0x0b, 0x26, 0x0a, 0xbf, 0xaf, 0x93, 0x5e, 0x06, 0x3b, 0x3a, 0x65, 0x84, 0xcf, 0x8e, 0x8e, 0xa0,
		0x81, 0xc0, 0x8e, 0x8e, 0x9c, 0x61, 0xcd, 0x8e, 0x8e, 0xf0, 0x0b, 0x62, 0x47, 0x87, 0xcc, 0xf4,
		0x4c, 0xe9, 0xe8, 0xd3, 0xd1, 0x99, 0xf8, 0x61, 0xf2, 0x7a, 0x5b, 0x83, 0x76, 0xce, 0xff, 0x67,
		0xef, 0x5b, 0x9b, 0xda, 0xc6, 0xb6, 0xb4, 0xbf, 0xe7, 0x57, 0x50, 0xaa, 0x99, 0xaa, 0xe4, 0x4c,
		0x2b, 0xc6, 0x60, 0x43, 0x48, 0xd5, 0x5b, 0xa7, 0x0c, 0x76, 0x12, 0x4f, 0x1b, 0xdb, 0x65, 0x9b,
		0x74, 0x67, 0x12, 0x46, 0x25, 0xec, 0x6d, 0xd0, 0x44, 0x48, 0x3e, 0x92, 0x4c, 0xe0, 0x74, 0xf3,
		0xdf, 0xdf, 0xb2, 0x6c, 0x8b, 0x8b, 0x71, 0x08, 0xa0, 0xbd, 0xf7, 0x5a, 0x5b, 0x8f, 0x3f, 0x24,
		0x84, 0x6e, 0xd0, 0x92, 0xb4, 0x2e, 0xcf, 0xb3, 0xf6, 0xba, 0xec, 0x32, 0xbe, 0x85, 0x9e, 0x1b,
		0x9c, 0x0a, 0xf6, 0xac, 0x9a, 0x77, 0xc0, 0xde, 0x58, 0xd4, 0xaf, 0xb0, 0x47, 0x1e, 0x86, 0x10,
		0x8b, 0x95, 0xdb, 0xf9, 0xbc, 0xe0, 0xaa, 0xa6, 0xdc, 0xcf, 0x87, 0xc8, 0x1d, 0x26, 0x5e, 0x18,
		0xd4, 0xbd, 0x53, 0x6f, 0x5e, 0x2e, 0xc5, 0xfe, 0xbe, 0xae, 0x7f, 0x33, 0xc0, 0x05, 0xb8, 0x97,
		0x70, 0x01, 0xc4, 0x5d, 0x40, 0x65, 0x6b, 0xaf, 0xb2, 0xb7, 0xb3, 0xbb, 0xb5, 0x57, 0x85, 0x2f,
		0x00, 0x21, 0x81, 0xf4, 0xb7, 0x3f, 0x48, 0xf7, 0x23, 0xd6, 0xad, 0x73, 0x33, 0x3f, 0x84, 0x77,
		0x7a, 0x96, 0xf0, 0xcf, 0xf7, 0x2f, 0xee, 0x03, 0x09, 0x7f, 0x1d, 0xe2, 0x23, 0xe1, 0x4f, 0xc8,
		0x12, 0x90, 0xf0, 0xa7, 0x63, 0xd6, 0x48, 0xf8, 0x13, 0xbf, 0x21, 0x24, 0xfc, 0x81, 0x9a, 0x9e,
		0xa9, 0x3a, 0x66, 0x25, 0xfc, 0xdf, 0x19, 0x90, 0xef, 0xaf, 0x22, 0xdf, 0xaf, 0xf9, 0x83, 0x7c,
		0x3f, 0x78, 0x85, 0xc4, 0xdb, 0x41, 0xbe, 0x1f, 0xd1, 0x5c, 0x85, 0x0b, 0x40, 0xbe, 0x9f, 0xbc,
		0x0b, 0xd8, 0xaa, 0x22, 0xd1, 0x0f, 0x22, 0x02, 0xe9, 0xef, 0x7c, 0x90, 0xe8, 0x87, 0xc4, 0xec,
		0x43, 0x32, 0xd7, 0x4d, 0xc2, 0x99, 0xfc, 0xa6, 0x2d, 0x0c, 0x5d, 0xdd, 0x3d, 0xb8, 0xfa, 0x2d,
		0x4e, 0x0b, 0x86, 0xf9, 0x59, 0x31, 0x23, 0x0b, 0x66, 0xda, 0x3f, 0xc4, 0xba, 0x6f, 0x88, 0x29,
		0xc6, 0xc7, 0x26, 0x05, 0x9d, 0x8a, 0x8e, 0x4d, 0x0a, 0xfa, 0xcc, 0x15, 0x9b, 0x14, 0xa8, 0x41,
		0x4e, 0x6c, 0x52, 0x00, 0xa6, 0xf9, 0xb9, 0x8a, 0xb0, 0x3d, 0xee, 0xbb, 0xd9, 0xb0, 0x29, 0xdc,
		0x71, 0x24, 0xc6, 0x1c, 0x3d, 0xfe, 0x72, 0x3e, 0x0b, 0xc3, 0x8e, 0x1e, 0xab, 0xbb, 0x20, 0x82,
		0x6f, 0xdf, 0xce, 0x49, 0x52, 0x69, 0x0e, 0x31, 0x41, 0x95, 0x0a, 0x2c, 0x29, 0x97, 0x3d, 0x7e,
		0xbf, 0x8b, 0x2b, 0x6e, 0xa4, 0x88, 0xe7, 0xd8, 0x64, 0xbe, 0x63, 0x92, 0x8d, 0x1a, 0x8b, 0xcc,
		0x73, 0x0c, 0x32, 0x17, 0x6f, 0xc2, 0x34, 0xb1, 0x5b, 0xc8, 0x84, 0x2e, 0xa7, 0x95, 0xd5, 0x71,
		0x12, 0x4d, 0x87, 0x49, 0xb0, 0x80, 0xb9, 0xed, 0xf9, 0x03, 0x6f, 0x2e, 0x6e, 0xde, 0xe9, 0x2e,
		0x9e, 0xb2, 0xd3, 0x8c, 0xbd, 0xd8, 0x69, 0xcd, 0x1e, 0xaf, 0xd3, 0x8a, 0x27, 0xce, 0xc0, 0xbf,
		0x70, 0x0e, 0x93, 0x66, 0x1c, 0x38, 0xed, 0xc5, 0xa3, 0x73, 0xb2, 0x9f, 0xe9, 0xa7, 0x0f, 0xca,
		0x69, 0xb9, 0x41, 0x6d, 0xf9, 0x50, 0xfa, 0xde, 0x88, 0x07, 0x66, 0xa3, 0x8f, 0x80, 0x68, 0x4b,
		0x48, 0xdc, 0x9b, 0x72, 0xf3, 0xa2, 0x05, 0xf0, 0x9e, 0xb4, 0xfd, 0x02, 0x5d, 0x6b, 0x23, 0x6c,
		0x69, 0x56, 0xaa, 0x42, 0x6e, 0x92, 0x44, 0xde, 0xc9, 0x34, 0x11, 0xf4, 0x37, 0x51, 0xde, 0x64,
		0x79, 0xee, 0x09, 0x4e, 0xdc, 0x9b, 0xf1, 0x58, 0x02, 0xce, 0xe6, 0xa8, 0x8a, 0xd3, 0xd1, 0x14,
		0xc3, 0xa3, 0x28, 0x6e, 0x47, 0x4f, 0x6c, 0x8f, 0x9a, 0xd8, 0x1e, 0x2d, 0xf1, 0x3c, 0x4a, 0x02,
		0x22, 0x7f, 0xc9, 0x2b, 0xe7, 0xb2, 0x64, 0xdb, 0x9a, 0x17, 0x69, 0xb1, 0x71, 0x5e, 0xd9, 0x8a,
		0x81, 0x54, 0x6c, 0x2e, 0x29, 0x73, 0x16, 0x80, 0x86, 0x1d, 0xb0, 0xe1, 0x08, 0x70, 0x18, 0x03,
		0x1d, 0xae, 0x80, 0x87, 0x3d, 0xf0, 0x61, 0x0f, 0x80, 0x78, 0x03, 0x21, 0x1e, 0x80, 0x88, 0x09,
		0x30, 0x62, 0x07, 0x90, 0x32, 0x81, 0xfd, 0x70, 0xe8, 0xfa, 0xf6, 0x24, 0x0a, 0x13, 0x31, 0x64,
		0xd9, 0x88, 0x70, 0x93, 0x0e, 0xba, 0x7f, 0x27, 0x28, 0x6d, 0x06, 0xac, 0x32, 0x0b, 0x5e, 0x19,
		0x00, 0xb3, 0xb8, 0xc3, 0x2d, 0x63, 0x60, 0x97, 0x31, 0xf0, 0xcb, 0x0c, 0x18, 0xc6, 0x0b, 0x8e,
		0x31, 0x83, 0x65, 0x99, 0x8a, 0xf0, 0x2f, 0x6d, 0x16, 0xc1, 0xf4, 0x5c, 0x44, 0x2e, 0x43, 0x80,
		0x73, 0x1b, 0xe4, 0x94, 0x2b, 0x0c, 0x65, 0x6f, 0x04, 0xd3, 0xf3, 0x99, 0xf2, 0xc0, 0x44, 0x65,
		0x3e, 0x65, 0x96, 0x45, 0xad, 0x99, 0xf4, 0x6c, 0x8b, 0x5b, 0x6f, 0xee, 0xc0, 0xa0, 0x22, 0xd7,
		0xec, 0xa6, 0x58, 0x16, 0xbb, 0xf2, 0x83, 0x04, 0xc8, 0x25, 0xe5, 0x8a, 0x67, 0x51, 0x44, 0x4c,
		0xa3, 0x0c, 0xee, 0x6e, 0x9d, 0x11, 0xa7, 0x01, 0x10, 0xa8, 0x90, 0x35, 0xda, 0x55, 0xa0, 0x42,
		0x96, 0x96, 0x6b, 0xe0, 0x50, 0xd7, 0x25, 0xaf, 0x85, 0xc0, 0x0b, 0xbe, 0xd7, 0x6e, 0x1e, 0x05,
		0x2a, 0x85, 0x4d, 0xf3, 0x38, 0xf3, 0x82, 0xdb, 0x91, 0xf0, 0xdd, 0x2b, 0x66, 0x45, 0xc2, 0x73,
		0x99, 0x51, 0x1f, 0x9c, 0x87, 0x98, 0xa8, 0x0f, 0x96, 0xa8, 0xad, 0xa8, 0x0f, 0x96, 0x67, 0x5e,
		0xa8, 0x0f, 0x56, 0x0d, 0x4e, 0x51, 0x1f, 0x5c, 0x34, 0x3e, 0x82, 0xfa, 0x60, 0xb9, 0xf1, 0x01,
		0xf5, 0xc1, 0x00, 0x36, 0x1c, 0x01, 0x0e, 0x63, 0xa0, 0xc3, 0x15, 0xf0, 0xb0, 0x07, 0x3e, 0xec,
		0x01, 0x10, 0x6f, 0x20, 0xc4, 0x03, 0x10, 0x31, 0x01, 0x46, 0xec, 0x00, 0x52, 0x26, 0xb0, 0x6b,
		0x9f, 0x78, 0x09, 0xdf, 0xa2, 0xe0, 0xb9, 0xf8, 0xa8, 0x04, 0x06, 0x80, 0x32, 0x0b, 0x48, 0x19,
		0x00, 0xa8, 0xb8, 0x03, 0x2b, 0x63, 0x00, 0x96, 0x31, 0x40, 0xcb, 0x0c, 0xc0, 0xc5, 0x0b, 0x78,
		0x31, 0x03, 0x60, 0x99, 0x8a, 0xf0, 0xaf, 0x04, 0x3e, 0x09, 0x43, 0x5f, 0xb8, 0xac, 0xab, 0x80,
		0xcb, 0xa8, 0xc3, 0x2b, 0xba, 0x31, 0x5a, 0x3c, 0xce, 0x93, 0xd7, 0x5a, 0x21, 0x87, 0xa3, 0x65,
		0x10, 0x0c, 0x10, 0x0c, 0x10, 0x0c, 0x10, 0x0c, 0x10, 0x0c, 0x10, 0x0c, 0x10, 0x0c, 0x10, 0x8c,
		0x5f, 0xf4, 0xf8, 0x53, 0x2f, 0x48, 0xb6, 0xb7, 0x18, 0xf3, 0x0b, 0x8e, 0x3b, 0x54, 0x7a, 0x6e,
		0x70, 0x3a, 0x7b, 0xfa, 0x5f, 0x59, 0x3a, 0x46, 0xbe, 0x9b, 0xc4, 0xad, 0x43, 0x2f, 0x60, 0xbf,
		0x0a, 0xdd, 0x90, 0x15, 0xe8, 0xd9, 0xea, 0x73, 0xee, 0xf7, 0x61, 0xd0, 0xc2, 0xf3, 0xeb, 0xdf,
		0x18, 0x9b, 0xb6, 0x7b, 0x09, 0xd3, 0x26, 0x66, 0xda, 0x95, 0xad, 0xbd, 0xca, 0xde, 0xce, 0xee,
		0xd6, 0x5e, 0x15, 0x36, 0x0e, 0x42, 0x50, 0x2c, 0xa9, 0x8f, 0x91, 0xf6, 0x2e, 0xb0, 0xa4, 0x68,
		0x3f, 0x97, 0x2b, 0xb7, 0x91, 0x3d, 0xa6, 0xe9, 0x31, 0x03, 0x3a, 0xcf, 0x8b, 0x23, 0x21, 0x3a,
		0xcf, 0xe1, 0x15, 0x7e, 0xcd, 0x2b, 0x14, 0xbe, 0xe9, 0xbc, 0x9e, 0x3e, 0x05, 0xf4, 0x9b, 0x9b,
		0xe6, 0x67, 0x6e, 0xf5, 0x6e, 0xdb, 0x17, 0x6e, 0xe4, 0xf1, 0xf0, 0x36, 0x0f, 0x74, 0x9e, 0xdf,
		0x92, 0x1e, 0x3d, 0xe8, 0x79, 0x88, 0x89, 0x1e, 0x74, 0x89, 0x7a, 0x8b, 0x1e, 0x74, 0x79, 0xe6,
		0x85, 0x1e, 0x74, 0xd5, 0x30, 0x15, 0x3d, 0xe8, 0x45, 0x63, 0x26, 0xe8, 0x41, 0x97, 0x1b, 0x1f,
		0xd0, 0x83, 0x0e, 0x60, 0xc3, 0x11, 0xe0, 0x30, 0x06, 0x3a, 0x5c, 0x01, 0x0f, 0x7b, 0xe0, 0xc3,
		0x1e, 0x00, 0xf1, 0x06, 0x42, 0x3c, 0x00, 0x11, 0x13, 0x60, 0xc4, 0x0e, 0x20, 0x65, 0x02, 0xa3,
		0x45, 0x44, 0x1b, 0x70, 0x42, 0x8b, 0x08, 0x80, 0x94, 0xc1, 0x80, 0x8a, 0x3b, 0xb0, 0x32, 0x06,
		0x60, 0x19, 0x03, 0xb4, 0xcc, 0x00, 0x5c, 0xbc, 0x80, 0x17, 0x33, 0x00, 0x96, 0xa9, 0x08, 0x5a,
		0x44, 0xb4, 0xe3, 0x1b, 0xb4, 0x88, 0xa8, 0xfe, 0xa0, 0x45, 0x04, 0xc0, 0x3e, 0x87, 0xdb, 0x40,
		0x8b, 0x08, 0xc2, 0x6f, 0x9e, 0xa6, 0x8d, 0x16, 0x11, 0x72, 0xa6, 0x8d, 0x16, 0x11, 0x10, 0x82,
		0xa2, 0x4a, 0x8d, 0x16, 0x91, 0x22, 0x4b, 0x8a, 0x16, 0x11, 0xb9, 0x72, 0x9b, 0x5b, 0x0c, 0x7e,
		0x53, 0x6a, 0x8a, 0x66, 0x91, 0xe2, 0x48, 0x88, 0x66, 0x11, 0xf8, 0x87, 0xa7, 0xfa, 0x07, 0xb4,
		0x8d, 0xcc, 0x9e, 0xc7, 0xe7, 0xec, 0x71, 0xa0, 0x7f, 0xc4, 0x34, 0xd7, 0x33, 0xef, 0xc0, 0xf0,
		0x46, 0xcc, 0x5a, 0x46, 0xbc, 0x11, 0xba, 0x44, 0x72, 0x11, 0x13, 0x5d, 0x22, 0x12, 0x55, 0x15,
		0x5d, 0x22, 0xf2, 0xcc, 0x0b, 0x5d, 0x22, 0xaa, 0xf1, 0x29, 0xba, 0x44, 0x8a, 0x46, 0x49, 0xd0,
		0x25, 0x22, 0x37, 0x3e, 0xa0, 0x4b, 0x04, 0xc0, 0x86, 0x23, 0xc0, 0x61, 0x0c, 0x74, 0xb8, 0x02,
		0x1e, 0xf6, 0xc0, 0x87, 0x3d, 0x00, 0xe2, 0x0d, 0x84, 0x78, 0x00, 0x22, 0x26, 0xc0, 0x88, 0x1d,
		0x40, 0xca, 0x04, 0xf6, 0xc3, 0xa1, 0xeb, 0xf3, 0xed, 0x12, 0x99, 0x8b, 0x8f, 0x2e, 0x11, 0x00,
		0x28, 0xb3, 0x80, 0x94, 0x01, 0x80, 0x8a, 0x3b, 0xb0, 0x32, 0x06, 0x60, 0x19, 0x03, 0xb4, 0xcc,
		0x00, 0x5c, 0xbc, 0x80, 0x17, 0x33, 0x00, 0x96, 0xa9, 0x08, 0xba, 0x44, 0xb4, 0xe3, 0x1b, 0x74,
		0x89, 0xa8, 0xfe, 0xa0, 0x4b, 0x04, 0xc0, 0x3e, 0x87, 0xdb, 0x40, 0x97, 0x08, 0xc2, 0x6f, 0x9e,
		0xa6, 0x8d, 0x2e, 0x11, 0x72, 0xa6, 0x8d, 0x2e, 0x11, 0x10, 0x82, 0xa2, 0x4a, 0x8d, 0x2e, 0x91,
		0xc2, 0xc7, 0x28, 0x2b, 0x12, 0xe7, 0x61, 0x22, 0xf8, 0xe6, 0xbd, 0x17, 0xf2, 0x23, 0xf1, 0xad,
		0x42, 0x6c, 0x24, 0xbe, 0x35, 0x6a, 0x3a, 0x12, 0xdf, 0xfa, 0xcc, 0x15, 0x89, 0x6f, 0x62, 0x37,
		0x82, 0xc4, 0x37, 0x50, 0xcd, 0x23, 0x2a, 0x82, 0xc4, 0xb7, 0x76, 0x7c, 0x83, 0xc4, 0xb7, 0xea,
		0x0f, 0x12, 0xdf, 0x00, 0xf6, 0x39, 0xdc, 0x06, 0x12, 0xdf, 0x08, 0xbf, 0x79, 0x9a, 0x36, 0x12,
		0xdf, 0xe4, 0x4c, 0x1b, 0x89, 0x6f, 0x10, 0x82, 0xa2, 0x4a, 0x8d, 0xc4, 0x77, 0x91, 0x25, 0xc5,
		0x78, 0x24, 0xb9, 0x72, 0x1b, 0x39, 0xfe, 0xc4, 0x1b, 0x61, 0x22, 0x52, 0x71, 0x24, 0xc4, 0x44,
		0x24, 0xb8, 0x84, 0x5f, 0x70, 0x09, 0x85, 0x1f, 0x82, 0xd4, 0x1c, 0x61, 0xf0, 0x91, 0x71, 0x1e,
		0x66, 0x3e, 0x47, 0xc8, 0x0f, 0xe3, 0x98, 0xd9, 0xe8, 0xa3, 0x54, 0x64, 0x0c, 0x3f, 0xca, 0x43,
		0x4c, 0x0c, 0x3f, 0x92, 0xa8, 0xac, 0x18, 0x7e, 0x24, 0xcf, 0xbc, 0x30, 0xfc, 0x48, 0x35, 0x14,
		0xc5, 0xf0, 0xa3, 0xa2, 0xb1, 0x0f, 0x0c, 0x3f, 0x92, 0x1b, 0x1f, 0x30, 0xfc, 0x08, 0xc0, 0x86,
		0x23, 0xc0, 0x61, 0x0c, 0x74, 0xb8, 0x02, 0x1e, 0xf6, 0xc0, 0x87, 0x3d, 0x00, 0xe2, 0x0d, 0x84,
		0x78, 0x00, 0x22, 0x26, 0xc0, 0x88, 0x1d, 0x40, 0xca, 0x04, 0x76, 0xed, 0x13, 0x2f, 0xe1, 0xdb,
		0x04, 0x32, 0x17, 0x1f, 0x3d, 0x20, 0x00, 0x50, 0x66, 0x01, 0x29, 0x03, 0x00, 0x15, 0x77, 0x60,
		0x65, 0x0c, 0xc0, 0x32, 0x06, 0x68, 0x99, 0x01, 0xb8, 0x78, 0x01, 0x2f, 0x66, 0x00, 0x2c, 0x53,
		0x11, 0xfe, 0x3d, 0x20, 0x27, 0x61, 0xe8, 0x0b, 0x37, 0x60, 0xdc, 0x04, 0x52, 0x2e, 0xa3, 0xda,
		0xae, 0xe8, 0xc6, 0xc8, 0xe8, 0x48, 0x79, 0xad, 0x25, 0x72, 0x39, 0x62, 0x06, 0xd1, 0x00, 0xd1,
		0x00, 0xd1, 0x00, 0xd1, 0x00, 0xd1, 0x00, 0xd1, 0x00, 0xd1, 0x00, 0xd1, 0xf8, 0x45, 0x8f, 0x8f,
		0x66, 0x73, 0x0d, 0xa2, 0xa3, 0xd9, 0x5c, 0xd3, 0x83, 0x47, 0xb3, 0x39, 0x9d, 0xdb, 0x40, 0xb3,
		0x39, 0xc2, 0x6f, 0x9e, 0xa6, 0x8d, 0x66, 0x73, 0x72, 0xa6, 0x8d, 0x66, 0x73, 0x10, 0x82, 0xa2,
		0x4a, 0x8d, 0x66, 0xf3, 0x22, 0x4b, 0x8a, 0x66, 0x73, 0xb9, 0x72, 0x1b, 0xd9, 0x59, 0xea, 0x87,
		0x71, 0x8c, 0x76, 0xf3, 0xe2, 0x48, 0x88, 0x76, 0x73, 0x38, 0x85, 0x5f, 0x72, 0x0a, 0x85, 0x6f,
		0x38, 0x6f, 0xcd, 0x1e, 0x02, 0x5a, 0xce, 0x4d, 0xf3, 0x32, 0xf3, 0xc3, 0xf5, 0x99, 0x79, 0x89,
		0x94, 0x5e, 0xd9, 0x09, 0x87, 0x7c, 0xfa, 0xdd, 0xd2, 0x80, 0xfb, 0xd2, 0xa3, 0x11, 0x3d, 0x0f,
		0x31, 0xd1, 0x88, 0x2e, 0x51, 0x6f, 0xd1, 0x88, 0x2e, 0xcf, 0xbc, 0xd0, 0x88, 0xae, 0x1a, 0xa4,
		0xa2, 0x11, 0xbd, 0x68, 0xbc, 0x04, 0x8d, 0xe8, 0x72, 0xe3, 0x03, 0x1a, 0xd1, 0x01, 0x6c, 0x38,
		0x02, 0x1c, 0xc6, 0x40, 0x87, 0x2b, 0xe0, 0x61, 0x0f, 0x7c, 0xd8, 0x03, 0x20, 0xde, 0x40, 0x88,
		0x07, 0x20, 0x62, 0x02, 0x8c, 0xd8, 0x01, 0xa4, 0x4c, 0xe0, 0x84, 0x63, 0x1d, 0x65, 0x16, 0x66,
		0x18, 0xe4, 0x7d, 0xd6, 0xc1, 0x26, 0x74, 0x87, 0x00, 0x46, 0x19, 0x0c, 0xa7, 0xb8, 0xc3, 0x2a,
		0x63, 0xe0, 0x95, 0x31, 0x30, 0xcb, 0x0c, 0xb8, 0xc5, 0x0b, 0x76, 0x31, 0x83, 0x5f, 0x99, 0x8a,
		0xf0, 0xef, 0x0e, 0x11, 0xc1, 0xf4, 0x5c, 0x44, 0xf3, 0x12, 0x00, 0xc6, 0xad, 0xe8, 0x15, 0x86,
		0xb2, 0x37, 0x82, 0xe9, 0xf9, 0x4c, 0x79, 0x60, 0xa2, 0x32, 0x9f, 0x72, 0xcb, 0x8b, 0x93, 0x5a,
		0x92, 0x44, 0x3c, 0xcd, 0xf4, 0xd0, 0x0b, 0x1a, 0xbe, 0x98, 0x45, 0xa1, 0x98, 0x67, 0xd5, 0xb8,
		0x75, 0xe8, 0x5e, 0xde, 0xba, 0x83, 0xf2, 0xbb, 0x4a, 0x65, 0x67, 0xb7, 0x52, 0xd9, 0xdc, 0xdd,
		0xde, 0xdd, 0xdc, 0xab, 0x56, 0xcb, 0x3b, 0x65, 0x86, 0x95, 0xe3, 0x56, 0x27, 0x1a, 0x89, 0x48,
		0x8c, 0xf6, 0xaf, 0xac, 0xf7, 0x1b, 0xc1, 0xd4, 0xf7, 0x51, 0x09, 0x5c, 0x60, 0x49, 0x51, 0x09,
		0x2c, 0x57, 0x6e, 0x23, 0x8b, 0xfe, 0xee, 0x15, 0x15, 0xa1, 0x28, 0xb8, 0x38, 0x12, 0xa2, 0x28,
		0x18, 0xfe, 0xe1, 0xa9, 0xfe, 0xa1, 0xf0, 0xf5, 0xc1, 0xdd, 0xec, 0x79, 0xa4, 0x9c, 0x1b, 0x95,
		0xc2, 0xa6, 0xb9, 0x1e, 0xeb, 0xdc, 0xbd, 0xb4, 0x53, 0xd5, 0x3f, 0x71, 0x83, 0xd1, 0x0f, 0x6f,
		0x94, 0x9a, 0x33, 0x93, 0x3a, 0xe1, 0x07, 0x64, 0x47, 0x95, 0x70, 0x1e, 0x62, 0xa2, 0x4a, 0x58,
		0xa2, 0xd6, 0xa2, 0x4a, 0x58, 0x9e, 0x79, 0xa1, 0x4a, 0x58, 0x35, 0x6a, 0x45, 0x95, 0x70, 0xd1,
		0x88, 0x0a, 0xaa, 0x84, 0xe5, 0xc6, 0x07, 0x54, 0x09, 0x03, 0xd8, 0x70, 0x04, 0x38, 0x8c, 0x81,
		0x0e, 0x57, 0xc0, 0xc3, 0x1e, 0xf8, 0xb0, 0x07, 0x40, 0xbc, 0x81, 0x10, 0x0f, 0x40, 0xc4, 0x04,
		0x18, 0xb1, 0x03, 0x48, 0x99, 0xc0, 0x7c, 0x52, 0x3f, 0x6b, 0x63, 0x0d, 0x97, 0x0c, 0xd0, 0x3a,
		0x00, 0x85, 0x7a, 0x61, 0x00, 0x2a, 0x83, 0x81, 0x15, 0x77, 0x80, 0x65, 0x0c, 0xd0, 0x32, 0x06,
		0x70, 0x99, 0x01, 0xbc, 0x78, 0x01, 0x30, 0x66, 0x40, 0x2c, 0x53, 0x11, 0xfe, 0xf5, 0xc2, 0x9e,
		0x10, 0x62, 0xec, 0x87, 0x2e, 0xef, 0x91, 0xf2, 0x7b, 0x0c, 0x45, 0x6f, 0x89, 0xe0, 0x34, 0x05,
		0xc6, 0x98, 0x29, 0xaf, 0xf8, 0xc9, 0x63, 0xa6, 0x3c, 0x9d, 0xdb, 0xc8, 0x06, 0x4f, 0x63, 0xde,
		0x34, 0x82, 0x70, 0x0e, 0xa6, 0x8d, 0x99, 0xf2, 0x30, 0x6d, 0x98, 0xb6, 0x19, 0x6c, 0x80, 0xaf,
		0xd4, 0x18, 0x25, 0x5f, 0x64, 0x49, 0xd1, 0x40, 0x22, 0x57, 0x6e, 0xd3, 0x0a, 0xc4, 0x57, 0xab,
		0x4d, 0xd1, 0x3e, 0x52, 0x1c, 0x09, 0xd1, 0x3e, 0x02, 0xef, 0xf0, 0x34, 0xef, 0x50, 0xe8, 0xe6,
		0x91, 0x43, 0xf7, 0xb2, 0xe5, 0x05, 0xdf, 0xf7, 0xb3, 0x87, 0x81, 0xd6, 0x11, 0xd3, 0xdc, 0x4e,
		0xda, 0x7e, 0x11, 0x89, 0x58, 0x44, 0x17, 0xee, 0x89, 0x2f, 0x58, 0x77, 0x91, 0xac, 0xbf, 0x0d,
		0x34, 0x94, 0xe4, 0x21, 0x26, 0x1a, 0x4a, 0x24, 0x2a, 0x30, 0x1a, 0x4a, 0xe4, 0x99, 0x17, 0x1a,
		0x4a, 0x54, 0xe3, 0x58, 0x34, 0x94, 0x14, 0x8d, 0xba, 0xa0, 0xa1, 0x44, 0x6e, 0x7c, 0x40, 0x43,
		0x09, 0x80, 0x0d, 0x47, 0x80, 0xc3, 0x18, 0xe8, 0x70, 0x05, 0x3c, 0xec, 0x81, 0x0f, 0x7b, 0x00,
		0xc4, 0x1b, 0x08, 0xf1, 0x00, 0x44, 0x4c, 0x80, 0x11, 0x3b, 0x80, 0x94, 0x09, 0x8c, 0x86, 0x12,
		0xed, 0x00, 0x0a, 0x0d, 0x25, 0x00, 0x54, 0x06, 0x03, 0x2b, 0xee, 0x00, 0xcb, 0x18, 0xa0, 0x65,
		0x0c, 0xe0, 0x32, 0x03, 0x78, 0xf1, 0x02, 0x60, 0xcc, 0x80, 0x58, 0xa6, 0x22, 0x68, 0x28, 0xa1,
		0x01, 0x72, 0xd0, 0x50, 0xa2, 0xfc, 0x83, 0x86, 0x12, 0xc0, 0xfb, 0x1c, 0x6e, 0x03, 0x55, 0xe7,
		0x08, 0xc2, 0x79, 0x9a, 0x36, 0x1a, 0x4a, 0x60, 0xda, 0x30, 0x6d, 0x33, 0xd8, 0x00, 0x5f, 0xa9,
		0xd1, 0x50, 0x52, 0x64, 0x49, 0xd1, 0x50, 0x22, 0x57, 0x6e, 0x13, 0x4b, 0xc6, 0xd7, 0x16, 0x9e,
		0xa2, 0xb7, 0xa4, 0x38, 0x12, 0xa2, 0xb7, 0x04, 0x8e, 0xe2, 0xd9, 0x8e, 0xa2, 0xe8, 0x6d, 0x26,
		0xbd, 0xec, 0xc1, 0xa0, 0xe1, 0xc4, 0x6c, 0x5f, 0x64, 0x9d, 0x7b, 0x81, 0x9d, 0xf5, 0x59, 0x8d,
		0x84, 0xef, 0x5e, 0x31, 0xea, 0x32, 0x59, 0x95, 0x1d, 0xad, 0x25, 0x79, 0x88, 0x89, 0xd6, 0x12,
		0x89, 0x5a, 0x8b, 0xd6, 0x12, 0x79, 0xe6, 0x85, 0xd6, 0x12, 0xd5, 0x30, 0x16, 0xad, 0x25, 0x45,
		0x63, 0x2e, 0x68, 0x2d, 0x91, 0x1b, 0x1f, 0xd0, 0x5a, 0x02, 0x60, 0xc3, 0x11, 0xe0, 0x30, 0x06,
		0x3a, 0x5c, 0x01, 0x0f, 0x7b, 0xe0, 0xc3, 0x1e, 0x00, 0xf1, 0x06, 0x42, 0x3c, 0x00, 0x11, 0x13,
		0x60, 0xc4, 0x0e, 0x20, 0x65, 0x02, 0xbb, 0xf6, 0x89, 0x97, 0xf0, 0x6d, 0x2b, 0x99, 0x8b, 0x8f,
		0x96, 0x12, 0x00, 0x28, 0xb3, 0x80, 0x94, 0x01, 0x80, 0x8a, 0x3b, 0xb0, 0x32, 0x06, 0x60, 0x19,
		0x03, 0xb4, 0xcc, 0x00, 0x5c, 0xbc, 0x80, 0x17, 0x33, 0x00, 0x96, 0xa9, 0x08, 0xff, 0x96, 0x92,
		0x93, 0x30, 0xf4, 0x85, 0x1b, 0x30, 0x6e, 0x27, 0x29, 0x97, 0x51, 0xbf, 0x57, 0x74, 0x63, 0x4c,
		0xc7, 0x01, 0xf2, 0x38, 0x5b, 0x5e, 0x6b, 0x89, 0x37, 0xb7, 0x00, 0xa2, 0x01, 0xa2, 0x01, 0xa2,
		0x01, 0xa2, 0x01, 0xa2, 0x01, 0xa2, 0x01, 0x5c, 0x03, 0xa2, 0x61, 0x04, 0xd1, 0x98, 0x7a, 0x01,
		0xef, 0xb6, 0xf5, 0x5d, 0x86, 0xa2, 0xf7, 0xdc, 0xe0, 0x54, 0xa0, 0x6b, 0x5d, 0xfd, 0x83, 0x47,
		0xd7, 0x3a, 0x9d, 0xdb, 0x58, 0xb6, 0xb6, 0x6e, 0xa2, 0xb5, 0x15, 0xe1, 0x37, 0x07, 0xd3, 0x46,
		0xd7, 0x3a, 0x39, 0xd3, 0xae, 0x6c, 0xed, 0x55, 0xf6, 0x76, 0x76, 0xb7, 0xf6, 0xaa, 0xb0, 0x71,
		0x10, 0x82, 0x62, 0x49, 0x8d, 0xf6, 0xf5, 0xc2, 0xc7, 0xa8, 0xb4, 0x4f, 0x89, 0x7b, 0xfa, 0x3b,
		0xbb, 0x05, 0xa4, 0xbf, 0x55, 0x88, 0x8d, 0xf4, 0xb7, 0x46, 0x65, 0x47, 0xfa, 0x5b, 0x9f, 0xb9,
		0x22, 0xfd, 0x4d, 0xec, 0x46, 0x90, 0xfe, 0x06, 0xb6, 0x79, 0x44, 0x45, 0x90, 0xfe, 0xd6, 0x8e,
		0x6f, 0x90, 0xfe, 0x56, 0xfd, 0x41, 0xfa, 0x1b, 0xc0, 0x3e, 0x87, 0xdb, 0x40, 0xfa, 0x1b, 0xe1,
		0x37, 0x4f, 0xd3, 0x46, 0xfa, 0x9b, 0x9c, 0x69, 0x23, 0xfd, 0x0d, 0x42, 0x50, 0x54, 0xa9, 0x91,
		0xfe, 0x2e, 0xb2, 0xa4, 0x98, 0xde, 0x2a, 0x57, 0x6e, 0xe3, 0x86, 0x32, 0xae, 0x0c, 0x74, 0xc3,
		0xc8, 0xd6, 0xe2, 0x48, 0x88, 0x91, 0xad, 0xf0, 0x0e, 0x4f, 0xf3, 0x0e, 0xc5, 0x9e, 0xd3, 0xea,
		0x05, 0x87, 0xee, 0x65, 0xcb, 0x0b, 0xbe, 0xd7, 0xd3, 0x67, 0x81, 0xe1, 0xac, 0xa6, 0x79, 0x1d,
		0x2b, 0x12, 0xb1, 0x37, 0x9a, 0xba, 0xbe, 0xcd, 0x67, 0xf9, 0x6b, 0x96, 0x52, 0x7f, 0x40, 0x76,
		0x0c, 0x67, 0xcd, 0x43, 0x4c, 0x0c, 0x67, 0x95, 0xa8, 0xb5, 0x18, 0xce, 0x2a, 0xcf, 0xbc, 0x30,
		0x9c, 0x55, 0x35, 0x60, 0xc5, 0x70, 0xd6, 0xa2, 0x71, 0x14, 0x0c, 0x67, 0x95, 0x1b, 0x1f, 0x30,
		0x9c, 0x15, 0xc0, 0x86, 0x23, 0xc0, 0x61, 0x0c, 0x74, 0xb8, 0x02, 0x1e, 0xf6, 0xc0, 0x87, 0x3d,
		0x00, 0xe2, 0x0d, 0x84, 0x78, 0x00, 0x22, 0x26, 0xc0, 0x88, 0x1d, 0x40, 0xca, 0x04, 0xe6, 0x93,
		0xfa, 0x59, 0x1b, 0x6b, 0x38, 0xed, 0xd5, 0x7a, 0x08, 0x40, 0xa1, 0x79, 0x04, 0x80, 0xca, 0x60,
		0x60, 0xc5, 0x1d, 0x60, 0x19, 0x03, 0xb4, 0x8c, 0x01, 0x5c, 0x66, 0x00, 0x2f, 0x5e, 0x00, 0x8c,
		0x19, 0x10, 0xcb, 0x54, 0x84, 0x7f, 0xf3, 0x88, 0x27, 0x84, 0x18, 0xfb, 0xa1, 0xcb, 0xbb, 0x83,
		0x64, 0x8f, 0xa1, 0xe8, 0x2d, 0x11, 0x9c, 0xa6, 0xc0, 0x18, 0x2d, 0x24, 0x8a, 0x9f, 0x3c, 0x5a,
		0x48, 0xe8, 0xdc, 0x46, 0x56, 0x67, 0x8e, 0xf2, 0x72, 0x04, 0xe1, 0x1c, 0x4c, 0x1b, 0x2d, 0x24,
		0x30, 0x6d, 0x98, 0xb6, 0x19, 0x6c, 0x80, 0xaf, 0xd4, 0xe8, 0x1c, 0x29, 0xb2, 0xa4, 0xe8, 0x1c,
		0x91, 0x2b, 0xb7, 0x69, 0xb5, 0xe1, 0xab, 0xd5, 0xa6, 0xe8, 0x1c, 0x29, 0x8e, 0x84, 0xe8, 0x1c,
		0x81, 0x77, 0x78, 0x9a, 0x77, 0x28, 0x74, 0xe7, 0x48, 0x6f, 0xf1, 0x38, 0xf6, 0xb3, 0xa7, 0x81,
		0xde, 0x11, 0xd3, 0xfc, 0x0e, 0x93, 0x02, 0x4b, 0x56, 0x85, 0x95, 0xe8, 0x10, 0xc9, 0x59, 0x50,
		0x74, 0x88, 0x48, 0x15, 0x19, 0x1d, 0x22, 0x8a, 0x04, 0x47, 0x87, 0x08, 0xf0, 0x00, 0x17, 0x2e,
		0xc2, 0xa6, 0x43, 0x24, 0xe1, 0x54, 0x18, 0x90, 0x85, 0x87, 0x54, 0x6a, 0x5e, 0xfd, 0x21, 0x9b,
		0xe8, 0x0f, 0x29, 0x3c, 0xbc, 0x61, 0x0c, 0x73, 0xb8, 0xc2, 0x1d, 0xf6, 0xb0, 0x87, 0x3d, 0xfc,
		0xe1, 0x0d, 0x83, 0x78, 0xc0, 0x21, 0x26, 0xb0, 0x28, 0x53, 0x05, 0x76, 0xe5, 0x88, 0x37, 0x65,
		0x88, 0x23, 0x11, 0x24, 0x5e, 0x72, 0x15, 0x89, 0x31, 0x27, 0xaf, 0xbd, 0xcc, 0xa9, 0x30, 0x1a,
		0x8e, 0x69, 0x35, 0x17, 0x8f, 0x7a, 0xdf, 0x8d, 0x05, 0xdf, 0xb6, 0x9c, 0x66, 0xbf, 0xd9, 0x77,
		0xfa, 0x47, 0xfb, 0x83, 0xd6, 0x67, 0x67, 0xf0, 0xa5, 0xdb, 0xe0, 0x16, 0x76, 0xd2, 0xe2, 0x98,
		0x98, 0x65, 0xf5, 0x27, 0xd3, 0x06, 0x8b, 0x4c, 0x73, 0xba, 0x4e, 0xaf, 0x51, 0x3b, 0xf8, 0x54,
		0xdb, 0x6f, 0xb6, 0x9a, 0x83, 0x2f, 0x0b, 0x25, 0xea, 0x73, 0xd4, 0x22, 0x13, 0xb4, 0x89, 0xb7,
		0x56, 0x3d, 0xaa, 0x5d, 0xdd, 0x5e, 0xe3, 0x43, 0xf3, 0x4f, 0xe7, 0x43, 0xab, 0xf6, 0xb1, 0x6f,
		0xa1, 0x24, 0x14, 0x7a, 0x95, 0x93, 0x5e, 0x35, 0xbb, 0x9f, 0x2b, 0x4e, 0xaf, 0x73, 0x34, 0x68,
		0xf4, 0x9c, 0x66, 0x1d, 0x9a, 0x05, 0xcd, 0xca, 0x4b, 0xb3, 0x06, 0xb5, 0x8f, 0x50, 0x27, 0xa8,
		0x53, 0x8e, 0xea, 0xb4, 0x53, 0x81, 0x42, 0x41, 0xa1, 0x72, 0x8c, 0x7c, 0x3b, 0x88, 0x7c, 0xd0,
		0x2c, 0x69, 0x58, 0xbd, 0xcf, 0x5a, 0xab, 0x58, 0x4a, 0x7e, 0xfc, 0x0a, 0xd6, 0x0b, 0xab, 0x2d,
		0x12, 0xb3, 0x86, 0xfe, 0x80, 0x41, 0x43, 0x83, 0xc0, 0x94, 0xa1, 0x36, 0x45, 0x54, 0x1b, 0x8e,
		0x8c, 0x18, 0x8a, 0x03, 0xe6, 0x0b, 0x0d, 0x02, 0xc3, 0x85, 0xf6, 0x14, 0x45, 0x7b, 0x16, 0xae,
		0xe6, 0xa0, 0xd6, 0xc5, 0x59, 0x39, 0xf4, 0x4a, 0x89, 0x7e, 0xf5, 0x9c, 0x5a, 0xeb, 0x63, 0xa7,
		0xd7, 0x1c, 0x7c, 0x3a, 0x44, 0x66, 0x17, 0x9a, 0x95, 0xab, 0x66, 0xdd, 0xfc, 0x0b, 0xe9, 0x5d,
		0xb5, 0x1f, 0xa4, 0x77, 0x61, 0xba, 0x45, 0x0b, 0x06, 0xd0, 0x20, 0x38, 0x7d, 0xa8, 0x10, 0x37,
		0xbe, 0xdc, 0x47, 0x6d, 0x30, 0xb4, 0x4a, 0x95, 0x76, 0xb5, 0x9a, 0xed, 0xdf, 0x51, 0xc2, 0x02,
		0x95, 0xca, 0x51, 0xa5, 0x8e, 0xda, 0x07, 0x9d, 0x76, 0x7f, 0xd0, 0xab, 0x35, 0xdb, 0x8d, 0xba,
		0xd3, 0xea, 0x77, 0xa1, 0x5c, 0x50, 0xae, 0x5c, 0xfd, 0x55, 0x6d, 0x30, 0xe8, 0x35, 0xf7, 0x8f,
		0x06, 0x0d, 0xb4, 0x33, 0x40, 0xb5, 0x72, 0x53, 0xad, 0xf4, 0x68, 0xab, 0xdd, 0x68, 0x7e, 0xfc,
		0xb4, 0xdf, 0xe9, 0x39, 0xb5, 0x7a, 0xbd, 0xd7, 0xe8, 0x43, 0xc1, 0xa0, 0x60, 0x79, 0x2a, 0x58,
		0xc5, 0x69, 0xb6, 0x07, 0x8d, 0xde, 0x87, 0xda, 0x41, 0x03, 0x1a, 0x06, 0x0d, 0xcb, 0x1d, 0x7a,
		0x0d, 0x9a, 0xad, 0xe6, 0xff, 0x34, 0xea, 0xce, 0x7e, 0xad, 0x5d, 0xff, 0xa3, 0x59, 0x1f, 0x7c,
		0x82, 0x76, 0x41, 0xbb, 0x72, 0xc5, 0x5e, 0xdd, 0x5e, 0x67, 0xd0, 0x38, 0x18, 0x34, 0x3b, 0xed,
		0x79, 0x46, 0x02, 0xfa, 0x05, 0xfd, 0xca, 0x49, 0xbf, 0x7a, 0x8d, 0x7e, 0xb3, 0x7e, 0x54, 0x6b,
		0xc1, 0x7b, 0x41, 0xbb, 0xf2, 0xd7, 0xae, 0xc3, 0xda, 0x9f, 0x73, 0x0f, 0x06, 0xed, 0x82, 0x76,
		0xc9, 0x21, 0x8f, 0xc0, 0xf6, 0xd0, 0x30, 0xa9, 0xfe, 0xab, 0xd7, 0xe8, 0x37, 0x7a, 0x9f, 0x6b,
		0xfb, 0xad, 0x06, 0xbc, 0x18, 0x74, 0x4c, 0x12, 0xc2, 0x6f, 0x75, 0xe0, 0xb8, 0xa0, 0x54, 0x39,
		0x2b, 0x55, 0xbd, 0xd1, 0xaa, 0x7d, 0x71, 0x3e, 0xd7, 0x7a, 0xcd, 0xda, 0x8c, 0x3b, 0x42, 0xbf,
		0xa0, 0x5f, 0x79, 0xe9, 0x57, 0xad, 0xfe, 0xdf, 0x4e, 0xab, 0xd6, 0x66, 0xde, 0x33, 0x0f, 0xb5,
		0xa2, 0xa6, 0x56, 0x9f, 0x6b, 0xcd, 0x16, 0xa0, 0x16, 0xd4, 0x4b, 0x9e, 0xd7, 0x82, 0xc7, 0x82,
		0x4a, 0xe5, 0xc9, 0x10, 0x9b, 0xed, 0x9b, 0x2c, 0x57, 0x0a, 0xb8, 0xa0, 0x5d, 0xd0, 0xae, 0xbc,
		0xb4, 0xeb, 0xa8, 0x3d, 0xcf, 0x3e, 0xe0, 0x74, 0x11, 0xfa, 0x25, 0x43, 0xbf, 0x32, 0xa5, 0x72,
		0xb2, 0xf2, 0xc1, 0x01, 0xf2, 0x10, 0x50, 0xb0, 0xdc, 0x14, 0xac, 0xf1, 0xe7, 0xa0, 0xd1, 0xae,
		0x37, 0xea, 0x4e, 0xad, 0x3e, 0x8b, 0x94, 0x1f, 0x7b, 0x9d, 0x23, 0x94, 0xa6, 0x42, 0xbf, 0x72,
		0x44, 0xf4, 0x50, 0x2b, 0xa8, 0x55, 0xee, 0x6a, 0x95, 0x56, 0x0d, 0xa2, 0x2c, 0x15, 0x0a, 0x26,
		0x4b, 0xc1, 0x40, 0x17, 0xa1, 0x55, 0xf9, 0x6b, 0xd5, 0xa0, 0xe1, 0xd4, 0x1b, 0x1f, 0x6a, 0x47,
		0xad, 0x81, 0x73, 0xd8, 0x18, 0xf4, 0x9a, 0x07, 0x18, 0x78, 0xa0, 0xf6, 0x83, 0x81, 0x07, 0x30,
		0xde, 0x67, 0x85, 0x02, 0x0c, 0xe6, 0x82, 0xea, 0x3c, 0x5d, 0x75, 0x0c, 0xe8, 0xfa, 0x84, 0x12,
		0x91, 0xf0, 0x3f, 0x9c, 0xbb, 0x3b, 0xa1, 0x42, 0x04, 0xe8, 0xb2, 0x09, 0x5d, 0x9c, 0x50, 0x24,
		0x12, 0x79, 0x17, 0x03, 0x2a, 0xba, 0xa1, 0x49, 0xda, 0xa1, 0x91, 0x01, 0x5d, 0x99, 0xd0, 0x22,
		0x12, 0xd8, 0x88, 0x7d, 0xf7, 0x25, 0xf4, 0x48, 0xb7, 0x1e, 0x99, 0xd0, 0x65, 0x09, 0x2d, 0xd2,
		0xad, 0x45, 0x26, 0x74, 0x53, 0x42, 0x8b, 0x48, 0x90, 0x35, 0x60, 0x6c, 0x68, 0x52, 0x2e, 0xfe,
		0xc8, 0x8c, 0xee, 0x48, 0xe8, 0x12, 0x09, 0xa4, 0xcd, 0xb3, 0x0b, 0x12, 0xca, 0x43, 0x42, 0x79,
		0xd8, 0x77, 0x3b, 0x42, 0x8f, 0x74, 0xeb, 0x11, 0xeb, 0xae, 0x46, 0xa8, 0x8f, 0x76, 0xf5, 0x31,
		0xa1, 0x7b, 0x11, 0x6a, 0x44, 0xc1, 0x0b, 0xc1, 0x03, 0x41, 0x75, 0x9e, 0xc3, 0xc8, 0x0c, 0xe8,
		0x46, 0x84, 0x16, 0xe9, 0xd6, 0x22, 0x33, 0xba, 0x0e, 0xa1, 0x47, 0xba, 0xf5, 0xc8, 0x90, 0xee,
		0x42, 0x28, 0x92, 0x6e, 0x45, 0x32, 0xa3, 0x8b, 0x10, 0x7a, 0xa4, 0x1f, 0x59, 0x43, 0x7d, 0xa0,
		0x3e, 0xcf, 0x56, 0x1f, 0x43, 0xba, 0x02, 0xa1, 0x48, 0xba, 0x15, 0x09, 0xf4, 0x0c, 0xda, 0xf3,
		0x7c, 0xed, 0x31, 0xa0, 0xcb, 0x8f, 0x57, 0x77, 0x1f, 0x9f, 0xae, 0x3e, 0x1e, 0xcf, 0x95, 0xbe,
		0x94, 0xb4, 0x25, 0x24, 0xee, 0x82, 0xad, 0x5a, 0x10, 0x84, 0x89, 0x9b, 0x78, 0x61, 0x60, 0xbd,
		0x67, 0xe0, 0x7c, 0xad, 0x78, 0x78, 0x26, 0xce, 0xdd, 0x89, 0x9b, 0x9c, 0xcd, 0xdc, 0x6d, 0x29,
		0x9c, 0x88, 0x60, 0x18, 0x06, 0x63, 0xef, 0xd4, 0x0e, 0x44, 0xf2, 0x23, 0x8c, 0xbe, 0xdb, 0x5e,
		0x10, 0x27, 0x6e, 0x30, 0x14, 0xa5, 0xfb, 0xdf, 0x88, 0x57, 0xbe, 0x53, 0x9a, 0x44, 0x61, 0x12,
		0x0e, 0x43, 0x3f, 0xce, 0xbe, 0x2a, 0x79, 0xb1, 0x17, 0x97, 0x7c, 0x71, 0x21, 0xfc, 0xc5, 0x5f,
		0x25, 0xdf, 0x0b, 0xbe, 0xdb, 0x71, 0xe2, 0x26, 0xc2, 0x1e, 0xb9, 0x89, 0x7b, 0xe2, 0xc6, 0xa2,
		0xe4, 0xc7, 0x93, 0x52, 0xe2, 0x5f, 0xc4, 0xb3, 0x3f, 0x4a, 0xe7, 0x89, 0xed, 0xc5, 0x41, 0x29,
		0x10, 0xde, 0xe9, 0xd9, 0x49, 0x18, 0xc5, 0xd9, 0x57, 0xa5, 0x9b, 0x4b, 0x67, 0x97, 0x8c, 0xa7,
		0x27, 0xe9, 0x0f, 0xce, 0xff, 0x2e, 0xa5, 0xbf, 0x97, 0x76, 0x50, 0xa0, 0x6b, 0x60, 0x84, 0x8d,
		0xcb, 0x9a, 0x69, 0x8b, 0x18, 0xbb, 0x53, 0x3f, 0xb1, 0xcf, 0x45, 0x12, 0x79, 0x43, 0xf2, 0xf6,
		0x95, 0x81, 0x98, 0x55, 0xd1, 0x89, 0x3b, 0xb1, 0xdf, 0xbd, 0x60, 0x64, 0xbd, 0xdf, 0x28, 0x13,
		0x17, 0xf3, 0x20, 0x75, 0x54, 0xd6, 0xfb, 0x8d, 0x4d, 0xe2, 0x82, 0x76, 0x23, 0x31, 0xf6, 0x2e,
		0x79, 0x04, 0x84, 0xa5, 0xd2, 0x86, 0x43, 0x7b, 0xe6, 0xba, 0x19, 0x6c, 0x00, 0xb7, 0xfa, 0xe1,
		0x34, 0x1a, 0x0a, 0x16, 0x8f, 0x77, 0x6e, 0x5e, 0xe2, 0xea, 0x47, 0x18, 0xcd, 0x2c, 0xcc, 0x9a,
		0xcc, 0x35, 0x83, 0x07, 0xaf, 0xb4, 0x3e, 0xb9, 0x71, 0x2d, 0x3a, 0x9d, 0x9e, 0x8b, 0x20, 0xb1,
		0xde, 0x6f, 0x24, 0xd1, 0x54, 0x30, 0x11, 0xfc, 0x96, 0xd4, 0x99, 0x62, 0x03, 0x88, 0x1b, 0x0d,
		0xc4, 0xeb, 0x5e, 0xc4, 0x04, 0x81, 0xa7, 0x88, 0x95, 0x8d, 0xf3, 0x5a, 0xc6, 0x87, 0xb9, 0xd8,
		0x4c, 0xec, 0x9f, 0x07, 0xa0, 0x61, 0x07, 0x6c, 0x38, 0x02, 0x1c, 0xc6, 0x40, 0x87, 0x2b, 0xe0,
		0x61, 0x0f, 0x7c, 0xd8, 0x03, 0x20, 0xde, 0x40, 0x88, 0x07, 0x20, 0x62, 0x02, 0x8c, 0xd8, 0x01,
		0xa4, 0x4c, 0x60, 0x26, 0x69, 0x9f, 0xb5, 0x81, 0x86, 0x45, 0xee, 0x67, 0x1d, 0x74, 0xda, 0x64,
		0x26, 0x36, 0x37, 0x08, 0xc5, 0x19, 0x4a, 0x19, 0x00, 0xa9, 0xb8, 0x43, 0x2b, 0x63, 0x20, 0x96,
		0x31, 0x50, 0xcb, 0x0c, 0xc8, 0xc5, 0x0b, 0x7a, 0x31, 0x83, 0x60, 0x99, 0x8a, 0x0c, 0xae, 0x26,
		0x82, 0xb7, 0xc7, 0x9f, 0x7a, 0x41, 0xb2, 0xbd, 0xc5, 0xd1, 0xe1, 0x2f, 0xf0, 0xcd, 0x2e, 0x43,
		0xd1, 0x7b, 0x6e, 0x70, 0x3a, 0x7b, 0xfa, 0x5f, 0x59, 0x3a, 0x46, 0xbe, 0x73, 0xe8, 0xad, 0x43,
		0x2f, 0x60, 0x8b, 0x10, 0x98, 0x03, 0xfb, 0x95, 0xdb, 0xf8, 0xec, 0xfa, 0x53, 0x61, 0xc0, 0x7d,
		0x7c, 0x88, 0xdc, 0x61, 0xe2, 0x85, 0x41, 0xdd, 0x3b, 0xf5, 0x92, 0x78, 0x76, 0x43, 0x58, 0x8e,
		0xa1, 0xc3, 0xb4, 0xdd, 0x4b, 0x98, 0x36, 0x31, 0xd3, 0xae, 0x6c, 0xed, 0x55, 0xf6, 0x76, 0x76,
		0xb7, 0xf6, 0xaa, 0xb0, 0x71, 0x10, 0x82, 0x62, 0x49, 0xcd, 0x6b, 0xab, 0xca, 0x35, 0xce, 0x12,
		0x8a, 0x18, 0x49, 0xb9, 0x55, 0x3d, 0x67, 0x72, 0x9b, 0x56, 0xfd, 0xbc, 0x52, 0x69, 0xca, 0xa1,
		0x1e, 0x9a, 0x8f, 0x49, 0xa2, 0x22, 0xab, 0x40, 0x4e, 0xc2, 0x7c, 0xe7, 0xc0, 0xa1, 0xb6, 0x37,
		0x4e, 0xa2, 0xe9, 0x30, 0x09, 0x16, 0x69, 0xc6, 0xf6, 0xfc, 0xa9, 0x36, 0x17, 0x77, 0xe8, 0x74,
		0x17, 0x8f, 0xd2, 0x69, 0xc6, 0x5e, 0xec, 0xb4, 0x66, 0xcf, 0xd0, 0x69, 0xc5, 0x13, 0x67, 0xe0,
		0x5f, 0x38, 0x87, 0x49, 0x33, 0x0e, 0x9c, 0xf6, 0xe2, 0xf9, 0x38, 0xd9, 0xcf, 0xf4, 0xd3, 0xa7,
		0xe1, 0x0c, 0x44, 0x7d, 0xfe, 0x30, 0x0e, 0xe7, 0xcf, 0x02, 0x2d, 0x23, 0xa6, 0x39, 0x1d, 0x2b,
		0xe1, 0x90, 0x56, 0xbf, 0xe9, 0x12, 0x99, 0x49, 0xcb, 0xa3, 0x31, 0x64, 0x13, 0x8d, 0x21, 0xf9,
		0x08, 0x8a, 0xc6, 0x10, 0xa9, 0x22, 0xa3, 0x31, 0x44, 0x91, 0xe0, 0x68, 0x0c, 0x01, 0x1a, 0xe0,
		0x42, 0x43, 0xd8, 0x1c, 0xb6, 0x67, 0x1e, 0xd7, 0x17, 0xee, 0x38, 0x12, 0x63, 0x0e, 0x1e, 0x77,
		0xd9, 0x68, 0xc1, 0xe0, 0x38, 0xdd, 0xea, 0x2e, 0x98, 0xdd, 0xdb, 0xb7, 0xf3, 0x2c, 0x49, 0x29,
		0x45, 0x60, 0xe0, 0x01, 0xc6, 0xf1, 0x80, 0xe9, 0x8c, 0xb7, 0xc7, 0x49, 0xe4, 0x7a, 0x81, 0x18,
		0xd9, 0x7e, 0x3c, 0xe1, 0x43, 0x0a, 0x56, 0x45, 0x47, 0xeb, 0x38, 0x18, 0x02, 0x18, 0x02, 0x18,
		0x02, 0x18, 0x02, 0x18, 0x02, 0x18, 0x82, 0x94, 0x57, 0x8e, 0xd6, 0x71, 0xb9, 0xf1, 0x01, 0xad,
		0xe3, 0x00, 0x36, 0x1c, 0x01, 0x0e, 0x63, 0xa0, 0xc3, 0x15, 0xf0, 0xb0, 0x07, 0x3e, 0xec, 0x01,
		0x10, 0x6f, 0x20, 0xc4, 0x03, 0x10, 0x31, 0x01, 0x46, 0xec, 0x00, 0x52, 0x26, 0xf0, 0x30, 0x9c,
		0xa6, 0x8a, 0xcb, 0xb4, 0x73, 0x7c, 0x2e, 0x3e, 0x1a, 0xc7, 0x01, 0xa0, 0xcc, 0x02, 0x52, 0x06,
		0x00, 0x2a, 0xee, 0xc0, 0xca, 0x18, 0x80, 0x65, 0x0c, 0xd0, 0x32, 0x03, 0x70, 0xf1, 0x02, 0x5e,
		0xcc, 0x00, 0x58, 0xa6, 0x22, 0x66, 0x34, 0x8e, 0x97, 0x77, 0x18, 0x37, 0x8e, 0xef, 0xa0, 0x71,
		0x5c, 0xf1, 0x07, 0x8d, 0xe3, 0x00, 0xf6, 0x39, 0xdc, 0x06, 0x1a, 0xc7, 0x11, 0x7e, 0xf3, 0x34,
		0x6d, 0x34, 0x8e, 0x93, 0x33, 0xed, 0x9d, 0x6a, 0x75, 0x1b, 0x3d, 0xe3, 0xe0, 0x02, 0x05, 0x93,
		0x1a, 0x3d, 0xe3, 0x85, 0x0f, 0x4f, 0x3c, 0x7a, 0x9f, 0xd6, 0xb2, 0x42, 0x06, 0xbd, 0x50, 0x86,
		0xc4, 0x4e, 0xe4, 0xbb, 0x75, 0xea, 0x39, 0xf2, 0xdd, 0xfa, 0xcc, 0x15, 0xf9, 0x6e, 0x62, 0x37,
		0x82, 0x7c, 0x37, 0x10, 0xcd, 0x23, 0x2a, 0xc2, 0x3f, 0xdf, 0xed, 0x8d, 0x44, 0x90, 0x78, 0xc9,
		0x15, 0x8f, 0x7e, 0xae, 0x75, 0x20, 0xa7, 0xcc, 0x90, 0x55, 0x5b, 0xcd, 0xc5, 0xa3, 0xdf, 0x77,
		0x63, 0xc6, 0x71, 0xeb, 0x66, 0x33, 0x76, 0xb3, 0xef, 0xf4, 0x8f, 0xf6, 0x07, 0xad, 0xcf, 0xce,
		0xe0, 0x4b, 0xb7, 0xc1, 0x35, 0x7c, 0xa5, 0xb9, 0x9a, 0x98, 0xed, 0x61, 0xc4, 0x06, 0xeb, 0x03,
		0x89, 0xbb, 0x1a, 0xd5, 0xbd, 0xbb, 0x6b, 0x7d, 0xae, 0x5c, 0x7d, 0xce, 0xda, 0x65, 0x92, 0x96,
		0x99, 0xa1, 0x6d, 0x8f, 0x6a, 0x5d, 0xb7, 0xd7, 0xf8, 0xd0, 0xfc, 0xd3, 0xf9, 0xd0, 0xaa, 0x7d,
		0xec, 0x5b, 0xec, 0x6f, 0xf5, 0xfa, 0x37, 0xe8, 0x1b, 0x6d, 0x7d, 0x6b, 0x76, 0x3f, 0x57, 0x9c,
		0x5e, 0xe7, 0x68, 0xd0, 0xe8, 0x39, 0xcd, 0x3a, 0x34, 0x0e, 0x1a, 0x27, 0x5b, 0xe3, 0x06, 0xb5,
		0x8f, 0x50, 0x33, 0xa8, 0x99, 0x02, 0x35, 0xdb, 0xa9, 0x40, 0xd1, 0xa0, 0x68, 0x0a, 0x22, 0xe8,
		0x0e, 0x22, 0x28, 0x34, 0x4e, 0x39, 0x47, 0xe8, 0x1b, 0xa1, 0x6d, 0xac, 0xef, 0xe0, 0x18, 0xb5,
		0x66, 0xb0, 0x6e, 0x30, 0x7f, 0xe8, 0x15, 0x18, 0x3e, 0x34, 0xab, 0x70, 0x9a, 0xc5, 0x9a, 0xc9,
		0x43, 0x9d, 0xc0, 0xd8, 0xa1, 0x50, 0xa6, 0x47, 0xbe, 0x1d, 0x44, 0x3e, 0x68, 0x16, 0x18, 0x38,
		0xb4, 0x8a, 0xa2, 0x56, 0x2d, 0x5c, 0xd3, 0x41, 0xad, 0x8b, 0x9a, 0x03, 0xe8, 0x9b, 0x56, 0xbd,
		0xeb, 0x39, 0xb5, 0xd6, 0xc7, 0x4e, 0xaf, 0x39, 0xf8, 0x74, 0x88, 0x0c, 0x36, 0x34, 0x4e, 0x89,
		0xc6, 0xdd, 0xfc, 0x0b, 0x69, 0x6c, 0xbd, 0x1f, 0xa4, 0xb1, 0x61, 0xe2, 0x08, 0x26, 0xd0, 0x2c,
		0x04, 0x0d, 0xa8, 0x56, 0x31, 0xf8, 0x7c, 0x1f, 0xb5, 0xde, 0xd0, 0x36, 0xdd, 0x5a, 0xd7, 0x6a,
		0xb6, 0x7f, 0x47, 0xc9, 0x10, 0x54, 0x4d, 0x81, 0xaa, 0x1d, 0xb5, 0x0f, 0x3a, 0xed, 0xfe, 0xa0,
		0x57, 0x6b, 0xb6, 0x1b, 0x75, 0xa7, 0xd5, 0xef, 0x42, 0xe9, 0xa0, 0x74, 0x4a, 0xfc, 0x5b, 0x6d,
		0x30, 0xe8, 0x35, 0xf7, 0x8f, 0x06, 0x0d, 0xb4, 0xb3, 0x40, 0xe5, 0xa4, 0xab, 0x5c, 0x7a, 0xe4,
		0xd7, 0x6e, 0x34, 0x3f, 0x7e, 0xda, 0xef, 0xf4, 0x9c, 0x5a, 0xbd, 0xde, 0x6b, 0xf4, 0xa1, 0x78,
		0x50, 0x3c, 0x15, 0x8a, 0x57, 0x71, 0x9a, 0xed, 0x41, 0xa3, 0xf7, 0xa1, 0x76, 0xd0, 0x80, 0xe6,
		0x41, 0xf3, 0x94, 0x41, 0xbb, 0x41, 0xb3, 0xd5, 0xfc, 0x9f, 0x46, 0xdd, 0xd9, 0xaf, 0xb5, 0xeb,
		0x7f, 0x34, 0xeb, 0x83, 0x4f, 0xd0, 0x3a, 0x68, 0x9d, 0x12, 0x6c, 0xd7, 0xed, 0x75, 0x06, 0x8d,
		0x83, 0x41, 0xb3, 0xd3, 0x9e, 0x67, 0x4e, 0xa0, 0x77, 0xd0, 0x3b, 0xc9, 0x7a, 0xd7, 0x6b, 0xf4,
		0x9b, 0xf5, 0xa3, 0x5a, 0x0b, 0xde, 0x0e, 0x5a, 0xa7, 0x4e, 0xeb, 0x0e, 0x6b, 0x7f, 0xce, 0x3d,
		0x1e, 0xb4, 0x0e, 0x5a, 0xa7, 0x96, 0xcc, 0x82, 0x53, 0x40, 0xf3, 0xb4, 0xf8, 0xbb, 0x5e, 0xa3,
		0xdf, 0xe8, 0x7d, 0xae, 0xed, 0xb7, 0x1a, 0xf0, 0x7a, 0xd0, 0x3d, 0xc5, 0xcc, 0xa2, 0xd5, 0x81,
		0xa3, 0x83, 0xb2, 0x29, 0x52, 0xb6, 0x7a, 0xa3, 0x55, 0xfb, 0xe2, 0x7c, 0xae, 0xf5, 0x9a, 0xb5,
		0x19, 0x97, 0x85, 0xde, 0x41, 0xef, 0x64, 0xeb, 0x5d, 0xad, 0xfe, 0xdf, 0x4e, 0xab, 0xd6, 0x36,
		0x64, 0x86, 0x03, 0xd4, 0x8d, 0xba, 0xba, 0x7d, 0xae, 0x35, 0x5b, 0x80, 0x72, 0x50, 0x3b, 0xf5,
		0x5e, 0x0e, 0x1e, 0x0e, 0xaa, 0xa6, 0x82, 0xb1, 0x36, 0xdb, 0x37, 0x59, 0xba, 0x14, 0xd0, 0x41,
		0xeb, 0xa0, 0x75, 0xb2, 0xb5, 0xee, 0xa8, 0x3d, 0xcf, 0x92, 0xe0, 0xf4, 0x15, 0x7a, 0xa7, 0x52,
		0xef, 0x32, 0x65, 0x73, 0xb2, 0xb2, 0xce, 0x01, 0xf2, 0x25, 0x50, 0x3c, 0xe9, 0x8a, 0xd7, 0xf8,
		0x73, 0xd0, 0x68, 0xd7, 0x1b, 0x75, 0xa7, 0x56, 0x9f, 0x45, 0xdc, 0x8f, 0xbd, 0xce, 0x11, 0x4a,
		0x89, 0xa1, 0x77, 0x0a, 0x98, 0x04, 0xd4, 0x0d, 0xea, 0xa6, 0x4c, 0xdd, 0xd2, 0x6a, 0x4e, 0x94,
		0x11, 0x43, 0xf1, 0x54, 0x2b, 0x1e, 0xe8, 0x2b, 0xb4, 0x4d, 0x9d, 0xb6, 0x0d, 0x1a, 0x4e, 0xbd,
		0xf1, 0xa1, 0x76, 0xd4, 0x1a, 0x38, 0x87, 0x8d, 0x41, 0xaf, 0x79, 0x80, 0x41, 0x1c, 0x7a, 0x3f,
		0x18, 0xc4, 0x01, 0x23, 0xcf, 0x35, 0x94, 0x60, 0x40, 0x1d, 0x54, 0x2a, 0x3f, 0x95, 0x32, 0xa8,
		0x8b, 0x18, 0xca, 0x45, 0xd2, 0x5f, 0x99, 0xd0, 0x2d, 0x0c, 0xd5, 0x22, 0x48, 0xe7, 0x4d, 0xea,
		0x0a, 0x86, 0x82, 0x11, 0x54, 0x30, 0xa3, 0xba, 0x7f, 0xa1, 0x61, 0xe4, 0xa0, 0x97, 0x41, 0x5d,
		0xbe, 0xd0, 0x2e, 0x92, 0xd8, 0xcb, 0x98, 0x6e, 0x5e, 0xe8, 0x17, 0x35, 0xfd, 0x32, 0xa9, 0x6b,
		0x17, 0xda, 0x45, 0x4d, 0xbb, 0x4c, 0xea, 0xce, 0x85, 0x76, 0x91, 0x24, 0x8f, 0xc0, 0xf6, 0xd0,
		0x30, 0xa9, 0xfe, 0xcb, 0xac, 0x6e, 0x5b, 0xe8, 0x18, 0x49, 0x84, 0xcf, 0xbb, 0xab, 0x16, 0x4a,
		0x45, 0x52, 0xa9, 0x8c, 0xe9, 0x9e, 0x85, 0x7e, 0x51, 0xd3, 0x2f, 0x23, 0xba, 0x64, 0xa1, 0x56,
		0xe4, 0xd4, 0xca, 0xa4, 0x6e, 0x58, 0xa8, 0x17, 0x45, 0xaf, 0x05, 0x8f, 0x05, 0x95, 0xca, 0x93,
		0x21, 0x1a, 0xd4, 0xdd, 0x0a, 0xed, 0xa2, 0xa6, 0x5d, 0x66, 0x75, 0xb1, 0x42, 0xbf, 0xa8, 0xe9,
		0x97, 0x61, 0xdd, 0xaa, 0x50, 0x30, 0x6a, 0x0a, 0x66, 0x56, 0x57, 0x2a, 0xf4, 0x8b, 0x1e, 0xa2,
		0x87, 0x5a, 0x41, 0xad, 0x72, 0x57, 0x2b, 0xc3, 0xba, 0x4c, 0xa1, 0x60, 0xd4, 0x14, 0x0c, 0x74,
		0x11, 0x5a, 0x95, 0xbf, 0x56, 0x19, 0xd4, 0x35, 0xca, 0xb3, 0x5b, 0x94, 0x5f, 0x97, 0x28, 0xaf,
		0xe7, 0xcc, 0x47, 0x5a, 0x1e, 0x92, 0x32, 0x71, 0xe1, 0x56, 0x2d, 0x08, 0xc2, 0xc4, 0x4d, 0xbc,
		0x30, 0xb0, 0xde, 0x33, 0x72, 0xde, 0x56, 0x3c, 0x3c, 0x13, 0xe7, 0xee, 0xc4, 0x4d, 0xce, 0x66,
		0xee, 0xba, 0x14, 0x4e, 0x44, 0x30, 0x0c, 0x83, 0xb1, 0x77, 0x6a, 0x07, 0x22, 0xf9, 0x11, 0x46,
		0xdf, 0x6d, 0x2f, 0x88, 0x13, 0x37, 0x18, 0x8a, 0xd2, 0xfd, 0x6f, 0xc4, 0x2b, 0xdf, 0x29, 0x4d,
		0xa2, 0x30, 0x09, 0x87, 0xa1, 0x1f, 0x67, 0x5f, 0x95, 0xbc, 0xd8, 0x8b, 0x4b, 0xbe, 0xb8, 0x10,
		0xfe, 0xe2, 0xaf, 0x92, 0xef, 0x05, 0xdf, 0xed, 0x38, 0x71, 0x13, 0x61, 0x8f, 0xdc, 0xc4, 0x3d,
		0x71, 0x63, 0x51, 0xf2, 0xe3, 0x49, 0x29, 0xf1, 0x2f, 0xe2, 0xd9, 0x1f, 0xa5, 0xf3, 0xc4, 0xf6,
		0xe2, 0xa0, 0x14, 0x08, 0xef, 0xf4, 0xec, 0x24, 0x8c, 0xe2, 0xec, 0xab, 0xd2, 0xcd, 0xa5, 0xb3,
		0x4b, 0xc6, 0xd3, 0x93, 0xf4, 0x07, 0xe7, 0x7f, 0x97, 0xa6, 0x33, 0xf1, 0xe3, 0x24, 0x72, 0xbd,
		0x40, 0x8c, 0xec, 0xd9, 0xaf, 0x4d, 0xaf, 0xc4, 0x23, 0xcc, 0xd0, 0x37, 0x49, 0xda, 0x12, 0x12,
		0x77, 0x16, 0xdc, 0x9c, 0x84, 0xf9, 0xce, 0x81, 0xc1, 0xbe, 0x7e, 0x2b, 0x4e, 0xa2, 0xe9, 0x30,
		0x09, 0x16, 0x80, 0xba, 0x3d, 0x7f, 0xaa, 0xcd, 0xc5, 0x1d, 0x3a, 0xdd, 0xc5, 0xa3, 0x74, 0x9a,
		0xb1, 0x17, 0x3b, 0xad, 0xd9, 0x33, 0x74, 0x5a, 0xf1, 0xc4, 0x19, 0xf8, 0x17, 0xce, 0x61, 0xd2,
		0x8c, 0x03, 0xa7, 0xbd, 0x78, 0x3e, 0x4e, 0xf6, 0x33, 0xfd, 0xf4, 0x69, 0x38, 0x47, 0xb7, 0x9f,
		0x46, 0x2b, 0x9e, 0xd0, 0xf6, 0x91, 0x74, 0x3d, 0x0f, 0x61, 0xaf, 0x63, 0x4d, 0x83, 0x48, 0xc4,
		0x22, 0xba, 0x10, 0x23, 0xfb, 0xc4, 0x0d, 0x46, 0x3f, 0xbc, 0x51, 0x6a, 0xcb, 0xb4, 0x7d, 0x4f,
		0xc6, 0x1e, 0x1f, 0x94, 0x9e, 0xb8, 0x8f, 0xff, 0xdd, 0x0b, 0x46, 0xd6, 0xfb, 0x8d, 0x32, 0x71,
		0x31, 0x0f, 0x52, 0x3f, 0x6e, 0xbd, 0xdf, 0xd8, 0x24, 0x2e, 0x68, 0x37, 0x12, 0x63, 0xef, 0x92,
		0x47, 0xbc, 0x5c, 0xea, 0x6d, 0x38, 0xb4, 0x67, 0x91, 0x8d, 0x43, 0x74, 0xe9, 0x87, 0xd3, 0x68,
		0x28, 0xd8, 0x70, 0x16, 0xeb, 0x77, 0x71, 0xf5, 0x23, 0x8c, 0x66, 0x16, 0x66, 0x4d, 0xe6, 0x9a,
		0xc1, 0x84, 0x20, 0x7e, 0x72, 0xe3, 0x5a, 0x74, 0x3a, 0x3d, 0x17, 0x41, 0x62, 0xbd, 0xdf, 0x48,
		0xa2, 0xa9, 0xe0, 0xc2, 0x6c, 0x6f, 0xa4, 0xce, 0x14, 0x1b, 0x3c, 0xc5, 0x68, 0x9e, 0x52, 0xf7,
		0x22, 0x26, 0x04, 0x45, 0x24, 0xd3, 0x89, 0x3d, 0x89, 0xbc, 0x30, 0xf2, 0x92, 0x2b, 0x3e, 0x5e,
		0x6c, 0x19, 0x28, 0xee, 0xc9, 0xcf, 0xc4, 0x23, 0xf0, 0x80, 0x38, 0xec, 0xa0, 0x0e, 0x47, 0xc8,
		0xc3, 0x18, 0xfa, 0x70, 0x85, 0x40, 0xec, 0xa1, 0x10, 0x7b, 0x48, 0xc4, 0x1b, 0x1a, 0xf1, 0x80,
		0x48, 0x4c, 0xa0, 0x12, 0x3b, 0xc8, 0x94, 0x09, 0xcc, 0x0e, 0x34, 0xad, 0x84, 0x1a, 0x66, 0xb0,
		0xe9, 0x3e, 0x7c, 0xda, 0x64, 0x26, 0x36, 0x37, 0x18, 0xc5, 0x19, 0x4e, 0x19, 0x00, 0xab, 0xb8,
		0xc3, 0x2b, 0x63, 0x60, 0x96, 0x31, 0x70, 0xcb, 0x0c, 0xd8, 0xc5, 0x0b, 0x7e, 0x31, 0x83, 0x61,
		0x99, 0x8a, 0x0c, 0xae, 0x26, 0x82, 0xb7, 0xc7, 0xf7, 0x85, 0x3b, 0x8e, 0xc4, 0x98, 0xa3, 0xc7,
		0x5f, 0xe6, 0x87, 0x76, 0x19, 0xca, 0xde, 0x5d, 0x14, 0x3b, 0xbc, 0x7d, 0x3b, 0x2f, 0x1c, 0x2a,
		0x65, 0x28, 0x13, 0x65, 0x88, 0x45, 0xf7, 0x2c, 0xd6, 0xbc, 0x94, 0x8c, 0x2d, 0x61, 0x9a, 0x8b,
		0xcf, 0x93, 0x2d, 0x95, 0xc1, 0x96, 0xc0, 0x96, 0xc0, 0x96, 0xc0, 0x96, 0xc0, 0x96, 0xc0, 0x96,
		0x80, 0x69, 0xf2, 0x55, 0x11, 0x6e, 0xc9, 0xeb, 0x4c, 0x70, 0x3e, 0x35, 0x8d, 0x8f, 0xc6, 0x2c,
		0x2e, 0x05, 0x8e, 0x8f, 0x01, 0xb5, 0x4d, 0xa6, 0xe2, 0x73, 0x05, 0x6c, 0x26, 0x00, 0x37, 0x83,
		0x00, 0x9c, 0x29, 0x40, 0xce, 0x38, 0x40, 0x67, 0x1c, 0xb0, 0x33, 0x0b, 0xe0, 0xf1, 0x04, 0x7a,
		0x4c, 0x01, 0x5f, 0xa6, 0x3a, 0x6c, 0xd3, 0xe4, 0x2b, 0x11, 0xc3, 0x13, 0x42, 0x8c, 0xfd, 0xd0,
		0x4d, 0xb6, 0xb7, 0x38, 0x47, 0x8d, 0x05, 0x88, 0xda, 0x63, 0x7c, 0x0b, 0x2d, 0x11, 0x9c, 0xa6,
		0x80, 0xfc, 0x2b, 0x6b, 0xb7, 0xca, 0x7f, 0x7d, 0xbb, 0x75, 0xe8, 0x05, 0xec, 0xf1, 0x87, 0x21,
		0xf4, 0x62, 0xe5, 0x76, 0x3e, 0xbb, 0xfe, 0x74, 0xe6, 0xb8, 0x2a, 0x86, 0xdc, 0xcf, 0x87, 0xc8,
		0x1d, 0x26, 0x5e, 0x18, 0xd4, 0xbd, 0x53, 0x2f, 0x89, 0x67, 0x2f, 0x8a, 0xfd, 0x7d, 0x5d, 0xff,
		0x66, 0x80, 0x0b, 0x70, 0x2f, 0xe1, 0x02, 0xe0, 0x02, 0xe0, 0x02, 0x8a, 0xc4, 0x46, 0xf8, 0x4b,
		0x7f, 0xfc, 0x0a, 0xcf, 0x1b, 0x21, 0xee, 0x61, 0x37, 0xc3, 0xb6, 0x70, 0x7d, 0x85, 0xb3, 0x32,
		0x2d, 0x60, 0x37, 0x24, 0x1e, 0x23, 0xe3, 0x4f, 0xc9, 0x16, 0x90, 0xf1, 0xa7, 0x63, 0xd6, 0xc8,
		0xf8, 0x13, 0xbf, 0x21, 0x64, 0xfc, 0x81, 0x9c, 0x9e, 0xa9, 0x3a, 0xe6, 0x64, 0xfc, 0xa7, 0x5e,
		0x90, 0xbc, 0x33, 0x20, 0xd7, 0x5f, 0x65, 0x7c, 0x0b, 0x3d, 0x37, 0x38, 0x15, 0x48, 0xf5, 0xeb,
		0x7f, 0x11, 0x48, 0xf5, 0xd3, 0xbd, 0x9d, 0x65, 0x9e, 0x6f, 0x13, 0x79, 0x3e, 0x44, 0x73, 0x89,
		0x2e, 0x00, 0xa9, 0x7e, 0xf2, 0x2e, 0x60, 0x17, 0x2e, 0x00, 0x34, 0x04, 0xd2, 0xdf, 0xfe, 0x20,
		0xd5, 0x0f, 0x89, 0xd9, 0x07, 0x64, 0xae, 0xeb, 0x1f, 0x32, 0xf9, 0xcd, 0x9b, 0xf4, 0xbe, 0x3a,
		0x39, 0xba, 0x74, 0x77, 0xda, 0x22, 0xa7, 0xc5, 0x10, 0xfc, 0x8c, 0x18, 0xd3, 0xc5, 0x72, 0x85,
		0xc3, 0xe2, 0x8a, 0xe1, 0x81, 0xa1, 0xd5, 0xf2, 0xe2, 0xa4, 0x96, 0x24, 0xcc, 0x26, 0xa3, 0x1d,
		0x7a, 0x41, 0xc3, 0x17, 0xe7, 0x22, 0x98, 0x23, 0x5b, 0x46, 0xf3, 0x09, 0x0e, 0xdd, 0xcb, 0x5b,
		0x92, 0x97, 0xdf, 0x55, 0x2a, 0x3b, 0xbb, 0x95, 0xca, 0xe6, 0xee, 0xf6, 0xee, 0xe6, 0x5e, 0xb5,
		0x5a, 0xde, 0x29, 0x33, 0xca, 0x35, 0x5a, 0x9d, 0x68, 0x24, 0x22, 0x31, 0xda, 0x9f, 0x69, 0x7e,
		0x30, 0xf5, 0x7d, 0x38, 0x14, 0xe0, 0x95, 0x22, 0xe2, 0x14, 0x8b, 0xd5, 0x80, 0x14, 0x49, 0xbb,
		0x6a, 0xfa, 0xb3, 0x47, 0xd2, 0x65, 0x35, 0x8a, 0x07, 0xcb, 0xbc, 0x8c, 0x76, 0xa5, 0x58, 0xe6,
		0x45, 0xd0, 0x75, 0x62, 0x85, 0x95, 0x71, 0xb6, 0x66, 0x4d, 0x13, 0xcf, 0xf7, 0xfe, 0xcd, 0x74,
		0x81, 0xd5, 0xaa, 0xec, 0x58, 0x5f, 0x95, 0x87, 0x98, 0x58, 0x5f, 0x25, 0x51, 0x6b, 0xb1, 0xbe,
		0x4a, 0x66, 0x22, 0x07, 0xeb, 0xab, 0xd4, 0xc2, 0x34, 0xac, 0xaf, 0x2a, 0x1a, 0x32, 0xe7, 0xb3,
		0xbe, 0x8a, 0xd5, 0x3c, 0x51, 0x96, 0x73, 0x44, 0xb1, 0xac, 0x0a, 0x00, 0xc7, 0x00, 0xa0, 0xc3,
		0x15, 0xf0, 0xb0, 0x07, 0x3e, 0xec, 0x01, 0x10, 0x6f, 0x20, 0xc4, 0x03, 0x10, 0x31, 0x01, 0x46,
		0xec, 0x00, 0x52, 0x26, 0x30, 0xdf, 0x39, 0x9f, 0xec, 0xe7, 0x7b, 0x62, 0x5d, 0x15, 0x00, 0x55,
		0x01, 0x80, 0x15, 0x77, 0x80, 0x65, 0x0c, 0xd0, 0x32, 0x06, 0x70, 0x99, 0x01, 0xbc, 0x78, 0x01,
		0x30, 0x66, 0x40, 0x2c, 0x53, 0x11, 0xfe, 0xeb, 0xaa, 0x78, 0xcf, 0xdf, 0x64, 0x3c, 0x77, 0x93,
		0xfb, 0xbc, 0x4d, 0xc6, 0x9d, 0xe8, 0x26, 0x34, 0xdd, 0x1a, 0xd2, 0x69, 0x67, 0xca, 0x30, 0x3d,
		0x93, 0x3a, 0xeb, 0x18, 0x37, 0xd5, 0x1a, 0xd1, 0x4c, 0x0b, 0xd3, 0x86, 0x69, 0x83, 0x0d, 0xb0,
		0x96, 0xfa, 0x18, 0xdd, 0x69, 0x45, 0x0f, 0x4d, 0x56, 0xc2, 0x91, 0x1b, 0x66, 0xbc, 0x30, 0x95,
		0x1e, 0x19, 0x6f, 0x15, 0x62, 0x23, 0xe3, 0xad, 0x51, 0xcf, 0x91, 0xf1, 0xd6, 0x67, 0xae, 0xc8,
		0x78, 0x13, 0xbb, 0x11, 0x64, 0xbc, 0x81, 0x68, 0x1e, 0x51, 0x11, 0x03, 0x32, 0xde, 0x23, 0x11,
		0x24, 0x5e, 0x72, 0x15, 0x89, 0x31, 0xe3, 0x8c, 0x77, 0x99, 0xe1, 0xf8, 0x49, 0xab, 0xb9, 0x78,
		0xf4, 0xfb, 0x6e, 0x2c, 0xf8, 0x8f, 0x81, 0x6f, 0xf6, 0x9b, 0x7d, 0xa7, 0x7f, 0xb4, 0x3f, 0x68,
		0x7d, 0x76, 0x06, 0x5f, 0xba, 0x0d, 0xae, 0xe1, 0x2b, 0xcd, 0xd3, 0xc4, 0xac, 0xa7, 0x81, 0x32,
		0x4f, 0xf8, 0x65, 0x1a, 0xd5, 0x75, 0x7a, 0x8d, 0xda, 0xc1, 0xa7, 0xda, 0x7e, 0xb3, 0xd5, 0x1c,
		0x7c, 0x59, 0x28, 0x57, 0x9f, 0xb3, 0x76, 0x99, 0xa4, 0x65, 0x66, 0x68, 0xdb, 0xa3, 0x5a, 0xd7,
		0xed, 0x35, 0x3e, 0x34, 0xff, 0x74, 0x3e, 0xb4, 0x6a, 0x1f, 0xfb, 0x16, 0x46, 0x84, 0x42, 0xdf,
		0x24, 0xeb, 0x5b, 0xb3, 0xfb, 0xb9, 0xe2, 0xf4, 0x3a, 0x47, 0x83, 0x46, 0xcf, 0x69, 0xd6, 0xa1,
		0x71, 0xd0, 0x38, 0xd9, 0x1a, 0x37, 0xa8, 0x7d, 0x84, 0x9a, 0x41, 0xcd, 0x14, 0xa8, 0xd9, 0x4e,
		0x05, 0x8a, 0x06, 0x45, 0x53, 0x10, 0x41, 0x77, 0x10, 0x41, 0xa1, 0x71, 0xca, 0x39, 0x42, 0xdf,
		0x08, 0x6d, 0x63, 0x7d, 0x07, 0xc7, 0xa8, 0x33, 0x83, 0x75, 0x83, 0xf9, 0x43, 0xaf, 0xc0, 0xf0,
		0xa1, 0x59, 0x85, 0xd3, 0x2c, 0xd6, 0x4c, 0x1e, 0xea, 0x04, 0xc6, 0x0e, 0x85, 0x32, 0x3d, 0xf2,
		0xed, 0x20, 0xf2, 0x41, 0xb3, 0xc0, 0xc0, 0xa1, 0x55, 0x14, 0xb5, 0x6a, 0xe1, 0x9a, 0x0e, 0x6a,
		0x5d, 0xd4, 0x1c, 0x40, 0xdf, 0xb4, 0xea, 0x5d, 0xcf, 0xa9, 0xb5, 0x3e, 0x76, 0x7a, 0xcd, 0xc1,
		0xa7, 0x43, 0x64, 0xb0, 0xa1, 0x71, 0x4a, 0x34, 0xee, 0xe6, 0x5f, 0x48, 0x63, 0xeb, 0xfd, 0x20,
		0x8d, 0x0d, 0x13, 0x47, 0x30, 0x81, 0x66, 0x21, 0x68, 0x40, 0xb5, 0x8a, 0xc1, 0xe7, 0xfb, 0xa8,
		0xf5, 0x86, 0xb6, 0xe9, 0xd6, 0xba, 0x56, 0xb3, 0xfd, 0x3b, 0x4a, 0x86, 0xa0, 0x6a, 0x0a, 0x54,
		0xed, 0xa8, 0x7d, 0xd0, 0x69, 0xf7, 0x07, 0xbd, 0x5a, 0xb3, 0xdd, 0xa8, 0x3b, 0xad, 0x7e, 0x17,
		0x4a, 0x07, 0xa5, 0x53, 0xe2, 0xdf, 0x6a, 0x83, 0x41, 0xaf, 0xb9, 0x7f, 0x34, 0x68, 0xa0, 0x9d,
		0x05, 0x2a, 0x27, 0x5d, 0xe5, 0xd2, 0x23, 0xbf, 0x76, 0xa3, 0xf9, 0xf1, 0xd3, 0x7e, 0xa7, 0xe7,
		0xd4, 0xea, 0xf5, 0x5e, 0xa3, 0x0f, 0xc5, 0x83, 0xe2, 0xa9, 0x50, 0xbc, 0x8a, 0xd3, 0x6c, 0x0f,
		0x1a, 0xbd, 0x0f, 0xb5, 0x83, 0x06, 0x34, 0x0f, 0x9a, 0xa7, 0x0c, 0xda, 0x0d, 0x9a, 0xad, 0xe6,
		0xff, 0x34, 0xea, 0xce, 0x7e, 0xad, 0x5d, 0xff, 0xa3, 0x59, 0x1f, 0x7c, 0x82, 0xd6, 0x41, 0xeb,
		0x94, 0x60, 0xbb, 0x6e, 0xaf, 0x33, 0x68, 0x1c, 0x0c, 0x9a, 0x9d, 0xf6, 0x3c, 0x73, 0x02, 0xbd,
		0x83, 0xde, 0x49, 0xd6, 0xbb, 0x5e, 0xa3, 0xdf, 0xac, 0x1f, 0xd5, 0x5a, 0xf0, 0x76, 0xd0, 0x3a,
		0x75, 0x5a, 0x77, 0x58, 0xfb, 0x73, 0xee, 0xf1, 0xa0, 0x75, 0xd0, 0x3a, 0xb5, 0x64, 0x16, 0x9c,
		0x02, 0x9a, 0xa7, 0xc5, 0xdf, 0xf5, 0x1a, 0xfd, 0x46, 0xef, 0x73, 0x6d, 0xbf, 0xd5, 0x80, 0xd7,
		0x83, 0xee, 0x29, 0x66, 0x16, 0xad, 0x0e, 0x1c, 0x1d, 0x94, 0x4d, 0x91, 0xb2, 0xd5, 0x1b, 0xad,
		0xda, 0x17, 0xe7, 0x73, 0xad, 0xd7, 0xac, 0xcd, 0xb8, 0x2c, 0xf4, 0x0e, 0x7a, 0x27, 0x5b, 0xef,
		0x6a, 0xf5, 0xff, 0x76, 0x5a, 0xb5, 0xb6, 0x21, 0x33, 0x1c, 0xa0, 0x6e, 0xd4, 0xd5, 0xed, 0x73,
		0xad, 0xd9, 0x02, 0x94, 0x83, 0xda, 0xa9, 0xf7, 0x72, 0xf0, 0x70, 0x50, 0x35, 0x15, 0x8c, 0xb5,
		0xd9, 0xbe, 0xc9, 0xd2, 0xa5, 0x80, 0x0e, 0x5a, 0x07, 0xad, 0x93, 0xad, 0x75, 0x47, 0xed, 0x79,
		0x96, 0x04, 0xa7, 0xaf, 0xd0, 0x3b, 0x95, 0x7a, 0x97, 0x29, 0x9b, 0x93, 0x95, 0x75, 0x0e, 0x90,
		0x2f, 0x81, 0xe2, 0x49, 0x57, 0xbc, 0xc6, 0x9f, 0x83, 0x46, 0xbb, 0xde, 0xa8, 0x3b, 0xb5, 0xfa,
		0x2c, 0xe2, 0x7e, 0xec, 0x75, 0x8e, 0x50, 0x4a, 0x0c, 0xbd, 0x53, 0xc0, 0x24, 0xa0, 0x6e, 0x50,
		0x37, 0x65, 0xea, 0x96, 0x56, 0x73, 0xa2, 0x8c, 0x18, 0x8a, 0xa7, 0x5a, 0xf1, 0x40, 0x5f, 0xa1,
		0x6d, 0xea, 0xb4, 0x6d, 0xd0, 0x70, 0xea, 0x8d, 0x0f, 0xb5, 0xa3, 0xd6, 0xc0, 0x39, 0x6c, 0x0c,
		0x7a, 0xcd, 0x03, 0x0c, 0xe2, 0xd0, 0xfb, 0xc1, 0x20, 0x0e, 0x18, 0x79, 0xae, 0xa1, 0x04, 0x03,
		0xea, 0xa0, 0x52, 0xf9, 0xa9, 0x94, 0x41, 0x5d, 0xc4, 0x50, 0x2e, 0x92, 0xfe, 0xca, 0x84, 0x6e,
		0x61, 0xa8, 0x16, 0x41, 0x3a, 0x6f, 0x52, 0x57, 0x30, 0x14, 0x8c, 0xa0, 0x82, 0x19, 0xd5, 0xfd,
		0x0b, 0x0d, 0x23, 0x07, 0xbd, 0x0c, 0xea, 0xf2, 0x85, 0x76, 0x91, 0xc4, 0x5e, 0xc6, 0x74, 0xf3,
		0x42, 0xbf, 0xa8, 0xe9, 0x97, 0x49, 0x5d, 0xbb, 0xd0, 0x2e, 0x6a, 0xda, 0x65, 0x52, 0x77, 0x2e,
		0xb4, 0x8b, 0x24, 0x79, 0x04, 0xb6, 0x87, 0x86, 0x49, 0xf5, 0x5f, 0x66, 0x75, 0xdb, 0x42, 0xc7,
		0x48, 0x22, 0x7c, 0xde, 0x5d, 0xb5, 0x50, 0x2a, 0x92, 0x4a, 0x65, 0x4c, 0xf7, 0x2c, 0xf4, 0x8b,
		0x9a, 0x7e, 0x19, 0xd1, 0x25, 0x0b, 0xb5, 0x22, 0xa7, 0x56, 0x26, 0x75, 0xc3, 0x42, 0xbd, 0x28,
		0x7a, 0x2d, 0x78, 0x2c, 0xa8, 0x54, 0x9e, 0x0c, 0xd1, 0xa0, 0xee, 0x56, 0x68, 0x17, 0x35, 0xed,
		0x32, 0xab, 0x8b, 0x15, 0xfa, 0x45, 0x4d, 0xbf, 0x0c, 0xeb, 0x56, 0x85, 0x82, 0x51, 0x53, 0x30,
		0xb3, 0xba, 0x52, 0xa1, 0x5f, 0xf4, 0x10, 0x3d, 0xd4, 0x0a, 0x6a, 0x95, 0xbb, 0x5a, 0x19, 0xd6,
		0x65, 0x0a, 0x05, 0xa3, 0xa6, 0x60, 0xa0, 0x8b, 0xd0, 0xaa, 0xfc, 0xb5, 0xca, 0xa0, 0xae, 0x51,
		0x9e, 0xdd, 0xa2, 0xfc, 0xba, 0x44, 0x79, 0x3d, 0x67, 0x3e, 0xd2, 0xf2, 0x90, 0x94, 0x89, 0x0b,
		0xb7, 0x6a, 0x41, 0x10, 0x26, 0x6e, 0xe2, 0x85, 0x81, 0xf5, 0x9e, 0x91, 0xf3, 0xb6, 0xe2, 0xe1,
		0x99, 0x38, 0x77, 0x27, 0x6e, 0x72, 0x36, 0x73, 0xd7, 0xa5, 0x70, 0x22, 0x82, 0x61, 0x18, 0x8c,
		0xbd, 0x53, 0x3b, 0x10, 0xc9, 0x8f, 0x30, 0xfa, 0x6e, 0x7b, 0x41, 0x9c, 0xb8, 0xc1, 0x50, 0x94,
		0xee, 0x7f, 0x23, 0x5e, 0xf9, 0x4e, 0x69, 0x12, 0x85, 0x49, 0x38, 0x0c, 0xfd, 0x38, 0xfb, 0xaa,
		0xe4, 0xc5, 0x5e, 0x5c, 0xf2, 0xc5, 0x85, 0xf0, 0x17, 0x7f, 0x95, 0x7c, 0x2f, 0xf8, 0x6e, 0xc7,
		0x89, 0x9b, 0x08, 0x7b, 0xe4, 0x26, 0xee, 0x89, 0x1b, 0x8b, 0x92, 0x1f, 0x4f, 0x4a, 0x89, 0x7f,
		0x11, 0xcf, 0xfe, 0x28, 0x9d, 0x27, 0xb6, 0x17, 0x07, 0xa5, 0x40, 0x78, 0xa7, 0x67, 0x27, 0x61,
		0x14, 0x67, 0x5f, 0x95, 0x6e, 0x2e, 0x9d, 0x5d, 0x32, 0x9e, 0x9e, 0xa4, 0x3f, 0x38, 0xff, 0xbb,
		0x34, 0x4d, 0x3c, 0xdf, 0xfb, 0xb7, 0x18, 0xd9, 0x27, 0x6e, 0x30, 0xfa, 0xe1, 0x8d, 0x92, 0xb3,
		0x52, 0x7a, 0x29, 0x1e, 0x71, 0x86, 0xbe, 0x4d, 0xd2, 0x96, 0x90, 0xb8, 0xb7, 0xe0, 0xe6, 0x25,
		0x0a, 0xe0, 0x1d, 0x18, 0x6c, 0xec, 0xb7, 0xe2, 0x24, 0x9a, 0x0e, 0x93, 0x60, 0x01, 0xa9, 0xdb,
		0xf3, 0xc7, 0xda, 0x5c, 0xdc, 0xa2, 0xd3, 0x5d, 0x3c, 0x4b, 0xa7, 0x19, 0x7b, 0xb1, 0xd3, 0x9a,
		0x3d, 0x44, 0xa7, 0x15, 0x4f, 0x9c, 0x81, 0x7f, 0xe1, 0x1c, 0x26, 0xcd, 0x38, 0x70, 0xda, 0x8b,
		0x07, 0xe4, 0x64, 0x3f, 0xd3, 0x4f, 0x1f, 0x87, 0x73, 0xb4, 0x78, 0x1c, 0xfb, 0xd9, 0xd3, 0x78,
		0x05, 0xdf, 0x63, 0x8e, 0x64, 0x44, 0xbd, 0xa1, 0xf5, 0xbb, 0xb8, 0x9a, 0x29, 0x72, 0x72, 0x35,
		0x11, 0x44, 0xcd, 0xcf, 0x6a, 0x79, 0x71, 0x52, 0x4b, 0x92, 0x88, 0xb4, 0x9b, 0xb6, 0x0e, 0xbd,
		0xa0, 0xe1, 0x8b, 0x73, 0x11, 0x24, 0xb1, 0xf5, 0x7e, 0x63, 0xf3, 0x37, 0xc2, 0x92, 0xba, 0x97,
		0xb7, 0x24, 0x2d, 0xbf, 0xab, 0x54, 0x76, 0x76, 0x2b, 0x95, 0xcd, 0xdd, 0xed, 0xdd, 0xcd, 0xbd,
		0x6a, 0xb5, 0xbc, 0x53, 0xae, 0x12, 0x16, 0xbe, 0x13, 0x8d, 0x44, 0x24, 0x46, 0xfb, 0x33, 0xad,
		0x0d, 0xa6, 0xbe, 0x0f, 0x63, 0x37, 0x0f, 0xf2, 0x98, 0x06, 0x75, 0x08, 0xe3, 0x1a, 0x69, 0x78,
		0x86, 0x26, 0x7a, 0xa1, 0x87, 0x0d, 0x68, 0x49, 0x44, 0xcc, 0x71, 0x51, 0x77, 0x58, 0xc6, 0x38,
		0x2a, 0x5a, 0xd6, 0x4a, 0xc7, 0x26, 0x08, 0xd9, 0x83, 0x35, 0x0d, 0x46, 0x62, 0xec, 0x05, 0x62,
		0x64, 0x2f, 0x5f, 0x1a, 0x35, 0x93, 0xc8, 0x4e, 0x9a, 0x56, 0x45, 0x25, 0xe6, 0x57, 0x7e, 0xf7,
		0x82, 0xd1, 0x0c, 0xfb, 0x12, 0x13, 0xeb, 0x20, 0xf5, 0x1d, 0xf4, 0xe8, 0x83, 0xd5, 0x8d, 0xc4,
		0xd8, 0xbb, 0xa4, 0xe9, 0x83, 0x97, 0x4a, 0x17, 0x0e, 0xed, 0x99, 0xb7, 0x24, 0x08, 0xb6, 0xac,
		0x7e, 0x38, 0x8d, 0x86, 0x82, 0x2c, 0xe6, 0xb6, 0x7e, 0x17, 0x57, 0x3f, 0xc2, 0x68, 0x66, 0x11,
		0xd6, 0x64, 0xfe, 0xa6, 0x89, 0x12, 0x98, 0x4f, 0x6e, 0x5c, 0x8b, 0x4e, 0xa7, 0x33, 0xee, 0x6a,
		0xbd, 0xdf, 0x48, 0xa2, 0xa9, 0xa0, 0xca, 0xb4, 0x6e, 0xa4, 0xcc, 0x14, 0x13, 0xd8, 0x93, 0x15,
		0xf6, 0xac, 0x7b, 0x34, 0x33, 0x4e, 0x2b, 0xd1, 0x95, 0xae, 0x5f, 0x59, 0x87, 0x07, 0xa8, 0xba,
		0x17, 0x9a, 0xb0, 0x80, 0x3c, 0x3c, 0xe0, 0x00, 0x13, 0x18, 0xc1, 0x05, 0x2e, 0xb0, 0x81, 0x1d,
		0x7c, 0x60, 0x07, 0x23, 0x78, 0xc1, 0x09, 0x9a, 0xb0, 0x82, 0x28, 0xbc, 0x20, 0x0f, 0x33, 0x32,
		0x01, 0xe7, 0x25, 0x3b, 0xe4, 0x9d, 0xd0, 0xd2, 0xaf, 0xcf, 0xc5, 0x25, 0x6e, 0xcf, 0xb4, 0x81,
		0x06, 0x1b, 0xc0, 0xc1, 0x09, 0x78, 0x30, 0x04, 0x20, 0xdc, 0x80, 0x08, 0x5b, 0x40, 0xc2, 0x16,
		0x98, 0xf0, 0x04, 0x28, 0xb4, 0x81, 0x0a, 0x71, 0xc0, 0xc2, 0x06, 0xb8, 0x64, 0x82, 0xfa, 0x22,
		0x38, 0x4d, 0x0f, 0xe8, 0x98, 0x78, 0xaf, 0x65, 0x80, 0x58, 0xc8, 0xcd, 0xc4, 0x03, 0x2c, 0x20,
		0xcd, 0x26, 0x13, 0x71, 0xb9, 0x40, 0x1b, 0x8e, 0x10, 0x87, 0x31, 0xd4, 0xe1, 0x0a, 0x79, 0xd8,
		0x43, 0x1f, 0xf6, 0x10, 0x88, 0x37, 0x14, 0xe2, 0x01, 0x89, 0x98, 0x40, 0xa3, 0x4c, 0x15, 0x06,
		0x57, 0x13, 0xc1, 0xd3, 0x63, 0x4f, 0xbd, 0x20, 0x79, 0xc7, 0xc9, 0x5f, 0x2f, 0xe0, 0x47, 0x95,
		0x91, 0xc8, 0x3d, 0x37, 0x38, 0x9d, 0x3d, 0xec, 0xaf, 0xac, 0xfc, 0x1b, 0xbf, 0x66, 0x78, 0xeb,
		0xd0, 0x0b, 0xd8, 0x05, 0x72, 0xa6, 0xb8, 0x7a, 0x45, 0xfc, 0xcf, 0xae, 0x3f, 0x15, 0x8c, 0xe5,
		0xff, 0x10, 0xb9, 0xc3, 0xc4, 0x0b, 0x83, 0xba, 0x77, 0xea, 0xcd, 0x3b, 0x3b, 0xf8, 0x35, 0xed,
		0xff, 0xc6, 0xd0, 0x64, 0xdd, 0x4b, 0x98, 0xac, 0x66, 0x93, 0xdd, 0xaa, 0x56, 0x61, 0xb4, 0x00,
		0xe2, 0x66, 0x49, 0x7b, 0x8c, 0xd9, 0x03, 0x45, 0x09, 0x2a, 0xf3, 0xa6, 0x56, 0x76, 0x69, 0x5f,
		0xc2, 0xad, 0xb8, 0xcc, 0x23, 0x1d, 0x92, 0xbe, 0x2a, 0xf5, 0x18, 0x49, 0x5f, 0x75, 0x66, 0x88,
		0xa4, 0xaf, 0xe6, 0x1b, 0x40, 0xd2, 0x17, 0x88, 0x63, 0xa1, 0x0a, 0x48, 0xfa, 0xaa, 0x86, 0x1f,
		0x48, 0xfa, 0xca, 0xfe, 0x20, 0xe9, 0x0b, 0x5c, 0xfd, 0x04, 0xf1, 0x91, 0xf4, 0x45, 0xb4, 0x7c,
		0x8e, 0xc9, 0x22, 0xe9, 0xab, 0xdd, 0x64, 0x91, 0xf4, 0x05, 0x10, 0x37, 0x4e, 0x5a, 0x24, 0x7d,
		0x0b, 0x13, 0x54, 0xac, 0x8b, 0x85, 0x23, 0x63, 0x96, 0xf5, 0x9d, 0x8b, 0x8d, 0xb4, 0xaf, 0x0c,
		0x71, 0x91, 0xf6, 0x55, 0xa8, 0xc8, 0x48, 0xfb, 0xaa, 0x33, 0x43, 0xa4, 0x7d, 0x35, 0xdf, 0x00,
		0xd2, 0xbe, 0xc0, 0x1c, 0x0b, 0x55, 0xe0, 0x9b, 0xf6, 0x3d, 0xf1, 0x02, 0x37, 0xba, 0x62, 0x98,
		0xf7, 0xdd, 0x03, 0xac, 0x2f, 0x80, 0x84, 0xd8, 0x23, 0x91, 0xaf, 0xbc, 0xec, 0x67, 0x96, 0xae,
		0x4c, 0x97, 0x5c, 0xf9, 0x0e, 0x87, 0x35, 0x33, 0x84, 0x17, 0x28, 0x10, 0x1e, 0x89, 0xc4, 0xa2,
		0xa4, 0x8b, 0x53, 0x29, 0x17, 0x13, 0x2e, 0x8f, 0x51, 0x24, 0xe0, 0xec, 0x1b, 0x18, 0x45, 0x02,
		0x6e, 0x6e, 0x28, 0x27, 0x07, 0x04, 0x2f, 0x04, 0xf7, 0xbe, 0x35, 0xdb, 0xc3, 0x1d, 0x47, 0x62,
		0xcc, 0xc1, 0xe3, 0x2e, 0x67, 0x95, 0xed, 0x32, 0x90, 0xb5, 0xbb, 0x60, 0x35, 0x6f, 0xdf, 0xce,
		0x29, 0x40, 0x29, 0x45, 0x60, 0xe0, 0x01, 0x06, 0x49, 0x86, 0x45, 0x6a, 0xcf, 0x16, 0x11, 0x8b,
		0xd4, 0x72, 0x96, 0x14, 0x8b, 0xd4, 0x0a, 0x6a, 0xec, 0x58, 0xa4, 0x46, 0x26, 0xd7, 0x57, 0xac,
		0xe5, 0x6a, 0x47, 0xcb, 0xbb, 0xc7, 0x96, 0x35, 0xbe, 0x12, 0x61, 0xcb, 0x5a, 0xd1, 0xbd, 0x18,
		0xf6, 0xad, 0x51, 0x96, 0x84, 0x88, 0x7d, 0x2e, 0x29, 0x85, 0x37, 0x22, 0x12, 0xe3, 0x68, 0x12,
		0x08, 0xba, 0x84, 0x81, 0x15, 0x41, 0xa0, 0x49, 0x08, 0xa8, 0x98, 0x22, 0xd1, 0x10, 0xc9, 0x3e,
		0x34, 0x12, 0x42, 0xef, 0xf9, 0xa3, 0x75, 0x1a, 0x51, 0x5e, 0x7f, 0x4c, 0xd5, 0x2b, 0x81, 0x66,
		0x17, 0x42, 0xcd, 0x75, 0x70, 0x75, 0x19, 0x7a, 0x8d, 0x49, 0x9f, 0x0a, 0x6b, 0x54, 0x5f, 0x6b,
		0xf6, 0x5a, 0x46, 0xda, 0xb5, 0x36, 0x3b, 0x34, 0x9b, 0x8b, 0xa3, 0xd9, 0x9c, 0x69, 0xd4, 0xcb,
		0x90, 0xa9, 0x87, 0xa1, 0x54, 0xef, 0x42, 0xb0, 0x9e, 0x85, 0x5a, 0xbd, 0x0a, 0xd9, 0x7a, 0x14,
		0xb2, 0xf5, 0x26, 0x34, 0xeb, 0x49, 0x8a, 0x0d, 0xa9, 0xc8, 0xd4, 0x7b, 0x10, 0xac, 0xe7, 0xa0,
		0x54, 0xaf, 0xb1, 0x5a, 0x8f, 0x31, 0x0f, 0xe1, 0x80, 0x72, 0x1a, 0xc8, 0x2d, 0x85, 0x2d, 0x8e,
		0xa4, 0xb6, 0x34, 0x12, 0xd9, 0xc2, 0x08, 0x28, 0x07, 0x28, 0x07, 0x28, 0x07, 0x28, 0x57, 0x4c,
		0x28, 0x47, 0x65, 0x8b, 0x20, 0x91, 0x5c, 0x07, 0xc9, 0x9c, 0x07, 0xb1, 0xdc, 0x07, 0xb9, 0xc0,
		0x49, 0x31, 0x80, 0x12, 0x0e, 0xa4, 0x54, 0x03, 0x2a, 0xf9, 0xc0, 0x4a, 0x3e, 0xc0, 0xd2, 0x0e,
		0xb4, 0x34, 0x02, 0x2e, 0x91, 0xc0, 0x4b, 0x2f, 0x97, 0xb2, 0xe2, 0xb1, 0xa6, 0x5e, 0x90, 0x94,
		0x77, 0x28, 0x39, 0xac, 0x45, 0xfc, 0xdb, 0x21, 0x24, 0x12, 0xcd, 0x79, 0xc2, 0x04, 0x8b, 0x08,
		0x29, 0xcf, 0x03, 0x26, 0xde, 0x84, 0x4d, 0x7d, 0x9e, 0x2f, 0x87, 0xd1, 0x9f, 0x04, 0x3b, 0x19,
		0x48, 0xcf, 0xdb, 0xe5, 0x62, 0x12, 0x95, 0xcd, 0xbd, 0x2a, 0xac, 0x82, 0x37, 0x14, 0xa3, 0x27,
		0xcd, 0x31, 0x2a, 0xc7, 0xa8, 0x78, 0x4d, 0x2b, 0xbe, 0x8a, 0x13, 0x71, 0x4e, 0x32, 0x39, 0x74,
		0x23, 0x1a, 0x12, 0x44, 0x0f, 0x89, 0x83, 0x04, 0xd1, 0x13, 0x94, 0x09, 0x09, 0xa2, 0x5f, 0x57,
		0x73, 0x24, 0x88, 0x5e, 0x28, 0x20, 0x12, 0x44, 0x5c, 0x18, 0x03, 0xe1, 0x04, 0x11, 0xb5, 0xf0,
		0x77, 0x3b, 0x04, 0x96, 0xdf, 0x11, 0x92, 0xa9, 0xeb, 0x26, 0x89, 0x88, 0x02, 0x72, 0x69, 0x22,
		0xeb, 0x7f, 0xbf, 0x6e, 0xda, 0x7b, 0x35, 0xfb, 0x83, 0x6b, 0x8f, 0x8f, 0xff, 0xaa, 0x5c, 0x7f,
		0xfb, 0xf6, 0xf6, 0x91, 0x6f, 0xfc, 0x07, 0x1d, 0x2f, 0x71, 0x4c, 0xe9, 0x05, 0x77, 0xfa, 0xcd,
		0x3f, 0xf1, 0x96, 0xc1, 0xc4, 0x0c, 0x95, 0x00, 0x3d, 0x3c, 0xf7, 0x38, 0x29, 0xab, 0x1e, 0x1e,
		0x02, 0xd3, 0x78, 0x0b, 0x5a, 0xf4, 0x49, 0x26, 0x75, 0x41, 0x0e, 0xb3, 0xa1, 0x8f, 0x87, 0x6e,
		0x6a, 0x02, 0xc5, 0x9f, 0x7c, 0x53, 0x10, 0x28, 0xfe, 0x04, 0xac, 0xe2, 0x97, 0x5a, 0x40, 0x1f,
		0xcf, 0xa3, 0x09, 0x84, 0xbb, 0x7d, 0x3c, 0x37, 0x61, 0xbc, 0xa8, 0xb0, 0xee, 0x55, 0x81, 0x0c,
		0x76, 0x39, 0x89, 0x28, 0x2d, 0x46, 0xde, 0xd0, 0x0d, 0xe1, 0x68, 0x8c, 0x21, 0xa2, 0x33, 0x76,
		0x88, 0xf4, 0x98, 0x21, 0x1a, 0x63, 0x85, 0x74, 0xd9, 0x0d, 0x91, 0xbc, 0x01, 0xaf, 0x7c, 0x81,
		0xa5, 0xb5, 0x4d, 0x32, 0x9f, 0x19, 0x40, 0x7a, 0xc2, 0xa2, 0xfa, 0xa0, 0xa4, 0xf6, 0x8a, 0x8a,
		0xcd, 0x58, 0xb7, 0xf9, 0xb2, 0x30, 0x5b, 0xb5, 0x9a, 0xae, 0x4e, 0xdf, 0xd4, 0x5c, 0x49, 0x91,
		0x46, 0xeb, 0xd2, 0x64, 0xc2, 0x1a, 0xac, 0x30, 0xca, 0xbc, 0x34, 0xaa, 0xa8, 0x31, 0x31, 0xf9,
		0x0a, 0xaf, 0x40, 0xd9, 0xad, 0xf3, 0xa9, 0x9f, 0x78, 0x76, 0x12, 0x4e, 0x42, 0x3f, 0x3c, 0xbd,
		0x52, 0xa6, 0xec, 0x37, 0xfd, 0x9a, 0x77, 0xaf, 0xaf, 0xc8, 0xbc, 0xd5, 0x4e, 0x32, 0x50, 0x9e,
		0xb4, 0xd6, 0x91, 0x9c, 0xd6, 0x98, 0x84, 0xd6, 0x95, 0x6c, 0xd6, 0x9e, 0x54, 0xd6, 0x9e, 0x3c,
		0xd6, 0x9b, 0x24, 0x36, 0x0b, 0x72, 0xa8, 0xee, 0xec, 0xb7, 0x16, 0x4e, 0xd7, 0x13, 0xb1, 0x7a,
		0xcb, 0xc9, 0x36, 0x7e, 0xde, 0xc8, 0xa0, 0x58, 0x73, 0xf5, 0x0c, 0xb3, 0xd1, 0x76, 0x7e, 0xa9,
		0xf3, 0xbc, 0x92, 0xc0, 0xf9, 0xa4, 0xee, 0xf3, 0x48, 0x32, 0xe7, 0x8f, 0x64, 0xce, 0x1b, 0x69,
		0x9c, 0x2f, 0x9a, 0x9d, 0x8f, 0xd1, 0x35, 0x2c, 0xc6, 0x52, 0xce, 0x27, 0x1e, 0x0b, 0x30, 0x57,
		0xba, 0xcc, 0x4d, 0xef, 0xcc, 0x34, 0xed, 0xe5, 0x32, 0x14, 0xca, 0x64, 0x08, 0x95, 0xc7, 0x50,
		0x29, 0x8b, 0x21, 0x57, 0x0e, 0x43, 0xae, 0x0c, 0x86, 0x56, 0xf9, 0x4b, 0xb1, 0x4e, 0xcf, 0x75,
		0xcf, 0x38, 0xc3, 0x1c, 0xf7, 0xf5, 0x81, 0x0c, 0xf5, 0x9f, 0x74, 0x02, 0x1b, 0xc1, 0x00, 0x47,
		0x2d, 0xd0, 0x91, 0x0d, 0x78, 0x64, 0x03, 0x1f, 0xcd, 0x00, 0xa8, 0x37, 0x10, 0x6a, 0x0e, 0x88,
		0xd9, 0x2b, 0x41, 0xfd, 0xe7, 0x2f, 0x30, 0x2d, 0xcc, 0x71, 0xa7, 0x66, 0x3a, 0x98, 0xe3, 0x8e,
		0x39, 0xee, 0x80, 0x72, 0x80, 0x72, 0x80, 0x72, 0x80, 0x72, 0x80, 0x72, 0x34, 0x72, 0x1c, 0x99,
		0x20, 0x6e, 0x92, 0x44, 0xde, 0xc9, 0x34, 0xd1, 0x70, 0x0a, 0xfc, 0xa8, 0x13, 0xbc, 0x25, 0x1b,
		0x06, 0x76, 0x51, 0x0e, 0xa1, 0x14, 0x43, 0x29, 0xe1, 0x90, 0x4a, 0x35, 0xb4, 0x92, 0x0f, 0xb1,
		0xe4, 0x43, 0x2d, 0xed, 0x90, 0x4b, 0x23, 0xf4, 0x12, 0x09, 0xc1, 0xf4, 0xb2, 0x2a, 0x2b, 0x1e,
		0x4b, 0x04, 0xd3, 0x73, 0x11, 0xcd, 0xcb, 0xd0, 0x09, 0x8e, 0xec, 0xaa, 0x10, 0x92, 0xa9, 0x11,
		0x4c, 0xcf, 0x67, 0x2f, 0xf1, 0x1a, 0xf3, 0x87, 0xa8, 0x18, 0x17, 0x56, 0x04, 0x01, 0x50, 0x02,
		0x50, 0x02, 0x50, 0x02, 0x50, 0x02, 0x50, 0x02, 0x50, 0x92, 0xf0, 0x58, 0x58, 0x11, 0xf4, 0x0b,
		0x22, 0x61, 0x45, 0xd0, 0x2f, 0x3e, 0x28, 0xac, 0x08, 0x7a, 0xbe, 0x78, 0x58, 0x11, 0x64, 0x8a,
		0xbb, 0xbf, 0x6b, 0x12, 0x58, 0x11, 0xf4, 0x62, 0x93, 0xc0, 0x8a, 0x20, 0xfe, 0x50, 0x8c, 0x9e,
		0x34, 0x18, 0x4c, 0x4d, 0x41, 0x02, 0x0c, 0xa6, 0xbe, 0x2b, 0x0f, 0xc9, 0x79, 0x1f, 0x77, 0x46,
		0x32, 0x94, 0x6e, 0x5a, 0x74, 0x4b, 0xd9, 0xf7, 0x8a, 0x3d, 0xa1, 0xba, 0xb0, 0xa3, 0x0c, 0x31,
		0xc0, 0x10, 0x03, 0x0c, 0x1f, 0x15, 0x0e, 0x03, 0x0c, 0x31, 0xc0, 0xf0, 0x99, 0x71, 0x85, 0xe9,
		0x24, 0xc3, 0xd9, 0x7d, 0x0d, 0x16, 0xb7, 0xe0, 0x2c, 0xbf, 0xc0, 0x44, 0x43, 0x03, 0xec, 0x1a,
		0x13, 0x0d, 0x9f, 0x62, 0xc7, 0x18, 0x6d, 0xc8, 0x40, 0xb5, 0x31, 0xda, 0x70, 0xad, 0x2a, 0x33,
		0x19, 0x71, 0x78, 0x3b, 0xdc, 0x60, 0xd4, 0xe1, 0xaf, 0x3f, 0xf2, 0xc0, 0x9f, 0x28, 0x2c, 0x47,
		0xc9, 0xce, 0xdc, 0xe6, 0x97, 0xc5, 0x60, 0xc3, 0x5c, 0x2e, 0x88, 0xc1, 0x86, 0xaa, 0x48, 0x3f,
		0x06, 0x1b, 0x62, 0xb0, 0x61, 0x3e, 0x8f, 0x52, 0xf9, 0x60, 0x43, 0x3d, 0x3d, 0x9f, 0x5a, 0x7b,
		0x3c, 0x31, 0xce, 0x50, 0xc3, 0x8b, 0xc6, 0x38, 0x43, 0x8c, 0x33, 0xa4, 0x11, 0x30, 0x8a, 0x91,
		0x8c, 0xd1, 0x36, 0xce, 0x50, 0x2d, 0x73, 0x20, 0xc1, 0x24, 0xd6, 0x05, 0x98, 0x4d, 0x0c, 0x32,
		0xc4, 0x20, 0x43, 0x0c, 0x32, 0xa4, 0x1f, 0x90, 0x68, 0x05, 0x26, 0x3d, 0x01, 0x4a, 0x53, 0xa0,
		0xca, 0x1e, 0xbd, 0xf6, 0x42, 0x70, 0x62, 0x9d, 0x84, 0x14, 0x3a, 0x07, 0x35, 0x77, 0x0a, 0x5e,
		0xa3, 0x84, 0x02, 0x25, 0x14, 0x8f, 0x09, 0x47, 0xa3, 0x84, 0x02, 0xec, 0x25, 0xdf, 0x38, 0x8c,
		0xa3, 0xe4, 0x95, 0xf3, 0xb7, 0x94, 0xd1, 0xe8, 0xa8, 0x26, 0xc4, 0xe1, 0x31, 0x2b, 0x25, 0xa6,
		0xab, 0xbc, 0x3c, 0xce, 0x8c, 0xdb, 0xa9, 0xa8, 0x38, 0x2b, 0xfe, 0xe5, 0x47, 0x3d, 0x99, 0x46,
		0xa7, 0xc2, 0x0e, 0x3d, 0xf5, 0xc7, 0xc5, 0xd9, 0x95, 0x71, 0x62, 0xcc, 0x35, 0x6f, 0x83, 0x13,
		0x63, 0x9c, 0x18, 0xe3, 0xc4, 0xf8, 0x05, 0x8f, 0x12, 0x27, 0xc6, 0xc6, 0x39, 0x7e, 0x6d, 0x01,
		0x40, 0x67, 0x20, 0x20, 0x10, 0x10, 0x74, 0x07, 0x06, 0x32, 0x01, 0x82, 0x4c, 0xa0, 0xa0, 0x11,
		0x30, 0x8a, 0x91, 0x73, 0xd1, 0x76, 0x62, 0x1c, 0x89, 0xa1, 0xf0, 0x2e, 0xc4, 0xc8, 0x8e, 0xaf,
		0xe2, 0x44, 0x9c, 0xdb, 0x14, 0x8e, 0x8f, 0x1f, 0x90, 0x09, 0x67, 0xc9, 0x5a, 0x04, 0xc0, 0x59,
		0x32, 0xa5, 0xd0, 0x44, 0x2e, 0x44, 0x91, 0x0b, 0x55, 0xb4, 0x42, 0x96, 0x9e, 0xd0, 0xa5, 0x29,
		0x84, 0x65, 0x8f, 0x9e, 0xce, 0x59, 0xb2, 0xee, 0xf0, 0x71, 0x87, 0xbd, 0xbc, 0xd3, 0x28, 0x43,
		0xd7, 0x4d, 0x12, 0x11, 0x05, 0xda, 0x47, 0x85, 0x59, 0xff, 0xfb, 0x75, 0xd3, 0xde, 0xab, 0xd9,
		0x1f, 0x5c, 0x7b, 0x7c, 0xfc, 0x57, 0xe5, 0xfa, 0xdb, 0xb7, 0xb7, 0x8f, 0x7c, 0xe3, 0x3f, 0xf4,
		0x59, 0xed, 0xb1, 0xce, 0x17, 0xd6, 0xe9, 0x37, 0xff, 0xc4, 0x5b, 0x7b, 0xce, 0x5b, 0x2b, 0xca,
		0x11, 0xb4, 0x06, 0x66, 0x1e, 0xa7, 0xf0, 0x87, 0x12, 0x53, 0x58, 0x91, 0x08, 0x3c, 0x01, 0x3c,
		0x01, 0x3c, 0x01, 0x3c, 0x01, 0x3c, 0x01, 0x3c, 0x01, 0x3c, 0x01, 0x3c, 0x01, 0x3c, 0x01, 0x6f,
		0x0d, 0x3c, 0x41, 0x35, 0x4f, 0x58, 0xfa, 0x53, 0x7b, 0x18, 0x4e, 0xd3, 0xd8, 0xaa, 0x9b, 0x26,
		0xdc, 0x13, 0x08, 0x2c, 0x01, 0x2c, 0x01, 0x2c, 0x01, 0x2c, 0x01, 0x2c, 0x01, 0x2c, 0xe1, 0x97,
		0x3d, 0xc6, 0xd4, 0x0b, 0x92, 0x77, 0x04, 0x18, 0x82, 0xce, 0x7e, 0x1f, 0x1a, 0x1b, 0x47, 0x08,
		0x8c, 0xc3, 0xa6, 0xb4, 0x51, 0x84, 0xda, 0x6a, 0x36, 0x62, 0x1b, 0x43, 0x28, 0xee, 0x42, 0xa0,
		0xb0, 0xf4, 0x90, 0xd2, 0x06, 0x10, 0xaa, 0x2a, 0xbc, 0x55, 0xad, 0x42, 0x89, 0x69, 0x01, 0x11,
		0xfd, 0x57, 0x3f, 0x46, 0x97, 0x2b, 0x7f, 0x97, 0x88, 0x2e, 0xd7, 0x07, 0x1a, 0x05, 0x97, 0x2d,
		0x5d, 0x68, 0x74, 0x65, 0xa3, 0xcf, 0x68, 0x74, 0x7d, 0x40, 0x7f, 0x79, 0xf4, 0xba, 0x76, 0x67,
		0xd2, 0x76, 0x3c, 0x74, 0xbb, 0xfe, 0xfa, 0xc3, 0x8e, 0xc2, 0x69, 0x22, 0x22, 0x7b, 0xe8, 0x4e,
		0xdc, 0x13, 0xcf, 0xf7, 0x12, 0x4f, 0xc4, 0xea, 0x1b, 0x5f, 0x1f, 0x12, 0x02, 0x3d, 0xb0, 0xb9,
		0x5c, 0x10, 0x3d, 0xb0, 0x6a, 0xd4, 0x08, 0x3d, 0xb0, 0xe8, 0x81, 0xcd, 0xeb, 0x51, 0x2a, 0xef,
		0x81, 0xcd, 0x1c, 0xef, 0x95, 0xbe, 0x46, 0xd8, 0x5b, 0x32, 0xa0, 0x1b, 0xd6, 0xb4, 0x90, 0x40,
		0x20, 0x34, 0xe8, 0x0e, 0x11, 0x64, 0x42, 0x05, 0x99, 0x90, 0x41, 0x23, 0x74, 0x14, 0x23, 0x37,
		0xa3, 0xad, 0x1b, 0x76, 0xc9, 0x47, 0xed, 0x60, 0x7a, 0x7e, 0x22, 0x22, 0xfd, 0x95, 0x2b, 0xf7,
		0x05, 0x42, 0xe5, 0x8a, 0x16, 0x01, 0x50, 0xb9, 0x42, 0x29, 0x28, 0x91, 0x0b, 0x4e, 0xe4, 0x82,
		0x14, 0xad, 0x60, 0xa5, 0x27, 0x68, 0x69, 0x0a, 0x5e, 0xd9, 0xa3, 0xa7, 0x53, 0xb9, 0xe2, 0x0b,
		0x77, 0x1c, 0x89, 0x31, 0x85, 0xea, 0xf6, 0x5d, 0xbd, 0xd5, 0xed, 0x69, 0xae, 0xfa, 0xed, 0xdb,
		0xf9, 0xf9, 0x46, 0xe9, 0x7e, 0x70, 0x45, 0x49, 0xb0, 0xb4, 0x67, 0xaf, 0x67, 0x6e, 0xd5, 0x8a,
		0x25, 0xe8, 0x98, 0x5f, 0xa5, 0x99, 0xb9, 0x03, 0x44, 0x01, 0x44, 0x01, 0x44, 0x01, 0x44, 0xf1,
		0x04, 0x51, 0xba, 0x32, 0x01, 0x99, 0x00, 0x63, 0xdf, 0x3d, 0x8d, 0xf5, 0x1b, 0xe9, 0xd2, 0x6f,
		0xcd, 0xc5, 0xd1, 0x6c, 0x0f, 0x34, 0x8a, 0xf5, 0xb4, 0x07, 0x34, 0x4a, 0x81, 0x8d, 0x60, 0x80,
		0xa3, 0x16, 0xe8, 0xc8, 0x06, 0x3c, 0xb2, 0x81, 0x8f, 0x66, 0x00, 0xd4, 0x1b, 0x08, 0x35, 0x07,
		0x44, 0x3a, 0xd9, 0x85, 0x15, 0x8f, 0x43, 0x63, 0x73, 0xd3, 0x0a, 0xdb, 0xaa, 0x10, 0x90, 0x45,
		0xef, 0x26, 0x27, 0x2a, 0x2a, 0x4b, 0x62, 0xb3, 0x53, 0x26, 0x0d, 0x99, 0x0d, 0x4f, 0x37, 0x12,
		0x11, 0xde, 0xf4, 0x94, 0x09, 0x49, 0x62, 0xe3, 0x93, 0xfe, 0x10, 0xa0, 0xd1, 0x96, 0xc8, 0x1c,
		0x52, 0xae, 0x44, 0x00, 0x1a, 0x87, 0x95, 0xa0, 0x29, 0xa0, 0x29, 0xa0, 0x29, 0xa0, 0x29, 0xa0,
		0x29, 0xa0, 0x29, 0x0f, 0x78, 0x9c, 0xa9, 0x17, 0x24, 0xdb, 0x5b, 0x84, 0x18, 0xca, 0x2e, 0x01,
		0x51, 0x68, 0xf4, 0xf5, 0x2f, 0x3f, 0x34, 0x1c, 0xf0, 0x06, 0xb5, 0x3e, 0x7f, 0x62, 0xc0, 0x66,
		0x45, 0x2c, 0x62, 0x7d, 0xff, 0x99, 0x5c, 0x04, 0x5b, 0xa7, 0x89, 0xb8, 0xe7, 0xfb, 0xf4, 0x13,
		0xaa, 0xfe, 0x44, 0x55, 0xaf, 0x6c, 0xed, 0x55, 0xf6, 0x76, 0x76, 0xb7, 0xf6, 0xaa, 0xd0, 0x79,
		0x1e, 0x80, 0x88, 0x8e, 0x14, 0xc7, 0x48, 0x9d, 0x28, 0x37, 0x8b, 0x45, 0xeb, 0xa6, 0xc6, 0xd1,
		0xe5, 0x2b, 0x78, 0xf4, 0x46, 0x24, 0xa4, 0x4b, 0x90, 0x2e, 0x41, 0xba, 0x04, 0xe9, 0x12, 0xa4,
		0x4b, 0x90, 0x2e, 0x21, 0xe3, 0x71, 0xbc, 0xc9, 0x45, 0xc5, 0x76, 0x47, 0xa3, 0x48, 0xc4, 0x31,
		0xa5, 0x63, 0xdd, 0x77, 0x04, 0x64, 0xa1, 0x32, 0x78, 0x3b, 0x13, 0xe8, 0x7f, 0x5f, 0xbf, 0xfe,
		0xba, 0x69, 0xef, 0x1d, 0xff, 0xfd, 0xb5, 0x6c, 0xef, 0x1d, 0xcf, 0xbf, 0x2c, 0xa7, 0x7f, 0xcd,
		0xbf, 0xde, 0xfa, 0xba, 0x69, 0x57, 0x96, 0x5f, 0x57, 0xbf, 0x6e, 0xda, 0xd5, 0xe3, 0x37, 0xdf,
		0xbe, 0xbd, 0x7d, 0xf3, 0xd7, 0xf6, 0xf5, 0xd3, 0x7f, 0xf0, 0x3f, 0xf4, 0x3b, 0x8b, 0x63, 0x0a,
		0x4a, 0x40, 0x69, 0x04, 0x7b, 0x71, 0x35, 0xa1, 0xa8, 0x64, 0xaa, 0x50, 0xd5, 0xc0, 0x9a, 0x67,
		0xb6, 0x65, 0x72, 0x50, 0x9c, 0x7d, 0xf5, 0xc0, 0x54, 0xa2, 0xd2, 0xcd, 0x94, 0x0a, 0x1d, 0x13,
		0xdd, 0xf4, 0xe9, 0xa8, 0x96, 0x0e, 0xa7, 0xe9, 0xc9, 0xec, 0x5d, 0x10, 0xe8, 0x71, 0x5a, 0x08,
		0x82, 0x2e, 0xa7, 0xa2, 0xa6, 0x0d, 0xd0, 0xe5, 0x44, 0x3f, 0x3d, 0x80, 0x2e, 0x27, 0xe0, 0x9a,
		0xec, 0xd1, 0x6b, 0xef, 0x72, 0x9a, 0xc7, 0x0c, 0x3a, 0x49, 0xf1, 0x85, 0x3c, 0x34, 0x32, 0xe2,
		0x65, 0x64, 0xc4, 0xc9, 0x84, 0x36, 0x82, 0x21, 0x8e, 0x5a, 0xa8, 0x23, 0x1b, 0xf2, 0xc8, 0x86,
		0x3e, 0x9a, 0x21, 0x50, 0x7f, 0x72, 0x61, 0x83, 0x40, 0x46, 0x5c, 0x77, 0x68, 0xbc, 0x09, 0x91,
		0xe2, 0x74, 0xa6, 0x1a, 0xf6, 0x8c, 0x67, 0x7b, 0xc1, 0xa9, 0xed, 0xfa, 0xa7, 0x61, 0xe4, 0x25,
		0x67, 0xe7, 0x31, 0x1d, 0x8b, 0xcf, 0xc2, 0xe7, 0x7a, 0x59, 0x7f, 0x23, 0xb5, 0xef, 0xa3, 0x4c,
		0x44, 0x1c, 0x2a, 0x21, 0x96, 0x62, 0xa8, 0x25, 0x1c, 0x72, 0xa9, 0x86, 0x5e, 0xf2, 0x21, 0x98,
		0x7c, 0x28, 0xa6, 0x1d, 0x92, 0x69, 0x84, 0x66, 0x22, 0x21, 0x9a, 0x5c, 0xa8, 0xbe, 0x09, 0xd9,
		0x5a, 0x87, 0x4e, 0x3d, 0x1e, 0xa5, 0x35, 0x0e, 0xa3, 0x62, 0x12, 0x98, 0xc9, 0x06, 0x68, 0xca,
		0x81, 0x9a, 0x41, 0xc0, 0xa6, 0x1e, 0xb8, 0xd9, 0x04, 0x70, 0x36, 0x81, 0x9c, 0x47, 0x40, 0xa7,
		0x15, 0xd8, 0x89, 0x05, 0x78, 0xb2, 0x81, 0x3e, 0x13, 0x2c, 0xe3, 0xb9, 0x74, 0x1d, 0xca, 0xd2,
		0x27, 0xdf, 0x88, 0x4a, 0xd4, 0x4e, 0x69, 0x76, 0xde, 0x90, 0x07, 0x04, 0x1c, 0x80, 0x01, 0x23,
		0x80, 0xc0, 0x05, 0x28, 0xb0, 0x03, 0x0c, 0xec, 0x80, 0x03, 0x2f, 0x00, 0x41, 0x13, 0x48, 0x10,
		0x05, 0x14, 0xd9, 0xab, 0x25, 0x53, 0xfe, 0xfe, 0xa8, 0xc7, 0xa4, 0x35, 0xec, 0xec, 0x51, 0x36,
		0x5f, 0x21, 0x2c, 0x23, 0x8d, 0xe1, 0x68, 0xdc, 0x4c, 0x85, 0xd4, 0x30, 0xb5, 0xb5, 0x52, 0x92,
		0x1b, 0xb2, 0xb6, 0x5e, 0x52, 0x06, 0xc3, 0xd7, 0xd6, 0x0a, 0x4f, 0x6a, 0x28, 0x1b, 0x9f, 0x50,
		0x08, 0x96, 0xff, 0x53, 0x9c, 0x45, 0xa3, 0xd8, 0x7e, 0xad, 0x7c, 0x1c, 0x8b, 0xf0, 0xe7, 0xa5,
		0xd9, 0x8b, 0xbf, 0x4b, 0xeb, 0x8f, 0xe9, 0x75, 0x96, 0xeb, 0xd3, 0xb7, 0x16, 0x1c, 0xbb, 0x31,
		0xb0, 0x53, 0xa3, 0xed, 0x93, 0x52, 0xed, 0xc3, 0xf3, 0x17, 0xd0, 0x1f, 0x64, 0x77, 0xee, 0xf4,
		0xd3, 0x3b, 0x76, 0xfa, 0xf3, 0x3b, 0xee, 0xcd, 0x6f, 0xb8, 0x76, 0x73, 0xbf, 0x98, 0xd9, 0x42,
		0xc5, 0xe6, 0x57, 0x8a, 0xbb, 0x34, 0xae, 0x43, 0x7e, 0x94, 0x26, 0xff, 0x44, 0x56, 0x14, 0xa2,
		0x3d, 0x24, 0x0e, 0x0a, 0xd1, 0x9e, 0xa0, 0x5d, 0x28, 0x44, 0xfb, 0x75, 0x35, 0x47, 0x21, 0xda,
		0x4b, 0x61, 0x16, 0x0a, 0xd1, 0xb8, 0x20, 0x62, 0x7a, 0x85, 0x68, 0xd1, 0xe9, 0x89, 0x3d, 0x12,
		0xf1, 0x30, 0xf2, 0x26, 0x49, 0x18, 0xc5, 0x84, 0x6b, 0xd2, 0xee, 0x4b, 0x8a, 0xf2, 0x34, 0x8e,
		0x61, 0x9b, 0x72, 0xf8, 0x66, 0x10, 0xc6, 0xa9, 0x87, 0x73, 0x36, 0x61, 0x9d, 0x4d, 0x78, 0xe7,
		0x11, 0xe6, 0x69, 0x85, 0x7b, 0x62, 0x61, 0x9f, 0x6c, 0xf8, 0x5f, 0x07, 0x03, 0xe8, 0x17, 0xa9,
		0xdd, 0x17, 0x98, 0x76, 0xa9, 0x5a, 0x19, 0xa5, 0x6a, 0xc6, 0x81, 0x04, 0x46, 0x60, 0x81, 0x0b,
		0x68, 0x60, 0x07, 0x1e, 0xd8, 0x81, 0x08, 0x5e, 0x60, 0x82, 0x26, 0xa8, 0x20, 0x0a, 0x2e, 0xc8,
		0x83, 0x8c, 0x4c, 0xc0, 0x68, 0xb1, 0xd2, 0x85, 0xb8, 0x13, 0xca, 0xc6, 0xa0, 0xa7, 0xe2, 0x12,
		0xb7, 0x67, 0xda, 0x35, 0xf1, 0x6c, 0x00, 0x07, 0x27, 0xe0, 0xc1, 0x10, 0x80, 0x70, 0x03, 0x22,
		0x6c, 0x01, 0x09, 0x5b, 0x60, 0xc2, 0x13, 0xa0, 0xd0, 0x06, 0x2a, 0xc4, 0x01, 0x4b, 0xf6, 0xca,
		0xc9, 0xd7, 0xd8, 0xaf, 0x78, 0x5c, 0x5f, 0xb8, 0xe3, 0x48, 0x8c, 0x39, 0x78, 0xdc, 0x65, 0x26,
		0x62, 0x97, 0x81, 0xac, 0xdd, 0x45, 0x65, 0xd6, 0xdb, 0xb7, 0xf3, 0x6a, 0xc3, 0xd2, 0x1c, 0x82,
		0xbd, 0x82, 0xe9, 0x1b, 0x66, 0xf6, 0x44, 0xe7, 0x60, 0xac, 0xb5, 0x77, 0x8a, 0x73, 0x31, 0xd6,
		0x5a, 0x3a, 0xa8, 0x00, 0xa8, 0x00, 0xa8, 0x00, 0xa8, 0x00, 0xa8, 0x00, 0xf0, 0x00, 0x37, 0x2a,
		0x40, 0x3d, 0x87, 0x99, 0x09, 0xea, 0xbb, 0x27, 0xc2, 0xe7, 0xe3, 0xbc, 0x32, 0xe2, 0x92, 0x8a,
		0xcd, 0xc4, 0xfe, 0x79, 0xe4, 0x36, 0xd9, 0x01, 0x1b, 0x8e, 0x00, 0x87, 0x31, 0xd0, 0xe1, 0x0a,
		0x78, 0xd8, 0x03, 0x1f, 0xf6, 0x00, 0x88, 0x37, 0x10, 0xe2, 0x01, 0x88, 0x98, 0x00, 0xa3, 0x4c,
		0x15, 0xd8, 0xe4, 0x4a, 0x57, 0x3c, 0xf6, 0xf9, 0xc4, 0x8f, 0x6d, 0x4e, 0xf8, 0xe3, 0x4e, 0x52,
		0x65, 0x8f, 0x91, 0xcc, 0x0b, 0x1d, 0xf9, 0xca, 0xca, 0xc9, 0xf1, 0x0a, 0x8a, 0x77, 0x34, 0x7b,
		0xea, 0x05, 0xc9, 0xf6, 0x16, 0xb3, 0xa8, 0x78, 0x5b, 0xbb, 0x77, 0x19, 0x8a, 0xde, 0x5b, 0x14,
		0x93, 0x7c, 0x65, 0x27, 0x3a, 0x4f, 0x6d, 0xcf, 0x1e, 0xfc, 0xa1, 0x17, 0xb0, 0xc3, 0xb0, 0xcc,
		0xa9, 0xe5, 0xda, 0xdb, 0xf8, 0xec, 0xfa, 0xd3, 0x99, 0x11, 0x94, 0x77, 0x98, 0xdf, 0xc8, 0x87,
		0xc8, 0x1d, 0x26, 0x5e, 0x18, 0xd4, 0xbd, 0x53, 0x6f, 0x3e, 0x98, 0x89, 0xed, 0xfd, 0x5c, 0xff,
		0xc6, 0xd8, 0xb6, 0xdd, 0x4b, 0xd8, 0x36, 0x35, 0xdb, 0xde, 0xac, 0xbc, 0xab, 0xee, 0x56, 0x61,
		0xe0, 0x20, 0xb4, 0xc5, 0x92, 0xfa, 0xf8, 0x15, 0xdc, 0x3e, 0x00, 0xe8, 0x2a, 0xdd, 0xe2, 0x31,
		0xe8, 0xf4, 0xd1, 0x8c, 0x42, 0x85, 0xa1, 0xec, 0xb4, 0x07, 0xa3, 0xf2, 0x77, 0x7d, 0x3c, 0x5c,
		0x1e, 0xfd, 0xe7, 0xc9, 0xc0, 0x19, 0x33, 0xe9, 0x86, 0x59, 0xf1, 0xbe, 0x1c, 0xba, 0x62, 0x98,
		0x52, 0x01, 0x9c, 0x20, 0xab, 0x54, 0x64, 0x9c, 0x20, 0xab, 0x33, 0x43, 0x9c, 0x20, 0x6b, 0xbe,
		0x01, 0x9c, 0x20, 0x03, 0x73, 0x2c, 0x54, 0x81, 0xef, 0x09, 0x32, 0xbb, 0x73, 0x36, 0x86, 0xe7,
		0x6b, 0x4c, 0xcf, 0xd5, 0x18, 0xa6, 0x33, 0x38, 0x9f, 0xa3, 0x31, 0xcf, 0xb1, 0x67, 0xb9, 0x75,
		0xae, 0xf2, 0x1b, 0x90, 0x4d, 0x67, 0x78, 0x4c, 0xc6, 0xfa, 0x78, 0xcc, 0x14, 0x93, 0xad, 0x6c,
		0xed, 0x55, 0xf6, 0x76, 0x76, 0xb7, 0xf6, 0xaa, 0xb0, 0x5d, 0x00, 0x72, 0xb3, 0xa4, 0x45, 0xfa,
		0xb7, 0x08, 0x12, 0x52, 0xef, 0xc1, 0x22, 0xbe, 0x65, 0x69, 0x45, 0x5e, 0xf3, 0xb6, 0xba, 0xdc,
		0xfe, 0x3f, 0xef, 0x4d, 0xbf, 0xbe, 0xff, 0x0d, 0x8a, 0x6b, 0x99, 0xf8, 0x98, 0x23, 0x06, 0xcc,
		0x3d, 0x09, 0x41, 0x8a, 0x2b, 0xea, 0x27, 0x40, 0x58, 0x42, 0x99, 0x3f, 0xe5, 0xc1, 0x12, 0xca,
		0x42, 0x5a, 0x3b, 0x13, 0x18, 0x50, 0xec, 0xf0, 0x6f, 0x91, 0x9e, 0xf1, 0x23, 0x6b, 0x0b, 0xdc,
		0xed, 0xff, 0x1e, 0x9d, 0x9e, 0xd4, 0x6f, 0x1e, 0x07, 0xd6, 0xcc, 0x32, 0x94, 0x08, 0x6b, 0x66,
		0xe1, 0xf1, 0xd6, 0x7a, 0x3c, 0x6c, 0x9c, 0x25, 0x6f, 0x34, 0x44, 0xa7, 0xb9, 0x91, 0x9e, 0xde,
		0x86, 0xb5, 0x51, 0x4f, 0x14, 0x0c, 0x6b, 0xa3, 0x5e, 0x24, 0x22, 0xd6, 0x46, 0xe5, 0x24, 0x28,
		0xd6, 0x46, 0x01, 0x88, 0xaa, 0x7a, 0x85, 0x64, 0xd7, 0x46, 0x8d, 0x7d, 0xf7, 0x34, 0xa6, 0xbf,
		0x2c, 0x6a, 0x2e, 0x26, 0xed, 0x15, 0x51, 0x9b, 0x58, 0x11, 0x65, 0x1c, 0x20, 0x60, 0x04, 0x0c,
		0xb8, 0x00, 0x04, 0x76, 0x40, 0x81, 0x1d, 0x60, 0xe0, 0x05, 0x1c, 0x68, 0x02, 0x08, 0xa2, 0x40,
		0x22, 0x7b, 0xb5, 0xe4, 0x6b, 0xbf, 0x99, 0x35, 0xf9, 0x72, 0x68, 0xe6, 0x25, 0xde, 0xb4, 0x7b,
		0x8d, 0x83, 0xe4, 0x17, 0x48, 0x89, 0x83, 0x64, 0x25, 0xc2, 0xf3, 0x38, 0x48, 0x06, 0xbb, 0x67,
		0xc5, 0xee, 0x71, 0xcc, 0xa4, 0xf3, 0x98, 0x89, 0x5e, 0xd9, 0x1c, 0xa1, 0xb3, 0xa5, 0x57, 0xb0,
		0x57, 0xf2, 0x76, 0x6a, 0xb4, 0x7d, 0x5a, 0xa4, 0x4e, 0x37, 0xe5, 0xd7, 0xb1, 0xd0, 0xf0, 0x44,
		0xfa, 0xed, 0x9e, 0x80, 0xcd, 0x13, 0x3b, 0xcd, 0x26, 0x79, 0x8a, 0x4d, 0xec, 0xf4, 0x9a, 0x5c,
		0xb2, 0x9a, 0x62, 0x72, 0x9a, 0x70, 0x32, 0x9a, 0x6a, 0xf2, 0x99, 0x7c, 0xb2, 0x99, 0x7c, 0x72,
		0x99, 0x76, 0x32, 0x19, 0x38, 0xf7, 0xf6, 0xab, 0xa2, 0x76, 0xda, 0x6c, 0x25, 0x14, 0xb3, 0xd5,
		0x99, 0x1b, 0x4d, 0xa5, 0xa3, 0x59, 0x54, 0xb6, 0x89, 0xa2, 0x32, 0xb6, 0x61, 0x9a, 0x41, 0xb8,
		0xa6, 0x1e, 0xb6, 0xd9, 0x84, 0x6f, 0x36, 0x61, 0x9c, 0x47, 0x38, 0xa7, 0x15, 0xd6, 0x89, 0x85,
		0xf7, 0xec, 0x15, 0x92, 0x3d, 0x03, 0xce, 0x3c, 0x9e, 0x37, 0x12, 0x41, 0xe2, 0x25, 0x57, 0x34,
		0x37, 0xec, 0x67, 0xdc, 0x97, 0xe0, 0x81, 0x95, 0xd5, 0x5c, 0x3c, 0xba, 0x7d, 0x37, 0x16, 0xf4,
		0xeb, 0xf3, 0x9a, 0xfd, 0x66, 0xdf, 0xe9, 0x1f, 0xed, 0x0f, 0x5a, 0x9f, 0x9d, 0xc1, 0x97, 0x6e,
		0x83, 0xaa, 0x7b, 0x4e, 0x67, 0xcf, 0xc4, 0xa4, 0x87, 0xa2, 0x31, 0x59, 0xa4, 0xdf, 0xec, 0x3a,
		0xbd, 0x46, 0xed, 0xe0, 0x53, 0x6d, 0xbf, 0xd9, 0x6a, 0x0e, 0xbe, 0x2c, 0x5e, 0x7e, 0x9f, 0xf2,
		0xdb, 0xe7, 0xa4, 0x05, 0x3c, 0xb4, 0xe1, 0x51, 0xad, 0xe8, 0xf6, 0x1a, 0x1f, 0x9a, 0x7f, 0x3a,
		0x1f, 0x5a, 0xb5, 0x8f, 0x7d, 0x0b, 0xc3, 0xc6, 0x0b, 0xaf, 0x0f, 0xcd, 0xee, 0xe7, 0x8a, 0xd3,
		0xeb, 0x1c, 0x0d, 0x1a, 0x3d, 0xa7, 0x59, 0x87, 0x46, 0x40, 0x23, 0x06, 0xb5, 0x8f, 0x50, 0x03,
		0xa8, 0xc1, 0xa0, 0xf6, 0x71, 0xa7, 0x02, 0x45, 0x80, 0x22, 0x34, 0xbb, 0x9f, 0x77, 0x10, 0x21,
		0xa0, 0x11, 0x2b, 0x18, 0xb2, 0xcf, 0x42, 0x1b, 0x48, 0x4b, 0x48, 0x77, 0x2a, 0x25, 0x61, 0x2b,
		0x62, 0xca, 0xc7, 0x79, 0x30, 0x2f, 0xbc, 0xf7, 0xa2, 0x32, 0x2c, 0xbc, 0xf9, 0x42, 0x31, 0x29,
		0xbc, 0xee, 0x82, 0x31, 0x26, 0xbc, 0xf0, 0xa2, 0x32, 0x23, 0xbc, 0xf9, 0x22, 0x32, 0x20, 0xbc,
		0xf5, 0x97, 0xbe, 0xf5, 0x85, 0x69, 0x1f, 0xd4, 0xba, 0x38, 0x53, 0x43, 0x3e, 0xe4, 0xa7, 0x7a,
		0xd1, 0x73, 0x6a, 0xad, 0x8f, 0x9d, 0x5e, 0x73, 0xf0, 0xe9, 0x10, 0x19, 0x32, 0x68, 0x44, 0xaa,
		0x11, 0x37, 0xff, 0x42, 0x9a, 0xec, 0x65, 0x1f, 0xa4, 0xc9, 0x0a, 0x15, 0x64, 0x59, 0x38, 0x53,
		0xbc, 0xf9, 0xc2, 0x3a, 0x4d, 0xbc, 0xfa, 0x17, 0xf3, 0xa9, 0x3e, 0x6a, 0xd5, 0x80, 0xa2, 0x1e,
		0xd3, 0x8a, 0x56, 0xb3, 0xfd, 0x3b, 0x8e, 0x9c, 0xa1, 0x0a, 0x83, 0x2f, 0xce, 0x51, 0xfb, 0xa0,
		0xd3, 0xee, 0x0f, 0x7a, 0xb5, 0x66, 0xbb, 0x51, 0x77, 0x5a, 0xfd, 0x2e, 0x94, 0x02, 0x4a, 0x91,
		0xfa, 0x87, 0xda, 0x60, 0xd0, 0x6b, 0xee, 0x1f, 0x0d, 0x1a, 0x28, 0x67, 0x85, 0x4a, 0xcc, 0x53,
		0xf2, 0xed, 0x46, 0xf3, 0xe3, 0xa7, 0xfd, 0x4e, 0xcf, 0xa9, 0xd5, 0xeb, 0xbd, 0x46, 0x1f, 0x8a,
		0x01, 0xc5, 0x98, 0x9f, 0xc2, 0x37, 0xdb, 0x83, 0x46, 0xef, 0x43, 0xed, 0xa0, 0x01, 0xcd, 0x80,
		0x66, 0x64, 0xd0, 0x62, 0xd0, 0x6c, 0x35, 0xff, 0xa7, 0x51, 0x77, 0xf6, 0x6b, 0xed, 0xfa, 0x1f,
		0xcd, 0xfa, 0xe0, 0x13, 0xb4, 0x02, 0x5a, 0x91, 0x62, 0x8b, 0x6e, 0xaf, 0x33, 0x68, 0x1c, 0x0c,
		0x9a, 0x9d, 0xf6, 0x9c, 0x99, 0x42, 0x2f, 0x0a, 0xaf, 0x17, 0xbd, 0x46, 0xbf, 0x59, 0x3f, 0xaa,
		0xb5, 0xe0, 0x2d, 0xa0, 0x15, 0x37, 0x5a, 0x71, 0x58, 0xfb, 0x73, 0xee, 0x31, 0xa0, 0x15, 0xd0,
		0x8a, 0xbb, 0x64, 0x04, 0x98, 0x13, 0x9a, 0xf1, 0xa0, 0xbf, 0xe8, 0x35, 0xfa, 0x8d, 0xde, 0xe7,
		0xda, 0x7e, 0xab, 0x01, 0xaf, 0x01, 0xdd, 0xb8, 0x87, 0x3c, 0x5b, 0x1d, 0x38, 0x0a, 0x28, 0xc3,
		0x42, 0x19, 0xea, 0x8d, 0x56, 0xed, 0x8b, 0xf3, 0xb9, 0xd6, 0x6b, 0xd6, 0x66, 0x5c, 0x04, 0x7a,
		0x01, 0xbd, 0xa8, 0xd5, 0xff, 0xdb, 0x69, 0xd5, 0xda, 0x4c, 0x7a, 0xf0, 0xa0, 0x0e, 0xb2, 0xd5,
		0xe1, 0x73, 0xad, 0xd9, 0x02, 0x94, 0x80, 0x5a, 0xac, 0x7a, 0x09, 0x78, 0x08, 0xa8, 0xc2, 0x8c,
		0x71, 0x34, 0xdb, 0x37, 0x59, 0x8a, 0x14, 0x50, 0x40, 0x2b, 0xa0, 0x15, 0x47, 0xed, 0x39, 0x0b,
		0xc5, 0xe9, 0x07, 0xf4, 0xe2, 0xb6, 0x5e, 0x64, 0xca, 0xe0, 0x64, 0x65, 0x37, 0x03, 0xf0, 0x51,
		0x28, 0x86, 0xd3, 0xf8, 0x73, 0xd0, 0x68, 0xd7, 0x1b, 0x75, 0xa7, 0x56, 0x9f, 0x45, 0x94, 0x8f,
		0xbd, 0xce, 0x11, 0x4a, 0xb1, 0xa0, 0x17, 0x50, 0x07, 0xa8, 0xc3, 0x4a, 0xb5, 0x0d, 0xca, 0xb0,
		0xa0, 0x18, 0xeb, 0xf3, 0x99, 0xd0, 0x06, 0x68, 0xc3, 0xa0, 0xe1, 0xd4, 0x1b, 0x1f, 0x6a, 0x47,
		0xad, 0x81, 0x73, 0xd8, 0x18, 0xf4, 0x9a, 0x07, 0x68, 0x94, 0x7c, 0xd9, 0x07, 0x8d, 0x92, 0xc6,
		0x19, 0x11, 0xdf, 0xee, 0x18, 0xbc, 0xf2, 0xfc, 0xd3, 0x35, 0x6c, 0xba, 0x60, 0xf0, 0xf2, 0xa5,
		0xd8, 0x3b, 0x87, 0x6e, 0x17, 0xbc, 0x7a, 0x09, 0x74, 0x8a, 0x53, 0x57, 0x0b, 0x14, 0x40, 0x0a,
		0x9f, 0x66, 0x54, 0x49, 0x08, 0x0d, 0xc8, 0x3d, 0xf4, 0x33, 0xea, 0x52, 0xc1, 0xdb, 0x97, 0x12,
		0xfb, 0xd9, 0x74, 0xa3, 0xe0, 0xfd, 0xe7, 0xfd, 0xfe, 0x39, 0x75, 0x9d, 0xe0, 0xed, 0xe7, 0xfd,
		0xf6, 0x39, 0x75, 0x97, 0xe0, 0xed, 0x4b, 0x01, 0xff, 0xc0, 0x7e, 0x05, 0xb7, 0x7f, 0x5e, 0xdd,
		0x22, 0xd0, 0x01, 0x29, 0x08, 0x90, 0x76, 0x57, 0x08, 0x5e, 0xba, 0x94, 0x97, 0xce, 0xa6, 0xfb,
		0x03, 0xef, 0x3f, 0xef, 0xf7, 0xcf, 0xa2, 0xcb, 0x03, 0xaf, 0x3d, 0xf7, 0xd7, 0xce, 0xa9, 0x9b,
		0x03, 0xaf, 0x5f, 0x86, 0xd5, 0xc3, 0xe2, 0x8b, 0x85, 0xf0, 0x19, 0x75, 0x67, 0xe0, 0xed, 0xe7,
		0xfd, 0xf6, 0x79, 0x75, 0x61, 0xe0, 0xfd, 0xe7, 0xfd, 0xfe, 0x99, 0x75, 0x5b, 0x40, 0x01, 0xf2,
		0x56, 0x00, 0x5e, 0x5d, 0x15, 0x78, 0xff, 0xf9, 0x23, 0x3e, 0xbc, 0xf6, 0x02, 0xbe, 0x76, 0x66,
		0x5d, 0x12, 0x50, 0x80, 0xbc, 0x15, 0x00, 0x70, 0xbf, 0x88, 0x6f, 0x9d, 0x51, 0xd7, 0x03, 0xcd,
		0x6e, 0x07, 0x7a, 0x5d, 0x0e, 0xb4, 0x9e, 0x13, 0x1d, 0x69, 0x68, 0x48, 0x42, 0xc4, 0x85, 0x59,
		0xb5, 0x20, 0x08, 0x13, 0x37, 0xf1, 0xc2, 0xc0, 0x7a, 0x4f, 0xc8, 0x79, 0x59, 0xf1, 0xf0, 0x4c,
		0x9c, 0xbb, 0x13, 0x37, 0x39, 0x9b, 0xb9, 0xab, 0x52, 0x38, 0x11, 0xc1, 0x30, 0x0c, 0xc6, 0xde,
		0xa9, 0x1d, 0x88, 0xe4, 0x47, 0x18, 0x7d, 0xb7, 0xbd, 0x20, 0x4e, 0xdc, 0x60, 0x28, 0x4a, 0xf7,
		0xbf, 0x11, 0xaf, 0x7c, 0xa7, 0x34, 0x89, 0xc2, 0x24, 0x1c, 0x86, 0x7e, 0x9c, 0x7d, 0x55, 0xf2,
		0x62, 0x2f, 0x2e, 0xf9, 0xe2, 0x42, 0xf8, 0x8b, 0xbf, 0x4a, 0xbe, 0x17, 0x7c, 0xb7, 0xe3, 0xc4,
		0x4d, 0x84, 0x3d, 0x72, 0x13, 0xf7, 0xc4, 0x8d, 0x45, 0xc9, 0x8f, 0x27, 0xa5, 0xc4, 0xbf, 0x88,
		0x67, 0x7f, 0x94, 0xa2, 0x70, 0x9a, 0x88, 0xc8, 0x1e, 0xba, 0x13, 0xf7, 0xc4, 0xf3, 0xbd, 0xc4,
		0x13, 0x71, 0x29, 0xfb, 0xc7, 0x55, 0x29, 0x9e, 0x9e, 0xa4, 0xff, 0xeb, 0xfc, 0xef, 0x52, 0xfa,
		0x9b, 0x68, 0xb8, 0x51, 0xfd, 0x2a, 0x4f, 0x40, 0xdd, 0xad, 0xe4, 0x6a, 0x22, 0xc8, 0x28, 0x79,
		0x16, 0x89, 0x53, 0xa9, 0x88, 0x38, 0x83, 0xdf, 0xbd, 0x60, 0x64, 0xbd, 0xdf, 0xd8, 0x24, 0x22,
		0xce, 0x41, 0x6a, 0xf0, 0x84, 0x04, 0xea, 0x46, 0x62, 0xec, 0x5d, 0xd2, 0x72, 0x94, 0x4b, 0x3d,
		0x0a, 0x87, 0xf6, 0xcc, 0xa5, 0x11, 0xda, 0x54, 0x66, 0xf5, 0xc3, 0x69, 0x34, 0x14, 0xa4, 0x1e,
		0xd7, 0x5c, 0xcd, 0xc5, 0xd5, 0x8f, 0x30, 0x9a, 0x69, 0xba, 0x35, 0x99, 0xbf, 0x51, 0x5a, 0x7c,
		0xc2, 0xfa, 0xe4, 0xc6, 0xb5, 0xe8, 0x74, 0x7a, 0x2e, 0x82, 0xc4, 0x7a, 0xbf, 0x91, 0x44, 0x53,
		0x41, 0x4c, 0xc0, 0x5b, 0xd2, 0x65, 0x8a, 0x07, 0x80, 0x47, 0x12, 0xe0, 0x0d, 0x28, 0x45, 0xbd,
		0x3b, 0x1e, 0xcb, 0x17, 0xee, 0x38, 0x12, 0x63, 0x4a, 0x1e, 0x6b, 0x11, 0x00, 0xcb, 0xbb, 0x84,
		0x64, 0xea, 0x2e, 0x30, 0xf0, 0xdb, 0xb7, 0x73, 0x48, 0x59, 0x4a, 0x11, 0x03, 0x70, 0x25, 0x01,
		0x09, 0x34, 0xdb, 0xf8, 0x2c, 0x90, 0x11, 0x81, 0x90, 0x56, 0xcb, 0x8b, 0x93, 0x5a, 0x92, 0x44,
		0x24, 0x5c, 0x8d, 0x75, 0xe8, 0x05, 0x0d, 0x5f, 0xcc, 0x22, 0x54, 0x4c, 0x03, 0x3e, 0x5a, 0x87,
		0xee, 0xe5, 0x2d, 0x89, 0xca, 0xef, 0x2a, 0x95, 0x9d, 0xdd, 0x4a, 0x65, 0x73, 0x77, 0x7b, 0x77,
		0x73, 0xaf, 0x5a, 0x2d, 0xef, 0x94, 0xab, 0x04, 0x84, 0xec, 0x44, 0x23, 0x11, 0x89, 0xd1, 0xfe,
		0x4c, 0xab, 0x82, 0xa9, 0xef, 0x17, 0xda, 0xb8, 0x88, 0x65, 0x46, 0xf8, 0x67, 0x44, 0x08, 0x04,
		0x7a, 0x2b, 0x4e, 0xa2, 0xe9, 0x30, 0x09, 0x16, 0x08, 0xa4, 0x3d, 0x7f, 0x2a, 0xcd, 0xc5, 0x43,
		0x71, 0xba, 0x8b, 0x47, 0xe1, 0x34, 0x63, 0x2f, 0x76, 0x5a, 0xb3, 0x67, 0xe0, 0xb4, 0xe2, 0x89,
		0x33, 0xf0, 0x2f, 0x9c, 0x83, 0xec, 0xb6, 0x9c, 0xfe, 0xfc, 0x76, 0x5e, 0x15, 0x33, 0xf0, 0xe9,
		0xb9, 0xb2, 0x26, 0x6f, 0x40, 0xc5, 0x0b, 0x30, 0xb6, 0x7e, 0x3d, 0x76, 0xa2, 0x5e, 0x4b, 0x35,
		0x68, 0xa8, 0x35, 0x0d, 0x46, 0x62, 0xec, 0x05, 0x62, 0x64, 0x2f, 0x1f, 0xb6, 0x2e, 0x25, 0xcd,
		0x58, 0xdd, 0xaa, 0x48, 0x9a, 0x2c, 0x77, 0xc9, 0xe5, 0x34, 0x5d, 0x5e, 0x77, 0xf2, 0x92, 0x42,
		0xb2, 0x92, 0x50, 0x72, 0x92, 0x4a, 0x32, 0x92, 0x5c, 0xf2, 0x91, 0x5c, 0xb2, 0x91, 0x56, 0x72,
		0xb1, 0x58, 0x68, 0xa7, 0xee, 0xe9, 0x25, 0xf0, 0x2b, 0xd1, 0x43, 0xbf, 0xbd, 0xae, 0x8b, 0x6b,
		0xba, 0xcd, 0x56, 0x6f, 0x78, 0x23, 0x13, 0xe6, 0x28, 0x85, 0x3b, 0x82, 0x61, 0x8f, 0x5a, 0xf8,
		0x23, 0x1b, 0x06, 0xc9, 0x86, 0x43, 0x9a, 0x61, 0x51, 0x7f, 0x1a, 0x62, 0x83, 0x40, 0x8a, 0x50,
		0x77, 0xb8, 0xbc, 0x95, 0xd6, 0x72, 0x13, 0x82, 0xb5, 0x2d, 0x73, 0xb1, 0x68, 0x15, 0xb7, 0x94,
		0x51, 0xdc, 0x42, 0x3e, 0x80, 0x12, 0x0e, 0xa4, 0x54, 0x03, 0x2a, 0xf9, 0xc0, 0x4a, 0x3e, 0xc0,
		0xd2, 0x0e, 0xb4, 0x34, 0x02, 0x2e, 0x91, 0xc0, 0x4b, 0x2e, 0x00, 0x67, 0x02, 0xf9, 0x22, 0x38,
		0x4d, 0x53, 0xf4, 0xc4, 0xbc, 0xc2, 0x4d, 0xcd, 0x4d, 0x2a, 0x1f, 0x31, 0x8b, 0xa3, 0x55, 0x77,
		0x4a, 0x36, 0x44, 0x53, 0x0e, 0xd5, 0x0c, 0x42, 0x36, 0xf5, 0xd0, 0xcd, 0x26, 0x84, 0xb3, 0x09,
		0xe5, 0x3c, 0x42, 0x3a, 0xad, 0xd0, 0x4e, 0x2c, 0xc4, 0x67, 0xaf, 0x90, 0x5c, 0x1d, 0xeb, 0x8a,
		0xc7, 0x9b, 0x7a, 0x41, 0xf2, 0x8e, 0xa2, 0xbf, 0x5b, 0x84, 0xd7, 0x2a, 0x41, 0xd1, 0x7a, 0x6e,
		0x70, 0x3a, 0x7b, 0x78, 0x5f, 0x49, 0xfa, 0x0d, 0xba, 0xcd, 0xbc, 0xd6, 0xa1, 0x17, 0x90, 0x0d,
		0x60, 0xc4, 0x71, 0xdd, 0x8a, 0x98, 0x9f, 0x5d, 0x7f, 0x2a, 0x18, 0xc8, 0xf9, 0x21, 0x72, 0x87,
		0x89, 0x17, 0x06, 0x75, 0xef, 0xd4, 0x9b, 0x17, 0xb6, 0xa2, 0x43, 0xff, 0x39, 0xa6, 0xe3, 0x5e,
		0xc2, 0x74, 0x72, 0x36, 0x9d, 0xad, 0x6a, 0x15, 0xc6, 0x63, 0x26, 0x10, 0xa4, 0x2b, 0xd5, 0x31,
		0x26, 0x1c, 0x50, 0x77, 0xbe, 0xb4, 0x9a, 0xae, 0x57, 0x20, 0x3b, 0xa1, 0xe6, 0x6b, 0xe2, 0x9e,
		0x1f, 0xc9, 0xb0, 0x97, 0xe8, 0x19, 0x92, 0x61, 0xcf, 0x37, 0x07, 0x24, 0xc3, 0x72, 0x16, 0x14,
		0xc9, 0x30, 0xee, 0x74, 0x06, 0xc9, 0xb0, 0x17, 0x87, 0x57, 0x24, 0xc3, 0x9e, 0xfa, 0x41, 0x32,
		0xac, 0x50, 0x8c, 0x1e, 0xc9, 0x30, 0x53, 0xa3, 0xc7, 0x5d, 0xd3, 0x41, 0x32, 0x2c, 0x77, 0xd3,
		0x41, 0x32, 0xcc, 0x58, 0x20, 0x48, 0x57, 0x2a, 0x24, 0xc3, 0xc8, 0x3b, 0x5f, 0xeb, 0x62, 0xe1,
		0x20, 0x88, 0x66, 0xc3, 0xe6, 0xe2, 0x21, 0x1d, 0xf6, 0x2b, 0x62, 0x21, 0x1d, 0xf6, 0x02, 0x45,
		0x43, 0x3a, 0xec, 0xf9, 0xe6, 0x80, 0x74, 0x58, 0xce, 0x82, 0x22, 0x1d, 0xc6, 0x9d, 0xd0, 0x30,
		0x48, 0x87, 0x9d, 0x78, 0x81, 0x1b, 0x5d, 0x11, 0xce, 0x87, 0xed, 0x01, 0x3e, 0x12, 0x96, 0x04,
		0xd3, 0xe2, 0x7f, 0x2e, 0x17, 0xc3, 0xe9, 0x48, 0x2b, 0x73, 0x72, 0x56, 0xbe, 0x83, 0x09, 0xf2,
		0xc4, 0x4c, 0x00, 0x13, 0xe4, 0x99, 0xb1, 0x35, 0x34, 0xd9, 0xf2, 0x66, 0x65, 0x68, 0xb2, 0x35,
		0x95, 0x7d, 0xa1, 0xc9, 0x96, 0x0f, 0xe8, 0xc3, 0x04, 0xf9, 0xa7, 0x07, 0x40, 0x4c, 0x90, 0x67,
		0x83, 0x2b, 0x31, 0x41, 0x1e, 0x13, 0xe4, 0x57, 0xa5, 0xc1, 0x04, 0xf9, 0x67, 0x09, 0x89, 0x09,
		0xf2, 0x74, 0xb3, 0x25, 0x66, 0x66, 0x49, 0x8c, 0x99, 0x2a, 0x7f, 0xb4, 0xbc, 0x31, 0x8c, 0x97,
		0x2f, 0x8c, 0xab, 0xc0, 0x78, 0xf9, 0x1c, 0x5d, 0x43, 0x61, 0x06, 0xcd, 0xbf, 0x32, 0xd8, 0x32,
		0x96, 0x88, 0x74, 0xa9, 0x4b, 0x76, 0x30, 0x3d, 0x3f, 0x11, 0x91, 0x62, 0x2f, 0xaf, 0x17, 0x8c,
		0xea, 0x07, 0x9f, 0x24, 0xc1, 0xa6, 0x5e, 0x70, 0xa9, 0xda, 0x0e, 0x34, 0x47, 0x06, 0x86, 0x11,
		0x41, 0x03, 0x12, 0xcc, 0x05, 0xf9, 0xa9, 0x8d, 0x5b, 0xea, 0xa2, 0x87, 0x9a, 0x2b, 0x29, 0xb2,
		0x4b, 0x5d, 0xf6, 0xc8, 0xc5, 0x0e, 0xd5, 0x28, 0xb1, 0x7c, 0x95, 0x52, 0xa0, 0x4e, 0x8a, 0xa7,
		0x35, 0x6b, 0x99, 0xc6, 0xac, 0x78, 0xda, 0xf2, 0xcd, 0x41, 0xef, 0x96, 0xa2, 0x0b, 0x6a, 0x38,
		0xc8, 0xd5, 0x78, 0x50, 0xab, 0xeb, 0x20, 0x56, 0xfb, 0x41, 0xab, 0xf6, 0x83, 0x54, 0xbd, 0x07,
		0xa5, 0x66, 0x85, 0x70, 0xd5, 0xd3, 0x82, 0xf5, 0xd4, 0x0b, 0xe9, 0xac, 0x0b, 0xd2, 0x54, 0xff,
		0xa3, 0xad, 0xce, 0x47, 0x67, 0x3d, 0x0f, 0x81, 0xba, 0x1d, 0xdd, 0xf5, 0x39, 0x64, 0xea, 0x70,
		0xc8, 0xd4, 0xdb, 0xd0, 0xa8, 0xab, 0x31, 0x3b, 0x43, 0xa9, 0xad, 0x1e, 0x26, 0xb3, 0x78, 0x6f,
		0x24, 0x82, 0xc4, 0x4b, 0xae, 0xf4, 0xd4, 0xbe, 0x64, 0xd8, 0x5e, 0x47, 0x0e, 0xb0, 0xb9, 0xb8,
		0xf5, 0x7d, 0x37, 0x16, 0xfa, 0x97, 0x9d, 0x36, 0xfb, 0xcd, 0xbe, 0x33, 0x68, 0x7d, 0x76, 0x06,
		0x5f, 0xba, 0x0d, 0x5d, 0xbe, 0x27, 0x6d, 0x3b, 0x8f, 0xb5, 0xce, 0x0d, 0x21, 0xb2, 0xa3, 0xaf,
		0xd9, 0xfd, 0xbc, 0xe3, 0xf4, 0x1a, 0xb5, 0x83, 0x4f, 0xb5, 0xfd, 0x66, 0xab, 0x39, 0xf8, 0xa2,
		0x71, 0x6f, 0xe4, 0x6f, 0x45, 0x7f, 0x19, 0x87, 0x03, 0xa7, 0xd9, 0x6f, 0xe3, 0x0d, 0xe8, 0x7b,
		0x03, 0xb5, 0xa3, 0xc1, 0xa7, 0x46, 0x7b, 0xd0, 0x3c, 0xa8, 0x0d, 0x9a, 0x1d, 0xbc, 0x09, 0x9d,
		0x8e, 0xa9, 0xd9, 0x77, 0xda, 0x8d, 0xe6, 0xc7, 0x4f, 0xfb, 0x9d, 0x5e, 0x1f, 0x2f, 0x42, 0x6b,
		0x84, 0xa8, 0x38, 0x8d, 0x3f, 0x07, 0x8d, 0x5e, 0xbb, 0xd6, 0x42, 0xa8, 0xa0, 0xf4, 0x56, 0xfa,
		0xbd, 0xd6, 0x47, 0xbc, 0x04, 0xcd, 0xe0, 0x69, 0xd0, 0x70, 0x7a, 0x9d, 0xa3, 0x41, 0xa3, 0xe7,
		0x34, 0xeb, 0x78, 0x19, 0x3a, 0x89, 0x45, 0x16, 0x2f, 0x9c, 0xda, 0x60, 0xd0, 0x6b, 0xee, 0x1f,
		0x0d, 0x1a, 0x78, 0x21, 0x9a, 0xd1, 0x2c, 0xde, 0x09, 0xa9, 0x77, 0x32, 0x8b, 0xe3, 0xed, 0x7a,
		0xa3, 0xee, 0xa4, 0xf1, 0x03, 0xc1, 0x9c, 0xc6, 0x5b, 0xe9, 0x1e, 0xf5, 0x3e, 0x36, 0x9c, 0x4e,
		0x13, 0xef, 0x80, 0x82, 0x65, 0xf4, 0x61, 0x17, 0x54, 0xd8, 0x78, 0xaf, 0x51, 0x73, 0x6a, 0xf5,
		0x7a, 0xaf, 0xd1, 0xef, 0x37, 0x40, 0x02, 0x75, 0xd3, 0x8d, 0x66, 0x7b, 0xd0, 0xe8, 0x7d, 0xa8,
		0x1d, 0x34, 0xf0, 0x4e, 0x28, 0xbc, 0x93, 0x56, 0xbf, 0xeb, 0xec, 0x1f, 0x7d, 0xf8, 0xd0, 0xe8,
		0x39, 0xfd, 0xe6, 0xff, 0x00, 0x56, 0xe9, 0x26, 0x82, 0x30, 0x0f, 0x72, 0xf4, 0x03, 0x87, 0x1b,
		0xd4, 0xde, 0x07, 0x48, 0x07, 0x95, 0xf7, 0x51, 0xff, 0xd2, 0xae, 0x1d, 0x36, 0x0f, 0x9c, 0x76,
		0xed, 0x10, 0xb1, 0x43, 0xe3, 0x7b, 0x68, 0xb7, 0xba, 0x48, 0x1c, 0x6a, 0x75, 0x4c, 0x47, 0xad,
		0x41, 0xd3, 0x19, 0x74, 0xba, 0x9d, 0x56, 0xe7, 0x23, 0x5c, 0x92, 0x4e, 0x18, 0xd5, 0xee, 0x0f,
		0x6a, 0xed, 0x83, 0x06, 0x32, 0xe9, 0x7a, 0x5f, 0x43, 0xbf, 0xd9, 0x77, 0x6a, 0xad, 0x66, 0xad,
		0x8f, 0x17, 0xa1, 0x9f, 0x56, 0xe0, 0x90, 0x4f, 0xef, 0x4b, 0x58, 0x1c, 0xee, 0x1d, 0xd4, 0xba,
		0x00, 0xad, 0x14, 0x2c, 0x62, 0x91, 0x87, 0x42, 0x31, 0x02, 0xb1, 0xb7, 0x42, 0xe4, 0x1c, 0x5c,
		0xcb, 0x95, 0x8f, 0x4d, 0xaf, 0x17, 0x47, 0xfb, 0xd4, 0xb3, 0x0c, 0x04, 0x1d, 0xd0, 0x37, 0x1d,
		0xd0, 0x0a, 0x47, 0x73, 0x9b, 0xd1, 0xf3, 0xac, 0xb4, 0x15, 0x4e, 0x47, 0x0b, 0x9c, 0xe2, 0xd6,
		0x37, 0xe5, 0x2d, 0x6f, 0xe8, 0x78, 0x56, 0x73, 0x5d, 0x74, 0x3c, 0xa3, 0xe3, 0x39, 0xb7, 0x47,
		0xa9, 0xbc, 0x55, 0x4d, 0xe3, 0x68, 0x66, 0x1d, 0xa3, 0x97, 0x75, 0x8e, 0x56, 0x56, 0x80, 0x0b,
		0x5e, 0x31, 0xb6, 0x01, 0x85, 0xa3, 0x8d, 0xd5, 0x4e, 0x8b, 0x53, 0x3f, 0x1d, 0x8e, 0xc4, 0x34,
		0x38, 0xb5, 0xd3, 0xdf, 0x64, 0x2b, 0xa7, 0x62, 0x2e, 0x45, 0x91, 0x43, 0x59, 0x4a, 0x26, 0x2d,
		0x3d, 0x73, 0x3c, 0x9b, 0x5c, 0x17, 0x2e, 0xcf, 0xb1, 0xca, 0xf9, 0xcd, 0x92, 0xac, 0x41, 0x95,
		0x15, 0x50, 0xd3, 0x7e, 0x39, 0xca, 0x95, 0xff, 0xab, 0x97, 0xf0, 0xda, 0xad, 0x9b, 0xa9, 0xbd,
		0xe9, 0x93, 0x90, 0xf5, 0xda, 0x33, 0x1c, 0x7a, 0xef, 0x7a, 0x92, 0x14, 0x59, 0xee, 0xb4, 0x33,
		0xe9, 0x5c, 0x5f, 0x05, 0xb7, 0x57, 0xc8, 0xe5, 0x55, 0x71, 0x77, 0xe5, 0x5c, 0x5d, 0x39, 0x37,
		0x57, 0xcb, 0xc5, 0x79, 0x05, 0x2f, 0xd9, 0xd3, 0xc4, 0xee, 0xba, 0x2e, 0xf9, 0xca, 0xfc, 0xa0,
		0xc7, 0x94, 0xad, 0xd0, 0x6a, 0xc6, 0x44, 0x2a, 0x4b, 0x96, 0xaa, 0x4c, 0x92, 0x6a, 0x48, 0x8e,
		0xaa, 0x4e, 0x8a, 0x6a, 0x4b, 0x86, 0x6a, 0x4b, 0x82, 0xea, 0x49, 0x7e, 0xf2, 0x4e, 0xf4, 0xa8,
		0x1a, 0xeb, 0x88, 0xb9, 0xbd, 0x7c, 0x1d, 0xb3, 0x0e, 0x07, 0xad, 0xd1, 0x51, 0xeb, 0x72, 0xd8,
		0xda, 0x1d, 0xb7, 0x76, 0x07, 0xae, 0xd7, 0x91, 0xab, 0x71, 0xe8, 0x8a, 0x1c, 0xbb, 0x72, 0x07,
		0x9f, 0x5d, 0xd0, 0x17, 0xc1, 0x69, 0x9a, 0x2b, 0xd2, 0x34, 0xb9, 0x77, 0x71, 0x7d, 0xcc, 0xee,
		0x35, 0x2d, 0x14, 0x10, 0x08, 0x09, 0xba, 0x43, 0x03, 0x99, 0x10, 0x41, 0x26, 0x54, 0xd0, 0x08,
		0x19, 0x6a, 0x43, 0x87, 0xe2, 0x10, 0x92, 0x3d, 0x62, 0xfd, 0xb3, 0x7b, 0xa7, 0x5e, 0x90, 0xbc,
		0xd3, 0x38, 0xb5, 0x57, 0xc7, 0xd0, 0xde, 0x9e, 0x1b, 0x9c, 0x0a, 0x6d, 0x03, 0x6a, 0x35, 0xae,
		0x55, 0x3c, 0xf4, 0xf4, 0xaf, 0x7e, 0xd5, 0x14, 0xd7, 0x57, 0xc4, 0x48, 0xc7, 0x14, 0x13, 0x90,
		0xe3, 0x43, 0xe4, 0x0e, 0x13, 0x2f, 0x0c, 0xea, 0xde, 0xa9, 0x37, 0xaf, 0xa0, 0x28, 0x62, 0xb3,
		0x85, 0x75, 0xe8, 0x5e, 0x42, 0x35, 0xef, 0xa9, 0xe6, 0x56, 0xb5, 0x0a, 0xe5, 0xd4, 0x03, 0x04,
		0xf4, 0x5d, 0xf5, 0xd8, 0xd4, 0xe6, 0x93, 0xdf, 0xb0, 0xe8, 0x06, 0x64, 0x19, 0x64, 0x19, 0x64,
		0x19, 0x64, 0x19, 0x64, 0x19, 0x64, 0x19, 0x64, 0x19, 0x64, 0x19, 0x64, 0x19, 0x64, 0x19, 0x64,
		0x19, 0x64, 0x19, 0x64, 0x19, 0x64, 0x59, 0x1b, 0x59, 0xbe, 0x58, 0x18, 0x90, 0x26, 0xb6, 0x3c,
		0xbf, 0x3c, 0xe8, 0x32, 0xe8, 0x32, 0xe8, 0x32, 0xe8, 0x32, 0xe8, 0xb2, 0x41, 0x74, 0xf9, 0xc4,
		0x0b, 0xdc, 0xe8, 0x4a, 0x23, 0x5f, 0xde, 0xc3, 0x20, 0x27, 0xfa, 0x0a, 0x8b, 0x41, 0x4e, 0x93,
		0xd2, 0xdd, 0xb6, 0xc0, 0xbb, 0xff, 0xc4, 0x70, 0xa7, 0xa7, 0xbe, 0x58, 0x0c, 0x77, 0x62, 0x8e,
		0x5b, 0x51, 0x16, 0x5f, 0x0c, 0x5c, 0x8a, 0xb2, 0x78, 0x83, 0xc2, 0x38, 0x86, 0x3b, 0xc9, 0x76,
		0x8a, 0x18, 0xee, 0x44, 0xd4, 0x06, 0x30, 0xdc, 0x29, 0xc7, 0x2b, 0x62, 0xb8, 0x13, 0x6f, 0x7e,
		0xc5, 0x85, 0x57, 0xd1, 0x1d, 0xf8, 0x74, 0xb4, 0x14, 0x13, 0x93, 0x9f, 0xd4, 0x98, 0x4a, 0x11,
		0x27, 0x3f, 0xdd, 0x9b, 0x44, 0xc4, 0x65, 0x06, 0xd4, 0x2b, 0xc2, 0xea, 0xb4, 0x84, 0x01, 0x7e,
		0x3c, 0xb1, 0xbd, 0x51, 0xce, 0xfe, 0x45, 0x6e, 0xe0, 0x97, 0x1f, 0xe8, 0xb5, 0x04, 0x76, 0xb9,
		0x81, 0x3c, 0x6f, 0xf5, 0x91, 0xec, 0x85, 0x08, 0x79, 0x1f, 0x09, 0xb1, 0xf7, 0x79, 0xb1, 0x36,
		0x5f, 0xbf, 0x97, 0x9f, 0x77, 0xca, 0xe7, 0x37, 0xe5, 0xa4, 0xa0, 0xb2, 0x14, 0x93, 0x88, 0x42,
		0xe6, 0xa3, 0x03, 0x2f, 0x7f, 0x63, 0x39, 0xbc, 0x2d, 0x2b, 0x0a, 0xa7, 0x89, 0xb0, 0x27, 0x91,
		0x18, 0x8b, 0x48, 0x04, 0x39, 0xe6, 0x14, 0xb3, 0x64, 0xcb, 0xca, 0x15, 0x72, 0xd2, 0xb1, 0x7c,
		0x27, 0xbd, 0xe4, 0x9e, 0xb2, 0x96, 0x91, 0x92, 0x96, 0x98, 0x72, 0x96, 0x95, 0x52, 0x96, 0x9e,
		0x32, 0x96, 0x9e, 0x12, 0x96, 0x9b, 0xf2, 0xa5, 0xe5, 0xb7, 0xf3, 0x9e, 0x54, 0x62, 0x0d, 0x97,
		0x56, 0x95, 0xb3, 0x56, 0x2d, 0x0d, 0x61, 0xf1, 0xfb, 0xf3, 0x86, 0xe5, 0x52, 0x86, 0x48, 0x49,
		0x3b, 0x15, 0x93, 0x79, 0xfa, 0xa5, 0xe0, 0x94, 0x4b, 0xf6, 0x69, 0x96, 0xb2, 0x53, 0x2b, 0x65,
		0xa7, 0x53, 0x6a, 0x4e, 0xa1, 0x68, 0x53, 0x67, 0x59, 0x43, 0x95, 0x2c, 0x71, 0x99, 0x88, 0x28,
		0x70, 0x7d, 0x5b, 0x1a, 0x34, 0x5a, 0x6b, 0x63, 0xeb, 0x2f, 0x2d, 0x77, 0xee, 0xf3, 0x26, 0xe6,
		0x3e, 0xeb, 0x74, 0x80, 0xaa, 0x1c, 0xa1, 0x72, 0x87, 0xa8, 0xdc, 0x31, 0xaa, 0x75, 0x90, 0xf2,
		0xb2, 0x96, 0x1b, 0x12, 0x53, 0xd7, 0xd2, 0x8f, 0xdd, 0x95, 0x75, 0x3f, 0x2a, 0xe8, 0x72, 0x54,
		0xd4, 0xcd, 0xa8, 0xe6, 0x60, 0x56, 0xe1, 0xdc, 0x63, 0xb5, 0xe5, 0x66, 0xcb, 0x96, 0x2e, 0x55,
		0x53, 0x5f, 0x35, 0x34, 0x6e, 0x5d, 0xab, 0x39, 0x49, 0x57, 0xae, 0x22, 0xdb, 0x8a, 0x55, 0x64,
		0xd3, 0x60, 0x15, 0x61, 0x7a, 0xf2, 0x7b, 0x5c, 0xe0, 0x75, 0x32, 0x5e, 0xa0, 0x8d, 0x6c, 0xac,
		0xbf, 0x34, 0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x06,
		0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x06, 0xc8, 0x86, 0x62, 0xb2, 0x81, 0xc2, 0x33, 0xb5, 0x75, 0x3e,
		0xf7, 0x59, 0x50, 0x69, 0x71, 0xb4, 0x4c, 0xb5, 0xde, 0x2b, 0xc7, 0xd2, 0x0f, 0x39, 0x7b, 0xa1,
		0xa4, 0xee, 0x7f, 0x92, 0x7e, 0x44, 0xbf, 0x85, 0x23, 0x7a, 0x85, 0x64, 0x11, 0x47, 0xf4, 0x26,
		0x46, 0x09, 0x1c, 0xd1, 0x23, 0x6b, 0x86, 0xac, 0x19, 0xb2, 0x66, 0xc8, 0x9a, 0x21, 0x6b, 0x86,
		0xac, 0x19, 0xb2, 0x66, 0xc8, 0x9a, 0x21, 0x6b, 0x86, 0xac, 0x19, 0xb2, 0x66, 0x12, 0xb3, 0x66,
		0x38, 0xa2, 0x07, 0xd9, 0x00, 0xd9, 0x00, 0xd9, 0x00, 0xd9, 0x00, 0xd9, 0x00, 0xd9, 0x00, 0xd9,
		0x00, 0xd9, 0x00, 0xd9, 0x00, 0xd9, 0x00, 0xd9, 0xc0, 0x11, 0x7d, 0xde, 0x0a, 0x4d, 0xe1, 0x88,
		0x5e, 0xc2, 0xa0, 0x6b, 0x4c, 0x64, 0x61, 0xa7, 0x06, 0x56, 0xae, 0xa5, 0x10, 0x4f, 0x9d, 0x09,
		0xd4, 0x9b, 0x49, 0xd3, 0xbd, 0x11, 0xc6, 0xa0, 0xd9, 0x30, 0xf9, 0xd6, 0x85, 0x48, 0xa9, 0x07,
		0x91, 0x36, 0x05, 0x66, 0x0b, 0x53, 0x60, 0x38, 0x65, 0x18, 0x30, 0x05, 0x86, 0xf2, 0x14, 0x18,
		0x77, 0x9a, 0x9c, 0x89, 0x20, 0xf1, 0x86, 0x69, 0x00, 0xb2, 0x87, 0x67, 0x62, 0xf8, 0x5d, 0x5e,
		0xbd, 0xd9, 0x83, 0x57, 0xcb, 0xbb, 0xb4, 0x45, 0x8c, 0xdd, 0xa9, 0x9f, 0x2a, 0xc3, 0x4c, 0xd7,
		0x24, 0x55, 0xb7, 0x6d, 0x62, 0x00, 0x0d, 0xaa, 0xdb, 0x28, 0x79, 0x41, 0x35, 0xde, 0x90, 0x07,
		0xc1, 0x92, 0x96, 0x37, 0xbd, 0x59, 0x87, 0x15, 0x86, 0xbe, 0x70, 0x03, 0x19, 0x1a, 0xbf, 0x84,
		0x4d, 0xe5, 0x02, 0x94, 0x37, 0x8b, 0xc0, 0x3d, 0xf1, 0xc5, 0x48, 0x5e, 0xc0, 0x59, 0x5e, 0x40,
		0x5e, 0x8c, 0x19, 0xbb, 0x7e, 0x8c, 0x20, 0x83, 0x20, 0x83, 0x20, 0x83, 0x20, 0x83, 0x20, 0x43,
		0x31, 0xc8, 0xa4, 0xa9, 0x29, 0x3b, 0x98, 0x9e, 0x9f, 0x88, 0x48, 0x5e, 0xa4, 0xb9, 0x73, 0x15,
		0x84, 0x03, 0x84, 0x03, 0x84, 0x03, 0x84, 0x03, 0x2e, 0x1e, 0x66, 0x43, 0x6e, 0x89, 0x86, 0xe4,
		0xd2, 0x0c, 0x89, 0xf5, 0x31, 0x2a, 0x4a, 0x31, 0x14, 0x95, 0x60, 0xa8, 0x2a, 0xbd, 0x50, 0x79,
		0x9e, 0x2e, 0xb1, 0xd4, 0x42, 0x49, 0x89, 0x85, 0xea, 0x57, 0xbf, 0x65, 0xd0, 0xab, 0x67, 0x52,
		0x8a, 0x70, 0x5c, 0x00, 0x84, 0x7d, 0x2e, 0x92, 0xc8, 0x1b, 0xda, 0x71, 0x72, 0xe5, 0x4b, 0x6c,
		0x56, 0xbf, 0x73, 0x15, 0x20, 0x6c, 0x20, 0x6c, 0x20, 0x6c, 0x20, 0x6c, 0x2e, 0x1e, 0xe6, 0x4e,
		0xd6, 0xa5, 0x22, 0xe1, 0x77, 0x37, 0x82, 0xe9, 0xf9, 0xec, 0xe9, 0x5c, 0xa3, 0xe6, 0xea, 0x57,
		0xcc, 0xc9, 0x9c, 0x9a, 0xab, 0x1c, 0x2b, 0xed, 0x88, 0xd4, 0x36, 0x5d, 0xc5, 0x89, 0x38, 0xb7,
		0xe7, 0x74, 0x77, 0x18, 0x4e, 0x83, 0x44, 0x44, 0xb1, 0x84, 0x5a, 0xa7, 0x07, 0x2f, 0x83, 0x0d,
		0x58, 0x04, 0x71, 0x03, 0x6a, 0x9f, 0xf4, 0xe0, 0x02, 0xc3, 0x6b, 0x9f, 0x30, 0x5c, 0x6b, 0xd5,
		0xc1, 0x60, 0xb8, 0x16, 0x88, 0x0a, 0x88, 0x0a, 0x2d, 0x47, 0x95, 0xfd, 0x62, 0x77, 0x9a, 0x9c,
		0xd9, 0x63, 0xd7, 0xf3, 0x63, 0xf9, 0x0d, 0xee, 0xb7, 0xae, 0x85, 0x8e, 0x76, 0xd5, 0xae, 0x4d,
		0xa1, 0x8b, 0x53, 0xe5, 0xea, 0x94, 0xbb, 0x3c, 0xe5, 0xae, 0x4f, 0xad, 0x0b, 0x94, 0xe3, 0x0a,
		0x25, 0xb9, 0x44, 0xf9, 0x39, 0x9c, 0x15, 0x8b, 0x59, 0x30, 0xba, 0xed, 0x2d, 0x05, 0x5d, 0xed,
		0xbb, 0xe8, 0x6a, 0x7f, 0xfc, 0x46, 0x8a, 0xd0, 0xd5, 0xbe, 0x89, 0xae, 0xf6, 0x17, 0xa9, 0x88,
		0x86, 0xae, 0x76, 0xd5, 0x2a, 0x52, 0xd9, 0xda, 0xab, 0xec, 0xed, 0xec, 0x6e, 0xed, 0x55, 0xd1,
		0xde, 0x4e, 0xed, 0xb7, 0x17, 0x79, 0x96, 0x56, 0x8a, 0xf7, 0x93, 0xab, 0x89, 0x50, 0x4a, 0x30,
		0x6e, 0x5d, 0x10, 0x2c, 0x03, 0x2c, 0x03, 0x2c, 0x03, 0x2c, 0x03, 0x2c, 0x03, 0x2c, 0x03, 0x2c,
		0x03, 0x2c, 0x03, 0x2c, 0x03, 0x2c, 0x03, 0x2c, 0xc3, 0x30, 0x96, 0x31, 0x0c, 0xa3, 0x68, 0x3a,
		0x49, 0xc4, 0xc8, 0xf6, 0xe3, 0x89, 0x02, 0x92, 0x71, 0xef, 0x7a, 0xe0, 0x18, 0xe0, 0x18, 0xe0,
		0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0,
		0x18, 0x86, 0x71, 0x8c, 0x91, 0x9b, 0xb8, 0x27, 0x6e, 0x2c, 0xec, 0xf0, 0x42, 0x44, 0x7e, 0xe8,
		0x8e, 0x14, 0xf0, 0x8c, 0x07, 0xae, 0x09, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae,
		0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x61, 0x18, 0xd7, 0x10,
		0x97, 0x43, 0x21, 0x46, 0xf6, 0xb9, 0x7b, 0x69, 0xc7, 0xe2, 0x5f, 0x76, 0x30, 0x3d, 0x8f, 0x55,
		0x2c, 0x3a, 0x5f, 0xbd, 0x28, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8,
		0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x06, 0xd8, 0x86, 0x61, 0x6c, 0xc3, 0x1b, 0xd9,
		0xbe, 0x08, 0xec, 0x73, 0x2f, 0x3e, 0x77, 0x93, 0xe1, 0x99, 0x82, 0x2d, 0xe7, 0xf7, 0x2e, 0x08,
		0x96, 0x01, 0x96, 0x01, 0x96, 0x01, 0x96, 0x01, 0x96, 0x01, 0x96, 0x01, 0x96, 0x01, 0x96, 0x01,
		0x96, 0x01, 0x96, 0x01, 0x96, 0x61, 0x18, 0xcb, 0xf0, 0xe3, 0x89, 0x2d, 0xa2, 0x28, 0x8c, 0x14,
		0x1c, 0x65, 0xdc, 0xba, 0x16, 0xb8, 0x05, 0xb8, 0x05, 0xb8, 0x05, 0xb8, 0x05, 0xb8, 0x05, 0xb8,
		0x05, 0xb8, 0x05, 0xb8, 0x05, 0xb8, 0x05, 0xb8, 0x05, 0xb8, 0x85, 0x61, 0xdc, 0xe2, 0xdc, 0x0d,
		0xa6, 0xae, 0x6f, 0xbb, 0xa3, 0x51, 0x24, 0xe2, 0xd8, 0x1e, 0x45, 0xe1, 0xc4, 0x1e, 0x47, 0xe1,
		0xb9, 0xed, 0x46, 0xc2, 0x55, 0xc0, 0x37, 0x1e, 0xb9, 0x3e, 0x38, 0x08, 0x38, 0x08, 0x38, 0x08,
		0x38, 0x08, 0x38, 0x08, 0x38, 0x08, 0x38, 0x08, 0x38, 0x08, 0x38, 0x08, 0x38, 0x08, 0x38, 0x88,
		0x71, 0x1c, 0xe4, 0x32, 0x85, 0xfb, 0x19, 0x0b, 0x58, 0x96, 0x37, 0x09, 0x25, 0x04, 0x64, 0xfd,
		0xc5, 0xc1, 0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0xc0,
		0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0xc0, 0x3e, 0x0c, 0x63, 0x1f, 0xe1, 0x8f, 0xc0, 0xf6, 0xe3, 0x89,
		0x3d, 0x99, 0x46, 0xa7, 0x2a, 0x08, 0xc7, 0xbd, 0xeb, 0x81, 0x63, 0x80, 0x63, 0x80, 0x63, 0x80,
		0x63, 0x80, 0x63, 0x80, 0x63, 0x80, 0x63, 0x80, 0x63, 0x80, 0x63, 0x80, 0x63, 0x80, 0x63, 0x18,
		0xc6, 0x31, 0x26, 0x6e, 0x94, 0xd8, 0xc3, 0xb3, 0x59, 0xb4, 0x51, 0xc0, 0x30, 0xee, 0x5c, 0x0d,
		0xfc, 0x02, 0xfc, 0x02, 0xfc, 0x02, 0xfc, 0x02, 0xfc, 0x02, 0xfc, 0x02, 0xfc, 0x02, 0xfc, 0x02,
		0xfc, 0x02, 0xfc, 0x02, 0xfc, 0xc2, 0x30, 0x7e, 0xb1, 0x98, 0x3a, 0x6b, 0xc7, 0xdf, 0x3d, 0x15,
		0x4b, 0xfc, 0xee, 0x5e, 0x0e, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0x03, 0x0c,
		0x03, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0xc3, 0x34, 0x86, 0x31, 0x19, 0xdb,
		0xd1, 0x34, 0x50, 0x41, 0x2e, 0x96, 0x57, 0x02, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00,
		0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0x00, 0xaf, 0xd0, 0xc9, 0x2b,
		0x5e, 0x11, 0xb6, 0x6c, 0xab, 0x16, 0x04, 0x61, 0xe2, 0xce, 0x54, 0x4e, 0x8a, 0x31, 0x5b, 0xf1,
		0xf0, 0x4c, 0x9c, 0xbb, 0x13, 0x37, 0x39, 0x9b, 0xc5, 0xf9, 0x52, 0x38, 0x11, 0xc1, 0x30, 0xc5,
		0xfa, 0x76, 0x20, 0x92, 0x1f, 0x61, 0xf4, 0xdd, 0xf6, 0x82, 0x38, 0x71, 0x83, 0xa1, 0x28, 0xdd,
		0xff, 0x46, 0xbc, 0xf2, 0x9d, 0xd2, 0x24, 0x0a, 0x93, 0x70, 0x18, 0xfa, 0x71, 0xf6, 0x55, 0x69,
		0x06, 0xd8, 0x4a, 0xbe, 0xb8, 0x10, 0xfe, 0xe2, 0xaf, 0x52, 0x7c, 0x15, 0x27, 0xe2, 0xdc, 0x4e,
		0xff, 0x61, 0x2f, 0x90, 0x45, 0x5c, 0x8a, 0x13, 0x37, 0x11, 0xf9, 0x22, 0xbb, 0xfc, 0xde, 0x6c,
		0x3e, 0xbf, 0x29, 0x27, 0xdd, 0x90, 0xa5, 0x13, 0x64, 0x74, 0x21, 0x47, 0x90, 0x69, 0xc5, 0x49,
		0x34, 0x1d, 0x26, 0xc1, 0x02, 0xc7, 0xb6, 0xe7, 0x42, 0x36, 0x17, 0x32, 0x3a, 0xdd, 0x85, 0x64,
		0x4e, 0x33, 0xf6, 0x62, 0xa7, 0x35, 0x93, 0xc2, 0xe9, 0xa7, 0x22, 0xa5, 0x5f, 0x1f, 0x2c, 0x05,
		0x7a, 0x45, 0x43, 0x89, 0x72, 0x50, 0x20, 0x2b, 0x89, 0xdc, 0xf1, 0xd8, 0x1b, 0xda, 0x22, 0x38,
		0xf5, 0x02, 0x21, 0x22, 0x2f, 0x38, 0xcd, 0x4d, 0x8b, 0x32, 0xbe, 0xf0, 0xd0, 0x45, 0x72, 0x52,
		0xfe, 0x05, 0xd2, 0x28, 0xe7, 0xf4, 0xeb, 0xf2, 0x4e, 0x6c, 0xc8, 0x48, 0x64, 0x48, 0x4c, 0x5c,
		0xc8, 0x4a, 0x54, 0x48, 0x4f, 0x4c, 0x48, 0x4f, 0x44, 0xc8, 0x4d, 0x3c, 0xd0, 0x0a, 0x28, 0x75,
		0x2f, 0xca, 0x57, 0x61, 0x87, 0x4b, 0xab, 0xca, 0x59, 0xab, 0x6e, 0xf2, 0x11, 0xe9, 0xef, 0xcf,
		0xf9, 0x8d, 0xe7, 0xeb, 0x5a, 0xa4, 0xb9, 0x18, 0x99, 0xae, 0x46, 0x81, 0xcb, 0x91, 0xed, 0x7a,
		0x94, 0xb9, 0x20, 0x65, 0xae, 0x48, 0x8d, 0x4b, 0xe2, 0xc1, 0x87, 0xf2, 0x76, 0x55, 0xd9, 0x2f,
		0x16, 0x81, 0x7b, 0xe2, 0x8b, 0x91, 0x82, 0xb5, 0xea, 0x8b, 0x0b, 0x49, 0xd2, 0x91, 0xba, 0x18,
		0xbb, 0x53, 0x3f, 0x55, 0x91, 0xb1, 0xeb, 0xc7, 0x02, 0x07, 0x4e, 0xca, 0x9d, 0xa7, 0x42, 0x27,
		0xaa, 0xca, 0x99, 0x2a, 0x77, 0xaa, 0xca, 0x9d, 0xab, 0x5a, 0x27, 0x2b, 0x37, 0xfd, 0xc6, 0xff,
		0xc0, 0xe9, 0x24, 0x0c, 0x7d, 0xe1, 0x06, 0x0a, 0x8e, 0x9b, 0xca, 0xe5, 0x22, 0x6f, 0xfa, 0x9d,
		0x5c, 0x54, 0xec, 0x28, 0x9c, 0x26, 0x22, 0xb2, 0x3d, 0x05, 0xb1, 0xef, 0xde, 0xf5, 0x10, 0x9a,
		0x10, 0x9a, 0x10, 0x9a, 0x10, 0x9a, 0x58, 0x85, 0xa6, 0xd4, 0x87, 0x2d, 0xc7, 0xea, 0x06, 0xa1,
		0xfd, 0xef, 0x30, 0x10, 0x2a, 0xe2, 0xd4, 0x3b, 0x89, 0xd7, 0xe8, 0xba, 0x49, 0x22, 0xa2, 0x40,
		0x7a, 0x65, 0x84, 0xf5, 0xfa, 0xf5, 0xd7, 0x4d, 0x7b, 0xef, 0xf8, 0xef, 0xaf, 0x65, 0x7b, 0xef,
		0x78, 0xfe, 0x65, 0x39, 0xfd, 0x6b, 0xfe, 0xf5, 0xd6, 0xd7, 0x4d, 0xbb, 0xb2, 0xfc, 0xba, 0xfa,
		0x75, 0xd3, 0xae, 0x1e, 0xbf, 0xf9, 0xf6, 0xed, 0xed, 0x9b, 0xbf, 0xb6, 0xaf, 0x9f, 0xfe, 0x83,
		0xaf, 0xff, 0xf3, 0xeb, 0xb7, 0x6f, 0x93, 0xbf, 0xda, 0xd7, 0xb3, 0x3f, 0x5b, 0xd7, 0xc7, 0xff,
		0xf5, 0xe6, 0x9f, 0xb2, 0x3d, 0xc2, 0x4c, 0x80, 0x6f, 0xdf, 0xde, 0x1e, 0xff, 0xc3, 0xc2, 0xb1,
		0xaa, 0x1c, 0xb8, 0xb2, 0xa3, 0x18, 0xae, 0xec, 0x00, 0xae, 0x00, 0xae, 0x00, 0xae, 0x00, 0xae,
		0x30, 0x86, 0x2b, 0x3b, 0x80, 0x2b, 0xcf, 0x86, 0x2b, 0xef, 0xff, 0x9e, 0xc5, 0x74, 0xd7, 0x1e,
		0xd7, 0xec, 0x0f, 0xc7, 0x7f, 0x6d, 0xfe, 0x56, 0xb9, 0x7e, 0xf3, 0xfe, 0xcd, 0xeb, 0xfb, 0xdf,
		0x7b, 0xff, 0xe6, 0xaf, 0xcd, 0xdf, 0xaa, 0xd7, 0xaf, 0x5f, 0x3f, 0xf0, 0x5f, 0xfe, 0xf9, 0xd0,
		0xef, 0x78, 0xf3, 0xf7, 0xeb, 0xd7, 0xaf, 0x17, 0x40, 0xe5, 0x0e, 0x78, 0xf9, 0xba, 0x59, 0x3e,
		0xfe, 0x67, 0xfa, 0xe5, 0xfc, 0xcf, 0x0c, 0xfe, 0xfc, 0xd2, 0xff, 0xfc, 0x46, 0x07, 0xe8, 0x79,
		0xfd, 0xfa, 0xeb, 0xff, 0xbe, 0x3f, 0xfe, 0xaf, 0xf7, 0x6f, 0xfe, 0xda, 0xb9, 0x5e, 0x7e, 0x9d,
		0xfe, 0xf9, 0xe6, 0xef, 0xd7, 0x6f, 0xff, 0xf1, 0xed, 0xdb, 0xdb, 0xb7, 0xff, 0x78, 0x33, 0xbf,
		0xe1, 0xc5, 0xff, 0xf7, 0x8f, 0xf9, 0x7f, 0xfd, 0xe7, 0xfb, 0xf7, 0x2b, 0xdf, 0x7a, 0xf3, 0xfa,
		0x3f, 0xdf, 0x2a, 0xc2, 0x69, 0xf3, 0xf7, 0xf1, 0x1e, 0x70, 0x4d, 0xc2, 0x6f, 0x44, 0x15, 0xdc,
		0xa3, 0x95, 0x4f, 0x0f, 0x94, 0xc8, 0x94, 0x16, 0xc7, 0xda, 0x54, 0x8b, 0xe0, 0x72, 0x2d, 0xcb,
		0x72, 0x13, 0x21, 0xaf, 0x3e, 0x60, 0xfe, 0xeb, 0x99, 0x95, 0x07, 0x6c, 0xa1, 0x3c, 0x40, 0x21,
		0x0e, 0x47, 0x79, 0x80, 0x89, 0x81, 0x02, 0xe5, 0x01, 0x8f, 0x3d, 0x20, 0x94, 0x07, 0x20, 0xa9,
		0x81, 0xa4, 0x06, 0x92, 0x1a, 0xac, 0x93, 0x1a, 0x28, 0x0f, 0x50, 0xf1, 0x52, 0x51, 0x1e, 0x80,
		0xd0, 0x84, 0xd0, 0x84, 0xd0, 0x84, 0xd0, 0xf4, 0x54, 0x1f, 0x86, 0x7c, 0xfb, 0xf3, 0x2e, 0x84,
		0xf2, 0x80, 0x97, 0x7e, 0x50, 0x1e, 0x80, 0xf2, 0x00, 0xc0, 0x15, 0xc0, 0x15, 0xc0, 0x15, 0xc0,
		0x95, 0x5f, 0xf6, 0x61, 0x80, 0x2b, 0xcf, 0x85, 0x2b, 0x28, 0x0f, 0xf8, 0x15, 0x4c, 0x87, 0xf2,
		0x00, 0xf6, 0x70, 0x0d, 0xe5, 0x01, 0xfa, 0xcb, 0x03, 0x30, 0x22, 0x47, 0xb7, 0x46, 0x10, 0xd1,
		0x04, 0xbd, 0x03, 0x72, 0x06, 0x73, 0x81, 0x1a, 0xb7, 0xe4, 0xa1, 0x32, 0x1f, 0xe7, 0x95, 0x46,
		0xdd, 0x9b, 0x21, 0xf6, 0xd9, 0x23, 0x9c, 0xcf, 0x32, 0x0a, 0xa6, 0xe7, 0x27, 0x22, 0x7a, 0xe1,
		0x8b, 0xb2, 0x5a, 0x5e, 0x9c, 0xd4, 0x92, 0x24, 0x9f, 0x33, 0x6d, 0xeb, 0xd0, 0x0b, 0x1a, 0xbe,
		0x98, 0x41, 0xee, 0x38, 0x1f, 0xbe, 0x67, 0x1d, 0xba, 0x97, 0xb7, 0x7e, 0x63, 0xf9, 0x5d, 0xa5,
		0xb2, 0xb3, 0x5b, 0xa9, 0x6c, 0xee, 0x6e, 0xef, 0x6e, 0xee, 0x55, 0xab, 0xe5, 0x9d, 0x72, 0x0e,
		0x73, 0xf9, 0xac, 0x4e, 0x34, 0x12, 0x91, 0x18, 0xed, 0xcf, 0x9e, 0x6e, 0x30, 0xf5, 0x7d, 0xad,
		0x2f, 0x39, 0x67, 0xc7, 0xa2, 0xc1, 0xa1, 0xe4, 0xe0, 0x3c, 0x9e, 0xee, 0x34, 0x5e, 0xe6, 0x21,
		0x9e, 0x6f, 0xd7, 0xcf, 0xfb, 0xc9, 0x67, 0x2a, 0x49, 0x5e, 0xca, 0xa1, 0x54, 0x29, 0x9e, 0xf7,
		0x66, 0x9e, 0xfe, 0x5c, 0x9f, 0xf6, 0x13, 0x4f, 0x7c, 0x03, 0x2f, 0x7d, 0xf2, 0x6a, 0x9e, 0xf8,
		0x33, 0x2c, 0xef, 0x29, 0x96, 0xf6, 0xb4, 0x37, 0xf9, 0xeb, 0xef, 0xe3, 0x09, 0xef, 0xc2, 0xf2,
		0xc3, 0xa1, 0xeb, 0xdb, 0xee, 0xe9, 0x69, 0x24, 0x4e, 0xdd, 0xe4, 0x19, 0x6b, 0x81, 0xb3, 0xc4,
		0xc4, 0xca, 0x6f, 0x7a, 0xa2, 0x46, 0x3c, 0xaf, 0x5a, 0xf3, 0xd9, 0xe9, 0xd0, 0x97, 0xa4, 0x39,
		0x6f, 0xa7, 0x2f, 0xfd, 0x70, 0x68, 0x47, 0xc9, 0x73, 0x34, 0xe5, 0x85, 0x89, 0xc9, 0xdc, 0x12,
		0x8e, 0xb9, 0x25, 0x12, 0xef, 0x27, 0x08, 0x17, 0x8f, 0x86, 0x98, 0xe7, 0x79, 0x6e, 0xc5, 0xa1,
		0x95, 0xa9, 0xf6, 0xf3, 0x5f, 0xd9, 0x52, 0x6f, 0x6e, 0x7e, 0xd5, 0x33, 0x9f, 0xf4, 0xcb, 0x4a,
		0x9b, 0x5f, 0x7c, 0x86, 0x90, 0xc7, 0x19, 0x41, 0x2e, 0x46, 0x94, 0x97, 0x31, 0xe5, 0x6e, 0x54,
		0xd2, 0xb2, 0xf4, 0x79, 0x19, 0x99, 0x1e, 0xc0, 0xf5, 0xd2, 0x72, 0xdf, 0xbc, 0x06, 0x15, 0xe6,
		0x3b, 0x98, 0x30, 0xa7, 0x4e, 0x83, 0xdc, 0x8e, 0xf6, 0xf2, 0x3c, 0xc2, 0xcb, 0xd5, 0x4c, 0xf3,
		0x36, 0x57, 0x69, 0x66, 0x2b, 0xcd, 0x7c, 0x65, 0x99, 0x31, 0x8d, 0x8c, 0x4a, 0x5e, 0xd5, 0xfc,
		0xd6, 0x48, 0xc4, 0xc3, 0xc8, 0x9b, 0xe4, 0x9a, 0x0f, 0xcc, 0x34, 0xf9, 0xf6, 0x2f, 0xcf, 0x77,
		0xc8, 0xf1, 0x66, 0x41, 0x87, 0x1c, 0xe7, 0xe6, 0x18, 0x64, 0x39, 0x08, 0xe9, 0x8e, 0x42, 0xba,
		0xc3, 0x90, 0xed, 0x38, 0xf2, 0x4b, 0xea, 0x6e, 0xe4, 0x78, 0x2c, 0x90, 0xfb, 0xb9, 0xfa, 0xad,
		0x8e, 0xc3, 0xbc, 0x13, 0xf3, 0xd9, 0x49, 0xb9, 0x41, 0xc3, 0xe7, 0x47, 0x5e, 0x3c, 0x74, 0xa3,
		0x91, 0x04, 0x1f, 0xbc, 0xf8, 0xc5, 0x79, 0x0d, 0xc4, 0x96, 0xd3, 0x25, 0x05, 0xbf, 0x0e, 0xbf,
		0x0e, 0xbf, 0xce, 0xca, 0xaf, 0xe7, 0xdf, 0x69, 0x94, 0x73, 0x67, 0x11, 0x0d, 0xc7, 0x3e, 0xc9,
		0xd7, 0x71, 0x64, 0x8f, 0x3f, 0x5f, 0xf6, 0x05, 0xf7, 0x0b, 0xf7, 0x0b, 0xf7, 0xcb, 0xc9, 0xfd,
		0x7a, 0x13, 0x3b, 0x77, 0x05, 0xc8, 0x1c, 0xf0, 0x5e, 0x8e, 0xbf, 0x73, 0xf1, 0x08, 0xf2, 0x2d,
		0x38, 0x95, 0x38, 0xb8, 0x23, 0x6d, 0x53, 0x92, 0x56, 0x58, 0x2e, 0xb3, 0xcc, 0x57, 0x7a, 0x79,
		0xaf, 0xf5, 0xbf, 0x2a, 0xdb, 0x90, 0x4a, 0x8b, 0x8b, 0xbd, 0xf9, 0xfb, 0xf5, 0xd7, 0xb2, 0xbd,
		0x75, 0xbc, 0xfc, 0xc7, 0xf6, 0xd7, 0x4d, 0x7b, 0xeb, 0xf8, 0xcd, 0x9b, 0xff, 0xc8, 0xbf, 0xf8,
		0xf4, 0x58, 0xc6, 0x4b, 0xe9, 0xf4, 0x9b, 0x7f, 0xe2, 0xcd, 0xbc, 0xf4, 0xcd, 0x50, 0x2e, 0xb3,
		0x95, 0xeb, 0x8d, 0x76, 0xe0, 0x8d, 0x7e, 0xaa, 0xf3, 0xcb, 0xfe, 0x80, 0xf2, 0xbc, 0x9f, 0x60,
		0xf7, 0xfa, 0xfe, 0x37, 0xff, 0x7e, 0xe8, 0x7f, 0x2b, 0xff, 0xb6, 0x7b, 0xfd, 0x7e, 0xcd, 0x7f,
		0xd9, 0xb9, 0x7e, 0xff, 0x8b, 0xbf, 0xa3, 0x7a, 0xfd, 0x7a, 0xe5, 0x7f, 0x9d, 0x7d, 0x7f, 0x6b,
		0xdd, 0x0f, 0x54, 0xd6, 0xfc, 0xc0, 0xf6, 0xba, 0x1f, 0xd8, 0x5e, 0xf3, 0x03, 0x6b, 0x45, 0xda,
		0x5a, 0xf3, 0x03, 0xd5, 0xeb, 0xbf, 0x57, 0xfe, 0xff, 0xd7, 0x0f, 0xff, 0xaf, 0x3b, 0xd7, 0x6f,
		0xfe, 0x5e, 0xf7, 0xdf, 0x76, 0xaf, 0xff, 0x7e, 0xff, 0xe6, 0x4d, 0xe9, 0x75, 0x79, 0xe6, 0x18,
		0xde, 0xcd, 0x7d, 0x45, 0xf9, 0x78, 0xc5, 0x85, 0xcc, 0x5d, 0x02, 0x5c, 0x34, 0xd4, 0xb5, 0xe0,
		0xea, 0x4a, 0xb4, 0x29, 0xe1, 0xd8, 0xa0, 0x14, 0x4b, 0x2c, 0x12, 0x3b, 0x71, 0x25, 0x2c, 0x6b,
		0x5d, 0xfe, 0x62, 0x24, 0x59, 0x90, 0x64, 0x41, 0x92, 0xa5, 0x80, 0x49, 0x96, 0xc4, 0x3d, 0xb5,
		0x93, 0xd9, 0x6f, 0x47, 0x8e, 0x25, 0xd7, 0xe7, 0x3a, 0xf5, 0x82, 0x64, 0x7b, 0x4b, 0x22, 0xa1,
		0xd9, 0x95, 0xf0, 0xab, 0x7b, 0x6e, 0x70, 0x2a, 0xa4, 0xc1, 0x43, 0x89, 0x1d, 0xed, 0x87, 0x5e,
		0xa0, 0x60, 0x2a, 0x83, 0xd4, 0x61, 0x1c, 0xd9, 0x65, 0x3e, 0xbb, 0xfe, 0x54, 0x28, 0xb8, 0xce,
		0x87, 0xc8, 0x1d, 0x26, 0x5e, 0x18, 0xd4, 0xbd, 0x53, 0x6f, 0xde, 0x14, 0x26, 0x6f, 0x00, 0x83,
		0xc4, 0x86, 0xff, 0x43, 0xf7, 0xd2, 0xb8, 0x57, 0x5f, 0xd9, 0xda, 0xab, 0xec, 0xed, 0xec, 0x6e,
		0xed, 0x55, 0x0d, 0xd2, 0x01, 0x26, 0xdd, 0xee, 0x45, 0x4d, 0xc3, 0x9d, 0x89, 0x4b, 0x3b, 0xf7,
		0x42, 0x26, 0x33, 0xb2, 0x70, 0x77, 0x68, 0xfd, 0x7d, 0x36, 0xbf, 0x75, 0xfd, 0xe6, 0x1f, 0x6f,
		0xfe, 0x09, 0x5a, 0xad, 0x9c, 0x56, 0xa3, 0x15, 0xf8, 0x29, 0x3d, 0x88, 0xf7, 0x5b, 0xea, 0x4a,
		0xd9, 0x97, 0xb9, 0x6c, 0x9e, 0x78, 0x41, 0x97, 0xee, 0x0b, 0x3a, 0x75, 0x72, 0xaa, 0x3c, 0xc9,
		0xb7, 0xe2, 0x24, 0x27, 0xb0, 0x80, 0x0e, 0x0e, 0x72, 0xc9, 0x0d, 0x74, 0x70, 0xe8, 0x49, 0x5a,
		0xdc, 0xf4, 0x05, 0x0b, 0x77, 0x1c, 0x89, 0x71, 0x1e, 0x3a, 0xb7, 0x04, 0x24, 0x39, 0xd0, 0xe8,
		0x19, 0x00, 0x49, 0xdd, 0xf6, 0xdb, 0xb7, 0xf3, 0x31, 0x3d, 0xa5, 0x85, 0xd6, 0x31, 0xf4, 0xa8,
		0xf9, 0xec, 0xe6, 0xc9, 0x75, 0x17, 0x4f, 0xee, 0x1d, 0x71, 0x5b, 0xf0, 0xa7, 0xf0, 0xa7, 0x0c,
		0xfd, 0x29, 0x3a, 0xe2, 0x70, 0xaa, 0x94, 0xcf, 0x2f, 0xc7, 0xa9, 0x92, 0x62, 0xc7, 0x91, 0x2f,
		0x0d, 0x47, 0x47, 0x1c, 0x81, 0xf4, 0x03, 0x3a, 0xe2, 0xe0, 0xd7, 0xe1, 0xd7, 0xe1, 0xd7, 0x0b,
		0xe5, 0xd7, 0xd1, 0x11, 0xf7, 0x4b, 0xf7, 0x84, 0x8e, 0x38, 0xb8, 0x5f, 0xb8, 0x5f, 0xb8, 0xdf,
		0xbc, 0xb5, 0x16, 0x1d, 0x71, 0xf9, 0x7e, 0xd0, 0x11, 0xf7, 0x0b, 0x17, 0x40, 0x47, 0xdc, 0x33,
		0x5e, 0x0a, 0x3a, 0xe2, 0xf2, 0x78, 0x33, 0xe8, 0x88, 0x83, 0x37, 0x7a, 0x58, 0xe7, 0xd1, 0x62,
		0x84, 0x8e, 0x38, 0x46, 0x2e, 0x1a, 0xea, 0x8a, 0x8e, 0x38, 0xbd, 0xe4, 0x66, 0x03, 0x1d, 0x71,
		0xbf, 0x16, 0x7c, 0xd1, 0x11, 0x87, 0x24, 0x0b, 0x92, 0x2c, 0x05, 0x4e, 0xb2, 0xa0, 0x23, 0x4e,
		0x0e, 0xab, 0x41, 0x47, 0x9c, 0x82, 0xa7, 0x9d, 0x09, 0x8e, 0x8e, 0xb8, 0xa7, 0x5f, 0x07, 0x1d,
		0x71, 0x64, 0x5f, 0x3d, 0x3a, 0xe2, 0xf4, 0xfd, 0x56, 0x74, 0xc4, 0x21, 0x0b, 0x77, 0xef, 0x02,
		0xe8, 0x88, 0xa3, 0x48, 0xab, 0xd1, 0x11, 0x97, 0x53, 0x47, 0x5c, 0x0e, 0xcb, 0x96, 0xb9, 0xac,
		0xad, 0x5c, 0x2c, 0xae, 0x7d, 0xd9, 0xd6, 0xb7, 0x5c, 0x56, 0xd5, 0xe6, 0xb7, 0xa2, 0x56, 0xea,
		0x6a, 0xda, 0x7c, 0x56, 0xd2, 0x1a, 0xbf, 0x65, 0x74, 0xbd, 0x75, 0x59, 0x2f, 0x6a, 0x4f, 0xfa,
		0xa5, 0x8d, 0x98, 0xb5, 0xec, 0x5a, 0x58, 0x70, 0xaa, 0xe3, 0x65, 0x53, 0xd8, 0x46, 0xba, 0x50,
		0x92, 0x67, 0x6e, 0x20, 0x4d, 0x7f, 0xfa, 0x79, 0x5b, 0x47, 0x37, 0x99, 0x6d, 0x1d, 0x0d, 0x44,
		0x32, 0x7b, 0xb7, 0x58, 0x3b, 0xfa, 0x40, 0x0e, 0x75, 0xf9, 0x6c, 0x88, 0x39, 0x84, 0x67, 0x27,
		0x3f, 0x73, 0xe8, 0xa4, 0x7d, 0x49, 0xe7, 0xec, 0x6a, 0xa7, 0x6c, 0x6a, 0x67, 0x04, 0xbc, 0x45,
		0x18, 0x4f, 0xc6, 0x17, 0x5b, 0xcf, 0xf7, 0x17, 0x8b, 0x9f, 0x2f, 0xc6, 0x9e, 0xe2, 0x67, 0xdd,
		0x6c, 0x31, 0x1c, 0xc6, 0xe2, 0xd1, 0x18, 0xb3, 0xa7, 0x38, 0x12, 0x6e, 0x9c, 0xc3, 0x8e, 0xe2,
		0xf4, 0xd7, 0x60, 0x3f, 0xf1, 0x8b, 0x8c, 0x27, 0x2f, 0x23, 0xca, 0xdd, 0x98, 0x72, 0x37, 0xaa,
		0xbc, 0x8d, 0x4b, 0x0f, 0xb3, 0x7e, 0xf1, 0x7e, 0xe2, 0x99, 0xd5, 0xe4, 0x37, 0x8a, 0x21, 0xfd,
		0x6d, 0xd8, 0x4d, 0xac, 0xc4, 0x44, 0xf3, 0x36, 0x55, 0x69, 0x26, 0x2b, 0xcd, 0x74, 0x65, 0x99,
		0x30, 0x8d, 0x5c, 0x67, 0x6e, 0x93, 0x18, 0x72, 0x5a, 0x41, 0xbe, 0xa2, 0xc4, 0xb9, 0xac, 0x22,
		0xcf, 0xd9, 0xec, 0x73, 0x37, 0x7f, 0x19, 0x6e, 0x40, 0xaa, 0x3b, 0x90, 0xe5, 0x16, 0xa4, 0xbb,
		0x07, 0xe9, 0x6e, 0x42, 0xb6, 0xbb, 0xc8, 0xc7, 0x6d, 0xe4, 0xe4, 0x3e, 0x72, 0x77, 0x23, 0xd9,
		0x2f, 0xf4, 0x46, 0x22, 0x48, 0xbc, 0xb1, 0x27, 0xa2, 0xfc, 0x75, 0x2b, 0x6b, 0x4e, 0xb8, 0xb9,
		0x46, 0xce, 0xef, 0x5e, 0x4e, 0x49, 0x41, 0xee, 0xee, 0x46, 0xa6, 0xdb, 0x51, 0xe2, 0x7e, 0x64,
		0xbb, 0x21, 0x65, 0xee, 0x48, 0x99, 0x5b, 0x52, 0xe5, 0x9e, 0xf2, 0x75, 0x53, 0x39, 0xbb, 0xab,
		0x97, 0x67, 0x1f, 0x9f, 0x94, 0x4d, 0xb3, 0x67, 0x84, 0xc5, 0x96, 0xe6, 0x6d, 0x36, 0x24, 0x95,
		0x65, 0xde, 0x7f, 0x4a, 0xec, 0x0a, 0x07, 0xa5, 0x97, 0x6b, 0xde, 0x7f, 0xfa, 0xbb, 0x12, 0x2f,
		0x21, 0xb7, 0x7c, 0x53, 0xfe, 0xdb, 0xc8, 0x6e, 0x44, 0x45, 0x39, 0xa7, 0xe4, 0x40, 0xbc, 0xf6,
		0x72, 0x8a, 0xca, 0x3b, 0xb3, 0xeb, 0x29, 0x2c, 0xf1, 0x93, 0xe4, 0x82, 0x1f, 0x56, 0x11, 0x05,
		0x65, 0x9f, 0xba, 0x55, 0x44, 0x55, 0x19, 0xa8, 0x56, 0x5d, 0x79, 0xc5, 0xf3, 0xb7, 0x1f, 0xbf,
		0x62, 0x64, 0x39, 0x0a, 0x02, 0xe8, 0x28, 0x4c, 0x12, 0x31, 0xb2, 0xff, 0x35, 0x75, 0x47, 0x0a,
		0xa2, 0xa8, 0x8c, 0x3a, 0xd2, 0x1b, 0xa6, 0x23, 0xb9, 0x9e, 0x34, 0xbb, 0x90, 0xca, 0x81, 0x06,
		0x16, 0x37, 0x4b, 0x28, 0x4c, 0x41, 0x2d, 0xad, 0x2c, 0x4d, 0xce, 0x85, 0xad, 0xd9, 0xef, 0x95,
		0x5e, 0x95, 0x35, 0x67, 0xa7, 0xa5, 0xf4, 0xf0, 0x35, 0xfd, 0x33, 0x97, 0x4d, 0x0f, 0xf9, 0xbd,
		0xa4, 0x3c, 0xda, 0x80, 0x25, 0x64, 0xbc, 0xe4, 0x65, 0xba, 0x8a, 0xde, 0x0c, 0x8c, 0x44, 0xba,
		0xb2, 0x8c, 0x55, 0xb1, 0x12, 0xe9, 0xf2, 0x9a, 0x81, 0xf3, 0xdb, 0x38, 0xb1, 0x02, 0xd8, 0x72,
		0xcc, 0x7b, 0xac, 0xd6, 0xd5, 0xdd, 0xf2, 0x5d, 0x26, 0x79, 0xfb, 0x20, 0x11, 0xd1, 0xd8, 0x1d,
		0x8a, 0x58, 0x82, 0xb7, 0xbf, 0xf9, 0xdd, 0x38, 0x36, 0x85, 0xb7, 0x87, 0xb7, 0x27, 0xeb, 0xed,
		0xf3, 0x3f, 0x36, 0x5d, 0x9a, 0xbe, 0xc4, 0x53, 0xd3, 0xec, 0x12, 0x72, 0x0e, 0x4d, 0xcb, 0x38,
		0x34, 0xc5, 0xa1, 0x29, 0x2d, 0xa7, 0xa4, 0xca, 0x39, 0xc9, 0xc9, 0x8f, 0xe4, 0x7d, 0x68, 0x9a,
		0xb7, 0xd3, 0xca, 0x7e, 0x71, 0xce, 0x25, 0x64, 0x6b, 0x8d, 0x2a, 0xd7, 0x92, 0x32, 0x45, 0x6e,
		0x4c, 0xba, 0x3b, 0x53, 0xe1, 0xd6, 0x94, 0xba, 0x37, 0x55, 0x6e, 0x4e, 0xb9, 0xbb, 0x53, 0xee,
		0xf6, 0x54, 0xbb, 0x3f, 0x39, 0x6e, 0x50, 0x92, 0x3b, 0x94, 0xee, 0x16, 0xb3, 0x0b, 0xb8, 0xd3,
		0xe4, 0x6c, 0x46, 0x85, 0x87, 0x69, 0x06, 0x77, 0x3e, 0xd8, 0x4b, 0xba, 0x52, 0x67, 0x35, 0xf7,
		0x0f, 0x5c, 0xfc, 0x37, 0x23, 0xe6, 0xf2, 0xc8, 0x76, 0xa8, 0x2a, 0x1d, 0xab, 0x16, 0x07, 0xab,
		0xda, 0xd1, 0x6a, 0x73, 0xb8, 0xda, 0x1c, 0xaf, 0x2e, 0x07, 0x2c, 0xd7, 0x11, 0x4b, 0x76, 0xc8,
		0xd9, 0x43, 0x1b, 0xa8, 0x70, 0x94, 0x1b, 0x52, 0x77, 0xc6, 0x3d, 0x0a, 0x36, 0xdf, 0x31, 0xad,
		0xb4, 0x90, 0x39, 0x3c, 0xee, 0xcc, 0x1b, 0x89, 0xe5, 0x01, 0xa4, 0xba, 0x40, 0x79, 0xe7, 0xaa,
		0x88, 0x90, 0x88, 0x90, 0x88, 0x90, 0x88, 0x90, 0x88, 0x90, 0xf7, 0xac, 0x2e, 0xff, 0xed, 0x7b,
		0x8f, 0x86, 0xc8, 0x32, 0x42, 0xe4, 0xca, 0xb3, 0xf1, 0x46, 0xea, 0x02, 0xa3, 0x37, 0x42, 0x38,
		0x44, 0x38, 0x44, 0x38, 0x44, 0x38, 0x44, 0x38, 0x04, 0x61, 0xa4, 0x18, 0x0d, 0xcf, 0x45, 0x12,
		0x79, 0x43, 0x75, 0x11, 0x71, 0x71, 0x3d, 0x44, 0x45, 0x44, 0x45, 0x44, 0x45, 0x44, 0x45, 0x44,
		0xc5, 0xfb, 0x56, 0x17, 0x4f, 0xc6, 0xb6, 0x12, 0x27, 0x79, 0xdb, 0x51, 0xee, 0x28, 0xb8, 0x94,
		0x9a, 0x66, 0xde, 0xe5, 0x47, 0x8d, 0x1f, 0xd9, 0x50, 0xdd, 0xdc, 0xab, 0x38, 0xc2, 0xad, 0x5c,
		0x56, 0x71, 0xb3, 0x6f, 0x76, 0x5d, 0x0d, 0x8d, 0x9c, 0x8a, 0x7c, 0xcc, 0x5d, 0x55, 0x52, 0xd8,
		0x04, 0x4c, 0x45, 0x95, 0x76, 0xaa, 0xd5, 0xed, 0x6a, 0x81, 0xd4, 0xe9, 0x95, 0x19, 0x57, 0x39,
		0x06, 0x99, 0x5a, 0x25, 0x53, 0x53, 0x3f, 0xf1, 0xe6, 0x93, 0x4f, 0xdc, 0xd1, 0xff, 0xb9, 0x43,
		0x11, 0x0c, 0xaf, 0xec, 0x49, 0xe4, 0x9d, 0xbb, 0xd1, 0x95, 0x42, 0x8a, 0xf5, 0x33, 0x29, 0x24,
		0x03, 0xa6, 0xba, 0x18, 0xbb, 0x53, 0x3f, 0x05, 0x99, 0x33, 0x6c, 0x0b, 0x9e, 0x07, 0x9e, 0x07,
		0x9e, 0x07, 0x9e, 0x07, 0x9e, 0x77, 0xdf, 0xea, 0x70, 0x18, 0x48, 0x22, 0x62, 0x2f, 0x1b, 0xf1,
		0xd5, 0x16, 0x96, 0xde, 0xb9, 0x2a, 0x42, 0x24, 0x42, 0x24, 0x42, 0x24, 0x42, 0x24, 0x42, 0xe4,
		0x3d, 0xab, 0x9b, 0x37, 0xc1, 0x27, 0x57, 0xf9, 0x36, 0xf0, 0x3f, 0x1a, 0x26, 0x15, 0xe4, 0x22,
		0xac, 0xe6, 0xe2, 0xd6, 0xf6, 0xdd, 0x58, 0xa1, 0xa5, 0x2f, 0x1f, 0x6c, 0xa7, 0xdf, 0xfd, 0xe0,
		0xb4, 0x1b, 0x83, 0x3f, 0x3a, 0xbd, 0xdf, 0x9d, 0xc1, 0x97, 0x6e, 0xc3, 0x52, 0x39, 0x07, 0x2e,
		0x56, 0x96, 0x03, 0xde, 0x50, 0x9a, 0x07, 0xbe, 0xf3, 0x88, 0xf7, 0x7b, 0x9d, 0x5a, 0xfd, 0xa0,
		0xd6, 0x1f, 0x2c, 0x9f, 0xb3, 0x65, 0x62, 0xbe, 0x52, 0xd3, 0xc3, 0x6d, 0x77, 0xda, 0x0e, 0x1e,
		0xb0, 0xc4, 0x07, 0xdc, 0xed, 0x34, 0xdb, 0x03, 0x67, 0xd0, 0x71, 0xe6, 0x5f, 0xa8, 0x7f, 0xc2,
		0x4a, 0xae, 0x74, 0x8c, 0x59, 0x90, 0x1a, 0x18, 0xd7, 0xc4, 0x8d, 0x63, 0xef, 0x42, 0x21, 0xd9,
		0x5a, 0x5e, 0x10, 0x3c, 0x0b, 0x3c, 0x0b, 0x3c, 0x0b, 0x3c, 0x0b, 0x3c, 0xeb, 0x9e, 0xd5, 0x21,
		0x15, 0x49, 0x23, 0x30, 0x46, 0x5e, 0x18, 0x79, 0x89, 0xc2, 0x83, 0xc2, 0xec, 0x8a, 0x08, 0x8d,
		0x08, 0x8d, 0x08, 0x8d, 0x08, 0x8d, 0x08, 0x8d, 0xf7, 0xac, 0x6e, 0xea, 0x05, 0xc9, 0x3b, 0x85,
		0x81, 0xb1, 0x8a, 0x3a, 0xcc, 0xe7, 0xdf, 0x18, 0xea, 0x30, 0xe5, 0x5f, 0x17, 0x75, 0x98, 0xc6,
		0xaa, 0xd2, 0x56, 0x15, 0x55, 0x98, 0xec, 0xae, 0xc2, 0xb6, 0x0a, 0x93, 0xd5, 0x98, 0x33, 0x49,
		0x3b, 0x24, 0x56, 0xae, 0xa3, 0x61, 0xa7, 0xc4, 0xcd, 0xdc, 0xec, 0x9b, 0x2f, 0x73, 0x5d, 0x34,
		0x21, 0xff, 0xcd, 0x4b, 0x78, 0xeb, 0x32, 0x87, 0x04, 0xc8, 0x1f, 0x0e, 0x20, 0x39, 0x92, 0x60,
		0x1c, 0x27, 0x55, 0x42, 0x8d, 0x71, 0x9c, 0xc5, 0x8e, 0x53, 0xd2, 0x09, 0xb2, 0xc4, 0xc5, 0x1a,
		0xeb, 0x9c, 0x58, 0x79, 0x57, 0xee, 0x66, 0xb4, 0xfb, 0x8b, 0x37, 0x0a, 0x1d, 0xf5, 0x96, 0x08,
		0xc0, 0x9e, 0xbd, 0x5b, 0xf9, 0x01, 0xf0, 0xce, 0xe5, 0x30, 0x9a, 0x9a, 0x42, 0x2c, 0xf4, 0xc6,
		0x88, 0x83, 0x0c, 0xe3, 0xa0, 0x37, 0x46, 0x0c, 0x9c, 0x3f, 0x18, 0xe9, 0x23, 0xa9, 0x25, 0x4f,
		0xec, 0x5f, 0x31, 0x4a, 0xa9, 0x93, 0xfb, 0x15, 0xb9, 0x49, 0x65, 0xee, 0x52, 0xa5, 0xdb, 0x54,
		0xee, 0x3e, 0x55, 0xbb, 0x51, 0x6d, 0xee, 0x54, 0x9b, 0x5b, 0xd5, 0xe1, 0x5e, 0xe5, 0x27, 0xdb,
		0x36, 0x14, 0x9c, 0xcd, 0xc9, 0x76, 0xbb, 0xab, 0x18, 0x55, 0x7d, 0xdd, 0xbc, 0xac, 0x2d, 0x50,
		0x9a, 0xf2, 0x38, 0xda, 0x9c, 0xb3, 0x0e, 0x27, 0xad, 0xcd, 0x59, 0xeb, 0x72, 0xda, 0xda, 0x9d,
		0xb7, 0x76, 0x27, 0xae, 0xd3, 0x99, 0xab, 0x71, 0xea, 0x8a, 0x9c, 0xbb, 0xba, 0xfc, 0x92, 0xc6,
		0x7c, 0x93, 0x8e, 0xfc, 0xd3, 0xda, 0x7c, 0x54, 0x29, 0x55, 0xd3, 0xf7, 0xb7, 0x0e, 0x67, 0xee,
		0x7d, 0x63, 0xf1, 0xef, 0x60, 0xf6, 0x78, 0x0c, 0x39, 0xca, 0x54, 0xa0, 0xc4, 0x56, 0x3c, 0x3d,
		0xd1, 0x88, 0x1f, 0xee, 0x5c, 0x1d, 0x10, 0x02, 0x10, 0x02, 0x10, 0x02, 0x10, 0x02, 0x10, 0x02,
		0x10, 0x42, 0x0b, 0x84, 0xf8, 0x7a, 0x03, 0x21, 0xfe, 0xdf, 0x70, 0x1a, 0x45, 0x22, 0x48, 0x5e,
		0xbf, 0x29, 0xbd, 0x7d, 0x7b, 0x53, 0x07, 0x72, 0xbc, 0xf8, 0x91, 0xdb, 0x71, 0x2b, 0x7e, 0xe0,
		0x7b, 0xd9, 0x6f, 0x1e, 0x89, 0x4b, 0x63, 0xd0, 0x08, 0xeb, 0x6c, 0x4c, 0xe3, 0x32, 0x51, 0xd3,
		0x66, 0xaf, 0x3e, 0x01, 0x19, 0x0e, 0x6d, 0x71, 0x99, 0xbc, 0x4f, 0x84, 0x2f, 0xce, 0x45, 0x12,
		0x5d, 0xd9, 0x61, 0x60, 0x0f, 0xcf, 0xd2, 0x9a, 0x66, 0x2d, 0x49, 0xc9, 0xb1, 0xeb, 0xc7, 0x3a,
		0xb2, 0x92, 0xdc, 0x13, 0x92, 0xc7, 0xb2, 0x0f, 0xc8, 0xd4, 0xd4, 0xec, 0xdd, 0x50, 0x0b, 0x22,
		0xb5, 0x7b, 0x77, 0x0e, 0xd5, 0xa5, 0x56, 0xf2, 0xc9, 0xd7, 0x13, 0x99, 0xed, 0x76, 0x69, 0xbd,
		0x87, 0xba, 0x53, 0xbc, 0xf9, 0xe5, 0x0c, 0x3b, 0xc4, 0xdb, 0xc2, 0x21, 0x1e, 0x1b, 0x32, 0x87,
		0x43, 0x3c, 0x1c, 0xe2, 0x3d, 0xf6, 0xc0, 0x70, 0x88, 0x87, 0x0c, 0x1c, 0x32, 0x70, 0xc8, 0xc0,
		0x21, 0x03, 0x87, 0x0c, 0x1c, 0x32, 0x70, 0xd2, 0x33, 0x70, 0x38, 0xc4, 0x7b, 0x1e, 0x73, 0xc3,
		0x21, 0x1e, 0x20, 0x04, 0x20, 0x04, 0x20, 0x04, 0x20, 0x04, 0x20, 0x44, 0xc1, 0x21, 0x04, 0x0e,
		0xf1, 0xcc, 0xcd, 0xc6, 0xe0, 0x04, 0x23, 0x12, 0xe3, 0x79, 0x5f, 0xa6, 0x85, 0x31, 0x17, 0xf2,
		0x15, 0xaf, 0x70, 0x63, 0x2e, 0x54, 0xf4, 0x9f, 0xce, 0x6f, 0x38, 0x89, 0xa6, 0xc3, 0x24, 0x58,
		0x8e, 0x2f, 0x9f, 0xdf, 0x41, 0x73, 0x71, 0x03, 0x4e, 0x77, 0x21, 0xb6, 0xd3, 0x49, 0xc5, 0x76,
		0x6a, 0x91, 0x70, 0x9d, 0xe6, 0x52, 0xb6, 0x9b, 0xaf, 0x7a, 0x62, 0x5c, 0xe4, 0xe6, 0x64, 0x3f,
		0x76, 0xed, 0xb1, 0xe7, 0x27, 0x22, 0x92, 0xdf, 0x99, 0x7c, 0xeb, 0x5a, 0x68, 0x4b, 0xd6, 0x45,
		0xd9, 0x30, 0xa2, 0x83, 0x25, 0xed, 0xc2, 0x88, 0x8e, 0x9f, 0x3d, 0x1c, 0xb4, 0x27, 0x13, 0x74,
		0x97, 0xca, 0x33, 0x5f, 0x18, 0x21, 0x6c, 0x4a, 0x76, 0x0b, 0x23, 0x84, 0x59, 0x71, 0x6a, 0x65,
		0x15, 0x0e, 0xae, 0xef, 0xab, 0x3f, 0x9b, 0x98, 0x5d, 0x14, 0x47, 0x12, 0xdc, 0x1c, 0xb4, 0x56,
		0x47, 0xad, 0xcb, 0x61, 0x6b, 0x77, 0xdc, 0xda, 0x1d, 0xb8, 0x6e, 0x47, 0xae, 0xc6, 0xa1, 0x2b,
		0x72, 0xec, 0xd9, 0xc3, 0xd4, 0x77, 0x34, 0xa1, 0x6e, 0x8d, 0xca, 0x0a, 0x2a, 0x2e, 0x23, 0x5f,
		0x4f, 0x00, 0x5b, 0x14, 0x35, 0x5f, 0x7f, 0x93, 0x2c, 0x43, 0xbb, 0xc1, 0xfa, 0x97, 0x85, 0x76,
		0x83, 0x17, 0x63, 0xbf, 0x2d, 0x90, 0x72, 0x90, 0x72, 0x90, 0x72, 0x90, 0x72, 0x90, 0x72, 0x90,
		0x72, 0x90, 0x72, 0x90, 0x72, 0x90, 0x72, 0x90, 0x72, 0x90, 0x72, 0x60, 0x0b, 0x90, 0xf2, 0x9f,
		0x91, 0x72, 0x54, 0xd0, 0xa9, 0xd2, 0xba, 0xc2, 0x55, 0xd0, 0x49, 0xaf, 0x93, 0xda, 0x78, 0x71,
		0xf9, 0x5c, 0x2b, 0x76, 0x3f, 0xcc, 0x25, 0x2c, 0x70, 0xed, 0xdc, 0xf9, 0xc4, 0x8f, 0xe5, 0x57,
		0xcd, 0xa5, 0x57, 0x41, 0xbd, 0x9c, 0x2e, 0xea, 0x82, 0x7a, 0x39, 0x96, 0xd4, 0x03, 0xf5, 0x72,
		0x3a, 0x73, 0x43, 0xa8, 0x97, 0xe3, 0x90, 0x01, 0x42, 0x6a, 0xde, 0x94, 0x0c, 0x0f, 0x52, 0xf3,
		0xac, 0xe8, 0xb3, 0xb2, 0xd4, 0x7c, 0x12, 0xb9, 0xe3, 0xb1, 0x37, 0xb4, 0x45, 0x70, 0xea, 0x05,
		0x42, 0x44, 0x5e, 0x70, 0x6a, 0x9f, 0x8b, 0x24, 0xf2, 0x86, 0xea, 0x33, 0xf6, 0x3f, 0x91, 0x05,
		0x89, 0x7c, 0x6e, 0xee, 0x5c, 0xab, 0x5b, 0xd7, 0xe5, 0xde, 0xb5, 0xbb, 0x79, 0xed, 0xee, 0x5e,
		0xb7, 0xdb, 0x57, 0xe3, 0xfe, 0x15, 0x85, 0x81, 0xec, 0x61, 0xea, 0x4b, 0xe4, 0x4f, 0xbd, 0x20,
		0xd9, 0xde, 0xd2, 0x90, 0xc7, 0x57, 0xd9, 0xf6, 0xdf, 0x4b, 0xc7, 0x18, 0xab, 0x98, 0xdb, 0x7c,
		0xfb, 0xa3, 0xd6, 0x25, 0xa5, 0x37, 0x7a, 0xe8, 0x05, 0xca, 0x7d, 0xa1, 0xa6, 0xe0, 0xba, 0x72,
		0xf9, 0xcf, 0xae, 0x3f, 0x15, 0x1a, 0xaf, 0xff, 0x21, 0x72, 0x87, 0x89, 0x17, 0x06, 0x75, 0xef,
		0xd4, 0x4b, 0xa7, 0x84, 0x6f, 0x2a, 0x97, 0xe3, 0xfa, 0x37, 0x0d, 0x2a, 0xe7, 0x5e, 0x16, 0x5e,
		0xe5, 0x2a, 0x5b, 0x7b, 0x95, 0xbd, 0x9d, 0xdd, 0xad, 0xbd, 0x6a, 0x81, 0x75, 0xef, 0x95, 0x99,
		0x57, 0x3b, 0xc6, 0x71, 0x33, 0x01, 0xbe, 0x5c, 0xd4, 0xe3, 0xe6, 0xf3, 0x89, 0x1f, 0xa3, 0xfa,
		0x7b, 0xed, 0x6b, 0xf2, 0x4e, 0x27, 0xb6, 0x3f, 0x9a, 0xd8, 0xf1, 0x55, 0x30, 0x54, 0x97, 0x6a,
		0xbe, 0x73, 0x55, 0x24, 0x9c, 0xa9, 0x66, 0x28, 0x90, 0x70, 0x36, 0x32, 0x03, 0x81, 0x84, 0xf3,
		0x73, 0x1e, 0x9a, 0xb2, 0x84, 0xb3, 0xa2, 0x73, 0xbf, 0x15, 0x23, 0x57, 0x72, 0xfe, 0xa7, 0xd8,
		0x2d, 0x2b, 0x77, 0xcf, 0x3a, 0xdc, 0xb4, 0x56, 0x77, 0xad, 0xcb, 0x6d, 0x6b, 0x77, 0xdf, 0xda,
		0xdd, 0xb8, 0x6e, 0x77, 0xae, 0x96, 0x49, 0xaa, 0x4a, 0x24, 0xab, 0x72, 0xf3, 0xd9, 0x05, 0x45,
		0xe0, 0x9e, 0xf8, 0x62, 0xa4, 0xde, 0x70, 0x96, 0xde, 0x62, 0x29, 0x80, 0x62, 0xad, 0xd5, 0x93,
		0x79, 0x52, 0x1e, 0x08, 0x74, 0x06, 0x04, 0x12, 0x81, 0x41, 0x77, 0x80, 0x20, 0x13, 0x28, 0xc8,
		0x04, 0x0c, 0x2a, 0x81, 0x43, 0x6d, 0x00, 0x51, 0x1c, 0x48, 0xb2, 0x87, 0xac, 0xfc, 0x64, 0x72,
		0xc5, 0xea, 0xd5, 0xb7, 0x1a, 0xad, 0xa0, 0xfc, 0xb2, 0xa1, 0xb9, 0x6d, 0x85, 0xca, 0x64, 0x4d,
		0xc2, 0x38, 0xb1, 0x63, 0x11, 0xc7, 0x5e, 0x18, 0xd8, 0xd3, 0x89, 0x3d, 0x12, 0xbe, 0x7b, 0xa5,
		0x0f, 0x36, 0x3c, 0x2c, 0x0e, 0x40, 0x04, 0x40, 0x04, 0x40, 0x04, 0x40, 0x04, 0x40, 0x84, 0x61,
		0x20, 0x42, 0x79, 0x99, 0xd3, 0x7d, 0x1f, 0xbf, 0xab, 0xe1, 0xd2, 0x7a, 0xca, 0x9e, 0x96, 0x1f,
		0x3d, 0x2e, 0x6e, 0x43, 0x77, 0x19, 0x94, 0xe6, 0xe0, 0xbe, 0x22, 0x86, 0xe6, 0xb2, 0xa8, 0x4c,
		0x0e, 0x02, 0x25, 0x2a, 0x9a, 0xdc, 0xdf, 0x5d, 0xd5, 0xd4, 0x58, 0x2e, 0x45, 0x55, 0x35, 0x75,
		0x97, 0x4f, 0x91, 0xd4, 0xd1, 0x57, 0xc5, 0xb8, 0xea, 0xb1, 0xa9, 0xd4, 0xda, 0xa8, 0x63, 0x05,
		0xc5, 0xe5, 0x57, 0xd9, 0x75, 0x49, 0x95, 0x61, 0xdd, 0x2e, 0xfb, 0x51, 0x52, 0x93, 0xa5, 0x4e,
		0x97, 0x94, 0xac, 0x97, 0x55, 0x32, 0xa9, 0x73, 0x05, 0xf9, 0xab, 0x98, 0xd8, 0x79, 0x3f, 0xb0,
		0x2a, 0x2f, 0x0b, 0xd8, 0x42, 0x59, 0x80, 0x51, 0x09, 0x1b, 0x94, 0x05, 0xa0, 0x2c, 0x20, 0xcf,
		0x87, 0x89, 0xb2, 0x00, 0xa3, 0x99, 0x15, 0x32, 0xfa, 0xc8, 0xe8, 0x23, 0xa3, 0x4f, 0x23, 0x70,
		0xe8, 0xa1, 0xd2, 0x28, 0x0b, 0x50, 0xef, 0xe4, 0x51, 0x16, 0x90, 0xc3, 0xb3, 0x44, 0x59, 0x00,
		0x40, 0x04, 0x40, 0x04, 0x40, 0x04, 0x40, 0x04, 0x40, 0x84, 0x7a, 0xab, 0x47, 0x59, 0x80, 0xf2,
		0x0f, 0xca, 0x02, 0x50, 0x16, 0x70, 0x4b, 0x0e, 0x94, 0x05, 0x6c, 0xa0, 0x2c, 0xe0, 0x61, 0xd5,
		0x44, 0x59, 0x80, 0x6e, 0x40, 0xa0, 0xef, 0xaa, 0xc7, 0xa0, 0xd6, 0x2f, 0x56, 0xdb, 0xf8, 0x2a,
		0x18, 0x9e, 0x45, 0x61, 0xe0, 0xfd, 0x5b, 0x67, 0x22, 0xfe, 0x8e, 0x14, 0x20, 0xd2, 0x20, 0xd2,
		0x20, 0xd2, 0x20, 0xd2, 0x20, 0xd2, 0x86, 0x11, 0x69, 0x64, 0xe3, 0x99, 0x5f, 0x09, 0x95, 0x84,
		0xba, 0x2a, 0x09, 0x15, 0xac, 0x11, 0x53, 0xa7, 0x4a, 0x98, 0x32, 0x68, 0x84, 0x52, 0x5a, 0x4a,
		0xea, 0x41, 0x5f, 0xb0, 0x7d, 0xec, 0x70, 0xe2, 0xc7, 0x4e, 0xf3, 0x74, 0xd2, 0x1a, 0x4d, 0xfa,
		0x33, 0x79, 0x31, 0x1b, 0xf1, 0x81, 0xe7, 0x8b, 0xcd, 0xf8, 0x2f, 0x25, 0x70, 0xd8, 0x8c, 0xcf,
		0x8b, 0x90, 0x61, 0x1a, 0x22, 0xa6, 0x21, 0xfe, 0xca, 0x43, 0xc3, 0xfa, 0x1d, 0xac, 0xdf, 0x31,
		0x23, 0xff, 0x86, 0xf6, 0x08, 0xb4, 0x47, 0xa0, 0x3d, 0x82, 0x5b, 0xfe, 0x0c, 0xeb, 0x77, 0xe4,
		0x7f, 0xb0, 0x7e, 0x47, 0xe9, 0xe5, 0xb1, 0x7e, 0x07, 0xeb, 0x77, 0x34, 0xa9, 0x1c, 0xd6, 0xef,
		0x60, 0xfd, 0x0e, 0xf5, 0xfb, 0x41, 0x62, 0xfc, 0x29, 0xd7, 0x23, 0x95, 0x18, 0x57, 0x70, 0x40,
		0x73, 0x8d, 0xad, 0xf4, 0x2a, 0xf5, 0x8c, 0x94, 0x7e, 0x59, 0x52, 0xcf, 0x00, 0x5e, 0x78, 0xc6,
		0x22, 0x47, 0xed, 0xf3, 0x57, 0x4a, 0x09, 0x0a, 0x69, 0x05, 0xc2, 0x3b, 0x3d, 0x3b, 0x09, 0xa3,
		0x58, 0x9a, 0x2e, 0x66, 0x34, 0xf0, 0xe6, 0x52, 0x92, 0x0c, 0x4b, 0xee, 0xc1, 0x89, 0xf4, 0x4c,
		0x9b, 0x8a, 0xcc, 0x9a, 0xd2, 0x4c, 0x9a, 0xaa, 0xcc, 0x99, 0xf2, 0x4c, 0x99, 0xf2, 0xcc, 0x98,
		0xea, 0x4c, 0x18, 0xaf, 0x80, 0x2a, 0xfb, 0xa0, 0x23, 0xf3, 0x5c, 0xea, 0x0e, 0x9a, 0xb3, 0x2b,
		0x62, 0xf3, 0x1e, 0x35, 0x17, 0xaa, 0xc5, 0x95, 0xaa, 0x76, 0xa9, 0xda, 0x5c, 0xab, 0x36, 0x17,
		0xab, 0xcb, 0xd5, 0x9a, 0xc1, 0x9d, 0xb1, 0x79, 0x8f, 0xa1, 0x5b, 0x56, 0xee, 0x9e, 0x75, 0xb8,
		0x69, 0xad, 0xee, 0x5a, 0x97, 0xdb, 0xd6, 0xee, 0xbe, 0xb5, 0xbb, 0x71, 0xdd, 0xee, 0x5c, 0x8d,
		0x5b, 0x57, 0xe4, 0xde, 0x95, 0xbb, 0xf9, 0xec, 0x82, 0x8a, 0xcb, 0x88, 0x56, 0x9c, 0x85, 0xd2,
		0xd2, 0xa1, 0xfb, 0xee, 0x1f, 0x2d, 0x7d, 0x86, 0x87, 0x05, 0xdd, 0xe1, 0x81, 0x4c, 0x98, 0x20,
		0x13, 0x2e, 0xa8, 0x84, 0x0d, 0xb5, 0xe1, 0x43, 0x71, 0x18, 0xc9, 0x1e, 0xb2, 0xfe, 0x96, 0xbe,
		0xd9, 0x7b, 0xb5, 0xb5, 0x38, 0xf9, 0xdb, 0x8e, 0x7e, 0x07, 0x03, 0x72, 0xd4, 0xdd, 0x38, 0x06,
		0xe4, 0xdc, 0x88, 0x81, 0x01, 0x39, 0xba, 0x7d, 0xe0, 0x5d, 0xd5, 0xc4, 0x80, 0x9c, 0x15, 0xd5,
		0xdc, 0xa9, 0x56, 0xb7, 0x31, 0x1b, 0x47, 0x13, 0x20, 0xd0, 0x77, 0x55, 0xcc, 0xc6, 0x79, 0xb9,
		0xda, 0x46, 0xe1, 0x34, 0x11, 0x91, 0xed, 0x69, 0x1c, 0x8c, 0x73, 0x23, 0x02, 0x28, 0x34, 0x28,
		0x34, 0x28, 0x34, 0x28, 0x34, 0x28, 0xb4, 0x61, 0x14, 0x7a, 0x14, 0x26, 0x89, 0x18, 0xd9, 0xff,
		0x9a, 0xba, 0x23, 0x9d, 0x93, 0x71, 0xde, 0x69, 0xb8, 0x76, 0xd7, 0x4d, 0x12, 0x11, 0x05, 0xda,
		0x58, 0xb4, 0xf5, 0xfa, 0xf5, 0xd7, 0x4d, 0x7b, 0xef, 0xf8, 0xef, 0xaf, 0x65, 0x7b, 0xef, 0x78,
		0xfe, 0x65, 0x39, 0xfd, 0x6b, 0xfe, 0xf5, 0xd6, 0xd7, 0x4d, 0xbb, 0xb2, 0xfc, 0xba, 0xfa, 0x75,
		0xd3, 0xae, 0x1e, 0xbf, 0xf9, 0xf6, 0xed, 0xed, 0x9b, 0xbf, 0xb6, 0xaf, 0x9f, 0xfe, 0x83, 0x16,
		0x30, 0x20, 0xab, 0x2b, 0x61, 0xd8, 0x91, 0x9a, 0xf2, 0xe6, 0xac, 0xac, 0x35, 0xfb, 0x0a, 0x7b,
		0x13, 0x19, 0x50, 0x15, 0x6d, 0x14, 0x05, 0x03, 0x02, 0x0c, 0xa3, 0x20, 0x28, 0xee, 0x40, 0x71,
		0x87, 0x09, 0x81, 0x5c, 0xdf, 0x80, 0x00, 0x5f, 0xb8, 0xe3, 0x48, 0x8c, 0x35, 0x4c, 0x08, 0x28,
		0xab, 0x1c, 0x11, 0xd0, 0x5d, 0x60, 0x95, 0xb7, 0x6f, 0xe7, 0xed, 0x76, 0xa5, 0x9b, 0xd0, 0x03,
		0xa8, 0xf0, 0xeb, 0xb8, 0x0f, 0x2b, 0x96, 0xa5, 0x41, 0x04, 0xac, 0x58, 0x06, 0x44, 0x00, 0x44,
		0x00, 0x44, 0x58, 0xf7, 0x30, 0x95, 0xd7, 0x7f, 0xba, 0xa3, 0xff, 0x73, 0x87, 0x22, 0x18, 0x5e,
		0xd9, 0x6a, 0xdd, 0xfe, 0x8a, 0xd7, 0xb8, 0x2f, 0x08, 0x8e, 0xb3, 0x4c, 0x0b, 0x10, 0x24, 0x02,
		0x85, 0xee, 0x80, 0x41, 0x26, 0x70, 0x90, 0x09, 0x20, 0x54, 0x02, 0x89, 0xda, 0x80, 0xa2, 0x38,
		0xb0, 0xe8, 0xe3, 0xa0, 0x2b, 0x56, 0xef, 0x8d, 0x44, 0x90, 0x78, 0xc9, 0x95, 0x5a, 0x3e, 0xba,
		0x82, 0xfc, 0x35, 0x94, 0x3c, 0x59, 0xcd, 0xc5, 0xad, 0xef, 0xbb, 0xb1, 0x46, 0xcf, 0xb3, 0x7c,
		0x11, 0x9d, 0x7e, 0xf7, 0x83, 0xd3, 0x6e, 0x34, 0x3f, 0x7e, 0xda, 0xef, 0xf4, 0x9c, 0xfe, 0xa0,
		0x36, 0x68, 0x58, 0x3a, 0x67, 0x70, 0xc5, 0xda, 0x8e, 0xf9, 0x36, 0xb4, 0x16, 0xcc, 0xde, 0x79,
		0x29, 0xf5, 0xce, 0x1f, 0x6d, 0xab, 0x88, 0xb5, 0x99, 0x44, 0x9e, 0x7f, 0xe3, 0xcf, 0xfe, 0xa0,
		0xd6, 0x1b, 0xe0, 0x15, 0xe8, 0x7b, 0x05, 0xb5, 0xc1, 0xa0, 0x71, 0xd8, 0xc5, 0x2b, 0xd0, 0x6a,
		0x05, 0x07, 0x9f, 0x6a, 0xed, 0x8f, 0x0d, 0xbc, 0x03, 0x7d, 0xef, 0xe0, 0xc3, 0x51, 0xab, 0x85,
		0xe7, 0xaf, 0xef, 0xf9, 0xb7, 0x3a, 0xb5, 0x7a, 0xb3, 0xfd, 0x11, 0xaf, 0x40, 0xdf, 0x2b, 0x18,
		0xfc, 0xd1, 0x71, 0xfe, 0xa8, 0x7d, 0xc1, 0x2b, 0xd0, 0xf7, 0x0a, 0x9a, 0xed, 0xa6, 0xce, 0x48,
		0xac, 0xe5, 0xca, 0xc7, 0x98, 0xbb, 0xcb, 0xcf, 0x7e, 0xac, 0x13, 0x77, 0xf8, 0x7d, 0x3a, 0xb1,
		0x47, 0x22, 0xf6, 0x4e, 0x03, 0x37, 0x11, 0x23, 0x7b, 0x7e, 0xfa, 0xab, 0x2f, 0xa5, 0xbd, 0x56,
		0x22, 0xe4, 0xb6, 0xa5, 0x5e, 0x18, 0xb9, 0x6d, 0xe4, 0xb6, 0xe7, 0x82, 0x20, 0xb7, 0xad, 0x35,
		0xce, 0xa0, 0x55, 0x63, 0x43, 0x87, 0xa3, 0x47, 0xab, 0x06, 0x5a, 0x35, 0x80, 0x10, 0x57, 0x35,
		0x64, 0x24, 0xdc, 0x91, 0x9d, 0x78, 0xe7, 0x1a, 0xab, 0x1c, 0x6e, 0x44, 0x00, 0x06, 0x04, 0x06,
		0x04, 0x06, 0x04, 0x06, 0x04, 0x06, 0x34, 0x0c, 0x03, 0xce, 0xbc, 0x7b, 0xe2, 0x0d, 0xbf, 0xc7,
		0x3b, 0x15, 0x8d, 0x18, 0x50, 0x07, 0x04, 0x3c, 0x0a, 0xe6, 0xc3, 0x5b, 0xac, 0xc0, 0x0d, 0xc2,
		0x58, 0x0c, 0xc3, 0x60, 0x14, 0x5b, 0x98, 0xbc, 0xa5, 0xee, 0xc6, 0x31, 0x79, 0xeb, 0x46, 0x0c,
		0x4c, 0xde, 0xd2, 0xed, 0x8b, 0xef, 0xaa, 0x26, 0x26, 0x6f, 0xad, 0xa8, 0x66, 0xf9, 0x5d, 0xa5,
		0xb2, 0xb3, 0x5b, 0xa9, 0x6c, 0xee, 0x6e, 0xef, 0x6e, 0xee, 0x55, 0xab, 0xe5, 0x9d, 0x32, 0x06,
		0x71, 0x69, 0xc2, 0x29, 0xfa, 0xae, 0x0a, 0x66, 0x9f, 0x07, 0xb3, 0x27, 0x73, 0xe8, 0x83, 0xd3,
		0x1e, 0x30, 0x7d, 0x30, 0x7d, 0x30, 0x7d, 0x30, 0x7d, 0xe3, 0x99, 0x3e, 0x4e, 0x7b, 0x70, 0xda,
		0x03, 0x4c, 0x48, 0x15, 0x13, 0xfa, 0x6e, 0x9c, 0xd8, 0x22, 0x4e, 0xdc, 0x13, 0xdf, 0x8b, 0xcf,
		0x84, 0xee, 0x93, 0x9f, 0x87, 0xc5, 0x01, 0x36, 0x04, 0x36, 0x04, 0x36, 0x04, 0x36, 0x04, 0x36,
		0x34, 0x0c, 0x1b, 0xe2, 0x14, 0x08, 0xa7, 0x40, 0x7a, 0x3e, 0x38, 0x05, 0xba, 0x25, 0x06, 0x4e,
		0x81, 0x74, 0xfb, 0xe2, 0xbb, 0xaa, 0x89, 0x53, 0xa0, 0x15, 0xd5, 0xc4, 0x29, 0x10, 0x1d, 0x9c,
		0xa2, 0xef, 0xaa, 0x60, 0xfc, 0x2f, 0x57, 0x5b, 0xec, 0x32, 0x05, 0xa7, 0x07, 0xa7, 0x07, 0xa7,
		0x07, 0xa7, 0x07, 0xa7, 0x97, 0x62, 0xf5, 0xd8, 0x65, 0x0a, 0x2e, 0x0d, 0xc2, 0x02, 0x2e, 0x0d,
		0x2e, 0x4d, 0x54, 0x35, 0xb1, 0xcb, 0x14, 0xe4, 0x19, 0xe4, 0xf9, 0x59, 0x6a, 0x1b, 0x4e, 0x66,
		0x4a, 0xeb, 0xfa, 0xf6, 0xd0, 0x9d, 0xb8, 0x27, 0x9e, 0xef, 0x25, 0x5e, 0x3a, 0x91, 0x51, 0x13,
		0x97, 0x7e, 0x58, 0x1c, 0x50, 0x6b, 0x50, 0x6b, 0x50, 0x6b, 0x50, 0x6b, 0x50, 0x6b, 0xc3, 0xa8,
		0xf5, 0x99, 0xb8, 0xb4, 0xe3, 0x24, 0xf2, 0x82, 0x53, 0x54, 0x52, 0x2a, 0x16, 0x20, 0xad, 0x87,
		0x74, 0xed, 0x71, 0xcd, 0xfe, 0x70, 0xfc, 0xd7, 0xd6, 0xf5, 0xeb, 0xf7, 0x77, 0xff, 0xfd, 0xe6,
		0x1f, 0x6f, 0xfe, 0x89, 0x02, 0x48, 0x8e, 0x88, 0x6e, 0x12, 0x79, 0x61, 0xe4, 0x25, 0x57, 0xfa,
		0x40, 0x5c, 0x26, 0x01, 0x70, 0x1b, 0x70, 0x1b, 0x70, 0x1b, 0x70, 0x1b, 0x70, 0x9b, 0x61, 0xb8,
		0x6d, 0xea, 0x05, 0xc9, 0x3b, 0x8d, 0x90, 0xad, 0x8a, 0xc3, 0x10, 0x75, 0x37, 0x8e, 0xc3, 0x90,
		0x1b, 0x31, 0x70, 0x18, 0xa2, 0xdb, 0xfb, 0xdd, 0x55, 0x4d, 0x1c, 0x86, 0xac, 0xa8, 0xe6, 0x56,
		0x15, 0x47, 0x21, 0x9a, 0x80, 0x80, 0xbe, 0xab, 0x82, 0x38, 0xbf, 0x5c, 0x6d, 0x23, 0x91, 0x44,
		0x6e, 0x70, 0xee, 0xc5, 0xb1, 0x17, 0x06, 0xf6, 0xbf, 0xa6, 0x62, 0x2a, 0x6c, 0x5f, 0x04, 0xa7,
		0xe9, 0x72, 0x69, 0x4d, 0x54, 0xfa, 0x27, 0x32, 0x81, 0x5c, 0x83, 0x5c, 0x83, 0x5c, 0x83, 0x5c,
		0x83, 0x5c, 0x1b, 0x48, 0xae, 0xb7, 0xb7, 0x34, 0xb2, 0xeb, 0x5d, 0xb0, 0x6b, 0xb0, 0x6b, 0xb0,
		0x6b, 0xb0, 0x6b, 0xb0, 0xeb, 0x15, 0xd5, 0xac, 0x6c, 0xed, 0x55, 0xf6, 0x76, 0x76, 0xb7, 0xf6,
		0x40, 0xb2, 0x41, 0xb2, 0x41, 0xb2, 0x9f, 0x4e, 0xb2, 0xd3, 0xe1, 0x88, 0xb6, 0x37, 0xd2, 0xc8,
		0xa9, 0x33, 0x11, 0x40, 0xa1, 0x41, 0xa1, 0x41, 0xa1, 0x41, 0xa1, 0x41, 0xa1, 0x0d, 0xa3, 0xd0,
		0x18, 0xd1, 0x88, 0x11, 0x8d, 0xc0, 0x80, 0x54, 0x31, 0x60, 0x9c, 0xb8, 0x89, 0xb0, 0x87, 0x67,
		0x6e, 0x70, 0xaa, 0xb3, 0xd7, 0xe4, 0xae, 0x18, 0xc0, 0x82, 0xc0, 0x82, 0xc0, 0x82, 0xc0, 0x82,
		0xc0, 0x82, 0x86, 0x61, 0x41, 0x1c, 0xa7, 0x28, 0xff, 0xe0, 0x38, 0x05, 0xc7, 0x29, 0xb7, 0xe4,
		0xc0, 0x71, 0xca, 0x06, 0x8e, 0x53, 0x1e, 0x56, 0x4d, 0x1c, 0xa7, 0xe8, 0x06, 0x04, 0xfa, 0xae,
		0x6a, 0x2c, 0x95, 0x7e, 0x65, 0x90, 0x27, 0xb3, 0x6a, 0x41, 0x10, 0x26, 0xee, 0xcc, 0x34, 0x94,
		0x3a, 0x2f, 0x2b, 0x1e, 0x9e, 0x89, 0x73, 0x77, 0xe2, 0xa6, 0xd5, 0x97, 0x56, 0x29, 0x9c, 0x88,
		0x60, 0x98, 0x92, 0x57, 0x3b, 0x10, 0xc9, 0x8f, 0x30, 0xfa, 0x6e, 0x7b, 0x41, 0x9c, 0xb8, 0xc1,
		0x50, 0x94, 0xee, 0x7f, 0x23, 0x5e, 0xf9, 0x4e, 0x69, 0x12, 0x85, 0x49, 0x38, 0x0c, 0xfd, 0x38,
		0xfb, 0xaa, 0x34, 0xc7, 0xfb, 0x25, 0x37, 0x12, 0x6e, 0x9c, 0xfe, 0x59, 0xf2, 0x82, 0x44, 0x44,
		0x63, 0x77, 0xf6, 0x0b, 0xb2, 0x2f, 0x4b, 0x81, 0xf0, 0x4e, 0xcf, 0x4e, 0xc2, 0x28, 0xce, 0xbe,
		0x2a, 0xa5, 0x89, 0x03, 0x35, 0x44, 0x41, 0xbe, 0x2e, 0xc9, 0xbd, 0x82, 0x64, 0x2d, 0x9d, 0xb1,
		0x5a, 0x95, 0x47, 0x7a, 0x56, 0xcb, 0x8b, 0x93, 0x5a, 0x92, 0xa8, 0x59, 0x34, 0x37, 0x03, 0xb3,
		0x0d, 0x5f, 0xcc, 0x38, 0x6a, 0xac, 0x26, 0x66, 0xcf, 0x30, 0xca, 0xad, 0x2b, 0xea, 0x99, 0x51,
		0x6c, 0x75, 0xa2, 0x91, 0x88, 0xc4, 0x68, 0x7f, 0xf6, 0x6a, 0x83, 0xa9, 0xef, 0xb3, 0xd6, 0x50,
		0xc5, 0xfe, 0x93, 0xb0, 0xdf, 0x54, 0x40, 0xc1, 0xad, 0x38, 0x89, 0xa6, 0xc3, 0x24, 0x58, 0x50,
		0xff, 0xf6, 0xfc, 0x76, 0x9a, 0x8b, 0xbb, 0x71, 0xba, 0x8b, 0x7b, 0x70, 0x3a, 0xe9, 0x3d, 0x38,
		0xb5, 0x48, 0xb8, 0x4e, 0x73, 0x29, 0xb2, 0xd3, 0x5e, 0x0a, 0xfa, 0x8a, 0xa7, 0xc3, 0x95, 0xf3,
		0x9b, 0x25, 0x19, 0x88, 0x2a, 0xc3, 0xa0, 0x67, 0x10, 0x72, 0xd4, 0x2b, 0xff, 0x97, 0x2f, 0xe1,
		0xc5, 0xcf, 0xcf, 0x5c, 0xa4, 0xbd, 0xef, 0xbb, 0x47, 0x3b, 0x92, 0xfc, 0x4d, 0x76, 0xba, 0x2b,
		0xe9, 0xd7, 0x67, 0x47, 0x34, 0x5b, 0x92, 0x2e, 0xa0, 0xe0, 0x28, 0x46, 0xe9, 0x91, 0x8b, 0xaa,
		0xa3, 0x15, 0xe5, 0x47, 0x28, 0xca, 0x8f, 0x4a, 0x54, 0x1f, 0x89, 0xf0, 0x0a, 0x58, 0x75, 0x4f,
		0x2e, 0xec, 0xb7, 0xdc, 0x69, 0x72, 0x26, 0x82, 0xc4, 0x1b, 0xa6, 0x51, 0xd1, 0x4e, 0x54, 0x1c,
		0x9d, 0x64, 0x96, 0xfa, 0xd0, 0xc5, 0x65, 0x93, 0x37, 0x25, 0xb9, 0x48, 0x65, 0x67, 0xde, 0x2a,
		0xcf, 0xb8, 0xb5, 0x9c, 0x69, 0xab, 0x3e, 0xc3, 0xd6, 0x76, 0x66, 0xad, 0xed, 0x8c, 0x5a, 0xd7,
		0x99, 0x34, 0xef, 0x24, 0x90, 0xb2, 0x33, 0xe6, 0x5b, 0xf8, 0x52, 0xd1, 0xcc, 0xc2, 0x9b, 0x52,
		0x42, 0xae, 0x9c, 0x54, 0x22, 0xee, 0x3b, 0xf3, 0x46, 0x62, 0x49, 0xe2, 0xd4, 0x05, 0xca, 0x3b,
		0x57, 0x45, 0x84, 0x44, 0x84, 0x44, 0x84, 0x44, 0x84, 0x44, 0x84, 0xbc, 0x67, 0x75, 0x27, 0x61,
		0xe8, 0x0b, 0x37, 0x50, 0x19, 0x22, 0xcb, 0x08, 0x91, 0x2b, 0xcf, 0x46, 0x41, 0x9f, 0x5d, 0xf6,
		0xca, 0xe5, 0x9f, 0xbe, 0x21, 0x1c, 0x22, 0x1c, 0x22, 0x1c, 0x22, 0x1c, 0x82, 0x30, 0x82, 0x30,
		0x3e, 0xe7, 0xd9, 0x28, 0xda, 0x14, 0xab, 0x76, 0x33, 0x2c, 0xa2, 0x22, 0xa2, 0x22, 0xa2, 0x22,
		0xa2, 0x22, 0xc3, 0xa8, 0xa8, 0x76, 0xb3, 0xaa, 0xc2, 0x4d, 0xaa, 0x8a, 0xfb, 0x6f, 0x14, 0x96,
		0xe5, 0xea, 0xe8, 0xaf, 0xd1, 0xd5, 0x2c, 0xab, 0xa9, 0x7f, 0x46, 0x67, 0x2f, 0x82, 0xca, 0x36,
		0x70, 0x1d, 0xfd, 0x30, 0xba, 0x55, 0x49, 0xc3, 0xa6, 0x52, 0xad, 0xea, 0x64, 0x48, 0x91, 0xfc,
		0x31, 0xc8, 0xd4, 0x2a, 0x99, 0x9a, 0xfa, 0x89, 0x67, 0xbb, 0x91, 0x70, 0x6d, 0x77, 0xf4, 0x7f,
		0xee, 0x50, 0x04, 0xc3, 0x2b, 0x7b, 0x12, 0x79, 0xe7, 0x6e, 0x74, 0xa5, 0x90, 0x62, 0xfd, 0x4c,
		0x0a, 0xc9, 0x80, 0xa9, 0x2e, 0xc6, 0xee, 0xd4, 0x4f, 0x41, 0xe6, 0x0c, 0xdb, 0x82, 0xe7, 0x81,
		0xe7, 0x81, 0xe7, 0x81, 0xe7, 0x81, 0xe7, 0xdd, 0xb7, 0x3a, 0x1c, 0x06, 0x92, 0x88, 0xd8, 0xcb,
		0x66, 0x06, 0xb5, 0x85, 0xa5, 0x77, 0xae, 0x8a, 0x10, 0x89, 0x10, 0x89, 0x10, 0x89, 0x10, 0x89,
		0x10, 0x79, 0xcf, 0xea, 0xbc, 0x91, 0x08, 0x12, 0x2f, 0xb9, 0x8a, 0xc4, 0x58, 0x65, 0x98, 0x54,
		0xd1, 0xce, 0xdb, 0x5c, 0xdc, 0xda, 0xbe, 0x1b, 0x2b, 0xb4, 0xf4, 0xe5, 0x83, 0xed, 0xf4, 0xbb,
		0x1f, 0x9c, 0x76, 0x63, 0xf0, 0x47, 0xa7, 0xf7, 0xbb, 0x33, 0xf8, 0xd2, 0x6d, 0xa8, 0xb2, 0xf8,
		0x34, 0xe5, 0x13, 0x2b, 0x9d, 0xc1, 0xa4, 0x69, 0x90, 0xe2, 0x7e, 0xaf, 0x53, 0xab, 0x1f, 0xd4,
		0xfa, 0x83, 0xe5, 0x73, 0xb6, 0x4c, 0xcc, 0x57, 0x6a, 0x7a, 0xb8, 0xed, 0x4e, 0xdb, 0xc1, 0x03,
		0x96, 0xf8, 0x80, 0xbb, 0x9d, 0x66, 0x7b, 0xe0, 0x0c, 0x3a, 0xce, 0xfc, 0x0b, 0xf5, 0x4f, 0x58,
		0xc9, 0x95, 0x8e, 0xb9, 0x47, 0x7c, 0x96, 0x8c, 0x6b, 0xe2, 0xc6, 0xb1, 0x77, 0xa1, 0x90, 0x6c,
		0x2d, 0x2f, 0x08, 0x9e, 0x05, 0x9e, 0x05, 0x9e, 0x05, 0x9e, 0x05, 0x9e, 0x75, 0xcf, 0xea, 0x90,
		0x8a, 0xa4, 0x11, 0x18, 0x23, 0x2f, 0x8c, 0xbc, 0x44, 0xe1, 0x41, 0x61, 0x76, 0x45, 0x84, 0x46,
		0x84, 0x46, 0x84, 0x46, 0x84, 0x46, 0x84, 0xc6, 0x7b, 0x56, 0x37, 0xf5, 0x82, 0xe4, 0x9d, 0xc2,
		0xc0, 0x58, 0x45, 0x1d, 0xe6, 0xf3, 0x6f, 0x0c, 0x75, 0x98, 0xf2, 0xaf, 0x8b, 0x3a, 0x4c, 0x63,
		0x55, 0x69, 0xab, 0x8a, 0x2a, 0x4c, 0x76, 0x57, 0x39, 0xc6, 0x5c, 0x4e, 0xf9, 0x2e, 0xa2, 0x70,
		0x73, 0x39, 0x25, 0x4e, 0xf3, 0xe6, 0x31, 0x93, 0x33, 0xf1, 0xce, 0x45, 0x14, 0xcb, 0x1f, 0xca,
		0xb9, 0xb8, 0x0e, 0xf3, 0xa9, 0x9c, 0x9b, 0x98, 0xca, 0x49, 0x8a, 0x57, 0x63, 0x2a, 0x67, 0xb1,
		0xc3, 0x95, 0xf4, 0xa9, 0x9c, 0xc3, 0xa5, 0xe5, 0x2b, 0x4a, 0x54, 0x2e, 0xae, 0xa7, 0x26, 0x4d,
		0x59, 0x46, 0x9a, 0x92, 0xb6, 0x1b, 0x55, 0xed, 0x4e, 0xb5, 0xb9, 0x55, 0x6d, 0xee, 0x55, 0x97,
		0x9b, 0x55, 0xc3, 0x9b, 0x64, 0xa7, 0x29, 0x65, 0xbb, 0xdf, 0xec, 0x42, 0x23, 0xe1, 0x8e, 0xec,
		0x14, 0xb5, 0x5f, 0xb8, 0xbe, 0xfa, 0x32, 0xc2, 0xbb, 0x97, 0x57, 0xa4, 0x91, 0x6a, 0x93, 0x24,
		0xca, 0x97, 0x03, 0xeb, 0x58, 0x0a, 0xac, 0x75, 0x19, 0xb0, 0xae, 0x25, 0xc0, 0xda, 0x97, 0xff,
		0x6a, 0x5f, 0xfa, 0xab, 0x7b, 0xd9, 0xaf, 0x59, 0x3b, 0xe1, 0x94, 0x2f, 0xf5, 0xd5, 0xb7, 0xcc,
		0x57, 0xc3, 0x12, 0x5f, 0x4d, 0xcb, 0x7b, 0x35, 0xac, 0x68, 0xd6, 0xb9, 0xac, 0x57, 0xf3, 0x26,
		0x54, 0xdd, 0xcb, 0x79, 0x29, 0x2c, 0x3c, 0xd5, 0xb0, 0x8c, 0x57, 0xeb, 0x12, 0x5e, 0x2a, 0x2a,
		0xa7, 0x7b, 0xe9, 0x2e, 0x09, 0xdd, 0x33, 0x74, 0xf9, 0xec, 0xb1, 0x29, 0x6b, 0x49, 0x15, 0xa4,
		0x54, 0xce, 0x84, 0xef, 0x87, 0x1a, 0x39, 0xe5, 0xbd, 0xeb, 0x83, 0x54, 0x82, 0x54, 0x82, 0x54,
		0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54,
		0x82, 0x54, 0x82, 0x54, 0x72, 0x22, 0x95, 0x91, 0x48, 0x22, 0x37, 0x88, 0xcf, 0xbd, 0x38, 0xf6,
		0xc2, 0x40, 0x23, 0xbb, 0x5c, 0x27, 0x08, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68,
		0x26, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x68,
		0x26, 0x8f, 0x2b, 0xc8, 0xae, 0xe8, 0x55, 0xd4, 0xff, 0x97, 0x5d, 0x8f, 0x4a, 0x1f, 0xe0, 0xbc,
		0x3d, 0xad, 0xb4, 0x68, 0xbf, 0xc0, 0xcc, 0x9e, 0xd5, 0x17, 0x95, 0x36, 0x4a, 0x2a, 0xeb, 0x83,
		0x99, 0x5f, 0xce, 0xb0, 0x36, 0x98, 0x2d, 0xb4, 0xc1, 0xb0, 0xca, 0x42, 0xa0, 0x0d, 0x06, 0x6d,
		0x30, 0xbf, 0xf2, 0xd0, 0xd0, 0x06, 0x63, 0x0c, 0xf5, 0x40, 0x2a, 0xd9, 0x34, 0x27, 0xae, 0xdd,
		0x99, 0x6b, 0x77, 0xea, 0xba, 0x9d, 0xbb, 0x5a, 0x2e, 0x89, 0x54, 0xb2, 0x34, 0x1f, 0x8c, 0x54,
		0xb2, 0x84, 0x1b, 0x45, 0x2a, 0x19, 0xa9, 0x64, 0xd5, 0x2a, 0x87, 0x54, 0x32, 0x52, 0xc9, 0x48,
		0x25, 0x93, 0xbf, 0x1f, 0xb4, 0xc1, 0x80, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54,
		0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54, 0x82, 0x54,
		0x92, 0x26, 0x95, 0x68, 0x83, 0x01, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04,
		0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x04, 0xcd, 0x2c, 0x0e, 0xcd,
		0x44, 0x1b, 0xcc, 0x13, 0xae, 0x47, 0xac, 0x0d, 0x46, 0xe2, 0x56, 0x2c, 0xf9, 0xfa, 0x81, 0x85,
		0x6b, 0xf4, 0x35, 0xcc, 0x92, 0xda, 0xa9, 0x14, 0x4d, 0x87, 0x49, 0xb0, 0x20, 0x1c, 0xed, 0xb9,
		0xe8, 0xcd, 0x85, 0xe4, 0x4e, 0x77, 0x21, 0xaf, 0xd3, 0x49, 0xe5, 0x75, 0x6a, 0x91, 0x70, 0x9d,
		0xe6, 0x52, 0x3c, 0x67, 0x30, 0x17, 0x8f, 0xcb, 0x42, 0xb8, 0x57, 0x84, 0x55, 0xdc, 0xfa, 0x5d,
		0x5c, 0xcd, 0xde, 0x80, 0x37, 0xca, 0xf9, 0x6d, 0x5b, 0x2d, 0x2f, 0x4e, 0x6a, 0x49, 0x22, 0xa7,
		0xe9, 0x62, 0x46, 0x6a, 0x1a, 0xbe, 0x38, 0x17, 0xc1, 0x1c, 0xd9, 0x48, 0xd8, 0xb9, 0x77, 0xe8,
		0x5e, 0xde, 0xba, 0x42, 0xf9, 0x5d, 0xa5, 0xb2, 0xb3, 0x5b, 0xa9, 0x6c, 0xee, 0x6e, 0xef, 0x6e,
		0xee, 0x55, 0xab, 0xe5, 0x9d, 0xb2, 0x04, 0x5c, 0x67, 0x75, 0xa2, 0x91, 0x88, 0xc4, 0x68, 0x7f,
		0xf6, 0x4e, 0x82, 0xa9, 0xef, 0x93, 0x56, 0x1d, 0xc9, 0x5e, 0x91, 0x8a, 0x37, 0x94, 0xe0, 0x06,
		0x5f, 0xe4, 0xfe, 0xf2, 0xf5, 0x7b, 0xf9, 0x79, 0xa7, 0x7c, 0x7e, 0x53, 0x4e, 0x4a, 0x2a, 0x4b,
		0x39, 0xf5, 0x2a, 0x65, 0x3e, 0xaf, 0xfe, 0xe5, 0x2f, 0x2a, 0x87, 0x97, 0x64, 0xf9, 0xf1, 0xe8,
		0x24, 0xb7, 0x57, 0x93, 0xa5, 0x2e, 0xd3, 0xdf, 0x9a, 0x93, 0x0a, 0xe5, 0xdb, 0x79, 0x9c, 0x7b,
		0x87, 0xb1, 0x8c, 0x83, 0x1d, 0xa9, 0x07, 0x37, 0xb2, 0x0e, 0x66, 0xa4, 0x1f, 0xbc, 0x48, 0x3f,
		0x58, 0x91, 0x7d, 0x70, 0x42, 0xcb, 0x35, 0xe7, 0xdd, 0x89, 0x6b, 0xf9, 0xb1, 0x6b, 0x27, 0x57,
		0x13, 0x91, 0xff, 0x86, 0xe4, 0x5b, 0x7e, 0x65, 0x79, 0x89, 0xbc, 0xf1, 0xb7, 0x94, 0xf1, 0x06,
		0xd2, 0x4e, 0x99, 0x65, 0x9e, 0x26, 0x2b, 0x39, 0x35, 0x96, 0x7d, 0x3a, 0xac, 0xec, 0x14, 0x58,
		0xd9, 0x69, 0xaf, 0xaa, 0x53, 0x5d, 0xda, 0x3c, 0x59, 0xd6, 0xf8, 0x80, 0xcc, 0xb3, 0xc8, 0xdf,
		0xee, 0x9e, 0x5d, 0x09, 0xfb, 0xdd, 0x55, 0xbb, 0x36, 0xa5, 0x2e, 0x4e, 0x95, 0xab, 0x53, 0xee,
		0xf2, 0x94, 0xbb, 0x3e, 0xd5, 0x2e, 0x50, 0x5e, 0x12, 0x72, 0x83, 0xf3, 0x7e, 0x77, 0x3f, 0x76,
		0x63, 0x75, 0x53, 0xad, 0xd2, 0xab, 0x61, 0xb7, 0x3b, 0x35, 0xd7, 0xa9, 0xc5, 0x85, 0xaa, 0x76,
		0xa5, 0xda, 0x5c, 0xaa, 0x36, 0xd7, 0xaa, 0xcb, 0xc5, 0xca, 0x75, 0xb5, 0x92, 0x5d, 0xae, 0x32,
		0xd7, 0x7b, 0xdb, 0x05, 0xab, 0x2f, 0x0c, 0x9f, 0x5d, 0x54, 0x6d, 0x11, 0x78, 0x19, 0x45, 0xe0,
		0xbc, 0x1d, 0xb5, 0x2e, 0x87, 0xad, 0xdd, 0x71, 0x6b, 0x77, 0xe0, 0xba, 0x1d, 0xb9, 0x1a, 0x87,
		0xae, 0xc8, 0xb1, 0x2b, 0x77, 0xf0, 0xd9, 0x05, 0xdd, 0xd8, 0x16, 0x97, 0x89, 0x88, 0x02, 0xd7,
		0xb7, 0x55, 0x3a, 0xfd, 0x15, 0xaf, 0x71, 0x5f, 0x10, 0xc5, 0x5a, 0xac, 0x36, 0x20, 0x68, 0x0b,
		0x0c, 0x3a, 0x03, 0x04, 0x89, 0x40, 0xa1, 0x3b, 0x60, 0x90, 0x09, 0x1c, 0x64, 0x02, 0x08, 0x95,
		0x40, 0xa2, 0x36, 0xa0, 0x28, 0x0e, 0x2c, 0xda, 0x02, 0x4c, 0x76, 0x61, 0x35, 0xb3, 0xca, 0x1f,
		0xf5, 0x39, 0x2a, 0x66, 0x98, 0x13, 0x0b, 0x32, 0xda, 0x83, 0x0d, 0x85, 0xa0, 0x43, 0x2a, 0xf8,
		0x50, 0x09, 0x42, 0xe4, 0x82, 0x11, 0xb9, 0xa0, 0x44, 0x2d, 0x38, 0xe9, 0x09, 0x52, 0x9a, 0x82,
		0x95, 0xf6, 0xa0, 0x95, 0x09, 0x90, 0x31, 0x93, 0x28, 0x9c, 0x26, 0xc2, 0x4e, 0xdc, 0x53, 0xfd,
		0x36, 0xbb, 0x74, 0x64, 0x0f, 0xc8, 0xa6, 0xd9, 0x56, 0xf4, 0x76, 0xe4, 0x91, 0x09, 0x77, 0x94,
		0xc2, 0x1e, 0xc9, 0xf0, 0x47, 0x2d, 0x0c, 0x92, 0x0d, 0x87, 0x64, 0xc3, 0x22, 0xd5, 0xf0, 0xa8,
		0x37, 0x4c, 0x6a, 0x0e, 0x97, 0xd9, 0x4b, 0x51, 0x3e, 0x51, 0xe2, 0x51, 0xaf, 0xa3, 0x7c, 0xd2,
		0xc4, 0x63, 0x31, 0x6a, 0x97, 0x80, 0x28, 0x7a, 0x26, 0x53, 0xac, 0xfb, 0xd0, 0x70, 0xc1, 0x1b,
		0xba, 0x27, 0x59, 0x10, 0x07, 0x37, 0x2b, 0x62, 0x69, 0x9e, 0x7c, 0xb1, 0x56, 0x2e, 0x02, 0x53,
		0x09, 0x88, 0xba, 0xe7, 0xbb, 0xaa, 0xee, 0x5e, 0x42, 0xd5, 0x9f, 0xa8, 0xea, 0xba, 0x27, 0x6e,
		0xb0, 0xd4, 0xf9, 0x57, 0x90, 0x62, 0x43, 0xd9, 0x44, 0x0f, 0x7a, 0xf7, 0xaf, 0xd1, 0xe7, 0x59,
		0xe3, 0x30, 0xfa, 0xe1, 0x46, 0x23, 0x2f, 0x38, 0xb5, 0xdd, 0xd1, 0x28, 0x12, 0x71, 0x4c, 0x27,
		0x89, 0xf2, 0x80, 0x6c, 0x48, 0xa2, 0x20, 0x89, 0x82, 0x24, 0x0a, 0x92, 0x28, 0x48, 0xa2, 0x20,
		0x89, 0x42, 0xca, 0xeb, 0x78, 0x93, 0x8b, 0xca, 0x32, 0x4a, 0xd9, 0x41, 0x68, 0xff, 0x3b, 0x0c,
		0x04, 0xa1, 0x94, 0x4a, 0xf9, 0x1d, 0x01, 0x59, 0xba, 0x6e, 0x92, 0x88, 0x28, 0x20, 0x93, 0x55,
		0xb1, 0x5e, 0xbf, 0xfe, 0xba, 0x69, 0xef, 0x1d, 0xff, 0xfd, 0xb5, 0x6c, 0xef, 0x1d, 0xcf, 0xbf,
		0x2c, 0xa7, 0x7f, 0xcd, 0xbf, 0xde, 0xfa, 0xba, 0x69, 0x57, 0x96, 0x5f, 0x57, 0xbf, 0x6e, 0xda,
		0xd5, 0xe3, 0x37, 0xdf, 0xbe, 0xbd, 0x7d, 0xf3, 0xd7, 0xf6, 0xf5, 0xd3, 0x7f, 0xf0, 0xf5, 0x7f,
		0x7e, 0xfd, 0xf6, 0x6d, 0xf2, 0x57, 0xfb, 0x7a, 0xf6, 0x67, 0xeb, 0xfa, 0xf8, 0xbf, 0xde, 0xfc,
		0x93, 0x8a, 0xef, 0x9d, 0x09, 0xfa, 0xed, 0xdb, 0xdb, 0xe3, 0x7f, 0x58, 0xa0, 0x00, 0x05, 0xa4,
		0x00, 0xe7, 0x6e, 0xfc, 0x9d, 0x0e, 0xe8, 0x4f, 0xa5, 0x01, 0xcc, 0x07, 0xcc, 0x07, 0xcc, 0x07,
		0xcc, 0x07, 0xcc, 0x07, 0xcc, 0x27, 0x77, 0x56, 0xfa, 0x8e, 0x10, 0xae, 0xaf, 0xe2, 0xa8, 0xf4,
		0xde, 0x07, 0x47, 0xa5, 0x1c, 0xb0, 0xcd, 0x8a, 0x58, 0x38, 0x2a, 0xe5, 0xe6, 0x9d, 0xef, 0xaa,
		0x3a, 0x8e, 0x4a, 0x9f, 0xac, 0xea, 0xdb, 0x5b, 0xd0, 0x75, 0x1e, 0x38, 0x88, 0x8e, 0x14, 0xc8,
		0x8f, 0x68, 0xc8, 0x8f, 0x88, 0x24, 0xf2, 0x86, 0x84, 0x32, 0x24, 0x73, 0x79, 0x90, 0x23, 0x41,
		0x8e, 0x04, 0x39, 0x12, 0xe4, 0x48, 0x90, 0x23, 0x41, 0x8e, 0x84, 0x96, 0xd7, 0x89, 0x27, 0x63,
		0x9b, 0x44, 0x90, 0xba, 0x1d, 0xa8, 0x76, 0x90, 0x29, 0x41, 0xa6, 0x04, 0x99, 0x12, 0x64, 0x4a,
		0x90, 0x29, 0x61, 0xa7, 0xea, 0x3b, 0xd5, 0xea, 0x36, 0xea, 0xc9, 0x91, 0x2c, 0x41, 0xb2, 0x84,
		0x49, 0xb2, 0x44, 0xee, 0x30, 0xf5, 0x67, 0x66, 0x4c, 0x64, 0xce, 0x5d, 0x47, 0xda, 0x04, 0x69,
		0x13, 0xa4, 0x4d, 0x90, 0x36, 0x41, 0xda, 0x04, 0x69, 0x93, 0x67, 0x7a, 0x1d, 0x11, 0x4c, 0xcf,
		0x45, 0x34, 0xdf, 0x96, 0x47, 0xa8, 0x70, 0xbc, 0x42, 0x40, 0x96, 0x46, 0x30, 0x3d, 0x9f, 0xbd,
		0xac, 0xeb, 0xa2, 0x02, 0xba, 0x42, 0x0d, 0x96, 0x52, 0xbc, 0x52, 0x7c, 0xad, 0x1c, 0x1a, 0xb6,
		0x4c, 0xfa, 0xf1, 0xe8, 0xa4, 0x94, 0xad, 0x39, 0xcb, 0xbe, 0x9a, 0x7d, 0x91, 0xfe, 0xab, 0x74,
		0x6f, 0x20, 0xaf, 0x8a, 0xfd, 0xe3, 0x74, 0x94, 0x52, 0x83, 0x42, 0x5a, 0xe9, 0x8b, 0xb0, 0xc3,
		0xb1, 0x1d, 0x8b, 0xe8, 0xc2, 0x1b, 0x12, 0x18, 0x96, 0xb9, 0x22, 0x11, 0xe6, 0x66, 0x16, 0x95,
		0xb9, 0x60, 0x6e, 0x26, 0x07, 0x86, 0x82, 0xb9, 0x99, 0x80, 0x37, 0xb7, 0x1e, 0xbe, 0xf6, 0xb9,
		0x99, 0xb3, 0x00, 0x42, 0x21, 0xa2, 0x3d, 0x18, 0xd9, 0xf4, 0x07, 0x36, 0x22, 0x01, 0x8e, 0x4c,
		0xa0, 0xa3, 0x14, 0xf0, 0x48, 0x06, 0x3e, 0x6a, 0x01, 0x90, 0x6c, 0x20, 0x24, 0x1b, 0x10, 0xa9,
		0x06, 0x46, 0xfd, 0x99, 0x87, 0x0d, 0x02, 0xa9, 0x3a, 0xdd, 0x01, 0xf3, 0x26, 0x21, 0xa0, 0x75,
		0x5b, 0xc2, 0x5a, 0x1f, 0xa8, 0x73, 0x7b, 0x02, 0xd1, 0xa0, 0x49, 0x2e, 0x78, 0x52, 0x0c, 0xa2,
		0xa4, 0x83, 0x29, 0xd5, 0xa0, 0x4a, 0x3e, 0xb8, 0x92, 0x0f, 0xb2, 0xd4, 0x83, 0x2d, 0x8d, 0xa0,
		0x4b, 0x24, 0xf8, 0x92, 0x0b, 0xc2, 0x99, 0x40, 0x04, 0xb7, 0x3f, 0xac, 0x75, 0xac, 0xe4, 0xb6,
		0x41, 0xac, 0x0b, 0xdb, 0xd4, 0x0a, 0x00, 0xa9, 0x85, 0x6f, 0xca, 0x61, 0x9c, 0x45, 0x38, 0xa7,
		0x1e, 0xd6, 0xd9, 0x84, 0x77, 0x36, 0x61, 0x9e, 0x4b, 0xb8, 0xa7, 0x15, 0xf6, 0x89, 0x85, 0xff,
		0xec, 0x25, 0x92, 0x29, 0x9b, 0x59, 0xeb, 0xf5, 0xc8, 0x6c, 0xb3, 0x58, 0x17, 0x63, 0x77, 0x09,
		0x8a, 0x46, 0xab, 0x31, 0xe9, 0xfe, 0x87, 0x66, 0x88, 0xd8, 0xa0, 0xda, 0xb8, 0xc4, 0x04, 0xdc,
		0xad, 0x88, 0x49, 0xb4, 0xb1, 0x69, 0x45, 0x4e, 0xc2, 0x9d, 0x1f, 0xc4, 0xc3, 0xc7, 0x5d, 0xd3,
		0x71, 0x2f, 0x61, 0x3a, 0x39, 0x9b, 0x0e, 0xd5, 0xed, 0x1b, 0xac, 0x6d, 0xe8, 0x15, 0xa4, 0xfa,
		0x95, 0xcf, 0xf1, 0x2b, 0x3c, 0x1f, 0xe2, 0x3e, 0x98, 0xe2, 0xb6, 0x8f, 0xb5, 0x40, 0x9e, 0xdc,
		0xf6, 0x0f, 0x26, 0xc1, 0x01, 0x49, 0xb3, 0x97, 0x68, 0x1d, 0x92, 0x66, 0x2f, 0x31, 0x08, 0x24,
		0xcd, 0x72, 0x16, 0x14, 0x49, 0x33, 0xfe, 0xac, 0x87, 0x41, 0xd2, 0x8c, 0xe8, 0xf6, 0x92, 0x75,
		0x11, 0x97, 0xc2, 0x36, 0x93, 0xd5, 0xe8, 0x46, 0x6c, 0xbb, 0xc9, 0x8a, 0x80, 0xd8, 0x76, 0xf2,
		0xe0, 0x63, 0x21, 0xb4, 0xfd, 0x04, 0x94, 0x8a, 0x1f, 0xa5, 0x22, 0x32, 0x1d, 0x74, 0xad, 0x6b,
		0x27, 0x33, 0x88, 0x0d, 0xd4, 0x09, 0xd4, 0x09, 0xd4, 0x09, 0xd4, 0x09, 0xd4, 0x09, 0xd4, 0xc9,
		0x20, 0xea, 0x44, 0x6b, 0xda, 0xe9, 0xba, 0x40, 0xbb, 0x83, 0xa2, 0x83, 0x27, 0x7e, 0x50, 0x74,
		0x60, 0x22, 0xc2, 0x5b, 0x11, 0x13, 0x45, 0x07, 0xa6, 0xc7, 0x90, 0xbb, 0xa6, 0x83, 0xa2, 0x83,
		0xdc, 0x4d, 0x87, 0xe0, 0x74, 0x56, 0xd6, 0xe6, 0x83, 0x7a, 0x83, 0x5f, 0xfa, 0x20, 0x39, 0x46,
		0xde, 0xfd, 0x5a, 0x49, 0x48, 0xb8, 0xc0, 0x60, 0x26, 0x1c, 0xd2, 0x62, 0xbf, 0x22, 0x16, 0xd2,
		0x62, 0x2f, 0x21, 0x88, 0x48, 0x8b, 0xbd, 0xc0, 0x20, 0x90, 0x16, 0xcb, 0x59, 0x50, 0xa4, 0xc5,
		0xf8, 0x53, 0x1a, 0x26, 0x6d, 0x38, 0xef, 0x08, 0x27, 0xc4, 0xaa, 0x48, 0x88, 0x3d, 0xf1, 0x83,
		0x84, 0x58, 0xa1, 0x58, 0x3d, 0x12, 0x62, 0xa6, 0x46, 0x8f, 0xbb, 0xa6, 0x83, 0x84, 0x58, 0xee,
		0xa6, 0xb3, 0x55, 0x45, 0x3a, 0xcc, 0x50, 0x20, 0x48, 0x57, 0x2a, 0xa4, 0xc3, 0x28, 0x4b, 0x42,
		0x65, 0x8c, 0x0f, 0x91, 0xd9, 0xfa, 0x2b, 0x72, 0x71, 0x98, 0xb5, 0x7f, 0x7f, 0xf0, 0x7a, 0xe9,
		0xde, 0xbc, 0x5a, 0x9d, 0xc3, 0xf8, 0xe9, 0x69, 0x3d, 0x01, 0x8d, 0x27, 0x95, 0x7e, 0x26, 0x98,
		0x76, 0x26, 0x86, 0xab, 0x30, 0xac, 0xf1, 0x29, 0x6a, 0x84, 0x61, 0x8d, 0x4f, 0x51, 0x74, 0x0c,
		0x6b, 0x7c, 0x29, 0x70, 0xc0, 0xb0, 0x46, 0x3e, 0x28, 0x8f, 0x5c, 0x7a, 0x38, 0xf3, 0x5a, 0xbe,
		0x70, 0xc7, 0x91, 0x18, 0x53, 0xf2, 0x59, 0xcb, 0x9e, 0x32, 0x42, 0x73, 0x99, 0xac, 0xee, 0x02,
		0x08, 0xbf, 0x7d, 0x3b, 0x07, 0x95, 0xa5, 0x19, 0x68, 0x00, 0xb0, 0x24, 0x20, 0x81, 0xee, 0x61,
		0xe8, 0xbf, 0x8b, 0x2b, 0x1a, 0x20, 0xd2, 0x6a, 0x79, 0x71, 0x52, 0x4b, 0x12, 0x22, 0xb3, 0xd9,
		0x0f, 0xbd, 0xa0, 0xe1, 0x8b, 0x59, 0x84, 0x8a, 0x69, 0x00, 0x48, 0xeb, 0xd0, 0xbd, 0xbc, 0x25,
		0x51, 0xf9, 0x5d, 0xa5, 0xb2, 0xb3, 0x5b, 0xa9, 0x6c, 0xee, 0x6e, 0xef, 0x6e, 0xee, 0x55, 0xab,
		0xe5, 0x9d, 0x32, 0x81, 0x24, 0xa1, 0xd5, 0x89, 0x46, 0x22, 0x12, 0xa3, 0xfd, 0x99, 0x52, 0x05,
		0x53, 0xdf, 0x2f, 0xb4, 0x6d, 0x11, 0x4b, 0x8e, 0x18, 0x91, 0x14, 0xa1, 0xb0, 0x97, 0x25, 0x4e,
		0xa2, 0xe9, 0x30, 0x09, 0x16, 0x10, 0xa4, 0x3d, 0x7f, 0x30, 0xcd, 0xc5, 0x73, 0x71, 0xba, 0x8b,
		0xa7, 0xe1, 0x74, 0xd2, 0xa7, 0xe1, 0xd4, 0x22, 0xe1, 0x3a, 0xad, 0x78, 0x74, 0xe2, 0xb4, 0x62,
		0x77, 0x86, 0xa4, 0x66, 0x7f, 0x3b, 0xb5, 0xb8, 0xb1, 0xb8, 0xed, 0xd9, 0xbf, 0x66, 0xdf, 0xee,
		0x8c, 0xfb, 0x8b, 0x5b, 0xc4, 0x56, 0x52, 0xf3, 0x9d, 0x04, 0xb6, 0x92, 0xbe, 0xc0, 0x29, 0x14,
		0x66, 0x41, 0xe9, 0x2b, 0x83, 0x2d, 0x41, 0xb7, 0x05, 0x70, 0xd0, 0x7c, 0x0d, 0xd1, 0x2e, 0xff,
		0xe8, 0xa6, 0xd6, 0x5a, 0xd5, 0xd9, 0x8c, 0x42, 0x7b, 0xb1, 0x7c, 0x2f, 0xf8, 0x6e, 0xa7, 0xd4,
		0xdd, 0xf6, 0x46, 0xca, 0xcd, 0xe5, 0x26, 0xdd, 0x72, 0x47, 0x0c, 0xc5, 0xfe, 0x42, 0xcf, 0xe9,
		0x82, 0xb6, 0x53, 0x04, 0x9d, 0xa7, 0x05, 0x24, 0x4e, 0x05, 0x74, 0x67, 0xff, 0xc9, 0x64, 0xf9,
		0xc9, 0x64, 0xf3, 0xa9, 0x64, 0xed, 0xcd, 0xc6, 0x45, 0xda, 0xb2, 0xed, 0x04, 0xb2, 0xea, 0x3a,
		0xb3, 0xe7, 0xab, 0x59, 0xf2, 0xbb, 0xe1, 0x0e, 0x30, 0xe6, 0xc5, 0x4f, 0x78, 0x89, 0x9a, 0x67,
		0xd0, 0x56, 0x1b, 0x88, 0xb9, 0x2d, 0x84, 0x1e, 0x08, 0x53, 0x06, 0x84, 0x01, 0x84, 0x01, 0x84,
		0x01, 0x84, 0x31, 0x15, 0xc2, 0xe8, 0xda, 0xee, 0xa8, 0x79, 0xa5, 0x32, 0x89, 0x15, 0xca, 0x9a,
		0x57, 0x26, 0x6b, 0xaf, 0xba, 0xa3, 0x50, 0x65, 0x47, 0xaa, 0xaa, 0x8e, 0x4a, 0x15, 0x1d, 0xb9,
		0xaa, 0x39, 0x72, 0x55, 0x72, 0xd4, 0xaa, 0xe2, 0x8a, 0x75, 0x22, 0xa7, 0x7b, 0x25, 0xb1, 0xe5,
		0x26, 0x89, 0x3b, 0x3c, 0x13, 0xa3, 0xf9, 0x5a, 0x5f, 0xfd, 0x85, 0x30, 0x99, 0x17, 0xbb, 0x2f,
		0x98, 0xee, 0x9a, 0x25, 0x12, 0x65, 0xe6, 0x64, 0xca, 0xcb, 0x29, 0x95, 0x95, 0x93, 0x2c, 0x27,
		0xa7, 0x56, 0x46, 0x4e, 0xb6, 0x7c, 0x9c, 0x6c, 0xd9, 0x38, 0xd5, 0x72, 0xf1, 0x62, 0xd7, 0x8e,
		0x92, 0x29, 0x0b, 0xcf, 0xbc, 0xce, 0x28, 0x4c, 0x12, 0x31, 0xb2, 0xff, 0x35, 0x75, 0x47, 0x14,
		0xfc, 0x0e, 0xa1, 0xf5, 0x22, 0xe4, 0xd6, 0x89, 0x28, 0x5d, 0x1f, 0xa2, 0xdf, 0x53, 0x1c, 0x17,
		0xda, 0x53, 0xa0, 0xb6, 0xfb, 0x11, 0x89, 0x50, 0xdb, 0xcd, 0x26, 0xf2, 0x6a, 0xb4, 0xa5, 0xec,
		0xe8, 0xea, 0xdc, 0x8d, 0xbf, 0xd3, 0xa1, 0x87, 0x77, 0xa4, 0x02, 0x37, 0x04, 0x37, 0x04, 0x37,
		0x04, 0x37, 0x04, 0x37, 0x04, 0x37, 0x24, 0xe5, 0x75, 0xa8, 0x4c, 0x90, 0x24, 0x34, 0x31, 0x92,
		0xd8, 0x84, 0x48, 0x42, 0xfd, 0xe5, 0x14, 0x27, 0x40, 0x52, 0x9d, 0xe6, 0x4d, 0x74, 0xc2, 0x23,
		0xe5, 0xa1, 0x74, 0x94, 0x66, 0xea, 0x53, 0x9c, 0xd8, 0x48, 0x5d, 0xd5, 0xb7, 0xb7, 0xa0, 0xeb,
		0x3c, 0x70, 0x10, 0x1d, 0x29, 0x8e, 0xd1, 0xd6, 0x6b, 0xbe, 0x87, 0x45, 0x5b, 0xef, 0x4f, 0x9a,
		0x1b, 0x6f, 0x15, 0x5e, 0xeb, 0x9c, 0x6d, 0x88, 0x3e, 0x5e, 0xa3, 0x54, 0x9e, 0xba, 0xaa, 0x73,
		0xed, 0xe1, 0x5d, 0xfc, 0x14, 0x1a, 0x78, 0x73, 0x79, 0x23, 0x41, 0x1c, 0xbb, 0x77, 0x5b, 0xbb,
		0xf5, 0xf5, 0xbf, 0xac, 0x88, 0x82, 0x2e, 0x18, 0xa9, 0x17, 0x46, 0x17, 0x0c, 0xba, 0x60, 0xe6,
		0x82, 0xa0, 0x0b, 0xa6, 0x48, 0xc0, 0x08, 0x5d, 0x30, 0xe8, 0x82, 0x41, 0x17, 0x0c, 0xba, 0x60,
		0x68, 0x06, 0x23, 0x72, 0x41, 0x89, 0x5a, 0x70, 0x2a, 0x66, 0x02, 0x4b, 0x7b, 0x17, 0x4c, 0xc6,
		0x4c, 0xd2, 0x66, 0x13, 0x3b, 0x71, 0x4f, 0xe9, 0x54, 0x3a, 0x3d, 0x20, 0x1b, 0xea, 0x9d, 0x50,
		0xef, 0xc4, 0x20, 0xfc, 0x51, 0x0b, 0x83, 0x64, 0xc3, 0x21, 0xd9, 0xb0, 0x48, 0x35, 0x3c, 0xea,
		0x0d, 0x93, 0x9a, 0xc3, 0x65, 0xf6, 0x52, 0x68, 0xd6, 0x3b, 0x6d, 0x6f, 0x11, 0x2a, 0x78, 0xda,
		0x45, 0xc1, 0xd3, 0xbd, 0x0f, 0x0a, 0x9e, 0x38, 0x80, 0x9b, 0x15, 0xb1, 0x50, 0xf0, 0xc4, 0xcd,
		0x3d, 0xdf, 0x55, 0x75, 0x14, 0x3c, 0x3d, 0x59, 0xd5, 0x2b, 0x5b, 0x7b, 0x95, 0xbd, 0x9d, 0xdd,
		0xad, 0xbd, 0x2a, 0x74, 0x9e, 0x07, 0x20, 0xa2, 0x23, 0xc5, 0x31, 0x1a, 0xc5, 0x94, 0x9b, 0xc5,
		0x38, 0x8c, 0x7e, 0xb8, 0xd1, 0xc8, 0x0b, 0x4e, 0x6d, 0x77, 0x34, 0x8a, 0x44, 0x1c, 0xd3, 0x49,
		0xa2, 0x3c, 0x20, 0x1b, 0x92, 0x28, 0x48, 0xa2, 0x20, 0x89, 0x82, 0x24, 0x0a, 0x92, 0x28, 0x48,
		0xa2, 0x90, 0xf2, 0x3a, 0xde, 0xe4, 0xa2, 0xb2, 0x8c, 0x52, 0x76, 0x10, 0xda, 0xff, 0x0e, 0x03,
		0x81, 0xc9, 0x22, 0xf7, 0xa2, 0x45, 0x91, 0x27, 0x8b, 0xbc, 0xfe, 0xcf, 0xaf, 0xdf, 0xbe, 0x4d,
		0xfe, 0x6a, 0x5f, 0xcf, 0xfe, 0x6c, 0x5d, 0x1f, 0xff, 0xd7, 0x9b, 0x7f, 0x52, 0xf1, 0xbd, 0x33,
		0x41, 0xbf, 0x7d, 0x7b, 0x7b, 0xfc, 0x0f, 0x0b, 0x14, 0xa0, 0x80, 0x14, 0x80, 0xd6, 0x8c, 0x08,
		0xcc, 0x86, 0x00, 0xcc, 0x07, 0xcc, 0x07, 0xcc, 0x07, 0xcc, 0x07, 0xcc, 0xc7, 0x6c, 0x88, 0xc7,
		0x42, 0x14, 0x66, 0x43, 0xdc, 0xff, 0xe0, 0xa8, 0x94, 0x03, 0xb6, 0x59, 0x11, 0x0b, 0x47, 0xa5,
		0xdc, 0xbc, 0xf3, 0x5d, 0x55, 0xc7, 0x51, 0xe9, 0x93, 0x55, 0x1d, 0xb3, 0x21, 0xb8, 0xe0, 0x20,
		0x3a, 0x52, 0x20, 0x3f, 0xa2, 0x21, 0x3f, 0x22, 0x92, 0xc8, 0x1b, 0x12, 0xca, 0x90, 0xcc, 0xe5,
		0x41, 0x8e, 0x04, 0x39, 0x12, 0xe4, 0x48, 0x90, 0x23, 0x41, 0x8e, 0x04, 0x39, 0x12, 0x5a, 0x5e,
		0x27, 0x9e, 0x8c, 0x6d, 0x12, 0x41, 0xea, 0x76, 0xa0, 0xda, 0x41, 0xa6, 0x04, 0x99, 0x12, 0x64,
		0x4a, 0x90, 0x29, 0x41, 0xa6, 0x84, 0x9d, 0xaa, 0xef, 0x54, 0xab, 0xdb, 0xa8, 0x27, 0x47, 0xb2,
		0x04, 0xc9, 0x12, 0x26, 0xc9, 0x92, 0x74, 0xc8, 0x1d, 0xb5, 0x8c, 0xc9, 0x5c, 0x28, 0xa4, 0x4d,
		0x90, 0x36, 0x41, 0xda, 0x04, 0x69, 0x13, 0xa4, 0x4d, 0x90, 0x36, 0x21, 0xe5, 0x75, 0x44, 0x30,
		0x3d, 0x17, 0xd1, 0x7c, 0x3c, 0x2e, 0xa1, 0xc2, 0xf1, 0x0a, 0x01, 0x59, 0x1a, 0xc1, 0xf4, 0x7c,
		0xf6, 0xb2, 0xae, 0x01, 0xe8, 0x94, 0x3f, 0xfb, 0x49, 0x14, 0x4e, 0xdc, 0x53, 0x9d, 0x63, 0x02,
		0x57, 0x2c, 0xe5, 0x46, 0x24, 0x80, 0x39, 0x80, 0x39, 0x80, 0x39, 0x80, 0x39, 0x80, 0x39, 0x80,
		0x39, 0x52, 0x5e, 0xe7, 0x24, 0x0c, 0x7d, 0xe1, 0x92, 0x02, 0x72, 0x65, 0xac, 0x95, 0x31, 0xdf,
		0x24, 0xb0, 0x56, 0xe6, 0x67, 0xbb, 0x36, 0xee, 0xef, 0x33, 0x28, 0xd8, 0x72, 0x19, 0x0d, 0x03,
		0xfd, 0xd3, 0x57, 0x61, 0x87, 0x63, 0x3b, 0x16, 0xd1, 0x85, 0x37, 0x24, 0x30, 0x6b, 0x7c, 0x45,
		0x22, 0x8c, 0x1d, 0x2f, 0x2a, 0x57, 0xc0, 0xd8, 0x71, 0x0e, 0x9c, 0x00, 0x63, 0xc7, 0x01, 0x70,
		0x6e, 0x3d, 0x7c, 0xed, 0x63, 0xc7, 0x67, 0x01, 0x84, 0x42, 0x44, 0x7b, 0x30, 0xb2, 0xe9, 0x0f,
		0x6c, 0x44, 0x02, 0x1c, 0x99, 0x40, 0x47, 0x29, 0xe0, 0x91, 0x0c, 0x7c, 0xd4, 0x02, 0x20, 0xd9,
		0x40, 0x48, 0x36, 0x20, 0x52, 0x0d, 0x8c, 0xfa, 0x73, 0x0f, 0x1b, 0x04, 0x92, 0x63, 0xba, 0x03,
		0xe6, 0x4d, 0x4a, 0x20, 0xa1, 0x70, 0x8a, 0xb4, 0xe2, 0x03, 0x75, 0x2e, 0x9f, 0x22, 0x1a, 0x34,
		0xc9, 0x05, 0x4f, 0x8a, 0x41, 0x94, 0x74, 0x30, 0xa5, 0x1a, 0x54, 0xc9, 0x07, 0x57, 0xf2, 0x41,
		0x96, 0x7a, 0xb0, 0xa5, 0x11, 0x74, 0x89, 0x04, 0x5f, 0x72, 0x41, 0x38, 0x13, 0x88, 0xe0, 0xf2,
		0xac, 0xb5, 0x8e, 0x95, 0xdc, 0x32, 0xad, 0x75, 0x61, 0x9b, 0x5a, 0xff, 0x04, 0xb5, 0xf0, 0x4d,
		0x39, 0x8c, 0xb3, 0x08, 0xe7, 0xd4, 0xc3, 0x3a, 0x9b, 0xf0, 0xce, 0x26, 0xcc, 0x73, 0x09, 0xf7,
		0xb4, 0xc2, 0x3e, 0xb1, 0xf0, 0x9f, 0xbd, 0x44, 0x32, 0x85, 0x2a, 0x6b, 0xbd, 0x1e, 0x99, 0x65,
		0x60, 0xeb, 0x62, 0xec, 0x2e, 0x41, 0xd1, 0x68, 0xf5, 0x75, 0xdf, 0xff, 0xd0, 0x0c, 0x11, 0x1b,
		0x54, 0xfb, 0xbe, 0x99, 0x80, 0xbb, 0x15, 0x31, 0x89, 0xf6, 0x85, 0xaf, 0xc8, 0x49, 0xb8, 0x71,
		0x96, 0x78, 0xf8, 0xb8, 0x6b, 0x3a, 0xee, 0x25, 0x4c, 0x27, 0x67, 0xd3, 0xa1, 0xba, 0xbc, 0x8c,
		0xb5, 0x0d, 0xbd, 0x82, 0x54, 0xbf, 0xf2, 0x39, 0x7e, 0x85, 0xe7, 0x43, 0xdc, 0x07, 0x53, 0x5c,
		0x96, 0xb6, 0x16, 0xc8, 0x93, 0x5b, 0x9e, 0xc6, 0x24, 0x38, 0x20, 0x69, 0xf6, 0x12, 0xad, 0x43,
		0xd2, 0xec, 0x25, 0x06, 0x81, 0xa4, 0x59, 0xce, 0x82, 0x22, 0x69, 0xc6, 0x9f, 0xf5, 0x30, 0x48,
		0x9a, 0x11, 0x5d, 0xfe, 0xb6, 0x2e, 0xe2, 0x52, 0x58, 0x06, 0xb7, 0x1a, 0xdd, 0x88, 0x2d, 0x87,
		0x5b, 0x11, 0x10, 0xcb, 0xe2, 0x1e, 0x7c, 0x2c, 0x84, 0x96, 0xc7, 0x81, 0x52, 0xf1, 0xa3, 0x54,
		0x44, 0x86, 0xab, 0xaf, 0x75, 0xed, 0x64, 0xe6, 0xd8, 0x82, 0x3a, 0x81, 0x3a, 0x81, 0x3a, 0x81,
		0x3a, 0x81, 0x3a, 0x81, 0x3a, 0x19, 0x44, 0x9d, 0x68, 0x0d, 0x8b, 0x5f, 0x17, 0x68, 0x77, 0x50,
		0x74, 0xf0, 0xc4, 0x0f, 0x8a, 0x0e, 0x4c, 0x44, 0x78, 0x2b, 0x62, 0xa2, 0xe8, 0xc0, 0xf4, 0x18,
		0x72, 0xd7, 0x74, 0x50, 0x74, 0x90, 0xbb, 0xe9, 0x10, 0x1c, 0x6e, 0xcf, 0xda, 0x7c, 0x50, 0x6f,
		0xf0, 0x4b, 0x1f, 0x24, 0xc7, 0xc8, 0xbb, 0x5f, 0x2b, 0x09, 0x09, 0x17, 0x18, 0xcc, 0x84, 0x43,
		0x5a, 0xec, 0x57, 0xc4, 0x42, 0x5a, 0xec, 0x25, 0x04, 0x11, 0x69, 0xb1, 0x17, 0x18, 0x04, 0xd2,
		0x62, 0x39, 0x0b, 0x8a, 0xb4, 0x18, 0x7f, 0x4a, 0xc3, 0xa4, 0x0d, 0xe7, 0x1d, 0xe1, 0x84, 0x58,
		0x15, 0x09, 0xb1, 0x27, 0x7e, 0x90, 0x10, 0x2b, 0x14, 0xab, 0x47, 0x42, 0xcc, 0xd4, 0xe8, 0x71,
		0xd7, 0x74, 0x90, 0x10, 0xcb, 0xdd, 0x74, 0xb6, 0xaa, 0x48, 0x87, 0x19, 0x0a, 0x04, 0xe9, 0x4a,
		0x85, 0x74, 0x18, 0x65, 0x49, 0xa8, 0x8c, 0xf1, 0x21, 0x32, 0x5d, 0x7f, 0x45, 0x2e, 0x1e, 0xd3,
		0xf6, 0xef, 0x8f, 0x5e, 0x2f, 0xdd, 0x9b, 0x58, 0xab, 0x73, 0x1c, 0x3f, 0x3d, 0xbd, 0x27, 0xa0,
		0xf3, 0xa4, 0x12, 0xd0, 0x04, 0x13, 0xcf, 0xc4, 0x90, 0x15, 0xc6, 0x35, 0x3e, 0x45, 0x8d, 0x30,
		0xae, 0xf1, 0x29, 0x8a, 0x8e, 0x71, 0x8d, 0x2f, 0x85, 0x0e, 0x18, 0xd7, 0xc8, 0x07, 0xe7, 0x91,
		0x4b, 0x10, 0x67, 0x5e, 0xcb, 0x17, 0xee, 0x38, 0x12, 0x63, 0x4a, 0x3e, 0x6b, 0xd9, 0x55, 0x46,
		0x68, 0x32, 0x93, 0xd5, 0x5d, 0x40, 0xe1, 0xb7, 0x6f, 0xe7, 0xa0, 0xb2, 0x34, 0x03, 0x0d, 0x00,
		0x96, 0x04, 0x24, 0xd0, 0x3d, 0x0e, 0xfd, 0x77, 0x71, 0x45, 0x03, 0x44, 0x5a, 0x2d, 0x2f, 0x4e,
		0x6a, 0x49, 0x42, 0x64, 0x3a, 0xfb, 0xa1, 0x17, 0x34, 0x7c, 0x31, 0x8b, 0x50, 0x31, 0x0d, 0x00,
		0x69, 0x1d, 0xba, 0x97, 0xb7, 0x24, 0x2a, 0xbf, 0xab, 0x54, 0x76, 0x76, 0x2b, 0x95, 0xcd, 0xdd,
		0xed, 0xdd, 0xcd, 0xbd, 0x6a, 0xb5, 0xbc, 0x53, 0x26, 0x90, 0x26, 0xb4, 0x3a, 0xd1, 0x48, 0x44,
		0x62, 0xb4, 0x3f, 0x53, 0xaa, 0x60, 0xea, 0xfb, 0x85, 0xb6, 0x2d, 0x62, 0xe9, 0x11, 0x43, 0xd2,
		0x22, 0x14, 0x76, 0xb3, 0xc4, 0x49, 0x34, 0x1d, 0x26, 0xc1, 0x02, 0x84, 0xb4, 0xe7, 0x8f, 0xa6,
		0xb9, 0x78, 0x32, 0x4e, 0x77, 0xf1, 0x3c, 0x9c, 0x4e, 0xfa, 0x3c, 0x9c, 0x5a, 0x24, 0x5c, 0xa7,
		0x15, 0x8f, 0x4e, 0x9c, 0x56, 0xec, 0xce, 0xb0, 0xd4, 0xec, 0x6f, 0xa7, 0x1d, 0xc7, 0x6e, 0x63,
		0x71, 0xe3, 0xb3, 0x7f, 0xcf, 0xfe, 0x43, 0x67, 0xdc, 0x5f, 0xdc, 0x24, 0xb6, 0x93, 0x9a, 0xef,
		0x28, 0xb0, 0x9d, 0xf4, 0x45, 0x8e, 0xa1, 0x30, 0x8b, 0x4a, 0x5f, 0x19, 0x6c, 0x0b, 0xba, 0x6d,
		0x80, 0x87, 0xee, 0x6b, 0x88, 0x79, 0x32, 0x62, 0x9c, 0x5a, 0x8b, 0x55, 0x67, 0x37, 0x0a, 0x6d,
		0xc6, 0x0a, 0x27, 0xee, 0xbf, 0xa6, 0x22, 0x55, 0x0a, 0xd5, 0xf6, 0x72, 0x93, 0x2b, 0xbe, 0x91,
		0x41, 0xb1, 0xb7, 0xd0, 0xb3, 0x10, 0x4a, 0xdb, 0x49, 0x82, 0xce, 0x13, 0x03, 0x12, 0x27, 0x03,
		0xba, 0x4f, 0x00, 0xc8, 0x64, 0xfa, 0xc9, 0x64, 0xf4, 0xa9, 0x64, 0xee, 0xcd, 0x46, 0x45, 0xba,
		0x16, 0x24, 0xa5, 0xcb, 0x85, 0x82, 0x91, 0x18, 0xd9, 0xbe, 0x17, 0x7c, 0xd7, 0xbf, 0x9e, 0xfe,
		0xae, 0x38, 0xd8, 0x4d, 0xaf, 0x45, 0x00, 0xec, 0xa6, 0xa7, 0x15, 0x94, 0xc8, 0x05, 0x27, 0x72,
		0x41, 0x8a, 0x5a, 0xb0, 0x2a, 0x66, 0x7a, 0x4b, 0xfb, 0x6e, 0x7a, 0x1a, 0x2b, 0x76, 0x49, 0xad,
		0xd6, 0xc5, 0x1e, 0x7a, 0x7a, 0xc1, 0x8d, 0x64, 0x90, 0xa3, 0x16, 0xec, 0xc8, 0x06, 0x3d, 0xb2,
		0xc1, 0x8f, 0x6a, 0x10, 0xd4, 0x1b, 0x0c, 0x35, 0x07, 0x45, 0x32, 0xc1, 0x31, 0x13, 0x64, 0xc6,
		0xac, 0xec, 0x91, 0x9b, 0xb8, 0xf4, 0x4a, 0x9b, 0x6f, 0x44, 0x43, 0x81, 0x33, 0xe5, 0x20, 0x4a,
		0x31, 0x98, 0x92, 0x0e, 0xaa, 0x54, 0x83, 0x2b, 0xf9, 0x20, 0x4b, 0x3e, 0xd8, 0x52, 0x0f, 0xba,
		0x34, 0x82, 0x2f, 0x91, 0x20, 0x9c, 0xbd, 0x2c, 0xba, 0x05, 0xce, 0xd3, 0xc0, 0x0b, 0x03, 0x8a,
		0xe5, 0xcd, 0x7b, 0x84, 0x64, 0x5a, 0xbc, 0x3e, 0x5a, 0x93, 0x2e, 0x08, 0x8f, 0x53, 0x19, 0x85,
		0x49, 0x22, 0x46, 0xf6, 0xbf, 0xa6, 0xee, 0x08, 0x7b, 0x59, 0x9e, 0x88, 0x70, 0xb0, 0x97, 0xe5,
		0xe6, 0x07, 0xb1, 0xe3, 0x84, 0x45, 0x78, 0x63, 0xe0, 0x91, 0xb0, 0x67, 0xfd, 0x19, 0xa2, 0x61,
		0xc2, 0xd3, 0x33, 0x1f, 0x1c, 0x26, 0x3c, 0xe5, 0x27, 0x26, 0x26, 0x3c, 0x99, 0x1e, 0x36, 0xee,
		0x9a, 0x0e, 0x26, 0x3c, 0xe5, 0x6e, 0x3a, 0xd8, 0xb3, 0x6e, 0x6a, 0x7e, 0x83, 0xbe, 0x54, 0x18,
		0xf4, 0x44, 0xf9, 0xb9, 0x60, 0xec, 0x4e, 0x76, 0x42, 0xe5, 0x8d, 0x88, 0x9e, 0x4f, 0x79, 0x23,
		0x9c, 0x4e, 0x3d, 0x28, 0x0e, 0x4e, 0xa7, 0x9e, 0xa0, 0x4a, 0x38, 0x9d, 0x7a, 0x8a, 0xa2, 0xe3,
		0x74, 0xea, 0x85, 0x02, 0xe2, 0x74, 0x8a, 0x0f, 0x0f, 0x23, 0x7c, 0x3a, 0x45, 0xf3, 0x20, 0x81,
		0xe2, 0x01, 0x02, 0xd9, 0x83, 0x83, 0x82, 0x1e, 0x18, 0x00, 0xdf, 0x13, 0xc3, 0xf7, 0x09, 0x25,
		0x27, 0x77, 0x17, 0xe1, 0xa7, 0xa2, 0x01, 0xe3, 0x03, 0xe3, 0x03, 0xe3, 0x03, 0xe3, 0x03, 0xe3,
		0x03, 0xe3, 0x17, 0x0a, 0xe3, 0x7b, 0x23, 0x11, 0x24, 0x5e, 0x72, 0x45, 0x74, 0xcc, 0x26, 0xa1,
		0x33, 0x13, 0xab, 0xb9, 0x78, 0x54, 0xfb, 0x6e, 0x2c, 0xe8, 0x6e, 0xaa, 0xec, 0xf4, 0xbb, 0x1f,
		0x3e, 0x6f, 0x39, 0xbd, 0xce, 0xd1, 0xa0, 0xd1, 0x73, 0x5a, 0xcd, 0xf6, 0xef, 0xce, 0xe0, 0x4b,
		0xb7, 0x41, 0xcd, 0xbf, 0xa6, 0xa7, 0x63, 0x31, 0xc9, 0xf2, 0x06, 0xa2, 0xeb, 0x0d, 0x97, 0x2f,
		0xb8, 0xdb, 0x69, 0xb6, 0x07, 0xce, 0xa0, 0xe3, 0xcc, 0xbf, 0x98, 0xbd, 0x61, 0x82, 0x2b, 0xf9,
		0x7e, 0xc3, 0x6b, 0x7d, 0xda, 0x6b, 0x1d, 0xf4, 0x6a, 0xed, 0x7e, 0x73, 0xe0, 0xb4, 0x1b, 0x83,
		0x3f, 0x3a, 0xbd, 0xdf, 0xf1, 0x5e, 0x0d, 0x79, 0xaf, 0x9f, 0x9b, 0xbd, 0xc1, 0x51, 0xad, 0x85,
		0xf7, 0x69, 0xc8, 0xfb, 0xec, 0x0f, 0x8e, 0xf6, 0xa9, 0x1b, 0x29, 0x29, 0x89, 0x8e, 0xc1, 0x49,
		0x88, 0x49, 0x71, 0x8d, 0xb9, 0xcd, 0x98, 0xdb, 0xfc, 0xd3, 0x11, 0x95, 0x37, 0x23, 0x00, 0x4b,
		0x77, 0x66, 0x34, 0x51, 0x58, 0x5a, 0xa5, 0x71, 0x7c, 0xb1, 0xc6, 0xa1, 0x44, 0x89, 0x7f, 0x11,
		0xd3, 0x99, 0x75, 0x92, 0x4a, 0x83, 0x51, 0x27, 0x18, 0x75, 0xf2, 0x88, 0x9e, 0x60, 0xd4, 0xc9,
		0xcf, 0x14, 0x18, 0xa3, 0x4e, 0x9e, 0x1a, 0xba, 0x31, 0xea, 0x84, 0x1e, 0x9e, 0x22, 0x33, 0xea,
		0x24, 0xf1, 0x2f, 0x08, 0xee, 0x6f, 0xf4, 0x2f, 0x88, 0x1d, 0x2e, 0x97, 0x71, 0xb8, 0x4c, 0x3e,
		0x80, 0x92, 0x0e, 0xa4, 0x54, 0x03, 0x2a, 0xf9, 0xc0, 0x4a, 0x3e, 0xc0, 0x52, 0x0f, 0xb4, 0xc4,
		0x12, 0x39, 0x44, 0xfc, 0x16, 0x95, 0x00, 0x9c, 0x09, 0xe4, 0x8e, 0xfe, 0xcf, 0x1d, 0x8a, 0x60,
		0x78, 0x65, 0xc7, 0x84, 0xfa, 0x3a, 0x56, 0x7c, 0xea, 0x5d, 0x31, 0x89, 0x59, 0x20, 0xad, 0x60,
		0x4d, 0x36, 0x68, 0x53, 0x0e, 0xde, 0x2c, 0x82, 0x38, 0xf5, 0x60, 0xce, 0x26, 0xa8, 0xb3, 0x09,
		0xee, 0x5c, 0x82, 0x3c, 0xad, 0x60, 0x4f, 0x2c, 0xe8, 0x93, 0x0d, 0xfe, 0x99, 0x60, 0x34, 0xa6,
		0x73, 0x3f, 0xea, 0x93, 0x29, 0x4c, 0xed, 0x66, 0x06, 0x02, 0xc8, 0x83, 0x01, 0x0e, 0xa0, 0x80,
		0x15, 0x38, 0xe0, 0x02, 0x12, 0xd8, 0x81, 0x05, 0x76, 0xa0, 0x81, 0x1b, 0x78, 0xa0, 0x09, 0x22,
		0x88, 0x82, 0x09, 0xf2, 0xa0, 0x22, 0x13, 0xf0, 0xc4, 0x1d, 0x7e, 0x9f, 0x4e, 0xe8, 0xfb, 0xa1,
		0xa5, 0x73, 0x5f, 0xc8, 0x4b, 0xdc, 0xa6, 0xeb, 0x62, 0xec, 0x4e, 0xfd, 0xd4, 0xa4, 0xc7, 0xae,
		0x1f, 0x0b, 0xea, 0xf2, 0x32, 0x19, 0x04, 0x45, 0x1d, 0x26, 0x71, 0x82, 0x4b, 0x2c, 0x61, 0x13,
		0x37, 0xf8, 0xc4, 0x16, 0x46, 0xb1, 0x85, 0x53, 0x5c, 0x61, 0x15, 0x6d, 0x78, 0x45, 0x1c, 0x66,
		0x65, 0x2f, 0x9d, 0x5c, 0x77, 0xe0, 0xe3, 0x78, 0x26, 0x0c, 0x7d, 0xe1, 0x06, 0x1c, 0x7c, 0xee,
		0x32, 0x87, 0x52, 0x7e, 0x05, 0x03, 0x32, 0xcc, 0x78, 0xac, 0xd3, 0x28, 0xe4, 0xc4, 0x02, 0xe6,
		0xe2, 0x82, 0x04, 0x80, 0x04, 0x80, 0x04, 0x80, 0x04, 0x80, 0x04, 0x80, 0x04, 0x80, 0x04, 0x00,
		0xc7, 0x80, 0x04, 0x80, 0x04, 0x80, 0x04, 0x3c, 0xff, 0xdd, 0x9e, 0x4f, 0xfd, 0xc4, 0xb3, 0x93,
		0x70, 0x12, 0xfa, 0xe1, 0xe9, 0x95, 0x3d, 0x1f, 0x68, 0x33, 0xf6, 0x44, 0xc4, 0x87, 0x18, 0xac,
		0xbf, 0x05, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f,
		0x80, 0xef, 0x3b, 0x2b, 0xf5, 0xde, 0x31, 0x82, 0xde, 0x55, 0x06, 0xa2, 0xd2, 0xde, 0xb8, 0x77,
		0xff, 0xc3, 0x23, 0x82, 0x6d, 0x70, 0xd9, 0xc8, 0xc7, 0x14, 0xdb, 0xae, 0x88, 0xcd, 0x64, 0x63,
		0xdf, 0x8a, 0xdc, 0x8c, 0xb6, 0x8f, 0x31, 0x8b, 0x6e, 0x77, 0x4d, 0xd1, 0xbd, 0x84, 0x29, 0x2a,
		0x36, 0xc5, 0xad, 0x6a, 0x15, 0xc6, 0x08, 0x20, 0xcc, 0x4b, 0xca, 0x63, 0xa4, 0x4a, 0x4d, 0x0b,
		0x06, 0x56, 0xec, 0x8d, 0x68, 0x6d, 0xe2, 0x78, 0x94, 0xe6, 0x64, 0x12, 0x23, 0x11, 0x9a, 0x87,
		0x98, 0x48, 0x84, 0x4a, 0xd4, 0x55, 0x24, 0x42, 0x65, 0x1a, 0x18, 0x12, 0xa1, 0x8a, 0x05, 0x47,
		0x22, 0xb4, 0x78, 0x54, 0x91, 0x61, 0x22, 0x34, 0x8e, 0x6c, 0x26, 0x20, 0xe1, 0x36, 0x50, 0x28,
		0x57, 0x18, 0xc8, 0xda, 0x08, 0xa6, 0xe7, 0x33, 0x65, 0xb8, 0x06, 0x15, 0x30, 0x92, 0x0a, 0x5c,
		0x2c, 0xf2, 0x13, 0x8c, 0xb8, 0xc0, 0x5c, 0x64, 0x90, 0x01, 0x90, 0x01, 0x90, 0x01, 0x90, 0x01,
		0x90, 0x01, 0x90, 0x01, 0x90, 0x01, 0x90, 0x81, 0x3b, 0x55, 0x11, 0xdb, 0x5b, 0x8c, 0x78, 0xc0,
		0x2e, 0xca, 0x22, 0x72, 0xfe, 0xa0, 0x2c, 0x02, 0xe0, 0xf6, 0x01, 0xb1, 0x51, 0x16, 0x81, 0xf0,
		0xf6, 0x33, 0x53, 0x44, 0x59, 0x84, 0x72, 0x53, 0xac, 0x6c, 0xed, 0x55, 0xf6, 0x76, 0x76, 0xb7,
		0xf6, 0x50, 0x1d, 0x01, 0x40, 0xcc, 0x4c, 0x4a, 0x54, 0x47, 0x18, 0x17, 0x13, 0xac, 0x1f, 0xc2,
		0x3b, 0x3d, 0x4b, 0xf8, 0xe4, 0x43, 0x17, 0xf2, 0x22, 0x19, 0x9a, 0x87, 0x98, 0x48, 0x86, 0x4a,
		0xd4, 0x54, 0x24, 0x43, 0x65, 0x1a, 0x18, 0x92, 0xa1, 0x8a, 0x05, 0x47, 0x32, 0xb4, 0x78, 0x6c,
		0x11, 0x2d, 0x62, 0xd2, 0x21, 0x02, 0x5a, 0xc4, 0xf2, 0xfe, 0x20, 0x17, 0x0a, 0x6c, 0xfb, 0x80,
		0xd8, 0xc8, 0x85, 0x22, 0xba, 0xfd, 0xcc, 0x14, 0x91, 0x0b, 0x55, 0x6e, 0x8a, 0x68, 0x11, 0x03,
		0x10, 0x66, 0x27, 0x25, 0x92, 0xa0, 0x26, 0x49, 0x46, 0x75, 0x19, 0x49, 0x2d, 0x08, 0xc2, 0xc4,
		0x9d, 0xb9, 0x1a, 0xda, 0x3b, 0x49, 0xe2, 0xe1, 0x99, 0x38, 0x77, 0x27, 0x6e, 0x72, 0x36, 0x23,
		0x5f, 0xa5, 0x70, 0x22, 0x82, 0x61, 0x9a, 0x54, 0xb4, 0x03, 0x91, 0xfc, 0x08, 0xa3, 0xef, 0xb6,
		0x17, 0xc4, 0x89, 0x1b, 0x0c, 0x45, 0xe9, 0xfe, 0x37, 0xe2, 0x95, 0xef, 0x94, 0x26, 0x51, 0x98,
		0x84, 0xc3, 0xd0, 0x8f, 0xb3, 0xaf, 0x4a, 0xf3, 0x3c, 0x43, 0xc9, 0x8d, 0x84, 0x1b, 0xa7, 0x7f,
		0x96, 0xfc, 0x78, 0x74, 0x52, 0xf2, 0x63, 0x37, 0xad, 0x7e, 0x8f, 0xb3, 0xaf, 0x66, 0x5f, 0xa4,
		0xff, 0x2a, 0x85, 0x13, 0xf7, 0x5f, 0x53, 0x61, 0xcf, 0xbe, 0x14, 0x97, 0x89, 0x08, 0x46, 0x62,
		0x64, 0xfb, 0x5e, 0xf0, 0xbd, 0x94, 0xf8, 0x17, 0xf1, 0xec, 0x8f, 0xd2, 0x9d, 0x25, 0xa8, 0xa5,
		0xf9, 0x36, 0xb4, 0x57, 0x30, 0x1a, 0x7e, 0x12, 0x51, 0x5b, 0x4c, 0x48, 0xdc, 0x6c, 0x4d, 0x30,
		0x57, 0x8a, 0x6b, 0x64, 0xe3, 0x24, 0x9a, 0x0e, 0x93, 0x60, 0x91, 0x82, 0x6a, 0xcf, 0x9f, 0x53,
		0x73, 0xf1, 0x98, 0x9c, 0xee, 0xe2, 0xe1, 0x38, 0x9d, 0xf4, 0xe1, 0x38, 0xb5, 0x48, 0xb8, 0x4e,
		0x2b, 0x1e, 0x9d, 0x38, 0xad, 0xd8, 0x1d, 0x5c, 0x4d, 0xc4, 0xec, 0x6f, 0xa7, 0x93, 0x3e, 0x86,
		0xd9, 0x57, 0x8d, 0xc5, 0x53, 0x68, 0x79, 0xc1, 0x77, 0x67, 0xe0, 0x5f, 0x38, 0xb5, 0xe5, 0xfd,
		0xf7, 0xbd, 0x11, 0x2d, 0x3f, 0x45, 0xc7, 0x1b, 0x10, 0xf2, 0x04, 0x44, 0xb7, 0x80, 0x92, 0xde,
		0xfe, 0x89, 0xd5, 0xdf, 0x4f, 0x14, 0x0c, 0xab, 0xbf, 0x5f, 0x28, 0x24, 0x56, 0x7f, 0xe7, 0x24,
		0x28, 0x56, 0x7f, 0x03, 0x61, 0xab, 0x7b, 0x89, 0x64, 0x57, 0x7f, 0x93, 0x1e, 0x31, 0x93, 0xb9,
		0x64, 0xc2, 0x1d, 0xe3, 0xc4, 0xb3, 0xd9, 0x58, 0xfc, 0x5d, 0x14, 0x68, 0xc0, 0x05, 0x22, 0xb0,
		0x83, 0x0a, 0xec, 0x20, 0x03, 0x37, 0xe8, 0x40, 0x13, 0x42, 0x10, 0x85, 0x12, 0xd9, 0xcb, 0x25,
		0x5f, 0xe4, 0x94, 0x79, 0xcd, 0xf9, 0x8e, 0x8c, 0xe4, 0x2a, 0x12, 0x63, 0xca, 0x7e, 0x73, 0xc9,
		0xe5, 0x09, 0x9f, 0xee, 0x5a, 0xcd, 0xc5, 0xa3, 0xdc, 0x77, 0x63, 0x46, 0xd3, 0x40, 0x3a, 0xfd,
		0xee, 0x87, 0xcf, 0x5b, 0x4e, 0xe3, 0xcf, 0x41, 0xa3, 0x5d, 0x6f, 0xd4, 0x9d, 0x56, 0xb3, 0xfd,
		0xbb, 0xd3, 0x3f, 0xda, 0x1f, 0xb4, 0x3e, 0x3b, 0x83, 0x2f, 0xdd, 0x06, 0x75, 0xc7, 0x9f, 0x9e,
		0xfc, 0xc7, 0x2c, 0x4a, 0xc9, 0x98, 0x14, 0x42, 0x2f, 0x35, 0xa3, 0x56, 0xff, 0xef, 0xda, 0x41,
		0xa3, 0x7d, 0xf0, 0xc5, 0xe9, 0x37, 0xeb, 0x28, 0xcb, 0x7d, 0xd9, 0xe7, 0x18, 0x91, 0x9d, 0xb9,
		0x54, 0x48, 0xa2, 0xfc, 0x14, 0xce, 0xe2, 0x98, 0x52, 0xc2, 0x31, 0x25, 0xc1, 0x3a, 0x02, 0x9c,
		0xcf, 0x3d, 0xa4, 0x5e, 0xd3, 0xe0, 0x7b, 0x10, 0xfe, 0x08, 0xec, 0xc4, 0xbf, 0xa0, 0x7b, 0x4a,
		0x77, 0x5b, 0x48, 0x9c, 0xd5, 0xfd, 0x8a, 0x58, 0x38, 0xab, 0x7b, 0x81, 0xba, 0xe1, 0xac, 0xee,
		0x25, 0x06, 0x81, 0xb3, 0xba, 0xbc, 0x11, 0x0a, 0xce, 0xea, 0xf8, 0xc3, 0x4c, 0xb2, 0x67, 0x75,
		0x34, 0x0b, 0x74, 0x56, 0x7c, 0x32, 0xc5, 0x42, 0x1d, 0xe2, 0x20, 0x80, 0x3c, 0x18, 0xe0, 0x00,
		0x0a, 0x58, 0x81, 0x03, 0x2e, 0x20, 0x81, 0x1d, 0x58, 0x60, 0x07, 0x1a, 0xb8, 0x81, 0x07, 0x9a,
		0x20, 0x82, 0x28, 0x98, 0x20, 0x0f, 0x2a, 0x32, 0x01, 0x7d, 0x11, 0x9c, 0xa6, 0x89, 0x2b, 0x26,
		0x67, 0x4a, 0x0b, 0x79, 0x31, 0x51, 0xa9, 0x08, 0xb0, 0x83, 0x13, 0xfc, 0x60, 0x09, 0x43, 0xb8,
		0xc1, 0x11, 0xb6, 0xb0, 0x84, 0x2d, 0x3c, 0xe1, 0x0a, 0x53, 0x68, 0xc3, 0x15, 0xe2, 0xb0, 0x25,
		0x7b, 0xe9, 0x3c, 0x27, 0x2a, 0x95, 0x77, 0x18, 0x8d, 0x54, 0xda, 0xc1, 0x48, 0xa5, 0x9c, 0x3f,
		0x18, 0xa9, 0x04, 0x70, 0xfb, 0x80, 0xd8, 0x18, 0xa9, 0x84, 0xf0, 0xf6, 0x33, 0x53, 0xc4, 0x48,
		0x25, 0xe5, 0xa6, 0xb8, 0x53, 0xad, 0x6e, 0x63, 0xa8, 0x12, 0xb0, 0x30, 0x33, 0x29, 0x31, 0x54,
		0xc9, 0xb8, 0x70, 0x60, 0xf1, 0xda, 0xb9, 0x8f, 0x7d, 0xfb, 0xb9, 0x89, 0x89, 0x1c, 0xa8, 0x44,
		0x3d, 0x45, 0x0e, 0x54, 0xa6, 0x81, 0x21, 0x07, 0xaa, 0x58, 0x70, 0xe4, 0x40, 0x8b, 0x47, 0x12,
		0x91, 0x03, 0x95, 0x8f, 0x11, 0x90, 0x03, 0xcd, 0xfb, 0x83, 0x1c, 0x28, 0xc0, 0xed, 0x03, 0x62,
		0x23, 0x07, 0x8a, 0xf0, 0xf6, 0x33, 0x53, 0x44, 0x0e, 0x54, 0xb9, 0x29, 0x22, 0x07, 0x0a, 0x2c,
		0xcc, 0x50, 0x4a, 0xe4, 0x40, 0x8d, 0x0b, 0x07, 0xd6, 0xc5, 0xc2, 0x25, 0x31, 0x49, 0x82, 0xce,
		0xc5, 0x45, 0x16, 0x34, 0x0f, 0x31, 0x91, 0x05, 0x95, 0xa8, 0xa8, 0xc8, 0x82, 0xca, 0x34, 0x30,
		0x64, 0x41, 0x15, 0x0b, 0x8e, 0x2c, 0x68, 0xf1, 0x68, 0x22, 0xc3, 0x2c, 0xe8, 0x89, 0x17, 0xb8,
		0xd1, 0x15, 0xa3, 0x2c, 0xe8, 0x1e, 0x20, 0xb5, 0x41, 0x92, 0x61, 0x57, 0xd3, 0xcb, 0xe4, 0xe4,
		0x39, 0x55, 0xe9, 0xd6, 0x1c, 0x1c, 0x6c, 0x6a, 0xe2, 0x2b, 0x11, 0x46, 0xa0, 0x15, 0xcc, 0x58,
		0x0b, 0xb8, 0xa7, 0xe9, 0x68, 0x7e, 0xf7, 0x03, 0xff, 0x02, 0x53, 0xe0, 0x28, 0x4b, 0x42, 0xc4,
		0x17, 0x59, 0x2d, 0x2f, 0x4e, 0x6a, 0x49, 0x42, 0xab, 0x9f, 0xdd, 0x3a, 0xf4, 0x82, 0x86, 0x2f,
		0x66, 0x74, 0x34, 0xa6, 0x95, 0xbd, 0xb2, 0x0e, 0xdd, 0xcb, 0x5b, 0x92, 0x95, 0xdf, 0x55, 0x2a,
		0x3b, 0xbb, 0x95, 0xca, 0xe6, 0xee, 0xf6, 0xee, 0xe6, 0x5e, 0xb5, 0x5a, 0xde, 0xa1, 0x34, 0x70,
		0xda, 0xea, 0x44, 0x23, 0x11, 0x89, 0xd1, 0xfe, 0x95, 0xf5, 0x7e, 0x23, 0x98, 0xfa, 0x3e, 0x34,
		0x9f, 0x7e, 0xf4, 0xe5, 0x19, 0x75, 0x2d, 0x52, 0xab, 0xef, 0x64, 0x46, 0x58, 0x1a, 0x61, 0x55,
		0x7f, 0x10, 0xd3, 0x2b, 0x81, 0x66, 0x27, 0x42, 0xcd, 0x79, 0xf0, 0x73, 0x1a, 0x7a, 0xcd, 0x48,
		0x9f, 0xf2, 0xea, 0xb9, 0xb2, 0x26, 0x73, 0xa1, 0x62, 0x26, 0xac, 0xcc, 0x43, 0x63, 0x28, 0x95,
		0x18, 0x3a, 0xf5, 0xd8, 0xbb, 0x7a, 0x6b, 0xd3, 0x60, 0x69, 0x56, 0xa6, 0x3e, 0x13, 0xbd, 0xc7,
		0xe8, 0xd9, 0x21, 0xcd, 0x7d, 0x81, 0x34, 0x79, 0x1f, 0xbd, 0xe3, 0x41, 0xb5, 0x57, 0x5f, 0x50,
		0xa8, 0xaa, 0x20, 0x55, 0x2d, 0x41, 0xa5, 0x0a, 0x82, 0x5c, 0x75, 0x03, 0xb9, 0xaa, 0x05, 0x6a,
		0xd5, 0x08, 0xc5, 0x42, 0x6d, 0xba, 0xc7, 0x5b, 0x12, 0x99, 0x8d, 0x4d, 0x6a, 0x06, 0x36, 0x91,
		0x59, 0xd7, 0x64, 0x4a, 0x0a, 0x29, 0x95, 0x0c, 0x92, 0x2c, 0x09, 0xa4, 0x56, 0xf2, 0x47, 0xb6,
		0xa4, 0x8f, 0x6c, 0xc9, 0x1e, 0xd5, 0x92, 0xbc, 0x62, 0x67, 0xfe, 0xa8, 0xcc, 0x7e, 0xb6, 0xdc,
		0xd1, 0x28, 0x12, 0x71, 0x6c, 0x8f, 0xdd, 0x73, 0xcf, 0xbf, 0xa2, 0x63, 0xe7, 0x4b, 0x67, 0x78,
		0x4f, 0x3e, 0x22, 0x36, 0x45, 0xab, 0x72, 0x9f, 0x5c, 0x85, 0x3e, 0xc5, 0x4a, 0x7c, 0xd2, 0x15,
		0xf7, 0x54, 0x2b, 0xeb, 0xc9, 0x57, 0xd0, 0x93, 0xaf, 0x94, 0xa7, 0x5e, 0x11, 0x8f, 0x3a, 0x96,
		0xdb, 0x2f, 0x8b, 0x5c, 0x25, 0xfb, 0x4d, 0x32, 0x34, 0x98, 0x9e, 0x8b, 0x68, 0x7e, 0x08, 0x42,
		0xc8, 0x6f, 0x2d, 0xf9, 0x64, 0x85, 0x90, 0x4c, 0x8d, 0x60, 0x7a, 0x3e, 0x7b, 0x89, 0xd7, 0x38,
		0x63, 0xa7, 0x62, 0x5c, 0x96, 0x9b, 0x24, 0xee, 0xf0, 0x4c, 0x8c, 0x08, 0x02, 0xcc, 0xa5, 0x64,
		0x44, 0x5c, 0x50, 0x5d, 0x8c, 0xdd, 0xa9, 0x9f, 0x86, 0x8b, 0xb1, 0xeb, 0xc7, 0x02, 0x90, 0x17,
		0x90, 0x17, 0x90, 0x17, 0x90, 0x17, 0x90, 0x17, 0x90, 0xb7, 0x58, 0x90, 0xf7, 0x24, 0x0c, 0x7d,
		0xe1, 0x92, 0x84, 0xbb, 0x65, 0x40, 0x4b, 0x32, 0xd0, 0x32, 0x08, 0x47, 0x82, 0x1e, 0xac, 0x4c,
		0xa5, 0x02, 0xa4, 0x04, 0xa4, 0x04, 0xa4, 0x04, 0xa4, 0x04, 0xa4, 0x04, 0xa4, 0x04, 0xa4, 0x04,
		0xa4, 0x04, 0xa4, 0xe4, 0x01, 0x29, 0x27, 0xb4, 0x02, 0x6f, 0xa6, 0xbe, 0xb4, 0x2a, 0x5e, 0x00,
		0xdf, 0x00, 0xdf, 0x00, 0xdf, 0x00, 0xdf, 0x00, 0xdf, 0x00, 0xdf, 0xd4, 0x78, 0x2d, 0x6f, 0x72,
		0x51, 0xb1, 0x97, 0x15, 0x61, 0x41, 0x68, 0xff, 0x3b, 0x0c, 0x04, 0x45, 0x2c, 0xf7, 0x8e, 0x90,
		0x4c, 0x5d, 0x37, 0x49, 0x44, 0x14, 0x90, 0xdb, 0x4e, 0x61, 0xbd, 0x7e, 0xfd, 0x75, 0xd3, 0xde,
		0x3b, 0xfe, 0xfb, 0x6b, 0xd9, 0xde, 0x3b, 0x9e, 0x7f, 0x59, 0x4e, 0xff, 0x9a, 0x7f, 0xbd, 0xf5,
		0x75, 0xd3, 0xae, 0x2c, 0xbf, 0xae, 0x7e, 0xdd, 0xb4, 0xab, 0xc7, 0x6f, 0xbe, 0x7d, 0x7b, 0xfb,
		0xe6, 0xaf, 0xed, 0xeb, 0xa7, 0xff, 0xe0, 0xeb, 0xff, 0xfc, 0xfa, 0xed, 0xdb, 0xe4, 0xaf, 0xf6,
		0xf5, 0xec, 0xcf, 0xd6, 0xf5, 0xf1, 0x7f, 0xbd, 0xf9, 0x27, 0x35, 0x1f, 0x3e, 0x13, 0xf8, 0xdb,
		0xb7, 0xb7, 0xc7, 0xff, 0xa0, 0xe3, 0x16, 0x8f, 0x41, 0x49, 0x88, 0x51, 0x12, 0xdb, 0x17, 0xc1,
		0x69, 0xda, 0x7e, 0x4c, 0x92, 0x99, 0x2c, 0xc5, 0x03, 0x41, 0x01, 0x41, 0x01, 0x41, 0x01, 0x41,
		0x01, 0x41, 0x01, 0x41, 0x29, 0x14, 0x41, 0x99, 0x7a, 0x41, 0xf2, 0x8e, 0x20, 0x23, 0xa1, 0x34,
		0x4e, 0x8e, 0xe6, 0xb2, 0x3c, 0x82, 0x83, 0x53, 0x29, 0x2f, 0xbf, 0x23, 0xbe, 0xbb, 0x84, 0xfa,
		0x32, 0x3b, 0x0e, 0x5b, 0xb2, 0x08, 0x0e, 0x29, 0x27, 0xbd, 0x84, 0x8e, 0x8b, 0x49, 0x6c, 0x6f,
		0xc1, 0x26, 0x78, 0xe3, 0x30, 0x7a, 0xd2, 0x20, 0x53, 0x44, 0xc6, 0x67, 0x5a, 0x51, 0x38, 0x4d,
		0x44, 0x3a, 0x25, 0x8e, 0x5e, 0x9a, 0xe8, 0x96, 0x6c, 0xc8, 0x11, 0x3d, 0x24, 0x0e, 0x72, 0x44,
		0x4f, 0xd0, 0x26, 0xe4, 0x88, 0x9e, 0xa2, 0xe8, 0xc8, 0x11, 0xbd, 0x50, 0x40, 0xe4, 0x88, 0xf8,
		0xb0, 0x06, 0x74, 0x72, 0x3f, 0x33, 0x10, 0xa2, 0x93, 0x9b, 0x32, 0xbc, 0xc4, 0xb4, 0x74, 0x4c,
		0x4b, 0x7f, 0xf2, 0x38, 0xe8, 0x79, 0xb8, 0xa7, 0xb0, 0x72, 0x4c, 0xe3, 0xc0, 0x74, 0x8d, 0xf3,
		0x62, 0xd3, 0x41, 0xf5, 0x64, 0xc6, 0x50, 0xa6, 0xd2, 0x60, 0x0a, 0x25, 0xa6, 0x50, 0x32, 0x22,
		0x57, 0x98, 0x42, 0xc9, 0x9d, 0x44, 0x61, 0x0a, 0x25, 0x45, 0x44, 0x45, 0x66, 0x0a, 0x65, 0xe2,
		0x5f, 0xd0, 0x4b, 0x56, 0xd2, 0x59, 0x48, 0x45, 0x24, 0x60, 0x92, 0x0b, 0x9c, 0x14, 0x03, 0x28,
		0xe9, 0x40, 0x4a, 0x35, 0xa0, 0x92, 0x0f, 0xac, 0xe4, 0x03, 0x2c, 0xf5, 0x40, 0x4b, 0x27, 0x89,
		0xb2, 0x41, 0x28, 0x4b, 0x49, 0x25, 0x00, 0x67, 0x02, 0xdd, 0x4b, 0x1a, 0xd8, 0xd1, 0xa2, 0x58,
		0x8b, 0x98, 0x9b, 0x58, 0xb3, 0x22, 0x68, 0x21, 0x2e, 0x31, 0x8b, 0xa4, 0x15, 0xbc, 0xc9, 0x06,
		0x71, 0xca, 0xc1, 0x9c, 0x45, 0x50, 0xa7, 0x1e, 0xdc, 0xd9, 0x04, 0x79, 0x36, 0xc1, 0x9e, 0x4b,
		0xd0, 0xa7, 0x15, 0xfc, 0x89, 0x81, 0x00, 0xb2, 0x60, 0x20, 0x13, 0x8c, 0xc6, 0x22, 0xa5, 0x47,
		0x7d, 0x32, 0x85, 0x05, 0x4b, 0xcc, 0x40, 0x00, 0x79, 0x30, 0xc0, 0x01, 0x14, 0xb0, 0x02, 0x07,
		0x5c, 0x40, 0x02, 0x3b, 0xb0, 0xc0, 0x0e, 0x34, 0x70, 0x03, 0x0f, 0x34, 0x41, 0x04, 0x51, 0x30,
		0x41, 0x1e, 0x54, 0x64, 0x02, 0x12, 0x5d, 0x40, 0xf5, 0xa8, 0x93, 0x27, 0xb9, 0x98, 0xea, 0x31,
		0xf8, 0xb1, 0x49, 0x5c, 0x4c, 0xea, 0x30, 0x84, 0x13, 0x1c, 0x61, 0x09, 0x4b, 0xb8, 0xc1, 0x13,
		0xb6, 0x30, 0x85, 0x2d, 0x5c, 0xe1, 0x0a, 0x5b, 0x68, 0xc3, 0x17, 0xe2, 0x30, 0x26, 0x7b, 0xe9,
		0xe4, 0xca, 0xba, 0x1f, 0xf5, 0xba, 0x34, 0xcb, 0xbd, 0x1f, 0xcd, 0x53, 0x54, 0x18, 0xc8, 0x4a,
		0xab, 0x3c, 0x9c, 0x9f, 0xc1, 0x13, 0x36, 0x76, 0xcb, 0x0b, 0x12, 0x11, 0xd9, 0x6e, 0x24, 0x5c,
		0x3e, 0x94, 0xe0, 0x96, 0xcc, 0xc4, 0xdd, 0x28, 0xd1, 0x8d, 0x10, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0,
		0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0x40, 0x33, 0xa0, 0x2f, 0x24, 0xbc, 0x2e, 0xbd, 0x8d, 0x19, 0x8f,
		0x52, 0x97, 0x32, 0xe8, 0x80, 0x71, 0x74, 0x60, 0xc2, 0x03, 0xb0, 0xd0, 0xdc, 0xd4, 0x01, 0x58,
		0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x54, 0x00, 0x58, 0x4d, 0xc2, 0xeb, 0xa6,
		0x9b, 0x4c, 0xd8, 0xb8, 0x04, 0x8a, 0x8b, 0x4d, 0xd6, 0x07, 0x61, 0xa2, 0x0b, 0x4f, 0xd6, 0x0a,
		0xac, 0x72, 0x11, 0x4a, 0x69, 0x71, 0xb1, 0x37, 0x7f, 0xbf, 0xfe, 0x5a, 0xb6, 0xb7, 0x8e, 0x97,
		0xff, 0xd8, 0xfe, 0xba, 0x69, 0x6f, 0x1d, 0xbf, 0x79, 0x43, 0xdf, 0x53, 0x1e, 0x83, 0xdd, 0x19,
		0xca, 0xee, 0xa8, 0x2d, 0x37, 0xf9, 0x45, 0x92, 0x47, 0x6b, 0xe9, 0x09, 0xb8, 0x1e, 0xb8, 0x1e,
		0xb8, 0x1e, 0xb8, 0x1e, 0xb8, 0x1e, 0x30, 0x02, 0xb8, 0x1e, 0x09, 0xaf, 0x4b, 0x6d, 0x29, 0xcc,
		0x63, 0x10, 0xa1, 0xca, 0x40, 0x54, 0x9a, 0x4b, 0x64, 0xd6, 0x7d, 0x78, 0x44, 0xb0, 0x0d, 0xea,
		0x4b, 0x67, 0x98, 0x63, 0xdb, 0x15, 0xb1, 0x89, 0x2f, 0xa9, 0x59, 0x2b, 0x37, 0x83, 0x45, 0x1d,
		0x4c, 0xa3, 0xdb, 0x5d, 0x53, 0x74, 0x2f, 0x61, 0x8a, 0x8a, 0x4d, 0x91, 0xea, 0x72, 0x1c, 0x23,
		0x6d, 0xf1, 0x15, 0xa4, 0xcc, 0xe3, 0x83, 0x8c, 0xa8, 0x71, 0xb1, 0xc0, 0x4a, 0x07, 0x59, 0xd9,
		0xb1, 0xf7, 0x6f, 0xc1, 0x27, 0x1d, 0x7a, 0x4b, 0x66, 0xe4, 0x42, 0xf3, 0x10, 0x13, 0xb9, 0x50,
		0x89, 0xda, 0x8a, 0x5c, 0xa8, 0x4c, 0x03, 0x43, 0x2e, 0x54, 0xb1, 0xe0, 0xc8, 0x85, 0x16, 0x8f,
		0x2d, 0x32, 0xcd, 0x85, 0x96, 0x77, 0x18, 0x25, 0x43, 0x77, 0x90, 0x0c, 0xcd, 0xf9, 0x83, 0x64,
		0x28, 0xc0, 0xed, 0x03, 0x62, 0x23, 0x19, 0x8a, 0xf0, 0xf6, 0x33, 0x53, 0x44, 0x32, 0x54, 0xb9,
		0x29, 0xee, 0x54, 0xab, 0xdb, 0x55, 0x98, 0x23, 0xb0, 0x30, 0x2f, 0x29, 0x91, 0x0f, 0x35, 0x49,
		0x32, 0xaa, 0x83, 0x15, 0x89, 0x6d, 0xa3, 0x5c, 0x2b, 0x27, 0xb3, 0x2d, 0x95, 0x89, 0x7f, 0x11,
		0xcf, 0xfe, 0x28, 0x3d, 0xb8, 0xda, 0x81, 0xc2, 0x12, 0x4b, 0x3e, 0xe6, 0x83, 0x71, 0xeb, 0x8c,
		0x0d, 0xd8, 0x2c, 0xc3, 0xa5, 0xb8, 0x26, 0x23, 0x4e, 0xa2, 0xe9, 0x30, 0x09, 0x16, 0x99, 0xa9,
		0xf6, 0xfc, 0x89, 0x35, 0x17, 0x0f, 0xcc, 0xe9, 0x2e, 0x1e, 0x93, 0xd3, 0x49, 0x1f, 0x93, 0x53,
		0x8b, 0x84, 0xeb, 0xb4, 0xe2, 0xd1, 0x89, 0xd3, 0x8a, 0xdd, 0xc1, 0xd5, 0x44, 0xcc, 0xfe, 0x76,
		0x3a, 0xe9, 0x03, 0x99, 0x7d, 0xd5, 0x58, 0xdc, 0xf6, 0xfc, 0x2c, 0xc4, 0x19, 0xf8, 0x17, 0xf7,
		0xbe, 0x35, 0xcf, 0xd2, 0xbc, 0x82, 0x83, 0x20, 0xee, 0x1c, 0x96, 0x6d, 0x1d, 0xb1, 0x37, 0xa2,
		0xbb, 0xf8, 0xe8, 0x96, 0x8c, 0xd8, 0x76, 0xf4, 0x2b, 0x62, 0x61, 0xdb, 0xd1, 0x0b, 0xb4, 0x0d,
		0xdb, 0x8e, 0x5e, 0x62, 0x10, 0xd8, 0x76, 0x94, 0x37, 0x72, 0xc3, 0xb6, 0x23, 0xfe, 0xf0, 0x1b,
		0xdb, 0x8e, 0x5e, 0xe6, 0x93, 0xb1, 0xed, 0xc8, 0x3c, 0x30, 0xc0, 0x01, 0x14, 0xb0, 0x02, 0x07,
		0x5c, 0x40, 0x02, 0x3b, 0xb0, 0xc0, 0x0e, 0x34, 0x70, 0x03, 0x0f, 0x34, 0x41, 0x04, 0x51, 0x30,
		0x41, 0x1e, 0x54, 0x64, 0x02, 0xba, 0xfe, 0x69, 0x18, 0x79, 0xc9, 0xd9, 0x39, 0xa3, 0x45, 0x47,
		0x99, 0xc8, 0xa8, 0xea, 0x2e, 0x02, 0xf8, 0xe0, 0x04, 0x42, 0x58, 0x82, 0x11, 0x6e, 0xa0, 0x84,
		0x2d, 0x38, 0x61, 0x0b, 0x52, 0xb8, 0x82, 0x15, 0xda, 0xa0, 0x85, 0x38, 0x78, 0xc9, 0x5e, 0x3a,
		0x26, 0x5c, 0xc8, 0x86, 0x08, 0x98, 0x70, 0x91, 0xf7, 0x07, 0x45, 0xdd, 0xc0, 0xb6, 0x0f, 0x88,
		0x8d, 0xa2, 0x6e, 0x44, 0xb7, 0x9f, 0x99, 0x22, 0x8a, 0xba, 0x95, 0x9b, 0xe2, 0x56, 0x15, 0x25,
		0xdd, 0x00, 0xc2, 0xcc, 0xa4, 0x44, 0x49, 0xb7, 0x71, 0xc1, 0xc0, 0x12, 0x97, 0x13, 0xdf, 0x1b,
		0x7a, 0x89, 0x1d, 0x4c, 0x7d, 0x9f, 0x4f, 0x3a, 0xf4, 0xae, 0xd8, 0xd8, 0xf3, 0x58, 0xc0, 0xd8,
		0x8a, 0x14, 0xae, 0x4c, 0x03, 0x43, 0x0a, 0x57, 0xa6, 0x81, 0x21, 0x85, 0xab, 0x58, 0x70, 0xa4,
		0x70, 0x8b, 0x47, 0x72, 0xb1, 0xe7, 0x51, 0x01, 0x48, 0xc0, 0x9e, 0x47, 0x03, 0x49, 0xc1, 0xb9,
		0x3b, 0x99, 0x78, 0xc1, 0xa9, 0x1d, 0x8b, 0xe8, 0x42, 0x44, 0x7c, 0x58, 0xc1, 0x3d, 0xb9, 0x41,
		0x0b, 0x40, 0x0b, 0x40, 0x0b, 0x40, 0x0b, 0x40, 0x0b, 0x40, 0x0b, 0x40, 0x0b, 0x80, 0x6c, 0x40,
		0x0b, 0x40, 0x0b, 0x40, 0x0b, 0x5e, 0x40, 0x0b, 0xa6, 0x7e, 0xe2, 0xd9, 0x49, 0x38, 0x09, 0xfd,
		0xf0, 0xf4, 0xca, 0xf6, 0x46, 0x22, 0x48, 0xbc, 0xb1, 0xc7, 0x8a, 0x21, 0xac, 0xbd, 0x05, 0x80,
		0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x94,
		0x55, 0x4b, 0x14, 0x15, 0x65, 0xd5, 0x92, 0x1e, 0x2c, 0xca, 0xaa, 0xd5, 0x89, 0x8d, 0xb2, 0x6a,
		0x44, 0xb7, 0x9f, 0x99, 0x22, 0xca, 0xaa, 0x95, 0x9b, 0x22, 0xca, 0xaa, 0x01, 0x84, 0xd9, 0x49,
		0x89, 0xb2, 0x6a, 0xe3, 0x82, 0x81, 0x15, 0x84, 0xf6, 0xe4, 0x6c, 0xc2, 0x27, 0x2f, 0xba, 0x90,
		0x17, 0x15, 0x13, 0x05, 0x8c, 0xa6, 0x48, 0xda, 0xca, 0xb4, 0x2c, 0x24, 0x6d, 0x65, 0x1a, 0x18,
		0x92, 0xb6, 0x8a, 0x05, 0x47, 0xd2, 0xb6, 0x78, 0xb4, 0x16, 0x15, 0x13, 0x0a, 0x40, 0x02, 0x2a,
		0x26, 0x0c, 0xa4, 0x01, 0xb1, 0x37, 0xb2, 0xe3, 0x61, 0x38, 0x61, 0xb4, 0x3f, 0xfc, 0x46, 0x64,
		0x80, 0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x80, 0xeb,
		0x9b, 0xe1, 0x0b, 0xc1, 0xf4, 0x5c, 0x44, 0xf3, 0xa5, 0x5d, 0x8c, 0x00, 0x76, 0x85, 0x81, 0xac,
		0x8d, 0x60, 0x9a, 0x0e, 0x25, 0xbe, 0x06, 0x19, 0x30, 0x92, 0x0c, 0x5c, 0x2c, 0x0e, 0x2a, 0x19,
		0x91, 0x81, 0xb9, 0xc8, 0x20, 0x03, 0x20, 0x03, 0x20, 0x03, 0x20, 0x03, 0x20, 0x03, 0x20, 0x03,
		0x20, 0x03, 0x20, 0x03, 0x77, 0xca, 0xa3, 0xb7, 0xb7, 0x18, 0xf1, 0x80, 0x5d, 0xd4, 0x47, 0xe7,
		0xfc, 0x41, 0x7d, 0x34, 0xc0, 0xed, 0x03, 0x62, 0xa3, 0x3e, 0x1a, 0xe1, 0xed, 0x67, 0xa6, 0x88,
		0xfa, 0x68, 0xe5, 0xa6, 0x58, 0xd9, 0xda, 0xab, 0xec, 0xed, 0xec, 0x6e, 0xed, 0xa1, 0x4c, 0x1a,
		0x80, 0x98, 0x99, 0x94, 0x28, 0x93, 0x36, 0x2e, 0x26, 0xdc, 0xe4, 0x17, 0xed, 0xe4, 0x6a, 0xc2,
		0x31, 0x2f, 0x3a, 0x97, 0x1b, 0xc9, 0xd1, 0x3c, 0xc4, 0x44, 0x72, 0x54, 0xa2, 0xc6, 0x22, 0x39,
		0x2a, 0xd3, 0xc0, 0x90, 0x1c, 0x55, 0x2c, 0x38, 0x92, 0xa3, 0xc5, 0x63, 0x8f, 0xa8, 0x94, 0x50,
		0x04, 0x14, 0x50, 0x29, 0x51, 0x04, 0x5a, 0x80, 0x95, 0xe6, 0x4f, 0x89, 0x37, 0x41, 0x10, 0x26,
		0x73, 0x3b, 0x26, 0xbd, 0xd9, 0x3c, 0x1e, 0x9e, 0x89, 0x73, 0x77, 0xe2, 0x26, 0x67, 0x33, 0xf7,
		0x53, 0x0a, 0x27, 0x22, 0x18, 0xa6, 0xb0, 0xda, 0x0e, 0x44, 0xf2, 0x23, 0x8c, 0xbe, 0xdb, 0x5e,
		0x10, 0x27, 0x6e, 0x30, 0x14, 0xa5, 0xfb, 0xdf, 0x88, 0x57, 0xbe, 0x53, 0x9a, 0x44, 0x61, 0x12,
		0x0e, 0x43, 0x3f, 0xce, 0xbe, 0x2a, 0xcd, 0x23, 0x6d, 0xc9, 0x8d, 0x84, 0x1b, 0xa7, 0x7f, 0x96,
		0xfc, 0x78, 0x74, 0x52, 0xf2, 0x63, 0x37, 0xa5, 0x42, 0x71, 0xf6, 0xd5, 0xec, 0x8b, 0xf4, 0x5f,
		0xa5, 0x70, 0xe2, 0xfe, 0x6b, 0x2a, 0xec, 0xd9, 0x97, 0xe2, 0x32, 0x11, 0xc1, 0x48, 0x8c, 0xec,
		0x39, 0x4c, 0x2a, 0x25, 0xfe, 0x45, 0x3c, 0xfb, 0xa3, 0x34, 0xff, 0xb7, 0x1d, 0x7b, 0xa3, 0x52,
		0x9c, 0xb8, 0x89, 0xa0, 0x19, 0xca, 0xe9, 0xd9, 0x0c, 0x2d, 0x89, 0x88, 0x59, 0x2f, 0x75, 0xab,
		0x35, 0xc0, 0x5a, 0x09, 0xa2, 0x1a, 0x2b, 0x4e, 0xa2, 0xe9, 0x30, 0x09, 0x16, 0x10, 0xac, 0x3d,
		0x7f, 0x4c, 0xcd, 0xc5, 0x53, 0x72, 0xba, 0x8b, 0x67, 0xe3, 0x74, 0xd2, 0x67, 0xe3, 0xd4, 0x22,
		0xe1, 0x3a, 0xad, 0x78, 0x74, 0xe2, 0xb4, 0x62, 0x77, 0x86, 0x30, 0x67, 0x7f, 0x3b, 0x9d, 0xf4,
		0x29, 0xcc, 0xbe, 0x6a, 0x2c, 0x1e, 0xc2, 0x9c, 0xf4, 0x3b, 0x03, 0xff, 0xc2, 0x99, 0x7f, 0xd9,
		0xf7, 0x46, 0xb4, 0xbc, 0x14, 0x1d, 0x5f, 0x40, 0xc8, 0x0f, 0xa4, 0xa9, 0x3a, 0xdf, 0x3d, 0x11,
		0xbe, 0x7d, 0xe2, 0x05, 0x23, 0x2f, 0x38, 0x25, 0xe7, 0x0a, 0xee, 0x64, 0x15, 0xef, 0x8a, 0x4a,
		0xcc, 0x9f, 0x2e, 0xf9, 0x01, 0x31, 0xb1, 0xa8, 0x26, 0x0e, 0x29, 0x27, 0x0a, 0x59, 0x24, 0x06,
		0xa9, 0x27, 0x02, 0xd9, 0x24, 0xfe, 0xd8, 0x24, 0xfa, 0xb8, 0x24, 0xf6, 0x80, 0xbb, 0x7f, 0xf6,
		0x12, 0xeb, 0x5e, 0x44, 0x14, 0x70, 0xa7, 0xdc, 0x92, 0xac, 0x3b, 0xc9, 0x80, 0x40, 0x2a, 0x26,
		0x51, 0x0b, 0xa5, 0x09, 0x02, 0xc8, 0x83, 0x01, 0x0e, 0xa0, 0x80, 0x15, 0x38, 0xe0, 0x02, 0x12,
		0xd8, 0x81, 0x05, 0x76, 0xa0, 0x81, 0x1b, 0x78, 0xa0, 0x09, 0x22, 0x88, 0x82, 0x09, 0xf2, 0xa0,
		0x22, 0x13, 0xf0, 0xdc, 0x8b, 0xa2, 0x30, 0xa2, 0x98, 0x61, 0x58, 0xeb, 0xdf, 0x6f, 0x44, 0xc6,
		0xe4, 0x47, 0x19, 0x20, 0x09, 0x25, 0x57, 0xc5, 0x01, 0x4d, 0x2c, 0xc1, 0x13, 0x37, 0x10, 0xc5,
		0x16, 0x4c, 0xb1, 0x05, 0x55, 0x5c, 0xc1, 0x15, 0x6d, 0x90, 0x45, 0x1c, 0x6c, 0x65, 0x2f, 0x1d,
		0x93, 0x1f, 0x15, 0x64, 0x52, 0x30, 0xf9, 0xd1, 0x38, 0xe3, 0xc1, 0xae, 0x4c, 0x80, 0x6f, 0x80,
		0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0x80, 0x6f, 0xe0, 0x87, 0x82, 0x80, 0x6f, 0xec, 0xca,
		0xcc, 0x5f, 0x54, 0xcc, 0x82, 0x91, 0xf4, 0x60, 0x31, 0x0b, 0x46, 0x9d, 0xd8, 0x98, 0x05, 0x83,
		0xe8, 0xf6, 0x33, 0x53, 0xc4, 0x2c, 0x18, 0xe5, 0xa6, 0x88, 0x5d, 0x99, 0x00, 0xc2, 0xec, 0xa4,
		0xc4, 0x10, 0x18, 0xe3, 0x82, 0x81, 0xf5, 0x43, 0x78, 0xa7, 0x67, 0x09, 0x9f, 0xbc, 0xe8, 0x42,
		0x5e, 0x24, 0x41, 0xf3, 0x10, 0x13, 0x49, 0x50, 0x89, 0x9a, 0x8a, 0x24, 0xa8, 0x4c, 0x03, 0x43,
		0x12, 0x54, 0xb1, 0xe0, 0x48, 0x82, 0x16, 0x8f, 0x26, 0x22, 0x09, 0x2a, 0x1d, 0x22, 0x20, 0x09,
		0x9a, 0xf7, 0x07, 0x49, 0x50, 0x60, 0xdb, 0x07, 0xc4, 0x46, 0x12, 0x14, 0xd1, 0xed, 0x67, 0xa6,
		0x88, 0x24, 0xa8, 0x72, 0x53, 0x44, 0x12, 0x14, 0x40, 0x98, 0x9d, 0x94, 0x48, 0x82, 0x9a, 0x24,
		0x19, 0x46, 0xde, 0xbd, 0x4c, 0x4e, 0xae, 0x43, 0xb4, 0x56, 0xa6, 0xfd, 0x60, 0xf2, 0x1d, 0x73,
		0xb3, 0xb1, 0x66, 0xef, 0x96, 0xfe, 0x74, 0x89, 0x54, 0x4a, 0x0c, 0x97, 0x78, 0x8e, 0x78, 0x18,
		0x2e, 0x91, 0xa3, 0x1e, 0x62, 0xb8, 0x44, 0x9e, 0x86, 0x83, 0xe1, 0x12, 0xb2, 0xf1, 0x10, 0x86,
		0x4b, 0x98, 0x0b, 0x76, 0xc9, 0x0f, 0x97, 0x48, 0xfc, 0x0b, 0x3e, 0x15, 0x12, 0x33, 0x61, 0x79,
		0x94, 0x47, 0x94, 0x51, 0x1e, 0x51, 0x18, 0xe0, 0xc1, 0x12, 0x80, 0x70, 0x03, 0x22, 0x6c, 0x01,
		0x09, 0x5b, 0x60, 0xc2, 0x15, 0xa0, 0xd0, 0x06, 0x2a, 0xc4, 0x01, 0x0b, 0x1b, 0xe0, 0x92, 0x09,
		0x2a, 0xa2, 0xd0, 0x3e, 0x17, 0x49, 0xe4, 0x0d, 0xf9, 0xf8, 0xb0, 0x6c, 0x8d, 0xcf, 0x8d, 0xec,
		0x4c, 0x7c, 0x01, 0x0f, 0x78, 0xc3, 0x0e, 0xe6, 0x70, 0x84, 0x3b, 0xac, 0x61, 0x0f, 0x57, 0xf8,
		0xc3, 0x1e, 0x06, 0xb1, 0x87, 0x43, 0xdc, 0x61, 0x11, 0x0f, 0x78, 0xc4, 0x04, 0x26, 0xb1, 0x83,
		0x4b, 0x99, 0xc0, 0xb4, 0x27, 0x96, 0x3f, 0x1a, 0x6b, 0x28, 0x4f, 0x32, 0x37, 0x04, 0x3c, 0xb1,
		0x05, 0x51, 0x9c, 0xc1, 0x94, 0x11, 0xa0, 0x8a, 0x3b, 0xb8, 0x32, 0x06, 0x64, 0x19, 0x03, 0xb6,
		0x4c, 0x01, 0x5d, 0xbc, 0xc0, 0x17, 0x33, 0x10, 0xc6, 0x16, 0x8c, 0x65, 0x82, 0x33, 0xcb, 0x63,
		0xad, 0x0d, 0x5a, 0xac, 0x72, 0x5a, 0xeb, 0x60, 0xda, 0x26, 0x53, 0xf1, 0xb9, 0xc2, 0x35, 0x13,
		0x60, 0x9b, 0x51, 0xf0, 0xcd, 0x14, 0x18, 0x67, 0x1c, 0x9c, 0x33, 0x0e, 0xd6, 0x99, 0x06, 0xef,
		0x78, 0xc2, 0x3c, 0xa6, 0x70, 0x2f, 0x53, 0x1e, 0x36, 0x1d, 0xdd, 0x8f, 0x46, 0x8d, 0xa9, 0x17,
		0x24, 0xdb, 0xac, 0x43, 0xc6, 0x02, 0x43, 0xed, 0x32, 0xbe, 0x05, 0x5e, 0xad, 0xe1, 0xeb, 0x3e,
		0xbc, 0x43, 0xf6, 0x06, 0xd7, 0x56, 0x72, 0x43, 0xc9, 0xc5, 0xca, 0xed, 0x30, 0x6d, 0x3d, 0x5f,
		0x7b, 0x3f, 0x8c, 0xbb, 0x60, 0x0d, 0x0b, 0xe7, 0x77, 0x5d, 0x80, 0x7b, 0x09, 0x17, 0x40, 0xdc,
		0x05, 0x54, 0xb6, 0xf6, 0x2a, 0x7b, 0x3b, 0xbb, 0x5b, 0x7b, 0x55, 0xf8, 0x02, 0x10, 0x12, 0x48,
		0x7f, 0xfb, 0x73, 0xfc, 0x0a, 0xcf, 0x1b, 0x12, 0x33, 0x8f, 0xcc, 0x5c, 0x3a, 0xf7, 0xd7, 0xca,
		0x6f, 0x4e, 0x47, 0x7f, 0xf6, 0x9f, 0x6e, 0x2a, 0x88, 0x29, 0x77, 0xf9, 0xf3, 0x37, 0x57, 0x54,
		0xcb, 0xc1, 0x91, 0x18, 0xee, 0x40, 0x38, 0x55, 0x6d, 0xc7, 0x49, 0x34, 0x1d, 0x26, 0xc1, 0x22,
		0x5d, 0xda, 0x9e, 0x3f, 0xd9, 0xe6, 0xe2, 0xc1, 0x3a, 0xdd, 0xc5, 0xe3, 0x74, 0x3a, 0xe9, 0xe3,
		0x74, 0x6a, 0x91, 0x70, 0x9d, 0x56, 0x3c, 0x3a, 0x71, 0x5a, 0xb1, 0x3b, 0xb8, 0x9a, 0x88, 0xd9,
		0xdf, 0x4e, 0x27, 0x7d, 0x70, 0xb3, 0xaf, 0x1a, 0x8b, 0xe7, 0x36, 0x3f, 0x78, 0x74, 0x06, 0xfe,
		0x85, 0xd3, 0xf7, 0x46, 0xad, 0xd9, 0x03, 0xdb, 0x9f, 0x3f, 0xaf, 0xf4, 0x7b, 0x8d, 0x28, 0x3c,
		0x9c, 0x3f, 0x29, 0xcc, 0x9b, 0x2a, 0x8a, 0xbb, 0x4a, 0x5b, 0x74, 0x16, 0x06, 0xcf, 0xb0, 0xb9,
		0x28, 0x95, 0x1c, 0xad, 0x45, 0x32, 0xc4, 0x45, 0x6b, 0x91, 0x42, 0x5d, 0x46, 0x6b, 0x91, 0x4a,
		0x43, 0x44, 0x6b, 0x91, 0x6e, 0x7c, 0x8c, 0xd6, 0x22, 0xa0, 0x8f, 0xa5, 0x32, 0xf0, 0x6b, 0x2d,
		0x12, 0xa7, 0x33, 0xe5, 0x8d, 0x19, 0x77, 0x17, 0x2d, 0xef, 0x00, 0x0d, 0x46, 0x80, 0x52, 0x66,
		0x41, 0x2a, 0x23, 0xa0, 0x15, 0x77, 0x88, 0x65, 0x0c, 0xd4, 0x32, 0x06, 0x72, 0x99, 0x02, 0xbd,
		0x78, 0x41, 0x30, 0x66, 0x50, 0x8c, 0x2d, 0x24, 0xbb, 0x0f, 0xcd, 0xf8, 0x77, 0x18, 0x2d, 0x6f,
		0x84, 0x77, 0x8b, 0x51, 0x19, 0x2d, 0x46, 0x00, 0x6e, 0x45, 0x06, 0x70, 0xa6, 0x00, 0x39, 0xe3,
		0x00, 0x9d, 0x71, 0xc0, 0xce, 0x34, 0x80, 0xc7, 0x13, 0xe8, 0x31, 0x05, 0x7c, 0xec, 0x81, 0x5f,
		0x76, 0x03, 0xde, 0xe4, 0xa2, 0x62, 0x73, 0x47, 0x81, 0x2b, 0x21, 0xf0, 0xce, 0x5d, 0x31, 0xf7,
		0x4f, 0xbc, 0xa1, 0xa1, 0x31, 0x10, 0xd1, 0x24, 0xa8, 0x68, 0x24, 0x64, 0x34, 0x0d, 0x3a, 0x1a,
		0x0b, 0x21, 0x8d, 0x85, 0x92, 0xa6, 0x42, 0x4a, 0xde, 0xd0, 0x92, 0x39, 0xc4, 0x34, 0x06, 0x6a,
		0x66, 0x37, 0xc2, 0x73, 0xd2, 0xe4, 0xa3, 0x31, 0x94, 0xe3, 0x04, 0x4a, 0xc3, 0x41, 0xa7, 0x71,
		0xe0, 0xd3, 0x44, 0x10, 0x6a, 0x34, 0x18, 0x35, 0x15, 0x94, 0x1a, 0x0f, 0x4e, 0x8d, 0x07, 0xa9,
		0xa6, 0x83, 0x55, 0x33, 0x40, 0xab, 0x21, 0xe0, 0xd5, 0x38, 0x10, 0x9b, 0xdd, 0x90, 0x3b, 0x1a,
		0x45, 0x22, 0x8e, 0xcd, 0x73, 0xec, 0xcb, 0x68, 0xbc, 0xbc, 0x41, 0xc3, 0xbc, 0x9e, 0x59, 0x33,
		0x37, 0x8c, 0x05, 0xba, 0x26, 0x03, 0xde, 0x42, 0x00, 0x5f, 0xd3, 0x01, 0x70, 0x61, 0x80, 0x70,
		0x61, 0x00, 0xf1, 0xff, 0x67, 0xef, 0xed, 0x9b, 0x12, 0xd7, 0xb2, 0xb7, 0xe1, 0xff, 0xfb, 0x53,
		0x58, 0xa9, 0x7b, 0xaa, 0xf4, 0xcc, 0x89, 0x02, 0x82, 0x4a, 0x57, 0xdd, 0x75, 0x0a, 0x5b, 0xba,
		0x87, 0x67, 0x50, 0xb8, 0x91, 0xee, 0xdf, 0x39, 0xa5, 0xfc, 0x52, 0x11, 0xb6, 0x76, 0xa6, 0x43,
		0x60, 0x92, 0xe0, 0xe8, 0x74, 0xfb, 0xdd, 0x9f, 0x22, 0x40, 0x44, 0xd1, 0x6e, 0x81, 0xbd, 0x77,
		0xd6, 0xda, 0x5c, 0xd6, 0xa9, 0x96, 0xf6, 0xb4, 0xc9, 0xce, 0xce, 0x7a, 0xb9, 0xd6, 0xb5, 0xd7,
		0xcb, 0xa6, 0x00, 0x63, 0xb3, 0x00, 0xb2, 0x61, 0x40, 0x39, 0x15, 0x42, 0xf6, 0x3d, 0x4c, 0x7f,
		0xe9, 0xf5, 0x92, 0xb3, 0xfa, 0x29, 0xca, 0xb4, 0x83, 0x81, 0xfd, 0xdf, 0x41, 0x20, 0x4c, 0x74,
		0x80, 0x33, 0x4a, 0xf5, 0xc8, 0xc0, 0x67, 0x6b, 0xba, 0x71, 0x2c, 0xc2, 0x80, 0x7d, 0x73, 0xd4,
		0x57, 0x1f, 0x70, 0x7b, 0xfb, 0x22, 0x67, 0x97, 0x3b, 0x3f, 0x2e, 0xf2, 0x76, 0xb9, 0x33, 0xf9,
		0x98, 0x4f, 0xbe, 0x4d, 0x3e, 0x17, 0x2e, 0x72, 0x76, 0x71, 0xf6, 0xb9, 0x74, 0x91, 0xb3, 0x4b,
		0x9d, 0x9d, 0xcb, 0xcb, 0xdd, 0x9d, 0xef, 0xfb, 0x0f, 0xcb, 0xff, 0xe2, 0xf6, 0xdf, 0x2e, 0x2e,
		0x2f, 0x87, 0xdf, 0xcf, 0x1e, 0xc6, 0x7f, 0xd6, 0x1f, 0x3a, 0x7f, 0xdf, 0xf9, 0xc3, 0x54, 0x2c,
		0x31, 0x7e, 0xf0, 0xcb, 0xcb, 0xdd, 0xce, 0x6f, 0xe6, 0xb9, 0xd5, 0xce, 0x3b, 0x80, 0x04, 0x3c,
		0x09, 0x60, 0xce, 0x2f, 0x30, 0x36, 0xef, 0x0e, 0x72, 0xaf, 0x3e, 0x97, 0xa1, 0x8d, 0xa1, 0xc6,
		0x0f, 0xb4, 0x37, 0x2b, 0x86, 0x9e, 0x7d, 0xd8, 0x9b, 0xcf, 0xb6, 0xe4, 0xd8, 0x75, 0xce, 0x5c,
		0x53, 0x81, 0x8c, 0x1d, 0x18, 0x37, 0x18, 0xb5, 0xb5, 0x8d, 0x9a, 0x09, 0x59, 0xb1, 0x59, 0x75,
		0xc8, 0x6b, 0xba, 0xf1, 0x57, 0xe7, 0x7c, 0xb2, 0x8f, 0x4e, 0x6d, 0x78, 0x5b, 0x9c, 0x7e, 0xb6,
		0xd0, 0x79, 0x1a, 0x46, 0x75, 0x69, 0x19, 0x36, 0x21, 0x73, 0xd0, 0xa8, 0x8c, 0x41, 0x94, 0xa7,
		0x50, 0xa3, 0xe2, 0x50, 0x9e, 0x42, 0xfb, 0xa1, 0x50, 0x9e, 0xc2, 0xe4, 0xc1, 0x50, 0x9e, 0x02,
		0x4c, 0x06, 0x5c, 0xf6, 0x56, 0xa1, 0x32, 0xa6, 0x3c, 0xc5, 0x1f, 0x0c, 0x22, 0x03, 0xcb, 0x53,
		0x26, 0x8f, 0x65, 0x4a, 0x1a, 0xa9, 0xb8, 0x76, 0x47, 0x7e, 0x62, 0xc0, 0xae, 0x5d, 0x3f, 0x32,
		0xad, 0xec, 0x26, 0x87, 0xb2, 0x1b, 0x80, 0x6b, 0x80, 0x6c, 0x80, 0xed, 0x8d, 0x03, 0xdd, 0xc6,
		0x83, 0x6f, 0xd3, 0x41, 0xb8, 0x19, 0x60, 0xdc, 0x10, 0x50, 0x9e, 0x0a, 0x9b, 0x71, 0x59, 0x84,
		0xa9, 0xd7, 0xba, 0x1a, 0x0c, 0x7c, 0xe1, 0x06, 0x26, 0xf9, 0xac, 0x19, 0xa3, 0x9a, 0xc7, 0x21,
		0x3a, 0x8c, 0x80, 0x24, 0x99, 0x8a, 0x4d, 0x32, 0x00, 0xa9, 0xf2, 0x27, 0x4f, 0x85, 0xd0, 0x0f,
		0xa1, 0x1f, 0x42, 0x3f, 0x84, 0x7e, 0x08, 0xfd, 0x10, 0xfa, 0x21, 0xf4, 0x03, 0xe2, 0x03, 0xea,
		0xdb, 0x90, 0xd0, 0xcf, 0xeb, 0x89, 0x20, 0xf6, 0xe2, 0xfb, 0x50, 0x5c, 0x9b, 0x18, 0xfe, 0x95,
		0x0c, 0x7a, 0xa6, 0xda, 0xf4, 0x55, 0x1d, 0xbb, 0x91, 0x30, 0xb7, 0x55, 0x46, 0xe3, 0xbc, 0xf9,
		0xf1, 0x4b, 0xc1, 0xa9, 0xfe, 0xd9, 0x6e, 0xb6, 0xaa, 0x1f, 0x6b, 0x7f, 0x3a, 0xc7, 0xb5, 0xb3,
		0x93, 0xda, 0xd9, 0x27, 0xa7, 0xda, 0x6a, 0x38, 0xcd, 0x4a, 0xfb, 0x1f, 0xce, 0x79, 0xf5, 0xd3,
		0x69, 0xf5, 0xac, 0xed, 0xb4, 0xff, 0x6a, 0x56, 0x4d, 0x73, 0xdb, 0x5f, 0x5c, 0x7f, 0x24, 0x22,
		0x23, 0x4b, 0x00, 0x0d, 0x6d, 0x59, 0x30, 0x93, 0xdb, 0xcf, 0x67, 0x67, 0x9f, 0x4f, 0x8f, 0xab,
		0xad, 0xea, 0x89, 0x53, 0x3b, 0x6b, 0x57, 0x5b, 0x1f, 0x2b, 0x1f, 0xaa, 0x33, 0x51, 0x35, 0xb0,
		0xde, 0xfd, 0x77, 0xc8, 0x27, 0x2f, 0xf9, 0xac, 0x35, 0xbf, 0x14, 0x0d, 0x96, 0x47, 0xa3, 0x9e,
		0xa8, 0x83, 0x30, 0x06, 0x4f, 0x81, 0x27, 0x30, 0xc5, 0xdb, 0xa0, 0x86, 0x8d, 0x73, 0x0d, 0x9b,
		0x01, 0xb5, 0xb8, 0x28, 0xb4, 0xca, 0x42, 0x4b, 0x46, 0x41, 0x30, 0xea, 0x5f, 0x89, 0x50, 0xf4,
		0xec, 0xaf, 0x83, 0xa1, 0x39, 0x15, 0x57, 0xcf, 0x9e, 0x0b, 0xa5, 0x57, 0x14, 0x1e, 0x03, 0xa5,
		0x57, 0x84, 0x35, 0x06, 0xa5, 0x57, 0x94, 0x0d, 0x00, 0x4a, 0xaf, 0xb8, 0xc1, 0x69, 0x94, 0x5e,
		0x01, 0xa9, 0xc9, 0x16, 0x2a, 0x4c, 0x06, 0xa2, 0xed, 0x43, 0x31, 0x19, 0x08, 0xe0, 0x13, 0x20,
		0x14, 0x60, 0x74, 0x23, 0x40, 0xa9, 0xf1, 0xe0, 0xd4, 0x78, 0x90, 0x6a, 0x3a, 0x58, 0x35, 0x03,
		0xb4, 0x1a, 0x02, 0x5e, 0x8d, 0x03, 0xb1, 0xe9, 0x03, 0x79, 0x41, 0x2c, 0xc2, 0x6b, 0xb7, 0x2b,
		0x6c, 0xaf, 0x67, 0x6e, 0xce, 0xd3, 0x93, 0xa7, 0xc4, 0x8c, 0x20, 0x40, 0x5e, 0x40, 0x5f, 0x40,
		0x60, 0x40, 0xe1, 0xcd, 0x84, 0xc4, 0x1b, 0x03, 0x8d, 0x37, 0x05, 0x22, 0x9b, 0x05, 0x95, 0x0d,
		0x83, 0xcc, 0xa9, 0x10, 0x9a, 0x3f, 0x23, 0x68, 0xe4, 0x05, 0xf1, 0x7e, 0xc1, 0xe0, 0xa9, 0x40,
		0x87, 0x06, 0x3e, 0x5a, 0xcb, 0x0d, 0x6e, 0x84, 0xb1, 0x23, 0x81, 0xcc, 0x84, 0x28, 0xc9, 0x8b,
		0x3b, 0xf5, 0x02, 0x63, 0x31, 0x98, 0xe1, 0xc1, 0xdd, 0xc2, 0x63, 0x26, 0x55, 0x39, 0x1b, 0xf0,
		0x9c, 0x1f, 0x43, 0xb7, 0x1b, 0x7b, 0x83, 0xe0, 0xc4, 0xbb, 0xf1, 0xe2, 0x68, 0xfc, 0xc0, 0xc6,
		0x3e, 0xef, 0xc3, 0xef, 0x06, 0x9b, 0x1e, 0xf7, 0x0e, 0xa6, 0xc7, 0x30, 0xd3, 0x53, 0x2c, 0x94,
		0x8b, 0xe5, 0x83, 0xc3, 0x42, 0xb9, 0x04, 0x1b, 0x84, 0x80, 0x10, 0x4f, 0xa5, 0xf3, 0x0b, 0x53,
		0x08, 0xe1, 0xc3, 0x55, 0x9b, 0xbd, 0x70, 0x30, 0x8a, 0x45, 0x68, 0xf4, 0x29, 0xd7, 0xe3, 0x23,
		0xe2, 0x88, 0x8b, 0xc3, 0x63, 0xe1, 0x88, 0x8b, 0xb1, 0xb2, 0xe1, 0x88, 0x8b, 0xb3, 0x41, 0xc1,
		0x11, 0x97, 0x61, 0x0f, 0x8a, 0x23, 0x2e, 0xe0, 0xcb, 0xcc, 0x85, 0xd0, 0xfc, 0x23, 0xae, 0x64,
		0xde, 0xa8, 0xdb, 0xeb, 0x85, 0x22, 0x8a, 0xec, 0x60, 0x60, 0xff, 0x77, 0x10, 0x08, 0x83, 0x0f,
		0xbc, 0xf2, 0x47, 0x06, 0x3e, 0x5b, 0xd3, 0x8d, 0x63, 0x11, 0x06, 0xc6, 0x9e, 0x79, 0x59, 0xdb,
		0xdb, 0x17, 0x39, 0xbb, 0xdc, 0xf9, 0x71, 0x91, 0xb7, 0xcb, 0x9d, 0xc9, 0xc7, 0x7c, 0xf2, 0x6d,
		0xf2, 0xb9, 0x70, 0x91, 0xb3, 0x8b, 0xb3, 0xcf, 0xa5, 0x8b, 0x9c, 0x5d, 0xea, 0xec, 0x5c, 0x5e,
		0xee, 0xee, 0x7c, 0xdf, 0x7f, 0x58, 0xfe, 0x17, 0xb7, 0xff, 0x76, 0x71, 0x79, 0x39, 0xfc, 0x7e,
		0xf6, 0x30, 0xfe, 0xb3, 0xfe, 0xd0, 0xf9, 0xfb, 0xce, 0x1f, 0xa6, 0x62, 0x89, 0xf1, 0x83, 0x5f,
		0x5e, 0xee, 0x76, 0x7e, 0xb3, 0x40, 0x40, 0x01, 0x24, 0xe0, 0x49, 0x36, 0x0d, 0xe6, 0x98, 0xd6,
		0x65, 0x27, 0x7d, 0xae, 0x8d, 0xea, 0xb6, 0xf3, 0xb4, 0xb9, 0x88, 0x09, 0xcd, 0x77, 0xcc, 0x31,
		0x16, 0x28, 0x50, 0x87, 0x79, 0x83, 0x59, 0x93, 0x60, 0xd6, 0x4c, 0x68, 0x03, 0x13, 0xc5, 0xe1,
		0xa8, 0x1b, 0x07, 0xd3, 0xc0, 0xfb, 0x6c, 0xf2, 0x3e, 0x6a, 0xd3, 0xd7, 0xe1, 0x34, 0xa7, 0x2f,
		0xc1, 0x69, 0x24, 0x2f, 0xc1, 0xa9, 0x84, 0xc2, 0x75, 0xea, 0x51, 0xef, 0xca, 0xa9, 0x47, 0x6e,
		0xfb, 0x7e, 0x28, 0xc6, 0xdf, 0x9d, 0x46, 0xb2, 0xdd, 0xe3, 0x4f, 0xd5, 0xe9, 0x6e, 0x4f, 0xa8,
		0x79, 0xa7, 0xed, 0xdf, 0x3a, 0xe7, 0x5e, 0xaf, 0x3e, 0xde, 0xe6, 0xe3, 0xc9, 0x2e, 0x27, 0x3f,
		0xab, 0x86, 0x83, 0xa6, 0x1b, 0x7f, 0x75, 0xce, 0x27, 0xdb, 0xea, 0x7c, 0x4e, 0xb7, 0xf5, 0x1f,
		0x83, 0x21, 0x7a, 0xb4, 0x61, 0xe5, 0xc6, 0xbb, 0x03, 0xab, 0xee, 0x45, 0x71, 0x25, 0x8e, 0x79,
		0xd7, 0x79, 0x5a, 0xa7, 0x5e, 0x50, 0xf5, 0x45, 0x62, 0x23, 0x79, 0x1f, 0x30, 0x5a, 0xa7, 0xee,
		0xdd, 0xdc, 0x93, 0xe4, 0x8f, 0x8a, 0xc5, 0x83, 0xc3, 0x62, 0x31, 0x77, 0xb8, 0x7f, 0x98, 0x2b,
		0x97, 0x4a, 0xf9, 0x03, 0xce, 0x23, 0x08, 0xac, 0x46, 0xd8, 0x1b, 0x1b, 0xd7, 0xe3, 0x7b, 0xeb,
		0xfd, 0x56, 0x30, 0xf2, 0x7d, 0x68, 0x3a, 0x00, 0x1f, 0x80, 0xde, 0x4f, 0x80, 0x1e, 0x63, 0x64,
		0x47, 0x02, 0xd1, 0xf1, 0xc4, 0x70, 0xfc, 0x10, 0x10, 0xaf, 0x15, 0x33, 0xb3, 0xe0, 0xdc, 0x2d,
		0xf7, 0x46, 0x58, 0x6c, 0x5e, 0x96, 0x86, 0x8f, 0xbe, 0xf2, 0x58, 0x29, 0x13, 0x8b, 0xc2, 0xd5,
		0x92, 0x98, 0x6c, 0x41, 0x18, 0x41, 0xbc, 0x4c, 0x21, 0x1d, 0x0f, 0x03, 0x4b, 0xdf, 0x5c, 0x31,
		0x30, 0x55, 0xd6, 0x82, 0xda, 0xb0, 0xb1, 0x56, 0x8f, 0xfd, 0x65, 0x17, 0x1e, 0x81, 0x89, 0x8b,
		0xe0, 0xd5, 0x4b, 0x96, 0x5d, 0x55, 0x01, 0xc7, 0x6a, 0x01, 0xd6, 0x55, 0x00, 0x5c, 0xb3, 0xfb,
		0xd9, 0x67, 0xed, 0xb3, 0xcf, 0xc6, 0xe7, 0x9e, 0x65, 0x8f, 0xd0, 0x49, 0xa6, 0x30, 0x70, 0xeb,
		0x85, 0xca, 0xb4, 0x71, 0x3f, 0xeb, 0x06, 0xfd, 0x4c, 0x1b, 0xf1, 0xb3, 0x2d, 0xcd, 0xe4, 0x5c,
		0x7a, 0x69, 0x44, 0x69, 0x25, 0xf7, 0xd2, 0x49, 0x63, 0x4a, 0x23, 0x8d, 0x29, 0x7d, 0x34, 0xa5,
		0xb4, 0x11, 0x27, 0x62, 0x00, 0x63, 0x2f, 0x81, 0x32, 0xaf, 0x97, 0xd0, 0xc8, 0x7c, 0x2d, 0xe6,
		0x3c, 0xc1, 0x95, 0x3c, 0x09, 0x53, 0x3b, 0xc3, 0xbb, 0xcb, 0x06, 0xfb, 0x6e, 0x1a, 0x26, 0x74,
		0xcd, 0x30, 0xaa, 0x3b, 0x86, 0x29, 0x5d, 0x30, 0x8c, 0xeb, 0x76, 0x61, 0x5c, 0x57, 0x0b, 0xd3,
		0xba, 0x57, 0x20, 0x61, 0x5d, 0xa7, 0xf0, 0xb0, 0xef, 0x3a, 0xf1, 0x88, 0xa0, 0x42, 0x9b, 0x39,
		0x88, 0x9a, 0x07, 0x52, 0xf9, 0x22, 0xe3, 0x67, 0xa8, 0x06, 0xa3, 0xfe, 0x58, 0xa8, 0x1e, 0x90,
		0x2f, 0x0a, 0xe3, 0xf3, 0x93, 0xd0, 0xed, 0x76, 0xda, 0x3e, 0xd7, 0x80, 0xd8, 0x6d, 0xf2, 0x28,
		0x08, 0xde, 0x10, 0xbc, 0x21, 0x78, 0x43, 0xf0, 0x86, 0xe0, 0x0d, 0xc1, 0x1b, 0x82, 0x37, 0xe0,
		0x27, 0x04, 0x6f, 0x6f, 0xf4, 0x1a, 0xec, 0xa7, 0x5f, 0x19, 0x30, 0xe5, 0xca, 0x90, 0x69, 0x56,
		0x06, 0x34, 0x5f, 0x31, 0x69, 0x3a, 0x95, 0x61, 0xfd, 0xd7, 0x4d, 0x9b, 0x36, 0x65, 0xe2, 0x44,
		0x17, 0x03, 0x5a, 0xe6, 0x19, 0x35, 0x25, 0xca, 0x54, 0x13, 0x60, 0xda, 0xd4, 0x27, 0x23, 0x6d,
		0x01, 0xda, 0x4e, 0x65, 0xf2, 0xd5, 0x01, 0xf5, 0x8f, 0x15, 0x73, 0xf7, 0xcc, 0x68, 0x15, 0x41,
		0xaf, 0xd0, 0x7b, 0xf1, 0x7f, 0x31, 0xec, 0x42, 0x8b, 0x86, 0x11, 0x1b, 0x69, 0x57, 0xd0, 0x30,
		0x82, 0xb0, 0x1d, 0x41, 0xe7, 0x88, 0x5f, 0x74, 0x8e, 0x78, 0xf6, 0x33, 0x74, 0x90, 0xd8, 0x18,
		0xdb, 0xc5, 0xac, 0xf8, 0x91, 0x65, 0xd1, 0x23, 0x3a, 0x45, 0x28, 0x5e, 0x30, 0x3a, 0x45, 0x68,
		0x5e, 0x3c, 0x3a, 0x45, 0x64, 0xf4, 0x00, 0xe8, 0x14, 0x01, 0xcc, 0x61, 0x4e, 0xcc, 0xc4, 0xae,
		0x53, 0x04, 0xcb, 0x82, 0xc4, 0xd4, 0xd5, 0x30, 0xcc, 0x9f, 0x67, 0x7a, 0xbe, 0x84, 0x3e, 0x11,
		0x80, 0x54, 0x9b, 0x05, 0xad, 0x8c, 0x81, 0x58, 0xc6, 0x40, 0x2d, 0x53, 0x20, 0x17, 0x2f, 0xe8,
		0xc5, 0x0c, 0x82, 0xa5, 0x42, 0xc2, 0x36, 0xdf, 0xf4, 0x71, 0x04, 0x75, 0x4f, 0x04, 0xb1, 0x17,
		0xdf, 0x87, 0xe2, 0x9a, 0xa3, 0xdd, 0x9f, 0x71, 0x44, 0x0c, 0x13, 0x4e, 0xac, 0xda, 0x74, 0xeb,
		0x8f, 0xdd, 0xc8, 0x80, 0x9a, 0xaf, 0xc6, 0x79, 0xf3, 0xe3, 0x97, 0x82, 0x53, 0xfd, 0xb3, 0x5d,
		0x3d, 0x3b, 0xa9, 0x9e, 0x38, 0xcd, 0x56, 0xf5, 0x63, 0xed, 0x4f, 0xe7, 0xbc, 0x76, 0xe2, 0xd4,
		0x2b, 0xc7, 0xd5, 0xba, 0x73, 0x5c, 0x3b, 0x3b, 0xa9, 0x9d, 0x7d, 0x72, 0xce, 0x3f, 0x1f, 0xb7,
		0xeb, 0x5f, 0x9c, 0xf6, 0x5f, 0xcd, 0x2a, 0x57, 0x27, 0x97, 0xe4, 0x3b, 0x45, 0xac, 0x13, 0x83,
		0x99, 0xd7, 0xf1, 0xcc, 0xa4, 0xae, 0xda, 0x6a, 0x38, 0xcd, 0x4a, 0xfb, 0x1f, 0x8c, 0x0b, 0x44,
		0x7e, 0x87, 0x0c, 0x65, 0x2f, 0x43, 0xa7, 0xd5, 0x76, 0xab, 0xf6, 0x01, 0x52, 0x04, 0x29, 0x5a,
		0x55, 0x8a, 0xc6, 0x8e, 0xee, 0xb4, 0x59, 0x3f, 0x7f, 0xea, 0xed, 0x50, 0xb8, 0xa6, 0xf7, 0xab,
		0x83, 0x00, 0x0d, 0xab, 0x65, 0xb4, 0x52, 0xe4, 0x69, 0xa9, 0x5d, 0xb7, 0x89, 0x79, 0x5a, 0x7c,
		0xb2, 0x3b, 0x19, 0xe4, 0x1a, 0xbd, 0x83, 0x75, 0x58, 0x5d, 0xbb, 0x58, 0x0d, 0x77, 0xe6, 0x37,
		0xc4, 0xd9, 0x88, 0x61, 0xcd, 0xbc, 0x86, 0x32, 0x53, 0xd7, 0x38, 0x66, 0x7e, 0xd8, 0x40, 0xff,
		0x6b, 0xb1, 0xc8, 0x4e, 0xd5, 0x9f, 0x0d, 0x4d, 0x1b, 0x91, 0xd0, 0xf5, 0xf3, 0x34, 0x57, 0x46,
		0xd4, 0x0e, 0x72, 0xb1, 0x7f, 0x86, 0xd9, 0x3d, 0x9a, 0xba, 0x4d, 0x4f, 0x73, 0x68, 0xad, 0x88,
		0x98, 0x0e, 0x53, 0xd7, 0x5d, 0x73, 0x74, 0x96, 0x20, 0x44, 0xd1, 0x0e, 0x49, 0x68, 0x99, 0x2c,
		0x3a, 0x86, 0x81, 0x90, 0x51, 0x20, 0x5a, 0x44, 0x45, 0xba, 0x58, 0x8a, 0x68, 0x51, 0x14, 0xd9,
		0xcc, 0x5d, 0xca, 0x99, 0xb9, 0x2c, 0x32, 0x6f, 0xa9, 0x67, 0xd6, 0xb2, 0xc9, 0x9c, 0x65, 0x93,
		0x19, 0xcb, 0x25, 0xf3, 0x15, 0x60, 0xfb, 0x67, 0x2f, 0x91, 0x6a, 0x91, 0x10, 0xed, 0x62, 0x20,
		0x0e, 0x45, 0x3f, 0xc4, 0x8b, 0x7b, 0xc8, 0x17, 0xf1, 0x70, 0x28, 0xd6, 0x61, 0x55, 0x94, 0xc3,
		0xa5, 0xf8, 0x86, 0x5d, 0x91, 0x0d, 0xbb, 0x62, 0x1a, 0x6e, 0x45, 0x33, 0xe0, 0xde, 0x97, 0x79,
		0xb9, 0xe4, 0x8b, 0x5d, 0x98, 0x15, 0xb5, 0x70, 0x28, 0x5e, 0xe1, 0x55, 0xa4, 0xf2, 0xcb, 0x62,
		0x14, 0x36, 0xa5, 0x27, 0x9c, 0x4a, 0x4c, 0x98, 0xf5, 0x40, 0x5a, 0xa8, 0x48, 0xb2, 0xd0, 0x11,
		0x6b, 0xe3, 0x84, 0xe0, 0xb1, 0x3a, 0x0d, 0x6f, 0x7f, 0xf3, 0xde, 0xfe, 0x73, 0xbf, 0xd0, 0xaa,
		0x9c, 0x7d, 0xaa, 0x5a, 0x48, 0x56, 0x5d, 0xeb, 0xab, 0x03, 0x98, 0xcf, 0x7c, 0x55, 0x60, 0x54,
		0x7f, 0x1a, 0xdb, 0x22, 0x7d, 0x41, 0x4d, 0xfa, 0x02, 0xbd, 0x7a, 0x06, 0x1c, 0xd7, 0xbf, 0x24,
		0x60, 0xa3, 0xe0, 0x5b, 0x30, 0xf8, 0x4f, 0x60, 0xc7, 0xfe, 0x2d, 0xdd, 0x43, 0xfb, 0xf9, 0x45,
		0xe2, 0xe8, 0xfe, 0x2d, 0xcb, 0xc2, 0xd1, 0xfd, 0x1a, 0xe2, 0x86, 0xa3, 0xfb, 0x75, 0x14, 0x02,
		0x47, 0xf7, 0xb2, 0x31, 0x0a, 0x8e, 0xee, 0xf9, 0x03, 0x4d, 0xb2, 0x47, 0xf7, 0xb4, 0x9b, 0x9e,
		0xb3, 0x68, 0x72, 0x4e, 0xbc, 0xa9, 0x39, 0x0e, 0xef, 0x37, 0x05, 0x1c, 0x70, 0x01, 0x09, 0xec,
		0xc0, 0x02, 0x3b, 0xd0, 0xc0, 0x0d, 0x3c, 0xd0, 0x04, 0x11, 0x44, 0xc1, 0x04, 0x79, 0x50, 0x91,
		0x2e, 0xd0, 0x17, 0xc1, 0x4d, 0x42, 0x5d, 0x31, 0x39, 0x62, 0x9e, 0xae, 0x97, 0xb8, 0x4e, 0xf3,
		0x68, 0x04, 0xce, 0xa6, 0xf1, 0x37, 0xa7, 0x46, 0xdf, 0x2c, 0x1b, 0x7b, 0x73, 0x6b, 0xe4, 0xcd,
		0xb6, 0x71, 0x37, 0xdb, 0x46, 0xdd, 0x5c, 0x1b, 0x73, 0xa3, 0xd3, 0xd0, 0x3a, 0x2f, 0x9d, 0x4d,
		0xa3, 0xed, 0xc7, 0x83, 0x08, 0x2f, 0x88, 0xf3, 0x07, 0x1c, 0x4c, 0xee, 0x14, 0x23, 0x1c, 0x30,
		0x58, 0x6a, 0xcb, 0x0d, 0x6e, 0x04, 0x9b, 0xbe, 0xcb, 0x8c, 0xfa, 0xe4, 0x9d, 0x7a, 0x01, 0xc3,
		0xb9, 0x64, 0x3c, 0xa7, 0xdc, 0x24, 0xa9, 0x9d, 0x0c, 0xd7, 0xfd, 0x31, 0x74, 0xbb, 0xb1, 0x37,
		0x08, 0x4e, 0xbc, 0x1b, 0x6f, 0xd2, 0x42, 0x8d, 0x4f, 0x33, 0x50, 0x46, 0x53, 0x02, 0x4f, 0xdd,
		0x3b, 0xa8, 0xa2, 0x66, 0x55, 0x3c, 0x28, 0x95, 0xf6, 0x4b, 0x50, 0x47, 0x60, 0x61, 0x5e, 0xab,
		0xec, 0xa0, 0xe7, 0x9a, 0x69, 0xee, 0x80, 0xc7, 0xb0, 0x44, 0x4e, 0xc3, 0x11, 0xc1, 0x81, 0x4a,
		0x5e, 0x28, 0x38, 0x50, 0xc5, 0x8b, 0x06, 0x07, 0xaa, 0x69, 0xe1, 0xe0, 0x40, 0x81, 0x08, 0xd8,
		0x04, 0x89, 0xe0, 0x40, 0xd5, 0x63, 0x04, 0x70, 0xa0, 0xb2, 0xbf, 0xc0, 0x81, 0x02, 0xdc, 0xbe,
		0xb0, 0x6c, 0x70, 0xa0, 0x70, 0x6f, 0x3f, 0x53, 0x45, 0x70, 0xa0, 0xda, 0x55, 0x11, 0x1c, 0x28,
		0xb0, 0x30, 0xc3, 0x55, 0x82, 0x03, 0x35, 0xce, 0x1d, 0x58, 0xb7, 0x53, 0x93, 0xc4, 0x84, 0x04,
		0x9d, 0x2c, 0x17, 0x2c, 0xa8, 0x8c, 0x65, 0x82, 0x05, 0x55, 0x28, 0xa8, 0x60, 0x41, 0x55, 0x2a,
		0x18, 0x58, 0x50, 0xcd, 0x0b, 0x07, 0x0b, 0xba, 0x79, 0x61, 0x22, 0x43, 0x16, 0xf4, 0xca, 0x0b,
		0xdc, 0xf0, 0x9e, 0x11, 0x0b, 0x5a, 0x06, 0xa4, 0x36, 0x68, 0x65, 0x18, 0xe5, 0xb6, 0xde, 0x3a,
		0xb9, 0xf6, 0x55, 0x9a, 0xeb, 0x84, 0x43, 0x79, 0x66, 0x34, 0xda, 0xa0, 0xb1, 0x52, 0x5f, 0xb4,
		0x41, 0x53, 0xaf, 0xae, 0x1b, 0x39, 0xbf, 0xed, 0xf3, 0xe4, 0xf9, 0xc9, 0x4d, 0x92, 0x25, 0xd4,
		0x0b, 0xee, 0x1d, 0xec, 0xd1, 0xa3, 0x40, 0x92, 0x9c, 0x3d, 0x4f, 0x77, 0xc6, 0x3c, 0xab, 0x59,
		0xf2, 0x34, 0x67, 0xc6, 0x53, 0x91, 0x7c, 0xa2, 0x1e, 0x98, 0xab, 0xe7, 0xb5, 0x48, 0x4d, 0xc4,
		0x54, 0xeb, 0x65, 0x69, 0xb8, 0xd6, 0xec, 0x1d, 0x59, 0xb6, 0x2b, 0xc8, 0xd8, 0x90, 0x50, 0x33,
		0x20, 0x1c, 0x0d, 0x47, 0xb6, 0x8a, 0x94, 0x9d, 0xf8, 0x66, 0x73, 0xe7, 0x8c, 0x14, 0x86, 0x8a,
		0xa2, 0x30, 0x53, 0x90, 0x0c, 0x1d, 0xaa, 0x52, 0x07, 0x9a, 0x8d, 0xce, 0xeb, 0xd7, 0xb8, 0x0c,
		0xb4, 0xcd, 0xba, 0x09, 0xdd, 0x6e, 0x22, 0x4c, 0x99, 0x29, 0x5a, 0x7a, 0x5c, 0xf3, 0xb8, 0x94,
		0x8c, 0xac, 0x4e, 0xb6, 0x2d, 0x42, 0x33, 0xcf, 0xc0, 0xa0, 0x90, 0x59, 0x41, 0x2a, 0x63, 0x82,
		0x4a, 0x26, 0x04, 0xb9, 0x0c, 0x07, 0x72, 0x99, 0x0b, 0xd4, 0x32, 0x12, 0x36, 0x0b, 0xad, 0x65,
		0xdd, 0xe2, 0xd2, 0x4a, 0x02, 0x83, 0xcc, 0xb5, 0x34, 0x2d, 0xcd, 0x1e, 0xaf, 0x26, 0x63, 0x7d,
		0xa0, 0xd1, 0xed, 0x9a, 0x4c, 0x52, 0x21, 0xa5, 0xa4, 0x41, 0x92, 0x49, 0x81, 0xd4, 0x92, 0xfe,
		0xc8, 0x26, 0xf5, 0x91, 0x4d, 0xda, 0xa3, 0x9a, 0x94, 0xb7, 0xd9, 0x8c, 0x1f, 0x95, 0xee, 0xcf,
		0x16, 0xa5, 0xd9, 0x51, 0xf3, 0x9e, 0x92, 0x8a, 0x5a, 0xd3, 0x1a, 0x0f, 0x41, 0x2e, 0x1b, 0x9f,
		0x62, 0xd6, 0x3d, 0xe9, 0xec, 0x7a, 0xaa, 0x59, 0xf4, 0xe4, 0xb3, 0xe5, 0xc9, 0x67, 0xc5, 0x53,
		0xcf, 0x7e, 0x47, 0xb6, 0x0a, 0x45, 0x07, 0x9c, 0x2e, 0x88, 0xe6, 0x2c, 0x27, 0xd2, 0x33, 0x9c,
		0x30, 0xc0, 0x91, 0xbf, 0xb3, 0x66, 0xe1, 0xb4, 0xa9, 0x3b, 0x6f, 0x36, 0x4e, 0x9c, 0x8d, 0x33,
		0xe7, 0xe2, 0xd4, 0x69, 0x39, 0x77, 0x62, 0x4e, 0x9e, 0xac, 0xb3, 0x4f, 0x17, 0xe6, 0x0d, 0x6d,
		0x2f, 0x88, 0x45, 0x78, 0xed, 0x76, 0x85, 0xed, 0xf6, 0x7a, 0xa1, 0x88, 0x22, 0xfa, 0xf3, 0x1c,
		0x5f, 0x5c, 0x35, 0xed, 0xf1, 0x8e, 0x39, 0x8c, 0x77, 0x34, 0x0e, 0x32, 0xb0, 0x82, 0x0e, 0x5c,
		0x20, 0x04, 0x3b, 0x28, 0xc1, 0x0e, 0x52, 0x70, 0x83, 0x16, 0x34, 0x21, 0x06, 0x51, 0xa8, 0x91,
		0xbe, 0x5c, 0xf2, 0x55, 0xf1, 0x73, 0xde, 0xfc, 0xb6, 0x38, 0xf3, 0xe2, 0x76, 0x30, 0xb0, 0xff,
		0x3b, 0x08, 0x28, 0xf7, 0xce, 0x49, 0x83, 0xfe, 0x23, 0xc2, 0x6b, 0x6c, 0xba, 0x71, 0x2c, 0xc2,
		0x80, 0x7c, 0x53, 0x50, 0x6b, 0x7b, 0xfb, 0x22, 0x67, 0x97, 0x3b, 0x3f, 0x2e, 0xf2, 0x76, 0xb9,
		0x33, 0xf9, 0x98, 0x4f, 0xbe, 0x4d, 0x3e, 0x17, 0x2e, 0x72, 0x76, 0x71, 0xf6, 0xb9, 0x74, 0x91,
		0xb3, 0x4b, 0x9d, 0x9d, 0xcb, 0xcb, 0xdd, 0x9d, 0xef, 0xfb, 0x0f, 0xcb, 0xff, 0xe2, 0xf6, 0xdf,
		0x2e, 0x2e, 0x2f, 0x87, 0xdf, 0xcf, 0x1e, 0xc6, 0x7f, 0xd6, 0x1f, 0x3a, 0x7f, 0xdf, 0xf9, 0x83,
		0xba, 0x4f, 0x19, 0x3f, 0xc0, 0xe5, 0xe5, 0x6e, 0xe7, 0x37, 0xba, 0x66, 0xb9, 0x83, 0x22, 0x72,
		0xae, 0x8e, 0xc2, 0x1a, 0x8a, 0xd0, 0x1b, 0xf4, 0xe8, 0x07, 0x7c, 0xd3, 0x75, 0x22, 0xc4, 0x43,
		0x88, 0x87, 0x10, 0x0f, 0x21, 0x1e, 0x42, 0x3c, 0x84, 0x78, 0x08, 0xf1, 0x18, 0x85, 0x78, 0x23,
		0x2f, 0x88, 0xf7, 0x0b, 0x0c, 0x82, 0xba, 0x43, 0xc2, 0x4b, 0xe4, 0x31, 0xe6, 0x81, 0x41, 0x1b,
		0x3e, 0x4e, 0x63, 0x1d, 0x98, 0xf5, 0x90, 0xe7, 0x36, 0xc6, 0x81, 0x63, 0xbf, 0x78, 0x06, 0x63,
		0x1b, 0x58, 0x8d, 0x6b, 0xe0, 0xaa, 0x62, 0xc5, 0x42, 0xb9, 0x58, 0x3e, 0x38, 0x2c, 0x94, 0x4b,
		0xd0, 0xb5, 0xcd, 0x02, 0xa4, 0xf4, 0x57, 0x07, 0x52, 0x90, 0xad, 0x2d, 0xb7, 0x42, 0xe1, 0x46,
		0x84, 0x5b, 0xb0, 0xa6, 0x41, 0xc5, 0x74, 0x9d, 0x20, 0x05, 0x57, 0x59, 0x1e, 0x48, 0x41, 0x89,
		0x92, 0x08, 0x52, 0x50, 0xa6, 0xe2, 0x80, 0x14, 0x54, 0xbc, 0x60, 0x90, 0x82, 0xe6, 0x46, 0x61,
		0x8c, 0x48, 0x41, 0x11, 0x8c, 0xfa, 0x22, 0x9c, 0x34, 0xd3, 0x62, 0x90, 0xee, 0x51, 0x24, 0xbc,
		0xc6, 0x6a, 0x30, 0xea, 0x8f, 0x5f, 0xfa, 0x03, 0x60, 0x37, 0x5b, 0xd8, 0x1d, 0x53, 0x56, 0xdc,
		0xc7, 0xca, 0xe8, 0xf1, 0x2a, 0x01, 0xb9, 0x01, 0xb9, 0x01, 0xb9, 0x01, 0xb9, 0x01, 0xb9, 0x01,
		0xb9, 0x01, 0xb9, 0x39, 0xa5, 0x5a, 0xf7, 0x44, 0x10, 0x7b, 0xf1, 0x7d, 0x28, 0xae, 0x39, 0x40,
		0x6e, 0xc2, 0x07, 0x1b, 0x56, 0x6d, 0xba, 0x95, 0xc7, 0x6e, 0xc4, 0x68, 0x30, 0xed, 0xa7, 0x56,
		0xe5, 0x43, 0xd5, 0xa9, 0x9f, 0x57, 0x9c, 0x76, 0xfd, 0x8b, 0xd3, 0xfe, 0xab, 0x59, 0x3d, 0xa7,
		0x6e, 0xeb, 0x93, 0xe3, 0xae, 0x88, 0x7c, 0xde, 0xc3, 0x16, 0x8b, 0xdc, 0x87, 0x17, 0x84, 0xa1,
		0xd6, 0x74, 0x6a, 0x67, 0xed, 0x6a, 0xeb, 0xe3, 0xf8, 0x2f, 0x95, 0x93, 0x93, 0x56, 0xf5, 0xfc,
		0xdc, 0xc2, 0x21, 0xf8, 0x86, 0x4a, 0x43, 0xb3, 0xda, 0xaa, 0x35, 0x4e, 0xf0, 0xfe, 0x37, 0xf5,
		0xfd, 0xb7, 0xaa, 0xe7, 0xed, 0x4a, 0xab, 0xed, 0xb4, 0xaa, 0x95, 0xf3, 0xc6, 0x19, 0x46, 0xe7,
		0xae, 0xf7, 0xd5, 0x01, 0xc2, 0x67, 0xbe, 0x2a, 0xf4, 0xb5, 0xf8, 0x69, 0x58, 0x8b, 0xd1, 0x8f,
		0xeb, 0x8c, 0xc9, 0x48, 0x07, 0x0b, 0x3c, 0x0e, 0x7d, 0x24, 0x38, 0x97, 0x95, 0xd0, 0xbc, 0x43,
		0x42, 0x6d, 0x14, 0xe7, 0xa7, 0x73, 0x92, 0x6d, 0x9a, 0x46, 0x77, 0x84, 0x28, 0x5a, 0xa7, 0x2d,
		0xb9, 0x30, 0xb4, 0x4e, 0x5b, 0x73, 0x91, 0x68, 0x9d, 0x26, 0x69, 0xa1, 0x68, 0x9d, 0x06, 0x88,
		0xa9, 0xef, 0x25, 0x92, 0x6d, 0x9d, 0x46, 0xb3, 0x5f, 0xea, 0x82, 0x4d, 0xa6, 0xd8, 0x37, 0x95,
		0x38, 0x08, 0x20, 0x0f, 0x06, 0x38, 0x80, 0x02, 0x56, 0xe0, 0x80, 0x0b, 0x48, 0x60, 0x07, 0x16,
		0xd8, 0x81, 0x06, 0x6e, 0xe0, 0x81, 0x26, 0x88, 0x20, 0x0a, 0x26, 0xc8, 0x83, 0x8a, 0x74, 0x81,
		0xbe, 0x08, 0x6e, 0x12, 0xd2, 0x8a, 0xc9, 0xb9, 0xf2, 0x74, 0xbd, 0xc4, 0x75, 0x9a, 0x47, 0xa1,
		0x27, 0x79, 0xd8, 0xc1, 0x09, 0x7e, 0xb0, 0x84, 0x21, 0xdc, 0xe0, 0x08, 0x5b, 0x58, 0xc2, 0x16,
		0x9e, 0x70, 0x85, 0x29, 0xb4, 0xe1, 0x0a, 0x71, 0xd8, 0x92, 0xbe, 0x74, 0xf2, 0x09, 0x87, 0x0b,
		0x56, 0x77, 0xe4, 0x05, 0x71, 0xfe, 0x80, 0x83, 0xc9, 0x9d, 0x62, 0x84, 0x03, 0x06, 0x4b, 0xe5,
		0xd1, 0x10, 0x68, 0xf6, 0xc5, 0xc3, 0x85, 0x6d, 0x71, 0x6b, 0x10, 0xc4, 0x0c, 0xdc, 0x2e, 0x2c,
		0x9b, 0x59, 0xc3, 0xa0, 0x74, 0xdd, 0x0c, 0x9b, 0x99, 0x30, 0x71, 0x6f, 0x4f, 0x55, 0x91, 0x51,
		0x23, 0x21, 0x53, 0x54, 0xf1, 0xa0, 0x54, 0xda, 0x2f, 0x41, 0x1d, 0x81, 0x85, 0x79, 0xad, 0xb2,
		0x83, 0x5e, 0x4d, 0xa6, 0xb9, 0x03, 0xda, 0x45, 0xd1, 0x0b, 0x51, 0x0e, 0xe1, 0xe2, 0x68, 0x66,
		0xbe, 0x09, 0x1c, 0xa8, 0x4a, 0x39, 0x05, 0x07, 0xaa, 0x52, 0xc1, 0xc0, 0x81, 0x6a, 0x5e, 0x38,
		0x38, 0xd0, 0xcd, 0x0b, 0x12, 0xc1, 0x81, 0xaa, 0xc7, 0x08, 0xe0, 0x40, 0x65, 0x7f, 0x81, 0x03,
		0x05, 0xb8, 0x7d, 0x61, 0xd9, 0xe0, 0x40, 0xe1, 0xde, 0x7e, 0xa6, 0x8a, 0xe0, 0x40, 0xb5, 0xab,
		0x22, 0x38, 0x50, 0x60, 0x61, 0x86, 0xab, 0x04, 0x07, 0x6a, 0x9c, 0x3b, 0xb0, 0x6e, 0xa7, 0x26,
		0x89, 0x09, 0x09, 0x3a, 0x59, 0x2e, 0x58, 0x50, 0x19, 0xcb, 0x04, 0x0b, 0xaa, 0x50, 0x50, 0xc1,
		0x82, 0xaa, 0x54, 0x30, 0xb0, 0xa0, 0x9a, 0x17, 0x0e, 0x16, 0x74, 0xf3, 0xc2, 0x44, 0x86, 0x2c,
		0xe8, 0x95, 0x17, 0xb8, 0xe1, 0x3d, 0x23, 0x16, 0xb4, 0x0c, 0x48, 0x6d, 0xd0, 0xca, 0xa8, 0x56,
		0xa4, 0x11, 0xef, 0xa4, 0x94, 0xae, 0x93, 0x5f, 0x47, 0xa5, 0xb9, 0x1e, 0x38, 0x14, 0xbb, 0x2b,
		0xd1, 0x55, 0x17, 0xf4, 0xa5, 0x60, 0xac, 0xb0, 0xbc, 0x15, 0x95, 0x62, 0xff, 0xa0, 0x28, 0x0e,
		0x47, 0xdd, 0x38, 0x98, 0xc2, 0x98, 0xb3, 0xc9, 0x0e, 0xd5, 0xa6, 0x1b, 0xe4, 0x34, 0xa7, 0xdb,
		0xe2, 0x34, 0x92, 0x6d, 0x71, 0x2a, 0xa1, 0x70, 0x9d, 0x7a, 0xd4, 0xbb, 0x72, 0xea, 0x91, 0x3b,
		0x46, 0x69, 0xe3, 0xef, 0x4e, 0x23, 0xd9, 0x80, 0xf1, 0xa7, 0x4f, 0xe3, 0xe7, 0x1f, 0x7f, 0x68,
		0xfb, 0xb7, 0xce, 0xe7, 0xc9, 0x93, 0xb7, 0xfd, 0x5b, 0x74, 0x7e, 0xa3, 0xbc, 0x12, 0x22, 0x36,
		0xc8, 0xaa, 0x7b, 0x51, 0x5c, 0x89, 0x63, 0x5a, 0x35, 0xec, 0xd6, 0xa9, 0x17, 0x54, 0x7d, 0x31,
		0x0e, 0x41, 0x23, 0x5a, 0x8c, 0x95, 0x75, 0xea, 0xde, 0xcd, 0xad, 0x2c, 0x7f, 0x54, 0x2c, 0x1e,
		0x1c, 0x16, 0x8b, 0xb9, 0xc3, 0xfd, 0xc3, 0x5c, 0xb9, 0x54, 0xca, 0x1f, 0x50, 0x6a, 0x34, 0x6f,
		0x35, 0xc2, 0x9e, 0x08, 0x45, 0xef, 0xf8, 0xde, 0x7a, 0xbf, 0x15, 0x8c, 0x7c, 0x1f, 0x92, 0x4f,
		0xdf, 0xeb, 0xf2, 0xf3, 0xb6, 0x84, 0x3c, 0xac, 0x42, 0xcf, 0x4a, 0xc3, 0x9d, 0x66, 0xef, 0xbc,
		0xb2, 0x5d, 0x41, 0xc6, 0xc6, 0x83, 0x9a, 0xd1, 0xe0, 0x65, 0x2c, 0xb2, 0x55, 0xa1, 0xec, 0x04,
		0x37, 0x9b, 0x3b, 0x67, 0xa4, 0x2a, 0x54, 0x54, 0x84, 0x8d, 0x6a, 0x64, 0xe8, 0x3e, 0x15, 0xb9,
		0xcb, 0x6c, 0xf4, 0x5c, 0xbf, 0x96, 0x65, 0xa0, 0x61, 0x56, 0x38, 0x18, 0xc5, 0x22, 0xb4, 0xbd,
		0xe0, 0x7a, 0x10, 0xf6, 0xb3, 0xd5, 0xb2, 0xc7, 0xe9, 0xf9, 0x8b, 0x6b, 0xca, 0xc8, 0xf6, 0x64,
		0xdb, 0x04, 0x34, 0xf3, 0x1c, 0x0b, 0x0a, 0xb9, 0x13, 0xa4, 0x72, 0x22, 0xa8, 0xe4, 0x3a, 0x90,
		0xcb, 0x61, 0x20, 0x97, 0x9b, 0x40, 0x2d, 0xe7, 0x60, 0xb3, 0x30, 0x5b, 0xd6, 0x4d, 0x2c, 0xad,
		0x24, 0x3c, 0xc8, 0x5c, 0x4b, 0xd3, 0xe2, 0xeb, 0xf1, 0x6a, 0x32, 0xd6, 0x07, 0x1a, 0xfd, 0xac,
		0xc9, 0xa4, 0x0d, 0x52, 0x4a, 0x0b, 0x24, 0x99, 0xf6, 0x47, 0x2d, 0xad, 0x8f, 0x6c, 0xda, 0x1e,
		0xd9, 0xb4, 0x3c, 0xaa, 0x69, 0x77, 0x9b, 0xcd, 0xf8, 0x51, 0xe9, 0xef, 0x6c, 0x51, 0x9a, 0x0e,
		0x35, 0xef, 0x29, 0xa9, 0xa8, 0x35, 0xad, 0x01, 0x10, 0xe4, 0xf2, 0xed, 0x29, 0xe6, 0xd5, 0x93,
		0xce, 0x9f, 0xa7, 0x9a, 0x27, 0x4f, 0x3e, 0x1f, 0x9e, 0x7c, 0xde, 0x3b, 0xf5, 0xfc, 0x76, 0x64,
		0xa8, 0x50, 0x74, 0xc0, 0xe9, 0x82, 0xe6, 0x78, 0x4e, 0xd7, 0xb7, 0xbb, 0xee, 0xd0, 0xbd, 0xf2,
		0x7c, 0x2f, 0xf6, 0x44, 0x44, 0x77, 0x7a, 0xe3, 0x4f, 0xd6, 0x8c, 0x61, 0x8e, 0x1c, 0xdd, 0x39,
		0x65, 0xb7, 0xce, 0xc2, 0xbd, 0x53, 0x77, 0xf3, 0x6c, 0xdc, 0x3d, 0x1b, 0xb7, 0xcf, 0xc5, 0xfd,
		0xd3, 0x82, 0x01, 0xc4, 0xe0, 0x00, 0x59, 0x58, 0x90, 0x2e, 0x0c, 0xc3, 0x1c, 0x4d, 0x05, 0x01,
		0xe4, 0xc1, 0x00, 0x07, 0x50, 0xc0, 0x0a, 0x1c, 0x70, 0x01, 0x09, 0xec, 0xc0, 0x02, 0x3b, 0xd0,
		0xc0, 0x0d, 0x3c, 0xd0, 0x04, 0x11, 0x44, 0xc1, 0x04, 0x79, 0x50, 0x91, 0x2e, 0x50, 0xdc, 0x0d,
		0x45, 0xe8, 0x8d, 0xe5, 0xcf, 0xf5, 0xed, 0x98, 0x51, 0x2b, 0x9f, 0xe7, 0x0b, 0x27, 0xae, 0xe5,
		0x27, 0xe2, 0xda, 0x1d, 0xf9, 0x89, 0x92, 0x5f, 0xbb, 0x7e, 0x84, 0x26, 0x44, 0x9b, 0x01, 0x9c,
		0x38, 0x01, 0x28, 0x96, 0x40, 0x8a, 0x1b, 0xa0, 0x62, 0x0b, 0xac, 0xd8, 0x02, 0x2c, 0xae, 0x40,
		0x8b, 0x36, 0xe0, 0x22, 0x0e, 0xbc, 0xd2, 0x97, 0xce, 0xb0, 0x09, 0xd1, 0x60, 0xe0, 0x0b, 0x37,
		0x60, 0xd4, 0x85, 0x28, 0x9f, 0x47, 0x1b, 0x22, 0xd3, 0x94, 0xc7, 0x4a, 0xca, 0x89, 0xae, 0x47,
		0xbe, 0x1d, 0x8a, 0x28, 0x76, 0xc3, 0x78, 0x72, 0xc6, 0xe7, 0x33, 0x8a, 0x10, 0x5e, 0x7d, 0x02,
		0x84, 0x0a, 0x08, 0x15, 0x10, 0x2a, 0x20, 0x54, 0x40, 0xa8, 0x80, 0x50, 0x01, 0xa1, 0x02, 0xd0,
		0x0e, 0x42, 0x05, 0x84, 0x0a, 0x08, 0x15, 0x24, 0x86, 0x0a, 0x5f, 0x85, 0x3f, 0x14, 0x21, 0xe3,
		0x48, 0x61, 0xfa, 0x00, 0x08, 0x14, 0x10, 0x28, 0x20, 0x50, 0x40, 0xa0, 0x80, 0x40, 0x01, 0x81,
		0x02, 0x02, 0x05, 0x60, 0x1d, 0x04, 0x0a, 0x08, 0x14, 0x10, 0x28, 0xac, 0xfe, 0x6e, 0x87, 0x03,
		0x2f, 0x88, 0xed, 0x78, 0x60, 0x4f, 0x3e, 0x0c, 0x6e, 0x45, 0x68, 0xfb, 0x6e, 0xc0, 0x27, 0x50,
		0x78, 0xed, 0x01, 0x10, 0x28, 0x20, 0x50, 0x40, 0xa0, 0x80, 0x40, 0x01, 0x81, 0x02, 0x02, 0x05,
		0x04, 0x0a, 0xc0, 0x3a, 0x08, 0x14, 0x10, 0x28, 0x20, 0x50, 0x58, 0xfd, 0xdd, 0x46, 0xf1, 0xe8,
		0xca, 0x9e, 0x74, 0x81, 0xe5, 0x13, 0x1c, 0xcc, 0x2f, 0x1a, 0x01, 0x01, 0x02, 0x02, 0x04, 0x04,
		0x08, 0x08, 0x10, 0x10, 0x20, 0x20, 0x40, 0x40, 0x00, 0x4c, 0x83, 0x80, 0x00, 0x01, 0x01, 0x02,
		0x82, 0xd5, 0xdf, 0x6d, 0x1c, 0xba, 0xd7, 0xd7, 0x5e, 0xd7, 0x16, 0xc1, 0x8d, 0x17, 0x08, 0x11,
		0x7a, 0xc1, 0x0d, 0x9f, 0xc0, 0xe0, 0xa5, 0xc5, 0x23, 0x40, 0x40, 0x80, 0x80, 0x00, 0x01, 0x01,
		0x02, 0x02, 0x04, 0x04, 0x08, 0x08, 0x10, 0x80, 0x71, 0x10, 0x20, 0x20, 0x40, 0x20, 0x1f, 0x20,
		0xa0, 0xf5, 0xd3, 0x32, 0xf6, 0x9b, 0xe6, 0x38, 0xe8, 0x85, 0x75, 0x12, 0x1f, 0x6b, 0xb9, 0x38,
		0x0b, 0x30, 0x9d, 0x13, 0xbd, 0xf7, 0x7a, 0x13, 0xea, 0xbd, 0x49, 0x37, 0xca, 0x77, 0x50, 0x23,
		0x7e, 0x2b, 0xa2, 0xd6, 0x18, 0x96, 0xb8, 0x22, 0x9b, 0xa9, 0xc0, 0x14, 0x1b, 0x7b, 0xcb, 0x1d,
		0x6e, 0xdb, 0x4a, 0xf6, 0xa5, 0xf6, 0xb8, 0x03, 0x4e, 0xdb, 0xbf, 0x75, 0x6a, 0xf3, 0x3b, 0xf2,
		0x61, 0x7e, 0x43, 0xde, 0xc1, 0x62, 0x10, 0xb7, 0x16, 0x56, 0x30, 0xe8, 0x09, 0xdb, 0xed, 0xf5,
		0xbd, 0xc0, 0x8b, 0xe2, 0xd0, 0x8d, 0xbd, 0x5b, 0x61, 0xc7, 0xee, 0x0d, 0xe1, 0x31, 0x0e, 0xaf,
		0xae, 0x18, 0x43, 0x1c, 0xde, 0xb2, 0x2c, 0x0c, 0x71, 0x30, 0x94, 0xaf, 0xc3, 0x10, 0x87, 0x4d,
		0xe3, 0xdf, 0x30, 0xc4, 0xc1, 0x04, 0xac, 0x8e, 0x21, 0x0e, 0xeb, 0xd9, 0x64, 0x0c, 0x71, 0x30,
		0x0f, 0x0c, 0x70, 0x00, 0x05, 0xac, 0xc0, 0x01, 0x17, 0x90, 0xc0, 0x0e, 0x2c, 0xb0, 0x03, 0x0d,
		0xdc, 0xc0, 0x03, 0x4d, 0x10, 0x41, 0x14, 0x4c, 0x90, 0x07, 0x15, 0xe9, 0x02, 0x39, 0x50, 0x0e,
		0xaf, 0x5a, 0x7a, 0xfa, 0xec, 0xc3, 0x6b, 0x40, 0x04, 0xd9, 0x46, 0x9b, 0x03, 0x4c, 0x58, 0x02,
		0x14, 0x6e, 0x40, 0x85, 0x2d, 0x60, 0x61, 0x0b, 0x5c, 0xb8, 0x02, 0x18, 0xda, 0x40, 0x86, 0x38,
		0xa0, 0x49, 0x5f, 0x3a, 0xbf, 0x6c, 0xa3, 0x91, 0x17, 0xc4, 0xfb, 0x05, 0x46, 0xc9, 0x46, 0x87,
		0x0c, 0x96, 0xda, 0x72, 0x83, 0x9b, 0xf1, 0xee, 0x5e, 0xb0, 0x30, 0x55, 0x3c, 0x5c, 0x58, 0xb2,
		0xb1, 0xa7, 0x5e, 0xc0, 0xc6, 0xe7, 0x32, 0x03, 0xb7, 0x0b, 0xcb, 0xfe, 0xe2, 0xfa, 0x23, 0xc1,
		0x70, 0xdd, 0x1f, 0x43, 0xb7, 0x1b, 0x7b, 0x83, 0xe0, 0xc4, 0xbb, 0xf1, 0xe2, 0x71, 0xd8, 0x96,
		0x63, 0xb3, 0xfe, 0x87, 0xdf, 0x19, 0xa9, 0xa2, 0x7b, 0x07, 0x55, 0xd4, 0xac, 0x8a, 0xc5, 0x42,
		0xb9, 0x58, 0x3e, 0x38, 0x2c, 0x94, 0x4b, 0xd0, 0x49, 0x00, 0x62, 0x5e, 0xab, 0xec, 0x20, 0xb0,
		0x58, 0x43, 0x81, 0xea, 0x5e, 0x14, 0x57, 0xe2, 0x38, 0xe4, 0x11, 0x5c, 0x9c, 0x7a, 0x41, 0xd5,
		0x17, 0xe3, 0xe8, 0x37, 0xe2, 0x61, 0x6d, 0xc7, 0xde, 0x6c, 0x6e, 0xc5, 0xf9, 0xa3, 0x62, 0xf1,
		0xe0, 0xb0, 0x58, 0xcc, 0x1d, 0xee, 0x1f, 0xe6, 0xca, 0xa5, 0x52, 0xfe, 0x20, 0xcf, 0xc0, 0xe2,
		0x5a, 0x8d, 0xb0, 0x27, 0x42, 0xd1, 0x3b, 0xbe, 0xb7, 0xde, 0x6f, 0x05, 0x23, 0xdf, 0x47, 0x55,
		0x86, 0x41, 0x2b, 0x43, 0x55, 0xc6, 0x7a, 0xeb, 0x64, 0x9c, 0xd4, 0xfd, 0x5a, 0x4e, 0x29, 0x6a,
		0x32, 0xf8, 0xae, 0x08, 0x35, 0x19, 0x1b, 0xaf, 0xbe, 0x9b, 0x5a, 0x91, 0x71, 0x36, 0xe8, 0x89,
		0xca, 0x93, 0xed, 0x68, 0x8f, 0x77, 0x03, 0xe5, 0x18, 0xd4, 0x0d, 0x85, 0x15, 0x89, 0x9b, 0x31,
		0x44, 0x4e, 0x7a, 0x32, 0x7a, 0xc1, 0x8d, 0xed, 0xfa, 0x37, 0x83, 0xd0, 0x8b, 0xbf, 0xf6, 0xe9,
		0xd6, 0x63, 0xbc, 0xbe, 0x64, 0x14, 0x64, 0xbc, 0x65, 0x59, 0x28, 0xc8, 0x58, 0x43, 0xf8, 0x50,
		0x90, 0xb1, 0x8e, 0x42, 0xa0, 0x20, 0x43, 0x36, 0xc6, 0x43, 0x41, 0x06, 0x7f, 0xa0, 0x8e, 0x82,
		0x8c, 0x35, 0x01, 0x01, 0x0a, 0x32, 0x8c, 0x03, 0x03, 0x1c, 0x40, 0x01, 0x2b, 0x70, 0xc0, 0x05,
		0x24, 0xb0, 0x03, 0x0b, 0xec, 0x40, 0x03, 0x37, 0xf0, 0x40, 0x13, 0x44, 0x10, 0x05, 0x13, 0xe4,
		0x41, 0xc5, 0x23, 0xb8, 0x18, 0x0d, 0x87, 0x83, 0x30, 0x16, 0xbd, 0xc7, 0x00, 0x9e, 0x51, 0x45,
		0xc6, 0x8b, 0xab, 0x47, 0x49, 0xc6, 0x26, 0x40, 0x12, 0x4e, 0xd0, 0x84, 0x25, 0x44, 0xe1, 0x06,
		0x55, 0xd8, 0x42, 0x16, 0xb6, 0xd0, 0x85, 0x2b, 0x84, 0xa1, 0x0d, 0x65, 0x88, 0x43, 0x9a, 0xf4,
		0xa5, 0xf3, 0x2b, 0xc9, 0xf0, 0x7a, 0x22, 0x88, 0xbd, 0xf8, 0x3e, 0x14, 0xd7, 0x9c, 0x9a, 0xc0,
		0x72, 0xc8, 0x90, 0xaa, 0x4d, 0xb7, 0xf6, 0xd8, 0x8d, 0x18, 0x79, 0x8a, 0x99, 0x60, 0x9c, 0xb7,
		0x9c, 0x4a, 0xfd, 0x53, 0xa3, 0x55, 0x6b, 0xff, 0xe3, 0x94, 0x8b, 0xb3, 0x48, 0x52, 0x97, 0x23,
		0x36, 0xb5, 0x30, 0x5b, 0xac, 0xea, 0x61, 0x9e, 0x4a, 0x47, 0xf3, 0xa3, 0x85, 0x4a, 0x07, 0x88,
		0xc3, 0x4c, 0x1c, 0xda, 0xad, 0xda, 0x87, 0xb6, 0xc3, 0x4b, 0x2a, 0x58, 0xac, 0xb4, 0x03, 0xc4,
		0x68, 0x34, 0x62, 0x44, 0xae, 0xbd, 0xe2, 0x15, 0x23, 0xd7, 0x1e, 0xf6, 0x80, 0xf4, 0xca, 0x90,
		0x6b, 0xbf, 0xde, 0x3a, 0x19, 0x27, 0xeb, 0xbe, 0x9a, 0x2f, 0x88, 0x64, 0x7b, 0xbe, 0x2b, 0x42,
		0xb2, 0x3d, 0xf4, 0x77, 0x53, 0xb3, 0xed, 0xcf, 0x27, 0x1b, 0xd2, 0x9a, 0xec, 0x47, 0x25, 0xdd,
		0x0e, 0xa4, 0xdb, 0x53, 0x37, 0x15, 0x0b, 0xb9, 0xeb, 0x91, 0xd7, 0xb3, 0x7d, 0xf7, 0x4a, 0xf8,
		0x76, 0x38, 0x6d, 0x30, 0xc3, 0x24, 0xe9, 0xfe, 0xf9, 0xc2, 0x91, 0x7a, 0xff, 0x96, 0x65, 0x21,
		0xf5, 0x7e, 0x0d, 0x11, 0x44, 0xea, 0xfd, 0x3a, 0x0a, 0x81, 0xd4, 0x7b, 0xd9, 0x88, 0x0f, 0xa9,
		0xf7, 0xfc, 0x61, 0x3b, 0xd9, 0xd4, 0xfb, 0x31, 0xfa, 0xa5, 0x9f, 0x79, 0x9f, 0xac, 0x12, 0x89,
		0xf7, 0x26, 0x41, 0x01, 0x0e, 0x90, 0x80, 0x15, 0x34, 0xe0, 0x02, 0x11, 0xd8, 0x41, 0x05, 0x76,
		0x90, 0x81, 0x1b, 0x74, 0xa0, 0x09, 0x21, 0x88, 0x42, 0x09, 0xf2, 0x90, 0x62, 0x1e, 0x5a, 0xf0,
		0xc9, 0xb3, 0x1f, 0x2f, 0x96, 0x47, 0x5a, 0x7d, 0x1e, 0x69, 0xf5, 0x1b, 0x03, 0x3c, 0x58, 0x02,
		0x10, 0x6e, 0x40, 0x84, 0x2d, 0x20, 0x61, 0x0b, 0x4c, 0xb8, 0x02, 0x14, 0xda, 0x40, 0x85, 0x38,
		0x60, 0x61, 0x03, 0x5c, 0xd2, 0x85, 0xa6, 0x67, 0x0f, 0xfc, 0xf2, 0xbd, 0x1f, 0x97, 0xce, 0xc4,
		0x12, 0xf0, 0x00, 0x37, 0xec, 0x40, 0x0e, 0x47, 0xb0, 0xc3, 0x1a, 0xf4, 0x70, 0x05, 0x3f, 0xec,
		0x41, 0x10, 0x7b, 0x30, 0xc4, 0x1d, 0x14, 0xf1, 0x00, 0x47, 0x4c, 0x40, 0x12, 0x3b, 0xb0, 0xf4,
		0x08, 0x9a, 0x48, 0xf7, 0x72, 0xfa, 0x35, 0x70, 0x22, 0xdc, 0xe3, 0xc9, 0x10, 0xf0, 0xc4, 0x16,
		0x44, 0x71, 0x06, 0x53, 0x46, 0x80, 0x2a, 0xee, 0xe0, 0xca, 0x18, 0x90, 0x65, 0x0c, 0xd8, 0x32,
		0x05, 0x74, 0xf1, 0x02, 0x5f, 0xcc, 0x40, 0x18, 0x5b, 0x30, 0x96, 0x2e, 0x5c, 0x04, 0x71, 0x78,
		0x9f, 0x64, 0xc5, 0xf3, 0xb5, 0x99, 0x33, 0xc7, 0x35, 0xf7, 0x2c, 0x4c, 0x6d, 0x0d, 0xcf, 0x51,
		0x72, 0xec, 0x61, 0x9b, 0x09, 0xf0, 0xcd, 0x28, 0x18, 0x67, 0x0a, 0x9c, 0x33, 0x0e, 0xd6, 0x19,
		0x07, 0xef, 0x4c, 0x83, 0x79, 0x3c, 0xe1, 0x1e, 0x53, 0xd8, 0x97, 0x0a, 0x4f, 0x9b, 0x33, 0x7e,
		0x7a, 0xe2, 0x35, 0xa2, 0x30, 0x29, 0xac, 0x62, 0x0c, 0xa2, 0xe6, 0x81, 0x54, 0xbe, 0xc8, 0xf8,
		0x19, 0xaa, 0xc1, 0x28, 0x99, 0x81, 0xc3, 0x54, 0x95, 0xdf, 0xc1, 0xf8, 0xa8, 0x97, 0x91, 0x6b,
		0x2f, 0x8c, 0x62, 0xfb, 0x76, 0x3a, 0xca, 0x99, 0x79, 0xfc, 0x36, 0xff, 0x30, 0x08, 0xe0, 0x10,
		0xc0, 0x21, 0x80, 0x43, 0x00, 0x87, 0x00, 0x0e, 0x01, 0x1c, 0x02, 0x38, 0x60, 0x28, 0x04, 0x70,
		0x6f, 0xf4, 0x1a, 0x23, 0x2f, 0x88, 0xf7, 0x0b, 0x06, 0xc4, 0x6e, 0x87, 0x8c, 0x1f, 0xa1, 0x35,
		0x6d, 0xa5, 0x72, 0xc1, 0xda, 0xa4, 0xf2, 0x76, 0xd9, 0x5b, 0xd3, 0x46, 0x96, 0xec, 0xb1, 0x87,
		0x21, 0xc1, 0xc5, 0xc2, 0xe3, 0x7c, 0x99, 0x46, 0xad, 0xa6, 0x3c, 0xcf, 0xc7, 0xd0, 0xed, 0xc6,
		0xde, 0x20, 0x38, 0xf1, 0x6e, 0xbc, 0x49, 0xdf, 0x54, 0xf6, 0xcf, 0xf5, 0xf0, 0xbb, 0x01, 0x26,
		0xc0, 0xbd, 0x83, 0x09, 0x20, 0x6e, 0x02, 0x8a, 0x85, 0x72, 0xb1, 0x7c, 0x70, 0x58, 0x28, 0x97,
		0x60, 0x0b, 0x10, 0x90, 0x60, 0xf5, 0xf3, 0x5f, 0x1d, 0xd0, 0xff, 0x58, 0x31, 0x77, 0xcf, 0xcc,
		0xa5, 0xcb, 0xf4, 0xab, 0xeb, 0x37, 0xa8, 0x7b, 0xed, 0xb3, 0xc6, 0x99, 0x73, 0xff, 0x70, 0xf6,
		0x3f, 0x28, 0xb7, 0xa5, 0xe6, 0xaf, 0xbe, 0x28, 0x83, 0x82, 0x61, 0xd9, 0x30, 0x83, 0xc2, 0xa9,
		0x3c, 0x57, 0x7f, 0xff, 0xec, 0x73, 0xaf, 0x57, 0x1f, 0xef, 0x52, 0xc2, 0x1a, 0x4e, 0xfe, 0xff,
		0xf4, 0x27, 0x3c, 0x4c, 0x30, 0x7d, 0x83, 0xc6, 0xc0, 0x98, 0x31, 0x2b, 0x8f, 0x64, 0x59, 0x16,
		0x89, 0x5e, 0x12, 0x8a, 0x17, 0x8c, 0x5e, 0x12, 0x9a, 0x17, 0x8f, 0x5e, 0x12, 0x19, 0x3d, 0x00,
		0x7a, 0x49, 0x00, 0x73, 0x98, 0x13, 0x44, 0xb1, 0xeb, 0x25, 0x91, 0x04, 0x1a, 0x76, 0xe4, 0xfd,
		0x97, 0x71, 0x43, 0x89, 0xb9, 0x67, 0xe0, 0xd9, 0x55, 0x22, 0x87, 0xae, 0x12, 0x80, 0x55, 0x26,
		0xc3, 0x2b, 0xee, 0x30, 0xcb, 0x18, 0xb8, 0x65, 0x0c, 0xec, 0x32, 0x05, 0x7e, 0xf1, 0x82, 0x61,
		0xcc, 0xe0, 0x58, 0x2a, 0x24, 0x6c, 0xb3, 0x52, 0xf9, 0x67, 0xa3, 0x32, 0xce, 0x42, 0x65, 0x9e,
		0x7d, 0xca, 0x38, 0x07, 0xdb, 0x84, 0x6c, 0x53, 0x43, 0x52, 0xcc, 0x4c, 0xc9, 0x2e, 0x35, 0x29,
		0x93, 0x8c, 0x71, 0x36, 0xa9, 0x11, 0x59, 0xa4, 0xa6, 0xa9, 0x76, 0xfe, 0xe0, 0xf0, 0xf0, 0xb0,
		0x90, 0x3f, 0x80, 0x86, 0x23, 0x1c, 0xd8, 0xac, 0x55, 0x77, 0x90, 0x9a, 0xb5, 0xe9, 0x1e, 0xca,
		0x62, 0xd9, 0xb3, 0xef, 0x71, 0xaa, 0x16, 0xbf, 0x06, 0x33, 0xa0, 0xbd, 0x35, 0x2f, 0x1c, 0xb4,
		0x77, 0xc6, 0x0f, 0x01, 0xda, 0x9b, 0xc8, 0x83, 0x80, 0xf6, 0x06, 0xa2, 0xd9, 0x98, 0xb8, 0xdb,
		0x04, 0xda, 0x3b, 0xf0, 0x06, 0x01, 0x63, 0xd6, 0x3b, 0x5f, 0x66, 0xb8, 0xf6, 0xa9, 0xd8, 0x80,
		0xf5, 0xce, 0x48, 0xe8, 0xbd, 0x9e, 0x08, 0x62, 0x2f, 0xbe, 0x0f, 0xc5, 0xb5, 0x09, 0xad, 0x23,
		0x19, 0x97, 0x22, 0x5b, 0xb5, 0xe9, 0xab, 0x38, 0x76, 0x23, 0x03, 0x7a, 0x6f, 0xcd, 0x04, 0xac,
		0x71, 0xde, 0xfc, 0xe8, 0xb4, 0x6a, 0xce, 0x79, 0xcb, 0x39, 0xaf, 0x9d, 0x38, 0xf5, 0xca, 0x71,
		0xb5, 0xee, 0xb4, 0xeb, 0x5f, 0x9c, 0xf6, 0x5f, 0xcd, 0xea, 0xb9, 0x65, 0x02, 0xab, 0x19, 0xb1,
		0x6f, 0x1a, 0xb3, 0x65, 0x44, 0xe3, 0x98, 0x27, 0x72, 0xf7, 0x5c, 0xde, 0x2c, 0xd4, 0xf2, 0x67,
		0xfa, 0xd5, 0x01, 0x3f, 0x8e, 0xf8, 0x61, 0x23, 0x20, 0x95, 0x08, 0x46, 0x7d, 0x11, 0x4e, 0xaa,
		0x5b, 0xd1, 0x8d, 0x3b, 0xd3, 0x67, 0x40, 0x37, 0x6e, 0x18, 0x79, 0x13, 0xf6, 0x17, 0x85, 0x33,
		0x32, 0xad, 0x02, 0xba, 0x0f, 0x10, 0xee, 0x3e, 0xc0, 0xa7, 0x89, 0x09, 0x2a, 0xe8, 0x65, 0x08,
		0xf5, 0x28, 0xf8, 0x16, 0x0c, 0xfe, 0x13, 0xd8, 0xb1, 0x7f, 0xcb, 0xaf, 0x8e, 0x7e, 0x7e, 0xf1,
		0xa8, 0xa6, 0x57, 0xb1, 0x5c, 0x54, 0xd3, 0x6b, 0x14, 0x67, 0x54, 0xd3, 0xeb, 0x54, 0x44, 0x54,
		0xd3, 0x67, 0x8d, 0x03, 0x51, 0x4d, 0x0f, 0x0c, 0x32, 0x13, 0x06, 0x76, 0xd5, 0xf4, 0xbc, 0x5a,
		0x0f, 0x2d, 0xf8, 0x1a, 0x4e, 0x2d, 0x88, 0x98, 0x82, 0x27, 0xb6, 0x20, 0x8a, 0x33, 0x98, 0x32,
		0x02, 0x54, 0x71, 0x07, 0x57, 0xc6, 0x80, 0x2c, 0x63, 0xc0, 0x96, 0x29, 0xa0, 0x8b, 0x17, 0xf8,
		0x62, 0x06, 0xc2, 0xd8, 0x82, 0xb1, 0x74, 0xe1, 0xbe, 0x08, 0x6e, 0x12, 0x7a, 0x96, 0xf9, 0x54,
		0xcf, 0xe9, 0x73, 0x60, 0xa0, 0x27, 0xe0, 0xda, 0x66, 0xc1, 0x36, 0xa3, 0xe0, 0x9b, 0x29, 0x30,
		0xce, 0x38, 0x38, 0x67, 0x1c, 0xac, 0x33, 0x0d, 0xde, 0xf1, 0x84, 0x79, 0x4c, 0xe1, 0x5e, 0x2a,
		0x3c, 0x66, 0x0d, 0xf4, 0xcc, 0x1f, 0x18, 0x90, 0xfe, 0x75, 0x80, 0x81, 0x9e, 0x19, 0x7f, 0x61,
		0xa0, 0x27, 0x82, 0x0b, 0x85, 0x8f, 0x83, 0x81, 0x9e, 0x70, 0xe7, 0x3a, 0x4c, 0x00, 0x06, 0x7a,
		0x92, 0x37, 0x01, 0x07, 0xa5, 0xd2, 0x3e, 0x66, 0x79, 0x22, 0x16, 0xc1, 0xea, 0x9f, 0x7c, 0x61,
		0x96, 0x27, 0xdc, 0xdc, 0x6b, 0x66, 0x26, 0xe6, 0x1c, 0xb1, 0x72, 0xee, 0xeb, 0x64, 0x88, 0x2f,
		0x06, 0xd7, 0x4f, 0x49, 0x0f, 0xc0, 0xf5, 0x53, 0x52, 0x6c, 0x70, 0xfd, 0xc4, 0x1f, 0x08, 0x5c,
		0x3f, 0x50, 0xd3, 0xca, 0xc2, 0x03, 0xae, 0x9f, 0x1c, 0x86, 0x02, 0xd7, 0x9f, 0xf5, 0x17, 0xb8,
		0x7e, 0x04, 0x17, 0x0a, 0x1f, 0x07, 0x5c, 0x3f, 0xdc, 0xb9, 0x0e, 0x13, 0x00, 0xae, 0x9f, 0xbc,
		0x09, 0x00, 0xd7, 0x8f, 0x58, 0x04, 0xab, 0x5f, 0xf8, 0x02, 0xd7, 0x0f, 0x37, 0xf7, 0x9a, 0x99,
		0xb9, 0x9d, 0x9a, 0x4e, 0xe6, 0x64, 0xff, 0xe4, 0x31, 0xc0, 0xf6, 0x67, 0xb1, 0x7c, 0xb0, 0xfd,
		0x84, 0x14, 0x01, 0x6c, 0x3f, 0x25, 0xc5, 0x06, 0xdb, 0x4f, 0xfc, 0x81, 0xc0, 0xf6, 0x03, 0x37,
		0xad, 0x2c, 0x3c, 0xe6, 0xb0, 0xfd, 0x57, 0x5e, 0xe0, 0x86, 0xf7, 0x06, 0xb0, 0xfd, 0x65, 0x84,
		0x3a, 0x58, 0x31, 0x77, 0x03, 0xc3, 0xb5, 0x97, 0x67, 0xba, 0xfe, 0x4d, 0xe8, 0xe9, 0x39, 0xd7,
		0x25, 0x91, 0x53, 0x7f, 0x4f, 0x7e, 0x0a, 0x8c, 0x8e, 0x60, 0x30, 0x2d, 0x1b, 0x67, 0x52, 0x38,
		0xf5, 0xaa, 0x8c, 0xe2, 0x70, 0xd4, 0x8d, 0x83, 0x29, 0x94, 0x3c, 0x9b, 0xec, 0x75, 0x6d, 0xba,
		0xd5, 0x4e, 0x73, 0xba, 0xc1, 0x4e, 0x23, 0xd9, 0x60, 0xa7, 0x12, 0x0a, 0xd7, 0xa9, 0x47, 0xbd,
		0x2b, 0xa7, 0x1e, 0xb9, 0x63, 0x04, 0x3d, 0xfe, 0xee, 0x34, 0x92, 0xad, 0x1c, 0x7f, 0x6a, 0x25,
		0x3b, 0x59, 0x7b, 0xdc, 0x48, 0xa7, 0xed, 0xdf, 0x3a, 0xe7, 0x93, 0x3d, 0x6c, 0x4d, 0xb6, 0xf0,
		0xdc, 0xeb, 0xd5, 0xc7, 0x1b, 0x98, 0xe4, 0x47, 0x24, 0xff, 0xff, 0xf3, 0x64, 0xeb, 0xda, 0xfe,
		0x2d, 0xda, 0x2c, 0x6f, 0xc2, 0x0a, 0x89, 0x9b, 0x5b, 0xab, 0xee, 0x45, 0x71, 0x25, 0x8e, 0x79,
		0x34, 0xfc, 0xb1, 0x4e, 0xbd, 0xa0, 0xea, 0x8b, 0xb1, 0x82, 0x45, 0x3c, 0x68, 0x5c, 0xeb, 0xd4,
		0xbd, 0x9b, 0x5b, 0x71, 0xfe, 0xa8, 0x58, 0x3c, 0x38, 0x2c, 0x16, 0x73, 0x87, 0xfb, 0x87, 0xb9,
		0x72, 0xa9, 0x94, 0x3f, 0xe0, 0x30, 0x33, 0xcd, 0x6a, 0x84, 0x3d, 0x11, 0x8a, 0xde, 0xf1, 0xbd,
		0xf5, 0x7e, 0x2b, 0x18, 0xf9, 0x3e, 0x34, 0x6e, 0x73, 0x80, 0xcd, 0x26, 0x00, 0x1a, 0x06, 0x20,
		0x86, 0x02, 0x78, 0xa1, 0x8d, 0x58, 0xe8, 0xe2, 0x00, 0x9a, 0x2b, 0x23, 0x6a, 0x27, 0xb9, 0xd8,
		0x47, 0xd3, 0xed, 0x22, 0x4d, 0x65, 0xa7, 0xa7, 0x4a, 0xb4, 0x56, 0x44, 0x4c, 0xa9, 0xa9, 0x2b,
		0xb3, 0xc1, 0x4a, 0x4c, 0x10, 0xd3, 0x64, 0x8d, 0x61, 0x68, 0x99, 0x34, 0x3a, 0x86, 0x83, 0x90,
		0xd1, 0x20, 0x3a, 0x57, 0x81, 0xf4, 0xdc, 0x04, 0xa2, 0x73, 0x11, 0xc8, 0xa6, 0xdb, 0x51, 0x4e,
		0xa3, 0x63, 0x91, 0x1e, 0x47, 0x3d, 0xed, 0x8d, 0x4d, 0x3a, 0x1b, 0x9b, 0x34, 0x35, 0x2e, 0xe9,
		0x67, 0x00, 0xe3, 0x3f, 0x7b, 0x89, 0x54, 0xfb, 0xfa, 0xd3, 0xee, 0xe3, 0xc3, 0xa1, 0x4f, 0x0f,
		0xf1, 0xcc, 0x7c, 0xf2, 0x99, 0xf7, 0x1c, 0x32, 0xeb, 0x59, 0x65, 0xce, 0x73, 0xc9, 0x8c, 0x67,
		0x97, 0xf9, 0xce, 0x2e, 0xb3, 0x9d, 0x5b, 0xe6, 0x3a, 0xc8, 0xfa, 0x65, 0x5e, 0x2e, 0xf9, 0xcc,
		0xf2, 0xb9, 0x61, 0xd1, 0xde, 0x20, 0xa0, 0x6c, 0x31, 0x67, 0x51, 0x7c, 0x99, 0xf0, 0x1a, 0xa7,
		0xaf, 0x9b, 0x76, 0x9b, 0x17, 0x06, 0x67, 0xea, 0x33, 0xa1, 0xf4, 0x7a, 0x22, 0x88, 0xbd, 0xf8,
		0x3e, 0x14, 0xd7, 0x1c, 0xce, 0xa0, 0x67, 0x22, 0xca, 0x21, 0x67, 0xa5, 0x36, 0xdd, 0xda, 0x63,
		0x37, 0x12, 0xfc, 0x46, 0xdb, 0xb7, 0x6a, 0x4e, 0xfd, 0xbc, 0xe2, 0xb4, 0xeb, 0x5f, 0x9c, 0xf6,
		0x5f, 0xcd, 0xea, 0x39, 0x97, 0xf9, 0xf6, 0x49, 0x83, 0x8b, 0x88, 0x55, 0x27, 0x28, 0xa6, 0x13,
		0x7c, 0x5b, 0x35, 0xe7, 0xbc, 0xe5, 0x9c, 0xd7, 0x4e, 0x9c, 0x7a, 0xe5, 0xb8, 0x5a, 0x77, 0x5a,
		0x95, 0xb3, 0x4f, 0x55, 0x46, 0xe3, 0xb3, 0x7f, 0x87, 0x80, 0x28, 0x17, 0x90, 0x8f, 0x9f, 0xcf,
		0x3e, 0xb4, 0x6b, 0x8d, 0xb3, 0x4a, 0xdd, 0xf9, 0x50, 0x69, 0x56, 0x8e, 0x6b, 0xf5, 0x5a, 0xbb,
		0x56, 0x3d, 0x87, 0x94, 0x40, 0x4a, 0x9e, 0x9a, 0x91, 0x4a, 0xfd, 0x53, 0xa3, 0x55, 0x6b, 0xff,
		0xe3, 0x14, 0xa2, 0x01, 0xd1, 0x98, 0x13, 0x8d, 0xda, 0xd9, 0xc7, 0x46, 0xeb, 0xb4, 0x02, 0x1b,
		0x02, 0x41, 0xf9, 0xb9, 0xa0, 0x9c, 0x35, 0x4e, 0xaa, 0x4e, 0xe5, 0xe4, 0xb4, 0x76, 0xe6, 0xb4,
		0x2b, 0x9f, 0x2c, 0xd4, 0xec, 0x49, 0xfd, 0xea, 0xa0, 0x08, 0xc7, 0x64, 0x13, 0xc0, 0x88, 0xb0,
		0x10, 0xc1, 0xa8, 0x2f, 0xc2, 0x49, 0x42, 0x1f, 0x23, 0xc2, 0xa2, 0xc8, 0x60, 0xad, 0xd5, 0x60,
		0xd4, 0xb7, 0xde, 0x6f, 0x7d, 0x7f, 0x40, 0x96, 0xbd, 0x41, 0x46, 0x12, 0x09, 0xcb, 0xac, 0x4c,
		0x33, 0x12, 0x96, 0x15, 0x26, 0x2c, 0xd3, 0x6b, 0x3e, 0x81, 0x1c, 0xdc, 0x97, 0x64, 0x6c, 0xbe,
		0xbc, 0x9f, 0x6c, 0x26, 0x2e, 0xdd, 0x1e, 0x04, 0xc8, 0xc7, 0x5d, 0x72, 0x61, 0xc8, 0xc7, 0x5d,
		0x73, 0x91, 0xc8, 0xc7, 0x95, 0xb4, 0x50, 0xe4, 0xe3, 0x02, 0x6b, 0xea, 0x7b, 0x89, 0x64, 0xf3,
		0x71, 0x69, 0x16, 0xe1, 0x2c, 0xd8, 0x64, 0x8a, 0xc5, 0x38, 0xc4, 0x41, 0x00, 0x79, 0x30, 0xc0,
		0x01, 0x14, 0xb0, 0x02, 0x07, 0x5c, 0x40, 0x02, 0x3b, 0xb0, 0xc0, 0x0e, 0x34, 0x70, 0x03, 0x0f,
		0x34, 0x41, 0x04, 0x51, 0x30, 0x41, 0x1e, 0x54, 0xa4, 0x0b, 0xf4, 0x45, 0x70, 0x93, 0xb0, 0x57,
		0xc4, 0xed, 0xd0, 0xcc, 0xb8, 0x4f, 0xd7, 0x4b, 0x5c, 0xa7, 0x79, 0x8c, 0xe6, 0x60, 0x33, 0x82,
		0x83, 0xd3, 0xa8, 0x0d, 0x96, 0x23, 0x35, 0xb8, 0x8d, 0xce, 0x60, 0x3b, 0x22, 0x83, 0xed, 0x28,
		0x0c, 0xae, 0x23, 0x2f, 0x90, 0x0a, 0xb1, 0xce, 0x4b, 0x67, 0x33, 0xaa, 0x82, 0xdf, 0x00, 0x6a,
		0x46, 0x83, 0xa6, 0x99, 0x0d, 0x94, 0x66, 0xd4, 0x9e, 0x9c, 0xe3, 0x80, 0x68, 0xa6, 0x73, 0xe7,
		0xb8, 0x0e, 0x7c, 0xe6, 0x3c, 0xd1, 0x95, 0x51, 0xb2, 0x2f, 0xcb, 0x41, 0xcd, 0xdc, 0x55, 0x91,
		0xe1, 0xe0, 0x65, 0xd6, 0xea, 0x88, 0x19, 0x07, 0x52, 0xbe, 0x3a, 0xc8, 0x09, 0x35, 0xcd, 0x1d,
		0xd0, 0x6e, 0x7a, 0xb4, 0x10, 0xe5, 0x10, 0x6e, 0x7e, 0xc4, 0xcc, 0x37, 0x81, 0x03, 0x55, 0x29,
		0xa7, 0xe0, 0x40, 0x55, 0x2a, 0x18, 0x38, 0x50, 0xcd, 0x0b, 0x07, 0x07, 0xba, 0x79, 0x41, 0x22,
		0x38, 0x50, 0xf5, 0x18, 0x01, 0x1c, 0xa8, 0xec, 0x2f, 0x70, 0xa0, 0x00, 0xb7, 0x2f, 0x2c, 0x1b,
		0x1c, 0x28, 0xdc, 0xdb, 0xcf, 0x54, 0x11, 0x1c, 0xa8, 0x76, 0x55, 0x04, 0x07, 0x0a, 0x2c, 0xcc,
		0x70, 0x95, 0xe0, 0x40, 0x8d, 0x73, 0x07, 0xd6, 0xed, 0xd4, 0x24, 0x31, 0x21, 0x41, 0x27, 0xcb,
		0x05, 0x0b, 0x2a, 0x63, 0x99, 0x60, 0x41, 0x15, 0x0a, 0x2a, 0x58, 0x50, 0x95, 0x0a, 0x06, 0x16,
		0x54, 0xf3, 0xc2, 0xc1, 0x82, 0x6e, 0x5e, 0x98, 0xc8, 0x90, 0x05, 0xbd, 0xf2, 0x02, 0x37, 0xbc,
		0x67, 0xc4, 0x82, 0x96, 0x01, 0xa9, 0x0d, 0x5a, 0x19, 0x06, 0x3a, 0xaf, 0xb7, 0x4e, 0xc6, 0xad,
		0x95, 0xe6, 0x9a, 0xe1, 0x50, 0x6c, 0xb3, 0x44, 0x57, 0x6f, 0xd0, 0xa0, 0x82, 0xb1, 0xe6, 0x1a,
		0xa2, 0xb1, 0x9b, 0x3a, 0xa9, 0xf9, 0xf3, 0x64, 0x0b, 0xda, 0xfe, 0x2d, 0x9a, 0xc2, 0x51, 0x5e,
		0x09, 0x11, 0xab, 0x64, 0xd5, 0xbd, 0x28, 0xae, 0xc4, 0x31, 0xad, 0xf2, 0x76, 0xeb, 0xd4, 0x0b,
		0xaa, 0xbe, 0x18, 0x47, 0xa7, 0x11, 0x2d, 0x32, 0xcb, 0x3a, 0x75, 0xef, 0xe6, 0x56, 0x96, 0x3f,
		0x2a, 0x16, 0x0f, 0x0e, 0x8b, 0xc5, 0xdc, 0xe1, 0xfe, 0x61, 0xae, 0x5c, 0x2a, 0xe5, 0x0f, 0x28,
		0x8d, 0xf1, 0xb1, 0x1a, 0x61, 0x4f, 0x84, 0xa2, 0x77, 0x7c, 0x6f, 0xbd, 0xdf, 0x0a, 0x46, 0xbe,
		0x0f, 0xc9, 0xa7, 0xef, 0x87, 0x19, 0xfb, 0x5f, 0x8b, 0xd4, 0xc8, 0x7b, 0xe5, 0xbe, 0x96, 0x86,
		0x83, 0xcd, 0xde, 0x9d, 0x65, 0xbb, 0x82, 0x8c, 0xcd, 0x09, 0x35, 0x33, 0xc2, 0xd4, 0x7c, 0x64,
		0xab, 0x4b, 0xd9, 0x49, 0x70, 0x36, 0x77, 0xce, 0x48, 0x67, 0xa8, 0xe8, 0x0a, 0x3f, 0x1d, 0xc9,
		0xd0, 0xb3, 0xaa, 0xf6, 0xa4, 0xd9, 0x68, 0xbe, 0x7e, 0xbd, 0xcb, 0x40, 0xe7, 0x32, 0x6e, 0x39,
		0x4a, 0xa2, 0xa5, 0x68, 0xc6, 0x2d, 0x43, 0x33, 0xcf, 0xc8, 0xa0, 0x90, 0x69, 0x41, 0x2a, 0x83,
		0x82, 0x4a, 0x66, 0x04, 0xb9, 0x8c, 0x07, 0x72, 0x99, 0x0c, 0xd4, 0x32, 0x14, 0x36, 0x0b, 0xab,
		0x65, 0xdd, 0xf2, 0xd2, 0x8a, 0xba, 0x03, 0x02, 0xb9, 0x0a, 0x8f, 0x4e, 0x2c, 0x59, 0x4e, 0xc6,
		0x1a, 0x41, 0x23, 0x0d, 0x91, 0x4c, 0x9a, 0x21, 0xa5, 0x34, 0x42, 0x92, 0x69, 0x82, 0xd4, 0xd2,
		0x00, 0xc9, 0xa6, 0xf9, 0x91, 0x4d, 0xe3, 0xa3, 0x9a, 0xa6, 0xb7, 0xd9, 0xa4, 0x1f, 0x99, 0x34,
		0x3a, 0xa2, 0x33, 0x24, 0x29, 0xcd, 0x88, 0x24, 0x32, 0x03, 0x32, 0x43, 0x8e, 0x31, 0xc3, 0x60,
		0x8b, 0x44, 0x3f, 0x1e, 0x4a, 0xfd, 0x76, 0x00, 0xe1, 0x00, 0xe1, 0x00, 0xe1, 0x00, 0xe1, 0x00,
		0xe1, 0x00, 0xe1, 0x9e, 0x59, 0x1d, 0xaf, 0x27, 0x82, 0xd8, 0x8b, 0xef, 0x43, 0x71, 0x4d, 0x09,
		0xc2, 0x11, 0x48, 0x68, 0xb2, 0x6a, 0xd3, 0xad, 0x39, 0x76, 0x23, 0x42, 0x96, 0x70, 0xf6, 0xe2,
		0x1a, 0xe7, 0xcd, 0x8f, 0x4e, 0xa3, 0x59, 0xf9, 0x7f, 0x9f, 0xab, 0x4e, 0xfd, 0xbc, 0xe2, 0xb4,
		0xff, 0x6a, 0x56, 0xa9, 0x18, 0xc5, 0xa4, 0x3f, 0x41, 0x44, 0xaa, 0xe1, 0x0d, 0xd1, 0xd9, 0xb7,
		0x9f, 0x5a, 0x95, 0x0f, 0xc9, 0xfb, 0xb3, 0x30, 0xbf, 0x98, 0xcd, 0x4b, 0x1b, 0xab, 0xde, 0x97,
		0x82, 0x53, 0xfd, 0xb3, 0x5d, 0x3d, 0x3b, 0xa9, 0x9e, 0x38, 0xf5, 0xda, 0xd9, 0x3f, 0xf1, 0xfe,
		0xf8, 0xbe, 0xbf, 0x66, 0xab, 0xfa, 0xb1, 0xf6, 0x27, 0xde, 0x20, 0x9f, 0x37, 0xd8, 0x6a, 0x7c,
		0x6e, 0x57, 0x5b, 0x4e, 0xed, 0xec, 0x63, 0xa3, 0x75, 0x5a, 0x69, 0xd7, 0x1a, 0x67, 0x78, 0x7b,
		0x7c, 0xde, 0x5e, 0xbb, 0x55, 0xf9, 0xf8, 0xb1, 0xf6, 0xc1, 0xa9, 0x9e, 0x7d, 0xaa, 0x9d, 0x55,
		0xab, 0xad, 0xda, 0xd9, 0x27, 0x0b, 0x95, 0x1a, 0x4f, 0xbe, 0x3a, 0x9b, 0x1e, 0xa8, 0xe1, 0xc0,
		0x5d, 0x0f, 0x4b, 0x80, 0xe4, 0xc8, 0xb7, 0x24, 0x47, 0x66, 0x58, 0x89, 0xbb, 0x19, 0x49, 0x83,
		0x71, 0xe8, 0x5e, 0x5f, 0x7b, 0x5d, 0x5b, 0x04, 0x37, 0x5e, 0x20, 0x44, 0xe8, 0x05, 0x37, 0xd9,
		0xa7, 0x10, 0xbe, 0xb4, 0x28, 0x24, 0x14, 0x66, 0xb2, 0x00, 0x24, 0x14, 0x3e, 0x5b, 0x0c, 0x12,
		0x0a, 0x5f, 0x59, 0x10, 0x12, 0x0a, 0x81, 0x6f, 0x1e, 0x37, 0x3f, 0xf3, 0x84, 0xc2, 0xa4, 0xce,
		0x88, 0xce, 0x59, 0xf4, 0x78, 0x35, 0x34, 0xce, 0xa2, 0xf3, 0x38, 0x8b, 0x26, 0xe3, 0xda, 0x48,
		0xba, 0x38, 0x6a, 0xae, 0x8e, 0xac, 0xcb, 0x23, 0xeb, 0xfa, 0xa8, 0xba, 0x40, 0x22, 0x14, 0x47,
		0xc6, 0x76, 0x27, 0x6b, 0xd7, 0x38, 0xef, 0x22, 0xe9, 0x1d, 0xaf, 0xd2, 0xe9, 0x2c, 0x40, 0xc4,
		0x61, 0x92, 0x73, 0x9c, 0x14, 0x1d, 0x28, 0x69, 0x47, 0x4a, 0xd5, 0xa1, 0x92, 0x77, 0xac, 0xe4,
		0x1d, 0x2c, 0x75, 0x47, 0x4b, 0xc3, 0xe1, 0x12, 0x71, 0xbc, 0xe4, 0x1c, 0x70, 0xba, 0x20, 0xdf,
		0x0b, 0xbe, 0xd1, 0xb3, 0x0a, 0x33, 0x53, 0x9a, 0xac, 0x8e, 0x98, 0xbe, 0xd1, 0x72, 0xcd, 0x64,
		0x5d, 0x34, 0x65, 0x57, 0xcd, 0xc2, 0x65, 0x53, 0x77, 0xdd, 0x6c, 0x5c, 0x38, 0x1b, 0x57, 0xce,
		0xc5, 0xa5, 0xd3, 0x72, 0xed, 0xc4, 0x5c, 0x3c, 0x59, 0x57, 0x9f, 0x2e, 0x2c, 0x1a, 0x5d, 0xd9,
		0x24, 0x28, 0xea, 0x5f, 0x9a, 0xe5, 0x74, 0xa5, 0x44, 0xf5, 0x94, 0x26, 0x14, 0x20, 0x0f, 0x09,
		0x38, 0x40, 0x03, 0x56, 0x10, 0x81, 0x0b, 0x54, 0x60, 0x07, 0x19, 0xd8, 0x41, 0x07, 0x6e, 0x10,
		0x82, 0x26, 0x94, 0x20, 0x0a, 0x29, 0xc8, 0x43, 0x8b, 0xe7, 0x10, 0x83, 0xcf, 0x6c, 0xc0, 0xd9,
		0x82, 0x79, 0x4c, 0x07, 0xcc, 0x63, 0x3a, 0xe0, 0xc6, 0x00, 0x10, 0x96, 0x40, 0x84, 0x1b, 0x20,
		0x61, 0x0b, 0x4c, 0xd8, 0x02, 0x14, 0xae, 0x40, 0x85, 0x36, 0x60, 0x21, 0x0e, 0x5c, 0xd8, 0x00,
		0x98, 0x74, 0xa1, 0x6e, 0xaf, 0xef, 0x05, 0x5e, 0x14, 0x87, 0x6e, 0xec, 0xdd, 0x0a, 0xfb, 0x26,
		0x1c, 0x8c, 0x86, 0x11, 0x1f, 0x73, 0x36, 0xf3, 0x19, 0x2f, 0x3f, 0x06, 0x13, 0x0b, 0xc1, 0x03,
		0xf4, 0xb0, 0x03, 0x3f, 0x1c, 0x41, 0x10, 0x6b, 0x30, 0xc4, 0x15, 0x14, 0xb1, 0x07, 0x47, 0xec,
		0x41, 0x12, 0x77, 0xb0, 0xc4, 0x03, 0x34, 0x31, 0x01, 0x4f, 0xec, 0x40, 0xd4, 0x53, 0x30, 0x35,
		0x01, 0x1f, 0xfc, 0x8c, 0xdf, 0x13, 0x28, 0x35, 0x7d, 0x08, 0x66, 0xd6, 0x83, 0x17, 0x90, 0x62,
		0x0b, 0xa8, 0x38, 0x03, 0x2b, 0x23, 0x00, 0x16, 0x77, 0xa0, 0x65, 0x0c, 0xe0, 0x32, 0x06, 0x78,
		0x99, 0x02, 0xc0, 0x78, 0x01, 0x31, 0x66, 0x80, 0x8c, 0x2d, 0x30, 0x4b, 0x17, 0x7e, 0xe5, 0xc5,
		0xb6, 0x17, 0xf4, 0xc4, 0x1d, 0x5f, 0x93, 0x39, 0xf3, 0x5b, 0x8f, 0x8f, 0xc2, 0xd4, 0xd2, 0xd0,
		0x68, 0xdf, 0xbc, 0x71, 0xa0, 0xcd, 0x04, 0xf0, 0x66, 0x14, 0x88, 0x33, 0x05, 0xcc, 0x19, 0x07,
		0xea, 0x8c, 0x03, 0x77, 0xa6, 0x81, 0x3c, 0x9e, 0x60, 0x8f, 0x29, 0xe8, 0x4b, 0x85, 0x87, 0x4c,
		0xbb, 0xef, 0xb5, 0xbd, 0x86, 0x2f, 0xdc, 0x6b, 0x1a, 0x2d, 0xc2, 0xd7, 0x05, 0x51, 0xf9, 0x43,
		0xc6, 0xcf, 0xd0, 0x9c, 0x36, 0xc8, 0xdb, 0xdd, 0x9d, 0xb4, 0xa4, 0xdb, 0x7b, 0x84, 0xb6, 0xef,
		0x60, 0x8e, 0x60, 0x8a, 0x5e, 0x96, 0x9a, 0x6c, 0x27, 0xf2, 0x4a, 0xb3, 0x41, 0x59, 0x4e, 0xf4,
		0x95, 0x66, 0x7d, 0x10, 0xc2, 0x21, 0x84, 0x43, 0x08, 0x87, 0x10, 0x0e, 0x21, 0x1c, 0x42, 0x38,
		0x84, 0x70, 0xf4, 0x85, 0x87, 0x2b, 0x7f, 0x9f, 0x3e, 0x00, 0x7f, 0x1e, 0x7f, 0xc1, 0xff, 0x71,
		0xe7, 0xf3, 0x9f, 0x83, 0xc2, 0x1c, 0xf3, 0xc7, 0xe0, 0x0e, 0x0e, 0x4d, 0x02, 0x89, 0x46, 0x82,
		0x45, 0xd3, 0x40, 0xa3, 0xb1, 0xe0, 0xd1, 0x58, 0x10, 0x69, 0x2a, 0x98, 0xe4, 0x0d, 0x2a, 0x99,
		0x83, 0xcb, 0x54, 0xa8, 0xd8, 0x9f, 0x13, 0x2c, 0x78, 0x9d, 0x91, 0x17, 0xc4, 0x47, 0x26, 0x78,
		0x9c, 0x29, 0x44, 0x2b, 0x19, 0xf0, 0x28, 0x2d, 0x37, 0xb8, 0x11, 0xa4, 0x86, 0x72, 0xae, 0xf3,
		0x65, 0x06, 0x02, 0x48, 0x5e, 0xcc, 0xa9, 0x17, 0x18, 0x03, 0x69, 0x0c, 0x8b, 0x6d, 0x16, 0x1e,
		0x2b, 0x19, 0x6d, 0x6b, 0xe0, 0x73, 0x7d, 0x0c, 0xdd, 0x6e, 0xec, 0x0d, 0x82, 0x13, 0xef, 0xc6,
		0x8b, 0xa3, 0xf1, 0x03, 0x1a, 0xf3, 0x7c, 0x0f, 0xbf, 0x1b, 0x64, 0x2a, 0xdc, 0x3b, 0x98, 0x0a,
		0x66, 0xa6, 0x62, 0x3f, 0x0f, 0x5b, 0x81, 0x38, 0x08, 0x4f, 0xb1, 0xcc, 0x57, 0xe7, 0x1d, 0xf6,
		0x1f, 0xbe, 0x72, 0x39, 0xb3, 0x14, 0x89, 0xd8, 0x9c, 0x33, 0x8e, 0xf1, 0xc3, 0x30, 0x67, 0x35,
		0x4e, 0xc4, 0xb5, 0x3b, 0xf2, 0x13, 0xa6, 0xec, 0xda, 0xf5, 0x23, 0x81, 0xd3, 0x1a, 0x12, 0x8f,
		0x81, 0xd3, 0x1a, 0xc2, 0x6a, 0x8f, 0xd3, 0x1a, 0xca, 0x06, 0x00, 0xa7, 0x35, 0xcc, 0x1e, 0x0c,
		0xa7, 0x35, 0xc0, 0x98, 0xd2, 0x85, 0xca, 0xbc, 0xd3, 0x9a, 0xab, 0xc1, 0xc0, 0x17, 0x6e, 0x60,
		0xd0, 0x79, 0x4d, 0x3e, 0x8f, 0x00, 0x12, 0x2b, 0x37, 0xdd, 0x24, 0x59, 0x95, 0x20, 0x18, 0xc4,
		0x6e, 0xec, 0x0d, 0x78, 0x1f, 0x20, 0x59, 0x51, 0xf7, 0xab, 0xe8, 0xbb, 0xc3, 0x69, 0x75, 0xd3,
		0xde, 0x60, 0x28, 0x82, 0x6e, 0x12, 0xa6, 0xd8, 0x81, 0x88, 0xff, 0x33, 0x08, 0xbf, 0xd9, 0x5e,
		0x10, 0xc5, 0x6e, 0xd0, 0x15, 0x7b, 0xcf, 0x7f, 0x10, 0x2d, 0xfc, 0x64, 0x6f, 0x18, 0x0e, 0xe2,
		0x41, 0x77, 0xe0, 0x47, 0xe9, 0xa7, 0xbd, 0x89, 0xe7, 0xdf, 0x73, 0x43, 0xe1, 0x46, 0xc9, 0x9f,
		0x7b, 0x7e, 0xd4, 0xbb, 0xda, 0xf3, 0x23, 0xd7, 0x8e, 0xef, 0x87, 0x22, 0x4a, 0x3f, 0x8d, 0x3f,
		0x24, 0x7f, 0xdb, 0x1b, 0x0c, 0xdd, 0x7f, 0x8f, 0x84, 0x3d, 0xfe, 0x18, 0x87, 0xee, 0xf5, 0xb5,
		0xd7, 0xb5, 0x45, 0x70, 0xe3, 0x05, 0x42, 0x84, 0x5e, 0x70, 0xb3, 0x17, 0xfb, 0xb7, 0xd1, 0xf8,
		0x8f, 0x3d, 0xdf, 0x0b, 0xbe, 0xed, 0xcd, 0xa6, 0x93, 0xcc, 0x3e, 0xec, 0xbd, 0xd8, 0x65, 0x73,
		0x6f, 0xae, 0x61, 0xd4, 0xa4, 0x80, 0x0b, 0x65, 0x5b, 0x58, 0x31, 0x7b, 0x73, 0x34, 0x0e, 0x8c,
		0x38, 0xe7, 0xe5, 0x5a, 0x75, 0x2f, 0x8a, 0x2b, 0x71, 0xcc, 0xb4, 0x53, 0xcb, 0xa9, 0x17, 0x54,
		0x7d, 0x31, 0x0e, 0x73, 0x22, 0x9e, 0xac, 0x8e, 0x75, 0xea, 0xde, 0xcd, 0x3d, 0x41, 0xfe, 0xa8,
		0x58, 0x3c, 0x38, 0x2c, 0x16, 0x73, 0x87, 0xfb, 0x87, 0xb9, 0x72, 0xa9, 0x94, 0x3f, 0xc8, 0x33,
		0x4c, 0xbf, 0xb1, 0x1a, 0x61, 0x4f, 0x84, 0xa2, 0x77, 0x3c, 0x56, 0x8d, 0x60, 0xe4, 0xfb, 0xb0,
		0x40, 0x00, 0x42, 0x00, 0x40, 0x6c, 0x3b, 0x66, 0x4e, 0x5e, 0x53, 0x1c, 0x8e, 0xba, 0x71, 0x30,
		0x0d, 0x9b, 0xcf, 0x26, 0xfb, 0x5e, 0x9b, 0x6e, 0xbb, 0xd3, 0x9c, 0x6e, 0xb6, 0xd3, 0x48, 0x36,
		0xdb, 0xa9, 0x84, 0xc2, 0x75, 0xea, 0x51, 0xef, 0xca, 0xa9, 0x47, 0x6e, 0xfb, 0x7e, 0x28, 0xc6,
		0xdf, 0x9d, 0x46, 0xb2, 0xad, 0xe3, 0x4f, 0xed, 0xc9, 0xae, 0x56, 0x1f, 0x37, 0xd5, 0x69, 0xfb,
		0xb7, 0x4e, 0xdd, 0x0b, 0xbe, 0x39, 0xe7, 0xa3, 0xab, 0xf1, 0xe7, 0xca, 0x78, 0xbf, 0x3e, 0x25,
		0xdb, 0xf5, 0x0e, 0x78, 0x6b, 0x73, 0x57, 0xca, 0xa5, 0x0f, 0x31, 0x53, 0x3b, 0xbc, 0x29, 0xf6,
		0x97, 0x87, 0x11, 0xa1, 0xaf, 0x92, 0x0c, 0xd4, 0x91, 0x59, 0xd7, 0x0f, 0x96, 0x5d, 0x3e, 0x30,
		0x8e, 0x44, 0xf1, 0x82, 0x31, 0x8e, 0x44, 0xf3, 0xe2, 0x31, 0x8e, 0x24, 0xa3, 0x07, 0xc0, 0x38,
		0x12, 0x60, 0x0e, 0x73, 0xc2, 0x00, 0x76, 0xe3, 0x48, 0xc6, 0x18, 0xda, 0xf6, 0x7a, 0x7c, 0x47,
		0x91, 0xcc, 0x1e, 0x80, 0xe7, 0x18, 0x92, 0x1c, 0xc6, 0x90, 0x00, 0x50, 0x99, 0x0c, 0xac, 0xb8,
		0x03, 0x2c, 0x63, 0x80, 0x96, 0x31, 0x80, 0xcb, 0x14, 0xe0, 0xc5, 0x0b, 0x80, 0x31, 0x03, 0x62,
		0xa9, 0x90, 0xb0, 0xcd, 0x59, 0x4c, 0xad, 0x7e, 0x6f, 0x10, 0xc7, 0xa2, 0x67, 0xff, 0x7b, 0xe4,
		0xf6, 0x38, 0xda, 0xfd, 0x19, 0x53, 0x74, 0xc4, 0x70, 0xed, 0x4d, 0x37, 0x8e, 0x45, 0x18, 0xb0,
		0x6d, 0x1d, 0x61, 0x6d, 0x6f, 0x5f, 0xe4, 0xec, 0x72, 0xe7, 0xc7, 0x45, 0xde, 0x2e, 0x77, 0x26,
		0x1f, 0xf3, 0xc9, 0xb7, 0xc9, 0xe7, 0xc2, 0x45, 0xce, 0x2e, 0xce, 0x3e, 0x97, 0x2e, 0x72, 0x76,
		0xa9, 0xb3, 0x73, 0x79, 0xb9, 0xbb, 0xf3, 0x7d, 0xff, 0x61, 0xf9, 0x5f, 0xe4, 0x67, 0x79, 0x3b,
		0x38, 0x59, 0xdc, 0x74, 0x1f, 0x31, 0x09, 0x1f, 0x63, 0x8e, 0x4e, 0xe2, 0x69, 0x04, 0x9c, 0x3c,
		0x02, 0x62, 0x60, 0xc4, 0xc0, 0x88, 0x81, 0x11, 0x03, 0x23, 0x06, 0x46, 0x0c, 0x8c, 0x18, 0x18,
		0xf8, 0xc6, 0x98, 0x18, 0x58, 0x04, 0xa3, 0xbe, 0x08, 0x27, 0xe9, 0x55, 0x8c, 0x63, 0xe0, 0x22,
		0xc3, 0xb5, 0x57, 0x83, 0x51, 0x7f, 0x2c, 0x3c, 0x0f, 0x08, 0x96, 0x10, 0x2c, 0x0d, 0xba, 0xae,
		0x6f, 0x7b, 0x43, 0xdb, 0xed, 0xf5, 0x42, 0x11, 0x45, 0x8c, 0x63, 0xa6, 0xe7, 0x4f, 0x82, 0xd0,
		0x09, 0xa1, 0x13, 0x42, 0x27, 0x84, 0x4e, 0x08, 0x9d, 0x10, 0x3a, 0x21, 0x74, 0x02, 0xda, 0x31,
		0x26, 0x74, 0xf2, 0x86, 0xb7, 0xc5, 0x19, 0xca, 0xb1, 0x83, 0x81, 0xfd, 0xdf, 0x41, 0x20, 0x70,
		0x8e, 0xa8, 0x19, 0x3d, 0xe0, 0x1c, 0xf1, 0xed, 0xbf, 0xb8, 0xfd, 0xb7, 0x8b, 0xcb, 0xcb, 0xe1,
		0xf7, 0xb3, 0x87, 0xf1, 0x9f, 0xf5, 0x87, 0xce, 0xdf, 0x77, 0xfe, 0xe0, 0xea, 0x2b, 0xc7, 0x0f,
		0x76, 0x79, 0xb9, 0xdb, 0xf9, 0x0d, 0x67, 0xa3, 0x70, 0x2b, 0xf3, 0x82, 0x81, 0xbe, 0x0b, 0x19,
		0x3f, 0x01, 0xfa, 0x2e, 0x00, 0xc6, 0x9a, 0x6f, 0x6b, 0xac, 0xbe, 0x7b, 0xe7, 0xf5, 0x47, 0x7d,
		0xfb, 0xca, 0x0d, 0x7a, 0xff, 0xf1, 0x7a, 0x49, 0x91, 0x2f, 0x53, 0xc6, 0x6e, 0xf1, 0x51, 0x40,
		0xd9, 0xe9, 0x58, 0x36, 0x28, 0xbb, 0x0c, 0x85, 0x1e, 0x94, 0x5d, 0x96, 0x0a, 0x0b, 0xca, 0x8e,
		0xd8, 0x83, 0x80, 0xb2, 0x03, 0xde, 0xf9, 0xa5, 0x90, 0x18, 0x40, 0xd9, 0x09, 0x21, 0xae, 0xfd,
		0x81, 0x1b, 0xef, 0x17, 0x18, 0x33, 0x75, 0x65, 0x86, 0x4b, 0xaf, 0x8b, 0xe0, 0x26, 0x01, 0xc9,
		0x3c, 0x79, 0x3a, 0xc6, 0x8d, 0x70, 0x4d, 0x18, 0x05, 0x69, 0xca, 0xa0, 0x94, 0xd9, 0xfc, 0xb6,
		0x22, 0xf3, 0xe7, 0x30, 0x68, 0x5c, 0x1b, 0xe7, 0xf1, 0x54, 0x26, 0x8c, 0x6e, 0x84, 0x6a, 0x43,
		0xb5, 0x11, 0x0d, 0xb0, 0x5e, 0x35, 0xaa, 0xfd, 0x36, 0xde, 0x35, 0xa5, 0x24, 0x72, 0x28, 0x22,
		0x11, 0xde, 0xba, 0x57, 0xbe, 0x30, 0x89, 0x1a, 0x7f, 0xf1, 0xa9, 0xc0, 0x92, 0xeb, 0x58, 0x36,
		0x58, 0xf2, 0x0c, 0xe5, 0x1f, 0x2c, 0x79, 0x96, 0x0a, 0x0b, 0x96, 0x9c, 0xd8, 0x83, 0x80, 0x25,
		0x07, 0x0a, 0xfa, 0xa5, 0x90, 0x80, 0x25, 0xa7, 0x01, 0x74, 0xc0, 0x92, 0x6b, 0xff, 0x02, 0x4b,
		0x0e, 0x88, 0x2f, 0xe1, 0x31, 0x40, 0xa5, 0xc1, 0x09, 0xcb, 0x54, 0x6d, 0xb0, 0xe4, 0x50, 0x6d,
		0xa8, 0xb6, 0x19, 0xd1, 0x00, 0xdf, 0x55, 0x83, 0x25, 0xdf, 0x78, 0xd7, 0x64, 0xf5, 0x45, 0x1c,
		0x7a, 0x5d, 0xc6, 0x7c, 0xf8, 0x64, 0xfd, 0x60, 0xbe, 0x75, 0x2c, 0x1b, 0xcc, 0x77, 0x86, 0x92,
		0x0e, 0xe6, 0x3b, 0x4b, 0x85, 0x05, 0xf3, 0x4d, 0xec, 0x41, 0xc0, 0x7c, 0x03, 0xd9, 0xfc, 0x52,
		0x48, 0xf8, 0x33, 0xdf, 0x23, 0x2f, 0xe0, 0x4d, 0x7a, 0x1f, 0x32, 0x5c, 0x7a, 0xcb, 0x0d, 0x6e,
		0x04, 0x38, 0x6f, 0xfd, 0x1b, 0x0f, 0xce, 0x9b, 0xce, 0x63, 0xcc, 0x88, 0xb1, 0x1c, 0x88, 0x31,
		0xb8, 0x5f, 0x09, 0xaa, 0x0d, 0xce, 0x9b, 0x9c, 0x6a, 0x17, 0x0b, 0xe5, 0x62, 0xf9, 0xe0, 0xb0,
		0x50, 0x2e, 0x41, 0xc7, 0x11, 0x10, 0x6c, 0xd6, 0xaa, 0x41, 0x7e, 0x6f, 0xbc, 0x8f, 0xb2, 0x42,
		0xd1, 0x1f, 0xc4, 0xc2, 0x88, 0x26, 0xc7, 0x8b, 0x8f, 0x02, 0x4a, 0x5c, 0xc7, 0xb2, 0x41, 0x89,
		0x67, 0x28, 0xf4, 0xa0, 0xc4, 0xb3, 0x54, 0x58, 0x50, 0xe2, 0xc4, 0x1e, 0x04, 0x94, 0x38, 0xf0,
		0xce, 0x2f, 0x85, 0x04, 0x5d, 0x8e, 0x89, 0x21, 0x1e, 0x74, 0x39, 0xce, 0xe2, 0x01, 0xd0, 0xe5,
		0x78, 0xa5, 0x6d, 0x43, 0x97, 0x63, 0xb8, 0x95, 0x17, 0x05, 0x03, 0x5d, 0x8e, 0x33, 0x7e, 0x02,
		0x74, 0x39, 0x06, 0x8c, 0x35, 0xdf, 0xd6, 0x58, 0xbc, 0xc7, 0x37, 0x63, 0x72, 0xb3, 0xb6, 0x65,
		0x83, 0x98, 0xcb, 0x50, 0xce, 0x41, 0xcc, 0x65, 0xa9, 0xb0, 0x20, 0xe6, 0x88, 0x3d, 0x08, 0x88,
		0x39, 0xa0, 0x9a, 0x5f, 0x0a, 0x89, 0x01, 0xb9, 0xaa, 0x01, 0xf3, 0x99, 0xcd, 0x1c, 0x1b, 0x34,
		0x4c, 0xc5, 0x06, 0xa9, 0xaa, 0x19, 0x09, 0xbd, 0xd7, 0x13, 0x41, 0xec, 0xc5, 0xf7, 0xa1, 0xb8,
		0xb6, 0x18, 0xa7, 0xe7, 0xcd, 0x54, 0x80, 0x71, 0x26, 0x98, 0x55, 0x9b, 0xbe, 0x8a, 0x63, 0x37,
		0x12, 0xfc, 0x73, 0x0d, 0x67, 0x02, 0xd6, 0x38, 0x6f, 0x7e, 0x74, 0xda, 0x55, 0xa7, 0x5e, 0x3b,
		0xfb, 0xa7, 0xd3, 0xae, 0x7f, 0x71, 0xda, 0x7f, 0x35, 0xab, 0x96, 0x09, 0x19, 0x88, 0x11, 0x5b,
		0xbb, 0x65, 0x86, 0x0d, 0x7b, 0x51, 0xdc, 0x66, 0x92, 0xd6, 0xaa, 0x9e, 0x36, 0xda, 0x55, 0xa7,
		0xd6, 0xb4, 0xd8, 0x3f, 0xdf, 0xc3, 0xef, 0x10, 0x32, 0x9a, 0x42, 0x76, 0x5a, 0x6d, 0xb7, 0x6a,
		0x1f, 0x20, 0x61, 0x90, 0x30, 0x55, 0x12, 0x56, 0x39, 0x39, 0xad, 0x9d, 0x39, 0x9f, 0x5a, 0x8d,
		0xcf, 0x30, 0x64, 0x10, 0x33, 0x65, 0x62, 0x56, 0x3b, 0x81, 0x74, 0x41, 0xba, 0x94, 0xb9, 0xc9,
		0xca, 0x9f, 0xb5, 0xd3, 0xcf, 0xa7, 0xce, 0x71, 0xe5, 0xec, 0xe4, 0x7f, 0x6a, 0x27, 0xed, 0x7f,
		0x40, 0xd8, 0x20, 0x6c, 0xaa, 0x84, 0xad, 0xde, 0xf8, 0x50, 0xa9, 0x03, 0xf7, 0x43, 0xc6, 0x14,
		0xca, 0xd8, 0xe7, 0xb3, 0x56, 0xf5, 0xbc, 0xda, 0xfa, 0x52, 0x3d, 0x81, 0x4d, 0x83, 0xbc, 0xa9,
		0x97, 0xb7, 0x84, 0x32, 0x83, 0x7c, 0x41, 0xbe, 0x14, 0x03, 0xb4, 0x89, 0x55, 0xab, 0x1c, 0xd7,
		0xab, 0x46, 0xd9, 0x35, 0xd6, 0x4f, 0xd0, 0x41, 0x29, 0x38, 0xac, 0x94, 0xc9, 0x96, 0x29, 0xb5,
		0x46, 0x22, 0x18, 0xf5, 0x45, 0xe8, 0xc6, 0x3c, 0x4f, 0xe1, 0xd3, 0xc7, 0x99, 0x1d, 0x45, 0x32,
		0xee, 0xc8, 0x6c, 0x55, 0x83, 0x51, 0xdf, 0x7a, 0xbf, 0xf5, 0x1d, 0xdd, 0x1c, 0x60, 0xe4, 0x39,
		0xef, 0x2f, 0xa7, 0xd4, 0xf0, 0x51, 0xf0, 0x2d, 0x18, 0xfc, 0x27, 0xb0, 0x79, 0xa7, 0x88, 0x3f,
		0x79, 0x0a, 0xa4, 0x8a, 0xeb, 0x58, 0x36, 0x52, 0xc5, 0x33, 0x94, 0x77, 0xa4, 0x8a, 0x67, 0xa9,
		0xb0, 0x48, 0x15, 0x27, 0xf6, 0x20, 0x48, 0x15, 0x07, 0xca, 0xf9, 0xa5, 0x90, 0x98, 0xd1, 0xd6,
		0x38, 0x7f, 0xc0, 0x38, 0x57, 0xfc, 0x00, 0x6d, 0x8d, 0x35, 0x7f, 0xa1, 0xad, 0x31, 0xc0, 0xbd,
		0x84, 0xc7, 0x40, 0x5b, 0x63, 0xb8, 0x5f, 0x99, 0xaa, 0x8d, 0xb6, 0xc6, 0xe4, 0x54, 0xfb, 0xa0,
		0x54, 0xda, 0x47, 0x47, 0x63, 0xc4, 0x02, 0x1b, 0xb6, 0x6a, 0x70, 0xe0, 0x1b, 0xef, 0x9e, 0x52,
		0xf6, 0xf8, 0x76, 0x6a, 0x0a, 0x99, 0x93, 0xe0, 0x93, 0xc7, 0x00, 0x0b, 0xae, 0x63, 0xd9, 0x60,
		0xc1, 0x33, 0x14, 0x78, 0xb0, 0xe0, 0x59, 0x2a, 0x2c, 0x58, 0x70, 0x62, 0x0f, 0x02, 0x16, 0x1c,
		0x38, 0xe7, 0x97, 0x42, 0xc2, 0x9f, 0x05, 0xbf, 0xf2, 0x02, 0x37, 0xbc, 0x67, 0xcc, 0x82, 0x97,
		0x11, 0x72, 0x6c, 0xf0, 0x4a, 0x99, 0x18, 0x0c, 0xab, 0x12, 0x04, 0x83, 0x78, 0x92, 0x16, 0xc9,
		0xc9, 0x5c, 0x58, 0x51, 0xf7, 0xab, 0xe8, 0xbb, 0x43, 0x37, 0xfe, 0x3a, 0x36, 0x16, 0x7b, 0x83,
		0xa1, 0x08, 0xba, 0x09, 0x48, 0xb7, 0x03, 0x11, 0xff, 0x67, 0x10, 0x7e, 0xb3, 0xbd, 0x20, 0x8a,
		0xdd, 0xa0, 0x2b, 0xf6, 0x9e, 0xff, 0x20, 0x5a, 0xf8, 0xc9, 0xde, 0x30, 0x1c, 0xc4, 0x83, 0xee,
		0xc0, 0x8f, 0xd2, 0x4f, 0x7b, 0x13, 0xbf, 0xba, 0xe7, 0x86, 0xc2, 0x8d, 0x92, 0x3f, 0xf7, 0xfc,
		0xa8, 0x77, 0xb5, 0xe7, 0x47, 0x6e, 0x92, 0x7e, 0x14, 0xa5, 0x9f, 0xc6, 0x1f, 0x92, 0xbf, 0xed,
		0x0d, 0x86, 0xee, 0xbf, 0x47, 0xc2, 0x1e, 0x7f, 0x8c, 0x43, 0xf7, 0xfa, 0xda, 0xeb, 0xda, 0x22,
		0xb8, 0xf1, 0x02, 0x21, 0x42, 0x2f, 0xb8, 0xd9, 0x8b, 0xfd, 0xdb, 0x68, 0xfc, 0xc7, 0x9e, 0xef,
		0x05, 0xdf, 0xf6, 0xa2, 0xd1, 0x95, 0x9d, 0xfc, 0x64, 0xfa, 0x61, 0x2f, 0x8a, 0xdd, 0x58, 0xf0,
		0xf0, 0xe3, 0xf4, 0x55, 0x90, 0x81, 0xfa, 0xa5, 0x81, 0x7c, 0x34, 0xba, 0x8a, 0xfd, 0x5b, 0x36,
		0xea, 0xb7, 0x40, 0x44, 0x4c, 0xd7, 0xcf, 0xc4, 0xe0, 0xcd, 0x32, 0xa8, 0x99, 0x2c, 0x97, 0x1b,
		0xf3, 0xc0, 0x91, 0x71, 0x60, 0xcd, 0x34, 0x70, 0x65, 0x18, 0xd8, 0x33, 0x0b, 0xec, 0x19, 0x05,
		0xee, 0x4c, 0x02, 0x02, 0x01, 0x99, 0xc2, 0x70, 0xe2, 0x85, 0xcc, 0x22, 0x80, 0x04, 0x2f, 0xb3,
		0x3d, 0xc6, 0x99, 0x2c, 0x9f, 0xe7, 0xf1, 0x4d, 0x1e, 0xc7, 0x37, 0x00, 0x53, 0x26, 0x83, 0x2a,
		0xee, 0xe0, 0xca, 0x18, 0x90, 0x65, 0x0c, 0xd8, 0x32, 0x05, 0x74, 0xf1, 0x02, 0x5f, 0xcc, 0x40,
		0x18, 0x5b, 0x30, 0x96, 0x2e, 0xdc, 0x17, 0xc1, 0x4d, 0x42, 0xc9, 0x32, 0xb5, 0x97, 0x33, 0xa7,
		0x35, 0x7d, 0x0e, 0xa6, 0x36, 0x86, 0x77, 0xce, 0x2a, 0x5b, 0xb8, 0x66, 0x02, 0x6c, 0x33, 0x0a,
		0xbe, 0x99, 0x02, 0xe3, 0x8c, 0x83, 0x73, 0xc6, 0xc1, 0x3a, 0xd3, 0xe0, 0x1d, 0x4f, 0x98, 0xc7,
		0x14, 0xee, 0xa5, 0xc2, 0xc3, 0x36, 0x6b, 0x67, 0xc1, 0x6b, 0xb0, 0xad, 0x61, 0x7d, 0x8e, 0xa1,
		0x0e, 0x18, 0x3f, 0x02, 0xef, 0x9a, 0xd6, 0xd9, 0x17, 0xff, 0xb6, 0x88, 0x46, 0xd4, 0xb8, 0x1a,
		0x12, 0x5c, 0x2c, 0x3c, 0x8e, 0x21, 0x35, 0xaf, 0xe9, 0xf3, 0x18, 0x54, 0x1c, 0xc7, 0xdc, 0x9d,
		0x3f, 0x35, 0x01, 0x06, 0xd4, 0xc2, 0x9a, 0x6e, 0x02, 0x0c, 0xa8, 0x8d, 0x35, 0xda, 0x0c, 0xbc,
		0xc3, 0xea, 0xb3, 0xf8, 0xea, 0xa0, 0x46, 0x19, 0x6e, 0xee, 0x15, 0x33, 0x13, 0x73, 0x8e, 0x58,
		0xd3, 0x68, 0x95, 0x61, 0x3f, 0x49, 0x43, 0x7c, 0x31, 0xb8, 0x7e, 0x4a, 0x7a, 0x00, 0xae, 0x9f,
		0x92, 0x62, 0x83, 0xeb, 0x27, 0xfe, 0x40, 0xe0, 0xfa, 0x81, 0x9a, 0x56, 0x16, 0x1e, 0x70, 0xfd,
		0xe4, 0x30, 0x14, 0xb8, 0xfe, 0xac, 0xbf, 0xc0, 0xf5, 0x23, 0xb8, 0x50, 0xf8, 0x38, 0xe0, 0xfa,
		0xe1, 0xce, 0x75, 0x98, 0x00, 0x70, 0xfd, 0xe4, 0x4d, 0x00, 0xb8, 0x7e, 0xc4, 0x22, 0x58, 0xfd,
		0xc2, 0x17, 0xb8, 0x7e, 0xb8, 0xb9, 0xd7, 0xcc, 0x0c, 0xcf, 0xbe, 0x99, 0x0b, 0xe1, 0x2a, 0xc7,
		0xbe, 0x99, 0x86, 0x78, 0x63, 0xb0, 0xfd, 0x94, 0x14, 0x01, 0x6c, 0x3f, 0x25, 0xc5, 0x06, 0xdb,
		0x4f, 0xfc, 0x81, 0xc0, 0xf6, 0x03, 0x37, 0xad, 0x2c, 0x3c, 0xe6, 0xb0, 0xfd, 0x6c, 0xfb, 0x72,
		0x3e, 0xc7, 0x50, 0x65, 0x84, 0x3a, 0x58, 0x31, 0x77, 0x03, 0xc3, 0xb5, 0x7f, 0x67, 0xba, 0x7e,
		0xf3, 0xfa, 0x78, 0x3e, 0x6d, 0x8b, 0xc8, 0xa9, 0xad, 0x27, 0x3f, 0x8d, 0x45, 0x0b, 0x30, 0xd8,
		0x12, 0xf3, 0x6d, 0x08, 0xa7, 0x6e, 0x94, 0x51, 0x1c, 0x8e, 0xba, 0x71, 0x30, 0x05, 0x8b, 0x67,
		0x93, 0xcd, 0xad, 0x4d, 0xf7, 0xd6, 0x69, 0x4e, 0x77, 0xd4, 0x69, 0x24, 0x3b, 0xea, 0x54, 0x42,
		0xe1, 0x3a, 0xf5, 0xa8, 0x77, 0xe5, 0xd4, 0x23, 0x77, 0x8c, 0x91, 0xc7, 0xdf, 0x9d, 0x46, 0xb2,
		0x77, 0xe3, 0x4f, 0xed, 0xc9, 0xd6, 0x55, 0x1f, 0x77, 0xce, 0x69, 0xfb, 0xb7, 0x4e, 0xdd, 0x0b,
		0xbe, 0x39, 0xe7, 0xa3, 0xab, 0xf1, 0xe7, 0xcf, 0x93, 0xad, 0x3a, 0x9f, 0xec, 0x14, 0xda, 0x27,
		0x6f, 0x8a, 0xc5, 0xb2, 0x46, 0x41, 0x28, 0x22, 0x11, 0xde, 0x8a, 0x9e, 0x7d, 0xe5, 0x06, 0xbd,
		0xff, 0x78, 0xbd, 0xf8, 0x6b, 0xc4, 0xb1, 0x8b, 0xf2, 0x4b, 0x8f, 0x81, 0x66, 0xca, 0x2a, 0x96,
		0x8b, 0x66, 0xca, 0x1a, 0x05, 0x1b, 0xcd, 0x94, 0x75, 0x2a, 0x22, 0x9a, 0x29, 0x67, 0x0d, 0x9e,
		0xd1, 0x4c, 0x19, 0xb8, 0x64, 0x26, 0x0c, 0xec, 0x9a, 0x29, 0xbf, 0x84, 0x42, 0x38, 0x8f, 0xc8,
		0x7c, 0xe1, 0x69, 0xd0, 0x6a, 0x19, 0x10, 0xcb, 0x2c, 0xa8, 0x65, 0x04, 0xe4, 0xe2, 0x0e, 0xbd,
		0x8c, 0x81, 0x60, 0xc6, 0x40, 0x31, 0x53, 0x20, 0x19, 0x2f, 0x68, 0xc6, 0x0c, 0xa2, 0xb1, 0x85,
		0x6a, 0xe9, 0xc2, 0x87, 0xa1, 0x37, 0x08, 0xbd, 0xf8, 0x9e, 0x7f, 0x46, 0x66, 0xfa, 0x24, 0x48,
		0xca, 0x04, 0x64, 0xdb, 0x2c, 0xe8, 0x66, 0x14, 0x84, 0x33, 0x05, 0xca, 0x19, 0x07, 0xe9, 0x8c,
		0x83, 0x76, 0xa6, 0x41, 0x3c, 0x9e, 0x50, 0x8f, 0x29, 0xe4, 0x4b, 0x85, 0xc7, 0x9c, 0xa4, 0x4c,
		0x5f, 0xb8, 0xd7, 0xa1, 0xb8, 0x36, 0x20, 0x2b, 0x33, 0x7f, 0xc8, 0xf8, 0x19, 0x9a, 0xd3, 0x14,
		0x94, 0xdd, 0xdd, 0x49, 0xda, 0xd7, 0x5e, 0x8a, 0x6c, 0x91, 0x6b, 0x0a, 0x4b, 0xf4, 0x8a, 0xd0,
		0xf0, 0x9c, 0x63, 0xb8, 0x60, 0x82, 0x38, 0xce, 0x33, 0x5c, 0x30, 0x3e, 0x88, 0xe0, 0x10, 0xc1,
		0x21, 0x82, 0x43, 0x04, 0x87, 0x08, 0x0e, 0x11, 0x1c, 0x22, 0x38, 0xfa, 0xc2, 0xc3, 0x95, 0xbc,
		0x4f, 0x1f, 0x80, 0x3d, 0x89, 0xbf, 0xe0, 0xfe, 0x98, 0x93, 0xf9, 0xcf, 0x21, 0x21, 0xf3, 0xbe,
		0x47, 0xec, 0xa1, 0xa1, 0x49, 0x10, 0xd1, 0x48, 0xa8, 0x68, 0x1a, 0x64, 0x34, 0x16, 0x3a, 0x1a,
		0x0b, 0x21, 0x4d, 0x85, 0x92, 0xbc, 0x21, 0x25, 0x73, 0x68, 0x99, 0x0a, 0x15, 0xfb, 0x43, 0x82,
		0x05, 0xaf, 0x33, 0xf2, 0x82, 0xf8, 0xc8, 0x04, 0x8f, 0x33, 0x85, 0x68, 0x06, 0xb4, 0x71, 0x34,
		0xa4, 0x7d, 0xf3, 0xec, 0xcb, 0x0c, 0x04, 0xb0, 0x65, 0x5a, 0x3b, 0x67, 0xc3, 0x62, 0x9b, 0x85,
		0xc7, 0x32, 0xac, 0xbd, 0x73, 0xfa, 0x5c, 0x06, 0xf6, 0x77, 0x35, 0x04, 0x1d, 0x3c, 0x35, 0x15,
		0x06, 0xb5, 0x7d, 0xde, 0x14, 0x53, 0x71, 0x08, 0x53, 0x81, 0x30, 0x08, 0x4f, 0xb1, 0xcc, 0x57,
		0x07, 0xad, 0xb9, 0xe1, 0x2a, 0x97, 0x34, 0x4b, 0x46, 0x94, 0x97, 0xbe, 0x1e, 0x50, 0xf3, 0x2f,
		0x37, 0x35, 0xd4, 0xef, 0xe3, 0xf8, 0x83, 0xb2, 0xde, 0xe0, 0xf8, 0x83, 0xb2, 0x01, 0xc0, 0xf1,
		0x07, 0xb3, 0x07, 0xc3, 0xf1, 0x07, 0x50, 0x9b, 0x74, 0xa1, 0x32, 0xef, 0xf8, 0xc3, 0x13, 0x42,
		0x5c, 0xfb, 0x03, 0x37, 0xde, 0x2f, 0x18, 0x74, 0x08, 0x52, 0x36, 0xe0, 0x51, 0xea, 0x22, 0xb8,
		0x49, 0xe2, 0x02, 0x9c, 0x82, 0x10, 0x7b, 0x33, 0x38, 0x05, 0xe1, 0xf3, 0x58, 0x33, 0x6a, 0xb3,
		0x08, 0x6a, 0x13, 0x20, 0x21, 0x03, 0x53, 0x81, 0x53, 0x10, 0x98, 0x0a, 0x98, 0x0a, 0x44, 0x43,
		0x66, 0x3f, 0x05, 0x4e, 0x41, 0xb0, 0x72, 0xe3, 0x1d, 0x3c, 0xf7, 0xe9, 0x32, 0xe9, 0x73, 0x98,
		0x38, 0x21, 0xe2, 0x85, 0xb6, 0xf1, 0x2f, 0xfe, 0x94, 0xe3, 0x04, 0x1a, 0xbe, 0xda, 0x8e, 0x66,
		0x7d, 0x4a, 0x71, 0xb8, 0xb8, 0x67, 0x5c, 0x63, 0x66, 0xd5, 0xbd, 0x28, 0xae, 0xc4, 0x31, 0xd3,
		0x86, 0x83, 0xa7, 0x5e, 0x50, 0xf5, 0x45, 0x5f, 0x04, 0x13, 0x48, 0xcd, 0xb0, 0xd5, 0xc6, 0xa9,
		0x7b, 0x37, 0xf7, 0x04, 0xf9, 0xa3, 0x62, 0xf1, 0xe0, 0xb0, 0x58, 0xcc, 0x1d, 0xee, 0x1f, 0xe6,
		0xca, 0xa5, 0x52, 0xfe, 0x20, 0xcf, 0x30, 0x95, 0xdc, 0x6a, 0x84, 0x3d, 0x11, 0x8a, 0xde, 0xf1,
		0x58, 0x33, 0x82, 0x91, 0xef, 0xc3, 0x00, 0x01, 0x10, 0x01, 0x08, 0x99, 0x91, 0x92, 0x93, 0xc5,
		0x38, 0xad, 0xd9, 0xc6, 0x1d, 0xa7, 0xfb, 0x86, 0xe1, 0x85, 0x1b, 0xbc, 0x52, 0x0c, 0x2f, 0x84,
		0x45, 0x96, 0x60, 0x91, 0x31, 0x99, 0x6f, 0x13, 0x56, 0x48, 0xdc, 0x58, 0xf0, 0x0a, 0xc0, 0xf8,
		0x05, 0x5c, 0x46, 0x04, 0x58, 0xbc, 0x02, 0x2a, 0xea, 0x1a, 0xc7, 0xcc, 0x2d, 0x9b, 0xe7, 0x8e,
		0x19, 0x44, 0x3d, 0xda, 0xa3, 0x1c, 0xda, 0x60, 0x84, 0xae, 0x8b, 0xa7, 0xb9, 0x32, 0xa2, 0x26,
		0x90, 0x8b, 0xe9, 0x33, 0xc7, 0xe4, 0xd1, 0x54, 0x6b, 0x7a, 0x4a, 0x43, 0x6b, 0x45, 0xc4, 0xd4,
		0x97, 0xba, 0xda, 0xb2, 0x57, 0x57, 0x82, 0x80, 0x44, 0x1f, 0x00, 0xa1, 0x65, 0xa2, 0xe8, 0x18,
		0x02, 0x42, 0x46, 0xc0, 0x0a, 0x06, 0x3d, 0x61, 0xbb, 0x71, 0x1c, 0x7a, 0x57, 0x23, 0x82, 0x9d,
		0xf9, 0xd3, 0x42, 0x96, 0x67, 0xeb, 0x24, 0x66, 0x46, 0x69, 0xb6, 0xd4, 0x27, 0x5b, 0x10, 0x4c,
		0xb9, 0xc0, 0x97, 0x45, 0xc1, 0x2e, 0xf5, 0x02, 0x5c, 0x36, 0x05, 0xb5, 0x6c, 0x0a, 0x64, 0xb9,
		0x14, 0xbc, 0x02, 0x6e, 0xff, 0xec, 0x25, 0x52, 0x6d, 0xe1, 0x6e, 0xa5, 0x51, 0x25, 0x59, 0x8b,
		0x92, 0x8e, 0xde, 0x99, 0xad, 0x94, 0xa8, 0x9e, 0xd2, 0x9e, 0xae, 0x43, 0xbe, 0x47, 0x08, 0x87,
		0xde, 0x1f, 0xac, 0x7a, 0x7a, 0x70, 0xe9, 0xd5, 0xc1, 0xae, 0x07, 0x07, 0xbb, 0xde, 0x1a, 0xdc,
		0x7a, 0x66, 0x80, 0x80, 0x37, 0x01, 0x5a, 0x3c, 0x87, 0x18, 0xf4, 0x0d, 0xd1, 0x33, 0xa4, 0x41,
		0xdd, 0x0c, 0xf1, 0x18, 0xe7, 0xc7, 0xa6, 0x39, 0x19, 0xa7, 0xe6, 0x63, 0x2c, 0x9b, 0x8b, 0x71,
		0x6b, 0x1e, 0xc6, 0xb6, 0x39, 0x18, 0xdb, 0xe6, 0x5f, 0x5c, 0x9b, 0x7b, 0x21, 0x5d, 0xd1, 0x64,
		0x00, 0xf3, 0x08, 0x64, 0x58, 0xcd, 0x30, 0x66, 0x39, 0xb3, 0x98, 0xd9, 0x8c, 0x62, 0x76, 0x9d,
		0x57, 0x39, 0x76, 0x58, 0x65, 0xdd, 0x49, 0x95, 0x6b, 0xc7, 0x54, 0xf6, 0x9d, 0x51, 0xd9, 0x77,
		0x40, 0xe5, 0xde, 0xe9, 0x14, 0x85, 0x5f, 0x9b, 0x08, 0x92, 0xd2, 0x05, 0xfb, 0x83, 0xae, 0xeb,
		0xdb, 0xde, 0xf0, 0xb6, 0x68, 0xbb, 0xbd, 0x5e, 0x28, 0xa2, 0x48, 0x44, 0xfc, 0xac, 0xe0, 0xcc,
		0xf5, 0xbc, 0xf8, 0x34, 0xdc, 0xda, 0x4a, 0xb0, 0x6c, 0xef, 0xc6, 0xb6, 0xb9, 0x3d, 0xe7, 0x66,
		0xf6, 0x46, 0x34, 0xaf, 0xe7, 0xde, 0xac, 0xde, 0x98, 0xe6, 0xf4, 0xc6, 0x34, 0xa3, 0x37, 0xa5,
		0xf9, 0x3c, 0xda, 0x37, 0xa9, 0x14, 0x12, 0xb6, 0xcd, 0xe4, 0x1f, 0x9b, 0xc7, 0x8f, 0x71, 0x0e,
		0x5b, 0x93, 0x93, 0x72, 0x48, 0x47, 0x0c, 0xd7, 0xde, 0x74, 0xe3, 0x58, 0x84, 0x01, 0xdb, 0xf6,
		0xf0, 0xd6, 0xf6, 0xf6, 0x45, 0xce, 0x2e, 0x77, 0x7e, 0x5c, 0xe4, 0xed, 0x72, 0x67, 0xf2, 0x31,
		0x9f, 0x7c, 0x9b, 0x7c, 0x2e, 0x5c, 0xe4, 0xec, 0xe2, 0xec, 0x73, 0xe9, 0x22, 0x67, 0x97, 0x3a,
		0x3b, 0x97, 0x97, 0xbb, 0x3b, 0xdf, 0xf7, 0x1f, 0x96, 0xff, 0xc5, 0xbd, 0xe9, 0xcd, 0x76, 0x7e,
		0x6c, 0x5f, 0xe4, 0xed, 0x42, 0x67, 0xf6, 0x97, 0xfd, 0x8b, 0x9c, 0x5d, 0xe8, 0xec, 0xec, 0xf0,
		0xb3, 0xcc, 0x1d, 0x58, 0x66, 0x85, 0xb2, 0x89, 0xce, 0x74, 0x19, 0x3f, 0x01, 0x3a, 0xd3, 0x01,
		0x09, 0x9a, 0x6f, 0x6b, 0x1e, 0xd9, 0xa2, 0x03, 0xa3, 0xb8, 0xaf, 0x03, 0x70, 0x5f, 0x9a, 0x97,
		0x0d, 0xee, 0x2b, 0x43, 0xb9, 0x07, 0xf7, 0x95, 0xa5, 0xc2, 0x82, 0xfb, 0x22, 0xf6, 0x20, 0xe0,
		0xbe, 0x80, 0x7a, 0x7e, 0x29, 0x24, 0x46, 0x70, 0x5f, 0x07, 0xe0, 0xbe, 0xb2, 0x01, 0x0d, 0xfc,
		0xb9, 0xaf, 0xf7, 0x3f, 0x2e, 0x72, 0x76, 0xd9, 0xb5, 0xaf, 0x2b, 0xf6, 0xc7, 0xce, 0xf7, 0xdc,
		0xef, 0xc5, 0x87, 0x9d, 0xf7, 0x3b, 0xdb, 0xcf, 0x7f, 0xf6, 0x7e, 0xe7, 0x7b, 0xee, 0xf7, 0xd2,
		0xc3, 0xf6, 0xf6, 0x0b, 0xff, 0xe7, 0x8f, 0x97, 0xae, 0xb1, 0xf3, 0x63, 0x7b, 0x7b, 0x7b, 0xca,
		0x7a, 0x3d, 0x61, 0xc2, 0x2e, 0x72, 0xf9, 0xce, 0x1f, 0xc9, 0xc7, 0xc9, 0x9f, 0x29, 0x97, 0xf6,
		0xa6, 0x7f, 0xbc, 0xb3, 0xb3, 0x3d, 0x4f, 0xa1, 0x8d, 0xbf, 0x7f, 0x2f, 0x3c, 0xec, 0xfc, 0xd8,
		0xce, 0x5f, 0xe4, 0xec, 0x7c, 0x4a, 0xa7, 0xe5, 0xc7, 0x17, 0x39, 0x1a, 0xff, 0x73, 0xae, 0x4e,
		0x78, 0x7b, 0xfb, 0xe2, 0x7f, 0xdf, 0x77, 0xfe, 0xfe, 0x7e, 0xe7, 0xfb, 0xc1, 0xc3, 0xec, 0x73,
		0xf2, 0xe7, 0xce, 0x8f, 0xed, 0xdd, 0xdf, 0x2e, 0x2f, 0x77, 0x77, 0x7f, 0xdb, 0x99, 0x6c, 0xf2,
		0xf4, 0xdf, 0xfd, 0x36, 0xf9, 0xbf, 0x7f, 0xbc, 0x7f, 0xbf, 0xf0, 0xa3, 0x9d, 0xed, 0xbd, 0xdd,
		0xbf, 0x83, 0x5a, 0x84, 0xe3, 0x7b, 0x22, 0x61, 0xa0, 0x16, 0x33, 0x7e, 0x02, 0x50, 0x8b, 0x00,
		0xda, 0xe6, 0xdb, 0x1a, 0x2b, 0xe6, 0x08, 0xb0, 0x53, 0x70, 0x9d, 0xac, 0x1e, 0xd4, 0xa1, 0x8e,
		0x65, 0x83, 0x3a, 0xcc, 0x50, 0xce, 0x41, 0x1d, 0x66, 0xa9, 0xb0, 0xa0, 0x0e, 0x89, 0x3d, 0x08,
		0xa8, 0x43, 0xa0, 0x9a, 0x5f, 0x0a, 0x09, 0x7f, 0xea, 0x70, 0x14, 0x78, 0x83, 0x80, 0x33, 0x69,
		0x58, 0x66, 0xb8, 0xf6, 0xa9, 0xd8, 0xf0, 0x64, 0x0c, 0x19, 0x0f, 0x1b, 0x4e, 0xf9, 0xf2, 0x9e,
		0x08, 0x62, 0x2f, 0xbe, 0x0f, 0xc5, 0xb5, 0xc5, 0x77, 0xc0, 0x7e, 0xaa, 0x02, 0x25, 0xc6, 0xcf,
		0x50, 0x9b, 0xbe, 0x8a, 0x63, 0x37, 0x12, 0xac, 0x27, 0x59, 0x3f, 0x11, 0xb0, 0x76, 0xd5, 0x39,
		0x6b, 0x9c, 0x54, 0x9d, 0x4a, 0xbb, 0xdd, 0xaa, 0x1d, 0x7f, 0x6e, 0x57, 0x9d, 0x76, 0xfd, 0x8b,
		0xd3, 0xfe, 0xab, 0x59, 0x65, 0x2c, 0x6f, 0xc9, 0x13, 0x7e, 0x71, 0xfd, 0x51, 0x92, 0x18, 0x74,
		0xc1, 0xfa, 0x39, 0x78, 0x1b, 0xb2, 0x17, 0x65, 0x2e, 0x11, 0xb8, 0x5a, 0xf3, 0xcb, 0x81, 0x53,
		0x6f, 0x7c, 0xa8, 0xd4, 0x9d, 0xca, 0xc9, 0x49, 0xab, 0x7a, 0x7e, 0x6e, 0xb1, 0x7f, 0xca, 0x87,
		0xdf, 0x21, 0x6a, 0x34, 0x45, 0xad, 0x68, 0x9c, 0xa8, 0xb1, 0x7e, 0x82, 0xce, 0x3b, 0xec, 0x3b,
		0x0c, 0xd3, 0x26, 0x00, 0x78, 0x11, 0x8c, 0xfa, 0x22, 0x9c, 0x8c, 0x82, 0x31, 0x00, 0xc0, 0x17,
		0x19, 0x3f, 0x43, 0x35, 0x18, 0xf5, 0xc7, 0xc0, 0x9d, 0xa9, 0x0a, 0x23, 0x25, 0x02, 0xfb, 0xcb,
		0x68, 0xa5, 0x98, 0xf9, 0xad, 0x76, 0xdd, 0x9c, 0x47, 0x78, 0x3d, 0x9d, 0x3a, 0xb4, 0x38, 0xfd,
		0x7b, 0xd2, 0x53, 0x0f, 0xd3, 0xbe, 0x37, 0x45, 0x11, 0xad, 0x51, 0xf0, 0x2d, 0x18, 0xfc, 0x27,
		0xb0, 0xa3, 0xd1, 0x15, 0x87, 0x5e, 0xd6, 0x0b, 0x28, 0xef, 0xd9, 0xfa, 0xd1, 0x0d, 0x52, 0xc5,
		0x72, 0xd1, 0x0d, 0x52, 0xa3, 0x44, 0xa3, 0x1b, 0xa4, 0x4e, 0x45, 0x44, 0x37, 0xc8, 0xac, 0x51,
		0x20, 0xba, 0x41, 0x02, 0x89, 0xcc, 0x84, 0x81, 0x5d, 0x37, 0x48, 0x5e, 0xad, 0xb3, 0x17, 0x7c,
		0x0d, 0xa7, 0x16, 0xda, 0x4c, 0xc1, 0x13, 0x5b, 0x10, 0xc5, 0x19, 0x4c, 0x19, 0x01, 0xaa, 0xb8,
		0x83, 0x2b, 0x63, 0x40, 0x96, 0x31, 0x60, 0xcb, 0x14, 0xd0, 0xc5, 0x0b, 0x7c, 0x31, 0x03, 0x61,
		0x6c, 0xc1, 0x58, 0xba, 0x70, 0x5f, 0x04, 0x37, 0x09, 0x39, 0xcb, 0xd4, 0x5e, 0xa6, 0x0d, 0x8a,
		0x26, 0xcf, 0xc1, 0xd4, 0xc6, 0xf0, 0xac, 0x2f, 0x62, 0x0f, 0xd7, 0x4c, 0x80, 0x6d, 0x46, 0xc1,
		0x37, 0x53, 0x60, 0x9c, 0x71, 0x70, 0xce, 0x38, 0x58, 0x67, 0x1a, 0xbc, 0xe3, 0x09, 0xf3, 0x98,
		0xc2, 0xbd, 0x54, 0x78, 0xd8, 0xd6, 0x2b, 0x2d, 0x78, 0x8d, 0x91, 0x17, 0xc4, 0xf9, 0x03, 0x03,
		0x92, 0xbf, 0x0e, 0x18, 0x3f, 0x42, 0xcb, 0x0d, 0x6e, 0x04, 0xfb, 0x5a, 0x00, 0xfe, 0xc9, 0xd9,
		0xd6, 0xa9, 0x17, 0xb0, 0xc7, 0x1e, 0x86, 0x04, 0x17, 0x0b, 0x8f, 0x93, 0x54, 0xcc, 0x18, 0xf4,
		0x3c, 0x1f, 0x43, 0xb7, 0x1b, 0x7b, 0x83, 0xe0, 0xc4, 0xbb, 0xf1, 0x26, 0xad, 0x77, 0x50, 0x61,
		0x42, 0xc1, 0x04, 0xb8, 0x77, 0x30, 0x01, 0xc4, 0x4d, 0xc0, 0x41, 0xa9, 0xb4, 0x5f, 0x82, 0x19,
		0x40, 0x2c, 0x82, 0xd5, 0xcf, 0x7f, 0x75, 0x50, 0x3a, 0x00, 0x37, 0xf7, 0x8a, 0x99, 0x89, 0x39,
		0x47, 0xac, 0x9c, 0x7b, 0x88, 0x19, 0xe2, 0x8b, 0xc1, 0xf5, 0x53, 0xd2, 0x03, 0x70, 0xfd, 0x94,
		0x14, 0x1b, 0x5c, 0x3f, 0xf1, 0x07, 0x02, 0xd7, 0x0f, 0xd4, 0xb4, 0xb2, 0xf0, 0x80, 0xeb, 0x27,
		0x87, 0xa1, 0xc0, 0xf5, 0x67, 0xfd, 0x05, 0xae, 0x1f, 0xc1, 0x85, 0xc2, 0xc7, 0x01, 0xd7, 0x0f,
		0x77, 0xae, 0xc3, 0x04, 0x80, 0xeb, 0x27, 0x6f, 0x02, 0xc0, 0xf5, 0x23, 0x16, 0xc1, 0xea, 0x17,
		0xbe, 0xc0, 0xf5, 0xc3, 0xcd, 0xbd, 0x66, 0x66, 0x6e, 0xa7, 0xa6, 0x93, 0x39, 0xd9, 0x3f, 0x79,
		0x0c, 0xb0, 0xfd, 0x59, 0x2c, 0x1f, 0x6c, 0x3f, 0x21, 0x45, 0x00, 0xdb, 0x4f, 0x49, 0xb1, 0xc1,
		0xf6, 0x13, 0x7f, 0x20, 0xb0, 0xfd, 0xc0, 0x4d, 0x2b, 0x0b, 0x8f, 0x39, 0x6c, 0xff, 0x95, 0x17,
		0xb8, 0xe1, 0xbd, 0x01, 0x6c, 0x7f, 0x19, 0xa1, 0x0e, 0x56, 0xcc, 0xdd, 0xc0, 0x70, 0xed, 0xe4,
		0x99, 0xae, 0xdf, 0xe4, 0x8e, 0x9e, 0x4f, 0x1b, 0x24, 0x72, 0x6a, 0xf0, 0xc9, 0x4f, 0x77, 0xd1,
		0x0c, 0x0c, 0x56, 0x65, 0x93, 0xac, 0x09, 0xa7, 0x0e, 0x95, 0x51, 0x1c, 0x8e, 0xba, 0x71, 0x30,
		0x9b, 0x4e, 0x32, 0xd9, 0xe6, 0xda, 0x74, 0x97, 0x9d, 0xe6, 0x74, 0x6f, 0x9d, 0x46, 0xb2, 0xb7,
		0x4e, 0x25, 0x14, 0xae, 0x53, 0x8f, 0x7a, 0x57, 0x4e, 0x3d, 0x72, 0xc7, 0xb8, 0x79, 0xfc, 0xdd,
		0x69, 0x24, 0xbb, 0x38, 0xfe, 0xd4, 0x9e, 0x6c, 0x62, 0xf5, 0x71, 0x0f, 0x9d, 0xb6, 0x7f, 0xeb,
		0x9c, 0x0d, 0x7a, 0xa2, 0x32, 0xdb, 0x3d, 0xe7, 0x7c, 0x74, 0x35, 0xfe, 0xe1, 0xe7, 0xc9, 0x9e,
		0x9d, 0x4f, 0xb6, 0x0c, 0xbd, 0x95, 0x37, 0x60, 0x85, 0xc4, 0x4d, 0x2c, 0xaf, 0xa9, 0xfe, 0xfc,
		0xa6, 0xf8, 0x1b, 0x31, 0xb5, 0x9f, 0xd7, 0x94, 0x7e, 0xea, 0x1a, 0xc7, 0x0c, 0xcc, 0x98, 0x0c,
		0x62, 0x18, 0xa0, 0x96, 0xec, 0xd0, 0x0a, 0x6d, 0x7c, 0x42, 0xd7, 0xeb, 0xd3, 0x5c, 0x19, 0x51,
		0xab, 0xc8, 0xc5, 0x1a, 0x9a, 0x68, 0x05, 0x69, 0x2a, 0x38, 0x3d, 0xf5, 0xa1, 0xb5, 0x22, 0x62,
		0x8a, 0x4c, 0x5d, 0x81, 0x0d, 0x52, 0x5c, 0x82, 0x68, 0x25, 0x03, 0x74, 0x42, 0xcb, 0x6a, 0xd1,
		0xb1, 0x0d, 0x84, 0xec, 0x82, 0x15, 0x0e, 0x46, 0xb1, 0x08, 0x6d, 0xb7, 0xd7, 0x0b, 0x45, 0x14,
		0x91, 0xb3, 0x0b, 0xe9, 0xe1, 0xf1, 0xb3, 0x75, 0x12, 0xb3, 0xac, 0x34, 0xa7, 0x1b, 0x90, 0x4d,
		0x9a, 0xa3, 0x9c, 0x0c, 0xc7, 0x22, 0xc9, 0x8d, 0x7a, 0xf2, 0x1a, 0x9b, 0xa4, 0x34, 0x36, 0xc9,
		0x66, 0x5c, 0x92, 0xc8, 0x80, 0xc0, 0x7f, 0xf6, 0x12, 0xa9, 0x76, 0xe7, 0x27, 0x3e, 0x12, 0x89,
		0xc5, 0xe8, 0x23, 0xe2, 0x23, 0x8e, 0xc8, 0x67, 0xd0, 0x73, 0xc8, 0x90, 0x67, 0x95, 0x01, 0xcf,
		0x25, 0xc3, 0x9d, 0x5d, 0x06, 0x3b, 0xbb, 0x0c, 0x75, 0x6e, 0x19, 0xe8, 0xe0, 0xe5, 0x4d, 0x00,
		0x15, 0xe9, 0x02, 0xa9, 0x92, 0x0b, 0xaf, 0x5a, 0x77, 0x9a, 0x2c, 0xc3, 0x6b, 0x80, 0x83, 0x78,
		0x6e, 0x05, 0x9b, 0xd2, 0x3d, 0x4e, 0x25, 0x7a, 0x2c, 0x4b, 0xf1, 0xb8, 0x95, 0xdc, 0xb1, 0x2d,
		0xad, 0x63, 0x5b, 0x42, 0xc7, 0xb5, 0x54, 0x0e, 0x89, 0x8d, 0xeb, 0xbc, 0x74, 0x36, 0x25, 0x6e,
		0xa9, 0xd5, 0xf5, 0x86, 0xb7, 0xc5, 0xd9, 0x59, 0x84, 0x1d, 0x0c, 0xec, 0xff, 0x0e, 0x02, 0x0e,
		0x8d, 0x01, 0x52, 0x8a, 0xe2, 0x88, 0xc1, 0x5a, 0x9b, 0x6e, 0x1c, 0x8b, 0x30, 0x60, 0xd3, 0x99,
		0xce, 0xda, 0xde, 0xbe, 0xc8, 0xd9, 0xe5, 0xce, 0x8f, 0x8b, 0xbc, 0x5d, 0xee, 0x4c, 0x3e, 0xe6,
		0x93, 0x6f, 0x93, 0xcf, 0x85, 0x8b, 0x9c, 0x5d, 0x9c, 0x7d, 0x2e, 0x5d, 0xe4, 0xec, 0x52, 0x67,
		0xe7, 0xf2, 0x72, 0x77, 0xe7, 0xfb, 0xfe, 0xc3, 0xf2, 0xbf, 0xb8, 0xfd, 0xb7, 0x8b, 0xcb, 0xcb,
		0xe1, 0xf7, 0xb3, 0x87, 0xf1, 0x9f, 0xf5, 0x87, 0xce, 0xdf, 0x77, 0xfe, 0xe0, 0xe2, 0x9b, 0xc6,
		0x0f, 0x72, 0x79, 0xb9, 0xdb, 0xf9, 0x8d, 0xbe, 0x59, 0xef, 0x20, 0xaf, 0x0e, 0xf1, 0xbb, 0x7a,
		0xcc, 0x83, 0xbc, 0x3a, 0xe5, 0xe9, 0x39, 0x4f, 0xd3, 0x07, 0x28, 0x17, 0x54, 0x22, 0xa9, 0x8e,
		0x95, 0x16, 0x23, 0xa9, 0x4e, 0x9b, 0xd6, 0x6e, 0x6c, 0x52, 0x5d, 0x2b, 0xd9, 0x86, 0xca, 0x74,
		0x17, 0x90, 0x54, 0x47, 0xdd, 0x2e, 0x10, 0x3d, 0x4d, 0x27, 0x7d, 0x8a, 0x8e, 0x14, 0xba, 0x65,
		0xc3, 0x63, 0xa4, 0xd0, 0xad, 0xb7, 0x48, 0xa4, 0xd0, 0x49, 0x5a, 0x28, 0x52, 0xe8, 0x80, 0xb7,
		0xf5, 0xbd, 0x44, 0xb2, 0x29, 0x74, 0xa4, 0x07, 0xda, 0x71, 0x18, 0x58, 0x47, 0xfc, 0x3c, 0x1b,
		0x09, 0x74, 0x9b, 0x02, 0x0d, 0xb8, 0x40, 0x04, 0x76, 0x50, 0x81, 0x1d, 0x64, 0xe0, 0x06, 0x1d,
		0x68, 0x42, 0x08, 0xa2, 0x50, 0x22, 0x7d, 0xb9, 0xe4, 0xcf, 0x9f, 0x1f, 0xcf, 0x9d, 0x7b, 0x22,
		0x88, 0xbd, 0xf8, 0x3e, 0x14, 0xd7, 0x94, 0xed, 0xe6, 0x2c, 0x96, 0x27, 0xdc, 0x30, 0xc7, 0xaa,
		0x4d, 0xb7, 0xf2, 0xd8, 0x8d, 0x04, 0x9f, 0xcc, 0xc4, 0xc6, 0x79, 0xf3, 0xa3, 0xd3, 0xae, 0x3a,
		0xf5, 0xf3, 0x8a, 0xd3, 0xae, 0x7f, 0x71, 0xda, 0x7f, 0x35, 0xab, 0xd4, 0x8d, 0x7d, 0x32, 0x38,
		0x27, 0x62, 0x71, 0x8e, 0xcf, 0x24, 0x2f, 0x6d, 0x26, 0x0d, 0x63, 0x41, 0xa8, 0x9d, 0xfd, 0xd3,
		0xa9, 0x37, 0x3e, 0x54, 0xea, 0x0c, 0xb2, 0xa4, 0x7e, 0x87, 0x00, 0x48, 0x17, 0x80, 0x46, 0xb3,
		0x5d, 0xfb, 0x50, 0xa9, 0x3b, 0x67, 0x8d, 0x93, 0xaa, 0xd3, 0x6c, 0x35, 0x9a, 0xd5, 0x56, 0xfb,
		0x2f, 0xc8, 0xc2, 0xc6, 0x1a, 0x03, 0xbc, 0xfa, 0x8d, 0x7c, 0xf5, 0xad, 0xc6, 0xe7, 0x76, 0xb5,
		0xe5, 0xd4, 0x9a, 0x5f, 0x0e, 0x9c, 0xca, 0xc9, 0x49, 0xab, 0x7a, 0x7e, 0x0e, 0x49, 0xd8, 0x48,
		0x49, 0x48, 0x1c, 0x41, 0xa5, 0xdd, 0x6e, 0xd5, 0x8e, 0x3f, 0xb7, 0xab, 0x10, 0x82, 0x4d, 0x36,
		0x07, 0x7c, 0x2c, 0x01, 0xe9, 0x15, 0x76, 0x40, 0xf4, 0x30, 0x5f, 0x15, 0xce, 0xd4, 0x7e, 0x66,
		0x38, 0x90, 0xc3, 0xa6, 0x2e, 0x87, 0x8d, 0x60, 0xaa, 0x29, 0x92, 0xb6, 0x5e, 0x12, 0xb2, 0xd9,
		0x94, 0x84, 0xd8, 0xbf, 0xa5, 0x9b, 0xba, 0x35, 0xbf, 0x48, 0x24, 0x70, 0xbd, 0x65, 0x59, 0x48,
		0xe0, 0x5a, 0x43, 0xdc, 0x90, 0xc0, 0xb5, 0x8e, 0x42, 0x20, 0x81, 0x4b, 0x36, 0x4e, 0x41, 0x02,
		0x17, 0x7f, 0xb0, 0x89, 0x1e, 0x68, 0xeb, 0xd9, 0x64, 0xf4, 0x40, 0x33, 0x0f, 0x0c, 0x70, 0x00,
		0x05, 0xac, 0xc0, 0x01, 0x17, 0x90, 0xc0, 0x0e, 0x2c, 0xb0, 0x03, 0x0d, 0xdc, 0xc0, 0x03, 0x4d,
		0x10, 0x41, 0x14, 0x4c, 0x90, 0x07, 0x15, 0xe9, 0x02, 0x7d, 0x11, 0xdc, 0x24, 0xf4, 0x15, 0x93,
		0x44, 0xa3, 0xe9, 0x7a, 0xd1, 0x01, 0x6d, 0x13, 0x60, 0x07, 0x27, 0xf8, 0xc1, 0x12, 0x86, 0x70,
		0x83, 0x23, 0x6c, 0x61, 0x09, 0x5b, 0x78, 0xc2, 0x15, 0xa6, 0xd0, 0x86, 0x2b, 0xc4, 0x61, 0x4b,
		0xfa, 0xd2, 0xf9, 0x75, 0x40, 0x1b, 0x79, 0x41, 0x9c, 0x3f, 0x60, 0xd4, 0xf3, 0xec, 0x80, 0xc1,
		0x52, 0x5b, 0x6e, 0x70, 0x23, 0xd8, 0x34, 0x3c, 0x63, 0x34, 0xdd, 0xfd, 0xd4, 0xe3, 0x35, 0x8e,
		0x9e, 0x11, 0xb8, 0x5d, 0x58, 0x76, 0x92, 0xee, 0xcf, 0x70, 0xdd, 0x1f, 0x43, 0xb7, 0x1b, 0x7b,
		0x83, 0xe0, 0xc4, 0xbb, 0xf1, 0x26, 0x33, 0xab, 0xd9, 0xac, 0xff, 0x81, 0xd1, 0x48, 0xff, 0x53,
		0xf7, 0x0e, 0xaa, 0xa8, 0x59, 0x15, 0x0f, 0x4a, 0xa5, 0xfd, 0x12, 0xd4, 0x11, 0x58, 0x98, 0xd7,
		0x2a, 0xd1, 0x7e, 0xd3, 0x38, 0x77, 0x40, 0xbb, 0x4b, 0xc6, 0x42, 0x94, 0x43, 0xb8, 0x5b, 0x06,
		0x33, 0xdf, 0x04, 0x0e, 0x54, 0xa5, 0x9c, 0x82, 0x03, 0x55, 0xa9, 0x60, 0xe0, 0x40, 0x35, 0x2f,
		0x1c, 0x1c, 0xe8, 0xe6, 0x05, 0x89, 0xe0, 0x40, 0xd5, 0x63, 0x04, 0x70, 0xa0, 0xb2, 0xbf, 0xc0,
		0x81, 0x02, 0xdc, 0xbe, 0xb0, 0x6c, 0x70, 0xa0, 0x70, 0x6f, 0x3f, 0x53, 0x45, 0x70, 0xa0, 0xda,
		0x55, 0x11, 0x1c, 0x28, 0xb0, 0x30, 0xc3, 0x55, 0x82, 0x03, 0x35, 0xce, 0x1d, 0x58, 0xb7, 0x53,
		0x93, 0xc4, 0x84, 0x04, 0x9d, 0x2c, 0x17, 0x2c, 0xa8, 0x8c, 0x65, 0x82, 0x05, 0x55, 0x28, 0xa8,
		0x60, 0x41, 0x55, 0x2a, 0x18, 0x58, 0x50, 0xcd, 0x0b, 0x07, 0x0b, 0xba, 0x79, 0x61, 0x22, 0x43,
		0x16, 0xf4, 0xca, 0x0b, 0xdc, 0xf0, 0x9e, 0x11, 0x0b, 0x5a, 0x06, 0xa4, 0x36, 0x68, 0x65, 0x98,
		0xea, 0xb9, 0xde, 0x3a, 0x39, 0xf7, 0x56, 0x9a, 0xeb, 0x86, 0x83, 0x91, 0x9e, 0x7c, 0x57, 0x84,
		0x76, 0x68, 0x1b, 0xa9, 0xb2, 0x1b, 0x3b, 0xcf, 0xf3, 0xf3, 0x64, 0x0f, 0xda, 0xfe, 0x2d, 0xfa,
		0xc2, 0x51, 0x5e, 0x09, 0x11, 0xbb, 0x64, 0xd5, 0xbd, 0x28, 0xae, 0xc4, 0x31, 0xad, 0x0a, 0x77,
		0xeb, 0xd4, 0x0b, 0xaa, 0xbe, 0x18, 0x07, 0xa8, 0x11, 0x2d, 0x3e, 0xcb, 0x3a, 0x75, 0xef, 0xe6,
		0x56, 0x96, 0x3f, 0x2a, 0x16, 0x0f, 0x0e, 0x8b, 0xc5, 0xdc, 0xe1, 0xfe, 0x61, 0xae, 0x5c, 0x2a,
		0xe5, 0x0f, 0x28, 0xcd, 0x25, 0xb1, 0x1a, 0x61, 0x4f, 0x84, 0xa2, 0x77, 0x7c, 0x6f, 0xbd, 0xdf,
		0x0a, 0x46, 0xbe, 0x0f, 0xc9, 0xa7, 0xef, 0x89, 0x39, 0x7b, 0x60, 0x8b, 0xd4, 0x9c, 0x64, 0xf5,
		0xde, 0x96, 0x86, 0x8b, 0xcd, 0xde, 0xa1, 0x65, 0xbb, 0x82, 0x8c, 0x0d, 0x0a, 0x35, 0x43, 0xc2,
		0xd5, 0x80, 0x64, 0xab, 0x4c, 0xd9, 0x89, 0x70, 0x36, 0x77, 0xce, 0x48, 0x69, 0xa8, 0x28, 0x0b,
		0x43, 0x25, 0xc9, 0xd0, 0xb9, 0x2a, 0x77, 0xa6, 0xd9, 0xe8, 0xbe, 0x7e, 0xcd, 0xcb, 0x40, 0xeb,
		0x48, 0xf4, 0x1e, 0x27, 0xd4, 0x63, 0x3c, 0xe3, 0x36, 0xa2, 0x99, 0x67, 0x69, 0x50, 0xc8, 0xbe,
		0x20, 0x95, 0x55, 0x41, 0x25, 0x5b, 0x82, 0x5c, 0x16, 0x04, 0xb9, 0xec, 0x06, 0x6a, 0x59, 0x0b,
		0x9b, 0x85, 0xdc, 0xb2, 0x6e, 0x83, 0x49, 0xa4, 0x87, 0x36, 0xa9, 0x5e, 0xd9, 0x44, 0x7a, 0x62,
		0x93, 0x49, 0x3d, 0xa4, 0x94, 0x5a, 0x48, 0x32, 0x75, 0x90, 0x5a, 0x6a, 0x20, 0xd9, 0xd4, 0x3f,
		0xb2, 0xa9, 0x7d, 0x54, 0x53, 0xf7, 0x36, 0x9b, 0x03, 0xa4, 0xd2, 0x23, 0x9a, 0x5a, 0x2f, 0x68,
		0x9a, 0x3d, 0x9f, 0x89, 0x65, 0xf4, 0x93, 0xcb, 0xdc, 0xa7, 0x98, 0xa1, 0x4f, 0x3a, 0x13, 0x9f,
		0x6a, 0xc6, 0x3d, 0xf9, 0xcc, 0x7a, 0xf2, 0x19, 0xf4, 0xd4, 0x33, 0xe5, 0x91, 0xcd, 0x32, 0xff,
		0xb2, 0xc8, 0x65, 0xb8, 0xd3, 0xed, 0xe7, 0x41, 0xb0, 0x6f, 0x07, 0xd1, 0xfe, 0x1c, 0x04, 0xb3,
		0x34, 0x29, 0xf7, 0xdb, 0x20, 0x5e, 0x2e, 0x49, 0xbd, 0x7f, 0x06, 0x87, 0xc2, 0x7c, 0x82, 0x75,
		0x11, 0xa4, 0xfb, 0x5e, 0x70, 0x51, 0x09, 0xc2, 0x7d, 0x2c, 0x58, 0xa8, 0x05, 0x32, 0xae, 0x5f,
		0xfc, 0xea, 0x20, 0x4d, 0x8e, 0x8a, 0xd9, 0xa4, 0xd5, 0x23, 0x97, 0x62, 0x2f, 0x5c, 0x70, 0x43,
		0xbf, 0x58, 0x10, 0xb8, 0xa1, 0x25, 0x17, 0x07, 0x6e, 0x68, 0xc5, 0x05, 0x82, 0x1b, 0x32, 0x01,
		0x01, 0x80, 0x1b, 0xfa, 0x95, 0xd5, 0x02, 0x37, 0xf4, 0x86, 0x25, 0x81, 0x1b, 0x7a, 0x6b, 0x20,
		0x0c, 0x6e, 0x68, 0xed, 0x40, 0x18, 0xdc, 0x10, 0x77, 0x73, 0xff, 0x54, 0x25, 0xc0, 0x0d, 0xad,
		0xad, 0x12, 0xe0, 0x86, 0x0c, 0x61, 0x63, 0xb6, 0xc0, 0x0d, 0x11, 0xdc, 0x0f, 0x0a, 0xdc, 0x10,
		0xad, 0xde, 0xa1, 0x24, 0x7b, 0x84, 0x82, 0x1d, 0xfa, 0xc5, 0x82, 0xc0, 0x0e, 0x2d, 0xb9, 0x38,
		0xb0, 0x43, 0x2b, 0x2e, 0x10, 0xec, 0x90, 0x09, 0x18, 0x00, 0xec, 0xd0, 0xaf, 0xac, 0x16, 0xb9,
		0x1e, 0x98, 0xb4, 0x7a, 0x5d, 0xa2, 0xfb, 0x05, 0xba, 0x5f, 0xcc, 0xaf, 0x87, 0x78, 0x61, 0x3f,
		0xb1, 0xb6, 0x92, 0x68, 0x7b, 0xb1, 0x51, 0x5a, 0xc2, 0x48, 0x3b, 0xcc, 0x69, 0x77, 0x91, 0x75,
		0x4b, 0xc6, 0x0c, 0xda, 0x5c, 0xbc, 0x33, 0x58, 0xa7, 0xb3, 0xd6, 0x65, 0xe2, 0x3a, 0x9c, 0x81,
		0xde, 0xca, 0xd5, 0x57, 0xbd, 0x4a, 0xaa, 0x4f, 0x55, 0x34, 0xaa, 0x89, 0x15, 0x0e, 0x46, 0xb1,
		0x08, 0x13, 0x71, 0xd0, 0xad, 0x22, 0x69, 0xdc, 0x34, 0xb7, 0x06, 0xcd, 0x06, 0x22, 0x9b, 0xa2,
		0xfc, 0xcc, 0xb8, 0xc0, 0x2c, 0x39, 0x3f, 0x12, 0xdc, 0x5e, 0xd6, 0x1c, 0x1e, 0x19, 0xae, 0x8e,
		0x0c, 0x27, 0x47, 0x85, 0x7b, 0x33, 0x1b, 0x08, 0x65, 0x55, 0xf4, 0x9e, 0x71, 0x27, 0x18, 0x12,
		0x1d, 0x60, 0xd0, 0xc6, 0x0c, 0x6d, 0xcc, 0x48, 0x39, 0x21, 0x72, 0xce, 0x88, 0x9c, 0x53, 0xa2,
		0xe6, 0x9c, 0x36, 0x93, 0x89, 0xcb, 0xbc, 0x8d, 0x99, 0xef, 0x05, 0xdf, 0xec, 0x9e, 0x1b, 0xbb,
		0x74, 0x5a, 0x99, 0x3d, 0x2e, 0x89, 0x46, 0x3b, 0xb3, 0x1c, 0xda, 0x99, 0x91, 0x71, 0x72, 0x24,
		0x9d, 0x1d, 0x35, 0xa7, 0x47, 0xd6, 0xf9, 0x91, 0x75, 0x82, 0x54, 0x9d, 0x61, 0xb6, 0x4e, 0x31,
		0x63, 0xe7, 0x98, 0xbe, 0x14, 0x32, 0xd9, 0x10, 0x73, 0x8d, 0xa3, 0xbd, 0x41, 0x40, 0xc1, 0xe2,
		0xcc, 0xe2, 0xae, 0x32, 0x81, 0xb5, 0x4c, 0x5f, 0x13, 0x8d, 0x92, 0x18, 0x82, 0xa9, 0x33, 0xbd,
		0x41, 0x1c, 0x8b, 0x9e, 0xfd, 0xef, 0x91, 0xdb, 0x23, 0x98, 0x3f, 0x93, 0x3f, 0x22, 0xb4, 0xa6,
		0xa6, 0x1b, 0xc7, 0x22, 0x0c, 0xc8, 0x15, 0x58, 0x59, 0xdb, 0xdb, 0x17, 0x39, 0xbb, 0xdc, 0xf9,
		0x71, 0x91, 0xb7, 0xcb, 0x9d, 0xc9, 0xc7, 0x7c, 0xf2, 0x6d, 0xf2, 0xb9, 0x70, 0x91, 0xb3, 0x8b,
		0xb3, 0xcf, 0xa5, 0x8b, 0x9c, 0x5d, 0xea, 0xec, 0x5c, 0x5e, 0xee, 0xee, 0x7c, 0xdf, 0x7f, 0x58,
		0xfe, 0x17, 0x2d, 0xa4, 0xc5, 0x53, 0x72, 0x43, 0x84, 0x2d, 0xcb, 0xc8, 0x0b, 0xe2, 0xfd, 0x02,
		0x41, 0xa3, 0x72, 0x88, 0x92, 0x4d, 0x36, 0xd2, 0x94, 0x6e, 0x14, 0x4a, 0x36, 0x57, 0x5f, 0x1e,
		0x4a, 0x36, 0x4d, 0x31, 0xf3, 0x4f, 0x55, 0x02, 0x25, 0x9b, 0x6b, 0xab, 0x44, 0xb1, 0x50, 0x2e,
		0x96, 0x0f, 0x0e, 0x0b, 0x65, 0xd4, 0x6d, 0x32, 0xe5, 0x01, 0xe8, 0xae, 0x06, 0x75, 0x9b, 0x14,
		0xf6, 0x21, 0xc3, 0xf4, 0xed, 0xdf, 0x33, 0x3e, 0x41, 0xf1, 0x7a, 0xc4, 0xce, 0x4f, 0xbc, 0x1e,
		0x4e, 0x4f, 0xb6, 0x70, 0x7a, 0xf2, 0x0b, 0x51, 0xc1, 0xe9, 0xc9, 0xcf, 0x04, 0x18, 0xa7, 0x27,
		0x4b, 0x2e, 0x0c, 0xa7, 0x27, 0xf4, 0xe2, 0x19, 0x82, 0xa7, 0x27, 0xb4, 0x88, 0x70, 0x4a, 0x04,
		0x38, 0x39, 0xe2, 0x7b, 0xc3, 0x08, 0x6f, 0xe0, 0x67, 0xfd, 0x12, 0xd6, 0x17, 0x71, 0xe8, 0x75,
		0xe9, 0xc0, 0xe7, 0xe9, 0x7a, 0x80, 0x9e, 0x81, 0x9e, 0x81, 0x9e, 0x81, 0x9e, 0x81, 0x9e, 0x81,
		0x9e, 0x69, 0x59, 0x9d, 0x68, 0x78, 0x6d, 0x93, 0x70, 0x52, 0x5b, 0xb4, 0x9a, 0xf3, 0x12, 0x3b,
		0xe1, 0x25, 0x94, 0x27, 0x40, 0xf1, 0x44, 0x97, 0xe8, 0xb1, 0x15, 0xd5, 0x13, 0x5c, 0xca, 0xa7,
		0x53, 0x84, 0x4e, 0x6c, 0x49, 0x9e, 0xd4, 0x52, 0x17, 0x75, 0x82, 0xcd, 0x74, 0x49, 0x8b, 0x3b,
		0x0e, 0x1b, 0x41, 0x96, 0x64, 0xa4, 0x16, 0xc1, 0xa8, 0x7f, 0x25, 0x42, 0xdb, 0xf7, 0x82, 0x6f,
		0x11, 0x1d, 0xca, 0xe4, 0xc9, 0xaa, 0x40, 0x9c, 0x80, 0x38, 0x01, 0x71, 0x02, 0xe2, 0x04, 0xc4,
		0x09, 0x88, 0x13, 0x5a, 0x45, 0x5b, 0x54, 0x06, 0x1b, 0x81, 0x33, 0x01, 0x67, 0x02, 0xce, 0x04,
		0x9c, 0x09, 0x38, 0x13, 0x70, 0x26, 0xe0, 0x4c, 0xc0, 0x99, 0x80, 0x33, 0xd1, 0xc1, 0x99, 0xc4,
		0x83, 0x68, 0x7a, 0x6c, 0x46, 0x8f, 0x39, 0x99, 0x5f, 0x1b, 0xf8, 0x13, 0xf0, 0x27, 0xe0, 0x4f,
		0xc0, 0x9f, 0x80, 0x3f, 0x01, 0x7f, 0x02, 0xfe, 0x04, 0xfc, 0x09, 0xf8, 0x13, 0xf0, 0x27, 0x08,
		0x28, 0xc1, 0x9f, 0x80, 0x3f, 0x01, 0x7f, 0x02, 0xfe, 0x04, 0xfc, 0x89, 0x76, 0xb5, 0x88, 0x29,
		0x20, 0xd1, 0x14, 0x85, 0x26, 0xab, 0x01, 0x47, 0x02, 0x8e, 0x04, 0x1c, 0x09, 0x38, 0x12, 0x70,
		0x24, 0xe0, 0x48, 0x48, 0x59, 0x1d, 0xaf, 0x27, 0x82, 0xd8, 0x8b, 0xef, 0x43, 0x71, 0x4d, 0xa9,
		0xb4, 0x9d, 0x00, 0xd2, 0xb6, 0x6a, 0xd3, 0xad, 0x39, 0x76, 0x23, 0x42, 0x96, 0x70, 0xf6, 0xe2,
		0x5a, 0x8d, 0xcf, 0xed, 0x6a, 0xcb, 0xa9, 0x9f, 0x57, 0x9c, 0xf6, 0x5f, 0xcd, 0xea, 0x39, 0x15,
		0x83, 0x98, 0xc4, 0x4b, 0x11, 0xa9, 0xb6, 0x95, 0xc4, 0x02, 0xdd, 0x97, 0xde, 0x60, 0xab, 0x72,
		0x76, 0x5e, 0x6b, 0x3b, 0x67, 0xd5, 0xf6, 0xff, 0x34, 0x5a, 0xff, 0xb4, 0xc0, 0x5a, 0x70, 0x7c,
		0x8b, 0xe7, 0xed, 0xcf, 0xc7, 0x78, 0x85, 0xac, 0x5f, 0x61, 0xb3, 0xd0, 0xc4, 0x9b, 0x63, 0xf9,
		0xe6, 0xbe, 0xd4, 0x5a, 0xed, 0xcf, 0x95, 0xba, 0x53, 0xaf, 0x9d, 0x51, 0x52, 0x3e, 0x12, 0x2b,
		0xe9, 0x6c, 0x3a, 0xec, 0xc7, 0x70, 0x30, 0x3d, 0x31, 0x27, 0xc6, 0xf4, 0xbf, 0x3a, 0xe2, 0xfb,
		0x71, 0x9e, 0xf2, 0xde, 0x64, 0xf0, 0xe5, 0xa6, 0x0c, 0xb3, 0xcf, 0x60, 0xa0, 0x70, 0xf2, 0x0e,
		0xec, 0xc1, 0xb5, 0x1d, 0x89, 0xf0, 0xd6, 0xeb, 0x12, 0x98, 0x75, 0xba, 0xb0, 0x22, 0x8c, 0x3d,
		0xcd, 0x64, 0x01, 0x18, 0x7b, 0xfa, 0x6c, 0x31, 0x18, 0x7b, 0xfa, 0xca, 0x82, 0x30, 0xf6, 0x14,
		0xc8, 0xe6, 0x71, 0xf3, 0x33, 0x1f, 0x7b, 0x3a, 0x76, 0x20, 0x14, 0x3c, 0xda, 0x8b, 0x9e, 0x2d,
		0x7b, 0xc7, 0x46, 0xc4, 0xc1, 0x91, 0x71, 0x74, 0x94, 0x1c, 0x1e, 0x49, 0xc7, 0x47, 0xcd, 0x01,
		0x92, 0x75, 0x84, 0x64, 0x1d, 0x22, 0x55, 0xc7, 0x48, 0x84, 0xf2, 0xc8, 0xd8, 0xee, 0x64, 0xed,
		0x30, 0x1f, 0xb9, 0x80, 0x24, 0xd8, 0x26, 0x77, 0x7c, 0x37, 0x59, 0x16, 0x11, 0x0d, 0xa2, 0xe1,
		0x34, 0xc9, 0x39, 0x4f, 0x8a, 0x4e, 0x94, 0xb4, 0x33, 0xa5, 0xea, 0x54, 0xc9, 0x3b, 0x57, 0xf2,
		0x4e, 0x96, 0xba, 0xb3, 0xa5, 0xe1, 0x74, 0x89, 0x38, 0x5f, 0x72, 0x4e, 0x38, 0x5d, 0x10, 0x91,
		0xd6, 0xf9, 0xaf, 0x1a, 0x53, 0x32, 0x5d, 0x8a, 0x5f, 0x72, 0xcf, 0xd4, 0x2a, 0x23, 0xa8, 0xb9,
		0x69, 0xca, 0xee, 0x9a, 0x85, 0xdb, 0xa6, 0xee, 0xbe, 0xd9, 0xb8, 0x71, 0x36, 0xee, 0x9c, 0x8b,
		0x5b, 0xa7, 0xe5, 0xde, 0x89, 0xb9, 0xf9, 0xf4, 0x25, 0x92, 0xc9, 0x2e, 0x7e, 0xdd, 0xea, 0x91,
		0x1a, 0x05, 0xf0, 0x9a, 0xa3, 0x3d, 0x20, 0xb8, 0x34, 0x9a, 0xc3, 0xe0, 0x67, 0x5f, 0x34, 0xfd,
		0xc4, 0x16, 0xf5, 0xe1, 0xf0, 0xc4, 0x11, 0xde, 0xc2, 0x32, 0x89, 0x0f, 0x8b, 0x4f, 0xd7, 0xc9,
		0x60, 0x30, 0x36, 0x51, 0x1f, 0xf2, 0x54, 0x75, 0x08, 0x0f, 0x91, 0xe7, 0xaa, 0x3a, 0x04, 0xcb,
		0xc8, 0x59, 0xab, 0xcf, 0x3b, 0xac, 0xea, 0x2d, 0x5f, 0x1d, 0xcc, 0xe1, 0xa7, 0x6e, 0x7e, 0xad,
		0x78, 0x10, 0xd1, 0x65, 0xc6, 0xc6, 0x8b, 0x03, 0x2d, 0xf6, 0x96, 0x65, 0x81, 0x16, 0x5b, 0x27,
		0x40, 0x04, 0x2d, 0xb6, 0x86, 0x42, 0x80, 0x16, 0x93, 0xbc, 0x50, 0xd0, 0x62, 0xfc, 0x43, 0x1a,
		0x06, 0xb4, 0xd8, 0xc8, 0x0b, 0xe2, 0x23, 0xc2, 0x84, 0x58, 0x09, 0x84, 0xd8, 0x92, 0x5f, 0x20,
		0xc4, 0x36, 0x2a, 0xaa, 0x07, 0x21, 0x66, 0xaa, 0xf7, 0x78, 0xaa, 0x3a, 0x20, 0xc4, 0xa4, 0xab,
		0x4e, 0xa1, 0x04, 0x3a, 0xcc, 0x50, 0x20, 0x48, 0x77, 0x55, 0xa0, 0xc3, 0x28, 0xaf, 0x84, 0x4a,
		0xfa, 0x1c, 0x91, 0x72, 0xf6, 0x85, 0x75, 0x11, 0x2f, 0x6f, 0x7f, 0x5e, 0xeb, 0xbc, 0xf7, 0xac,
		0x44, 0x2c, 0xcb, 0xfa, 0x77, 0x7a, 0x02, 0x4f, 0x40, 0xd8, 0x49, 0x31, 0xcf, 0x04, 0x19, 0x67,
		0x62, 0x90, 0x0a, 0xf5, 0x11, 0xcb, 0x88, 0x11, 0xea, 0x23, 0x96, 0x11, 0x74, 0xd4, 0x47, 0xac,
		0x8b, 0x19, 0x50, 0x1f, 0xc1, 0x07, 0xe0, 0x91, 0x63, 0x86, 0x53, 0xab, 0xe5, 0x0b, 0xf7, 0x9a,
		0x46, 0x4b, 0xd6, 0xe7, 0x4e, 0x30, 0x7f, 0x48, 0x68, 0x4d, 0xcd, 0x29, 0x06, 0xde, 0xdd, 0x9d,
		0x80, 0xca, 0xbd, 0x31, 0x68, 0x00, 0xb0, 0x24, 0xb0, 0x82, 0xac, 0xeb, 0x8f, 0xff, 0x29, 0xee,
		0x69, 0x80, 0x48, 0xab, 0xee, 0x45, 0x71, 0x25, 0x8e, 0x89, 0x94, 0x43, 0x9f, 0x7a, 0x41, 0xd5,
		0x17, 0x63, 0x0f, 0x15, 0xd1, 0x00, 0x90, 0xd6, 0xa9, 0x7b, 0x37, 0xb7, 0xa2, 0xfc, 0x51, 0xb1,
		0x78, 0x70, 0x58, 0x2c, 0xe6, 0x0e, 0xf7, 0x0f, 0x73, 0xe5, 0x52, 0x29, 0x7f, 0x40, 0xa2, 0x17,
		0x74, 0x23, 0xec, 0x89, 0x50, 0xf4, 0x8e, 0xc7, 0x42, 0x15, 0x8c, 0x7c, 0x7f, 0xa3, 0x75, 0x8b,
		0x18, 0x2f, 0xc2, 0x9d, 0x0f, 0xa1, 0xd0, 0x05, 0x25, 0x8a, 0xc3, 0x51, 0x37, 0x0e, 0xa6, 0xe8,
		0xe3, 0x6c, 0xb2, 0x27, 0xb5, 0xe9, 0x96, 0x38, 0xcd, 0xe9, 0x46, 0x38, 0x8d, 0x64, 0x23, 0x9c,
		0x4a, 0x28, 0x5c, 0xa7, 0x1e, 0xf5, 0xae, 0x9c, 0x7a, 0xe4, 0x8e, 0x41, 0xd4, 0xf8, 0xbb, 0xd3,
		0x4a, 0x1e, 0x79, 0xfc, 0x69, 0xfc, 0xa3, 0xc6, 0xf5, 0xf9, 0xf4, 0xf1, 0xd0, 0xfa, 0xd3, 0x7c,
		0xdb, 0x80, 0xd6, 0x9f, 0xab, 0xd9, 0x82, 0x8d, 0xe9, 0x02, 0xfa, 0xce, 0x60, 0x25, 0xc8, 0x5a,
		0xf8, 0x89, 0x0b, 0x7d, 0x06, 0xfe, 0x4d, 0xae, 0x3f, 0xd3, 0xab, 0xa4, 0xfa, 0x54, 0x45, 0xa3,
		0x9a, 0x64, 0xd4, 0x86, 0x29, 0xd3, 0x76, 0x4b, 0x19, 0xb5, 0x55, 0xca, 0xec, 0x78, 0x20, 0xcb,
		0x63, 0x00, 0x12, 0x74, 0x7f, 0xd6, 0xb4, 0x3e, 0x19, 0xfa, 0x9e, 0x0c, 0x4d, 0x4f, 0x85, 0x8e,
		0x37, 0x1b, 0xfe, 0x64, 0xd5, 0x66, 0xc8, 0x72, 0x7b, 0xb7, 0x22, 0x8c, 0xbd, 0xc8, 0x0b, 0x6e,
		0xec, 0x09, 0xde, 0xc8, 0xbe, 0xd3, 0xfb, 0x0b, 0x6b, 0xca, 0xb6, 0xd7, 0x7b, 0x0e, 0xbd, 0xde,
		0xd1, 0xeb, 0x7d, 0x0b, 0xbd, 0xde, 0x19, 0xb8, 0x2b, 0x6a, 0x6e, 0x6b, 0x33, 0xa9, 0xac, 0xcc,
		0x4f, 0x85, 0x53, 0xab, 0xd1, 0x1b, 0xc4, 0xb1, 0xe8, 0xd9, 0xff, 0x1e, 0xb9, 0xbd, 0x2c, 0xed,
		0xc6, 0x2c, 0x8e, 0x39, 0xca, 0x70, 0x0d, 0x4d, 0x37, 0x8e, 0x45, 0x18, 0x64, 0x5e, 0xf0, 0x63,
		0x6d, 0x6f, 0x5f, 0xe4, 0xec, 0x72, 0xe7, 0xc7, 0x45, 0xde, 0x2e, 0x77, 0x26, 0x1f, 0xf3, 0xc9,
		0xb7, 0xc9, 0xe7, 0xc2, 0x45, 0xce, 0x2e, 0xce, 0x3e, 0x97, 0x2e, 0x72, 0x76, 0xa9, 0xb3, 0x73,
		0x79, 0xb9, 0xbb, 0xf3, 0x7d, 0xff, 0x61, 0xf9, 0x5f, 0xcc, 0x4e, 0xe3, 0x3b, 0x98, 0x4e, 0xa4,
		0x0e, 0xb5, 0xde, 0x10, 0x18, 0x48, 0x34, 0x5e, 0x04, 0x70, 0x29, 0x70, 0x29, 0x70, 0x29, 0x70,
		0x29, 0x70, 0x29, 0x70, 0xe9, 0x52, 0x56, 0x63, 0xe4, 0x05, 0x71, 0xfe, 0x80, 0x00, 0x24, 0xcd,
		0xb0, 0x53, 0x23, 0x91, 0x02, 0x74, 0x1a, 0x29, 0x65, 0x84, 0xc6, 0xe7, 0xd0, 0x2a, 0xd5, 0x20,
		0x56, 0x20, 0x4e, 0xb1, 0x96, 0xf5, 0x81, 0x46, 0x0e, 0x22, 0x44, 0xf8, 0x17, 0x22, 0x4c, 0xa8,
		0x73, 0x21, 0x49, 0x31, 0xde, 0xd0, 0x34, 0x37, 0x30, 0x05, 0xea, 0xc4, 0xbc, 0xfb, 0x55, 0x74,
		0xbf, 0x45, 0xa3, 0x7e, 0xf6, 0x74, 0x41, 0xba, 0x12, 0x70, 0x06, 0xe0, 0x0c, 0xc0, 0x19, 0x80,
		0x33, 0x00, 0x67, 0x00, 0xce, 0x00, 0x9c, 0x01, 0x38, 0x03, 0x70, 0x06, 0xe0, 0x0c, 0xc0, 0x19,
		0x40, 0x84, 0xc1, 0x19, 0x80, 0x33, 0x00, 0x67, 0x40, 0x80, 0x33, 0xf0, 0xbd, 0xe0, 0x9b, 0x9d,
		0x94, 0x3b, 0xd8, 0x5e, 0x2f, 0x7b, 0xe2, 0xe0, 0xe9, 0x72, 0xc0, 0x1e, 0x80, 0x3d, 0x00, 0x7b,
		0x00, 0xf6, 0x00, 0xec, 0x01, 0xd8, 0x83, 0xa5, 0xac, 0x06, 0x32, 0x61, 0x1f, 0x8d, 0x39, 0x32,
		0x61, 0x81, 0x55, 0xcd, 0xc0, 0xaa, 0x91, 0xf8, 0xf7, 0x48, 0x04, 0x5d, 0x61, 0x07, 0xa3, 0xfe,
		0x15, 0x85, 0xe2, 0xad, 0xe7, 0x0b, 0x02, 0x5e, 0x05, 0x5e, 0x05, 0x5e, 0x05, 0x5e, 0x05, 0x5e,
		0x05, 0x5e, 0x5d, 0xca, 0x6a, 0x78, 0x41, 0xbc, 0x5f, 0x20, 0x80, 0x54, 0xf7, 0x71, 0xd8, 0x85,
		0xc3, 0xae, 0x17, 0x43, 0x18, 0x62, 0x27, 0x05, 0x85, 0x7c, 0xf1, 0xb0, 0x78, 0xb4, 0x7f, 0x50,
		0x3c, 0xc2, 0x71, 0x01, 0x31, 0xb3, 0xfa, 0x54, 0x96, 0x71, 0xea, 0xf5, 0x76, 0x59, 0x3e, 0x84,
		0x2c, 0xd3, 0x02, 0x26, 0xd9, 0xdf, 0xbd, 0x83, 0x86, 0x7f, 0xfc, 0x2d, 0x23, 0x1a, 0xfe, 0xbd,
		0xd0, 0xf0, 0x2f, 0x83, 0xa9, 0x3e, 0x86, 0xb6, 0xca, 0x1b, 0xf5, 0xfb, 0x6e, 0x78, 0x9f, 0xb4,
		0x4e, 0xcc, 0xae, 0x61, 0xde, 0xdc, 0x22, 0xd0, 0x36, 0x4f, 0xe9, 0x8d, 0xd1, 0x36, 0x0f, 0x6d,
		0xf3, 0x26, 0x0b, 0x41, 0xdb, 0xbc, 0x4d, 0x02, 0x11, 0x99, 0xb5, 0xcd, 0xcb, 0xa6, 0x17, 0xeb,
		0xa2, 0x8b, 0xc9, 0xa0, 0x27, 0x2b, 0x11, 0x1a, 0x04, 0x47, 0x2c, 0x38, 0x62, 0x21, 0xee, 0x8c,
		0xc8, 0x39, 0x25, 0x6a, 0xce, 0x29, 0x5b, 0x2e, 0x21, 0xab, 0x23, 0x96, 0xac, 0x9c, 0x56, 0xba,
		0x80, 0x59, 0xf4, 0xda, 0x77, 0xa3, 0x6f, 0xd9, 0x6b, 0xeb, 0xcc, 0x84, 0x3d, 0x59, 0x55, 0xd6,
		0xa3, 0xaf, 0x48, 0xb0, 0xa2, 0x64, 0xa6, 0x94, 0x52, 0x9a, 0x4e, 0x4a, 0x72, 0x2a, 0x29, 0xb5,
		0x69, 0xa4, 0x64, 0xa7, 0x90, 0x92, 0x9d, 0x3e, 0x4a, 0x75, 0xea, 0xe8, 0x66, 0x8f, 0x20, 0x24,
		0x33, 0x5d, 0xf4, 0x49, 0x0d, 0xee, 0x11, 0x05, 0x8b, 0x33, 0x75, 0x51, 0x14, 0x26, 0xfb, 0xd1,
		0xc8, 0x52, 0x98, 0x7d, 0x11, 0x1a, 0x45, 0x4b, 0x29, 0x6b, 0x81, 0x18, 0xb6, 0x59, 0x58, 0x16,
		0xb1, 0x92, 0xdd, 0x74, 0x5d, 0x04, 0x0f, 0x7e, 0x89, 0x58, 0xe7, 0xa7, 0xa2, 0xee, 0xde, 0x41,
		0xd4, 0x97, 0x14, 0xf5, 0xfd, 0x02, 0x64, 0x9d, 0x07, 0x0e, 0xa2, 0xb3, 0x8a, 0x0e, 0x46, 0x81,
		0x9a, 0x6f, 0x61, 0x31, 0x0a, 0xf4, 0x67, 0x49, 0x12, 0x8f, 0xc7, 0xea, 0x59, 0x24, 0x4c, 0x64,
		0x27, 0x90, 0x59, 0x94, 0x17, 0x2d, 0x0c, 0x5b, 0xcd, 0xfc, 0xc8, 0x6b, 0x61, 0x45, 0x38, 0xfd,
		0xca, 0x64, 0x01, 0x38, 0xfd, 0x7a, 0xb6, 0x18, 0x9c, 0x7e, 0xbd, 0xb2, 0x20, 0x9c, 0x7e, 0x01,
		0xda, 0x3c, 0x6e, 0x7e, 0xe6, 0xa7, 0x5f, 0x63, 0x07, 0x42, 0xc1, 0xa3, 0xbd, 0xe8, 0xd9, 0xb2,
		0x77, 0x6c, 0x44, 0x1c, 0x1c, 0x19, 0x47, 0x47, 0xc9, 0xe1, 0x91, 0x74, 0x7c, 0xd4, 0x1c, 0x20,
		0x59, 0x47, 0x48, 0xd6, 0x21, 0x52, 0x75, 0x8c, 0x34, 0x58, 0x97, 0xac, 0xcf, 0xc0, 0xb2, 0x76,
		0x98, 0x8f, 0x64, 0x40, 0xa6, 0x39, 0x8f, 0xaf, 0xda, 0xc0, 0x2c, 0x73, 0x20, 0x89, 0x3a, 0x4d,
		0x72, 0xce, 0x93, 0xa2, 0x13, 0x25, 0xed, 0x4c, 0xa9, 0x3a, 0x55, 0xf2, 0xce, 0x95, 0xbc, 0x93,
		0xa5, 0xee, 0x6c, 0x69, 0x38, 0x5d, 0x22, 0xce, 0x97, 0x9c, 0x13, 0x4e, 0x17, 0xd4, 0x17, 0x71,
		0xe8, 0x75, 0xe9, 0xd9, 0x85, 0x99, 0x31, 0x9d, 0xae, 0xef, 0x77, 0x1c, 0x08, 0x33, 0x74, 0xd3,
		0x94, 0xdd, 0x35, 0x0b, 0xb7, 0x4d, 0xdd, 0x7d, 0xb3, 0x71, 0xe3, 0x6c, 0xdc, 0x39, 0x17, 0xb7,
		0x4e, 0xcb, 0xbd, 0x13, 0x73, 0xf3, 0xe9, 0x4b, 0x24, 0x93, 0x77, 0xfa, 0xba, 0xd5, 0x8b, 0x86,
		0xd7, 0x36, 0x49, 0x27, 0xbb, 0x45, 0x63, 0x50, 0xcc, 0xab, 0x4b, 0xa3, 0x95, 0xad, 0xfa, 0xfc,
		0x8b, 0xa6, 0x9f, 0xd8, 0xa2, 0x9a, 0xcd, 0xca, 0x04, 0xe1, 0x2d, 0x2c, 0x93, 0x68, 0xb6, 0xeb,
		0xc2, 0x3a, 0x09, 0x67, 0x04, 0x12, 0xf7, 0x21, 0x4f, 0x55, 0xc7, 0xbd, 0x83, 0xea, 0x48, 0x56,
		0x1d, 0x42, 0x83, 0x71, 0x8c, 0x50, 0x9f, 0x77, 0x58, 0xd5, 0x5b, 0xbe, 0x3a, 0xef, 0xb0, 0x3f,
		0xc4, 0xcd, 0xaf, 0x15, 0x0f, 0x22, 0xba, 0xcc, 0xd8, 0x78, 0x71, 0xa0, 0xc5, 0xde, 0xb2, 0x2c,
		0xd0, 0x62, 0xeb, 0x04, 0x88, 0xa0, 0xc5, 0xd6, 0x50, 0x08, 0xd0, 0x62, 0x92, 0x17, 0x0a, 0x5a,
		0x8c, 0x7f, 0x48, 0xc3, 0x80, 0x16, 0xa3, 0x52, 0x9e, 0xfd, 0x9a, 0x8b, 0x2d, 0x81, 0x10, 0x5b,
		0xf2, 0x0b, 0x84, 0xd8, 0x46, 0x45, 0xf5, 0x20, 0xc4, 0x4c, 0xf5, 0x1e, 0x4f, 0x55, 0x07, 0x84,
		0x98, 0x74, 0xd5, 0x29, 0x94, 0x40, 0x87, 0x19, 0x0a, 0x04, 0xe9, 0xae, 0x0a, 0x74, 0x18, 0xe5,
		0x95, 0x50, 0x49, 0x9f, 0x23, 0x52, 0xcf, 0xbe, 0xb0, 0x2e, 0xea, 0xf5, 0xed, 0xcf, 0x8b, 0x9d,
		0xf7, 0x9e, 0xd5, 0x88, 0x65, 0x59, 0x00, 0x4f, 0x4f, 0xe2, 0x29, 0x0c, 0xf7, 0xa1, 0x44, 0x3d,
		0x13, 0xa4, 0x9c, 0xa9, 0xcd, 0x1b, 0x42, 0x81, 0xc4, 0x12, 0x62, 0x84, 0x02, 0x89, 0x65, 0x04,
		0x1d, 0x05, 0x12, 0xeb, 0x82, 0x06, 0x14, 0x48, 0xf0, 0x41, 0x78, 0xe4, 0xa8, 0xe1, 0xd4, 0x6a,
		0xf9, 0xc2, 0xbd, 0x0e, 0xc5, 0x35, 0x25, 0x9b, 0x35, 0xab, 0x12, 0x3c, 0x24, 0xb4, 0xa6, 0xe6,
		0x14, 0x04, 0xef, 0xee, 0x4e, 0x40, 0xe5, 0xde, 0x18, 0x34, 0x00, 0x58, 0x12, 0x58, 0x41, 0xd6,
		0x05, 0xc8, 0xff, 0x14, 0xf7, 0x34, 0x40, 0xa4, 0x55, 0xf7, 0xa2, 0xb8, 0x12, 0xc7, 0x44, 0xea,
		0xa1, 0x4f, 0xbd, 0xa0, 0xea, 0x8b, 0xb1, 0x87, 0x8a, 0x68, 0x00, 0x48, 0xeb, 0xd4, 0xbd, 0x9b,
		0x5b, 0x51, 0xfe, 0xa8, 0x58, 0x3c, 0x38, 0x2c, 0x16, 0x73, 0x87, 0xfb, 0x87, 0xb9, 0x72, 0xa9,
		0x94, 0x3f, 0xc8, 0x53, 0xe8, 0x16, 0xdc, 0x08, 0x7b, 0x22, 0x14, 0xbd, 0xe3, 0xb1, 0x50, 0x05,
		0x23, 0xdf, 0xdf, 0x68, 0xdd, 0x22, 0x46, 0x8c, 0xb0, 0x27, 0x44, 0x28, 0xf4, 0x41, 0x89, 0xe2,
		0x70, 0xd4, 0x8d, 0x83, 0x29, 0xfc, 0x38, 0x9b, 0x6c, 0x4a, 0x6d, 0xba, 0x27, 0x4e, 0x73, 0xba,
		0x13, 0x4e, 0x23, 0xd9, 0x09, 0xa7, 0x12, 0x0a, 0xd7, 0xa9, 0x47, 0xbd, 0x2b, 0xa7, 0x1e, 0xb9,
		0x63, 0x14, 0x35, 0xfe, 0xee, 0x9c, 0x4f, 0x9e, 0x79, 0xfc, 0x71, 0xfc, 0xb3, 0xc6, 0xf5, 0xf9,
		0xf4, 0xf9, 0xd0, 0xfe, 0xd3, 0x7c, 0xeb, 0x80, 0xf6, 0x9f, 0x2b, 0x5a, 0x03, 0x0b, 0x93, 0x81,
		0xf9, 0x6b, 0x01, 0x26, 0x03, 0xff, 0x5c, 0xea, 0xb3, 0x18, 0x2f, 0x2a, 0xd7, 0xa5, 0x19, 0x3b,
		0xe1, 0xf8, 0x9d, 0x41, 0xea, 0x38, 0x0b, 0xfb, 0x7c, 0x2f, 0xf8, 0x66, 0x27, 0x8c, 0x80, 0xed,
		0xf5, 0x34, 0xc9, 0x5e, 0x36, 0x81, 0x5e, 0x76, 0x01, 0x1d, 0xa9, 0xc0, 0x2d, 0x9b, 0x00, 0x4d,
		0x97, 0x54, 0x67, 0xe4, 0x5c, 0x28, 0x3a, 0x15, 0x4b, 0xe7, 0x40, 0xf6, 0xf5, 0x1d, 0x88, 0x1e,
		0xaf, 0xa1, 0xde, 0x86, 0xab, 0xbd, 0x83, 0x62, 0x3d, 0xd2, 0xad, 0x3f, 0xd4, 0xf4, 0x46, 0xad,
		0x10, 0xaa, 0x13, 0x0d, 0x85, 0x62, 0xa1, 0xa9, 0x2f, 0xa4, 0xd6, 0x7e, 0x8f, 0x9a, 0xfa, 0x38,
		0x6a, 0x4b, 0x3f, 0xd0, 0x99, 0x56, 0x90, 0x49, 0xba, 0x80, 0xee, 0x34, 0x80, 0xcc, 0x8e, 0xf7,
		0x33, 0x3b, 0xb6, 0xcf, 0xea, 0x38, 0x9e, 0xb7, 0xbb, 0xd4, 0xd5, 0x37, 0x30, 0x69, 0x1e, 0xaf,
		0x4f, 0xfa, 0xe7, 0x5b, 0xd6, 0xeb, 0x12, 0x7c, 0xbd, 0x99, 0x63, 0xda, 0x33, 0xc3, 0xb2, 0xc8,
		0xfc, 0xca, 0x34, 0xb3, 0x2b, 0xab, 0xcc, 0xad, 0xcc, 0x33, 0xb3, 0x32, 0xcf, 0xbc, 0xca, 0x3a,
		0xb3, 0xca, 0x2c, 0x9e, 0x4c, 0x7b, 0xe6, 0x53, 0xaa, 0xb5, 0x5e, 0x4f, 0x04, 0xb1, 0x17, 0xdf,
		0xeb, 0xcd, 0x6e, 0x4a, 0xb1, 0xb1, 0x4e, 0x4e, 0xaa, 0x36, 0x7d, 0xd4, 0x63, 0x37, 0xca, 0xc0,
		0x62, 0xcc, 0x36, 0xbc, 0x71, 0xde, 0xfc, 0xe8, 0xd4, 0xcf, 0x2b, 0x4e, 0xfb, 0xaf, 0x66, 0x55,
		0xb7, 0xd5, 0x48, 0xca, 0xbc, 0xa2, 0x4c, 0xea, 0x74, 0x33, 0x1e, 0xf9, 0x76, 0xfe, 0xf9, 0xf4,
		0xb4, 0xd2, 0xfa, 0xcb, 0xa9, 0x35, 0x9d, 0xb3, 0x6a, 0xfb, 0x7f, 0x1a, 0xad, 0x7f, 0x8e, 0x5f,
		0x82, 0xb5, 0x09, 0x03, 0xf8, 0x32, 0xde, 0xf9, 0xb1, 0xc0, 0x7f, 0x29, 0x38, 0xf5, 0xda, 0xd9,
		0x3f, 0x9d, 0xf3, 0x0f, 0x8d, 0x66, 0xd5, 0x69, 0x34, 0x2b, 0xff, 0xef, 0x73, 0x15, 0xfb, 0xaf,
		0x75, 0xff, 0x2b, 0xad, 0x6a, 0x05, 0xfb, 0x9f, 0xc1, 0xfe, 0xc3, 0xdc, 0x64, 0x22, 0xee, 0xe7,
		0x10, 0xf6, 0x0c, 0x76, 0xbf, 0x72, 0xee, 0x54, 0xff, 0x6c, 0x57, 0x5b, 0x67, 0x95, 0x3a, 0xb6,
		0x5c, 0xcf, 0x96, 0xb7, 0x1a, 0x9f, 0xdb, 0xd5, 0x16, 0x76, 0x5b, 0x93, 0x35, 0x3f, 0x3f, 0xaf,
		0x38, 0x90, 0xf2, 0xcc, 0xf0, 0x7b, 0xe5, 0xfc, 0x38, 0x2b, 0x59, 0xd7, 0x7a, 0xc7, 0x8e, 0x69,
		0x4c, 0x0a, 0x48, 0xfe, 0x9f, 0xca, 0xf9, 0x06, 0x9f, 0x89, 0x6b, 0xe8, 0x3f, 0xc0, 0xf3, 0x50,
		0x5c, 0xcb, 0x79, 0x8c, 0xce, 0x73, 0x18, 0x4d, 0xe7, 0x2f, 0x38, 0x12, 0x97, 0x76, 0x53, 0x1c,
		0x89, 0xab, 0xbe, 0x31, 0x8e, 0xc4, 0x57, 0xd8, 0x34, 0x6d, 0xe7, 0x25, 0x19, 0x54, 0x80, 0xeb,
		0xac, 0xec, 0x7e, 0xa1, 0x62, 0x7b, 0xbc, 0xb3, 0x5c, 0x7d, 0xf1, 0x3b, 0x46, 0xb2, 0x9c, 0x96,
		0x44, 0xab, 0x73, 0xbb, 0x7a, 0x52, 0xe0, 0xf5, 0xa5, 0xbc, 0x67, 0x9a, 0xe2, 0xae, 0x27, 0xa5,
		0x5d, 0x95, 0xb0, 0x69, 0x0a, 0x2f, 0x08, 0x85, 0x15, 0x96, 0xd2, 0x6c, 0xd5, 0xb5, 0x32, 0xd1,
		0xd5, 0xd8, 0x57, 0xf9, 0xd6, 0x4f, 0xee, 0x15, 0x25, 0x8b, 0xb6, 0x6a, 0x91, 0xce, 0x5e, 0x94,
		0xe5, 0x8a, 0x89, 0xbc, 0x97, 0x29, 0xf1, 0x45, 0x2a, 0xca, 0xfb, 0x56, 0x9a, 0xe7, 0xad, 0x28,
		0xaf, 0x5b, 0x59, 0xd0, 0xaa, 0x32, 0x48, 0xd5, 0x12, 0x94, 0xaa, 0x0e, 0x42, 0xb5, 0x05, 0x9d,
		0xda, 0x82, 0x4c, 0x5d, 0x41, 0x25, 0x6d, 0x07, 0xa1, 0x2a, 0x6f, 0x7a, 0x9a, 0x33, 0x77, 0xed,
		0x09, 0x75, 0xc0, 0xfa, 0x59, 0x7e, 0x5e, 0x72, 0x2f, 0x55, 0x71, 0x88, 0x52, 0x4e, 0x4e, 0x39,
		0x17, 0xa7, 0x83, 0x83, 0xd3, 0xca, 0xbd, 0xe9, 0xe2, 0xdc, 0xb4, 0x73, 0x6d, 0xda, 0x39, 0x36,
		0xdd, 0xdc, 0x1a, 0x2f, 0xfe, 0x41, 0x39, 0x87, 0xf6, 0x74, 0xce, 0xf4, 0x18, 0xe0, 0xda, 0xca,
		0xad, 0xd9, 0x13, 0x80, 0x56, 0x56, 0x78, 0x8f, 0xe9, 0xee, 0xa9, 0xcd, 0xa3, 0xd5, 0xc8, 0x6f,
		0x8e, 0xbc, 0x20, 0xde, 0x2f, 0x68, 0xa4, 0x37, 0x75, 0xb0, 0x9b, 0x7a, 0xa7, 0x12, 0xe9, 0xed,
		0x32, 0x91, 0x41, 0xcd, 0x4b, 0x26, 0x6d, 0xb7, 0xb3, 0x9a, 0xea, 0x93, 0xe5, 0xa0, 0x91, 0x07,
		0xbd, 0x6d, 0x43, 0x36, 0x4e, 0x94, 0x8a, 0x85, 0x72, 0xb1, 0x7c, 0x70, 0x58, 0x28, 0x97, 0x36,
		0x48, 0xa6, 0x0c, 0x49, 0xf3, 0xe9, 0x70, 0x3e, 0xb8, 0xd4, 0xe8, 0xd0, 0x7b, 0x83, 0x38, 0x16,
		0x3d, 0xfb, 0xdf, 0x23, 0xb7, 0xa7, 0xf3, 0xd0, 0xf2, 0x48, 0xcf, 0xa1, 0x65, 0x2c, 0xc2, 0x40,
		0x9b, 0x63, 0xb7, 0xb6, 0xb7, 0x2f, 0x72, 0x76, 0xb9, 0xf3, 0xe3, 0x22, 0x6f, 0x97, 0x3b, 0x93,
		0x8f, 0xf9, 0xe4, 0xdb, 0xe4, 0x73, 0xe1, 0x22, 0x67, 0x17, 0x67, 0x9f, 0x4b, 0x17, 0x39, 0xbb,
		0xd4, 0xd9, 0xb9, 0xbc, 0xdc, 0xdd, 0xf9, 0xbe, 0xff, 0xb0, 0xfc, 0x2f, 0x5a, 0xdc, 0x35, 0xe8,
		0x1d, 0xaf, 0x75, 0xe3, 0xd8, 0x44, 0xae, 0xae, 0x64, 0x75, 0x6c, 0xa2, 0x20, 0x8b, 0x50, 0xe2,
		0x91, 0xc9, 0x3b, 0x42, 0xa2, 0xa0, 0x4a, 0x04, 0xb2, 0x7a, 0xf5, 0x96, 0xd4, 0xf3, 0xa8, 0x95,
		0x4e, 0x76, 0xe5, 0xc8, 0xdd, 0xfa, 0x52, 0x22, 0x41, 0x42, 0xac, 0xfe, 0xd0, 0x97, 0x37, 0x7e,
		0x2a, 0x85, 0x23, 0xc9, 0x55, 0x25, 0xc9, 0xaf, 0xdc, 0x03, 0x38, 0xe9, 0x0c, 0xb5, 0x0a, 0x46,
		0x5a, 0x29, 0x03, 0xad, 0x8a, 0x71, 0x56, 0xce, 0x30, 0x2b, 0x67, 0x94, 0x55, 0x33, 0xc8, 0xb4,
		0xfc, 0x82, 0xec, 0x03, 0x33, 0xab, 0x3b, 0xd3, 0x2c, 0x45, 0xc7, 0xfb, 0xd3, 0xeb, 0xe3, 0x7c,
		0x1f, 0xe7, 0xfb, 0x59, 0x9a, 0x21, 0x6d, 0xe6, 0x48, 0x97, 0x59, 0xe2, 0x11, 0xc9, 0x28, 0x3b,
		0xdf, 0x8f, 0x43, 0xf7, 0xfa, 0xda, 0xeb, 0xda, 0x22, 0xb8, 0xf1, 0x02, 0x21, 0x42, 0x2f, 0xb8,
		0xb1, 0x45, 0xe0, 0x5e, 0xf9, 0xa2, 0xa7, 0xfe, 0xc0, 0xff, 0x67, 0x37, 0x47, 0x06, 0x80, 0x6e,
		0x03, 0xa8, 0xd5, 0x10, 0xea, 0x32, 0x88, 0xda, 0x0d, 0xa3, 0x76, 0x03, 0xa9, 0xdb, 0x50, 0xaa,
		0x25, 0xbf, 0xf8, 0x67, 0x00, 0x5c, 0x0d, 0x06, 0xbe, 0x70, 0x03, 0x1d, 0x87, 0xfe, 0x79, 0xb0,
		0x84, 0x60, 0x09, 0x5f, 0xa2, 0x8a, 0xfa, 0x43, 0x3f, 0xda, 0x9b, 0x46, 0x0c, 0xc8, 0xac, 0x5e,
		0x57, 0xa3, 0x59, 0x66, 0x56, 0x17, 0x10, 0x79, 0x21, 0xf2, 0x42, 0xe4, 0x85, 0xc8, 0x0b, 0x91,
		0x17, 0x22, 0x2f, 0x44, 0x5e, 0x88, 0xbc, 0x10, 0x79, 0x21, 0xf2, 0x42, 0xe4, 0xa5, 0x25, 0xf2,
		0x42, 0x7e, 0x46, 0xd6, 0x22, 0x90, 0xd5, 0xab, 0xcf, 0x38, 0x3f, 0xe3, 0x74, 0xbc, 0x04, 0x83,
		0xf2, 0x33, 0xe4, 0x06, 0xf6, 0x4a, 0x02, 0x7a, 0x65, 0x19, 0x1a, 0x05, 0x64, 0x68, 0x20, 0x43,
		0x43, 0x2b, 0xce, 0x34, 0x3c, 0x43, 0x43, 0x61, 0x29, 0xb3, 0xfa, 0x12, 0x66, 0x45, 0xe1, 0x33,
		0x32, 0x35, 0xc0, 0x17, 0x82, 0x2f, 0x64, 0x11, 0xee, 0xea, 0x2e, 0x31, 0x56, 0x59, 0x5a, 0xac,
		0xb6, 0xa4, 0x58, 0x03, 0xd5, 0xa0, 0xbc, 0x84, 0x58, 0x43, 0xe9, 0xb0, 0xa6, 0x92, 0x61, 0x0d,
		0x75, 0x60, 0x3a, 0x4b, 0x84, 0x75, 0xcf, 0x55, 0xd4, 0x5c, 0x12, 0x9c, 0x45, 0xd9, 0xa6, 0x86,
		0x12, 0x60, 0xad, 0xa5, 0xbf, 0x59, 0x89, 0x88, 0xee, 0x52, 0xdf, 0x4c, 0x64, 0x05, 0x05, 0x7d,
		0xea, 0x35, 0x47, 0x83, 0x03, 0xd5, 0x53, 0xb2, 0xab, 0xa3, 0x54, 0x57, 0x5b, 0x89, 0xae, 0x21,
		0xa5, 0xb9, 0x5c, 0x4a, 0x5b, 0x3b, 0xe0, 0xef, 0xdf, 0x12, 0xf3, 0x99, 0xc3, 0xdf, 0x4b, 0x3c,
		0xb5, 0xa1, 0xc1, 0x9e, 0xdf, 0x7a, 0x61, 0x3c, 0x72, 0x7d, 0xdb, 0xf7, 0x82, 0x6f, 0x0a, 0xca,
		0x1c, 0x9f, 0x5e, 0x1e, 0xf5, 0x8e, 0x24, 0xe9, 0x2c, 0xb0, 0xe9, 0x59, 0xd1, 0x55, 0x86, 0xb3,
		0xe9, 0xf3, 0xda, 0xaf, 0x8e, 0x4f, 0x7f, 0x72, 0x17, 0xd4, 0x3e, 0x82, 0x51, 0xcf, 0xd2, 0x24,
		0x69, 0x33, 0x4d, 0xba, 0x4c, 0x94, 0x1a, 0xf0, 0xcc, 0x26, 0x03, 0x57, 0x51, 0xc9, 0xf6, 0x82,
		0x52, 0x29, 0x29, 0xdd, 0x56, 0x6c, 0xc6, 0x94, 0x9b, 0x33, 0x1d, 0x66, 0x4d, 0xab, 0x79, 0xd3,
		0x65, 0xe6, 0xb4, 0x9b, 0x3b, 0xed, 0x66, 0x4f, 0xb7, 0xf9, 0x53, 0xcb, 0xfe, 0xa9, 0xca, 0xab,
		0x55, 0x65, 0x16, 0xd3, 0x1b, 0x84, 0xa2, 0x3f, 0x88, 0x85, 0x1d, 0x0e, 0x46, 0xb1, 0x08, 0x6d,
		0xaf, 0xa7, 0x6f, 0x3c, 0xe3, 0xc2, 0x9d, 0x31, 0xaa, 0x91, 0x9a, 0x49, 0xcd, 0xc4, 0xb4, 0xea,
		0x36, 0xb1, 0x99, 0x99, 0xda, 0xcc, 0x4c, 0x6e, 0x56, 0xa6, 0x57, 0xad, 0x09, 0x56, 0x6c, 0x8a,
		0xd3, 0x4d, 0xd3, 0x3f, 0xaa, 0xd1, 0x1b, 0xde, 0x16, 0x6d, 0xb7, 0xd7, 0x0b, 0x45, 0x14, 0xd9,
		0xc1, 0xc0, 0xfe, 0xef, 0x20, 0x10, 0x68, 0x81, 0xba, 0xe6, 0x0d, 0x75, 0x9e, 0xb3, 0x6c, 0xff,
		0xed, 0xe2, 0xf2, 0x72, 0xf8, 0xfd, 0xec, 0x61, 0xfc, 0x67, 0xfd, 0xa1, 0xf3, 0xf7, 0x9d, 0x3f,
		0x74, 0xd9, 0x96, 0xf1, 0x42, 0x2e, 0x2f, 0x77, 0x3b, 0xbf, 0xa1, 0x0d, 0xab, 0x19, 0x88, 0xd0,
		0xe0, 0xc1, 0x87, 0x4f, 0xce, 0x1a, 0x9e, 0xfc, 0x4d, 0x49, 0x9b, 0x03, 0x75, 0xef, 0x5f, 0xc1,
		0xbb, 0xd7, 0x07, 0xd4, 0x75, 0x03, 0x74, 0xd4, 0x0c, 0x83, 0xdb, 0x00, 0xb7, 0xb1, 0x81, 0x9e,
		0x4c, 0x5f, 0xcd, 0xb0, 0xfa, 0x59, 0xe7, 0x3a, 0x66, 0x9c, 0x2f, 0xce, 0x36, 0x5f, 0xb0, 0xd0,
		0x1b, 0xec, 0x1f, 0xd5, 0xb4, 0x07, 0x5a, 0x10, 0x25, 0x15, 0x6d, 0x82, 0x16, 0x84, 0x48, 0xb5,
		0x27, 0x2c, 0xc0, 0x13, 0xc2, 0x13, 0xc2, 0x13, 0x92, 0xf1, 0x84, 0xca, 0x59, 0x7e, 0xb7, 0xf7,
		0x2f, 0xb7, 0x2b, 0x82, 0xee, 0xbd, 0xad, 0xd6, 0x4c, 0x2e, 0x68, 0xe9, 0xf3, 0x1b, 0x83, 0xe3,
		0xa7, 0x66, 0x50, 0x33, 0x31, 0xac, 0xba, 0x0d, 0x6c, 0x66, 0x86, 0x36, 0x33, 0x83, 0x9b, 0x95,
		0xe1, 0x55, 0x4f, 0xd7, 0x6d, 0x99, 0xc9, 0xf1, 0x27, 0x55, 0x9e, 0xf1, 0xbd, 0xda, 0x30, 0x65,
		0x01, 0x69, 0x6a, 0x28, 0x22, 0xb2, 0x6a, 0xd3, 0x47, 0x3b, 0x76, 0x23, 0x8d, 0x9a, 0x3e, 0xdb,
		0xd8, 0xc6, 0x79, 0xf3, 0xa3, 0x73, 0x56, 0xad, 0x7d, 0xfa, 0xc7, 0x71, 0xa3, 0xe5, 0x9c, 0xb7,
		0x2b, 0xed, 0xaa, 0xa5, 0xb3, 0x64, 0x2b, 0xd2, 0x76, 0xa4, 0xb1, 0xa5, 0x75, 0x64, 0xeb, 0x93,
		0x4d, 0x3e, 0x69, 0xfc, 0xcf, 0x99, 0x65, 0xe2, 0x34, 0xd1, 0x8c, 0xf6, 0xb3, 0xfa, 0xe7, 0x79,
		0xbb, 0xd2, 0x6a, 0x63, 0x4b, 0xe5, 0x6d, 0x69, 0xa5, 0xdd, 0xae, 0x9e, 0x36, 0xb1, 0xa5, 0x52,
		0xa5, 0xf4, 0xc3, 0x3f, 0x2a, 0x67, 0x9f, 0xaa, 0xd8, 0x53, 0x79, 0x7b, 0xfa, 0xf1, 0x73, 0xbd,
		0x8e, 0xfd, 0x94, 0xb7, 0x9f, 0xf5, 0x46, 0xe5, 0xa4, 0x76, 0xf6, 0x09, 0x5b, 0x2a, 0x6f, 0x4b,
		0xdb, 0xff, 0xd3, 0x70, 0xfe, 0xa7, 0xf2, 0x17, 0xb6, 0x54, 0xde, 0x96, 0xd6, 0xce, 0x6a, 0x3a,
		0x3d, 0x93, 0x96, 0x3b, 0x75, 0xd0, 0x26, 0x40, 0xbf, 0x3c, 0x5b, 0x57, 0x6e, 0xf7, 0xdb, 0x68,
		0x68, 0xf7, 0x44, 0xe4, 0xdd, 0x04, 0x6e, 0x2c, 0x7a, 0xd3, 0xd3, 0x21, 0x7d, 0x94, 0xdf, 0xab,
		0x2b, 0x00, 0xf7, 0xb7, 0xd4, 0x8d, 0xc0, 0xfd, 0xc9, 0x16, 0x10, 0x70, 0x7f, 0xe0, 0xfe, 0x7e,
		0xbd, 0x69, 0xfa, 0xb9, 0x3f, 0x3d, 0x6d, 0x52, 0x9e, 0x1b, 0x4a, 0xa4, 0xf5, 0xd2, 0x6d, 0x9f,
		0xa2, 0x07, 0x43, 0xf1, 0x44, 0x38, 0x3d, 0xe1, 0xf6, 0xec, 0xd8, 0xeb, 0x6b, 0x3c, 0xc5, 0x7c,
		0xbc, 0x25, 0x30, 0x0c, 0x30, 0x0c, 0x30, 0x0c, 0x30, 0x0c, 0x30, 0xcc, 0x33, 0xad, 0x1b, 0x5b,
		0xc7, 0xd8, 0xeb, 0x7e, 0x8b, 0x0e, 0x8a, 0x1a, 0x31, 0x8c, 0x0e, 0x08, 0xf3, 0x39, 0x98, 0xb4,
		0x3d, 0xb4, 0x02, 0x37, 0x18, 0x44, 0xa2, 0x3b, 0x08, 0x7a, 0x91, 0x8e, 0x47, 0xd4, 0xd3, 0xb8,
		0x55, 0x3f, 0xf1, 0xa5, 0xb5, 0x91, 0xab, 0x66, 0xcf, 0xba, 0x70, 0x5b, 0xcd, 0x8d, 0x5d, 0xd3,
		0xfb, 0x66, 0xd0, 0xb4, 0x53, 0x93, 0x6d, 0x7b, 0x2a, 0x4a, 0x1a, 0x1b, 0xbe, 0x52, 0x11, 0xa5,
		0xfc, 0x51, 0xb1, 0x78, 0x70, 0x58, 0x2c, 0xe6, 0x0e, 0xf7, 0x0f, 0x73, 0xe5, 0x52, 0x29, 0x7f,
		0x90, 0x2f, 0x6d, 0x90, 0x74, 0xbd, 0x33, 0xe3, 0x2e, 0x88, 0xec, 0x5e, 0x8a, 0xec, 0x32, 0x23,
		0xad, 0xc1, 0x56, 0x23, 0xd2, 0x43, 0xa4, 0x87, 0x48, 0x0f, 0x91, 0xde, 0xaf, 0x4d, 0x25, 0xd8,
		0x6a, 0x69, 0x37, 0x04, 0x5b, 0x6d, 0x3a, 0xa6, 0xf1, 0xdd, 0x28, 0xb6, 0x45, 0x14, 0xbb, 0x57,
		0xbe, 0x17, 0x7d, 0x15, 0xba, 0x99, 0xeb, 0x97, 0x6f, 0x0f, 0x6c, 0x03, 0x6c, 0x03, 0x6c, 0x03,
		0x6c, 0x03, 0x6c, 0xf3, 0x4c, 0xeb, 0xc0, 0x62, 0xcb, 0xbe, 0x2f, 0x58, 0x6c, 0x7e, 0x9e, 0x75,
		0xe1, 0xb6, 0x60, 0xb1, 0xd5, 0x8a, 0x12, 0x58, 0x6c, 0xb0, 0xd8, 0x2c, 0xef, 0x82, 0x88, 0x6f,
		0x51, 0xac, 0x06, 0xc3, 0xb1, 0x50, 0xb9, 0xbe, 0xdd, 0x75, 0x87, 0xee, 0x95, 0xe7, 0x7b, 0xb1,
		0x27, 0x22, 0x7d, 0x11, 0xdf, 0xcb, 0xb7, 0x47, 0xc4, 0x87, 0x88, 0x0f, 0x11, 0x1f, 0x22, 0x3e,
		0x44, 0x7c, 0xcf, 0xb4, 0xee, 0xab, 0xb8, 0xb3, 0xa3, 0x38, 0xf4, 0x82, 0x1b, 0x90, 0xd9, 0x6b,
		0xde, 0x30, 0xa1, 0xa4, 0x5d, 0xfb, 0xba, 0x62, 0x7f, 0xec, 0x7c, 0x2f, 0x3c, 0x6c, 0xbf, 0x7f,
		0xfa, 0xf7, 0x9d, 0xdf, 0x76, 0xfe, 0x00, 0x07, 0x9d, 0x05, 0x22, 0x19, 0x86, 0xde, 0x20, 0xf4,
		0xe2, 0x7b, 0x7d, 0x20, 0x24, 0xbd, 0x23, 0x70, 0x07, 0x70, 0x07, 0x70, 0x07, 0x70, 0x07, 0x70,
		0xc7, 0x33, 0xad, 0x1b, 0x79, 0x41, 0x7c, 0xa4, 0x11, 0x72, 0x94, 0xc0, 0xf5, 0xae, 0xfe, 0x60,
		0xe0, 0x7a, 0xd5, 0xdf, 0x17, 0x5c, 0xaf, 0xb1, 0xa2, 0x54, 0x28, 0x81, 0xda, 0x65, 0x77, 0x17,
		0x04, 0x52, 0x8b, 0x62, 0x85, 0x61, 0x79, 0x08, 0xac, 0x10, 0x58, 0x21, 0xb0, 0x42, 0x60, 0x45,
		0x37, 0xb0, 0xc2, 0xb0, 0x3c, 0x05, 0x37, 0xc4, 0xb0, 0x3c, 0xc0, 0x2b, 0x1d, 0xf0, 0x2a, 0x0e,
		0xdd, 0xa0, 0xef, 0x45, 0x91, 0x37, 0x08, 0xec, 0x7f, 0x8f, 0xc4, 0x48, 0xd8, 0xbe, 0x08, 0x6e,
		0x92, 0xa9, 0x37, 0xda, 0x80, 0xd6, 0xab, 0x6b, 0x00, 0xe4, 0x02, 0xe4, 0x02, 0xe4, 0x02, 0xe4,
		0x02, 0xe4, 0x7a, 0xa6, 0x75, 0x23, 0x2f, 0x88, 0xf7, 0x0b, 0x1a, 0x41, 0xd6, 0x21, 0xc8, 0xec,
		0xd5, 0x1f, 0x0c, 0x64, 0xb6, 0xfa, 0xfb, 0x82, 0xcc, 0x36, 0x56, 0x94, 0x8a, 0x85, 0x72, 0xb1,
		0x7c, 0x70, 0x58, 0x28, 0x83, 0xd3, 0x66, 0x77, 0x17, 0x04, 0x5d, 0x8b, 0x62, 0x95, 0xcc, 0x65,
		0xb3, 0xbb, 0x5f, 0xc7, 0xee, 0x4e, 0x63, 0x9a, 0xf2, 0xd3, 0xdb, 0x22, 0xb4, 0x42, 0x68, 0x85,
		0xd0, 0x0a, 0xa1, 0x15, 0x42, 0x2b, 0x84, 0x56, 0x08, 0xad, 0x10, 0x5a, 0x21, 0xb4, 0x42, 0x68,
		0x85, 0xd0, 0x0a, 0xa1, 0x95, 0x86, 0xd0, 0x8a, 0xd5, 0xa0, 0xf0, 0x4a, 0x10, 0x0c, 0x62, 0x77,
		0x2c, 0xaa, 0x6a, 0xe7, 0x85, 0x47, 0xdd, 0xaf, 0xa2, 0xef, 0x0e, 0xdd, 0xe4, 0xe4, 0xcd, 0xda,
		0x1b, 0x0c, 0x45, 0xd0, 0x4d, 0x82, 0x1b, 0x3b, 0x10, 0xf1, 0x7f, 0x06, 0xe1, 0x37, 0xdb, 0x0b,
		0xa2, 0xd8, 0x0d, 0xba, 0x62, 0xef, 0xf9, 0x0f, 0xa2, 0x85, 0x9f, 0xec, 0x0d, 0xc3, 0x41, 0x3c,
		0xe8, 0x0e, 0xfc, 0x28, 0xfd, 0xb4, 0x37, 0xc1, 0x9b, 0x7b, 0x6e, 0x28, 0xdc, 0x28, 0xf9, 0x73,
		0xef, 0xd6, 0x0b, 0xe3, 0x91, 0xeb, 0xdb, 0xbe, 0x17, 0x7c, 0x8b, 0x9e, 0xfc, 0x6d, 0x6f, 0x32,
		0x3a, 0xfc, 0x1d, 0x8f, 0xd7, 0x2f, 0xf7, 0x8a, 0x92, 0x05, 0x69, 0x1c, 0xe8, 0x68, 0x48, 0x27,
		0xb3, 0xea, 0x5e, 0x14, 0x57, 0xe2, 0x58, 0x4d, 0x03, 0xcf, 0x31, 0xcc, 0xaa, 0xfa, 0x62, 0x1c,
		0xbd, 0x44, 0x6a, 0xbc, 0xd5, 0xd8, 0xfb, 0xce, 0xdd, 0x41, 0x4f, 0xaf, 0x02, 0xab, 0x11, 0xf6,
		0x44, 0x28, 0x7a, 0xc7, 0xe3, 0x37, 0x14, 0x8c, 0x7c, 0x9f, 0xb4, 0x20, 0x29, 0xb6, 0x44, 0xb4,
		0x2c, 0x90, 0x82, 0xf8, 0xcb, 0x8a, 0xe2, 0x70, 0xd4, 0x8d, 0x83, 0x69, 0x9c, 0x77, 0x36, 0x59,
		0x71, 0x6d, 0xba, 0x60, 0xa7, 0x39, 0x5d, 0xa6, 0xd3, 0x48, 0x96, 0xe9, 0x54, 0x42, 0xe1, 0x3a,
		0x5f, 0x26, 0x4b, 0xaa, 0x8f, 0x57, 0xf4, 0x8e, 0xa6, 0xcd, 0x92, 0x73, 0x25, 0x49, 0xc2, 0xaa,
		0x4a, 0x48, 0x33, 0x17, 0x4e, 0x39, 0x6f, 0x7f, 0xfd, 0x77, 0xb5, 0xde, 0x15, 0xd6, 0x7c, 0xcb,
		0x33, 0x5f, 0x36, 0x99, 0x9c, 0x7f, 0xed, 0xad, 0xdd, 0xb3, 0x59, 0xae, 0xd7, 0x92, 0xef, 0xa5,
		0xb4, 0x78, 0x25, 0xb9, 0x5e, 0x68, 0xdd, 0x57, 0x2c, 0x59, 0x81, 0x33, 0x50, 0x5c, 0x09, 0xae,
		0x63, 0x05, 0x57, 0xb1, 0x9e, 0x81, 0x58, 0x5d, 0xad, 0x57, 0xfb, 0xcd, 0x15, 0xa5, 0x44, 0x96,
		0x74, 0xe8, 0x95, 0x8a, 0xd5, 0x5e, 0xcd, 0xf2, 0x1b, 0xbb, 0xc2, 0xa6, 0x5a, 0x37, 0xfe, 0xe0,
		0xca, 0xf5, 0x57, 0xde, 0xcc, 0x94, 0xb5, 0x9e, 0x5e, 0x67, 0xc5, 0xd7, 0x3a, 0xcb, 0xa4, 0x5e,
		0xf1, 0xd7, 0xd7, 0x3d, 0x85, 0x93, 0x71, 0xba, 0x26, 0xf5, 0xd4, 0x4c, 0xd6, 0x69, 0x98, 0xf4,
		0x53, 0x2e, 0xe9, 0xa7, 0x57, 0xb2, 0x4f, 0xa5, 0xf4, 0x9a, 0xa3, 0x13, 0x6f, 0x3d, 0xe4, 0x60,
		0x75, 0x67, 0x92, 0xbb, 0xe6, 0x7b, 0x9e, 0x09, 0xdf, 0xf4, 0x7a, 0xeb, 0xc2, 0xac, 0xb5, 0xd4,
		0x51, 0x9a, 0x5a, 0xca, 0x54, 0x4f, 0x25, 0x6a, 0x2a, 0x5b, 0x5d, 0x95, 0xa9, 0xad, 0x32, 0xf5,
		0x55, 0xa5, 0xc6, 0x34, 0xc2, 0x8d, 0x75, 0xd5, 0x3b, 0xbd, 0xd0, 0x57, 0xaf, 0x27, 0xec, 0x38,
		0x74, 0x83, 0xc8, 0x8b, 0xed, 0x41, 0xe0, 0xdf, 0xcf, 0x60, 0x86, 0xbc, 0xf4, 0x9b, 0xc7, 0xf6,
		0x56, 0xaf, 0xdf, 0x4b, 0xd2, 0xbb, 0x96, 0x7b, 0x66, 0x24, 0x3d, 0x87, 0x46, 0x45, 0xae, 0x8c,
		0xd2, 0x9c, 0x18, 0x55, 0xb9, 0x2f, 0xca, 0x73, 0x5c, 0x94, 0xe7, 0xb2, 0xa8, 0xce, 0x59, 0xa1,
		0xc5, 0x5d, 0x49, 0xcf, 0x35, 0x49, 0xa5, 0xf6, 0x6a, 0x30, 0xf0, 0x85, 0x1b, 0xc8, 0x94, 0xd9,
		0x19, 0x46, 0xc8, 0x53, 0x21, 0xa6, 0x24, 0xb8, 0x71, 0xef, 0x66, 0x68, 0x47, 0x5f, 0x07, 0x61,
		0xdc, 0x1d, 0xc5, 0x0a, 0x2c, 0xf3, 0xd3, 0xcb, 0xc3, 0x18, 0xc3, 0x18, 0xc3, 0x18, 0xc3, 0x18,
		0xc3, 0x18, 0xbf, 0xfc, 0x4c, 0xfe, 0xe0, 0xc6, 0x76, 0x7b, 0xff, 0x72, 0xbb, 0x22, 0xe8, 0xde,
		0x4b, 0xcf, 0x56, 0x7f, 0x1c, 0x97, 0xf4, 0xe2, 0x6d, 0x60, 0x9c, 0x61, 0x9c, 0x61, 0x9c, 0x61,
		0x9c, 0x61, 0x9c, 0x5f, 0x7e, 0x26, 0xf9, 0xfd, 0xb0, 0x1e, 0xdb, 0x31, 0x48, 0xce, 0x50, 0x82,
		0x11, 0x86, 0x11, 0x86, 0x11, 0x66, 0x65, 0x84, 0xd5, 0xcc, 0x9b, 0x55, 0xd1, 0xaf, 0x49, 0x59,
		0x5f, 0x26, 0xa6, 0x73, 0x62, 0x3b, 0x06, 0xf9, 0xb8, 0x68, 0xd4, 0xef, 0xbb, 0xe1, 0xfd, 0x24,
		0x65, 0xd6, 0xee, 0x0e, 0xa2, 0xd8, 0xee, 0x0f, 0x7a, 0x42, 0xbe, 0xc7, 0x7b, 0xed, 0x46, 0x92,
		0xf4, 0xf4, 0x44, 0x5c, 0xbb, 0x23, 0x3f, 0xb1, 0x49, 0xad, 0x8f, 0x1f, 0x0a, 0xfb, 0x85, 0x23,
		0xe7, 0x43, 0xe3, 0xb4, 0x59, 0x69, 0xd7, 0x8e, 0xeb, 0x55, 0x38, 0x59, 0x38, 0x59, 0x38, 0xd9,
		0x4d, 0x74, 0xb2, 0x22, 0x18, 0xf5, 0x45, 0x38, 0xc9, 0xa5, 0x52, 0xe0, 0x64, 0x8b, 0x12, 0xaf,
		0x59, 0x0d, 0x46, 0xfd, 0xf1, 0x26, 0x3c, 0x20, 0x09, 0x96, 0x71, 0x86, 0xe4, 0x24, 0x45, 0x6c,
		0x6f, 0x9a, 0xa2, 0x92, 0x55, 0xba, 0xe2, 0x1a, 0x49, 0x59, 0x37, 0xa1, 0xdb, 0x15, 0xd7, 0x23,
		0xdf, 0x0e, 0x45, 0x14, 0xbb, 0x61, 0x2c, 0x2f, 0x6d, 0x67, 0xe1, 0xca, 0x48, 0xe0, 0xd1, 0xea,
		0x75, 0x91, 0xc0, 0x83, 0x04, 0x9e, 0x9f, 0x5e, 0x48, 0x52, 0x9e, 0xde, 0x82, 0x10, 0x4b, 0xc9,
		0xd7, 0x93, 0xac, 0xf6, 0x00, 0xe1, 0x00, 0xe1, 0x00, 0xe1, 0x2a, 0xcc, 0x48, 0x7a, 0x41, 0x11,
		0xb8, 0x57, 0xbe, 0x90, 0x3f, 0x4c, 0x62, 0x0e, 0xdc, 0x4f, 0x6e, 0x20, 0xbb, 0x96, 0x58, 0x49,
		0xb7, 0x08, 0x65, 0x5d, 0xb4, 0x54, 0x76, 0xcd, 0xd2, 0xd2, 0x25, 0x4b, 0x75, 0x57, 0x2c, 0x6d,
		0x5d, 0xb0, 0xb4, 0x75, 0xbd, 0xd2, 0xd5, 0xe5, 0x8a, 0x76, 0xcd, 0xbf, 0xb2, 0xae, 0x55, 0x0a,
		0xcf, 0x49, 0x17, 0x50, 0x4c, 0x9e, 0x6a, 0xc1, 0xb3, 0x44, 0x80, 0xf1, 0x55, 0xf8, 0x43, 0x11,
		0x26, 0x69, 0xda, 0xea, 0x9c, 0xc1, 0xfc, 0x4d, 0xe0, 0x10, 0xe0, 0x10, 0xe0, 0x10, 0xe0, 0x10,
		0xe0, 0x10, 0xd0, 0x01, 0x63, 0xb9, 0xeb, 0x6a, 0xa6, 0x89, 0x9f, 0x53, 0xa2, 0x52, 0x78, 0x63,
		0x79, 0x6f, 0x4c, 0xca, 0x01, 0x73, 0xd2, 0xe4, 0x4a, 0xfe, 0x71, 0x72, 0x72, 0x59, 0xe2, 0x94,
		0x52, 0x01, 0x94, 0x12, 0x28, 0x25, 0x50, 0x4a, 0xa0, 0x94, 0x10, 0x41, 0x20, 0x82, 0x40, 0x04,
		0x81, 0x08, 0x02, 0x94, 0x12, 0x28, 0x25, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0x38,
		0x04, 0x50, 0x4a, 0x3a, 0x28, 0x25, 0x89, 0x5d, 0xc6, 0x91, 0x54, 0x4a, 0xea, 0xd5, 0xea, 0xef,
		0xc1, 0xf9, 0x29, 0x59, 0x88, 0xf3, 0x69, 0xba, 0x90, 0xd6, 0x74, 0x1d, 0x0c, 0xd3, 0x5c, 0xbd,
		0x20, 0x16, 0xa1, 0xed, 0x86, 0xc2, 0xb5, 0x87, 0xe1, 0x60, 0xe8, 0xde, 0x24, 0x62, 0x61, 0x0f,
		0x07, 0xbe, 0xd7, 0xf5, 0x24, 0x94, 0xe0, 0x3f, 0xf6, 0x43, 0xf9, 0xc5, 0x8d, 0x90, 0x04, 0xab,
		0x15, 0x18, 0x22, 0x09, 0x16, 0x49, 0xb0, 0x2b, 0x1b, 0x86, 0x7b, 0x05, 0xed, 0x92, 0x7e, 0x7a,
		0x3b, 0xa4, 0xcc, 0x92, 0x8c, 0x2a, 0x71, 0xbe, 0x91, 0x55, 0xd4, 0x68, 0xf8, 0xf9, 0x86, 0xe4,
		0x0c, 0xfc, 0x05, 0x65, 0x90, 0x9a, 0x89, 0xaf, 0xc8, 0xbc, 0x80, 0xcc, 0x02, 0x99, 0x05, 0x32,
		0x4b, 0x05, 0x99, 0x25, 0xdb, 0x5c, 0xa5, 0x17, 0xee, 0x4d, 0x8a, 0xef, 0x6d, 0xaf, 0x3f, 0x1c,
		0x84, 0xb1, 0x6c, 0xac, 0xf4, 0xaa, 0x8e, 0xbd, 0x7c, 0x5b, 0x45, 0x12, 0x34, 0xdf, 0x60, 0xa0,
		0xfa, 0xff, 0x55, 0x3f, 0xb4, 0x9d, 0x56, 0xe3, 0x73, 0xbb, 0xaa, 0xea, 0x76, 0x6a, 0x47, 0x56,
		0x2a, 0x1f, 0xe9, 0xad, 0x63, 0x94, 0xf7, 0xbc, 0xad, 0x0d, 0x87, 0x03, 0x5f, 0xe1, 0x34, 0x61,
		0x5d, 0x83, 0xbb, 0xb5, 0x0f, 0xec, 0xd6, 0x3e, 0xa8, 0xfb, 0xb9, 0x25, 0x4e, 0x5e, 0x1c, 0xa6,
		0x60, 0x6e, 0x69, 0x19, 0xc3, 0xbd, 0x60, 0x39, 0x27, 0x26, 0xd3, 0x8e, 0xc7, 0x37, 0x56, 0xa8,
		0x3d, 0x0a, 0xda, 0x25, 0x2c, 0xdc, 0x43, 0x6e, 0xfb, 0x04, 0xf5, 0x82, 0xa4, 0x40, 0x88, 0xac,
		0x5e, 0x14, 0x27, 0x54, 0x82, 0x06, 0xd7, 0x3b, 0xbb, 0x13, 0xdc, 0x1f, 0x05, 0xf7, 0xa7, 0x2c,
		0xd4, 0x80, 0x03, 0xe4, 0x1a, 0x8a, 0xc0, 0x05, 0xfe, 0x5c, 0x6b, 0x7c, 0xe1, 0x5e, 0x87, 0xe2,
		0x5a, 0x87, 0xdb, 0x3b, 0x54, 0x78, 0x8f, 0xe6, 0xf4, 0xf0, 0x71, 0x77, 0x77, 0x6f, 0xfe, 0xbf,
		0xb9, 0x09, 0x9b, 0x73, 0x73, 0x24, 0x37, 0xd8, 0x35, 0x6a, 0x0e, 0x4d, 0xb5, 0x84, 0xa4, 0x70,
		0x92, 0x88, 0x11, 0x11, 0x23, 0xc2, 0x41, 0xc2, 0x41, 0xbe, 0xc1, 0x41, 0xee, 0x4d, 0x05, 0xe9,
		0x7d, 0x38, 0x18, 0xc5, 0x5e, 0x70, 0x33, 0xb5, 0xcd, 0xe9, 0x8f, 0xa7, 0xa1, 0x70, 0x4f, 0x5c,
		0x7b, 0x81, 0x17, 0x7b, 0x83, 0x20, 0x7a, 0xfd, 0x7f, 0xa5, 0xff, 0x27, 0xc9, 0x9b, 0x61, 0x25,
		0x3f, 0x52, 0x67, 0x41, 0xbf, 0x7a, 0x17, 0xe9, 0x33, 0xa2, 0x5f, 0xbf, 0x93, 0x86, 0xd9, 0xd1,
		0xaf, 0xde, 0x7c, 0x7e, 0xa6, 0xb4, 0x62, 0xa3, 0x3f, 0xd3, 0xca, 0x51, 0xb4, 0xf6, 0x3c, 0x70,
		0x2a, 0x8e, 0xec, 0xb9, 0x33, 0x1b, 0x4c, 0x76, 0xd3, 0xbe, 0xba, 0x57, 0xfc, 0x80, 0x99, 0x38,
		0xb5, 0x05, 0xc7, 0x96, 0xbc, 0x49, 0xa5, 0xb7, 0x7c, 0xe0, 0xe6, 0x33, 0x59, 0x44, 0x12, 0x51,
		0xd8, 0xd5, 0x44, 0xb2, 0xa5, 0x77, 0x42, 0xfc, 0x00, 0x92, 0x0d, 0x11, 0x04, 0x48, 0x36, 0xc4,
		0x10, 0x20, 0xd9, 0x68, 0x5e, 0x51, 0x76, 0xaa, 0x8a, 0xa2, 0x62, 0x9c, 0x47, 0x27, 0xae, 0xb7,
		0x72, 0xe3, 0x17, 0x45, 0x00, 0x3f, 0xfd, 0xff, 0xf7, 0x52, 0x9b, 0xc2, 0xc8, 0x7f, 0xfd, 0x32,
		0xcb, 0x7a, 0x95, 0x1d, 0x60, 0xaa, 0x3e, 0xb8, 0x44, 0x41, 0xaf, 0x66, 0xcc, 0x84, 0x1c, 0x48,
		0xaa, 0x98, 0x68, 0xd3, 0x0b, 0x7a, 0xd5, 0x61, 0x1e, 0x95, 0x58, 0x67, 0x1e, 0xe3, 0x24, 0x15,
		0xa3, 0x7b, 0xa9, 0xa5, 0xdc, 0x00, 0xbf, 0xa3, 0x2c, 0xa6, 0x57, 0x1d, 0xcb, 0xc3, 0xef, 0xc0,
		0xef, 0xc0, 0xef, 0xc0, 0xef, 0x18, 0xe4, 0x77, 0x52, 0x4b, 0xb9, 0x09, 0x7e, 0x47, 0x6a, 0x73,
		0xcc, 0x45, 0xa7, 0x23, 0xb1, 0x49, 0xe6, 0x82, 0x30, 0xa8, 0xf2, 0x38, 0x05, 0x78, 0x1c, 0x78,
		0x1c, 0x78, 0x9c, 0xb5, 0x37, 0x01, 0xd5, 0x5e, 0xeb, 0x6c, 0x1e, 0xaa, 0xbd, 0x88, 0xd8, 0xd8,
		0x97, 0x6c, 0x2d, 0x32, 0xf9, 0x88, 0x5b, 0xe0, 0xd7, 0x2c, 0x31, 0x32, 0xf9, 0x34, 0x44, 0x04,
		0xaf, 0x5a, 0x4e, 0x54, 0x7b, 0x65, 0x26, 0x48, 0xa8, 0xf6, 0x82, 0xfb, 0xa3, 0x1f, 0x6a, 0xc0,
		0x01, 0x72, 0x0d, 0x45, 0xe0, 0x02, 0xb3, 0x22, 0xc7, 0x74, 0x90, 0x64, 0x2f, 0x91, 0x65, 0xa8,
		0xf6, 0xfa, 0xc9, 0x3e, 0xa1, 0xda, 0x0b, 0x31, 0x22, 0x62, 0x44, 0xc4, 0x88, 0x70, 0x90, 0x1b,
		0xea, 0x20, 0x51, 0xed, 0xb5, 0x85, 0x6a, 0x2f, 0xc9, 0x37, 0x47, 0xb5, 0x97, 0x4c, 0x67, 0x86,
		0x6a, 0x2f, 0x16, 0x9e, 0x6d, 0x0b, 0xd5, 0x5e, 0xa8, 0xf6, 0x02, 0xc9, 0x86, 0x08, 0x02, 0x24,
		0x1b, 0x62, 0x08, 0x90, 0x6c, 0xa8, 0xf6, 0xda, 0x42, 0xb5, 0x97, 0xda, 0x6a, 0x2f, 0x89, 0xf3,
		0x9a, 0xe4, 0xbf, 0x7d, 0x5a, 0xfd, 0xf7, 0xff, 0x29, 0xee, 0xe7, 0x91, 0xd3, 0x96, 0xe4, 0x73,
		0x4a, 0x35, 0xe1, 0xb3, 0xba, 0x70, 0x59, 0x6b, 0x78, 0xfc, 0x24, 0x1c, 0x0e, 0x46, 0xbe, 0x8f,
		0x61, 0x6e, 0xc4, 0x2c, 0x89, 0x25, 0x35, 0x51, 0x79, 0x85, 0x31, 0x61, 0xb5, 0xf1, 0xea, 0x2a,
		0xa1, 0x70, 0x9b, 0x8f, 0x6b, 0x6b, 0x4e, 0x96, 0x86, 0x71, 0x74, 0xfc, 0xc7, 0xd1, 0xfd, 0x6a,
		0xb2, 0x19, 0xc3, 0xa9, 0x70, 0xfd, 0xa1, 0x2f, 0x71, 0xf4, 0x5b, 0x72, 0x35, 0xcc, 0x77, 0xd3,
		0x1a, 0x6d, 0x63, 0xbe, 0x1b, 0xe6, 0xbb, 0xfd, 0xf4, 0x42, 0x92, 0x47, 0x2c, 0xa9, 0x19, 0xad,
		0x84, 0x89, 0x6d, 0x98, 0xd8, 0xa6, 0x89, 0x4c, 0xc3, 0xc4, 0xb6, 0xb5, 0x2e, 0x18, 0x87, 0xee,
		0xf5, 0xb5, 0xd7, 0xb5, 0x45, 0x70, 0xe3, 0x05, 0x42, 0x84, 0x5e, 0x70, 0x63, 0x8b, 0xbb, 0x58,
		0x04, 0x91, 0x37, 0x08, 0x22, 0x75, 0xa5, 0x7d, 0xbf, 0xb8, 0x2f, 0xaa, 0xcc, 0x51, 0xf3, 0x97,
		0xa5, 0xd9, 0xd2, 0x66, 0xbe, 0x74, 0x99, 0x31, 0x1e, 0x44, 0xaa, 0xfa, 0x2a, 0xf3, 0xab, 0xc1,
		0xc0, 0x17, 0x6e, 0xa0, 0xb2, 0xca, 0x3c, 0x0f, 0xee, 0x73, 0x73, 0x18, 0xae, 0x71, 0x8c, 0x2c,
		0xb5, 0xc1, 0x99, 0x04, 0x52, 0x48, 0x42, 0x14, 0xea, 0xdd, 0x0c, 0x6d, 0xbf, 0x37, 0xb4, 0xa3,
		0xfb, 0xa0, 0xab, 0x60, 0x68, 0xf4, 0xfc, 0xd5, 0x11, 0x71, 0x20, 0xe2, 0x40, 0xc4, 0xb1, 0x39,
		0x11, 0x07, 0x66, 0x44, 0x23, 0x82, 0x40, 0x04, 0x81, 0x08, 0x42, 0x4d, 0x04, 0xa1, 0xac, 0x6b,
		0x88, 0x08, 0xdc, 0x2b, 0x5f, 0xf4, 0xd4, 0xe7, 0x51, 0xce, 0x6e, 0x84, 0x34, 0x4a, 0xdd, 0x86,
		0x4d, 0xab, 0x81, 0xd3, 0x65, 0xe8, 0xb4, 0x1b, 0x3c, 0xed, 0x86, 0x4f, 0xb7, 0x01, 0x54, 0x63,
		0x08, 0x15, 0x19, 0x44, 0xf5, 0xd4, 0x8a, 0x46, 0x8a, 0x45, 0x31, 0xd5, 0xa2, 0xee, 0xc5, 0xaa,
		0xc8, 0xec, 0x1f, 0x0e, 0xa2, 0xd8, 0x8e, 0x44, 0x14, 0x79, 0x83, 0xc0, 0x1e, 0x0d, 0xed, 0x9e,
		0xf0, 0x5d, 0x0d, 0xb5, 0xc2, 0x2f, 0xdf, 0x16, 0xce, 0x0a, 0xce, 0x0a, 0xce, 0x0a, 0xce, 0x8a,
		0x9d, 0xb3, 0x1a, 0x79, 0x41, 0xbc, 0x5f, 0xd0, 0xe0, 0xab, 0x54, 0x66, 0xfc, 0xb7, 0xdc, 0xe0,
		0x66, 0xfc, 0x34, 0x17, 0x4a, 0x45, 0x56, 0x43, 0x7d, 0xe5, 0xa9, 0x17, 0x68, 0x29, 0xe4, 0xd4,
		0xe0, 0x5c, 0x16, 0x6e, 0xf7, 0xc5, 0xf5, 0x47, 0x42, 0xe3, 0xfd, 0x3e, 0x86, 0x6e, 0x37, 0xf6,
		0x06, 0xc1, 0x89, 0x77, 0xe3, 0x4d, 0x32, 0xb5, 0x95, 0xdf, 0xf7, 0x41, 0x43, 0x51, 0xea, 0xa9,
		0x7b, 0x67, 0xbc, 0x88, 0x14, 0x0b, 0xe5, 0x62, 0xf9, 0xe0, 0xb0, 0x50, 0x2e, 0x19, 0x2c, 0x2b,
		0x4c, 0x8b, 0x89, 0x3b, 0xa8, 0x98, 0x92, 0x81, 0x7e, 0xcc, 0xaa, 0x98, 0x4a, 0x4e, 0x81, 0xe7,
		0x4f, 0x35, 0x37, 0x68, 0xe6, 0x15, 0x7a, 0xc0, 0x2f, 0xc6, 0x93, 0xe8, 0x01, 0xaf, 0x37, 0x6e,
		0xc4, 0x69, 0x8e, 0x99, 0x6e, 0x02, 0xa7, 0x39, 0x20, 0xc8, 0x40, 0x90, 0x81, 0x20, 0x03, 0x41,
		0x96, 0x19, 0x41, 0x86, 0xd3, 0x1c, 0x1d, 0x2f, 0x15, 0xa7, 0x39, 0x70, 0x56, 0x70, 0x56, 0x70,
		0x56, 0x70, 0x56, 0x6b, 0x69, 0x0d, 0x4e, 0x73, 0xde, 0xfc, 0x85, 0xd3, 0x9c, 0xb5, 0x6e, 0x87,
		0xd3, 0x1c, 0x39, 0x22, 0x82, 0xd3, 0x1c, 0x33, 0x64, 0x05, 0xa7, 0x39, 0x6a, 0x43, 0x0e, 0x9c,
		0xe6, 0x64, 0x79, 0x9a, 0x83, 0x9e, 0x76, 0x59, 0xcb, 0x42, 0xe6, 0x32, 0x90, 0x79, 0x37, 0xb2,
		0xd3, 0xa1, 0x1f, 0x39, 0xb5, 0x9b, 0x61, 0xbd, 0x37, 0x3c, 0x1f, 0xaf, 0xc7, 0xa0, 0x6a, 0x53,
		0xb9, 0x47, 0x88, 0x4a, 0x8e, 0x0e, 0x95, 0xd5, 0x97, 0x16, 0x50, 0x5f, 0x8a, 0xfa, 0x52, 0xad,
		0x64, 0x02, 0x3a, 0xda, 0x28, 0xe1, 0x1e, 0xd0, 0xd1, 0x46, 0xb3, 0x79, 0xd2, 0x62, 0xa6, 0x54,
		0x9b, 0x2b, 0x6d, 0x66, 0x4b, 0x9b, 0xf9, 0xd2, 0x65, 0xc6, 0x78, 0x84, 0x46, 0xe8, 0x68, 0x83,
		0xc8, 0x87, 0x61, 0xe4, 0x23, 0x31, 0xe0, 0x45, 0x97, 0xe3, 0xcc, 0x5f, 0xa7, 0x25, 0x25, 0x46,
		0x5b, 0x31, 0x66, 0xe5, 0xd8, 0x47, 0x59, 0x4e, 0x40, 0x2a, 0x35, 0x10, 0x95, 0xde, 0x49, 0xb9,
		0x80, 0x4e, 0xca, 0x34, 0x10, 0x1a, 0x3a, 0x29, 0x67, 0x12, 0x30, 0x5a, 0x5f, 0xbd, 0x9e, 0xb0,
		0xe3, 0xd0, 0x0d, 0x22, 0x2f, 0xb6, 0x07, 0x81, 0x7f, 0x3f, 0x33, 0xc0, 0x91, 0x7c, 0x2a, 0xea,
		0x27, 0xf7, 0x92, 0xcb, 0x4f, 0xe5, 0xd0, 0xff, 0x0c, 0xfc, 0x14, 0xf8, 0x29, 0x79, 0xa8, 0x5e,
		0x7a, 0x00, 0xa7, 0x30, 0x70, 0x93, 0x1c, 0xb0, 0xd1, 0x69, 0x45, 0x19, 0x7d, 0x1d, 0x84, 0x71,
		0x77, 0x14, 0x47, 0x6a, 0x7a, 0x51, 0x3e, 0x5e, 0x1e, 0xc6, 0x18, 0xc6, 0x18, 0xc6, 0x18, 0xc6,
		0x18, 0xc6, 0xf8, 0xe5, 0x67, 0xf2, 0x07, 0x37, 0xb6, 0xdb, 0xfb, 0x97, 0xdb, 0x15, 0x41, 0xf7,
		0xde, 0xee, 0x7e, 0x75, 0x83, 0x1b, 0xa1, 0xc0, 0x28, 0xbf, 0x7c, 0x1b, 0x18, 0x67, 0x18, 0x67,
		0x18, 0x67, 0x18, 0x67, 0x18, 0xe7, 0x97, 0x9f, 0x29, 0x1c, 0x8c, 0x62, 0x11, 0xda, 0x5e, 0x4f,
		0xbe, 0x41, 0x7e, 0xbc, 0x34, 0x8c, 0x30, 0x8c, 0x30, 0x8c, 0xf0, 0x06, 0x1a, 0xe1, 0xde, 0x20,
		0x8e, 0x45, 0xcf, 0xfe, 0xf7, 0xc8, 0xed, 0xa9, 0x30, 0xc4, 0x47, 0x12, 0xaf, 0xd9, 0x74, 0xe3,
		0x58, 0x84, 0x81, 0xf4, 0x1a, 0x1a, 0x6b, 0x7b, 0xfb, 0x22, 0x67, 0x97, 0x3b, 0x3f, 0x2e, 0xf2,
		0x76, 0xb9, 0x33, 0xf9, 0x98, 0x4f, 0xbe, 0x4d, 0x3e, 0x17, 0x2e, 0x72, 0x76, 0x71, 0xf6, 0xb9,
		0x74, 0x91, 0xb3, 0x4b, 0x9d, 0x9d, 0xcb, 0xcb, 0xdd, 0x9d, 0xef, 0xfb, 0x0f, 0xcb, 0xff, 0xa2,
		0x3c, 0x09, 0xed, 0x98, 0x94, 0x2a, 0x3a, 0xea, 0xf7, 0xdd, 0xf0, 0xde, 0x4e, 0x1c, 0x92, 0xdd,
		0x1d, 0x44, 0xb1, 0xdd, 0x1f, 0xf4, 0x54, 0x24, 0x8f, 0xbe, 0x72, 0x23, 0x59, 0x69, 0x6f, 0xe2,
		0xda, 0x1d, 0xf9, 0x89, 0x4d, 0x6a, 0x7d, 0xfc, 0x50, 0xd8, 0x2f, 0x1c, 0x39, 0x1f, 0x1a, 0xa7,
		0xcd, 0x4a, 0xbb, 0x76, 0x5c, 0xaf, 0xc2, 0xc9, 0xc2, 0xc9, 0xc2, 0xc9, 0x6e, 0xa2, 0x93, 0x15,
		0xc1, 0xa8, 0x2f, 0xc2, 0x49, 0xb6, 0x89, 0x02, 0x27, 0x5b, 0x94, 0x78, 0xcd, 0x6a, 0x30, 0xea,
		0x8f, 0x37, 0xe1, 0x01, 0x59, 0x42, 0xfc, 0xb3, 0x84, 0x24, 0xe4, 0x7b, 0x65, 0x93, 0xa9, 0x13,
		0x7b, 0x7d, 0x11, 0x4a, 0x9c, 0x79, 0x3e, 0xbd, 0x1e, 0xa6, 0x9e, 0x6b, 0x75, 0xb0, 0xc8, 0xd5,
		0x41, 0xae, 0xce, 0x4f, 0x2f, 0xe4, 0x47, 0xae, 0x7d, 0x23, 0x82, 0x99, 0x6b, 0x94, 0x7f, 0xe0,
		0xf0, 0xf4, 0xfa, 0x98, 0x49, 0x08, 0xfc, 0x0d, 0xfc, 0x4d, 0x16, 0x7f, 0x63, 0x26, 0xe1, 0x16,
		0x66, 0x12, 0xea, 0x33, 0x3b, 0xaa, 0xcd, 0x8f, 0x36, 0x33, 0xa4, 0xcd, 0x1c, 0xe9, 0x32, 0x4b,
		0x72, 0xcd, 0x93, 0x64, 0x33, 0xa5, 0xcc, 0x5c, 0xa5, 0x17, 0xf6, 0x02, 0x2f, 0xf6, 0x5c, 0x5f,
		0x57, 0xb3, 0xc0, 0xa7, 0xb7, 0x43, 0x93, 0x40, 0xdd, 0x46, 0x4e, 0xab, 0xb1, 0xd3, 0x65, 0xf4,
		0xb4, 0x1b, 0x3f, 0xed, 0x46, 0x50, 0xb7, 0x31, 0x54, 0x63, 0x14, 0x15, 0x19, 0xc7, 0x74, 0x73,
		0xd0, 0x24, 0x70, 0xa9, 0x5b, 0xa0, 0x49, 0x20, 0x3d, 0xe7, 0xb2, 0x70, 0x3b, 0x34, 0x09, 0x94,
		0x23, 0x22, 0x68, 0x12, 0x68, 0x86, 0xac, 0xa0, 0x49, 0xa0, 0xd2, 0xf5, 0xaa, 0xe8, 0x4b, 0xde,
		0x77, 0xef, 0xbc, 0xfe, 0xa8, 0xaf, 0x2b, 0xc4, 0x78, 0x7a, 0x3b, 0x84, 0x18, 0x08, 0x31, 0x10,
		0x62, 0x20, 0xc4, 0x40, 0x88, 0x81, 0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31,
		0x10, 0x62, 0x64, 0x1a, 0x62, 0xa0, 0x0f, 0xb9, 0xbe, 0xa4, 0xbc, 0x49, 0x2e, 0xda, 0xde, 0xd3,
		0xdc, 0x14, 0x4c, 0x96, 0x95, 0x05, 0xd2, 0x30, 0x59, 0x16, 0x67, 0xf2, 0x74, 0x62, 0x46, 0x9c,
		0xc9, 0x6b, 0x75, 0x15, 0x38, 0x93, 0x07, 0x61, 0x06, 0xc2, 0x0c, 0x84, 0x19, 0x08, 0x33, 0x10,
		0x66, 0x20, 0xcc, 0x40, 0x98, 0x81, 0x30, 0x03, 0x61, 0x06, 0xc2, 0x0c, 0x84, 0x19, 0x03, 0x5d,
		0xc4, 0x99, 0x3c, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0x10, 0x62, 0x20, 0xc4, 0x40, 0x88, 0x81,
		0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0x64, 0x8a, 0x49, 0x72, 0xf4, 0x6c,
		0xc7, 0x2a, 0x9d, 0xf3, 0xd3, 0x96, 0x2b, 0x93, 0x7b, 0x21, 0xb8, 0x40, 0x70, 0x81, 0xe0, 0x02,
		0xc1, 0x05, 0xbb, 0xe0, 0x42, 0x4d, 0xdf, 0xb6, 0xd7, 0x0c, 0x99, 0xcc, 0x3e, 0x6e, 0x0b, 0xf7,
		0x90, 0xdb, 0xd7, 0x4d, 0x83, 0xfb, 0x43, 0x4a, 0x5a, 0xd6, 0x29, 0x69, 0x12, 0xa7, 0x85, 0xca,
		0x7f, 0xab, 0x18, 0x12, 0xab, 0x4b, 0x0e, 0x2c, 0xa9, 0xb9, 0x7f, 0x2b, 0x8c, 0x1b, 0x6d, 0x27,
		0xab, 0x72, 0xea, 0x91, 0xfb, 0xe9, 0x71, 0x51, 0x06, 0x35, 0x3f, 0xee, 0xbb, 0x77, 0x76, 0x5f,
		0xc4, 0xa1, 0xd7, 0x95, 0xdf, 0x01, 0x6d, 0xee, 0xda, 0xe8, 0x7e, 0x46, 0x12, 0x45, 0xa3, 0xfb,
		0x59, 0x56, 0x28, 0x18, 0xdd, 0xcf, 0xd6, 0x52, 0x06, 0x74, 0x3f, 0x43, 0xa6, 0x35, 0xa1, 0x60,
		0x1d, 0x99, 0xd6, 0x5a, 0x23, 0x20, 0x85, 0x99, 0xd6, 0x5d, 0x7f, 0xd4, 0x13, 0x3a, 0x72, 0xac,
		0x27, 0x37, 0x02, 0x3b, 0xa9, 0xdb, 0xb0, 0x69, 0x35, 0x70, 0xba, 0x0c, 0x9d, 0x76, 0x83, 0xa7,
		0xdd, 0xf0, 0xe9, 0x36, 0x80, 0xea, 0xc8, 0xa5, 0x2d, 0x23, 0xd8, 0x49, 0xaf, 0x27, 0x82, 0xd8,
		0x8b, 0xef, 0x43, 0x71, 0xad, 0x83, 0x9d, 0x54, 0x78, 0x96, 0x69, 0xd5, 0xa6, 0x8f, 0x72, 0xec,
		0x46, 0x1a, 0x34, 0x74, 0xb6, 0x81, 0xa7, 0x95, 0x3f, 0x9d, 0xd3, 0x6a, 0xbb, 0x55, 0xfb, 0xe0,
		0xd4, 0xce, 0x3e, 0xd4, 0x3f, 0x9f, 0x54, 0x55, 0xab, 0x6a, 0x72, 0x40, 0x1c, 0x29, 0xcf, 0xf4,
		0xd8, 0xd2, 0x92, 0xed, 0xf1, 0x8b, 0xbd, 0x74, 0xda, 0x7f, 0x35, 0xab, 0x05, 0xa7, 0xfa, 0x67,
		0xbb, 0xda, 0x3a, 0xab, 0xd4, 0x2d, 0x13, 0xb2, 0x17, 0xb2, 0xdf, 0xd4, 0xf3, 0xf6, 0xe7, 0x63,
		0x8b, 0xf9, 0xe1, 0x7e, 0x07, 0xae, 0x22, 0x79, 0xcd, 0x75, 0x2f, 0x8a, 0x2b, 0x71, 0x1c, 0xaa,
		0x75, 0x17, 0xa7, 0x5e, 0x50, 0xf5, 0xc5, 0xd8, 0x5f, 0x47, 0x6a, 0x53, 0x61, 0xac, 0x53, 0xf7,
		0x6e, 0xee, 0x4e, 0xf9, 0xa3, 0x62, 0xf1, 0xe0, 0xb0, 0x58, 0xcc, 0x1d, 0xee, 0x1f, 0xe6, 0xca,
		0xa5, 0x52, 0xfe, 0x40, 0xa9, 0x0b, 0x69, 0x84, 0x3d, 0x11, 0x8a, 0xde, 0xf1, 0xbd, 0xf5, 0x7e,
		0x2b, 0x18, 0xf9, 0xfe, 0x06, 0xa7, 0x79, 0x44, 0x22, 0x56, 0x1f, 0x3e, 0x8d, 0x6f, 0x82, 0xd0,
		0x09, 0xa1, 0x13, 0x42, 0x27, 0x84, 0x4e, 0xec, 0x42, 0x27, 0xf9, 0xa3, 0xc7, 0x5f, 0x0d, 0x9b,
		0xf2, 0x1b, 0x9e, 0x6f, 0x38, 0x18, 0xc5, 0x7a, 0x92, 0x0d, 0xc7, 0x37, 0x82, 0x43, 0x82, 0x43,
		0x82, 0x43, 0x82, 0x43, 0x62, 0xe7, 0x90, 0x46, 0x5e, 0x10, 0x1f, 0x14, 0x35, 0xf8, 0xa3, 0x23,
		0x94, 0x31, 0xbd, 0x29, 0x64, 0x46, 0x19, 0x93, 0xa4, 0xfb, 0xa1, 0x8c, 0x89, 0xad, 0x88, 0xe8,
		0x65, 0x70, 0x32, 0x97, 0x1a, 0x14, 0x34, 0xf1, 0x0b, 0x30, 0x42, 0xef, 0xe6, 0x46, 0x84, 0x1a,
		0x02, 0x8c, 0xe9, 0x8d, 0x10, 0x60, 0x20, 0xc0, 0x40, 0x80, 0x81, 0x00, 0x83, 0x5d, 0x80, 0x81,
		0x64, 0x81, 0x35, 0x37, 0x70, 0xee, 0x2c, 0xb6, 0xdd, 0xaa, 0x7d, 0xfa, 0x54, 0x6d, 0x21, 0x59,
		0x40, 0xc2, 0x5e, 0x36, 0xce, 0x9c, 0xf3, 0xbf, 0xce, 0xdb, 0xd5, 0x53, 0xe7, 0xb8, 0xd1, 0x68,
		0xe3, 0x64, 0xdb, 0x0c, 0xbb, 0x86, 0x93, 0x6d, 0x89, 0x37, 0xe7, 0x7a, 0xb2, 0x8d, 0x0a, 0x4e,
		0xed, 0x95, 0x7b, 0x8f, 0xe5, 0x5e, 0x18, 0x28, 0x20, 0xcb, 0x59, 0x61, 0xa0, 0x00, 0xca, 0x5c,
		0xe8, 0x04, 0x72, 0x28, 0x73, 0xd1, 0xea, 0x26, 0x50, 0xe6, 0x02, 0xe6, 0x0a, 0xcc, 0x15, 0x98,
		0x2b, 0x30, 0x57, 0x60, 0xae, 0x0c, 0x60, 0xae, 0x50, 0xe6, 0x22, 0x7d, 0x2f, 0x51, 0xe6, 0xa2,
		0x62, 0x53, 0x51, 0xe6, 0x62, 0x8e, 0xab, 0x00, 0x19, 0x28, 0xf1, 0xe6, 0x28, 0x73, 0x79, 0xe4,
		0x7d, 0x50, 0xe6, 0x82, 0xd0, 0x09, 0xa1, 0x13, 0x42, 0x27, 0x84, 0x4e, 0xaf, 0x68, 0x0d, 0xca,
		0x5c, 0xb4, 0x38, 0x22, 0x94, 0xb9, 0xc0, 0x21, 0xc1, 0x21, 0xc1, 0x21, 0xc1, 0x21, 0xfd, 0x4a,
		0x6b, 0x50, 0xe6, 0x42, 0x88, 0x83, 0x41, 0x99, 0x8b, 0xc4, 0xfb, 0xa1, 0xcc, 0x85, 0xad, 0x88,
		0xa0, 0xcc, 0x85, 0xc3, 0xd5, 0x51, 0xe6, 0x82, 0x32, 0x17, 0x04, 0x18, 0x08, 0x30, 0x10, 0x60,
		0x20, 0xc0, 0x78, 0x5d, 0x6b, 0x90, 0x2c, 0xb0, 0xe6, 0x06, 0xa2, 0xcc, 0x45, 0xc9, 0x5e, 0xa2,
		0xcc, 0xc5, 0x44, 0xbb, 0x86, 0x93, 0x6d, 0x89, 0x37, 0x47, 0x99, 0x0b, 0xca, 0x5c, 0x96, 0x2f,
		0x73, 0xc1, 0x90, 0xb2, 0xac, 0x65, 0x21, 0x73, 0x19, 0xa0, 0x32, 0xa0, 0xec, 0xd4, 0xbd, 0x3b,
		0x9d, 0x2c, 0xc8, 0xa0, 0xe1, 0x64, 0xd1, 0xf0, 0x5a, 0xfe, 0x54, 0xb2, 0xf1, 0x45, 0x31, 0x8e,
		0x8c, 0x24, 0x45, 0x80, 0x71, 0x64, 0x59, 0x85, 0xf8, 0x18, 0x47, 0xb6, 0x96, 0x32, 0x60, 0x1c,
		0x19, 0xea, 0x34, 0x09, 0x98, 0x21, 0x6d, 0xe6, 0x48, 0x97, 0x59, 0xe2, 0x11, 0xe7, 0x28, 0xac,
		0xd3, 0xf4, 0x62, 0xcf, 0xf5, 0xed, 0x9e, 0xf0, 0xdd, 0x7b, 0x1d, 0xd5, 0x9a, 0xf3, 0xb7, 0xc3,
		0x31, 0x8c, 0x6e, 0x23, 0xa7, 0xd5, 0xd8, 0xe9, 0x32, 0x7a, 0xda, 0x8d, 0x9f, 0x76, 0x23, 0xa8,
		0xdb, 0x18, 0xaa, 0xa3, 0x93, 0xb6, 0x8c, 0xc9, 0xf3, 0xda, 0x2f, 0x68, 0x38, 0x81, 0x39, 0x44,
		0x9e, 0xd7, 0xaf, 0x1f, 0x04, 0x79, 0x5e, 0xf2, 0xee, 0x87, 0x3c, 0x2f, 0xb6, 0x22, 0x52, 0x2c,
		0x94, 0x8b, 0xe5, 0x83, 0xc3, 0x42, 0x19, 0xd9, 0x5d, 0xe4, 0xae, 0xbe, 0xc9, 0xd9, 0x5d, 0x7d,
		0xf7, 0xce, 0xeb, 0x8f, 0xfa, 0xba, 0x42, 0x8c, 0xa7, 0xb7, 0x43, 0x88, 0x81, 0x10, 0x03, 0x21,
		0x06, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0x10, 0x62, 0x20, 0xc4, 0x40, 0x88, 0x81, 0x10, 0x03,
		0x21, 0x46, 0xa6, 0x21, 0x06, 0x12, 0xca, 0xb4, 0x27, 0x13, 0x45, 0xc3, 0x6b, 0x34, 0x4c, 0x96,
		0x85, 0xcc, 0xd0, 0x30, 0x19, 0x07, 0xf1, 0x74, 0x02, 0x45, 0x1c, 0xc4, 0x6b, 0xf5, 0x0f, 0x38,
		0x88, 0x07, 0x4b, 0x06, 0x96, 0x0c, 0x2c, 0x19, 0x58, 0x32, 0xb0, 0x64, 0x60, 0xc9, 0xc0, 0x92,
		0x81, 0x25, 0x03, 0x4b, 0x06, 0x96, 0x0c, 0x2c, 0x19, 0x03, 0x5d, 0xc4, 0x41, 0x3c, 0x42, 0x0c,
		0x84, 0x18, 0x08, 0x31, 0x10, 0x62, 0x20, 0xc4, 0x40, 0x88, 0x81, 0x10, 0x03, 0x21, 0x06, 0x42,
		0x0c, 0x84, 0x18, 0x08, 0x31, 0x64, 0x8a, 0x49, 0x72, 0xde, 0x6c, 0xc7, 0x2a, 0x9d, 0xf3, 0x93,
		0x6e, 0xf1, 0xd3, 0x7b, 0x21, 0xb8, 0x40, 0x70, 0x81, 0xe0, 0x02, 0xc1, 0x05, 0xbb, 0xe0, 0x42,
		0x04, 0xa3, 0xbe, 0x08, 0x27, 0xf9, 0x46, 0x1a, 0xfa, 0x39, 0x16, 0x15, 0xde, 0xa3, 0x1a, 0x8c,
		0xfa, 0xe3, 0x4d, 0x7b, 0x40, 0x1e, 0x9a, 0x0c, 0xfd, 0x34, 0x36, 0x0f, 0x0d, 0x1d, 0xcd, 0xb2,
		0x16, 0x82, 0xec, 0x5e, 0x3e, 0x95, 0x56, 0x66, 0xe7, 0xc3, 0x6b, 0x32, 0x4d, 0xcc, 0xde, 0x65,
		0x28, 0x69, 0xb2, 0x25, 0x2c, 0x1b, 0xc9, 0xb2, 0x64, 0xf4, 0x81, 0x5b, 0x5d, 0x9a, 0xd6, 0x93,
		0xa4, 0xd5, 0xdf, 0xff, 0x6a, 0xbf, 0xb9, 0xa2, 0xc4, 0xc8, 0x92, 0x14, 0xcd, 0x12, 0xb2, 0x86,
		0x68, 0xac, 0x24, 0x12, 0xab, 0xc9, 0xc2, 0xf2, 0x6f, 0x72, 0xb9, 0xdf, 0x58, 0xf2, 0x9d, 0xaf,
		0xfb, 0xae, 0x75, 0xbd, 0xe3, 0x15, 0x5e, 0xee, 0x72, 0x2f, 0x75, 0xb9, 0xb7, 0xf9, 0xf6, 0x77,
		0xb2, 0xc4, 0xfb, 0xb0, 0x86, 0x5e, 0x7f, 0xe9, 0x97, 0x90, 0x86, 0x17, 0xe3, 0x5f, 0x5e, 0xf2,
		0xdd, 0xaf, 0x96, 0x88, 0xbe, 0x32, 0x97, 0xb1, 0x0e, 0x47, 0x31, 0xcf, 0x3d, 0x2c, 0xff, 0xa4,
		0x32, 0x08, 0x05, 0x69, 0x44, 0x81, 0x34, 0x02, 0xe0, 0x79, 0x60, 0x3f, 0xde, 0x17, 0x62, 0xd6,
		0x65, 0xd5, 0x14, 0x6a, 0x6b, 0x6a, 0xd2, 0x57, 0x7e, 0x59, 0x33, 0x71, 0x59, 0xcb, 0x35, 0xac,
		0x59, 0xa9, 0xb1, 0x36, 0xe9, 0x27, 0x83, 0xd4, 0x5b, 0x5f, 0x71, 0x64, 0x33, 0x72, 0xd2, 0x19,
		0x37, 0xe9, 0x8c, 0x9a, 0x14, 0xc5, 0xca, 0x06, 0xba, 0xad, 0x5b, 0xb3, 0x60, 0x85, 0x22, 0xe8,
		0x89, 0xff, 0xde, 0x0e, 0x46, 0x91, 0x3d, 0x1c, 0x78, 0x93, 0xee, 0xf9, 0x6b, 0xbe, 0xef, 0x99,
		0x04, 0x2e, 0x5e, 0x7a, 0xcd, 0xd7, 0x24, 0xa7, 0x90, 0x4a, 0x1a, 0x37, 0x2f, 0x93, 0x83, 0x97,
		0xa7, 0xb6, 0xb2, 0xd5, 0x57, 0x99, 0x1a, 0x2b, 0x53, 0x67, 0x25, 0x6a, 0x4d, 0x23, 0xa6, 0x97,
		0x55, 0xa2, 0xb4, 0xa0, 0x9b, 0xf2, 0x1b, 0xa5, 0x2f, 0xdc, 0x01, 0x5d, 0xd3, 0xe9, 0x18, 0x07,
		0x55, 0x46, 0x42, 0xb9, 0xb1, 0x50, 0x6e, 0x34, 0x94, 0x1a, 0x0f, 0x9a, 0x54, 0xb4, 0xf4, 0x7e,
		0xe9, 0x6e, 0xaf, 0x17, 0x8a, 0x28, 0x52, 0x57, 0xa6, 0x3d, 0xbb, 0x81, 0x9a, 0x42, 0xed, 0x1c,
		0x3a, 0xa6, 0x2b, 0x34, 0x39, 0xaa, 0x4d, 0x8f, 0x36, 0x13, 0xa4, 0xcd, 0x14, 0x69, 0x31, 0x49,
		0x72, 0x4d, 0x93, 0x64, 0x13, 0x95, 0xee, 0x80, 0xb2, 0xd3, 0xfb, 0x54, 0xde, 0x7d, 0xe1, 0x5e,
		0xab, 0x99, 0xc0, 0x98, 0x22, 0x17, 0x05, 0xc9, 0xc0, 0x56, 0x73, 0x4a, 0xc8, 0xee, 0xee, 0x4e,
		0x0e, 0x61, 0xf7, 0x66, 0x26, 0x72, 0x03, 0x7a, 0x82, 0x60, 0x3c, 0x07, 0x9c, 0x0d, 0x9c, 0x0d,
		0x9c, 0x0d, 0x9b, 0x7e, 0x20, 0xaa, 0xf0, 0xb1, 0x26, 0x9c, 0xac, 0x18, 0x2f, 0x2b, 0x37, 0x65,
		0x3a, 0x4c, 0x9a, 0x3e, 0xd3, 0xa6, 0xcb, 0xc4, 0x69, 0x37, 0x75, 0xda, 0x4d, 0x9e, 0x56, 0xd3,
		0xa7, 0xc6, 0x04, 0x2a, 0x32, 0x85, 0xea, 0xf1, 0xf7, 0x82, 0xbe, 0x78, 0xc3, 0xdb, 0xa2, 0xad,
		0xd6, 0x7e, 0x3d, 0x81, 0x61, 0x47, 0x0a, 0xef, 0xd1, 0x74, 0xe3, 0x58, 0x84, 0x81, 0xf2, 0x1a,
		0x3d, 0x6b, 0x7b, 0xfb, 0x22, 0x67, 0x97, 0x3b, 0x3f, 0x2e, 0xf2, 0x76, 0xb9, 0x33, 0xf9, 0x98,
		0x4f, 0xbe, 0x4d, 0x3e, 0x17, 0x2e, 0x72, 0x76, 0x71, 0xf6, 0xb9, 0x74, 0x91, 0xb3, 0x4b, 0x9d,
		0x9d, 0xcb, 0xcb, 0xdd, 0x9d, 0xef, 0xfb, 0x0f, 0xcb, 0xff, 0xe2, 0xf6, 0xdf, 0x2e, 0x2e, 0x2f,
		0x87, 0xdf, 0xcf, 0x1e, 0xc6, 0x7f, 0xd6, 0x1f, 0x3a, 0x7f, 0xdf, 0xf9, 0xc3, 0x42, 0xdd, 0x8d,
		0x8a, 0xd2, 0xfe, 0x91, 0x1f, 0x7b, 0x5d, 0x37, 0x8a, 0xed, 0x9b, 0x70, 0x30, 0x1a, 0x6a, 0x80,
		0x0d, 0x0b, 0x77, 0x04, 0x7e, 0x00, 0x7e, 0x00, 0x7e, 0x00, 0x7e, 0x60, 0x84, 0x1f, 0xa2, 0x38,
		0xf4, 0x82, 0x1b, 0x2d, 0xc8, 0x01, 0x45, 0x31, 0x32, 0x74, 0x86, 0x7b, 0x51, 0xcc, 0xd0, 0xeb,
		0xcf, 0x52, 0xd7, 0x17, 0x12, 0x5f, 0x16, 0x7e, 0x82, 0x8e, 0xcd, 0xf2, 0xf4, 0x1c, 0x1d, 0x9b,
		0xc1, 0xcd, 0x92, 0x00, 0x1c, 0xe0, 0x66, 0xf5, 0xb9, 0x0b, 0x70, 0xb3, 0x88, 0xad, 0x10, 0x5b,
		0x21, 0xb6, 0x42, 0x6c, 0x95, 0x41, 0x6c, 0x05, 0x6e, 0x76, 0x85, 0x1b, 0x81, 0x9b, 0xcd, 0x3a,
		0xfe, 0x05, 0x37, 0x0b, 0xfc, 0x00, 0xfc, 0x00, 0xfc, 0x00, 0xfc, 0x90, 0x31, 0x7e, 0x00, 0x37,
		0xcb, 0x2b, 0xd8, 0xde, 0x30, 0x6e, 0x16, 0x5d, 0x8c, 0x96, 0xf1, 0x17, 0xf2, 0xb9, 0x0c, 0xab,
		0xee, 0x45, 0x71, 0x25, 0x8e, 0x25, 0x57, 0xa5, 0x9c, 0x7a, 0x41, 0xd5, 0x17, 0x63, 0xdb, 0x1f,
		0xc9, 0xc5, 0x1d, 0xd6, 0xa9, 0x7b, 0x37, 0x77, 0xe5, 0xfc, 0x51, 0xb1, 0x78, 0x70, 0x58, 0x2c,
		0xe6, 0x0e, 0xf7, 0x0f, 0x73, 0xe5, 0x52, 0x29, 0x7f, 0x90, 0x97, 0xd8, 0xc9, 0xd5, 0x6a, 0x84,
		0x3d, 0x11, 0x8a, 0xde, 0xf1, 0x78, 0xe3, 0x83, 0x91, 0xef, 0xa3, 0xab, 0x95, 0x76, 0x0b, 0x91,
		0x41, 0xab, 0xab, 0xa6, 0xd7, 0x9f, 0x75, 0x26, 0x6a, 0xa5, 0xab, 0x69, 0x26, 0x8b, 0x41, 0xb3,
		0x2b, 0x8e, 0xcd, 0xae, 0x7e, 0x26, 0x70, 0x99, 0x75, 0x9d, 0x5a, 0xa7, 0xa3, 0x52, 0x12, 0xa1,
		0x44, 0xf6, 0xbf, 0x06, 0x5e, 0x20, 0x7a, 0xf2, 0x9a, 0x08, 0x3c, 0xbb, 0x2e, 0xb1, 0x0e, 0x02,
		0x05, 0x74, 0x10, 0x20, 0x10, 0x5d, 0xa2, 0x83, 0xc0, 0xdb, 0x9f, 0x48, 0x5a, 0x07, 0x81, 0x48,
		0xb2, 0x70, 0x3c, 0x55, 0x78, 0x74, 0x0b, 0x20, 0x48, 0x4b, 0xa1, 0x5b, 0x40, 0x26, 0xb4, 0x12,
		0xba, 0x05, 0xac, 0xa7, 0x07, 0xe8, 0x16, 0xb0, 0x85, 0x24, 0xa1, 0xac, 0x4d, 0x90, 0x36, 0x53,
		0xa4, 0xc5, 0x24, 0xf1, 0xe0, 0x2d, 0xd1, 0x2d, 0xe0, 0x35, 0x53, 0xb0, 0xc1, 0xdd, 0x02, 0x90,
		0x8f, 0x2a, 0x3d, 0x8c, 0x85, 0xab, 0x81, 0xab, 0x41, 0x3e, 0x2a, 0xf2, 0x51, 0xf5, 0xa3, 0x65,
		0xe5, 0xa8, 0x59, 0x87, 0x49, 0xd3, 0x67, 0xda, 0x74, 0x99, 0x38, 0xed, 0xa6, 0x4e, 0xbb, 0xc9,
		0xd3, 0x6a, 0xfa, 0xd4, 0x98, 0x40, 0x45, 0xa6, 0x50, 0x3d, 0xfa, 0x5e, 0xd0, 0x17, 0xe4, 0xa3,
		0xae, 0x70, 0x23, 0xe4, 0xa3, 0x66, 0xac, 0x7b, 0x2a, 0xf2, 0x51, 0x93, 0x9c, 0x50, 0xf5, 0x58,
		0x61, 0x72, 0x1b, 0x20, 0x05, 0x20, 0x05, 0x20, 0x05, 0x20, 0x05, 0x20, 0x05, 0x20, 0x05, 0x20,
		0x05, 0x66, 0x48, 0x61, 0x34, 0x8c, 0xe2, 0x50, 0xb8, 0x7d, 0xdb, 0x0b, 0x62, 0x11, 0x5e, 0xbb,
		0x5d, 0x61, 0x7b, 0x3d, 0xf5, 0xc8, 0xe1, 0xe5, 0xdb, 0x02, 0x49, 0x00, 0x49, 0x00, 0x49, 0x00,
		0x49, 0x70, 0x42, 0x12, 0xea, 0xed, 0xd7, 0x16, 0x2a, 0x59, 0x50, 0xc9, 0xf2, 0x7a, 0xda, 0xf0,
		0xd3, 0xcc, 0xd8, 0xe9, 0x5f, 0x51, 0xbc, 0xb2, 0x94, 0xa3, 0x40, 0xf1, 0x0a, 0x8a, 0x57, 0x54,
		0x1b, 0x87, 0xec, 0x8d, 0x42, 0xb6, 0xf5, 0x2a, 0x53, 0xdc, 0x87, 0x32, 0x15, 0xe6, 0x65, 0x2a,
		0xcf, 0x2a, 0x31, 0x38, 0xd6, 0xa8, 0x44, 0x7d, 0x89, 0x85, 0x29, 0x51, 0x1f, 0xf3, 0x2c, 0x35,
		0xc6, 0x95, 0xa8, 0x46, 0x41, 0x35, 0xca, 0xeb, 0x17, 0x92, 0x3c, 0x03, 0x48, 0xcd, 0xec, 0x1f,
		0x54, 0xa3, 0xa0, 0x1a, 0x05, 0xd5, 0x28, 0x52, 0x31, 0xbb, 0xf4, 0x6a, 0x94, 0x28, 0xea, 0xdb,
		0xa1, 0x1b, 0xdc, 0x08, 0x85, 0x05, 0x29, 0x73, 0xf7, 0x40, 0x4d, 0x0a, 0x12, 0x85, 0x33, 0x33,
		0x44, 0xda, 0x0c, 0x92, 0x16, 0xc3, 0xc4, 0x83, 0x81, 0x44, 0x4d, 0xca, 0x6b, 0xa6, 0x20, 0x0d,
		0x62, 0xbb, 0xb6, 0xdb, 0xf5, 0xdf, 0xbb, 0x5d, 0x7f, 0xee, 0xa3, 0x1d, 0x89, 0x38, 0x7a, 0xf6,
		0xf7, 0xd9, 0x5f, 0x27, 0x25, 0x2c, 0xd3, 0xbf, 0x24, 0xcc, 0x04, 0xe8, 0xcf, 0x4d, 0xa1, 0xbb,
		0xa2, 0xbe, 0xd4, 0x56, 0xfa, 0x12, 0xf8, 0x25, 0x09, 0x91, 0xae, 0xdc, 0x12, 0x25, 0x25, 0xa5,
		0x49, 0xca, 0x42, 0x99, 0x02, 0x42, 0x19, 0x84, 0x32, 0x08, 0x65, 0x10, 0xca, 0x20, 0x94, 0x41,
		0x28, 0x83, 0x50, 0x06, 0xa1, 0x0c, 0x42, 0x19, 0x84, 0x32, 0x9b, 0x12, 0xca, 0x48, 0x4c, 0xde,
		0xc1, 0x49, 0x79, 0xa6, 0xaf, 0xd2, 0x92, 0x12, 0x06, 0x2e, 0x9d, 0x6a, 0x11, 0xf5, 0x59, 0x9e,
		0xcb, 0x4b, 0x89, 0x77, 0xa5, 0xc6, 0xb9, 0xe8, 0x14, 0x99, 0x25, 0x7c, 0xc4, 0xd9, 0x3c, 0x01,
		0x0b, 0x2c, 0xf1, 0x6c, 0x7e, 0x14, 0xc4, 0x22, 0x8c, 0x54, 0x9c, 0xce, 0x4f, 0xaf, 0x8c, 0xf3,
		0x79, 0x90, 0x5a, 0x20, 0xb5, 0x36, 0x81, 0xd4, 0xba, 0x1a, 0x0c, 0xe2, 0x28, 0x0e, 0xdd, 0xa1,
		0xdd, 0x17, 0x51, 0xe4, 0x2a, 0x25, 0xb7, 0x5e, 0xb8, 0x17, 0x48, 0x2e, 0x90, 0x5c, 0x20, 0xb9,
		0x40, 0x72, 0x49, 0x94, 0xf7, 0x91, 0x17, 0xc4, 0xfb, 0x05, 0x85, 0x1c, 0x97, 0x0a, 0x8a, 0xab,
		0xe5, 0x06, 0x37, 0x42, 0x59, 0xe9, 0xb9, 0xc2, 0xfa, 0xbd, 0x53, 0x2f, 0xd0, 0x50, 0x82, 0xaa,
		0xb4, 0xf0, 0x38, 0xbd, 0xcd, 0x17, 0xd7, 0x1f, 0x09, 0x0d, 0xf7, 0xf9, 0x18, 0xba, 0xdd, 0xd8,
		0x1b, 0x04, 0x27, 0xde, 0x8d, 0x37, 0xa9, 0x3f, 0x52, 0x57, 0x6e, 0xaa, 0xb0, 0x94, 0xf2, 0xd4,
		0xbd, 0x33, 0xee, 0xd5, 0x17, 0x0b, 0xe5, 0x62, 0xf9, 0xe0, 0xb0, 0x50, 0x2e, 0x19, 0x24, 0x03,
		0x4c, 0x4a, 0x5d, 0x3b, 0x1b, 0xd0, 0x2d, 0xf7, 0xab, 0xf0, 0xfd, 0x81, 0x06, 0xa8, 0xfd, 0xec,
		0x3e, 0x80, 0xd9, 0x80, 0xd9, 0x80, 0xd9, 0x80, 0xd9, 0x80, 0xd9, 0x80, 0xd9, 0x80, 0xd9, 0x80,
		0xd9, 0x80, 0xd9, 0x80, 0xd9, 0x26, 0xc3, 0xec, 0x7f, 0x0d, 0xbc, 0xc0, 0x1e, 0x86, 0xa3, 0x40,
		0x68, 0xc0, 0xda, 0x2f, 0xdd, 0x0c, 0x80, 0x1b, 0x80, 0x1b, 0x80, 0x1b, 0x80, 0x1b, 0x80, 0x1b,
		0x80, 0x1b, 0x80, 0x1b, 0x80, 0x1b, 0x80, 0x1b, 0x80, 0x9b, 0x1c, 0xe0, 0x46, 0xce, 0xb9, 0xec,
		0x44, 0xe5, 0xa4, 0xdc, 0x40, 0x72, 0x16, 0xdd, 0xd6, 0x6a, 0xb9, 0xcb, 0x1f, 0x66, 0xab, 0x30,
		0xa8, 0x90, 0x37, 0x10, 0xde, 0xcd, 0xd7, 0xab, 0x41, 0x68, 0x27, 0x5b, 0x2c, 0x3f, 0xff, 0xf1,
		0xd9, 0xf5, 0xe5, 0x66, 0x41, 0xe6, 0x90, 0x05, 0x49, 0x38, 0x38, 0x43, 0x16, 0x24, 0x23, 0x5f,
		0x21, 0x3d, 0xd8, 0x7a, 0x12, 0x64, 0x1d, 0xc9, 0x14, 0xd7, 0xa9, 0xf2, 0xcb, 0x6c, 0xfa, 0xaa,
		0x26, 0xa6, 0x52, 0x10, 0xb9, 0xaa, 0x8c, 0xa1, 0x54, 0x0f, 0x23, 0x50, 0x1c, 0x33, 0xe9, 0xc0,
		0xc9, 0x2a, 0xc6, 0x5c, 0xa8, 0x8c, 0x8d, 0x74, 0xbd, 0xd2, 0x42, 0xa9, 0xc4, 0xf8, 0xa5, 0x12,
		0x0d, 0x26, 0x3a, 0xa8, 0xb2, 0xe4, 0x5e, 0x65, 0xb9, 0x7e, 0xb1, 0xec, 0x1a, 0xe5, 0x8e, 0xef,
		0x34, 0xbe, 0x2e, 0x59, 0xaf, 0x49, 0xe7, 0xeb, 0xb1, 0xd6, 0xaa, 0x07, 0x5d, 0x32, 0x78, 0x5c,
		0x4d, 0x0a, 0x96, 0x7f, 0x87, 0x2b, 0xbc, 0xbf, 0xc7, 0x41, 0x21, 0xab, 0x9f, 0xe8, 0x2d, 0x0e,
		0x1d, 0x59, 0x35, 0x56, 0x5f, 0xb3, 0xc2, 0x6d, 0xed, 0x58, 0x4e, 0x46, 0xec, 0x26, 0x2f, 0x56,
		0x93, 0x15, 0x9b, 0x49, 0x8f, 0xc5, 0xa4, 0xc7, 0x5e, 0x52, 0x63, 0x2d, 0xbd, 0xb6, 0x6f, 0xdd,
		0x0a, 0xb2, 0x47, 0xa5, 0x91, 0x57, 0x61, 0xfe, 0x78, 0x49, 0x74, 0x80, 0xd7, 0x47, 0xa9, 0xa0,
		0xca, 0x1c, 0x55, 0xe6, 0xaf, 0x5f, 0x08, 0x1d, 0xe0, 0x65, 0x5c, 0x10, 0xdc, 0x2a, 0xb8, 0x55,
		0x3d, 0x41, 0x38, 0xe1, 0x0a, 0xf3, 0xb0, 0x27, 0x42, 0x3b, 0x1c, 0x8c, 0x62, 0x11, 0xaa, 0x2c,
		0x2e, 0x9f, 0xbf, 0x8d, 0xe4, 0xd7, 0x7f, 0x22, 0xae, 0xdd, 0x91, 0x9f, 0xbc, 0xfd, 0x6b, 0xd7,
		0x8f, 0x04, 0xf2, 0xfb, 0x90, 0xdf, 0x97, 0x9d, 0xb9, 0xd3, 0x66, 0xf6, 0xb4, 0x98, 0x3f, 0x45,
		0xcc, 0x26, 0xbb, 0xfc, 0xbe, 0xab, 0xc1, 0xc0, 0x17, 0x6e, 0xa0, 0xb2, 0x39, 0x63, 0x7e, 0x03,
		0x52, 0xbf, 0xaf, 0xa2, 0xd0, 0x9e, 0xf8, 0x02, 0x85, 0xbe, 0xe6, 0xf1, 0x1e, 0x70, 0x34, 0x70,
		0x34, 0x70, 0x34, 0x70, 0x34, 0x70, 0x34, 0x9b, 0xe6, 0x68, 0x7a, 0xc2, 0xed, 0xd9, 0xb1, 0xd7,
		0x57, 0xe9, 0x68, 0xe6, 0xee, 0x01, 0x47, 0x00, 0x47, 0x00, 0x47, 0x00, 0x47, 0x20, 0x51, 0xde,
		0x47, 0x5e, 0x10, 0xe7, 0x0f, 0x14, 0xfa, 0x81, 0x03, 0x54, 0x14, 0x3d, 0x2e, 0xdc, 0xc4, 0x8a,
		0xa2, 0x3c, 0x2a, 0x8a, 0xde, 0xf4, 0xea, 0x0d, 0xac, 0x28, 0x3a, 0x28, 0x95, 0xf6, 0x51, 0x4c,
		0xa4, 0xfd, 0xaa, 0x9b, 0x50, 0xbd, 0xdf, 0x0b, 0xed, 0x61, 0xe8, 0x0d, 0x42, 0x2f, 0xbe, 0x57,
		0x08, 0xad, 0xe7, 0x6e, 0x02, 0x6c, 0x0d, 0x6c, 0x0d, 0x6c, 0x0d, 0x6c, 0xad, 0xc6, 0xbc, 0xd8,
		0xf1, 0xf8, 0x6e, 0xa8, 0xdb, 0x07, 0xca, 0x5e, 0x11, 0x6a, 0xa1, 0x6e, 0x7f, 0x63, 0x51, 0x36,
		0xea, 0xf6, 0x01, 0xb5, 0x55, 0x42, 0x6d, 0x11, 0xb8, 0x57, 0xbe, 0xe8, 0xa9, 0x83, 0xd9, 0xb3,
		0x1b, 0xe0, 0x9c, 0x14, 0x10, 0x1e, 0x10, 0x1e, 0x10, 0x9e, 0x11, 0x84, 0xc7, 0x39, 0xa9, 0x94,
		0x67, 0x9d, 0xb4, 0x22, 0x4f, 0x4a, 0x3c, 0x6e, 0x5d, 0x5f, 0x75, 0xcb, 0xf3, 0xf4, 0x3e, 0x70,
		0x08, 0x70, 0x08, 0x70, 0x08, 0x70, 0x08, 0x12, 0xe5, 0x7d, 0xe8, 0xf5, 0x53, 0xfb, 0xa2, 0x9a,
		0xd4, 0x51, 0x10, 0xef, 0x59, 0x9f, 0x83, 0x49, 0x68, 0x67, 0x45, 0xa2, 0x3b, 0x08, 0x7a, 0x91,
		0x05, 0xe2, 0xc8, 0x6c, 0xe2, 0x08, 0xc7, 0xb3, 0x1b, 0x4b, 0x1c, 0x29, 0x6b, 0x72, 0x02, 0xc6,
		0x68, 0xb3, 0x19, 0xa3, 0xb4, 0x56, 0xdb, 0xf6, 0x14, 0xd2, 0x46, 0x4f, 0xee, 0x02, 0x28, 0x0f,
		0x28, 0x0f, 0x28, 0x0f, 0x28, 0xcf, 0xc3, 0xbe, 0x3c, 0x21, 0x78, 0x8e, 0x36, 0x6b, 0xd8, 0x86,
		0x7a, 0x96, 0xe7, 0xa5, 0x9b, 0xc1, 0x3f, 0xc0, 0x3f, 0xc0, 0x3f, 0xc0, 0x3f, 0x80, 0xea, 0x01,
		0xd5, 0x03, 0xaa, 0x07, 0x54, 0x0f, 0xa8, 0x1e, 0x50, 0x3d, 0xa0, 0x7a, 0xd6, 0x7f, 0xed, 0xfd,
		0x41, 0x4f, 0xa8, 0x43, 0xf2, 0xc9, 0xd5, 0x01, 0xdd, 0x01, 0xdd, 0x01, 0xdd, 0x01, 0xdd, 0x65,
		0x52, 0x3b, 0x3d, 0x11, 0xc4, 0x5e, 0x7c, 0x1f, 0x8a, 0x6b, 0x95, 0xcc, 0x8e, 0x0a, 0xd4, 0x5e,
		0x9b, 0x2e, 0xfd, 0xd8, 0x8d, 0x14, 0xaa, 0xd5, 0x6c, 0xa3, 0x9a, 0xb5, 0x53, 0xe7, 0xb4, 0x71,
		0x52, 0xb5, 0x54, 0xf6, 0xdb, 0x8f, 0x94, 0x05, 0x08, 0x6a, 0x83, 0x84, 0x17, 0x77, 0xca, 0x39,
		0x6f, 0x56, 0x5a, 0xe7, 0x55, 0x8b, 0x23, 0xf4, 0xd5, 0xbd, 0x55, 0x27, 0xd5, 0x33, 0xa5, 0x3b,
		0xa5, 0xe4, 0xca, 0x9d, 0x8d, 0x99, 0xd7, 0x80, 0xe1, 0x6f, 0xd2, 0x1a, 0xf4, 0x3f, 0x76, 0x91,
		0x7f, 0xfc, 0xb8, 0x37, 0x6d, 0x73, 0x6b, 0xd0, 0xf0, 0x35, 0x25, 0x07, 0xbf, 0x2a, 0x0f, 0x64,
		0x30, 0x78, 0x0d, 0xcd, 0x81, 0xd1, 0x1c, 0x58, 0xaa, 0x9d, 0x56, 0x37, 0x78, 0xcd, 0x17, 0xee,
		0xb5, 0x5c, 0xc4, 0x9e, 0x22, 0x75, 0x89, 0xf5, 0xb1, 0x56, 0x73, 0xea, 0x4a, 0x76, 0x77, 0xa7,
		0xc3, 0x3e, 0x9f, 0xd8, 0x2d, 0x23, 0xad, 0xfd, 0xf8, 0xad, 0x28, 0x34, 0xf7, 0xf2, 0x5e, 0xfa,
		0xa6, 0x37, 0x83, 0xf7, 0xae, 0x61, 0xee, 0x33, 0x30, 0xf7, 0xde, 0x35, 0x5a, 0xc1, 0xbf, 0xf1,
		0x82, 0x92, 0x67, 0x4a, 0x2c, 0x28, 0x81, 0xd4, 0xd9, 0x12, 0x8a, 0xcc, 0x8a, 0x32, 0xf3, 0xa2,
		0xd2, 0xcc, 0x28, 0x37, 0x37, 0xaa, 0xcd, 0x8e, 0x36, 0xf3, 0xa3, 0xcd, 0x0c, 0xe9, 0x30, 0x47,
		0x8a, 0x48, 0x0c, 0xd9, 0xb5, 0xe0, 0x5e, 0xa8, 0x46, 0xd8, 0xe5, 0x4d, 0xba, 0x7a, 0x3b, 0x1e,
		0x52, 0x25, 0x8e, 0x8a, 0x67, 0xab, 0xaa, 0x32, 0x66, 0x3a, 0x8c, 0x9a, 0x36, 0xe3, 0xa6, 0xcb,
		0xc8, 0x69, 0x37, 0x76, 0xda, 0x8d, 0x9e, 0x4e, 0xe3, 0xa7, 0xc6, 0x08, 0x2a, 0x32, 0x86, 0xea,
		0x22, 0x75, 0x8d, 0x91, 0xbb, 0x8e, 0x48, 0xfe, 0xd5, 0xc8, 0x7e, 0x2f, 0x11, 0xa3, 0xf7, 0x73,
		0xa4, 0xee, 0xb3, 0x1f, 0x4c, 0xff, 0x9e, 0x8c, 0x53, 0x65, 0x92, 0xac, 0xa2, 0x62, 0x12, 0x78,
		0x34, 0xba, 0xd2, 0xe8, 0x1f, 0x9f, 0xdc, 0x0d, 0x2e, 0x12, 0x2e, 0x12, 0x2e, 0x12, 0x2e, 0x12,
		0x2e, 0x92, 0xa8, 0x8b, 0xbc, 0x78, 0x74, 0x91, 0xff, 0xb7, 0x3b, 0x0a, 0x43, 0x11, 0xc4, 0xdb,
		0x3b, 0x7b, 0xbb, 0xbb, 0x8f, 0x6c, 0x79, 0x67, 0xfa, 0x2b, 0xf3, 0x76, 0x3d, 0x7a, 0xe1, 0x67,
		0xe9, 0x95, 0x7b, 0xe2, 0x8e, 0x8d, 0xb7, 0x25, 0x1d, 0x2d, 0x57, 0xef, 0x62, 0x35, 0x39, 0x39,
		0xea, 0x09, 0x9b, 0x41, 0xd7, 0x16, 0x77, 0xf1, 0xfb, 0x58, 0xf8, 0xa2, 0x2f, 0xe2, 0xf0, 0xde,
		0x1e, 0x04, 0x76, 0xf7, 0x6b, 0x52, 0x85, 0xa0, 0x85, 0xc4, 0x49, 0x3a, 0xcd, 0x69, 0x60, 0x71,
		0xa8, 0x13, 0x38, 0x1d, 0xd9, 0x84, 0xba, 0x9a, 0xec, 0x8f, 0x47, 0xa8, 0x9a, 0x59, 0x16, 0xc8,
		0x93, 0x63, 0x2e, 0xa9, 0x39, 0x21, 0xf2, 0xdf, 0xac, 0xcc, 0xcc, 0xf1, 0xe4, 0x6c, 0x54, 0x1d,
		0xcf, 0x3f, 0xb9, 0x3c, 0x33, 0x9a, 0xbf, 0x00, 0x9a, 0x5f, 0x1b, 0xbc, 0x07, 0xcd, 0x6f, 0x1e,
		0x70, 0x01, 0xcd, 0x0f, 0x0e, 0x03, 0x1c, 0x06, 0x38, 0x0c, 0x70, 0x18, 0xe0, 0x30, 0x34, 0x70,
		0x18, 0xa0, 0xf9, 0xb7, 0x40, 0xf3, 0xc3, 0x45, 0xc2, 0x45, 0xc2, 0x45, 0xc2, 0x45, 0xc2, 0x45,
		0x82, 0xe6, 0xe7, 0x15, 0x2d, 0x6f, 0x0a, 0xa7, 0x3a, 0xa1, 0x02, 0x51, 0x64, 0x99, 0x9d, 0x48,
		0x50, 0x11, 0x05, 0x4b, 0x2a, 0x7f, 0x1d, 0x8e, 0xba, 0x71, 0x30, 0xb5, 0xeb, 0x67, 0x93, 0x35,
		0xd6, 0xa6, 0x4b, 0x74, 0x9a, 0xd3, 0x85, 0x39, 0x4d, 0xaf, 0xef, 0xd4, 0x66, 0x6b, 0x78, 0xfc,
		0xd4, 0x12, 0xd7, 0x26, 0x95, 0x02, 0x05, 0xc2, 0xbb, 0xf9, 0x7a, 0x35, 0x08, 0x23, 0xf9, 0x65,
		0x40, 0x8f, 0x97, 0x26, 0x5e, 0x02, 0x54, 0x40, 0xc9, 0x27, 0x23, 0x34, 0x8e, 0x92, 0x4f, 0xc2,
		0x45, 0x40, 0x33, 0x9d, 0x57, 0x77, 0x3c, 0x98, 0xde, 0x01, 0x85, 0x40, 0xe8, 0x2e, 0x95, 0x39,
		0x25, 0x80, 0xee, 0x52, 0xfa, 0xa2, 0x1e, 0x65, 0x67, 0x84, 0x33, 0x93, 0x62, 0xbb, 0xbd, 0x5e,
		0x28, 0xa2, 0x48, 0x3d, 0x15, 0xba, 0x70, 0x47, 0xd0, 0xa1, 0xba, 0x8d, 0x9c, 0x3e, 0x63, 0xa7,
		0xcb, 0xe8, 0x69, 0x37, 0x7e, 0xda, 0x8d, 0xa0, 0x56, 0x63, 0xa8, 0x8e, 0x5c, 0xda, 0x02, 0x21,
		0xba, 0x1c, 0x26, 0xd3, 0x41, 0x88, 0xa6, 0x4d, 0x3f, 0x16, 0x6c, 0xf3, 0x26, 0x1f, 0x10, 0x2a,
		0x49, 0xf5, 0x5b, 0x10, 0x25, 0x15, 0x29, 0x7f, 0x8a, 0x81, 0xbd, 0x32, 0x16, 0x01, 0x3e, 0x10,
		0x3e, 0x10, 0x3e, 0x90, 0x64, 0xa0, 0x90, 0xde, 0xa0, 0xa7, 0x3e, 0x54, 0x58, 0x50, 0xcd, 0x9e,
		0xea, 0x60, 0x41, 0x53, 0xd0, 0xa0, 0x2d, 0x78, 0xd0, 0x69, 0x40, 0xf5, 0x1b, 0x52, 0xdd, 0x06,
		0x35, 0x33, 0xc3, 0x9a, 0x99, 0x81, 0xcd, 0xc4, 0xd0, 0xaa, 0x35, 0xb8, 0x8a, 0x0d, 0xaf, 0xbe,
		0x20, 0x64, 0x41, 0xdf, 0xbc, 0xe1, 0x6d, 0x51, 0x93, 0x7d, 0x7c, 0x02, 0x2a, 0x8f, 0x34, 0xdc,
		0xab, 0xe9, 0xc6, 0xb1, 0x08, 0x03, 0xa5, 0xbd, 0xb6, 0x9f, 0xdc, 0x70, 0x7b, 0xfb, 0x22, 0x67,
		0x97, 0x3b, 0x3f, 0x2e, 0xf2, 0x76, 0xb9, 0x33, 0xf9, 0x98, 0x4f, 0xbe, 0x4d, 0x3e, 0x17, 0x2e,
		0x72, 0x76, 0x71, 0xf6, 0xb9, 0x74, 0x91, 0xb3, 0x4b, 0x9d, 0x9d, 0xcb, 0xcb, 0xdd, 0x9d, 0xef,
		0xfb, 0x0f, 0xcb, 0xff, 0xe2, 0xf6, 0xdf, 0x2e, 0x2e, 0x2f, 0x87, 0xdf, 0xcf, 0x1e, 0xc6, 0x7f,
		0xd6, 0x1f, 0x3a, 0x7f, 0xdf, 0xf9, 0x43, 0xbd, 0x76, 0x75, 0xde, 0xf1, 0xd4, 0x5d, 0x95, 0xc3,
		0x73, 0x94, 0xcc, 0x03, 0x79, 0x55, 0x5f, 0x15, 0xcc, 0x07, 0x01, 0x8e, 0x01, 0x8e, 0x01, 0x8e,
		0x01, 0x8e, 0xe1, 0x8d, 0x63, 0x94, 0xce, 0x37, 0x79, 0x15, 0xc6, 0x94, 0x34, 0xdc, 0x4b, 0xcb,
		0xfc, 0x93, 0x57, 0x37, 0x56, 0xf1, 0x3c, 0x94, 0x85, 0xfb, 0x6a, 0x98, 0x8f, 0xf2, 0xfc, 0xeb,
		0xbb, 0xb6, 0x3b, 0x6d, 0x65, 0x32, 0x3f, 0x45, 0xb3, 0xf6, 0x53, 0xda, 0x5a, 0xc5, 0xf3, 0x56,
		0xf4, 0x5a, 0x6d, 0x3d, 0x28, 0x5c, 0x83, 0xf7, 0x61, 0x89, 0xf3, 0xb5, 0x25, 0x3b, 0x2c, 0x48,
		0xb3, 0xa6, 0xa4, 0x07, 0xe0, 0x7f, 0xe0, 0x7f, 0xe0, 0x7f, 0xe0, 0x7f, 0x9e, 0xf8, 0x1f, 0x3c,
		0xa6, 0xbc, 0x1b, 0x82, 0xc7, 0xdc, 0x64, 0x7c, 0x23, 0xa2, 0xd8, 0xbd, 0xf2, 0xbd, 0xe8, 0xab,
		0xe8, 0x65, 0x80, 0x71, 0xe6, 0xef, 0x0e, 0x9c, 0x03, 0x9c, 0x03, 0x9c, 0x03, 0x9c, 0x03, 0x9c,
		0x93, 0xea, 0x5b, 0xec, 0xf5, 0x45, 0xec, 0x75, 0xbf, 0x45, 0x07, 0x45, 0x8d, 0x30, 0x47, 0x07,
		0xca, 0xf9, 0x1c, 0x78, 0x49, 0x0f, 0x56, 0x2b, 0x70, 0x83, 0x41, 0x24, 0xba, 0x83, 0xa0, 0xa7,
		0x05, 0xc9, 0xb5, 0x92, 0x56, 0xa9, 0xba, 0xb0, 0x95, 0x3e, 0x42, 0xcc, 0x3a, 0xf5, 0x02, 0x6d,
		0xd6, 0x52, 0xb3, 0x4f, 0x5d, 0xb8, 0x6d, 0xc2, 0x1a, 0x67, 0x70, 0xdf, 0x8f, 0xa1, 0xdb, 0x8d,
		0xbd, 0x41, 0x70, 0xe2, 0xdd, 0x4c, 0xa4, 0x37, 0x67, 0x22, 0x8b, 0x6b, 0x9d, 0xba, 0x77, 0x1b,
		0x27, 0x4a, 0xf9, 0xa3, 0x62, 0xf1, 0xe0, 0xb0, 0x58, 0xcc, 0x1d, 0xee, 0x1f, 0xe6, 0xca, 0xa5,
		0x52, 0xfe, 0x40, 0xc7, 0x69, 0x0f, 0x19, 0xe9, 0x7a, 0x67, 0xc6, 0x5d, 0x10, 0xe9, 0xfd, 0x2c,
		0xd2, 0xbb, 0x1b, 0x7a, 0xa1, 0xc8, 0x82, 0xc9, 0x9e, 0xdd, 0x19, 0x11, 0x1e, 0x22, 0x3c, 0x44,
		0x78, 0x88, 0xf0, 0x10, 0xe1, 0x21, 0xc2, 0x43, 0x84, 0x87, 0x08, 0x0f, 0x11, 0x1e, 0x22, 0x3c,
		0x44, 0x78, 0x88, 0xf0, 0x36, 0x21, 0xc2, 0x63, 0x55, 0x1a, 0xaa, 0xb8, 0x73, 0x66, 0x7a, 0x9f,
		0xec, 0xda, 0x26, 0xa6, 0x5d, 0xf7, 0xd2, 0x4f, 0x2a, 0xda, 0x68, 0xaa, 0x7b, 0xfb, 0xb4, 0x7b,
		0x10, 0xfd, 0x53, 0xdc, 0x6b, 0x48, 0x65, 0xb3, 0xea, 0x5e, 0x14, 0x57, 0xe2, 0x58, 0x51, 0xbf,
		0xa3, 0x53, 0x2f, 0xa8, 0xfa, 0x62, 0x1c, 0x40, 0x45, 0x6a, 0xdc, 0xd6, 0xd8, 0x0d, 0xcf, 0xdd,
		0x41, 0x8f, 0x83, 0xb2, 0x1a, 0x61, 0x4f, 0x84, 0xa2, 0x77, 0x3c, 0x7e, 0x43, 0xc1, 0xc8, 0xf7,
		0xd1, 0xc2, 0x97, 0x88, 0x01, 0xb2, 0x94, 0x74, 0x26, 0x59, 0xa1, 0x89, 0xeb, 0xd9, 0x6c, 0x41,
		0x68, 0x29, 0x9c, 0x9d, 0x88, 0x52, 0x10, 0x4d, 0x93, 0x3a, 0xf8, 0xca, 0xed, 0xd1, 0xa3, 0xa4,
		0x27, 0x0f, 0x3a, 0xf7, 0xa2, 0x73, 0x2f, 0x3a, 0xf7, 0x4a, 0x35, 0xce, 0xd2, 0x3b, 0xf7, 0x5e,
		0x0d, 0xc6, 0xf0, 0xc9, 0x0e, 0x07, 0xa3, 0x58, 0x28, 0x6c, 0xdf, 0xfb, 0xf4, 0x36, 0xb2, 0x3b,
		0x84, 0x8a, 0x6b, 0x77, 0xe4, 0x27, 0x6f, 0x3f, 0x19, 0xe7, 0xab, 0xa8, 0x47, 0x70, 0x0e, 0x3d,
		0x82, 0xd1, 0x23, 0x98, 0x90, 0xd9, 0xd3, 0x62, 0xfe, 0x78, 0xc4, 0xe7, 0xca, 0xce, 0xb9, 0xe6,
		0x0c, 0xd8, 0xc0, 0x17, 0x6e, 0xa0, 0x42, 0xe0, 0x67, 0x28, 0x29, 0xbf, 0x01, 0x43, 0xa4, 0xaf,
		0xa2, 0xd0, 0x9e, 0xf8, 0x02, 0x85, 0xbe, 0xe6, 0xf1, 0x1e, 0x70, 0x34, 0x70, 0x34, 0x70, 0x34,
		0x70, 0x34, 0x70, 0x34, 0x9b, 0xe6, 0x68, 0xba, 0x83, 0x51, 0x10, 0x8b, 0x30, 0x52, 0xe7, 0x66,
		0xd2, 0x3b, 0x60, 0x22, 0x09, 0x9c, 0x00, 0x9c, 0xc0, 0x06, 0x39, 0x01, 0x65, 0x13, 0x49, 0xae,
		0x06, 0x83, 0x38, 0x8a, 0x43, 0x77, 0x68, 0xf7, 0x45, 0x14, 0xb9, 0x37, 0x42, 0xc3, 0x4c, 0x92,
		0x17, 0xee, 0x89, 0xa9, 0x24, 0xba, 0x0d, 0x9d, 0x3e, 0x83, 0xa7, 0xcb, 0xf0, 0x69, 0x37, 0x80,
		0xda, 0x0d, 0xa1, 0x56, 0x83, 0xa8, 0xc6, 0x30, 0x2a, 0x32, 0x90, 0xea, 0xd1, 0xf2, 0x82, 0xbe,
		0x8c, 0xbc, 0x20, 0xde, 0x2f, 0x68, 0x18, 0x4a, 0xa2, 0x72, 0x26, 0x89, 0x9e, 0x4c, 0x5f, 0x0d,
		0xc9, 0xe0, 0x3a, 0x33, 0x7b, 0x35, 0xa7, 0x61, 0xea, 0xce, 0xe4, 0xcd, 0x22, 0xc7, 0x52, 0x43,
		0xe6, 0xae, 0xd6, 0x8c, 0xdd, 0xac, 0x44, 0xa4, 0x58, 0x28, 0x17, 0xcb, 0x07, 0x87, 0x85, 0x72,
		0xc9, 0x60, 0x59, 0x61, 0x9a, 0xbf, 0xda, 0xd9, 0xe0, 0xf1, 0x4e, 0x5f, 0x85, 0xef, 0x0f, 0x34,
		0x86, 0x18, 0xcf, 0xee, 0x87, 0xf0, 0x02, 0xe1, 0x05, 0xc2, 0x0b, 0x84, 0x17, 0x08, 0x2f, 0x10,
		0x5e, 0x20, 0xbc, 0x40, 0x78, 0x81, 0xf0, 0x02, 0xe1, 0x05, 0xc2, 0x0b, 0x73, 0xc2, 0x8b, 0x7f,
		0x0d, 0xbc, 0xc0, 0x1e, 0x86, 0xa3, 0x40, 0x68, 0x8c, 0x31, 0x5e, 0xba, 0x29, 0x02, 0x0d, 0x04,
		0x1a, 0x08, 0x34, 0x10, 0x68, 0x20, 0xd0, 0x40, 0xa0, 0x81, 0x40, 0x03, 0x81, 0x06, 0x02, 0x0d,
		0x04, 0x1a, 0x08, 0x34, 0x32, 0x0a, 0x34, 0x50, 0x96, 0x9f, 0x49, 0xed, 0x73, 0x52, 0xcf, 0xbb,
		0xa7, 0x28, 0x57, 0x75, 0x6b, 0xe5, 0x92, 0xfc, 0x0f, 0xb3, 0x05, 0x6d, 0x40, 0x2a, 0x72, 0x4f,
		0xb8, 0x3d, 0x3b, 0xf6, 0xfa, 0x2a, 0x6b, 0x5e, 0xe6, 0xee, 0x81, 0x9a, 0x14, 0xa4, 0x23, 0x67,
		0x1e, 0xc5, 0x22, 0x1d, 0x59, 0x9f, 0xf3, 0x52, 0x5f, 0x93, 0x32, 0x8e, 0x4a, 0xf3, 0x07, 0x0a,
		0x4b, 0x52, 0x0e, 0x14, 0x5c, 0x5a, 0x6d, 0x14, 0xaa, 0x90, 0x0b, 0xd0, 0x11, 0x75, 0xea, 0xea,
		0x2d, 0x9d, 0x36, 0x2b, 0x54, 0x7c, 0x1f, 0x8d, 0x11, 0x83, 0xca, 0xde, 0xe6, 0x3a, 0xa2, 0x49,
		0xdd, 0xaf, 0xfe, 0xa0, 0x54, 0xda, 0x2f, 0x19, 0xf4, 0xfa, 0x99, 0x04, 0x5c, 0x9d, 0x4d, 0x40,
		0xd6, 0xa1, 0x3d, 0x0c, 0xbd, 0x41, 0xe8, 0xc5, 0xf7, 0x0a, 0xa1, 0xf5, 0xdc, 0x4d, 0x80, 0xad,
		0x81, 0xad, 0x81, 0xad, 0x81, 0xad, 0xd5, 0x98, 0x17, 0x3b, 0x1e, 0xdf, 0x4d, 0x1d, 0xca, 0x3e,
		0x04, 0xca, 0x36, 0x1b, 0x65, 0xe7, 0x80, 0xb2, 0x37, 0x15, 0x65, 0xeb, 0x3a, 0xa3, 0x01, 0xd4,
		0xde, 0x4c, 0xa8, 0x2d, 0x02, 0xf7, 0xca, 0x57, 0x30, 0x52, 0x39, 0xf5, 0x83, 0xb3, 0x1b, 0xa0,
		0x65, 0x13, 0x20, 0x3c, 0x20, 0x3c, 0x20, 0x3c, 0x23, 0x08, 0x8f, 0x96, 0x4d, 0x52, 0x9e, 0x75,
		0x52, 0x26, 0x98, 0x1c, 0x5d, 0xdf, 0xba, 0xbe, 0x3a, 0x4f, 0xf3, 0xec, 0x3e, 0x70, 0x08, 0x70,
		0x08, 0x70, 0x08, 0x70, 0x08, 0x12, 0xe5, 0x7d, 0xe8, 0xf5, 0x53, 0xfb, 0xa2, 0x9a, 0xd4, 0x51,
		0x31, 0x52, 0x25, 0x1d, 0x75, 0xa8, 0x6e, 0xcc, 0x21, 0x88, 0x23, 0x4a, 0xec, 0x01, 0x8e, 0x67,
		0x37, 0x96, 0x38, 0x2a, 0x94, 0xc0, 0x18, 0x81, 0x31, 0x52, 0x00, 0xe7, 0xd3, 0x1c, 0x54, 0xdb,
		0x53, 0x48, 0x1b, 0x3d, 0xb9, 0x0b, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0x0f, 0xfb,
		0xf2, 0x84, 0xe0, 0x39, 0xda, 0x00, 0x8f, 0x30, 0x57, 0xa3, 0xad, 0x9e, 0xe5, 0x79, 0xe9, 0x66,
		0xf0, 0x0f, 0xf0, 0x0f, 0xf0, 0x0f, 0xf0, 0x0f, 0xa0, 0x7a, 0x40, 0xf5, 0x80, 0xea, 0x01, 0xd5,
		0x03, 0xaa, 0x07, 0x54, 0x0f, 0xa8, 0x9e, 0xf5, 0x5f, 0x7b, 0x7f, 0xd0, 0x13, 0xea, 0x90, 0x7c,
		0x72, 0x75, 0x40, 0x77, 0x40, 0x77, 0x40, 0x77, 0x40, 0x77, 0x99, 0xd4, 0x4e, 0x4f, 0x04, 0xb1,
		0x17, 0xdf, 0x87, 0xe2, 0x5a, 0x25, 0xb3, 0xa3, 0x02, 0xb5, 0xd7, 0xa6, 0x4b, 0x3f, 0x76, 0x23,
		0xa1, 0xbe, 0xb7, 0x5e, 0xb3, 0x76, 0xea, 0x9c, 0x36, 0x4e, 0xaa, 0xaa, 0xb4, 0x2a, 0xc1, 0x27,
		0x91, 0xd2, 0x86, 0x51, 0x8a, 0x81, 0xdc, 0xf3, 0x9d, 0x72, 0xce, 0x9b, 0x95, 0xd6, 0x79, 0xd5,
		0xe2, 0x08, 0x7d, 0x75, 0x6f, 0xd5, 0x49, 0xf5, 0x4c, 0xe9, 0x4e, 0x29, 0xb9, 0x72, 0x87, 0xba,
		0x35, 0x36, 0x74, 0xfe, 0xbd, 0xa2, 0x46, 0x3d, 0x59, 0x37, 0xe8, 0x91, 0x23, 0xfe, 0xeb, 0xbf,
		0xaa, 0xf5, 0xae, 0xb0, 0xe6, 0x4b, 0x1e, 0xc3, 0x38, 0xc9, 0x47, 0x2e, 0x56, 0xdd, 0x8b, 0xe2,
		0x4a, 0x1c, 0xcb, 0xe9, 0xbc, 0x63, 0x9d, 0x7a, 0x41, 0xd5, 0x17, 0x63, 0x5c, 0x16, 0xc9, 0xc1,
		0xf8, 0xd6, 0xa9, 0x7b, 0x37, 0x77, 0xc5, 0xfc, 0x51, 0xb1, 0x78, 0x70, 0x58, 0x2c, 0xe6, 0x0e,
		0xf7, 0x0f, 0x73, 0xe5, 0x52, 0x29, 0x7f, 0x20, 0x03, 0x3d, 0x58, 0x8d, 0xb0, 0x27, 0x42, 0xd1,
		0x3b, 0x1e, 0xef, 0x6e, 0x30, 0xf2, 0xfd, 0x4c, 0x5f, 0xb2, 0x64, 0x0d, 0xce, 0x4e, 0x73, 0x25,
		0xa0, 0xa1, 0x95, 0x7a, 0x67, 0xad, 0x67, 0x2b, 0x56, 0xd7, 0xf0, 0xd5, 0x7e, 0x73, 0x45, 0x71,
		0x91, 0x25, 0x26, 0xba, 0xc5, 0x63, 0xb5, 0x97, 0xb3, 0xfc, 0xd6, 0x2e, 0xf7, 0x1b, 0x4b, 0xbe,
		0x84, 0x75, 0x37, 0x5f, 0xcb, 0xa6, 0xaf, 0xa0, 0x7e, 0x4b, 0xa8, 0xdb, 0x72, 0xef, 0xf1, 0xed,
		0x6f, 0x63, 0x89, 0x37, 0x61, 0x4d, 0x90, 0xc1, 0xb2, 0x2f, 0x20, 0x05, 0xd8, 0x93, 0x5f, 0x5f,
		0xf2, 0xcd, 0xaf, 0x36, 0x7c, 0xfa, 0x91, 0xf7, 0x2a, 0x2c, 0xf9, 0x8b, 0x6b, 0xf0, 0x5a, 0xf3,
		0xbc, 0x55, 0x20, 0xe2, 0xb1, 0xb8, 0xac, 0x22, 0x13, 0x6b, 0x72, 0x53, 0xd2, 0xb8, 0x27, 0x69,
		0xdc, 0xd2, 0x73, 0xee, 0x68, 0xb6, 0x37, 0xc4, 0x6c, 0xcc, 0xaa, 0x43, 0x94, 0xad, 0xde, 0xa4,
		0xa2, 0xd3, 0xee, 0x8b, 0x38, 0xf4, 0xba, 0xab, 0xbf, 0xb8, 0xc7, 0xd6, 0x89, 0x4f, 0xae, 0xb7,
		0xe2, 0xa6, 0xaf, 0x47, 0x28, 0xaf, 0x4d, 0x1c, 0xcb, 0x20, 0x88, 0xe5, 0x28, 0x94, 0x2c, 0xc5,
		0x52, 0x46, 0xee, 0x4a, 0x27, 0x71, 0xa5, 0x29, 0x5c, 0x36, 0x48, 0x6b, 0x6d, 0xa2, 0x55, 0x5e,
		0xf3, 0x7a, 0x09, 0x8d, 0x4a, 0x24, 0x25, 0x1b, 0xc8, 0x09, 0x16, 0xa5, 0x71, 0x14, 0x92, 0xcf,
		0xab, 0x64, 0x37, 0x0c, 0x51, 0x71, 0xee, 0xfb, 0x20, 0x27, 0xba, 0x26, 0xff, 0x0a, 0x64, 0x37,
		0xee, 0x50, 0xf2, 0x2e, 0x32, 0x0a, 0x39, 0x3b, 0xba, 0xa2, 0xa9, 0x15, 0x70, 0xe3, 0xba, 0x0d,
		0x31, 0x24, 0x35, 0xbe, 0x00, 0xf0, 0x00, 0xf0, 0xd8, 0x78, 0xe0, 0xb1, 0x7e, 0x03, 0x86, 0x35,
		0x1b, 0x2d, 0xe8, 0x31, 0x39, 0x93, 0x03, 0xeb, 0x6b, 0x6f, 0x8d, 0x46, 0xf2, 0xcf, 0x0e, 0xbf,
		0x93, 0x6b, 0xc1, 0xf0, 0xc0, 0xf0, 0xc0, 0xf0, 0xac, 0xa1, 0x45, 0xeb, 0xa6, 0x90, 0xc8, 0x48,
		0x15, 0x91, 0x9b, 0x12, 0x92, 0x3e, 0x60, 0xed, 0xec, 0xbc, 0x5d, 0xa9, 0xd7, 0x9d, 0x66, 0xab,
		0xd1, 0x6e, 0x7c, 0x68, 0xd4, 0x9d, 0xf6, 0x5f, 0xcd, 0x75, 0xf3, 0x40, 0x64, 0xe6, 0x7b, 0x48,
		0xc2, 0xf6, 0x73, 0x49, 0x09, 0x16, 0x85, 0xc8, 0x45, 0xf2, 0x63, 0xd5, 0x3e, 0x9d, 0x36, 0x4d,
		0x7c, 0xae, 0x93, 0x5a, 0xab, 0xfa, 0xa1, 0x5d, 0xff, 0xcb, 0xf9, 0xd0, 0x38, 0x3b, 0xab, 0x7e,
		0x68, 0x57, 0x4f, 0x4c, 0x7c, 0xca, 0xc6, 0x79, 0xf3, 0xe3, 0xbe, 0x89, 0x0f, 0x76, 0xde, 0xae,
		0xb4, 0x6b, 0x1f, 0x8c, 0x54, 0xb8, 0xf3, 0xda, 0xb9, 0x89, 0xcf, 0x75, 0xfc, 0xa9, 0x69, 0xaa,
		0x86, 0x99, 0xf8, 0x5c, 0xf5, 0xc6, 0x87, 0x4a, 0xdd, 0xa9, 0x7c, 0xfa, 0xd4, 0xaa, 0x7e, 0xaa,
		0xb4, 0x25, 0x24, 0xd9, 0xad, 0x47, 0x04, 0x75, 0x74, 0xe3, 0x43, 0x2d, 0x51, 0xd9, 0xf4, 0x38,
		0x79, 0xcd, 0x78, 0x2c, 0xb9, 0x0a, 0x22, 0x31, 0x44, 0x62, 0x88, 0xc4, 0x56, 0x92, 0x9b, 0x28,
		0x0e, 0xbd, 0xe0, 0x46, 0x46, 0x10, 0x76, 0x84, 0x14, 0x1e, 0x1d, 0x29, 0x3c, 0x2b, 0xe4, 0xbd,
		0xaa, 0x4b, 0xb3, 0xf1, 0xba, 0x76, 0x38, 0x18, 0xc5, 0x49, 0x50, 0xba, 0x46, 0xba, 0xcd, 0xe3,
		0x65, 0x34, 0xa7, 0xdd, 0xe4, 0xb2, 0x49, 0xbb, 0xf1, 0x07, 0x5d, 0x3b, 0x44, 0xd6, 0xcd, 0x4b,
		0x86, 0x78, 0xba, 0x35, 0xa6, 0x24, 0xdd, 0x4c, 0xa4, 0x7b, 0x7d, 0x98, 0x33, 0xbd, 0xce, 0x7a,
		0x40, 0x27, 0x6f, 0x08, 0xd0, 0x59, 0x59, 0x7d, 0x80, 0x73, 0x56, 0x55, 0xaf, 0x6c, 0x60, 0xce,
		0xaa, 0x6a, 0x97, 0x5e, 0xa0, 0x3b, 0x93, 0x5c, 0x49, 0xb4, 0xee, 0xf4, 0x7a, 0xeb, 0xd6, 0x6b,
		0xac, 0xa5, 0x8e, 0xd2, 0xd4, 0x52, 0xa6, 0x7a, 0x2a, 0x51, 0x53, 0xd9, 0xea, 0xaa, 0x4c, 0x6d,
		0x95, 0xa9, 0xaf, 0x2a, 0x35, 0x96, 0xc3, 0x4b, 0xac, 0x5b, 0xd2, 0xb2, 0xae, 0x7a, 0xa7, 0x17,
		0xea, 0x89, 0xa8, 0x1b, 0x7a, 0x43, 0xa9, 0xe5, 0x6d, 0x73, 0x79, 0xae, 0x8f, 0x17, 0xff, 0x9d,
		0x64, 0x4a, 0x94, 0xec, 0xee, 0x09, 0x2a, 0xba, 0x26, 0x28, 0x31, 0x0c, 0xaa, 0x0c, 0x84, 0x72,
		0x43, 0xa1, 0xdc, 0x60, 0xa8, 0x36, 0x1c, 0x72, 0x0c, 0x88, 0x24, 0x43, 0x22, 0x8f, 0x16, 0x51,
		0x47, 0x93, 0x48, 0xa6, 0x4d, 0xe4, 0xbf, 0x07, 0x19, 0x79, 0xa3, 0x43, 0xb9, 0x76, 0xe3, 0xb1,
		0x59, 0x9c, 0x54, 0x27, 0x0d, 0xeb, 0x0b, 0xeb, 0x0b, 0xeb, 0xcb, 0xc9, 0xfa, 0x7a, 0x43, 0x5b,
		0xba, 0x00, 0xa4, 0x06, 0xb8, 0x2c, 0xf1, 0x9a, 0xd3, 0x2d, 0x90, 0xdb, 0x8f, 0x45, 0x65, 0x2b,
		0x9f, 0xe1, 0x6d, 0xd1, 0x56, 0xd6, 0xfa, 0xe9, 0xd1, 0xc7, 0x29, 0xb8, 0x76, 0xd3, 0x8d, 0x63,
		0x11, 0x06, 0xca, 0xba, 0xdf, 0x58, 0xff, 0xbb, 0xbd, 0x7d, 0x91, 0xb3, 0xcb, 0x9d, 0x1f, 0x17,
		0x79, 0xbb, 0xdc, 0x99, 0x7c, 0xcc, 0x27, 0xdf, 0x26, 0x9f, 0x0b, 0x17, 0x39, 0xbb, 0x38, 0xfb,
		0x5c, 0xba, 0xc8, 0xd9, 0xa5, 0xce, 0xce, 0xe5, 0xe5, 0xee, 0xce, 0xf7, 0xfd, 0x87, 0xe5, 0x7f,
		0x71, 0x6f, 0x7a, 0xb3, 0x9d, 0x1f, 0xdb, 0x17, 0x79, 0xbb, 0xd0, 0x99, 0xfd, 0x65, 0xff, 0x22,
		0x67, 0x17, 0x3a, 0x3b, 0x3b, 0xff, 0x47, 0x7e, 0xa3, 0x97, 0x8e, 0x8a, 0x97, 0xd2, 0x38, 0xaf,
		0xfd, 0x89, 0x37, 0xb3, 0xee, 0x9b, 0xa1, 0xdc, 0x60, 0x4c, 0xad, 0x35, 0x3a, 0x80, 0x35, 0xfa,
		0xa9, 0xcc, 0xbb, 0xf6, 0x75, 0xc5, 0xfe, 0xd8, 0xf9, 0x9e, 0xff, 0xbd, 0xf8, 0xf0, 0x7e, 0xe7,
		0xfb, 0xe1, 0xc3, 0xf3, 0x1f, 0xfe, 0x78, 0xe9, 0x9f, 0xe5, 0x7f, 0x3f, 0x7c, 0x78, 0xff, 0xca,
		0xff, 0x39, 0x78, 0x78, 0xff, 0xc6, 0x6b, 0x94, 0x1e, 0xb6, 0x17, 0xfe, 0xe9, 0xf8, 0xe7, 0x85,
		0xd7, 0x7e, 0xa1, 0xf8, 0xca, 0x2f, 0xec, 0xbf, 0xf6, 0x0b, 0xfb, 0xaf, 0xfc, 0xc2, 0xab, 0x4b,
		0x2a, 0xbc, 0xf2, 0x0b, 0xa5, 0x87, 0x1f, 0x0b, 0xff, 0x7e, 0xfb, 0xe5, 0x7f, 0x7a, 0xf0, 0xb0,
		0xf3, 0xe3, 0xb5, 0xff, 0x77, 0xf8, 0xf0, 0xe3, 0xfd, 0xce, 0xce, 0xde, 0x76, 0x7e, 0x6c, 0x18,
		0x8e, 0x26, 0xb6, 0x22, 0xdf, 0x59, 0x30, 0x21, 0x13, 0x93, 0x00, 0x13, 0x0d, 0x71, 0xdd, 0x70,
		0x71, 0x25, 0xda, 0x8a, 0xad, 0x63, 0x10, 0xc5, 0x12, 0x89, 0xd8, 0x8e, 0xdd, 0x1b, 0xf9, 0x1c,
		0xcb, 0xec, 0xc2, 0x20, 0x59, 0x40, 0xb2, 0x80, 0x64, 0xd9, 0x40, 0x92, 0x25, 0x76, 0x6f, 0x64,
		0x0f, 0xe2, 0x00, 0xc7, 0x22, 0xa3, 0xbb, 0xc7, 0xaf, 0x76, 0xf7, 0x10, 0xa3, 0x47, 0x1e, 0x17,
		0x6e, 0xe2, 0xe8, 0x91, 0x1c, 0x46, 0x8f, 0xbc, 0xe9, 0xd5, 0x1b, 0x38, 0x7a, 0x44, 0x76, 0x97,
		0x13, 0x12, 0x32, 0xb0, 0x99, 0x13, 0x48, 0xd8, 0xd0, 0x70, 0x5f, 0xc5, 0x9d, 0x2d, 0xfd, 0xbc,
		0xdb, 0x0c, 0x16, 0xee, 0x49, 0x58, 0xff, 0x3c, 0x9a, 0x2f, 0x3c, 0xec, 0xfc, 0xb6, 0xf3, 0x07,
		0xc2, 0x6a, 0xed, 0x61, 0x35, 0xfa, 0x32, 0x2f, 0x5b, 0x40, 0x92, 0x16, 0x5c, 0x4c, 0xff, 0xb6,
		0x37, 0x4d, 0x6c, 0xcd, 0xaa, 0x45, 0xf2, 0x1a, 0xa9, 0xdc, 0x81, 0xb8, 0x8b, 0xed, 0xaf, 0x83,
		0x61, 0x24, 0x2f, 0xcb, 0xf7, 0xf1, 0x92, 0x48, 0xf4, 0xd5, 0x4a, 0x76, 0x20, 0xd1, 0x17, 0x89,
		0xbe, 0x6f, 0x52, 0x76, 0xf9, 0xf4, 0x67, 0x7a, 0x65, 0xb9, 0xfc, 0x67, 0x1e, 0xfc, 0xa7, 0xa4,
		0x8b, 0x83, 0xff, 0xd4, 0x6c, 0x32, 0xe4, 0x02, 0x46, 0x59, 0xfc, 0xa7, 0x2c, 0x53, 0x92, 0x5e,
		0x50, 0x52, 0x89, 0xd0, 0xab, 0xca, 0x20, 0xa5, 0x64, 0x48, 0xb1, 0x79, 0x51, 0x66, 0x66, 0x54,
		0x9a, 0x1b, 0x2d, 0x66, 0x47, 0xb5, 0xf9, 0xd1, 0x66, 0x86, 0xb4, 0x99, 0x23, 0x5d, 0x66, 0x49,
		0x0d, 0xef, 0x23, 0x7b, 0x1a, 0xa3, 0x6c, 0x73, 0x95, 0x5e, 0xd8, 0x0b, 0x7a, 0xe2, 0x4e, 0xfd,
		0x08, 0xc3, 0xc9, 0x6d, 0x14, 0x49, 0x88, 0x5a, 0x2e, 0x55, 0x99, 0x31, 0xd3, 0x61, 0xd4, 0xb4,
		0x1a, 0x37, 0x5d, 0x46, 0x4e, 0xbb, 0xb1, 0xd3, 0x6e, 0xf4, 0x74, 0x1b, 0x3f, 0x35, 0x46, 0x50,
		0x91, 0x31, 0x4c, 0x37, 0x47, 0xd9, 0x88, 0xda, 0x05, 0xad, 0x51, 0x46, 0x63, 0x2f, 0x00, 0xb1,
		0x23, 0x26, 0x87, 0x1a, 0x0a, 0xde, 0xa9, 0xb5, 0xe6, 0x44, 0x99, 0x37, 0xbf, 0xcd, 0xb5, 0x26,
		0xcd, 0xc0, 0x1b, 0xc1, 0x1b, 0xc1, 0x1b, 0xc1, 0x1b, 0x65, 0xe8, 0x8d, 0x94, 0x65, 0x02, 0x3d,
		0xb7, 0x61, 0x87, 0x0a, 0x6f, 0xa1, 0x36, 0x33, 0x68, 0xf6, 0xa5, 0x56, 0xe5, 0xb7, 0x74, 0x65,
		0x0a, 0x69, 0x72, 0x2e, 0x0b, 0xb7, 0xd3, 0x94, 0x39, 0x94, 0xde, 0x4f, 0x63, 0xf6, 0x88, 0x62,
		0x73, 0xf0, 0x54, 0x44, 0x34, 0x64, 0x14, 0x65, 0x2d, 0x22, 0xba, 0x32, 0x8c, 0x32, 0x95, 0x95,
		0x77, 0x3c, 0xaf, 0xde, 0xd9, 0xe0, 0xa0, 0x42, 0xfa, 0x51, 0xdf, 0xab, 0x6e, 0x59, 0xf2, 0xd1,
		0x1f, 0x02, 0x0b, 0x04, 0x16, 0x08, 0x2c, 0x10, 0x58, 0xe8, 0x0c, 0x2c, 0x02, 0x79, 0xcd, 0xc9,
		0x7e, 0x66, 0xc2, 0x64, 0xd6, 0x71, 0xbc, 0xb6, 0x5d, 0xec, 0xe3, 0x8a, 0xb9, 0xa6, 0x25, 0x6e,
		0xaf, 0x17, 0x8a, 0x28, 0xb2, 0x34, 0x40, 0x55, 0x0d, 0x6f, 0x48, 0xef, 0x9b, 0xd2, 0xf7, 0xc6,
		0x5e, 0x78, 0x73, 0xb7, 0x45, 0x8d, 0xef, 0x6e, 0xe1, 0x1d, 0x1e, 0x69, 0xbc, 0xa7, 0xea, 0x94,
		0xe9, 0x57, 0x6f, 0xac, 0xb5, 0x89, 0xc7, 0xff, 0xb1, 0xb4, 0x3d, 0x5c, 0x47, 0xe7, 0xcb, 0xd3,
		0x51, 0xcb, 0xbf, 0x79, 0x6f, 0x50, 0xcb, 0x9d, 0x1e, 0x7e, 0x37, 0xd8, 0x7c, 0x1e, 0xc0, 0x7c,
		0xea, 0x51, 0x3e, 0x34, 0xd8, 0xd0, 0xdf, 0x60, 0x03, 0xce, 0x04, 0xf2, 0x0c, 0x79, 0xa6, 0xec,
		0x5a, 0xdf, 0xf1, 0x7e, 0x0e, 0xc5, 0xd0, 0x40, 0x63, 0x0c, 0xec, 0x0f, 0xba, 0xae, 0x6f, 0xf7,
		0xc4, 0xb5, 0x17, 0x88, 0x9e, 0xad, 0x98, 0x68, 0x7d, 0x11, 0x0c, 0x68, 0x38, 0xd5, 0x90, 0x3b,
		0x42, 0x78, 0xe9, 0x3d, 0x9e, 0x0c, 0x2b, 0x3c, 0xa9, 0x7e, 0xac, 0x9d, 0x55, 0x4f, 0x9c, 0xb3,
		0xea, 0x9f, 0x6d, 0xe7, 0x1f, 0x8d, 0xa6, 0xa5, 0xf3, 0x18, 0x29, 0xd2, 0xea, 0x2f, 0xbe, 0xeb,
		0xf5, 0x4c, 0xe9, 0xd0, 0xdc, 0x56, 0xa3, 0xa9, 0xcf, 0x52, 0x3e, 0xfc, 0x6e, 0xfa, 0x7e, 0x4e,
		0xe4, 0xb6, 0x5e, 0x3b, 0xfb, 0xa7, 0xc6, 0x5d, 0x7d, 0x67, 0x86, 0x97, 0xc3, 0x81, 0xa6, 0xda,
		0xf5, 0xaa, 0x38, 0xd0, 0x0c, 0x45, 0x77, 0x14, 0x2a, 0x74, 0x10, 0xa9, 0x62, 0xcd, 0x6e, 0xa4,
		0xe8, 0x58, 0xe3, 0x44, 0x5c, 0xbb, 0x23, 0x3f, 0x39, 0xf2, 0xb9, 0x76, 0x7d, 0x75, 0xf7, 0xc1,
		0xb1, 0xe9, 0xdb, 0x5f, 0x39, 0x8e, 0x4d, 0xd7, 0xb9, 0x21, 0x8e, 0x4d, 0x09, 0x21, 0x14, 0x8d,
		0xc7, 0xa6, 0x57, 0x83, 0x81, 0x2f, 0x5c, 0x2d, 0x07, 0xa7, 0x79, 0x2e, 0x8e, 0x8f, 0x74, 0x35,
		0x9d, 0xe4, 0x5e, 0x2b, 0x0b, 0xd7, 0xcf, 0xa6, 0xf7, 0x4a, 0xda, 0x6e, 0x24, 0xfd, 0x24, 0xa5,
		0x1d, 0x8b, 0xba, 0x57, 0x2b, 0xf1, 0xb5, 0x2a, 0xaa, 0x63, 0x54, 0x5a, 0xbf, 0xa8, 0x08, 0x99,
		0xa0, 0xf8, 0x3a, 0x2b, 0xe4, 0x81, 0xe2, 0x6b, 0x33, 0xdd, 0x85, 0x32, 0x24, 0xf1, 0xc8, 0x6f,
		0x0a, 0xf7, 0x3a, 0x14, 0xd7, 0x2a, 0xfb, 0xe4, 0x1d, 0xaa, 0xe9, 0x93, 0x97, 0x78, 0xb8, 0xdd,
		0xdd, 0xc9, 0x38, 0xf9, 0xbd, 0x89, 0x99, 0xdc, 0x08, 0x77, 0x13, 0x8b, 0xf0, 0xda, 0xed, 0x0a,
		0x7b, 0xfc, 0xda, 0x14, 0xba, 0x9d, 0xf9, 0xdb, 0xa0, 0xf7, 0x87, 0x0e, 0xf7, 0xe3, 0x5d, 0xc3,
		0xf5, 0x10, 0x74, 0x3d, 0xde, 0x35, 0x7a, 0x7e, 0x48, 0xba, 0xb0, 0xa2, 0x56, 0x45, 0x0b, 0xca,
		0xa4, 0xa4, 0x65, 0x91, 0x62, 0xf3, 0xa5, 0xdc, 0x8c, 0xe9, 0x30, 0x67, 0xda, 0xcc, 0x9a, 0x2e,
		0xf3, 0xa6, 0xdd, 0xcc, 0x69, 0x37, 0x77, 0x3a, 0xcd, 0x9e, 0x3a, 0xda, 0x67, 0x4b, 0x21, 0x9f,
		0xa7, 0xca, 0x1c, 0x2e, 0x62, 0x3a, 0xf5, 0x62, 0xbc, 0x80, 0xef, 0x54, 0x8b, 0xb1, 0xa6, 0x76,
		0xf3, 0xaa, 0x8d, 0xa6, 0x4e, 0xe3, 0xa9, 0xdd, 0x88, 0xea, 0x36, 0xa6, 0x99, 0x19, 0xd5, 0xcc,
		0x8c, 0x6b, 0x16, 0x46, 0x56, 0xad, 0xb1, 0x55, 0x6c, 0x74, 0xd5, 0x53, 0x20, 0x19, 0x50, 0x22,
		0x3a, 0x29, 0x92, 0x57, 0x29, 0x93, 0xbd, 0x44, 0xec, 0xde, 0xa7, 0x0e, 0x20, 0x7a, 0xfe, 0x83,
		0xe9, 0xdf, 0x83, 0xf1, 0x76, 0x30, 0xcd, 0xd2, 0x50, 0x39, 0xa4, 0x25, 0x1a, 0x5d, 0x65, 0xe0,
		0xaf, 0x9f, 0xdc, 0x15, 0x2e, 0x1b, 0x2e, 0x1b, 0x2e, 0x1b, 0x2e, 0x1b, 0x2e, 0x1b, 0x2e, 0x3b,
		0xf9, 0xc1, 0xc5, 0xa3, 0xcb, 0xfe, 0xbf, 0xdd, 0x51, 0x18, 0x8a, 0x20, 0xde, 0xde, 0xd9, 0xdb,
		0xdd, 0xdd, 0x4b, 0xff, 0x45, 0x67, 0xfa, 0x2b, 0xf3, 0x7e, 0x24, 0x7a, 0xe1, 0x67, 0xe9, 0x95,
		0xa5, 0x1f, 0xa7, 0x68, 0xf4, 0xfe, 0xac, 0xd8, 0x85, 0xea, 0x5d, 0xac, 0x36, 0xfb, 0x5c, 0x1f,
		0x31, 0x36, 0xe8, 0xda, 0xe2, 0x2e, 0x7e, 0x1f, 0x0b, 0x5f, 0xf4, 0x45, 0x1c, 0xde, 0xdb, 0x83,
		0xc0, 0xee, 0x7e, 0x4d, 0xda, 0xad, 0x69, 0x25, 0xcb, 0x92, 0xac, 0x4e, 0x8d, 0x6c, 0x19, 0x37,
		0xa2, 0xac, 0xa3, 0xea, 0xe0, 0x44, 0x6d, 0x76, 0xd3, 0x23, 0x04, 0xa7, 0x92, 0xe5, 0xf4, 0xe4,
		0x94, 0x54, 0x49, 0xce, 0x93, 0x3a, 0x41, 0x50, 0x91, 0x21, 0x9e, 0x9c, 0xc5, 0xab, 0x3f, 0xde,
		0x99, 0xdc, 0x86, 0xf9, 0xe9, 0x4e, 0x01, 0xa7, 0x3b, 0x64, 0xa2, 0x1b, 0x9c, 0xee, 0x6c, 0x2e,
		0xfe, 0xc2, 0xe9, 0x0e, 0xa8, 0x22, 0x50, 0x45, 0xa0, 0x8a, 0x40, 0x15, 0x81, 0x2a, 0xda, 0x00,
		0xaa, 0x08, 0xa7, 0x3b, 0x3f, 0x8f, 0x60, 0x70, 0xba, 0x03, 0x97, 0x0d, 0x97, 0x0d, 0x97, 0x0d,
		0x97, 0x0d, 0x97, 0x4d, 0xc4, 0x65, 0xe3, 0x74, 0x87, 0x2f, 0xbb, 0xb0, 0xe1, 0x94, 0xf8, 0x84,
		0xa9, 0x45, 0xe9, 0x38, 0x7d, 0x49, 0x22, 0x2a, 0x41, 0x96, 0x92, 0x53, 0x8a, 0x70, 0xd4, 0x8d,
		0x83, 0xa9, 0x77, 0x39, 0x9b, 0x2c, 0xbd, 0x36, 0x5d, 0xb9, 0xd3, 0x9c, 0xae, 0xd7, 0x39, 0x4f,
		0x56, 0xe8, 0x9c, 0x89, 0xbb, 0xf8, 0x1f, 0x83, 0xa1, 0x53, 0x9b, 0x2d, 0xab, 0x25, 0xae, 0x37,
		0xa1, 0xd0, 0x50, 0xcd, 0x59, 0x8e, 0xd2, 0x33, 0x1c, 0xe5, 0x85, 0x85, 0x05, 0xd4, 0xb5, 0x6b,
		0x8d, 0x4f, 0x50, 0xd7, 0x6e, 0xa6, 0x2f, 0xc3, 0x50, 0xf1, 0xcc, 0x08, 0x1a, 0xb4, 0x0d, 0xa3,
		0x4a, 0xc2, 0xa0, 0x6d, 0xd8, 0x66, 0x87, 0x8a, 0x18, 0x2a, 0x9e, 0x61, 0xe8, 0x87, 0xa1, 0xe2,
		0xf0, 0x46, 0xf0, 0x46, 0xf0, 0x46, 0xf0, 0x46, 0xda, 0xbd, 0x11, 0x86, 0x8a, 0xbf, 0xf9, 0x0b,
		0x43, 0xc5, 0xd7, 0xba, 0x1d, 0x86, 0x8a, 0xcb, 0x11, 0x11, 0x0c, 0x15, 0x37, 0x43, 0x56, 0xd0,
		0x83, 0x9f, 0x5d, 0x50, 0x81, 0xa1, 0xe2, 0x08, 0x2c, 0x10, 0x58, 0x20, 0xb0, 0x40, 0x60, 0xf1,
		0x86, 0xc0, 0x02, 0x43, 0xc5, 0xe9, 0xc4, 0x15, 0x18, 0x2a, 0xce, 0xec, 0x8d, 0xbd, 0xf0, 0xe6,
		0x30, 0x54, 0x5c, 0xf9, 0x8d, 0x31, 0x54, 0x5c, 0xc2, 0xcb, 0xc3, 0x50, 0x71, 0x36, 0x51, 0x57,
		0x06, 0xfc, 0xc5, 0x16, 0x86, 0x8a, 0x9b, 0x6e, 0x3e, 0x31, 0x84, 0x19, 0x43, 0xc5, 0x4d, 0x72,
		0x26, 0x90, 0x67, 0x0c, 0x15, 0x27, 0x4e, 0xf7, 0x6e, 0x61, 0xa8, 0xf8, 0x9b, 0xa1, 0x00, 0x86,
		0x8a, 0xab, 0xdf, 0x63, 0x0c, 0x15, 0xd7, 0xb3, 0xcf, 0x18, 0x2a, 0xae, 0x42, 0x6e, 0x31, 0x54,
		0x9c, 0xde, 0x73, 0xe0, 0x40, 0x13, 0x43, 0xc5, 0x5f, 0xbf, 0x0d, 0x86, 0x8a, 0xbf, 0x31, 0x9e,
		0xc2, 0xb1, 0xe9, 0x8a, 0x2f, 0x1e, 0xc7, 0xa6, 0x1c, 0xec, 0x39, 0x86, 0x8a, 0x2f, 0x11, 0x86,
		0x60, 0xa8, 0xb8, 0x14, 0xbd, 0xd9, 0x94, 0xca, 0x70, 0x05, 0xdd, 0x04, 0x24, 0xd6, 0x5e, 0xbf,
		0x23, 0x24, 0x1b, 0x63, 0x6f, 0x21, 0xbb, 0x50, 0xd1, 0xaa, 0x7b, 0x51, 0x5c, 0x89, 0x63, 0xb9,
		0xa5, 0x9b, 0xd6, 0xa9, 0x17, 0x54, 0x7d, 0x31, 0xb6, 0xfb, 0x91, 0x5c, 0xd8, 0x61, 0x9d, 0xba,
		0x77, 0x73, 0x57, 0xce, 0x1f, 0x15, 0x8b, 0x07, 0x87, 0xc5, 0x62, 0xee, 0x70, 0xff, 0x30, 0x57,
		0x2e, 0x95, 0xf2, 0x07, 0x32, 0x59, 0x10, 0xab, 0x11, 0xf6, 0x44, 0x28, 0x7a, 0xc7, 0xe3, 0x6d,
		0x0f, 0x46, 0xbe, 0x4f, 0x4a, 0x1a, 0x14, 0x59, 0x08, 0x32, 0x96, 0xc1, 0x92, 0xda, 0xf7, 0x60,
		0x85, 0xee, 0x10, 0x72, 0x8c, 0xd2, 0xfa, 0x26, 0x64, 0xbd, 0x2b, 0xac, 0x29, 0x6e, 0xb2, 0xc5,
		0x2c, 0x6b, 0xf1, 0x5a, 0xef, 0xa5, 0xae, 0xfe, 0x2a, 0xd6, 0x78, 0x0d, 0xb3, 0xd0, 0x60, 0xdd,
		0xed, 0x4f, 0xc1, 0xa0, 0x94, 0x50, 0x43, 0x52, 0xd0, 0x2a, 0x2d, 0x38, 0x95, 0x19, 0x84, 0x2a,
		0x09, 0x36, 0x65, 0x07, 0x95, 0xca, 0x82, 0x47, 0x65, 0x41, 0xa2, 0xaa, 0x60, 0x30, 0x5b, 0x03,
		0x29, 0x2d, 0x88, 0x53, 0xd0, 0x1b, 0x4f, 0x66, 0xef, 0xbb, 0xb4, 0xb7, 0xdd, 0xee, 0xee, 0x04,
		0xb4, 0xef, 0x4d, 0xa5, 0x8e, 0xa1, 0x45, 0x95, 0xd3, 0x07, 0x49, 0x6a, 0xdf, 0x23, 0x49, 0x7d,
		0x8e, 0xa4, 0xf5, 0x35, 0x82, 0x3d, 0x85, 0x3d, 0xcd, 0xc4, 0x9e, 0xca, 0xea, 0x23, 0x64, 0xf5,
		0x44, 0xd4, 0x0d, 0xbd, 0xa1, 0xd4, 0x08, 0x29, 0x95, 0xe4, 0xf9, 0x8b, 0xcb, 0x0a, 0xef, 0xa5,
		0x9e, 0x02, 0x48, 0x67, 0xfd, 0x55, 0xb0, 0xfc, 0x4a, 0x59, 0x7d, 0x55, 0x2c, 0xbe, 0x72, 0xd6,
		0x5e, 0x39, 0x4b, 0xaf, 0x9a, 0x95, 0xa7, 0x45, 0x9b, 0x49, 0x67, 0xd9, 0xd5, 0xf5, 0xdc, 0x91,
		0xdc, 0x63, 0x47, 0x02, 0xf7, 0x20, 0xc1, 0x4f, 0x0f, 0xe5, 0xda, 0x0d, 0xb9, 0x61, 0x2c, 0xac,
		0x2f, 0xac, 0x2f, 0xac, 0x2f, 0x4b, 0xeb, 0xeb, 0x0d, 0x6d, 0xe9, 0x02, 0xa0, 0xa2, 0xb8, 0x50,
		0x4d, 0x11, 0xa1, 0xc2, 0xee, 0xb2, 0x49, 0x51, 0xa0, 0xb2, 0x7c, 0x04, 0x95, 0xc5, 0x2b, 0xca,
		0x8b, 0x54, 0xf4, 0x56, 0x82, 0xed, 0x4d, 0x6f, 0xb6, 0xf3, 0x63, 0xfb, 0x22, 0x6f, 0x17, 0x3a,
		0xb3, 0xbf, 0xec, 0x5f, 0xe4, 0xec, 0x42, 0x47, 0x49, 0x3a, 0x7b, 0x47, 0xc5, 0x4b, 0xd1, 0x51,
		0x6e, 0x61, 0xfe, 0x9b, 0xa1, 0x9c, 0xaf, 0xa0, 0xd6, 0x1a, 0x1d, 0xc0, 0x1a, 0xfd, 0x54, 0xe6,
		0x51, 0x4a, 0xa4, 0xbf, 0x94, 0x68, 0x6f, 0x3b, 0x3f, 0x36, 0x0c, 0x47, 0x13, 0x5b, 0x91, 0xef,
		0x2c, 0x98, 0x90, 0x89, 0x49, 0x80, 0x89, 0x86, 0xb8, 0x6e, 0xb8, 0xb8, 0x12, 0xcd, 0xed, 0xea,
		0x18, 0x44, 0xb1, 0x44, 0x22, 0xb6, 0x63, 0xf7, 0x46, 0x3e, 0xc7, 0x32, 0xbb, 0x30, 0x48, 0x16,
		0x90, 0x2c, 0x20, 0x59, 0x36, 0x90, 0x64, 0x89, 0xdd, 0x1b, 0x3b, 0x1e, 0x5f, 0x1d, 0x1c, 0x8b,
		0xd4, 0x7d, 0x55, 0xd6, 0x20, 0x59, 0x61, 0x63, 0x64, 0xc5, 0x0d, 0x91, 0x15, 0x96, 0x41, 0xe8,
		0x68, 0x80, 0xac, 0x6b, 0x08, 0xaf, 0xa6, 0x86, 0xc7, 0x3a, 0x9b, 0xd7, 0xaa, 0x1c, 0xfe, 0xac,
		0xa3, 0xb1, 0xb1, 0xee, 0x57, 0xaf, 0xab, 0x91, 0xb1, 0x56, 0x19, 0x60, 0x52, 0x36, 0xb4, 0xa9,
		0x34, 0xdc, 0x57, 0x71, 0x67, 0x2b, 0x9b, 0x31, 0xc3, 0x9b, 0x85, 0x7b, 0x12, 0xd6, 0x3f, 0x8f,
		0xe6, 0x0b, 0x0f, 0x3b, 0xbf, 0xed, 0xfc, 0x81, 0xb0, 0x5a, 0x7b, 0x58, 0x8d, 0xaa, 0x89, 0xb5,
		0xab, 0x26, 0x24, 0xd4, 0xe6, 0xad, 0x91, 0xdf, 0xfb, 0x4e, 0xe3, 0x8b, 0x9b, 0xd5, 0xd6, 0xad,
		0x15, 0xec, 0xca, 0x29, 0xa6, 0x93, 0x57, 0x3c, 0xa7, 0xb4, 0x58, 0x4e, 0x4e, 0x71, 0xdc, 0xaa,
		0xaf, 0x4b, 0x92, 0x7e, 0x65, 0xa3, 0x57, 0xd6, 0x5a, 0x99, 0xeb, 0x4b, 0x54, 0xb2, 0xad, 0xa6,
		0xba, 0xcb, 0x2b, 0xde, 0x72, 0xbf, 0xb1, 0xe4, 0x3b, 0x5f, 0xf7, 0x5d, 0x6b, 0x7e, 0xc7, 0xcb,
		0xed, 0xf9, 0xdb, 0x77, 0xee, 0x6d, 0xff, 0xf2, 0x8d, 0x7b, 0x9b, 0x96, 0x12, 0x27, 0xed, 0xbc,
		0xae, 0x3d, 0x11, 0x6e, 0x25, 0x22, 0xf5, 0xc6, 0xdf, 0x5e, 0xc9, 0xce, 0xad, 0x6e, 0xd7, 0xa4,
		0xda, 0xb1, 0xd5, 0xec, 0xd6, 0x5b, 0xf7, 0x75, 0x45, 0x59, 0x55, 0x2e, 0xa3, 0x4b, 0x98, 0x9c,
		0x37, 0x9a, 0x98, 0xb7, 0xc9, 0xf9, 0xaf, 0xa5, 0xf6, 0xe7, 0xff, 0xe2, 0x17, 0xfb, 0xbe, 0xec,
		0x7e, 0xab, 0xda, 0xe7, 0x9f, 0x6f, 0xc6, 0xeb, 0x8f, 0xf8, 0x93, 0xc7, 0xb3, 0x12, 0x73, 0x62,
		0xfb, 0x5e, 0x7f, 0x12, 0x79, 0xff, 0xfc, 0xe1, 0x1e, 0x3b, 0x22, 0xcd, 0xff, 0xd6, 0x2f, 0x36,
		0xef, 0x6d, 0x15, 0x47, 0x6f, 0x3e, 0x65, 0x59, 0xe6, 0xf4, 0x64, 0xfe, 0x54, 0x24, 0xf0, 0x6c,
		0x7f, 0xff, 0x0d, 0x02, 0xba, 0xec, 0x61, 0xc7, 0xca, 0x87, 0x18, 0x2b, 0x1f, 0x4e, 0x3c, 0x3f,
		0x74, 0x98, 0x3c, 0x99, 0x62, 0x15, 0x78, 0x6b, 0xbd, 0xcc, 0xbc, 0x68, 0xbc, 0x7d, 0x0f, 0x5f,
		0x90, 0xab, 0xb7, 0xee, 0xe2, 0x72, 0x05, 0x6d, 0x4b, 0x1f, 0xe6, 0xad, 0x72, 0x58, 0xb7, 0x8a,
		0xd8, 0xad, 0x2a, 0x7e, 0x6b, 0x8b, 0xe1, 0xda, 0xe2, 0xb8, 0xa6, 0x58, 0xaa, 0x41, 0x1e, 0xcb,
		0x96, 0x77, 0x59, 0xee, 0xb5, 0xb7, 0xfc, 0x9e, 0xcf, 0xde, 0xf3, 0xf8, 0x97, 0x97, 0xdc, 0xac,
		0xd5, 0xb8, 0xdc, 0x95, 0xcf, 0xa2, 0xd7, 0x39, 0x73, 0x5e, 0x47, 0x9c, 0xd7, 0x15, 0x6b, 0x69,
		0xe2, 0x2d, 0x4d, 0xcc, 0x25, 0x89, 0xbb, 0x9e, 0xa0, 0x66, 0xe5, 0x13, 0x5b, 0x09, 0x55, 0xe2,
		0xeb, 0x54, 0x85, 0x2f, 0x56, 0x81, 0x8f, 0x55, 0x4c, 0x55, 0xcc, 0xb3, 0x84, 0x75, 0xee, 0xce,
		0xf4, 0x6f, 0x45, 0x4b, 0x31, 0xfd, 0xfd, 0xd5, 0x8c, 0x45, 0x1e, 0xc6, 0x02, 0xc6, 0x42, 0x9d,
		0xb1, 0x58, 0xb5, 0x24, 0x7a, 0x25, 0xdf, 0x29, 0xc1, 0x87, 0xae, 0xe9, 0x4b, 0xd7, 0x56, 0x13,
		0x19, 0xea, 0x22, 0x53, 0x6d, 0x64, 0xa9, 0x8f, 0x74, 0x35, 0x92, 0xae, 0x4e, 0x92, 0xd5, 0x2a,
		0x9b, 0xb3, 0x80, 0xb5, 0xb3, 0xa9, 0x1e, 0x6b, 0x17, 0xa6, 0xed, 0xf2, 0xd7, 0xeb, 0xe6, 0x22,
		0xa3, 0xc3, 0xbf, 0xdc, 0xce, 0xfd, 0xe9, 0x03, 0x56, 0x4e, 0x4e, 0x5a, 0xd5, 0xf3, 0x73, 0xe7,
		0x63, 0xe5, 0xb4, 0x56, 0xff, 0x6b, 0x5d, 0x29, 0x94, 0xd8, 0x61, 0x5f, 0x72, 0x1e, 0x6c, 0xbd,
		0xe0, 0x54, 0xdb, 0xff, 0xa8, 0xb6, 0xce, 0xaa, 0x6d, 0x8b, 0x42, 0xc6, 0xaf, 0xe4, 0xc7, 0x3b,
		0x6d, 0xd6, 0xcf, 0x4d, 0x7c, 0xae, 0x5a, 0xf3, 0xcb, 0x81, 0xa1, 0xcf, 0x55, 0xcc, 0xba, 0xcf,
		0x4b, 0x47, 0xb7, 0x35, 0x7f, 0xa7, 0xe1, 0xbd, 0x59, 0xae, 0xef, 0x86, 0x7d, 0x3b, 0xfe, 0x1a,
		0x8a, 0xe8, 0xeb, 0xc0, 0xef, 0x49, 0x40, 0x4f, 0xcf, 0x2e, 0x08, 0x24, 0x05, 0x24, 0x05, 0x24,
		0xb5, 0xb4, 0xcc, 0xac, 0x9d, 0x2f, 0x2d, 0x21, 0x2f, 0x5a, 0x52, 0xfe, 0xb3, 0x84, 0x74, 0x20,
		0x99, 0xf9, 0xcc, 0xb2, 0x8b, 0x72, 0x24, 0xe7, 0x27, 0xab, 0xc8, 0x41, 0x95, 0x51, 0x72, 0x25,
		0x33, 0xaf, 0x58, 0xd5, 0x2b, 0x90, 0x9d, 0x27, 0xac, 0xe4, 0x5d, 0x64, 0x94, 0x5e, 0xd6, 0x21,
		0x0c, 0x42, 0xfa, 0xee, 0x9d, 0xd7, 0x1f, 0xf5, 0xd7, 0x07, 0x1f, 0xb3, 0x0b, 0x01, 0x74, 0x00,
		0x74, 0x00, 0x74, 0x00, 0x74, 0x00, 0x74, 0x00, 0x74, 0x00, 0x74, 0x00, 0x74, 0xbc, 0xb4, 0xcd,
		0xff, 0x71, 0xc3, 0xc0, 0x0b, 0x6e, 0xec, 0x41, 0xe0, 0xdf, 0xaf, 0x8f, 0x3c, 0x9e, 0x5c, 0x6d,
		0x45, 0x43, 0x2e, 0x69, 0xfc, 0x1e, 0x60, 0x0c, 0x60, 0xcc, 0x46, 0xc3, 0x98, 0xf5, 0x87, 0xbf,
		0xad, 0x39, 0xdc, 0x0d, 0x15, 0x05, 0x3f, 0xcb, 0x22, 0x9e, 0x4f, 0xd9, 0x9d, 0xff, 0xcb, 0xde,
		0x34, 0x25, 0x85, 0x40, 0x72, 0xcd, 0x6a, 0xf3, 0x12, 0xd6, 0x9a, 0x8f, 0xb0, 0x76, 0x6a, 0x4d,
		0x01, 0xa9, 0x35, 0x48, 0xad, 0xf9, 0x35, 0xc6, 0x40, 0x6a, 0x0d, 0x40, 0x0d, 0x40, 0x0d, 0x3f,
		0x50, 0x83, 0xd4, 0x9a, 0xe5, 0xa3, 0x73, 0xa4, 0xd6, 0xe8, 0x7f, 0x3c, 0xa4, 0xd6, 0xb0, 0x7b,
		0x2e, 0xa4, 0xd6, 0x28, 0x21, 0x98, 0x90, 0x5a, 0x03, 0x24, 0x05, 0x24, 0x45, 0x0f, 0x49, 0xe1,
		0x94, 0x6b, 0x7e, 0x21, 0x38, 0xe5, 0xca, 0xda, 0xa1, 0xe3, 0x94, 0x0b, 0xa7, 0x5c, 0xca, 0x40,
		0x48, 0xc2, 0xba, 0xfa, 0xbe, 0xe8, 0xcd, 0xda, 0xb5, 0xac, 0x8d, 0x42, 0x16, 0xae, 0x08, 0x18,
		0x02, 0x18, 0x02, 0x18, 0x02, 0x18, 0x02, 0x18, 0x02, 0x18, 0x02, 0x18, 0x02, 0x18, 0xf2, 0xd2,
		0x36, 0x23, 0xc3, 0x17, 0xa0, 0x03, 0xa0, 0x03, 0xa0, 0x03, 0xa0, 0x03, 0xa0, 0x03, 0xa0, 0x03,
		0xa0, 0x43, 0x0b, 0xe8, 0x48, 0x4f, 0x4a, 0x6c, 0x71, 0xd7, 0x15, 0xa2, 0x27, 0x24, 0x9c, 0xc1,
		0xbc, 0x70, 0x4d, 0x40, 0x11, 0x40, 0x11, 0x40, 0x91, 0xa5, 0x65, 0x86, 0x63, 0x96, 0x2e, 0xca,
		0x0c, 0x60, 0xc0, 0x60, 0xc0, 0x60, 0xc0, 0x50, 0x66, 0xf0, 0xa2, 0x58, 0xf0, 0x28, 0x33, 0x58,
		0x61, 0xca, 0x4b, 0xc6, 0x63, 0x0b, 0xde, 0x9e, 0x36, 0x8d, 0x51, 0x05, 0xb2, 0xa5, 0x53, 0x93,
		0x54, 0xca, 0x1b, 0x58, 0xd0, 0x1a, 0x5f, 0xb4, 0x9e, 0x5c, 0x13, 0x23, 0x0b, 0x9e, 0xec, 0xb7,
		0x8a, 0xa9, 0x05, 0x91, 0xb8, 0x19, 0x0b, 0x7f, 0x72, 0x16, 0xee, 0x05, 0x37, 0x6f, 0x1f, 0x5c,
		0xf0, 0xfc, 0x17, 0x79, 0xcc, 0x2e, 0x88, 0x42, 0x23, 0x07, 0x17, 0x44, 0x21, 0x99, 0xa9, 0x05,
		0x51, 0x78, 0x73, 0x15, 0x2d, 0x3f, 0xaf, 0x60, 0xf2, 0x6b, 0x66, 0x4c, 0x2a, 0x78, 0x93, 0x90,
		0xad, 0x0b, 0xbb, 0xe9, 0x8d, 0x29, 0x78, 0x8b, 0x10, 0xaa, 0x81, 0x19, 0x4b, 0xcf, 0x28, 0x18,
		0x4b, 0xdb, 0x1a, 0xe5, 0x91, 0xe3, 0xdf, 0xde, 0x8c, 0xc6, 0xe3, 0x4b, 0x89, 0xb2, 0xac, 0x48,
		0x92, 0x7e, 0x69, 0xe4, 0x32, 0xa2, 0xae, 0x27, 0x76, 0x59, 0xb9, 0x2e, 0x72, 0xc5, 0x3e, 0xfc,
		0x0b, 0xc2, 0xb2, 0x52, 0x3f, 0xfe, 0x35, 0xd5, 0x83, 0x2c, 0x17, 0xb3, 0x92, 0xda, 0x80, 0x88,
		0x59, 0x45, 0xad, 0xb2, 0x61, 0x61, 0x56, 0x55, 0xb7, 0xf4, 0x02, 0x3d, 0x37, 0x76, 0x87, 0xbe,
		0x1b, 0x08, 0x3b, 0x5e, 0x97, 0xd0, 0x79, 0x22, 0x7c, 0xcf, 0xae, 0xbb, 0xe6, 0xfb, 0x91, 0x73,
		0x20, 0xb9, 0xb6, 0x7a, 0xca, 0x54, 0x53, 0xe9, 0xea, 0x2a, 0x5b, 0x6d, 0x95, 0xa9, 0xaf, 0x32,
		0x35, 0x56, 0xa1, 0xce, 0xeb, 0xa9, 0xf5, 0x9a, 0xea, 0x2d, 0x8f, 0x6c, 0x7d, 0x01, 0x3b, 0xda,
		0x52, 0x55, 0xf4, 0x89, 0xf7, 0x2c, 0x4a, 0xb8, 0x56, 0x35, 0x98, 0xa4, 0xb9, 0x65, 0x75, 0x20,
		0xbf, 0xc6, 0x2b, 0xb3, 0xbc, 0xe1, 0xed, 0x81, 0x3d, 0xd1, 0x95, 0x35, 0x2a, 0x05, 0x16, 0xde,
		0xd9, 0xd3, 0xcb, 0xc2, 0xa4, 0xc2, 0xa4, 0xc2, 0xa4, 0x12, 0x32, 0xa9, 0x73, 0xea, 0x29, 0xd3,
		0x98, 0x1e, 0x49, 0xb8, 0x56, 0xd3, 0x8d, 0x63, 0x11, 0x06, 0x52, 0xda, 0x38, 0x24, 0x17, 0xdc,
		0xde, 0x7e, 0xff, 0xe3, 0x22, 0x67, 0x97, 0x5d, 0xfb, 0xba, 0x62, 0x7f, 0xec, 0x7c, 0xcf, 0xfd,
		0x5e, 0x7c, 0xd8, 0x79, 0xbf, 0xb3, 0xfd, 0xfc, 0x67, 0xef, 0x77, 0xbe, 0xe7, 0x7e, 0x2f, 0x3d,
		0x6c, 0x6f, 0xbf, 0xf0, 0x7f, 0xfe, 0x78, 0xe9, 0x1a, 0x3b, 0x3f, 0xb6, 0xb7, 0xb7, 0x0b, 0xa5,
		0x8b, 0x9c, 0x5d, 0xea, 0xfc, 0x28, 0x5c, 0xe4, 0xec, 0x62, 0x67, 0xfc, 0x6f, 0x3a, 0x3f, 0x2e,
		0x72, 0xf9, 0xce, 0x1f, 0xc9, 0xc7, 0xc9, 0x9f, 0x3b, 0x97, 0x97, 0xbb, 0x3b, 0xdf, 0xf7, 0x1f,
		0xde, 0xf6, 0x8f, 0x77, 0x76, 0xb6, 0xf7, 0x26, 0x6b, 0xe8, 0xec, 0xfc, 0x98, 0x7c, 0xff, 0x5e,
		0x78, 0xd8, 0xf9, 0xb1, 0x9d, 0xbf, 0xc8, 0xd9, 0xf9, 0xce, 0xec, 0x7f, 0xe4, 0xc7, 0x17, 0x39,
		0x1a, 0xff, 0x73, 0x59, 0x0a, 0xb9, 0xbd, 0x7d, 0xf1, 0xbf, 0xef, 0x3b, 0x7f, 0x7f, 0xbf, 0xf3,
		0xfd, 0xe0, 0x61, 0xf6, 0x39, 0xf9, 0x73, 0xe7, 0xc7, 0xf6, 0xee, 0x6f, 0x97, 0x97, 0xbb, 0xbb,
		0xbf, 0xed, 0x4c, 0x1e, 0x7a, 0xfa, 0xef, 0x7e, 0x9b, 0xfc, 0xdf, 0x3f, 0xde, 0xbf, 0x5f, 0xf8,
		0xd1, 0xce, 0xf6, 0xde, 0xee, 0xdf, 0x77, 0xd6, 0x57, 0xbc, 0x4e, 0xa6, 0x8a, 0xb7, 0xd2, 0xc9,
		0xda, 0xab, 0x57, 0x5b, 0xf9, 0xc4, 0xed, 0xf5, 0x2b, 0x4a, 0x3c, 0x89, 0x7b, 0xf5, 0x26, 0x2b,
		0x9d, 0xd0, 0xd1, 0x02, 0x39, 0xfe, 0xa0, 0xeb, 0xfa, 0xb6, 0xd7, 0x93, 0x87, 0x6f, 0xd2, 0x2b,
		0x02, 0xda, 0x00, 0xda, 0x00, 0xda, 0x50, 0x8a, 0x16, 0xe3, 0xf0, 0xd7, 0x67, 0xab, 0xcb, 0xa1,
		0x1a, 0x86, 0x16, 0xaf, 0x3f, 0xf4, 0x23, 0xdb, 0x77, 0xaf, 0x84, 0x6f, 0x5f, 0xf9, 0x83, 0xee,
		0x37, 0x89, 0xa1, 0xdd, 0xe2, 0xa5, 0x61, 0x03, 0x61, 0x03, 0x61, 0x03, 0x09, 0xd9, 0xc0, 0xd5,
		0xe7, 0x66, 0xbf, 0x6a, 0x04, 0x0f, 0xe5, 0x84, 0x76, 0xb3, 0xb9, 0xda, 0xf3, 0xff, 0x8d, 0x0d,
		0xca, 0xde, 0x8d, 0x3f, 0xb8, 0x72, 0xfd, 0xbd, 0x50, 0x44, 0x22, 0xbc, 0x15, 0xbd, 0x27, 0x06,
		0xe6, 0xc5, 0x9f, 0x4e, 0x47, 0x73, 0xa7, 0x40, 0x0c, 0x81, 0x02, 0x02, 0x85, 0x35, 0x7e, 0x73,
		0xd5, 0x53, 0xad, 0x35, 0x13, 0x60, 0xd3, 0xeb, 0xc8, 0x4d, 0x81, 0x7b, 0x96, 0x69, 0xb6, 0x97,
		0xa4, 0x0a, 0x25, 0x7f, 0xae, 0xd4, 0x71, 0x7b, 0xf5, 0xad, 0x5d, 0xa5, 0x7c, 0x62, 0xed, 0x68,
		0x4d, 0x56, 0x94, 0x66, 0x5a, 0xb9, 0x03, 0x8e, 0xd8, 0xb5, 0x23, 0x0c, 0xae, 0x85, 0x0e, 0xeb,
		0x23, 0x08, 0x19, 0xc8, 0x61, 0x1e, 0x31, 0xc8, 0x70, 0xf7, 0x7a, 0xec, 0xd7, 0x6a, 0x93, 0x04,
		0x5e, 0x08, 0x64, 0x97, 0x9f, 0x28, 0xb0, 0xb0, 0xf9, 0xeb, 0x5a, 0xae, 0x02, 0x2c, 0x17, 0x2c,
		0x97, 0x06, 0xcb, 0x85, 0xe4, 0x20, 0x50, 0x1d, 0xa0, 0x3a, 0x40, 0x75, 0x2c, 0xef, 0x25, 0x91,
		0x1c, 0xa4, 0xec, 0x95, 0x21, 0x39, 0x08, 0x26, 0x15, 0x26, 0x75, 0xe3, 0x4c, 0x2a, 0x92, 0x83,
		0x90, 0x1c, 0xf4, 0xc2, 0x46, 0x21, 0x39, 0xe8, 0xe9, 0x8e, 0x80, 0xf3, 0x47, 0x72, 0xd0, 0x2b,
		0xe4, 0x19, 0x92, 0x83, 0x00, 0x6d, 0x00, 0x6d, 0x90, 0x1c, 0x44, 0xd4, 0xe2, 0x21, 0x39, 0x08,
		0x36, 0x10, 0x36, 0x70, 0x53, 0x6d, 0x20, 0x92, 0x83, 0x10, 0x28, 0x20, 0x50, 0x58, 0xe1, 0x11,
		0x22, 0xef, 0xbf, 0x12, 0x0f, 0x96, 0x92, 0xab, 0xc1, 0x39, 0xc2, 0x39, 0xc2, 0x39, 0x12, 0x72,
		0x8e, 0x6b, 0x0f, 0x4b, 0x78, 0xae, 0x9b, 0x32, 0x5c, 0xa3, 0x9c, 0xe1, 0x09, 0xb3, 0x2f, 0x39,
		0xe2, 0xbf, 0x25, 0x7b, 0x98, 0x82, 0x64, 0xa3, 0xb6, 0x70, 0x59, 0xc9, 0xc3, 0x15, 0xd2, 0xeb,
		0x2a, 0x68, 0xec, 0x2f, 0x49, 0x3d, 0x9e, 0x3b, 0x79, 0x76, 0xaf, 0x4a, 0xf6, 0x10, 0x06, 0x2d,
		0xef, 0xec, 0x1d, 0x8d, 0xab, 0x74, 0x18, 0x02, 0xac, 0x51, 0x24, 0x24, 0xb2, 0xb0, 0xc9, 0xd5,
		0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0,
		0x0c, 0x00, 0x58, 0x28, 0x6f, 0xfb, 0x59, 0x79, 0xdb, 0x0a, 0x93, 0x1e, 0x56, 0xdf, 0x59, 0xb5,
		0xfd, 0x69, 0xa7, 0x93, 0x20, 0x56, 0xcc, 0x26, 0x58, 0x8f, 0x76, 0x5e, 0x9f, 0x66, 0x56, 0x42,
		0x2b, 0xaf, 0x47, 0x23, 0xf3, 0x1e, 0x6e, 0xf2, 0xba, 0xd0, 0x5b, 0x2b, 0x15, 0x29, 0xfd, 0x6c,
		0xa0, 0xc4, 0xf9, 0xe4, 0x5e, 0xad, 0xc9, 0xad, 0x9c, 0xf3, 0xf1, 0x4d, 0x58, 0x4c, 0x4f, 0xa1,
		0x31, 0xf1, 0xe3, 0xc5, 0x57, 0x25, 0x6d, 0x34, 0xc7, 0xef, 0x6f, 0x99, 0x28, 0xe0, 0xaf, 0x36,
		0x51, 0xc0, 0xc7, 0x44, 0x01, 0xad, 0x31, 0xea, 0x66, 0x4f, 0x14, 0xf0, 0xd7, 0x9a, 0x28, 0xe0,
		0x63, 0xa2, 0x80, 0x42, 0x3a, 0x06, 0x13, 0x05, 0x30, 0x51, 0x40, 0x2f, 0xcb, 0x89, 0xa2, 0xe1,
		0x4c, 0xd8, 0x4b, 0x14, 0x0d, 0xa3, 0x68, 0x58, 0xb7, 0x9a, 0x4a, 0x57, 0x57, 0xd9, 0x6a, 0xab,
		0x4c, 0x7d, 0x95, 0xa9, 0xb1, 0x0a, 0x75, 0x96, 0xc3, 0x96, 0xa1, 0x68, 0x78, 0xe9, 0x6b, 0x19,
		0x52, 0x34, 0xac, 0xa4, 0x64, 0x18, 0xe6, 0x14, 0xe6, 0x14, 0xe6, 0x94, 0x92, 0x39, 0x45, 0xc1,
		0x30, 0x0a, 0x86, 0x5f, 0xd8, 0x28, 0xe3, 0x0a, 0x86, 0x51, 0x9e, 0x0a, 0x47, 0x0a, 0x47, 0x0a,
		0x47, 0xaa, 0x2e, 0x2e, 0x41, 0x79, 0xea, 0x0b, 0xe5, 0xa9, 0xea, 0xaa, 0x53, 0x61, 0x01, 0x61,
		0x01, 0x61, 0x01, 0x29, 0x59, 0x40, 0x14, 0xa7, 0xea, 0x33, 0xd1, 0x48, 0x24, 0x7b, 0x21, 0x51,
		0xc3, 0x4f, 0x72, 0x6a, 0x7c, 0xf4, 0x49, 0xd7, 0xe7, 0x07, 0x71, 0x70, 0xa8, 0xc5, 0xbf, 0xe1,
		0xe0, 0x50, 0x9e, 0xdf, 0x42, 0x9f, 0x74, 0x09, 0xf6, 0x0b, 0x7d, 0xd2, 0x61, 0xb9, 0x60, 0xb9,
		0x96, 0x5b, 0x38, 0x52, 0x1e, 0x10, 0x58, 0x23, 0xb0, 0x46, 0x60, 0xbd, 0xbc, 0x97, 0x44, 0xca,
		0x83, 0x3a, 0xc6, 0x12, 0x29, 0x0f, 0x30, 0xa7, 0x30, 0xa7, 0x9b, 0x64, 0x4e, 0x91, 0xf2, 0x80,
		0x94, 0x87, 0x17, 0x36, 0x0a, 0x29, 0x0f, 0x32, 0xdc, 0x29, 0x52, 0x1e, 0xe0, 0x48, 0xe1, 0x48,
		0x37, 0x24, 0x2e, 0x41, 0xca, 0x03, 0x52, 0x1e, 0x60, 0x01, 0x61, 0x01, 0x37, 0xd6, 0x02, 0x22,
		0xe5, 0x41, 0x9f, 0x89, 0x46, 0xca, 0xc3, 0xcf, 0x52, 0x1e, 0xd0, 0x3b, 0x67, 0xf6, 0xeb, 0xe8,
		0x9d, 0xb3, 0xee, 0x0b, 0xa0, 0xde, 0x3b, 0x67, 0x26, 0xf4, 0x1a, 0x7a, 0xe7, 0xf8, 0xe8, 0x9d,
		0xb3, 0xee, 0xab, 0xd2, 0xd9, 0x3b, 0x27, 0x16, 0xf6, 0x70, 0xe0, 0x7b, 0x5d, 0x4f, 0xac, 0xd0,
		0x41, 0x67, 0xfe, 0x97, 0x15, 0xf7, 0xd1, 0x29, 0xe8, 0xea, 0xa3, 0xb3, 0x54, 0x76, 0x85, 0x49,
		0x9d, 0x74, 0x96, 0x71, 0x86, 0x19, 0xf7, 0xd2, 0x99, 0xc9, 0xdd, 0xfd, 0xea, 0x0d, 0x75, 0x1e,
		0x2f, 0xb1, 0x29, 0x5d, 0x75, 0x56, 0x4a, 0x1b, 0xda, 0x84, 0xbe, 0x3a, 0xab, 0xa0, 0x40, 0xaa,
		0x9d, 0x75, 0xdc, 0xa0, 0xe7, 0xf5, 0xdc, 0xb1, 0x70, 0xbb, 0xf1, 0xd7, 0x48, 0x42, 0x8b, 0x9d,
		0x67, 0x17, 0x44, 0xaf, 0x9d, 0x35, 0x94, 0x49, 0x36, 0x53, 0xc2, 0x31, 0xf5, 0x6c, 0xd5, 0x90,
		0x6b, 0x8b, 0x5f, 0xf2, 0xd9, 0x53, 0xdd, 0x91, 0x47, 0x72, 0x3e, 0xbb, 0xae, 0x1c, 0x8a, 0x33,
		0x6f, 0x3c, 0xc5, 0x19, 0x0b, 0x90, 0x9c, 0x4a, 0x48, 0xce, 0x75, 0x54, 0x9a, 0x06, 0xcd, 0xb9,
		0xae, 0xaa, 0xa7, 0x17, 0xea, 0x79, 0x51, 0x37, 0xf4, 0xfa, 0xff, 0x3f, 0x7b, 0xef, 0xde, 0xd3,
		0x38, 0x92, 0xbd, 0x8f, 0xff, 0xcf, 0xab, 0x40, 0xd6, 0xae, 0x04, 0xbb, 0x6d, 0x48, 0x42, 0x80,
		0x06, 0xe9, 0xa3, 0x51, 0x1a, 0xd2, 0xbd, 0xf9, 0x0d, 0x37, 0x41, 0x76, 0x66, 0x47, 0x74, 0x06,
		0x99, 0xa4, 0x42, 0x5b, 0x63, 0xec, 0xac, 0xed, 0xf4, 0x76, 0xff, 0xba, 0x79, 0xef, 0x5f, 0xc5,
		0x71, 0x9c, 0xab, 0x13, 0x57, 0xd5, 0x29, 0xdf, 0xf2, 0x8c, 0x56, 0xbd, 0x01, 0xe2, 0xb2, 0x5d,
		0x75, 0x2e, 0xcf, 0x79, 0xea, 0xd4, 0x39, 0xa6, 0x6d, 0xf8, 0x8e, 0x4b, 0x27, 0x24, 0x51, 0xda,
		0xe9, 0xdc, 0xf0, 0x44, 0xeb, 0x49, 0x5b, 0x75, 0x9d, 0xcc, 0x10, 0xa8, 0x30, 0x08, 0x0a, 0x0d,
		0x83, 0x2a, 0x03, 0xa1, 0xdc, 0x50, 0x28, 0x37, 0x18, 0x6a, 0x0d, 0x07, 0x8d, 0x01, 0x21, 0x32,
		0x24, 0xd1, 0xab, 0x92, 0xed, 0x9b, 0x2c, 0x49, 0x2c, 0xdd, 0xfe, 0xc9, 0x12, 0x02, 0x38, 0x25,
		0x1c, 0x73, 0xe9, 0x88, 0xce, 0xbc, 0xe9, 0xca, 0x49, 0x57, 0x03, 0x82, 0xe5, 0xd6, 0x1c, 0xd7,
		0x7c, 0x19, 0xbf, 0x95, 0x6e, 0xf4, 0x7a, 0x0a, 0x8c, 0xfe, 0xe2, 0x0d, 0x60, 0xf6, 0x61, 0xf6,
		0x61, 0xf6, 0x61, 0xf6, 0x0b, 0x61, 0xf6, 0x17, 0x8d, 0x57, 0x49, 0x0d, 0xbf, 0x67, 0xab, 0xb5,
		0xfb, 0x9e, 0x0d, 0xb3, 0x0f, 0xb3, 0x0f, 0xb3, 0x0f, 0xb3, 0x5f, 0x3c, 0xb3, 0xef, 0xd9, 0x65,
		0xb2, 0xfa, 0x03, 0xd7, 0xf1, 0x9d, 0xae, 0x63, 0xe9, 0xe3, 0x57, 0xa4, 0x37, 0xfb, 0x8b, 0x37,
		0x80, 0xdd, 0x87, 0xdd, 0x87, 0xdd, 0x87, 0xdd, 0x2f, 0x84, 0xdd, 0x5f, 0x34, 0x5e, 0x25, 0x32,
		0xfc, 0x93, 0x4c, 0x2d, 0xcb, 0xf4, 0x7c, 0x8f, 0xde, 0xec, 0xcf, 0x0f, 0x4f, 0x6b, 0xf4, 0xab,
		0x30, 0xfa, 0x30, 0xfa, 0x30, 0xfa, 0x34, 0x32, 0x4b, 0xb5, 0x57, 0xb8, 0xd2, 0xb0, 0xd0, 0xcb,
		0xd6, 0x2a, 0xfb, 0x42, 0x2d, 0x5e, 0xb4, 0x66, 0x46, 0x99, 0xb9, 0x51, 0x69, 0x76, 0x52, 0x30,
		0x3f, 0xaa, 0xcd, 0x50, 0x6a, 0xe6, 0x28, 0x35, 0xb3, 0x94, 0x8e, 0x79, 0xa2, 0x35, 0x53, 0xc4,
		0xe6, 0x4a, 0x99, 0xd9, 0x8a, 0x06, 0x26, 0x38, 0xb8, 0xbe, 0x51, 0x99, 0xa4, 0x8f, 0xb2, 0xa7,
		0x14, 0x16, 0xa7, 0x66, 0xc2, 0xd2, 0x30, 0x65, 0x29, 0x9a, 0xb4, 0xb4, 0x4c, 0x5b, 0xea, 0x26,
		0x2e, 0x75, 0x53, 0x97, 0xae, 0xc9, 0x53, 0x63, 0xfa, 0x14, 0x99, 0x40, 0x75, 0x61, 0x7b, 0x8a,
		0x61, 0x7c, 0x1a, 0x61, 0xfd, 0xe6, 0x30, 0x5f, 0xf6, 0x4c, 0x6b, 0x7a, 0x72, 0xa4, 0x40, 0x86,
		0x34, 0x9b, 0x7d, 0xf3, 0xf5, 0x2f, 0xce, 0xc0, 0x53, 0xef, 0xf8, 0xa6, 0xb7, 0x52, 0xeb, 0xff,
		0xaa, 0xf0, 0x7f, 0xf0, 0x7f, 0xf0, 0x7f, 0xdb, 0xe1, 0xff, 0x54, 0x85, 0x02, 0x4b, 0x06, 0x52,
		0xbd, 0x1c, 0x2f, 0xda, 0x49, 0xd5, 0x62, 0xac, 0xd6, 0x5c, 0xa6, 0x66, 0x36, 0xd3, 0x34, 0x9f,
		0x19, 0x98, 0xd1, 0xb4, 0xcd, 0x69, 0x66, 0x66, 0x35, 0x33, 0xf3, 0x9a, 0x8d, 0x99, 0x55, 0x6b,
		0x6e, 0x15, 0x9b, 0xdd, 0xd4, 0xcc, 0xef, 0x94, 0x99, 0xb1, 0x7b, 0xec, 0x5b, 0x7a, 0xc2, 0x1f,
		0x91, 0x35, 0xc1, 0x6d, 0x53, 0x92, 0x3f, 0xb5, 0xfc, 0x4d, 0x66, 0x86, 0x39, 0x0b, 0x03, 0x9d,
		0xa1, 0xa1, 0xce, 0xca, 0x60, 0x67, 0x6e, 0xb8, 0x33, 0x37, 0xe0, 0xd9, 0x1a, 0xf2, 0x74, 0x0c,
		0x7a, 0x4a, 0x86, 0x3d, 0x3d, 0x7e, 0x29, 0x43, 0xbe, 0x29, 0x0b, 0xfe, 0x29, 0x01, 0x1f, 0x15,
		0xb8, 0x9c, 0x9d, 0x72, 0x88, 0x6a, 0x0a, 0x62, 0xaa, 0x99, 0xb6, 0xcf, 0xdc, 0xbe, 0xd1, 0x65,
		0xfa, 0x48, 0x5c, 0x32, 0x80, 0x08, 0xb3, 0xb7, 0x4f, 0x17, 0x2a, 0x54, 0x01, 0x15, 0x94, 0x40,
		0x05, 0xb3, 0x0f, 0xa0, 0xb0, 0x85, 0x40, 0xc1, 0xec, 0x03, 0x26, 0xe4, 0x3b, 0x0e, 0x8c, 0x6e,
		0x28, 0xd7, 0x81, 0x4e, 0xda, 0x46, 0xc8, 0x74, 0xae, 0x2b, 0x88, 0xd1, 0x5f, 0x36, 0xfe, 0xb5,
		0x94, 0x6f, 0x9c, 0x81, 0x13, 0xc8, 0xdc, 0x19, 0x64, 0xed, 0x14, 0x72, 0xe3, 0x1c, 0x72, 0xe3,
		0x24, 0xf2, 0xe0, 0x2c, 0xd2, 0x75, 0x1a, 0x29, 0x3b, 0x8f, 0xcc, 0x9c, 0xc8, 0x72, 0x04, 0x91,
		0x9d, 0xba, 0x2d, 0x45, 0x13, 0x59, 0xa9, 0x5b, 0xba, 0x24, 0x64, 0xe6, 0x91, 0x46, 0x9e, 0x9c,
		0x4e, 0x6e, 0x9c, 0x4f, 0x5e, 0x9c, 0x50, 0xee, 0x9c, 0x51, 0xee, 0x9c, 0x52, 0x9e, 0x9c, 0x53,
		0x36, 0x4e, 0x2a, 0x23, 0x67, 0x15, 0x4d, 0x7c, 0xea, 0x04, 0x69, 0xac, 0xb5, 0x48, 0x9f, 0x30,
		0x8d, 0x8d, 0x50, 0x4e, 0x33, 0x7c, 0x86, 0xbb, 0xa8, 0x9a, 0xf9, 0x48, 0x0d, 0xce, 0x23, 0x87,
		0xea, 0x2d, 0xfe, 0x22, 0xfc, 0x39, 0x28, 0x06, 0xbf, 0xb3, 0x1d, 0x8a, 0x92, 0x81, 0x92, 0x68,
		0xde, 0xf0, 0x39, 0x47, 0xf8, 0x6a, 0xee, 0x69, 0x00, 0xb1, 0x00, 0xb1, 0x00, 0xb1, 0x00, 0xb1,
		0x00, 0xb1, 0x00, 0xb1, 0x00, 0xb1, 0x14, 0x40, 0xac, 0xc7, 0x29, 0xc4, 0xfa, 0xbf, 0xee, 0xd0,
		0x75, 0x99, 0xed, 0xef, 0xed, 0x1f, 0x1e, 0x1c, 0x1c, 0x46, 0xdf, 0xe8, 0x84, 0x97, 0xcc, 0xfa,
		0x65, 0x6f, 0xc5, 0xef, 0xa2, 0x91, 0x53, 0xdb, 0x1c, 0xcf, 0x01, 0x5a, 0x2b, 0x35, 0xdb, 0x47,
		0xd4, 0x63, 0x4d, 0x1c, 0x97, 0x2a, 0xed, 0x7d, 0x34, 0xd3, 0x4d, 0x28, 0xfa, 0xfc, 0xfd, 0x70,
		0xa1, 0x03, 0xc5, 0xc2, 0xcf, 0x87, 0x73, 0x75, 0x33, 0xe6, 0x7e, 0x3a, 0x8c, 0x0e, 0xcf, 0x44,
		0x9f, 0x0e, 0xe7, 0x12, 0x0f, 0x64, 0x3a, 0xc0, 0xe5, 0x5f, 0x3e, 0xcb, 0xb5, 0x59, 0x9a, 0x91,
		0xe4, 0x97, 0x4c, 0xe2, 0xd3, 0xcc, 0xd0, 0xe0, 0x6a, 0x1b, 0xd7, 0x66, 0x77, 0xc1, 0xbb, 0x3f,
		0x5d, 0x4c, 0xde, 0x75, 0xe4, 0x2f, 0x27, 0xdf, 0xba, 0x32, 0x3d, 0xff, 0xe9, 0x86, 0x7d, 0xf3,
		0xff, 0xe5, 0x0c, 0x9e, 0x5a, 0x93, 0x17, 0xba, 0x67, 0x7d, 0xa4, 0x7c, 0xf1, 0xac, 0x47, 0x9a,
		0xbb, 0xff, 0x99, 0xec, 0xfa, 0x67, 0x96, 0xe2, 0x55, 0x43, 0x36, 0x78, 0x89, 0xe2, 0x7c, 0x24,
		0x79, 0x21, 0x1b, 0x9c, 0x6e, 0x2a, 0x53, 0x4f, 0xf3, 0xea, 0x3a, 0xc3, 0x91, 0x8b, 0xf4, 0xb2,
		0xcb, 0xf4, 0x8a, 0x9e, 0x60, 0xcb, 0x92, 0xbd, 0x2a, 0xdb, 0x99, 0xec, 0x95, 0xb2, 0x5b, 0xc8,
		0xda, 0x3d, 0xe4, 0xc6, 0x4d, 0xe4, 0xc6, 0x5d, 0xe4, 0xc3, 0x6d, 0x6c, 0x07, 0x05, 0x94, 0x59,
		0xc2, 0x97, 0x33, 0xf4, 0x75, 0xcb, 0x78, 0x66, 0x16, 0xeb, 0xe9, 0x4e, 0xd7, 0x67, 0xbe, 0x97,
		0xfd, 0xce, 0xe4, 0x8a, 0x67, 0xc2, 0xfe, 0x64, 0x26, 0x0f, 0x90, 0xb3, 0xfd, 0xc9, 0x8c, 0x5c,
		0x52, 0x5e, 0x5c, 0x53, 0xee, 0x5c, 0x54, 0xee, 0x5c, 0x55, 0xbe, 0x5c, 0x56, 0x36, 0xae, 0x2b,
		0x23, 0x17, 0x16, 0x4d, 0x7d, 0x7e, 0xf6, 0x28, 0xc3, 0x80, 0xe5, 0xa4, 0x9e, 0x83, 0x5d, 0xca,
		0xf7, 0x19, 0x3e, 0xc2, 0xbd, 0x61, 0xbf, 0x8c, 0x26, 0xe4, 0x31, 0x53, 0x9d, 0xcc, 0xd6, 0x66,
		0x06, 0x13, 0x71, 0x6d, 0xda, 0x99, 0x1b, 0xef, 0x9c, 0x60, 0x8b, 0xa5, 0xc7, 0xf9, 0xcd, 0xb0,
		0x86, 0x2c, 0x47, 0xcf, 0xf3, 0xd1, 0x35, 0xba, 0xbe, 0xe9, 0xd8, 0x97, 0xe6, 0x8b, 0x19, 0x80,
		0xd2, 0x4a, 0xe6, 0xcf, 0xf5, 0xf6, 0x2e, 0x07, 0x22, 0x6c, 0x7c, 0x83, 0x08, 0x6f, 0x10, 0xe1,
		0xea, 0xfb, 0x7a, 0xfd, 0xe4, 0xb4, 0x5e, 0xaf, 0x9c, 0x1e, 0x9d, 0x56, 0xce, 0x8e, 0x8f, 0xab,
		0x27, 0xd5, 0x63, 0x48, 0x75, 0xbe, 0xd0, 0x49, 0xf6, 0x77, 0xef, 0x20, 0xd3, 0x39, 0x15, 0x56,
		0x61, 0xf0, 0x57, 0xde, 0x38, 0x85, 0xe0, 0x89, 0xc0, 0x28, 0x80, 0x51, 0x00, 0xa3, 0x00, 0x46,
		0x01, 0x8c, 0x02, 0x18, 0x05, 0x30, 0x0a, 0x60, 0x14, 0xc0, 0x28, 0x80, 0x51, 0x00, 0xa3, 0x00,
		0x11, 0x06, 0xa3, 0x00, 0x46, 0x01, 0x8c, 0x42, 0x2e, 0x19, 0x85, 0x3c, 0xe5, 0x27, 0x20, 0x2f,
		0x01, 0x2c, 0x02, 0x58, 0x04, 0xb0, 0x08, 0x60, 0x11, 0xc0, 0x22, 0x80, 0x45, 0x00, 0x8b, 0x00,
		0x16, 0x01, 0x2c, 0x02, 0x58, 0x04, 0x88, 0x30, 0x58, 0x04, 0xb0, 0x08, 0x60, 0x11, 0xf2, 0xcc,
		0x22, 0xe4, 0x27, 0x1f, 0x01, 0x79, 0x08, 0x60, 0x10, 0xc0, 0x20, 0x80, 0x41, 0x00, 0x83, 0x00,
		0x06, 0x01, 0x0c, 0x02, 0x18, 0x04, 0x30, 0x08, 0x60, 0x10, 0xc0, 0x20, 0x40, 0x84, 0xc1, 0x20,
		0x80, 0x41, 0x00, 0x83, 0x90, 0xb7, 0x3b, 0xa2, 0x2a, 0x68, 0xc1, 0x6a, 0x24, 0x8e, 0x9b, 0xc8,
		0x66, 0x54, 0xb5, 0x68, 0x57, 0x65, 0xb1, 0xc4, 0x8b, 0xc9, 0x3b, 0x95, 0xb5, 0xc8, 0x69, 0x8a,
		0xd5, 0xe8, 0x98, 0xdd, 0x35, 0x06, 0xde, 0xd0, 0x1a, 0x09, 0xd9, 0x17, 0x66, 0xf4, 0x98, 0x9b,
		0x5d, 0x85, 0xad, 0x15, 0xcf, 0x92, 0x4d, 0xad, 0xad, 0x0a, 0x6a, 0x6d, 0xa5, 0xb7, 0xea, 0x4e,
		0x57, 0x37, 0xfa, 0x3e, 0x4a, 0x6d, 0xa1, 0xd4, 0xd6, 0x12, 0xbb, 0x37, 0x92, 0x0b, 0xc0, 0x2a,
		0xd2, 0x19, 0xce, 0x8c, 0xc4, 0x5b, 0x61, 0xe5, 0x4d, 0xc7, 0x0e, 0xed, 0xbc, 0xee, 0x8f, 0x1e,
		0x2b, 0x03, 0x13, 0x30, 0x29, 0xae, 0x58, 0xcf, 0xe0, 0xde, 0x4d, 0x7b, 0xf8, 0x3a, 0x5a, 0x8a,
		0x37, 0xc0, 0x18, 0xe9, 0xb9, 0x1c, 0xb7, 0x83, 0xc8, 0x0c, 0xb9, 0x8c, 0x6f, 0x0f, 0xb0, 0x02,
		0xb0, 0x02, 0xb0, 0x02, 0xb0, 0x02, 0xb0, 0x52, 0x1a, 0xb0, 0x32, 0x34, 0x6d, 0x3f, 0x93, 0x6d,
		0xc6, 0x0c, 0xb7, 0x17, 0x33, 0xde, 0x56, 0xcc, 0x70, 0x7f, 0x39, 0x0f, 0xdb, 0x88, 0x39, 0xd9,
		0x7b, 0xc9, 0xcb, 0xb6, 0x61, 0x9e, 0x36, 0x56, 0x32, 0xdc, 0x26, 0xcc, 0xc5, 0xf6, 0x60, 0xde,
		0x44, 0x33, 0x7f, 0xdb, 0x81, 0xb9, 0x92, 0xd6, 0x2d, 0xd9, 0x06, 0xeb, 0x20, 0x7c, 0x96, 0x0f,
		0x9f, 0x07, 0xba, 0xd1, 0xeb, 0xb9, 0xcc, 0xcb, 0xb0, 0xbf, 0xc6, 0xcc, 0x33, 0x20, 0x90, 0x46,
		0x20, 0x8d, 0x40, 0x1a, 0x81, 0x34, 0x02, 0xe9, 0xd2, 0x04, 0xd2, 0x99, 0x59, 0xf7, 0x59, 0x0b,
		0x5f, 0x3d, 0xcb, 0xe0, 0xde, 0xe1, 0xdc, 0x6f, 0x5d, 0x30, 0x3d, 0x5d, 0xf9, 0xaf, 0xf5, 0x0c,
		0xd7, 0x7e, 0x49, 0x06, 0xde, 0x67, 0xdb, 0x2f, 0xdb, 0x67, 0xae, 0x9d, 0x79, 0xca, 0xb6, 0xf6,
		0xe7, 0xde, 0xde, 0x63, 0x45, 0x3f, 0xeb, 0xfc, 0x7c, 0xac, 0xea, 0x67, 0x9d, 0xf1, 0xc7, 0x6a,
		0xf0, 0x7f, 0xe3, 0xcf, 0xb5, 0xc7, 0x8a, 0x5e, 0x9f, 0x7c, 0x3e, 0x7e, 0xac, 0xe8, 0xc7, 0x9d,
		0xfd, 0xcf, 0x9f, 0x0f, 0xf6, 0x7f, 0x1c, 0xbd, 0xf1, 0x5f, 0xf8, 0xb7, 0xec, 0x4e, 0x68, 0x74,
		0xb2, 0x5c, 0xec, 0xdb, 0x87, 0xd6, 0x7f, 0xb0, 0xe2, 0xa5, 0x0e, 0x07, 0x33, 0xa6, 0x86, 0xf2,
		0x61, 0xde, 0x4f, 0x60, 0xde, 0xf3, 0x69, 0xde, 0x0d, 0xbd, 0xdf, 0xd0, 0x3f, 0x76, 0x7e, 0x54,
		0xdf, 0xd5, 0xdf, 0xce, 0xf7, 0x7f, 0x9c, 0xbe, 0x2d, 0xfe, 0xf2, 0xe7, 0xaa, 0xaf, 0x55, 0xdf,
		0x9d, 0xbe, 0x9d, 0xc7, 0xfc, 0xe5, 0xe4, 0xed, 0x3c, 0xe1, 0x18, 0xc7, 0x6f, 0x7b, 0x4b, 0x5f,
		0x1d, 0xfd, 0xbe, 0x16, 0x77, 0x41, 0x3d, 0xe6, 0x82, 0xa3, 0xb8, 0x0b, 0x8e, 0x62, 0x2e, 0x88,
		0x7d, 0xa4, 0x5a, 0xcc, 0x05, 0xc7, 0x6f, 0x3f, 0x97, 0xbe, 0xbf, 0xb7, 0xfa, 0xab, 0x27, 0x6f,
		0xfb, 0x3f, 0xe3, 0xfe, 0x76, 0xfa, 0xf6, 0xf3, 0x7c, 0x1f, 0xce, 0x0e, 0xf2, 0x0f, 0xf9, 0xdf,
		0x2a, 0xd7, 0x0f, 0xc6, 0xbb, 0x78, 0x20, 0x4a, 0x7b, 0x35, 0xba, 0xd9, 0x53, 0xde, 0xb3, 0x0f,
		0x01, 0xce, 0x5b, 0xad, 0x7f, 0x02, 0xe7, 0x0d, 0xce, 0x1b, 0x9c, 0x77, 0x86, 0x9e, 0x6b, 0xfb,
		0x38, 0xef, 0xec, 0xcc, 0x7b, 0xd6, 0x11, 0x71, 0xe6, 0x91, 0xb0, 0xf6, 0xe7, 0x2c, 0x42, 0x5d,
		0x04, 0xbe, 0xb5, 0xb7, 0xfd, 0x1f, 0xc7, 0x6f, 0x19, 0x20, 0xd5, 0x4e, 0x16, 0x4b, 0x91, 0x87,
		0xc8, 0x2c, 0xaf, 0xeb, 0x01, 0x24, 0x2d, 0xbd, 0xb2, 0x8e, 0x6b, 0xbe, 0x98, 0xb6, 0x3e, 0x70,
		0x1d, 0xdf, 0xe9, 0x3a, 0x56, 0x76, 0x68, 0x7a, 0xf1, 0x41, 0x80, 0xa8, 0x81, 0xa8, 0x81, 0xa8,
		0x81, 0xa8, 0x81, 0xa8, 0x4b, 0x83, 0xa8, 0xcd, 0x1e, 0xb3, 0x7d, 0xd3, 0xff, 0xee, 0xb2, 0x7e,
		0x96, 0x88, 0x3a, 0x83, 0x2c, 0x63, 0xad, 0x15, 0xbe, 0xfa, 0x07, 0xc3, 0x63, 0xd9, 0xd7, 0x6f,
		0x6d, 0xdd, 0x3c, 0xb4, 0x1b, 0x57, 0x57, 0x4f, 0x77, 0xf7, 0xb7, 0xed, 0xdb, 0x8b, 0xdb, 0xab,
		0xa7, 0xf6, 0x1f, 0x77, 0xcd, 0xac, 0x4c, 0x50, 0x90, 0x0f, 0xee, 0x65, 0xba, 0xeb, 0x90, 0x71,
		0x62, 0xfe, 0x64, 0x59, 0xee, 0x5a, 0xd7, 0xda, 0x36, 0x1e, 0x8f, 0xc8, 0xc9, 0xf4, 0xb7, 0x3e,
		0x5d, 0xdf, 0x61, 0xfe, 0xb3, 0x9b, 0xff, 0xcb, 0xd6, 0x7d, 0xf3, 0xa2, 0x7d, 0xf5, 0xc7, 0xd3,
		0xc5, 0xed, 0xcd, 0x4d, 0xf3, 0xa2, 0xdd, 0xbc, 0xc4, 0x6a, 0x64, 0xb7, 0x1a, 0xb7, 0x0f, 0x77,
		0x1f, 0x8f, 0xb0, 0x00, 0xd9, 0x2d, 0xc0, 0x43, 0xbb, 0xd1, 0x6e, 0x5d, 0x60, 0x05, 0x32, 0x74,
		0x08, 0x0f, 0xad, 0x07, 0xcc, 0x7f, 0x76, 0xf3, 0xff, 0xe1, 0x13, 0xfc, 0x71, 0xc6, 0x1e, 0x00,
		0xf3, 0x9f, 0xdd, 0xfc, 0x5f, 0xdd, 0x5e, 0x34, 0xae, 0x9e, 0x1a, 0x9f, 0x3e, 0xdd, 0x37, 0x3f,
		0x35, 0xda, 0xcd, 0x6d, 0x2b, 0x94, 0xdf, 0x29, 0x3b, 0xff, 0x53, 0xca, 0xfd, 0x84, 0xc1, 0xd0,
		0xfb, 0xc2, 0x7a, 0xfa, 0xeb, 0xc0, 0xf2, 0x74, 0xcb, 0x78, 0x66, 0x96, 0xee, 0xf9, 0x46, 0xf7,
		0xaf, 0xec, 0xf6, 0x15, 0xe2, 0x1e, 0x08, 0xfb, 0x0b, 0x4a, 0x6f, 0x8c, 0xfd, 0x05, 0xec, 0x2f,
		0x60, 0x7f, 0x21, 0x53, 0xff, 0xb2, 0x7d, 0x19, 0x3b, 0x91, 0x8d, 0xc7, 0x29, 0xd5, 0xad, 0x80,
		0xcb, 0x73, 0x85, 0xbe, 0x8e, 0x6a, 0x39, 0x38, 0xc0, 0x74, 0x8a, 0x7e, 0x42, 0xe8, 0x27, 0x94,
		0x03, 0xe0, 0x17, 0xfb, 0x38, 0x51, 0xf5, 0xa5, 0x13, 0xb4, 0x5e, 0xc9, 0x21, 0xf5, 0x30, 0x95,
		0x61, 0x34, 0x14, 0xda, 0x2c, 0xc3, 0x95, 0xfa, 0xfb, 0xe3, 0x53, 0xf4, 0x10, 0xca, 0x19, 0x71,
		0x93, 0xfd, 0xdd, 0x71, 0x8a, 0x3c, 0x5d, 0xf8, 0xc5, 0xec, 0xe1, 0x2b, 0x73, 0xc7, 0xed, 0x7e,
		0x72, 0x70, 0x88, 0xbc, 0x9e, 0xe1, 0x33, 0x64, 0x53, 0x16, 0x3e, 0x3b, 0x95, 0xeb, 0x94, 0x3a,
		0xa6, 0xbd, 0x32, 0x3d, 0xbf, 0xe1, 0xfb, 0x6e, 0x36, 0x71, 0xed, 0xb5, 0x69, 0x37, 0x2d, 0xf6,
		0xca, 0xec, 0xb1, 0x3b, 0xc9, 0x20, 0xae, 0xbc, 0x36, 0xbe, 0xcd, 0x3c, 0x41, 0x3e, 0x2a, 0x76,
		0x6a, 0xb7, 0x6e, 0x8f, 0xb9, 0xac, 0xf7, 0xe1, 0x7b, 0xf6, 0x89, 0x74, 0x43, 0x2f, 0xf5, 0x2e,
		0x47, 0xd1, 0x33, 0xe4, 0xa0, 0xeb, 0xf5, 0x2c, 0xcf, 0xe8, 0x8c, 0x57, 0x45, 0x7f, 0xfe, 0x9e,
		0xa5, 0x0b, 0xc8, 0x53, 0xc7, 0xeb, 0x39, 0xce, 0x31, 0x90, 0x14, 0xb4, 0x36, 0x2c, 0xf4, 0xdd,
		0xd2, 0xb9, 0x53, 0x4a, 0x3e, 0x2e, 0xab, 0x16, 0x8d, 0x25, 0x69, 0xcd, 0x98, 0x8e, 0x2e, 0xab,
		0x97, 0x38, 0xb5, 0x77, 0x50, 0x2c, 0xcb, 0x23, 0xff, 0x93, 0x56, 0x03, 0x9f, 0x74, 0xb1, 0x60,
		0xfa, 0xd8, 0x2f, 0x17, 0x58, 0x6f, 0x0e, 0xdb, 0xd9, 0x43, 0xcb, 0x2a, 0xb4, 0x74, 0xa6, 0x6c,
		0x61, 0x0b, 0x6f, 0x59, 0x53, 0x00, 0x8e, 0xaa, 0xba, 0xda, 0xaa, 0x75, 0x07, 0xea, 0x8c, 0xb4,
		0x9a, 0x91, 0x15, 0x29, 0x56, 0x5a, 0x0a, 0x55, 0x54, 0x45, 0x52, 0x23, 0x84, 0xf4, 0x22, 0xa2,
		0x40, 0x3c, 0x34, 0xcf, 0xec, 0xa9, 0x2b, 0x05, 0x15, 0xc5, 0xfb, 0xc1, 0x5d, 0x14, 0x09, 0xf7,
		0x84, 0xbd, 0x54, 0x34, 0xbc, 0xea, 0x4c, 0xb0, 0x34, 0x32, 0xbe, 0x66, 0x33, 0xbb, 0x3c, 0xd7,
		0x57, 0xd9, 0x73, 0x34, 0x2d, 0x7a, 0x25, 0xf5, 0x54, 0xad, 0xd4, 0x29, 0x92, 0xc5, 0xd4, 0xab,
		0x60, 0xe1, 0xe0, 0xd0, 0x82, 0xa9, 0xb9, 0x34, 0x5d, 0xc5, 0x9e, 0xcc, 0xec, 0xa9, 0x17, 0xe1,
		0x19, 0xeb, 0xa8, 0x5a, 0x78, 0xd5, 0x1a, 0xc9, 0xd4, 0x8c, 0x65, 0x9a, 0x46, 0x33, 0x03, 0xe3,
		0x99, 0xb6, 0x11, 0xcd, 0xcc, 0x98, 0x66, 0x66, 0x54, 0xb3, 0x31, 0xae, 0xe5, 0x20, 0x8d, 0x54,
		0x1b, 0xdd, 0xe8, 0x46, 0xe9, 0xb6, 0xb5, 0xce, 0xa4, 0x9d, 0x75, 0xca, 0xa9, 0x41, 0xa9, 0x9f,
		0x67, 0xc8, 0xe2, 0x1c, 0x43, 0x06, 0x86, 0x3a, 0x2b, 0x83, 0x9d, 0xb9, 0xe1, 0xce, 0xdc, 0x80,
		0x67, 0x6b, 0xc8, 0xd3, 0x31, 0xe8, 0x29, 0x19, 0xf6, 0x68, 0x2a, 0x53, 0x3f, 0x89, 0x10, 0x69,
		0xac, 0xc5, 0x8c, 0x7e, 0xba, 0xd5, 0x8d, 0x22, 0x44, 0x9c, 0x62, 0xe6, 0xb9, 0x76, 0x17, 0x32,
		0x63, 0x07, 0x07, 0xe3, 0xcd, 0xb0, 0xc3, 0xb1, 0xcb, 0x29, 0xcb, 0x96, 0x58, 0x2a, 0x34, 0xb4,
		0xe1, 0xb3, 0xf4, 0xa1, 0xc1, 0xf8, 0xb6, 0xe9, 0x42, 0x83, 0x6a, 0xda, 0xd0, 0xa0, 0x06, 0x68,
		0x00, 0x68, 0x00, 0x68, 0x00, 0x68, 0x90, 0x61, 0xec, 0x97, 0x51, 0x0c, 0x98, 0x69, 0x2c, 0x98,
		0x51, 0x4c, 0x98, 0x59, 0x6c, 0x98, 0xa5, 0x23, 0xc8, 0x81, 0x43, 0xc8, 0xda, 0x31, 0xe4, 0xc6,
		0x41, 0xe4, 0xc6, 0x51, 0xe4, 0xc3, 0x61, 0xa4, 0xeb, 0x38, 0x52, 0x76, 0x20, 0xd9, 0xc5, 0x98,
		0x4b, 0x1a, 0x3f, 0x34, 0x6d, 0xff, 0xa4, 0x9e, 0xe1, 0x49, 0xf7, 0x2c, 0x3a, 0x53, 0x64, 0x7b,
		0xc6, 0x39, 0xc3, 0x4c, 0xfb, 0x3c, 0x9c, 0x69, 0xce, 0xc9, 0x39, 0xd0, 0xe8, 0xfc, 0x67, 0xd6,
		0xcf, 0x91, 0xa3, 0x13, 0x9f, 0x19, 0x1e, 0x59, 0xce, 0xc5, 0x51, 0xe5, 0xbc, 0x89, 0x66, 0x3e,
		0x8e, 0x4a, 0xe5, 0x56, 0x5a, 0x71, 0x38, 0xb2, 0xd0, 0xef, 0x97, 0x6a, 0xab, 0xc7, 0x81, 0xe5,
		0xe9, 0x7e, 0x37, 0xc3, 0x36, 0x8f, 0xe1, 0x03, 0xa4, 0x0c, 0x30, 0x2f, 0x59, 0xdf, 0x18, 0x5a,
		0x01, 0x84, 0xaf, 0x20, 0x80, 0x47, 0x00, 0x8f, 0x00, 0x1e, 0x01, 0x3c, 0x02, 0xf8, 0xb2, 0x05,
		0xf0, 0xef, 0x33, 0x8c, 0xdf, 0x8f, 0x11, 0xbf, 0x23, 0x7e, 0x47, 0xfc, 0x8e, 0xf8, 0x1d, 0xf1,
		0xfb, 0x92, 0x68, 0x9e, 0x42, 0x34, 0x11, 0xac, 0x23, 0x58, 0x17, 0x0b, 0xd6, 0x7d, 0x2b, 0xeb,
		0x68, 0xdd, 0xb7, 0x10, 0xae, 0x23, 0x5c, 0x47, 0xb8, 0x8e, 0x70, 0x1d, 0xe1, 0x3a, 0xc2, 0x75,
		0x84, 0xeb, 0x08, 0xd7, 0x11, 0xae, 0x23, 0x5c, 0x47, 0xb8, 0x5e, 0x56, 0xd1, 0xac, 0x1d, 0x63,
		0x77, 0x1d, 0x01, 0x3b, 0x02, 0x76, 0x6e, 0xb1, 0xfd, 0x1a, 0x2a, 0x50, 0x46, 0xd1, 0xfa, 0xf8,
		0xf6, 0x08, 0x97, 0x11, 0x2e, 0x23, 0x5c, 0x46, 0xb8, 0x8c, 0x70, 0xb9, 0x44, 0xe1, 0xb2, 0xe7,
		0xea, 0x9e, 0xd9, 0xd3, 0xfd, 0xd1, 0x83, 0xa0, 0x1b, 0xdb, 0x56, 0x04, 0xcd, 0xb9, 0xe8, 0xc3,
		0x97, 0x07, 0x09, 0xc8, 0x87, 0x24, 0x64, 0x2f, 0x11, 0x4b, 0x92, 0x91, 0x79, 0x9f, 0xbe, 0x45,
		0xe9, 0x38, 0xcd, 0xc1, 0xa3, 0xe4, 0xa3, 0x6f, 0x5f, 0x7e, 0xa4, 0x65, 0xca, 0x74, 0xe4, 0xa8,
		0x8f, 0x5f, 0xce, 0x98, 0x8f, 0x58, 0x26, 0x24, 0x2f, 0x7d, 0xfd, 0xf2, 0x48, 0x8c, 0x64, 0x0c,
		0xca, 0xd6, 0xcb, 0x7a, 0x8e, 0xfa, 0xfd, 0x15, 0x46, 0xd6, 0xf3, 0xd4, 0xff, 0xaf, 0x10, 0x02,
		0xbf, 0x83, 0xa7, 0xd8, 0xcd, 0xac, 0x3f, 0x60, 0x4e, 0xcc, 0x4e, 0x8e, 0xe0, 0x60, 0x3e, 0xfa,
		0x06, 0x2e, 0x45, 0x0c, 0xf5, 0x1c, 0x3c, 0x4b, 0xb6, 0x7d, 0x04, 0xb3, 0x57, 0x55, 0xb4, 0xf0,
		0x4c, 0x57, 0x15, 0xcd, 0xc1, 0xd7, 0x13, 0xdd, 0xe8, 0xf5, 0x5c, 0xe6, 0x79, 0x79, 0x88, 0xda,
		0xdf, 0x67, 0xf8, 0x0c, 0x77, 0x86, 0xef, 0x33, 0xd7, 0xce, 0x3c, 0x24, 0xd3, 0xfe, 0xdc, 0xdb,
		0x7b, 0xac, 0xe8, 0x67, 0x86, 0xde, 0x6f, 0xe8, 0x1f, 0x3b, 0x3f, 0xaa, 0xef, 0xea, 0x6f, 0xe7,
		0xfb, 0x3f, 0x4e, 0xdf, 0x16, 0x7f, 0xf9, 0x73, 0xd5, 0xd7, 0xaa, 0xef, 0x4e, 0xdf, 0xce, 0x63,
		0xfe, 0x72, 0xf2, 0x76, 0x9e, 0x70, 0x8c, 0xe3, 0xb7, 0xbd, 0xa5, 0xaf, 0x8e, 0x7e, 0x5f, 0x8b,
		0xbb, 0xa0, 0x1e, 0x73, 0xc1, 0x51, 0xdc, 0x05, 0x47, 0x31, 0x17, 0xc4, 0x3e, 0x52, 0x2d, 0xe6,
		0x82, 0xe3, 0xb7, 0x9f, 0x4b, 0xdf, 0xdf, 0x5b, 0xfd, 0xd5, 0x93, 0xb7, 0xfd, 0x9f, 0x71, 0x7f,
		0x3b, 0x7d, 0xfb, 0x79, 0xbe, 0xbf, 0xff, 0x37, 0x2d, 0x3b, 0xd3, 0x97, 0xa5, 0xe8, 0xdf, 0x3e,
		0xb4, 0xfe, 0x03, 0xf9, 0x87, 0xfc, 0x67, 0x29, 0xff, 0xc8, 0x5f, 0x28, 0xf4, 0xfb, 0xa1, 0x4d,
		0x26, 0xc5, 0x7d, 0x8b, 0xd5, 0x83, 0xca, 0x33, 0x7b, 0xde, 0xe8, 0x1f, 0x34, 0xc7, 0xcc, 0x8d,
		0x04, 0xa3, 0x39, 0x26, 0xe5, 0x1d, 0xd1, 0x1c, 0xb3, 0xd8, 0x76, 0xb5, 0xa0, 0xf6, 0xb4, 0x88,
		0x2d, 0x31, 0x1f, 0xcc, 0x1e, 0xda, 0x61, 0xa6, 0xa0, 0x4a, 0x68, 0x87, 0x19, 0xab, 0x3a, 0x5b,
		0xdd, 0x09, 0x53, 0x69, 0x6b, 0x81, 0x54, 0x5a, 0x09, 0xa4, 0xd6, 0x0b, 0xb3, 0x86, 0x5e, 0x98,
		0x49, 0x6e, 0x85, 0x5e, 0x98, 0x64, 0x26, 0x1b, 0xbd, 0x30, 0xe3, 0xa6, 0x46, 0x79, 0x2f, 0xcc,
		0xae, 0x33, 0xb4, 0x7d, 0xe6, 0x7a, 0xe9, 0x35, 0xc4, 0x8c, 0xee, 0x88, 0xae, 0x98, 0x79, 0x33,
		0x9f, 0x19, 0x98, 0xd1, 0xb4, 0xcd, 0x69, 0x66, 0x66, 0x35, 0x33, 0xf3, 0x9a, 0x8d, 0x99, 0x2d,
		0x07, 0x5b, 0x94, 0x5a, 0x57, 0x4c, 0x67, 0xe8, 0x8f, 0x93, 0xc3, 0x59, 0x4f, 0x77, 0xba, 0x3e,
		0xf3, 0xbd, 0xf4, 0xfb, 0x60, 0xad, 0x78, 0x06, 0xf4, 0xcb, 0x2c, 0x9a, 0xe9, 0xce, 0xd0, 0x84,
		0x67, 0x65, 0xca, 0x33, 0x37, 0xe9, 0x99, 0x9b, 0xf6, 0x6c, 0x4d, 0x7c, 0x3a, 0xa6, 0x3e, 0x25,
		0x93, 0x1f, 0x4d, 0x65, 0x76, 0xfd, 0x32, 0x43, 0x80, 0x9c, 0x6a, 0x1b, 0x93, 0x0c, 0xda, 0x97,
		0x64, 0x74, 0xc4, 0x23, 0x83, 0xd3, 0x7f, 0x59, 0x1e, 0xd9, 0xc8, 0x38, 0x5d, 0x3d, 0xeb, 0x3a,
		0x29, 0x79, 0x48, 0x3c, 0xcf, 0x20, 0x7f, 0x32, 0xd3, 0x93, 0x13, 0x79, 0x11, 0xb9, 0xfc, 0xb4,
		0x1b, 0xc9, 0x85, 0x14, 0x96, 0x34, 0xb1, 0xa6, 0x83, 0x06, 0xcb, 0x42, 0x51, 0xe6, 0xe0, 0xaf,
		0xac, 0x63, 0xcc, 0xe0, 0x09, 0x10, 0x61, 0x22, 0xc2, 0x44, 0x84, 0x89, 0x08, 0x13, 0x11, 0x26,
		0x22, 0x4c, 0x44, 0x98, 0x88, 0x30, 0x11, 0x61, 0x22, 0xc2, 0x44, 0x84, 0x89, 0x08, 0x13, 0x11,
		0x66, 0x61, 0x23, 0xcc, 0x2c, 0xf7, 0x2f, 0xb1, 0x6f, 0x89, 0xa8, 0x12, 0x51, 0x25, 0xa2, 0x4a,
		0x44, 0x95, 0x88, 0x2a, 0x11, 0x55, 0x22, 0xaa, 0x44, 0x54, 0x89, 0xa8, 0x12, 0x51, 0x25, 0xa2,
		0x4a, 0x44, 0x95, 0x45, 0x8f, 0x2a, 0xb3, 0xdb, 0xaf, 0xc4, 0x3e, 0x25, 0x22, 0x4a, 0x44, 0x94,
		0x88, 0x28, 0x11, 0x51, 0x22, 0xa2, 0x44, 0x44, 0x89, 0x88, 0x12, 0x11, 0x25, 0x22, 0x4a, 0x44,
		0x94, 0x88, 0x28, 0x11, 0x51, 0x16, 0xf1, 0x0e, 0x28, 0xe1, 0x94, 0x69, 0x1d, 0x1a, 0xdf, 0xf0,
		0xd9, 0x61, 0x4a, 0x25, 0x00, 0x76, 0x55, 0x14, 0x72, 0xba, 0x98, 0x3c, 0x7b, 0x51, 0xab, 0x39,
		0x29, 0x2c, 0x89, 0x62, 0xf6, 0xd2, 0x2b, 0x23, 0xa1, 0xbc, 0x0c, 0x58, 0x4a, 0xce, 0x1b, 0x05,
		0x24, 0x8a, 0xc9, 0xb5, 0xa0, 0x80, 0x04, 0x0a, 0x48, 0xe4, 0x88, 0x3b, 0x49, 0xbf, 0x9b, 0x5c,
		0x8a, 0xdd, 0xe2, 0x52, 0x26, 0x48, 0x52, 0x64, 0xba, 0xb2, 0x20, 0x44, 0xb2, 0xea, 0xf5, 0x9c,
		0x11, 0x01, 0x92, 0x65, 0xc8, 0x99, 0x66, 0xd7, 0xf2, 0x2c, 0x88, 0x8e, 0xac, 0x45, 0xa9, 0x5e,
		0x3b, 0xab, 0x9f, 0x9d, 0x9c, 0xd6, 0xce, 0x8e, 0xb7, 0x48, 0xa6, 0x4a, 0x12, 0xe6, 0x77, 0x10,
		0x40, 0x2d, 0x07, 0x50, 0xf6, 0x57, 0xc3, 0x32, 0x7b, 0xba, 0xcb, 0x0c, 0x2f, 0x05, 0x02, 0x61,
		0x1a, 0x4c, 0xcd, 0xdf, 0x17, 0x81, 0x15, 0x02, 0x2b, 0x04, 0x56, 0x08, 0xac, 0x10, 0x58, 0xcd,
		0xf5, 0xee, 0xf7, 0x99, 0x3e, 0x31, 0x94, 0x9e, 0x95, 0x8e, 0xad, 0xdc, 0x4d, 0xb9, 0x05, 0x63,
		0x4a, 0x2d, 0x16, 0x8b, 0xe9, 0x9d, 0x83, 0xa5, 0x4f, 0xcf, 0x29, 0x8f, 0x6f, 0x07, 0x5f, 0x0c,
		0x5f, 0x0c, 0x5f, 0x0c, 0x5f, 0x0c, 0x5f, 0x3c, 0xa3, 0x71, 0xcf, 0x8e, 0x63, 0x31, 0x23, 0x55,
		0xe7, 0x5b, 0x85, 0x43, 0x5c, 0x9a, 0x9b, 0xff, 0x31, 0xf3, 0xe5, 0x8b, 0x9f, 0x9e, 0x47, 0x0c,
		0xef, 0x07, 0x97, 0x08, 0x97, 0x08, 0x97, 0x08, 0x97, 0x08, 0x97, 0x88, 0x7d, 0x3f, 0xca, 0xff,
		0xb0, 0xef, 0xa7, 0xe4, 0xb6, 0xd8, 0xf7, 0x53, 0x2b, 0x4a, 0xd8, 0xf7, 0xdb, 0x0e, 0x99, 0xc2,
		0xbe, 0x5f, 0xb6, 0x81, 0x14, 0xda, 0x60, 0xae, 0xb8, 0x4f, 0x01, 0xd3, 0x8f, 0x0b, 0xd3, 0x07,
		0x73, 0x27, 0xc7, 0x82, 0x16, 0x35, 0xd2, 0xa6, 0x66, 0xa8, 0xd5, 0x76, 0xcd, 0x56, 0xdf, 0x25,
		0x3b, 0x93, 0xae, 0xd8, 0x6a, 0xbb, 0x60, 0x53, 0x8b, 0x8e, 0x62, 0xdb, 0x54, 0x2c, 0x9b, 0xa4,
		0x29, 0xe9, 0x76, 0x4b, 0x7a, 0xe6, 0x81, 0xd6, 0x60, 0xd2, 0x99, 0x35, 0x9a, 0x91, 0x88, 0xa4,
		0x5b, 0x95, 0x54, 0xe7, 0x5e, 0x9a, 0x69, 0xa4, 0x43, 0x7e, 0x2d, 0x09, 0xd6, 0x91, 0xb8, 0x4d,
		0xb4, 0x92, 0xb6, 0xd0, 0xc4, 0x7d, 0x4d, 0xc9, 0xdb, 0x3e, 0xab, 0xa0, 0x9b, 0x15, 0xd2, 0xca,
		0xaa, 0xe8, 0x63, 0xe5, 0x34, 0xb1, 0x72, 0x3a, 0x58, 0x2d, 0xed, 0x9b, 0x2f, 0xdb, 0x4d, 0xdd,
		0xe7, 0x53, 0x33, 0xba, 0xbe, 0xf9, 0x55, 0x81, 0x54, 0x4d, 0x14, 0x21, 0x1c, 0x9f, 0x1a, 0xd3,
		0x2b, 0x61, 0x75, 0x94, 0xed, 0x74, 0xa9, 0xdc, 0xd9, 0x4a, 0x61, 0x27, 0x4b, 0xf5, 0xce, 0x55,
		0x6a, 0x3b, 0x55, 0xa9, 0xed, 0x4c, 0xa5, 0xb3, 0x13, 0x95, 0xef, 0xb8, 0x5b, 0xd9, 0xce, 0x52,
		0x0a, 0xc9, 0x15, 0x8a, 0x92, 0x29, 0x08, 0x23, 0x8a, 0x77, 0xd4, 0x2e, 0x40, 0xf7, 0x4c, 0xbb,
		0xab, 0xdc, 0x11, 0x84, 0x77, 0x81, 0x3b, 0x80, 0x3b, 0x80, 0x3b, 0x80, 0x3b, 0x20, 0x95, 0x78,
		0xdf, 0x7c, 0x65, 0xbe, 0xd9, 0xfd, 0xcb, 0x53, 0x52, 0x86, 0x4d, 0x61, 0xb9, 0x35, 0xed, 0xdf,
		0xf6, 0x78, 0x8f, 0x4e, 0xb3, 0x0d, 0xdb, 0xf1, 0x58, 0xd7, 0xb1, 0x7b, 0x2a, 0x4a, 0x8e, 0x28,
		0xce, 0x52, 0x50, 0xb8, 0x79, 0x93, 0x46, 0x16, 0x42, 0x5a, 0xe9, 0x74, 0x29, 0x65, 0x19, 0xa4,
		0xb9, 0x03, 0xac, 0x32, 0x75, 0x33, 0x8d, 0xac, 0x81, 0xb4, 0x97, 0x3e, 0xfd, 0x32, 0x67, 0xa9,
		0x4a, 0x43, 0x41, 0xb6, 0x2d, 0x3b, 0xdb, 0x83, 0xed, 0x7d, 0xd7, 0xb0, 0x3d, 0x73, 0xb4, 0xfe,
		0x9e, 0x72, 0x84, 0x3f, 0x7b, 0x2f, 0xe0, 0x7c, 0xe0, 0x7c, 0xe0, 0x7c, 0xe0, 0x7c, 0x52, 0x89,
		0x57, 0x59, 0x6c, 0x59, 0x25, 0xca, 0x07, 0xfa, 0x06, 0xfa, 0x06, 0xfa, 0x06, 0xfa, 0x06, 0xfa,
		0xde, 0x16, 0xf4, 0xdd, 0x33, 0xbd, 0xae, 0x6b, 0xbe, 0x9a, 0xb6, 0xe1, 0x3b, 0xae, 0x3a, 0xe0,
		0x3d, 0x7f, 0x1b, 0x60, 0x6e, 0x60, 0x6e, 0x60, 0x6e, 0x60, 0x6e, 0x52, 0x89, 0x57, 0x76, 0x68,
		0x4f, 0xe1, 0x21, 0x3d, 0x00, 0x6e, 0x00, 0x6e, 0x00, 0xee, 0x1c, 0x2c, 0x7d, 0x5a, 0x87, 0xe0,
		0x00, 0xb3, 0xb7, 0x13, 0x66, 0x33, 0xdb, 0x1a, 0xa8, 0x43, 0xd7, 0xc1, 0xe8, 0x00, 0xd5, 0x00,
		0xd5, 0x00, 0xd5, 0x00, 0xd5, 0xe4, 0x96, 0x45, 0xf7, 0x47, 0xb7, 0x51, 0x98, 0xc1, 0xa8, 0xa0,
		0x16, 0xa3, 0xa2, 0xda, 0x8b, 0xf9, 0x74, 0x2e, 0xe1, 0xe1, 0x34, 0x45, 0xce, 0x25, 0x18, 0x1d,
		0xce, 0x05, 0xce, 0x05, 0xce, 0x05, 0xce, 0x85, 0x54, 0xe2, 0x3d, 0xdf, 0x35, 0xed, 0x17, 0x95,
		0x9e, 0xe5, 0xfd, 0x16, 0x58, 0x7f, 0xc7, 0x35, 0x5f, 0xc6, 0xbc, 0xba, 0x6e, 0xf4, 0x7a, 0x0a,
		0x39, 0xfc, 0xc5, 0x1b, 0xc1, 0x27, 0xc0, 0x27, 0xc0, 0x27, 0xc0, 0x27, 0x90, 0x4a, 0xbc, 0x39,
		0xf8, 0x7a, 0x12, 0x98, 0x17, 0xe6, 0x79, 0x4a, 0x3d, 0x83, 0x82, 0xb1, 0xef, 0x0c, 0xdf, 0x67,
		0xae, 0xad, 0x8c, 0xce, 0xd7, 0xfe, 0xdc, 0xdb, 0x7b, 0xac, 0xe8, 0x67, 0x86, 0xde, 0x6f, 0xe8,
		0x1f, 0x3b, 0x3f, 0xaa, 0xef, 0xea, 0x6f, 0xe7, 0xfb, 0x3f, 0x4e, 0xdf, 0x16, 0x7f, 0xf9, 0x73,
		0xd5, 0xd7, 0xaa, 0xef, 0x4e, 0xdf, 0xce, 0x63, 0xfe, 0x72, 0xf2, 0x76, 0x9e, 0x70, 0x8c, 0xe3,
		0xb7, 0xbd, 0xa5, 0xaf, 0x8e, 0x7e, 0x5f, 0x8b, 0xbb, 0xa0, 0x1e, 0x73, 0xc1, 0x51, 0xdc, 0x05,
		0x47, 0x31, 0x17, 0xc4, 0x3e, 0x52, 0x2d, 0xe6, 0x82, 0xe3, 0xb7, 0x9f, 0x4b, 0xdf, 0xdf, 0x5b,
		0xfd, 0xd5, 0x93, 0xb7, 0xfd, 0x9f, 0x71, 0x7f, 0x3b, 0x7d, 0xfb, 0x79, 0xbe, 0xbf, 0xff, 0x37,
		0x7a, 0x55, 0xef, 0xa8, 0x10, 0xc1, 0xdb, 0x87, 0xd6, 0x7f, 0x20, 0x87, 0x90, 0x43, 0x1e, 0x39,
		0xdc, 0x32, 0x90, 0xec, 0xd9, 0xe9, 0x60, 0x64, 0xcf, 0x06, 0x44, 0x06, 0x44, 0x06, 0x44, 0x06,
		0x44, 0xa6, 0x95, 0x78, 0x24, 0xba, 0x2c, 0xfd, 0x87, 0x44, 0x97, 0x44, 0xb7, 0x41, 0xa2, 0x0b,
		0xdf, 0xd2, 0x23, 0xd1, 0xa5, 0x18, 0x32, 0x80, 0x44, 0x97, 0xdc, 0x00, 0xed, 0x11, 0x90, 0x61,
		0x2e, 0x53, 0x5a, 0xa7, 0x65, 0xe6, 0x1e, 0x00, 0xd8, 0x00, 0xd8, 0x00, 0xd8, 0x00, 0xd8, 0x00,
		0xd8, 0x00, 0xd8, 0x00, 0xd8, 0x00, 0xd8, 0x00, 0xd8, 0x00, 0xd8, 0x65, 0x07, 0xd8, 0x8e, 0xef,
		0x74, 0x1d, 0x4b, 0x1f, 0x53, 0xcd, 0x2a, 0x51, 0xf6, 0xfc, 0x8d, 0x00, 0xb5, 0x01, 0xb5, 0x01,
		0xb5, 0x01, 0xb5, 0x49, 0x25, 0x7e, 0x34, 0xab, 0x7a, 0x64, 0x69, 0x90, 0x68, 0x9e, 0x6f, 0xdf,
		0xa3, 0xa6, 0x69, 0xbf, 0xd2, 0x26, 0xfd, 0xf0, 0x33, 0xf0, 0x33, 0xf0, 0x33, 0xa8, 0xc3, 0xbe,
		0xc5, 0x75, 0xd8, 0xd1, 0xd9, 0x29, 0xa3, 0xce, 0x4e, 0x74, 0x0d, 0x12, 0x09, 0x3a, 0x3a, 0xed,
		0x64, 0xb8, 0xfa, 0x93, 0x06, 0x87, 0x0b, 0x21, 0xe5, 0xee, 0x7c, 0xb6, 0xd4, 0xee, 0xc2, 0x01,
		0x83, 0x5d, 0xca, 0xa2, 0x41, 0xb4, 0xad, 0x10, 0xe9, 0x5b, 0x1f, 0xa6, 0xd2, 0xea, 0x90, 0xb6,
		0xb5, 0xa1, 0xac, 0x50, 0x10, 0x9b, 0x82, 0x1c, 0x9a, 0x00, 0x8d, 0xa4, 0x8d, 0x9a, 0x74, 0xff,
		0x41, 0x39, 0x1b, 0x24, 0x6e, 0x39, 0xc4, 0xae, 0x14, 0x14, 0x2b, 0x2a, 0x71, 0xca, 0x83, 0x18,
		0x89, 0x2d, 0x18, 0xff, 0x74, 0x0b, 0x4c, 0xb5, 0xd6, 0x75, 0x2c, 0x89, 0x42, 0x71, 0x33, 0x15,
		0x52, 0x2d, 0x61, 0x9b, 0x2e, 0x19, 0xd3, 0x49, 0xc7, 0x6e, 0x14, 0x31, 0x1a, 0x61, 0x2c, 0x46,
		0x15, 0x73, 0x91, 0xc7, 0x56, 0xe4, 0x31, 0x14, 0x6d, 0xac, 0x94, 0xae, 0x79, 0x92, 0x8e, 0x71,
		0x22, 0x89, 0xb1, 0x98, 0xd1, 0x77, 0x59, 0x5f, 0x46, 0x62, 0x26, 0x31, 0x8b, 0xc4, 0x46, 0xb4,
		0x76, 0x17, 0x5a, 0xc8, 0x83, 0x83, 0x31, 0xd2, 0x3d, 0x1c, 0xab, 0x74, 0x8e, 0x4d, 0x17, 0xb3,
		0x7b, 0x03, 0xc7, 0x0c, 0xa4, 0x47, 0xd2, 0x7a, 0x45, 0x23, 0xc1, 0x80, 0xc1, 0x80, 0xc1, 0x80,
		0x95, 0xc4, 0x80, 0x45, 0x5a, 0x9d, 0x63, 0x1b, 0x26, 0xd7, 0x55, 0x99, 0xa4, 0x8b, 0xb2, 0x64,
		0xd7, 0x64, 0xe9, 0x2e, 0xc9, 0xb0, 0x5e, 0xb0, 0x5e, 0xdc, 0x8f, 0x2e, 0xdb, 0x95, 0x98, 0xaa,
		0x0b, 0x31, 0x6d, 0xd7, 0x61, 0xa2, 0xdd, 0x2d, 0xb2, 0xdd, 0x2c, 0xca, 0xdd, 0x2b, 0x05, 0xbb,
		0x55, 0xd4, 0xbb, 0x53, 0xca, 0x76, 0xa3, 0x94, 0xed, 0x3e, 0xa9, 0xd9, 0x6d, 0xca, 0x96, 0x5c,
		0x26, 0xdb, 0x3d, 0x52, 0xb0, 0x5b, 0x44, 0xb4, 0x3b, 0x24, 0xc1, 0xc1, 0xbd, 0x93, 0x35, 0x79,
		0x44, 0x5d, 0x77, 0x55, 0x74, 0xd9, 0x85, 0xf9, 0x83, 0xf9, 0x83, 0xf9, 0x23, 0x37, 0x7f, 0xb4,
		0x5d, 0x6a, 0x09, 0xfb, 0x55, 0xa9, 0xea, 0x42, 0x4b, 0x7c, 0x78, 0x82, 0x70, 0x5b, 0x5b, 0xc5,
		0xe1, 0x08, 0x55, 0x29, 0x51, 0x8a, 0x0e, 0x3f, 0xa8, 0x4c, 0x74, 0xa7, 0x4c, 0x8e, 0x53, 0x71,
		0x98, 0x41, 0xf5, 0x52, 0xa9, 0xef, 0x33, 0xa5, 0x74, 0xf5, 0x72, 0x92, 0x5b, 0xd1, 0x29, 0x2e,
		0xb6, 0xa3, 0xec, 0xba, 0xaa, 0xae, 0xcb, 0x2a, 0x70, 0x1e, 0x70, 0x1e, 0x70, 0x1e, 0x39, 0xce,
		0xa3, 0xec, 0x52, 0x4a, 0x89, 0xf2, 0x80, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0x80, 0xc6, 0xb6, 0x07,
		0x8d, 0x3d, 0x7b, 0x04, 0xe7, 0x6a, 0xa6, 0xf4, 0xa5, 0x27, 0x7d, 0x8c, 0x06, 0x88, 0x0b, 0x88,
		0x0b, 0x88, 0x8b, 0x1c, 0x71, 0x79, 0xae, 0xee, 0x99, 0x3d, 0xaa, 0x73, 0x8e, 0xd1, 0xe6, 0xc2,
		0x19, 0xc1, 0x58, 0xe1, 0xcb, 0xe6, 0x0e, 0x73, 0x4d, 0xa6, 0xee, 0x75, 0x60, 0x79, 0xba, 0x65,
		0x3c, 0x33, 0x8b, 0xf0, 0x10, 0x0f, 0xe5, 0x0c, 0xaa, 0x99, 0x49, 0xfa, 0x19, 0x5d, 0x9a, 0x59,
		0x94, 0xbb, 0x49, 0x61, 0xb6, 0x95, 0xc6, 0x10, 0x29, 0x01, 0xd5, 0x78, 0xe0, 0x7a, 0x82, 0x7a,
		0x37, 0x59, 0x05, 0x25, 0x99, 0xaf, 0x7d, 0xa5, 0xfe, 0xfe, 0xf8, 0x14, 0xc5, 0x6e, 0x52, 0x1f,
		0xb5, 0x93, 0xe7, 0x23, 0xbd, 0x4a, 0x5b, 0x12, 0x0e, 0x5f, 0x99, 0x3b, 0x3e, 0xe8, 0x83, 0x5a,
		0x11, 0xa4, 0xa2, 0xd5, 0xc9, 0xd3, 0x51, 0x61, 0x05, 0x18, 0x52, 0x51, 0x73, 0x19, 0x15, 0x4d,
		0x65, 0x94, 0x35, 0x93, 0x41, 0xf3, 0x8e, 0x52, 0x34, 0xef, 0xe8, 0x50, 0x8a, 0x9a, 0xca, 0xa6,
		0x31, 0x90, 0xb7, 0x72, 0xc8, 0x1b, 0xd8, 0x5d, 0x61, 0x0d, 0x90, 0x3b, 0x32, 0xbb, 0xe4, 0xc5,
		0x64, 0x8e, 0xce, 0x82, 0xdf, 0x05, 0xbf, 0x0b, 0x7e, 0x57, 0x19, 0xbf, 0x4b, 0x46, 0xa5, 0x11,
		0x52, 0x67, 0xd8, 0x4e, 0xa7, 0xa4, 0x3b, 0xb0, 0x9d, 0x5e, 0x98, 0xa5, 0x52, 0x55, 0x89, 0x19,
		0x9b, 0xe8, 0x79, 0x85, 0x59, 0x41, 0x3a, 0x93, 0x47, 0x89, 0xb4, 0xc2, 0x11, 0x69, 0xc0, 0x56,
		0x15, 0x60, 0x0b, 0x60, 0x6b, 0x5b, 0xc1, 0x96, 0xec, 0x01, 0xdc, 0x68, 0x20, 0xd3, 0x1e, 0x6f,
		0x03, 0xb3, 0x9e, 0xee, 0x74, 0x7d, 0xe6, 0x7b, 0x74, 0x82, 0x12, 0xf1, 0x84, 0x4b, 0xb7, 0x20,
		0x5a, 0x57, 0x5a, 0x8f, 0x47, 0x5e, 0x84, 0x56, 0x45, 0xf1, 0x59, 0x85, 0x45, 0x67, 0x55, 0x15,
		0x9b, 0x55, 0x5e, 0x64, 0x56, 0x79, 0x71, 0x59, 0xb5, 0x45, 0x65, 0xf3, 0x55, 0x51, 0x94, 0xbc,
		0x78, 0xac, 0x92, 0xfc, 0xe8, 0x45, 0x13, 0x40, 0xb9, 0x55, 0xa0, 0x26, 0x17, 0x42, 0xc1, 0x16,
		0x9e, 0xca, 0xdc, 0x07, 0xc5, 0xfb, 0xde, 0xaa, 0x5b, 0xfb, 0xa4, 0xb1, 0xc3, 0xad, 0x20, 0xb5,
		0x41, 0x69, 0x4a, 0x43, 0x5a, 0x4b, 0xaa, 0x3e, 0xef, 0x3a, 0xd5, 0x55, 0x2e, 0xf7, 0xe6, 0xf2,
		0x4e, 0x0e, 0xb4, 0x60, 0x16, 0x20, 0x0e, 0xfe, 0x52, 0x8c, 0x40, 0x83, 0x1b, 0x00, 0x7f, 0x02,
		0x7f, 0x02, 0x7f, 0x02, 0x7f, 0x02, 0x7f, 0x02, 0x7f, 0x02, 0x7f, 0x02, 0x7f, 0x02, 0x7f, 0x6e,
		0x3b, 0xfe, 0x54, 0xc8, 0x7d, 0x82, 0xf3, 0x04, 0xe6, 0x04, 0xe6, 0x04, 0xe6, 0x04, 0xe6, 0x04,
		0xe6, 0x04, 0xe6, 0x04, 0xe6, 0x04, 0xe6, 0x04, 0xe6, 0x0c, 0x80, 0xa1, 0x32, 0xae, 0x13, 0x1c,
		0x27, 0xf0, 0x26, 0xf0, 0x26, 0xf0, 0x26, 0xf0, 0x26, 0xf0, 0x26, 0xf0, 0x26, 0xf0, 0x26, 0xf0,
		0x26, 0xf0, 0xa6, 0x33, 0xf4, 0x95, 0x27, 0x7a, 0xae, 0xb8, 0x07, 0x50, 0x28, 0x50, 0x28, 0x50,
		0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0xa8, 0xd2,
		0x54, 0xcf, 0xa5, 0x3b, 0x00, 0x81, 0x02, 0x81, 0x02, 0x81, 0x02, 0x81, 0x02, 0x81, 0x02, 0x81,
		0x02, 0x81, 0x02, 0x81, 0x02, 0x81, 0x6e, 0x3d, 0x02, 0x55, 0xc9, 0x7f, 0x82, 0xf7, 0x04, 0xea,
		0x04, 0xea, 0x04, 0xea, 0x04, 0xea, 0x04, 0xea, 0x04, 0xea, 0x04, 0xea, 0x04, 0xea, 0x04, 0xea,
		0x1c, 0x23, 0x43, 0x75, 0x7c, 0x27, 0x78, 0x4e, 0x20, 0x4e, 0x20, 0x4e, 0x20, 0x4e, 0x20, 0x4e,
		0x20, 0x4e, 0x20, 0x4e, 0x20, 0x4e, 0x20, 0xce, 0x82, 0x23, 0xce, 0x4c, 0x4b, 0x8b, 0x36, 0x6c,
		0xdb, 0xf1, 0xc7, 0x0d, 0xa1, 0x48, 0x2a, 0x8c, 0x7a, 0xdd, 0x2f, 0xec, 0xd5, 0x18, 0x18, 0xfe,
		0x97, 0x91, 0xc7, 0x3a, 0x74, 0x06, 0xcc, 0xee, 0x06, 0xa8, 0x50, 0xb7, 0x99, 0xff, 0x3f, 0xc7,
		0xfd, 0x4b, 0x37, 0x6d, 0xcf, 0x37, 0xec, 0x2e, 0x3b, 0x5c, 0xfc, 0x85, 0xb7, 0xf4, 0x9b, 0x43,
		0x8f, 0xbd, 0x8c, 0x50, 0x83, 0xee, 0x3a, 0x43, 0xdf, 0xb4, 0x5f, 0x0e, 0x7d, 0xa6, 0x0f, 0x1c,
		0xcb, 0xec, 0x9a, 0xcc, 0x8b, 0x3e, 0x7f, 0x3f, 0xf4, 0x7c, 0xc3, 0x67, 0x87, 0x44, 0x05, 0x87,
		0xc7, 0x6f, 0xe1, 0xbb, 0xc3, 0xae, 0x6f, 0x87, 0x7e, 0xf7, 0x66, 0xfc, 0x58, 0xad, 0xf0, 0xa9,
		0x9e, 0x1e, 0xc6, 0x4f, 0x75, 0x3f, 0x7e, 0xa8, 0xa7, 0x36, 0xbb, 0x0b, 0x9e, 0xe3, 0xe9, 0x62,
		0xf2, 0x04, 0x05, 0x2c, 0x00, 0xcd, 0xec, 0xde, 0xc0, 0x31, 0x03, 0x80, 0x46, 0x54, 0x00, 0x3a,
		0x1a, 0x11, 0xdd, 0x36, 0x52, 0x8c, 0x45, 0x50, 0x00, 0x1a, 0xdd, 0x36, 0x92, 0x48, 0xdc, 0x68,
		0x56, 0xf4, 0x89, 0x8a, 0xa2, 0xa9, 0xb2, 0xc0, 0x0c, 0x9a, 0x83, 0xaf, 0x75, 0x34, 0xc4, 0x1b,
		0x37, 0x28, 0xeb, 0xfc, 0x7c, 0xac, 0xea, 0x67, 0x9d, 0xf1, 0xc7, 0x6a, 0xf0, 0x7f, 0xe3, 0xcf,
		0xb5, 0xc7, 0x8a, 0x5e, 0x9f, 0x7c, 0x3e, 0x7e, 0xac, 0xe8, 0xc7, 0x9d, 0xfd, 0xcf, 0x9f, 0x0f,
		0xf6, 0x7f, 0x1c, 0xbd, 0xf1, 0x5f, 0xb8, 0xcd, 0x2d, 0xe0, 0x8a, 0x37, 0xc3, 0xe8, 0x87, 0xb9,
		0x35, 0xea, 0x8f, 0xfe, 0x84, 0xe8, 0x87, 0x99, 0xa6, 0x31, 0x84, 0xbc, 0xa1, 0x1f, 0xe6, 0x96,
		0x36, 0x6a, 0x0a, 0x39, 0x09, 0xa2, 0x18, 0x3d, 0x18, 0x0d, 0xf1, 0x39, 0xe2, 0x73, 0xc4, 0xe7,
		0x79, 0x8b, 0xcf, 0x7d, 0xd7, 0xb4, 0x5f, 0x28, 0x63, 0xf2, 0xf7, 0x59, 0x59, 0xbb, 0x9d, 0x14,
		0x57, 0x84, 0x8a, 0xcf, 0xce, 0x8e, 0xc7, 0x16, 0x53, 0x05, 0xfe, 0x49, 0xe6, 0xbb, 0x82, 0x73,
		0x39, 0x46, 0x56, 0x29, 0x6a, 0xb7, 0xbc, 0x2b, 0xc8, 0x04, 0x6b, 0x57, 0xa6, 0xe7, 0x37, 0x7c,
		0x5f, 0xac, 0xf7, 0x99, 0x76, 0x6d, 0xda, 0x4d, 0x8b, 0x8d, 0xa6, 0xdd, 0x13, 0xf3, 0x2a, 0xda,
		0xb5, 0xf1, 0x6d, 0x66, 0x04, 0x9a, 0x5d, 0x39, 0xed, 0xd6, 0xed, 0x31, 0x97, 0xf5, 0x3e, 0x8c,
		0xe6, 0xc7, 0x1e, 0x5a, 0x96, 0xd2, 0x65, 0x90, 0xd4, 0x86, 0x2c, 0xb4, 0x40, 0xc0, 0xe4, 0x89,
		0x6d, 0xd7, 0xf0, 0x29, 0x5a, 0x72, 0x75, 0x49, 0xf6, 0xcd, 0x84, 0x2b, 0x29, 0xba, 0x82, 0xe9,
		0xad, 0x5c, 0xb2, 0x69, 0xdc, 0x3c, 0x29, 0xeb, 0xbf, 0xb1, 0x61, 0xba, 0x78, 0xa7, 0x49, 0xed,
		0xf4, 0x24, 0x10, 0x61, 0x2e, 0x91, 0x5d, 0x3f, 0xc5, 0xf1, 0x13, 0xb7, 0x66, 0xd2, 0xb4, 0xb1,
		0xaf, 0xd9, 0x34, 0x57, 0x33, 0x70, 0xc4, 0xd8, 0x08, 0x7f, 0x13, 0xb6, 0x6a, 0x9d, 0x22, 0xfd,
		0xda, 0x86, 0x2f, 0x72, 0x20, 0xf9, 0x59, 0xa4, 0x6e, 0x33, 0x7f, 0xb4, 0x32, 0x49, 0x56, 0x81,
		0x13, 0x8c, 0x0b, 0x83, 0x6d, 0x61, 0x30, 0xbd, 0x08, 0x96, 0x27, 0xef, 0xa6, 0x58, 0x9d, 0x92,
		0x36, 0x1c, 0xd5, 0x7a, 0xcc, 0xeb, 0xba, 0xe6, 0x80, 0xcb, 0x3e, 0x45, 0x6b, 0x35, 0x7b, 0x71,
		0xc2, 0xe9, 0xe0, 0x0b, 0x36, 0xb9, 0x83, 0x4a, 0x91, 0xe0, 0x51, 0x4c, 0xf4, 0x64, 0xe3, 0x41,
		0xe9, 0xb8, 0x4f, 0x3a, 0xbe, 0x13, 0x16, 0x4d, 0x35, 0x8e, 0x92, 0x3b, 0x04, 0x13, 0x0f, 0xb5,
		0x38, 0x43, 0xaa, 0x04, 0xbe, 0x2f, 0x81, 0xa9, 0x62, 0xb6, 0xf1, 0x6c, 0xb1, 0x1e, 0xbf, 0x96,
		0x4d, 0x2e, 0x84, 0x86, 0x41, 0xc3, 0x32, 0xd2, 0xb0, 0x67, 0xc7, 0xb1, 0x98, 0x61, 0x8b, 0xa8,
		0x58, 0x35, 0x7d, 0x15, 0x9b, 0xec, 0xea, 0xe9, 0x7d, 0xe3, 0xd5, 0xb4, 0x46, 0x10, 0x57, 0x54,
		0xe7, 0x96, 0x47, 0x2a, 0x89, 0x12, 0x9a, 0xba, 0x75, 0xb4, 0x9d, 0x2a, 0x18, 0xbc, 0x79, 0xe1,
		0x14, 0xd0, 0xec, 0x31, 0xdb, 0x37, 0xfd, 0xef, 0x2e, 0xeb, 0x8b, 0x28, 0x21, 0x07, 0xcf, 0xa1,
		0xb5, 0xc2, 0x5b, 0x7d, 0x30, 0x3c, 0x81, 0x05, 0x9f, 0x3c, 0x70, 0xe3, 0xf2, 0xf2, 0xbe, 0xf9,
		0xf0, 0xf0, 0xf4, 0xb1, 0x71, 0xdd, 0xba, 0xfa, 0x83, 0x77, 0xd5, 0x83, 0x44, 0x6a, 0x4f, 0x68,
		0xfb, 0x51, 0x8c, 0x32, 0x8c, 0x9e, 0xfb, 0xaa, 0xf6, 0xd4, 0x6c, 0xff, 0xab, 0x79, 0x7f, 0xd3,
		0x6c, 0xf3, 0x13, 0x79, 0x02, 0x9c, 0xa7, 0xe4, 0xe3, 0x5e, 0xdf, 0x5d, 0x3d, 0x14, 0xe1, 0x39,
		0x5b, 0x77, 0xbf, 0x9d, 0x14, 0xe4, 0x39, 0xeb, 0x9a, 0x62, 0x2a, 0xb6, 0x93, 0x91, 0xf5, 0x11,
		0x62, 0x63, 0xc5, 0x59, 0x58, 0x52, 0xf6, 0x55, 0x8c, 0x75, 0xa5, 0x41, 0x15, 0xaf, 0xfe, 0x90,
		0x1f, 0x40, 0x8c, 0x2e, 0x02, 0x60, 0x07, 0x60, 0xcf, 0x08, 0x2f, 0x0c, 0x4d, 0xdb, 0xaf, 0x9e,
		0x08, 0x40, 0x85, 0x13, 0x8e, 0x4b, 0xc4, 0x8e, 0x09, 0x8a, 0xed, 0x04, 0x09, 0x6f, 0x06, 0x4a,
		0xa6, 0x37, 0xc8, 0x1e, 0xd3, 0xa3, 0x38, 0xa0, 0xf5, 0x26, 0xb6, 0xf5, 0x95, 0xf9, 0x94, 0x9d,
		0x1c, 0x1f, 0x1f, 0x1d, 0x67, 0x38, 0x6d, 0x8a, 0xf6, 0x87, 0x3a, 0x29, 0xfa, 0x1e, 0xae, 0x6c,
		0x21, 0x91, 0xac, 0x20, 0x78, 0x1f, 0x78, 0x9f, 0x2d, 0x25, 0x64, 0x5d, 0x67, 0xe8, 0x33, 0xbd,
		0x67, 0x7a, 0xbe, 0x69, 0xbf, 0x0c, 0x4d, 0xef, 0x0b, 0x73, 0xf9, 0x55, 0x6d, 0xd5, 0x20, 0xd0,
		0x3c, 0x68, 0x5e, 0x46, 0x9a, 0x27, 0x2e, 0x8e, 0xbb, 0x82, 0xc7, 0xbf, 0xc4, 0x8e, 0x79, 0x09,
		0x80, 0x40, 0xe9, 0xc4, 0x3a, 0x99, 0x93, 0x19, 0xd2, 0x27, 0x30, 0xb4, 0x3f, 0xf7, 0x4e, 0xc6,
		0x67, 0x74, 0x1e, 0x2b, 0xfa, 0x51, 0x27, 0xf8, 0xf4, 0xf3, 0xb1, 0x3a, 0xfa, 0xb9, 0x3a, 0xfe,
		0xe5, 0xd9, 0xcc, 0x3f, 0xe3, 0x23, 0x3f, 0xbf, 0x84, 0xff, 0x2e, 0xfc, 0x7a, 0xff, 0x7c, 0xaf,
		0xfe, 0x58, 0xd1, 0x6b, 0xd1, 0xf7, 0xeb, 0xd1, 0xa7, 0x93, 0xd1, 0x3f, 0xa7, 0x9d, 0xb9, 0xbf,
		0x8e, 0xee, 0x13, 0xde, 0xf2, 0xac, 0xf3, 0xe3, 0xec, 0x6d, 0xe6, 0x38, 0xd1, 0x8f, 0xea, 0xbb,
		0xf7, 0xe1, 0xcf, 0x22, 0xe9, 0xe1, 0x1d, 0x91, 0x79, 0xa4, 0x38, 0x5e, 0x50, 0xca, 0xc9, 0x54,
		0x99, 0x47, 0xb6, 0x8d, 0xea, 0x96, 0xe2, 0xa9, 0xbb, 0x73, 0x3a, 0x71, 0x2c, 0x98, 0x1a, 0x6e,
		0xcf, 0x24, 0x43, 0x3d, 0x69, 0xd5, 0x53, 0x81, 0xd5, 0x8d, 0x95, 0x90, 0x1f, 0xb5, 0xb7, 0xf1,
		0x97, 0x8f, 0xc2, 0xaf, 0xfe, 0xa8, 0xbc, 0x0b, 0x7f, 0x55, 0x60, 0xdd, 0x2b, 0xc9, 0x0c, 0x96,
		0x80, 0xa5, 0x09, 0x50, 0xb7, 0xab, 0x9b, 0x3d, 0xc1, 0xf8, 0x31, 0xb8, 0x14, 0x51, 0x23, 0xa2,
		0xc6, 0x8c, 0xa2, 0xc6, 0x9e, 0xe3, 0xfb, 0xac, 0xa7, 0xff, 0x77, 0x68, 0xf4, 0x84, 0x48, 0x1b,
		0x8e, 0x6b, 0x44, 0xed, 0x9e, 0x96, 0x26, 0xd4, 0xd0, 0x72, 0x69, 0x65, 0x7c, 0x9e, 0xf5, 0x8d,
		0xd6, 0x96, 0xa3, 0x32, 0x0c, 0x6c, 0x0b, 0x6c, 0x0b, 0xb9, 0x6d, 0x29, 0x5c, 0xe6, 0xd2, 0x4d,
		0xb3, 0xfd, 0xfb, 0xed, 0xfd, 0xaf, 0x4f, 0xad, 0x9b, 0x87, 0x76, 0xe3, 0xe6, 0xa2, 0xf9, 0xd4,
		0xfe, 0xe3, 0xae, 0x59, 0xa4, 0x04, 0xa6, 0xab, 0xa3, 0x22, 0x64, 0xda, 0x5c, 0x36, 0x3f, 0x36,
		0xfe, 0x7d, 0xd5, 0x8e, 0xa6, 0xb9, 0x08, 0xcf, 0x7c, 0x55, 0xbb, 0xab, 0xdd, 0x15, 0xe3, 0x41,
		0x7f, 0x7b, 0x68, 0x15, 0xe2, 0x41, 0x8f, 0x7e, 0xbb, 0xff, 0x58, 0xb8, 0x84, 0xab, 0x72, 0x9f,
		0x85, 0xdb, 0x7c, 0x88, 0x59, 0xec, 0xc4, 0x9a, 0x6f, 0x3c, 0x5b, 0x4c, 0xef, 0x3a, 0xb6, 0xcd,
		0x82, 0xad, 0x7d, 0x2f, 0xf9, 0xe9, 0xb5, 0xe5, 0x4b, 0x89, 0x4f, 0xb2, 0x55, 0x70, 0x92, 0x4d,
		0x19, 0x22, 0x49, 0xe9, 0x24, 0xdb, 0xa2, 0x8c, 0x08, 0x40, 0xe5, 0xc5, 0x11, 0xf8, 0x60, 0x73,
		0x15, 0xb0, 0x19, 0xb0, 0x59, 0x4c, 0x78, 0xa3, 0x0b, 0xe6, 0xce, 0x9b, 0x7c, 0x17, 0x07, 0xb1,
		0x0b, 0xe3, 0xf0, 0x16, 0x7f, 0x10, 0xca, 0xff, 0x12, 0xae, 0x00, 0x24, 0x53, 0xf1, 0x47, 0x4e,
		0xd0, 0x65, 0x05, 0x9e, 0x4c, 0xf0, 0xc9, 0x14, 0x80, 0x4c, 0x11, 0xc4, 0xa0, 0x16, 0x6f, 0x7d,
		0x0b, 0xe1, 0xba, 0x3b, 0xd1, 0xba, 0x5b, 0xcc, 0xe8, 0xf3, 0xc5, 0x96, 0x4b, 0x76, 0xfb, 0x54,
		0x6c, 0x07, 0x24, 0x40, 0x5b, 0x07, 0x07, 0x61, 0xf5, 0xf2, 0x05, 0x8d, 0x53, 0x55, 0x9b, 0x82,
		0xc3, 0x88, 0x77, 0x27, 0xea, 0x28, 0x68, 0x43, 0xc2, 0xeb, 0xc5, 0x6c, 0x47, 0x15, 0xb6, 0x03,
		0xb6, 0x43, 0xad, 0xed, 0xe0, 0x75, 0xae, 0x54, 0x4e, 0x96, 0xd6, 0xd9, 0x4a, 0x3a, 0x5d, 0x69,
		0x05, 0xa2, 0x50, 0x24, 0x5a, 0x85, 0xa2, 0x52, 0x2c, 0x72, 0x05, 0x23, 0x57, 0x34, 0x72, 0x85,
		0x13, 0x53, 0x3c, 0x09, 0xfa, 0x67, 0x97, 0xa4, 0x78, 0x1e, 0x81, 0x33, 0xa7, 0x70, 0xea, 0xab,
		0x9c, 0x7b, 0xf4, 0xbf, 0x20, 0x38, 0xf4, 0xc6, 0xff, 0xf7, 0x38, 0x70, 0x1d, 0xdf, 0xe9, 0x3a,
		0xd6, 0xff, 0x75, 0x87, 0xae, 0xcb, 0x6c, 0x7f, 0x6f, 0x7f, 0xf4, 0x15, 0xcf, 0xed, 0xea, 0x93,
		0xbf, 0x74, 0x08, 0x60, 0x81, 0xf8, 0x6a, 0x8a, 0x9c, 0x18, 0xe9, 0xb1, 0xbe, 0x31, 0xb4, 0x7c,
		0xdd, 0x7c, 0x1d, 0x38, 0xae, 0x3f, 0x29, 0xe6, 0x25, 0x6d, 0x1c, 0x57, 0x0f, 0x2b, 0x28, 0x69,
		0x97, 0xe3, 0xc1, 0x46, 0xe3, 0xde, 0x37, 0xff, 0xbf, 0xe6, 0x45, 0xfb, 0xe9, 0xfe, 0xf6, 0xdf,
		0xed, 0x26, 0x4c, 0x6e, 0x60, 0x36, 0xdc, 0x81, 0x63, 0xc1, 0xde, 0x0a, 0xd8, 0xdb, 0x60, 0xe2,
		0xb6, 0xce, 0xd8, 0x4e, 0x34, 0x73, 0xac, 0x92, 0xb2, 0x2d, 0x44, 0x22, 0xc3, 0x5b, 0x97, 0x18,
		0xa3, 0x69, 0x0f, 0x5f, 0x47, 0x2f, 0xf7, 0x96, 0x67, 0x3b, 0x69, 0x7a, 0x01, 0x4f, 0xf8, 0xca,
		0x7c, 0xd7, 0x0c, 0x0c, 0xfe, 0xc0, 0x78, 0x91, 0x2b, 0x58, 0x3a, 0x5d, 0x92, 0xf8, 0xb1, 0xe5,
		0x2d, 0x66, 0xdf, 0xb0, 0x3c, 0x06, 0x53, 0x09, 0x74, 0x0a, 0x74, 0x2a, 0x26, 0x37, 0xfc, 0x55,
		0x90, 0x62, 0x8d, 0x64, 0x35, 0xcf, 0x06, 0xce, 0xf3, 0x23, 0x18, 0x4b, 0x60, 0xd2, 0x66, 0x47,
		0x83, 0xf1, 0x81, 0xf1, 0x81, 0xf1, 0x29, 0x73, 0x68, 0x1c, 0x86, 0xbd, 0x91, 0xc6, 0xe7, 0xd8,
		0xce, 0x11, 0x07, 0xba, 0x24, 0x01, 0x2e, 0x22, 0x52, 0x98, 0xb9, 0xed, 0x8d, 0x48, 0x73, 0x66,
		0xe3, 0x0e, 0xc3, 0x85, 0x38, 0x0f, 0xcb, 0x82, 0x4f, 0xda, 0x3c, 0x4c, 0x7e, 0x1d, 0x06, 0xce,
		0x3d, 0xd6, 0x37, 0x6d, 0x33, 0x48, 0x4b, 0x8a, 0xff, 0x53, 0xf4, 0x97, 0xa0, 0x36, 0x47, 0xaa,
		0xeb, 0x23, 0xd5, 0x85, 0x21, 0x1a, 0x45, 0xba, 0x1b, 0xc3, 0x74, 0x24, 0x05, 0x5d, 0x19, 0xa2,
		0xc1, 0x67, 0xeb, 0x84, 0x11, 0xf5, 0x58, 0x1a, 0x7a, 0x5c, 0x87, 0xe8, 0x55, 0x1a, 0xb2, 0x45,
		0x63, 0xe6, 0x8c, 0xdf, 0x56, 0x7f, 0xfe, 0x4e, 0xd1, 0x68, 0x46, 0x45, 0xc3, 0xa0, 0x39, 0xc3,
		0x16, 0xcc, 0x64, 0xb1, 0xba, 0xd8, 0xa4, 0x82, 0x44, 0x66, 0x37, 0x0e, 0xe4, 0x81, 0xc8, 0xdc,
		0x68, 0xc0, 0x21, 0x88, 0xb8, 0x10, 0x71, 0x21, 0xe2, 0xa2, 0xb7, 0x73, 0x5b, 0xd4, 0xf7, 0x68,
		0x29, 0xfd, 0x7c, 0xe9, 0x37, 0x87, 0x61, 0xb2, 0x54, 0x0e, 0xd2, 0xbe, 0xa4, 0xe8, 0x3b, 0x0a,
		0xda, 0x0e, 0xe9, 0xa3, 0x99, 0x39, 0x05, 0xa4, 0x8f, 0xa6, 0x67, 0xe4, 0x69, 0xd3, 0x47, 0xe7,
		0xf4, 0x2d, 0x07, 0x56, 0x44, 0x0a, 0x92, 0x52, 0x40, 0x51, 0x58, 0x11, 0x58, 0x11, 0x58, 0x11,
		0x4e, 0x2b, 0x32, 0xa7, 0x6f, 0x79, 0xb0, 0x22, 0x89, 0x9a, 0xd4, 0xc5, 0x9b, 0x8f, 0x04, 0x4d,
		0xeb, 0x62, 0x27, 0x54, 0xd4, 0x6e, 0xd4, 0x60, 0x37, 0x60, 0x37, 0x12, 0x3d, 0x25, 0x12, 0xd0,
		0xc1, 0xf9, 0x80, 0xf3, 0x01, 0xe7, 0x93, 0x3e, 0xe7, 0x83, 0x04, 0x74, 0x0e, 0x26, 0x03, 0x09,
		0xe8, 0x69, 0x99, 0x5c, 0x6c, 0xf7, 0x0b, 0xda, 0x5b, 0x24, 0xa0, 0x23, 0x01, 0x3d, 0xb9, 0x9d,
		0x44, 0x02, 0x3a, 0xd0, 0x29, 0xd0, 0x29, 0x12, 0xd0, 0x65, 0x8c, 0x24, 0x12, 0xd0, 0x61, 0x7c,
		0x60, 0x7c, 0x60, 0x7c, 0x4a, 0x17, 0x1a, 0x23, 0x01, 0x1d, 0x09, 0xe8, 0x88, 0x48, 0x11, 0x91,
		0x96, 0xc1, 0xc6, 0x21, 0x01, 0x7d, 0x66, 0x14, 0x24, 0xa0, 0xcb, 0x8c, 0x85, 0x04, 0x74, 0x24,
		0xa0, 0xc7, 0xcf, 0x11, 0x12, 0xd0, 0x11, 0x71, 0x21, 0xe2, 0x02, 0x1a, 0x29, 0x54, 0xc4, 0x85,
		0x04, 0xf4, 0xd9, 0x04, 0xf4, 0x04, 0x65, 0xdb, 0xc5, 0x67, 0x90, 0xb6, 0x2a, 0xf2, 0xaf, 0xec,
		0xfb, 0xa2, 0x9b, 0xd8, 0x9d, 0x65, 0xe9, 0x76, 0x85, 0xf2, 0x59, 0xc4, 0x60, 0xa6, 0x38, 0xac,
		0x24, 0x85, 0x91, 0x73, 0xb0, 0xd1, 0x1e, 0x5a, 0x16, 0xe9, 0x84, 0x0b, 0x0a, 0x73, 0xea, 0x42,
		0xac, 0x71, 0xa5, 0x16, 0xba, 0xc3, 0xae, 0x6f, 0x4f, 0x9a, 0xb6, 0x8c, 0x6f, 0xd6, 0x0a, 0xef,
		0xf5, 0xd4, 0x1e, 0x8d, 0x7c, 0x31, 0x1d, 0x18, 0x7d, 0x1d, 0x96, 0xa7, 0x5f, 0x59, 0x8f, 0x07,
		0xde, 0xc6, 0x0e, 0xe8, 0xe6, 0x80, 0x6e, 0x0e, 0x2b, 0x05, 0x49, 0xb0, 0x85, 0x03, 0xfa, 0x36,
		0xa0, 0x6f, 0x83, 0x9c, 0xc3, 0x44, 0xdf, 0x06, 0xd5, 0x41, 0x32, 0x52, 0xdf, 0x15, 0x07, 0xbf,
		0x38, 0x32, 0xb3, 0x29, 0x98, 0x45, 0xdf, 0x06, 0x71, 0x67, 0x08, 0xdb, 0x01, 0xdb, 0x21, 0x6a,
		0x3b, 0x70, 0x6c, 0x06, 0x4c, 0x35, 0x98, 0xea, 0x52, 0x31, 0xd5, 0x62, 0x4d, 0x7e, 0x63, 0x7d,
		0x90, 0xcc, 0xfe, 0xab, 0x54, 0x13, 0xe0, 0xd8, 0x17, 0x6c, 0x5c, 0x5e, 0xde, 0x37, 0x1f, 0x1e,
		0x9e, 0x3e, 0x36, 0xae, 0x5b, 0x57, 0x7f, 0xc8, 0xca, 0xa1, 0x44, 0x77, 0xe0, 0xc5, 0xff, 0xe4,
		0xb7, 0x73, 0x77, 0xe7, 0x1b, 0xc7, 0x3e, 0x35, 0xdb, 0xff, 0x6a, 0xde, 0xdf, 0x34, 0xdb, 0x9a,
		0xf4, 0xc8, 0x6f, 0xef, 0xf2, 0xf6, 0x7a, 0xd7, 0x77, 0x57, 0x0f, 0x65, 0x7c, 0xaf, 0xd6, 0xdd,
		0x6f, 0x27, 0x25, 0x7d, 0xaf, 0x3a, 0xc1, 0x7b, 0x49, 0x8d, 0xd0, 0x29, 0xe5, 0x8e, 0x3f, 0xdd,
		0x6e, 0x3f, 0x76, 0xfa, 0x81, 0x9f, 0x80, 0x9f, 0xe4, 0xe4, 0x26, 0xc7, 0x3b, 0xfd, 0x13, 0xf5,
		0xf6, 0xa2, 0x4f, 0x21, 0x71, 0x32, 0xc6, 0x7c, 0x7d, 0x53, 0x34, 0xa3, 0x0a, 0x3b, 0xfe, 0x1b,
		0x77, 0xeb, 0x26, 0x09, 0x16, 0xf9, 0x29, 0x2e, 0x27, 0x5f, 0x12, 0x0a, 0xe5, 0xa0, 0xc0, 0x4f,
		0x81, 0xdb, 0x56, 0x61, 0xc6, 0x97, 0xb9, 0x6d, 0x94, 0x82, 0x42, 0x29, 0x28, 0xd8, 0x8c, 0x34,
		0x6c, 0x06, 0x38, 0x6d, 0xc4, 0x64, 0x88, 0xc9, 0x4a, 0x15, 0x93, 0x81, 0xd3, 0xe6, 0x1a, 0x15,
		0x9c, 0x76, 0x46, 0xaf, 0x07, 0x4e, 0xbb, 0x70, 0xef, 0x05, 0x4e, 0x5b, 0xc5, 0xba, 0x81, 0xd3,
		0x06, 0x7e, 0x02, 0x7e, 0xca, 0x0d, 0x7e, 0x02, 0xa7, 0x9d, 0x7d, 0x58, 0x9a, 0x63, 0x4e, 0xbb,
		0x78, 0xe7, 0xd5, 0x70, 0x3c, 0xad, 0xfc, 0xc7, 0xd3, 0x42, 0xe9, 0x24, 0x3e, 0x88, 0x86, 0xe3,
		0x67, 0x93, 0xe9, 0x55, 0x71, 0xe6, 0xec, 0xab, 0x65, 0xd8, 0x1c, 0x47, 0xce, 0xc6, 0x5f, 0x2f,
		0xc6, 0x89, 0xb3, 0xd1, 0xb3, 0x96, 0xf2, 0xb8, 0x59, 0xf0, 0x62, 0x79, 0x39, 0x6b, 0x16, 0x3c,
		0x0c, 0xf7, 0x51, 0xb3, 0x84, 0x6b, 0xb3, 0x5b, 0x80, 0x93, 0x66, 0x1c, 0xaf, 0xb2, 0x5b, 0xaa,
		0x63, 0x66, 0xc9, 0xc4, 0x50, 0x0d, 0xaa, 0xe0, 0x3e, 0x63, 0x86, 0x73, 0x21, 0xea, 0x44, 0x9a,
		0x2a, 0x4e, 0xcd, 0xff, 0x06, 0x1a, 0x9f, 0xc8, 0xa7, 0x13, 0xa6, 0x08, 0xef, 0x9e, 0x85, 0xa8,
		0x4b, 0x92, 0xed, 0x09, 0x46, 0x01, 0xd3, 0x23, 0xa1, 0x36, 0xa0, 0x79, 0xc4, 0xd4, 0xaa, 0xe8,
		0x1c, 0x8f, 0xe7, 0xbb, 0xa6, 0xfd, 0x42, 0x41, 0xf1, 0xbc, 0xcf, 0x73, 0x75, 0x34, 0xdf, 0xf0,
		0x87, 0x1e, 0x41, 0x5d, 0xb4, 0xf1, 0x38, 0xf2, 0x85, 0xf4, 0x1b, 0x17, 0xed, 0xd6, 0x6f, 0x68,
		0x3a, 0x02, 0x93, 0x05, 0x93, 0xc5, 0x2d, 0x31, 0xcc, 0x1e, 0xbe, 0x32, 0x57, 0xa6, 0xa5, 0xc5,
		0xee, 0x36, 0x35, 0x1b, 0x19, 0x09, 0x89, 0x6e, 0xf6, 0xe4, 0x8d, 0xdf, 0x64, 0x20, 0x18, 0x2d,
		0x18, 0x2d, 0x18, 0xad, 0x54, 0x95, 0x67, 0x56, 0x81, 0x4e, 0x24, 0x86, 0xb8, 0x37, 0xec, 0x17,
		0x26, 0x9d, 0xe1, 0x43, 0x50, 0x80, 0xf8, 0xda, 0xb4, 0x49, 0x2a, 0x19, 0x13, 0x58, 0x96, 0xa5,
		0xe1, 0x82, 0x3c, 0x28, 0x7e, 0xc2, 0x24, 0x76, 0xbc, 0x8f, 0xae, 0x11, 0x94, 0x6b, 0xbb, 0x34,
		0x5f, 0xcc, 0xf1, 0x1e, 0x50, 0x1e, 0x72, 0x62, 0xb4, 0x6b, 0xe3, 0x5b, 0xee, 0x97, 0xa0, 0x5e,
		0x39, 0xab, 0xe7, 0x78, 0x15, 0x32, 0xaa, 0x43, 0xdd, 0xc1, 0xce, 0x36, 0xf9, 0xe6, 0x56, 0xb0,
		0xa7, 0x14, 0xfc, 0x9b, 0xa3, 0xb3, 0x5a, 0xaf, 0xec, 0xf5, 0x99, 0xb9, 0x9e, 0x38, 0x61, 0x3c,
		0x19, 0x00, 0x8c, 0xb1, 0x42, 0x28, 0x06, 0xc6, 0x78, 0x37, 0x4d, 0xc6, 0x78, 0x2c, 0xd3, 0xf2,
		0xe1, 0x4c, 0x38, 0x8e, 0x5c, 0x34, 0x53, 0x95, 0x8d, 0x66, 0x6a, 0x88, 0x66, 0x10, 0xcd, 0xa4,
		0x14, 0xcd, 0x88, 0xaa, 0xdc, 0xd4, 0xe5, 0x0a, 0x9d, 0x00, 0x8c, 0x95, 0x3b, 0x91, 0x13, 0x81,
		0xc4, 0x8a, 0x48, 0xa6, 0x90, 0x94, 0x8a, 0xb9, 0x4a, 0x41, 0xcd, 0x3e, 0x45, 0x7b, 0x16, 0xc2,
		0x1e, 0x32, 0x4a, 0xd4, 0x55, 0x99, 0xda, 0xc6, 0xa9, 0xaf, 0xd9, 0xcf, 0x3a, 0x91, 0x5f, 0x32,
		0x94, 0x93, 0x56, 0xea, 0x68, 0x20, 0xd3, 0xf6, 0x99, 0xdb, 0x37, 0x28, 0xc5, 0x23, 0x3a, 0x88,
		0x15, 0x0d, 0xfd, 0x2e, 0x97, 0xe1, 0xa6, 0x2c, 0xb7, 0xa8, 0xd2, 0x08, 0x28, 0x33, 0x06, 0xaa,
		0x8c, 0x82, 0x72, 0xe3, 0xa0, 0xdc, 0x48, 0xa8, 0x34, 0x16, 0x34, 0x46, 0x83, 0x90, 0x07, 0xda,
		0x25, 0xe1, 0x39, 0x63, 0xa5, 0xf5, 0xd9, 0xf0, 0x98, 0x1e, 0xe9, 0xbf, 0x2e, 0x77, 0x9c, 0x20,
		0xd6, 0xf9, 0x9f, 0x12, 0x8e, 0x39, 0xdb, 0xba, 0xcf, 0xec, 0x9f, 0x47, 0xcf, 0xee, 0x2d, 0xfe,
		0x22, 0xfc, 0x59, 0xbc, 0x1b, 0x1f, 0xbd, 0x4c, 0x64, 0xeb, 0x8a, 0x24, 0x19, 0x9d, 0xf4, 0x18,
		0x9e, 0x90, 0x16, 0x09, 0xff, 0x5f, 0xe4, 0x20, 0x03, 0xdd, 0xc4, 0xbf, 0xa1, 0x91, 0x63, 0x1a,
		0x8d, 0x1c, 0x13, 0x1f, 0x79, 0xa0, 0x9a, 0x69, 0x22, 0x65, 0x48, 0x4b, 0x09, 0x64, 0x82, 0xff,
		0xf5, 0xe7, 0x27, 0x7e, 0xb3, 0x0c, 0xfb, 0xe9, 0x7a, 0x7c, 0x13, 0x10, 0xd7, 0x29, 0xac, 0x28,
		0x6a, 0x05, 0xa5, 0x12, 0xf9, 0x83, 0xb5, 0x26, 0x86, 0xe1, 0xc8, 0x73, 0xde, 0x28, 0x2e, 0xc8,
		0x73, 0x06, 0x63, 0x9d, 0x8d, 0x5a, 0x65, 0x03, 0x57, 0x91, 0xe7, 0xcc, 0x8b, 0xc4, 0x90, 0xe7,
		0x0c, 0x93, 0x05, 0x93, 0x55, 0x0a, 0x93, 0x85, 0x3c, 0x67, 0xae, 0x67, 0x44, 0x9e, 0x33, 0x8c,
		0x16, 0x8c, 0x16, 0xf2, 0x9c, 0x91, 0xe7, 0x9c, 0x70, 0x38, 0xe4, 0x39, 0xe7, 0x66, 0x09, 0x90,
		0xe7, 0xbc, 0xea, 0x3f, 0xe4, 0x39, 0x2b, 0xa5, 0x8b, 0xd5, 0xd6, 0xef, 0xe2, 0x20, 0x8b, 0x45,
		0x91, 0x9b, 0xa4, 0xd3, 0x29, 0x6a, 0x43, 0x0a, 0x10, 0xc6, 0xa4, 0x88, 0x0b, 0xad, 0x28, 0x56,
		0x0b, 0xeb, 0x62, 0x2b, 0x8a, 0x89, 0x92, 0x15, 0xa9, 0xe0, 0x1f, 0x9f, 0x61, 0x40, 0x81, 0x3f,
		0x6a, 0x27, 0xa6, 0xcc, 0x79, 0xd1, 0x95, 0xf7, 0xfb, 0x2d, 0xb1, 0xd1, 0x28, 0x77, 0x75, 0xbf,
		0x71, 0x51, 0x3d, 0xd1, 0xe2, 0x7e, 0x3b, 0x1c, 0x2f, 0x3c, 0x51, 0xce, 0x35, 0x9b, 0x59, 0xc9,
		0x34, 0x31, 0xb9, 0xe6, 0x49, 0x69, 0x5a, 0x32, 0xcd, 0x8a, 0x7b, 0xd9, 0x84, 0xab, 0x4a, 0xbb,
		0x9a, 0x6b, 0xd4, 0x63, 0xbd, 0x3a, 0xac, 0x16, 0x80, 0xe5, 0xe5, 0x9d, 0xff, 0xcd, 0xc2, 0xbb,
		0x6f, 0x7a, 0x67, 0xa9, 0x77, 0x9d, 0x7f, 0xc2, 0xe9, 0x73, 0xcc, 0x3c, 0x83, 0xe6, 0x0c, 0x7c,
		0xb3, 0x6b, 0x58, 0xba, 0xf1, 0x3a, 0xb0, 0xc6, 0xb5, 0x80, 0x17, 0x1f, 0x63, 0x8a, 0xa7, 0x96,
		0xbe, 0xba, 0xf0, 0x2e, 0xab, 0xb3, 0x0a, 0x62, 0x41, 0xe0, 0x3a, 0x90, 0x37, 0x0b, 0xe2, 0x9c,
		0x81, 0x3f, 0xba, 0xe7, 0x8a, 0x85, 0xda, 0x84, 0xd3, 0x12, 0xe3, 0xb0, 0xc4, 0x38, 0x6b, 0x11,
		0x47, 0x4d, 0x9e, 0x8d, 0x73, 0xd5, 0xe3, 0xf6, 0xc6, 0xb5, 0x68, 0x6e, 0xe3, 0x77, 0xa6, 0xa6,
		0xdd, 0x6f, 0xa6, 0xdf, 0x8d, 0xb3, 0x1e, 0x6b, 0xd3, 0x3c, 0x36, 0xa2, 0xf3, 0x24, 0x28, 0x3c,
		0xd9, 0x42, 0xf1, 0x02, 0x6b, 0x6e, 0x00, 0xcd, 0x0d, 0x94, 0x13, 0x2f, 0xa4, 0x98, 0xdd, 0xde,
		0x94, 0xfc, 0xa0, 0xc5, 0xeb, 0xdb, 0xe6, 0xf5, 0x2e, 0x48, 0x3d, 0xd7, 0xcd, 0xe2, 0x20, 0x1a,
		0x6f, 0x65, 0x5f, 0xd2, 0x75, 0xa3, 0xb8, 0xd0, 0xe0, 0x9c, 0xc4, 0x55, 0x5d, 0x39, 0xcb, 0x65,
		0x8a, 0x95, 0xc9, 0xcc, 0x7b, 0x65, 0xd7, 0xe4, 0x02, 0x27, 0x1b, 0xe8, 0xe7, 0xaf, 0xb8, 0x6b,
		0x62, 0x81, 0x54, 0x13, 0x44, 0x72, 0xd7, 0x77, 0x35, 0x5e, 0x07, 0xfa, 0xab, 0xd3, 0x93, 0x48,
		0x7c, 0x8c, 0x46, 0xd8, 0x0e, 0x2a, 0x8b, 0x5f, 0xb8, 0xb7, 0x87, 0xcd, 0xe2, 0x16, 0xfe, 0xa2,
		0x10, 0x5a, 0x72, 0x6d, 0xd9, 0x64, 0xda, 0xb1, 0xd1, 0xb4, 0x61, 0x8b, 0x5e, 0xe4, 0xf6, 0xae,
		0xdd, 0xba, 0x68, 0x5c, 0x3d, 0x35, 0xae, 0xef, 0xae, 0x5a, 0x1f, 0x5b, 0xcd, 0xfb, 0xa7, 0xeb,
		0xdb, 0x4b, 0xe1, 0x64, 0x27, 0x82, 0xf6, 0x6b, 0x44, 0xe7, 0xb2, 0x2f, 0xff, 0xb8, 0x69, 0x5c,
		0xb7, 0x2e, 0x9e, 0x3e, 0x35, 0x5a, 0x37, 0x12, 0x3b, 0xd8, 0xef, 0xb2, 0x7e, 0x8f, 0x8b, 0xdb,
		0x9b, 0x87, 0x76, 0xe3, 0xa6, 0xfd, 0x74, 0x77, 0xfb, 0x7b, 0xf3, 0xbe, 0x14, 0x6f, 0x22, 0xb9,
		0x24, 0x42, 0x57, 0x76, 0x54, 0x5b, 0x20, 0x25, 0x9b, 0x4a, 0xcc, 0x36, 0x9e, 0x2d, 0x26, 0xb1,
		0xa9, 0x34, 0x19, 0x00, 0x9e, 0x18, 0x9e, 0xb8, 0xa4, 0x9e, 0xf8, 0xd9, 0x71, 0x2c, 0x26, 0xb6,
		0x99, 0x38, 0xf1, 0xc2, 0xd5, 0x1c, 0xa8, 0x7a, 0xdf, 0x7c, 0x66, 0xae, 0xee, 0x7f, 0x1f, 0x30,
		0x7d, 0xe0, 0x3a, 0x7d, 0xd3, 0x92, 0x00, 0xe0, 0x2b, 0xc6, 0x82, 0x01, 0x80, 0x01, 0x00, 0x14,
		0xcf, 0x37, 0x14, 0xff, 0xd8, 0xfa, 0xd0, 0xbc, 0x7f, 0x6a, 0xff, 0x71, 0xd7, 0x7c, 0xba, 0xbb,
		0xbf, 0xfd, 0xd8, 0xba, 0x2a, 0x01, 0x0c, 0xbf, 0x6a, 0x36, 0x3e, 0x16, 0x19, 0xb4, 0x3e, 0x3c,
		0x5c, 0x17, 0xfa, 0xf9, 0x2f, 0x1f, 0x0a, 0xfd, 0xf8, 0xed, 0xdf, 0x2f, 0x8a, 0xfd, 0xf8, 0xf7,
		0x0f, 0x88, 0x74, 0x92, 0xcc, 0xd8, 0x8b, 0x61, 0xda, 0xba, 0x1b, 0x66, 0x3c, 0x0b, 0xc2, 0x9e,
		0x99, 0x31, 0x00, 0x77, 0x00, 0x77, 0x00, 0x77, 0xf2, 0x0d, 0x77, 0x3e, 0x35, 0x5a, 0x37, 0x4f,
		0xf7, 0x8d, 0x9b, 0x4f, 0x65, 0x80, 0x39, 0xb7, 0xbf, 0x3f, 0xcd, 0xbc, 0x4f, 0x81, 0x5d, 0xd6,
		0x75, 0xeb, 0xb2, 0x24, 0x6f, 0xf2, 0xaf, 0xd6, 0xa7, 0x7f, 0x95, 0xe4, 0x55, 0x3e, 0xb6, 0xfe,
		0xd3, 0x24, 0x5a, 0x96, 0x2d, 0xc2, 0x14, 0xaf, 0xc6, 0x37, 0x7d, 0x84, 0x09, 0x24, 0x4a, 0x8f,
		0x4f, 0x46, 0x00, 0x9e, 0x00, 0x9e, 0x28, 0x29, 0x9e, 0xe8, 0xb1, 0xae, 0xf9, 0x6a, 0x58, 0x27,
		0x75, 0x19, 0x34, 0x21, 0x50, 0x70, 0x78, 0xf9, 0x90, 0x97, 0xc8, 0x20, 0x72, 0x87, 0x24, 0xe5,
		0xca, 0xc7, 0x11, 0x9c, 0x07, 0x1e, 0x4f, 0x9f, 0x6c, 0xb9, 0xe6, 0xc9, 0x09, 0x3c, 0xc9, 0x13,
		0x7d, 0x94, 0xc7, 0xee, 0xde, 0xe4, 0xea, 0xe9, 0x91, 0x4d, 0xed, 0x51, 0x09, 0xa7, 0x36, 0xa5,
		0x13, 0x85, 0x9d, 0x9c, 0xb8, 0x70, 0x67, 0xe8, 0x0f, 0x86, 0xbe, 0x3e, 0x70, 0xfe, 0x27, 0xd0,
		0x31, 0x61, 0xce, 0x95, 0xcf, 0x8d, 0x04, 0x97, 0x0e, 0x97, 0x0e, 0x97, 0x0e, 0x97, 0x0e, 0x97,
		0x0e, 0x97, 0x0e, 0x97, 0x9e, 0xa2, 0x4b, 0x37, 0x6d, 0xd9, 0xa8, 0x7c, 0x32, 0x02, 0x5c, 0x38,
		0x5c, 0x38, 0x5c, 0x38, 0x5c, 0x38, 0x5c, 0x38, 0x5c, 0x38, 0x5c, 0x78, 0x7a, 0x2e, 0x5c, 0xa8,
		0x0e, 0xb4, 0x4c, 0xfd, 0x67, 0xb8, 0x6e, 0xb8, 0xee, 0xc2, 0xb8, 0x6e, 0xe1, 0x2a, 0xcd, 0x82,
		0xd5, 0x99, 0xd5, 0xe8, 0xb8, 0x6f, 0xb8, 0x2f, 0xcc, 0x97, 0x44, 0xea, 0xb3, 0x83, 0x40, 0xe3,
		0xa1, 0xf1, 0x00, 0xeb, 0x00, 0xeb, 0x6a, 0xc0, 0x7a, 0x25, 0xaf, 0x88, 0xb2, 0x06, 0xb0, 0x0e,
		0xb0, 0x9e, 0x13, 0x47, 0xae, 0xfb, 0x66, 0xd0, 0xd1, 0x40, 0xde, 0x9b, 0x8f, 0x47, 0x82, 0x4b,
		0x87, 0x4b, 0x87, 0x4b, 0x87, 0x4b, 0x07, 0xff, 0x06, 0x97, 0x0e, 0x97, 0x9e, 0xba, 0x4b, 0xa7,
		0x49, 0x8c, 0x59, 0x35, 0x18, 0x1c, 0x3b, 0x1c, 0x3b, 0x1c, 0x3b, 0x1c, 0x3b, 0x1c, 0x3b, 0x1c,
		0x3b, 0x1c, 0x7b, 0x8a, 0x8e, 0x5d, 0xc4, 0xbc, 0x4d, 0x3d, 0xf9, 0xe8, 0x6a, 0xb8, 0x6e, 0xb8,
		0x6e, 0x9c, 0x7c, 0x5d, 0xe7, 0xbc, 0xf3, 0x58, 0x73, 0xaf, 0xfd, 0xc7, 0x5d, 0x09, 0x4e, 0xc1,
		0xfe, 0xeb, 0x8f, 0x0f, 0xf7, 0xad, 0xcb, 0x22, 0x1f, 0xb4, 0xfc, 0xd0, 0xb8, 0xf8, 0xf5, 0xf7,
		0xc6, 0xfd, 0xe5, 0xd3, 0x7d, 0xe3, 0xba, 0x51, 0xe8, 0xba, 0x81, 0x1f, 0x6f, 0xef, 0xcb, 0xf1,
		0x22, 0xcd, 0xcb, 0x8f, 0x8d, 0x2d, 0x3e, 0xef, 0x9a, 0xf3, 0x0e, 0x28, 0x4b, 0xad, 0x07, 0x0e,
		0x97, 0x7f, 0x33, 0x2d, 0x87, 0x3f, 0xfd, 0x78, 0x18, 0xd6, 0xb7, 0xa6, 0x6a, 0x5a, 0x92, 0xa0,
		0x94, 0x39, 0x57, 0xd6, 0x92, 0x48, 0xb6, 0x12, 0x27, 0x98, 0x42, 0x15, 0x6e, 0x85, 0xe0, 0x28,
		0x67, 0x55, 0xb8, 0xb9, 0xc1, 0x8f, 0x44, 0xe7, 0x2c, 0x91, 0x8e, 0x59, 0xcb, 0x9d, 0xb2, 0x02,
		0xb9, 0x4f, 0x51, 0x3b, 0xc7, 0x8d, 0xfc, 0xb8, 0xd5, 0x73, 0x7c, 0x99, 0xe2, 0x2a, 0xf9, 0x35,
		0xe8, 0x67, 0xc9, 0xf5, 0x93, 0xbf, 0x4a, 0x7e, 0xd7, 0x1f, 0x1a, 0x96, 0x64, 0x7a, 0xdc, 0xec,
		0x20, 0x62, 0x71, 0x7b, 0x15, 0x71, 0x3b, 0xe2, 0x76, 0xb5, 0x71, 0x3b, 0xaf, 0x6a, 0x4c, 0x55,
		0xe4, 0xeb, 0x8b, 0x7c, 0xa8, 0x3c, 0x1a, 0x04, 0x3d, 0xec, 0x47, 0xe2, 0xe1, 0x7f, 0x1f, 0x30,
		0x0f, 0x4d, 0xec, 0x05, 0x14, 0x6b, 0x3c, 0x73, 0x5b, 0xd7, 0xc5, 0x5e, 0x66, 0xa7, 0x6b, 0xc9,
		0xcf, 0x48, 0xec, 0xd9, 0x90, 0xec, 0x7c, 0x45, 0x83, 0x95, 0xba, 0x2b, 0x7e, 0x8d, 0xb8, 0x25,
		0x7b, 0x05, 0x5d, 0xf1, 0x79, 0x97, 0xe0, 0x68, 0x8b, 0x96, 0xa0, 0xec, 0x2d, 0xf1, 0x05, 0x50,
		0xe6, 0xb8, 0x45, 0xa7, 0x2f, 0x0f, 0x5c, 0x26, 0x03, 0x01, 0xbc, 0x00, 0xbc, 0x00, 0xbc, 0x00,
		0xbc, 0x00, 0xbc, 0x00, 0xbc, 0x00, 0xbc, 0x00, 0xbc, 0xa8, 0x05, 0x2f, 0x3e, 0x73, 0xbf, 0x1a,
		0x16, 0x05, 0x7a, 0x09, 0x47, 0x02, 0x7c, 0x01, 0x7c, 0x01, 0x7c, 0xe1, 0x96, 0x19, 0xcf, 0x37,
		0x7c, 0x5d, 0x52, 0x89, 0x66, 0x15, 0xe9, 0xbd, 0xc4, 0x10, 0xff, 0xb6, 0xc7, 0x36, 0x57, 0xb3,
		0x0d, 0xdb, 0xf1, 0x58, 0xd7, 0xb1, 0x7b, 0x52, 0xb2, 0x5c, 0x6a, 0x10, 0x53, 0x01, 0x88, 0xc9,
		0x1a, 0xc4, 0x50, 0x2f, 0x41, 0xf5, 0x7d, 0xbd, 0x7e, 0x72, 0x5a, 0xaf, 0x57, 0x4e, 0x8f, 0x4e,
		0x2b, 0x67, 0xc7, 0xc7, 0xd5, 0x13, 0x91, 0x14, 0x40, 0xe0, 0x9a, 0xec, 0x70, 0xcd, 0xab, 0x84,
		0x94, 0xcd, 0x16, 0x00, 0x06, 0x9a, 0x01, 0x9a, 0x01, 0x9a, 0x01, 0x19, 0x03, 0x32, 0x06, 0x38,
		0x06, 0x64, 0x0c, 0x40, 0x8b, 0x6a, 0xd0, 0xa2, 0xfb, 0xe6, 0x2b, 0x23, 0x41, 0x2e, 0xe3, 0x91,
		0x00, 0x5f, 0x00, 0x5f, 0x00, 0x5f, 0xb8, 0x65, 0x66, 0xa4, 0x3b, 0xbe, 0xd9, 0xfd, 0xcb, 0x23,
		0x01, 0x30, 0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0xb3, 0xa5, 0xa8, 0x46, 0x42, 0xd1,
		0x67, 0x1b, 0x38, 0x00, 0xcb, 0x00, 0xcb, 0x00, 0xcb, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x1c, 0x03,
		0x2a, 0x06, 0xa0, 0x45, 0x35, 0x68, 0xa1, 0xa2, 0x62, 0x26, 0x23, 0x01, 0xbe, 0x00, 0xbe, 0x00,
		0xbe, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x08, 0x03, 0x2a, 0x06, 0xa8, 0x46, 0x16, 0xd5, 0x28, 0x3d,
		0xc2, 0x2d, 0x58, 0xf6, 0x27, 0xba, 0x5e, 0x41, 0xf9, 0x9f, 0x71, 0x91, 0x11, 0xf1, 0x02, 0x08,
		0xe3, 0xe7, 0xf2, 0xdd, 0x61, 0xd7, 0xb7, 0x27, 0x55, 0xd5, 0xc6, 0x77, 0x6e, 0x4c, 0xee, 0xf1,
		0x34, 0xf3, 0x29, 0xb8, 0xcf, 0xa7, 0xd1, 0x6d, 0x72, 0x50, 0xe5, 0x71, 0xe6, 0xad, 0x25, 0x3b,
		0x32, 0x2c, 0x8d, 0x84, 0x2a, 0x12, 0x6a, 0x01, 0x27, 0xaa, 0x48, 0x08, 0x9a, 0x20, 0x54, 0x91,
		0x40, 0xc4, 0x86, 0x88, 0xad, 0x80, 0x11, 0x1b, 0x08, 0xe7, 0xc2, 0x45, 0x6b, 0x20, 0x9c, 0x33,
		0x8f, 0xd6, 0x40, 0x38, 0x97, 0x27, 0x34, 0x43, 0x15, 0x09, 0x80, 0x17, 0x80, 0x17, 0x80, 0x17,
		0x80, 0x17, 0x80, 0x17, 0x80, 0x17, 0x80, 0x97, 0xf2, 0x83, 0x17, 0x54, 0x91, 0x00, 0x7c, 0x01,
		0x7c, 0x41, 0x15, 0x89, 0xd9, 0x21, 0xb0, 0x5f, 0xae, 0xde, 0x62, 0x01, 0xc4, 0xe4, 0x77, 0x09,
		0xb0, 0x5f, 0x5e, 0x74, 0x5c, 0x83, 0x2a, 0x12, 0x40, 0x33, 0x40, 0x33, 0x20, 0x63, 0x40, 0xc6,
		0x80, 0x8c, 0x01, 0x19, 0x03, 0xd0, 0x52, 0x14, 0xd0, 0x82, 0x2a, 0x12, 0x80, 0x2f, 0x80, 0x2f,
		0x38, 0xba, 0x00, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x65, 0x40, 0x35, 0xa8, 0x22,
		0x01, 0x2c, 0x03, 0x2c, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x00, 0x2d, 0x05,
		0x01, 0x2d, 0xa8, 0x22, 0x01, 0xf8, 0x02, 0xf8, 0x02, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50,
		0x31, 0xa0, 0x62, 0xf2, 0x86, 0x6a, 0xb6, 0xbe, 0x8a, 0x84, 0x48, 0x15, 0x84, 0x5d, 0xc1, 0x52,
		0x12, 0xed, 0xd1, 0xad, 0xf2, 0x50, 0x4e, 0xe2, 0x75, 0xa0, 0xbf, 0x3a, 0x3d, 0x26, 0x51, 0x46,
		0x62, 0x32, 0x82, 0x58, 0xf9, 0x88, 0x0a, 0xca, 0x47, 0xa4, 0x8d, 0x30, 0xb7, 0xad, 0x7c, 0x84,
		0x30, 0x76, 0x9c, 0x9e, 0x45, 0xe8, 0x31, 0xdb, 0x37, 0xfd, 0xef, 0x2e, 0xeb, 0x8b, 0x2c, 0xfc,
		0x84, 0xec, 0x12, 0xf0, 0x6e, 0x5a, 0x2b, 0xbc, 0xf5, 0x07, 0xc3, 0x23, 0x08, 0x1e, 0x6f, 0xef,
		0xda, 0xad, 0x8b, 0xc6, 0xd5, 0x53, 0xe3, 0xfa, 0xee, 0xaa, 0xf5, 0xb1, 0xd5, 0xbc, 0x7f, 0xba,
		0xbe, 0xbd, 0x6c, 0x8a, 0xca, 0x51, 0xe0, 0xc8, 0x3d, 0x29, 0xc4, 0x29, 0x19, 0x74, 0x4d, 0xde,
		0xeb, 0xf2, 0x8f, 0x9b, 0xc6, 0x75, 0xeb, 0xe2, 0xe9, 0x53, 0xa3, 0x75, 0x23, 0x11, 0xd2, 0xbc,
		0xcb, 0xfa, 0x3d, 0x2e, 0x6e, 0x6f, 0x1e, 0xda, 0x8d, 0x9b, 0xf6, 0xd3, 0xdd, 0xed, 0xef, 0xcd,
		0xfb, 0x52, 0xbc, 0x89, 0xe4, 0x92, 0xec, 0xa4, 0x83, 0x99, 0xde, 0x72, 0xe0, 0x8b, 0xbb, 0xce,
		0xeb, 0xc0, 0xb1, 0x99, 0x2d, 0x51, 0xd3, 0x69, 0x3a, 0x04, 0xbc, 0x31, 0xbc, 0x71, 0x49, 0xbd,
		0xb1, 0xc5, 0x8c, 0xbe, 0xa4, 0x27, 0x3e, 0x15, 0xb8, 0xf6, 0x2e, 0x0a, 0x3e, 0xba, 0xfa, 0xc0,
		0x32, 0xfc, 0xbe, 0xe3, 0xbe, 0x9e, 0x47, 0x0a, 0xe7, 0xad, 0xfe, 0xf5, 0xdc, 0x6f, 0x83, 0x08,
		0x21, 0x07, 0x86, 0x86, 0xbd, 0xb8, 0xcc, 0xf3, 0xf4, 0x81, 0xe3, 0x4a, 0x98, 0x9a, 0xd9, 0x41,
		0x60, 0x6c, 0x60, 0x6c, 0x60, 0x6c, 0x60, 0x6c, 0x56, 0x1a, 0x1b, 0xdb, 0x78, 0xb6, 0x58, 0x4f,
		0xc2, 0xd0, 0x84, 0x03, 0xc0, 0xc8, 0xc0, 0xc8, 0x94, 0xd4, 0xc8, 0x3c, 0x3b, 0x8e, 0xc5, 0x0c,
		0x5b, 0xc6, 0xc8, 0x54, 0x73, 0xa0, 0xea, 0x7d, 0xf3, 0x99, 0xb9, 0xc1, 0xbe, 0xa2, 0x3e, 0x70,
		0x9d, 0xbe, 0x69, 0x49, 0xd0, 0x8a, 0x2b, 0xc6, 0x82, 0x01, 0x80, 0x01, 0x00, 0xc1, 0x98, 0x6f,
		0x82, 0xf1, 0x63, 0xeb, 0x43, 0xf3, 0xfe, 0xa9, 0xfd, 0xc7, 0x5d, 0xf3, 0xe9, 0xee, 0xfe, 0xf6,
		0x63, 0xeb, 0xaa, 0x04, 0xe4, 0xe2, 0x55, 0xb3, 0xf1, 0xb1, 0xc8, 0x54, 0xdc, 0xc3, 0xc3, 0x75,
		0xa1, 0x9f, 0xff, 0xf2, 0xa1, 0xd0, 0x8f, 0xdf, 0xfe, 0xfd, 0xa2, 0xd8, 0x8f, 0x7f, 0xff, 0x00,
		0xfe, 0x36, 0xc9, 0x8c, 0x05, 0x7b, 0xc8, 0x6e, 0x98, 0x84, 0x23, 0x08, 0x7b, 0x66, 0xc6, 0x00,
		0xdc, 0x01, 0xdc, 0x01, 0xdc, 0xc9, 0x37, 0xdc, 0xf9, 0xd4, 0x68, 0xdd, 0x3c, 0xdd, 0x37, 0x6e,
		0x3e, 0x95, 0x01, 0xe6, 0xdc, 0xfe, 0xfe, 0x34, 0xf3, 0x3e, 0x05, 0x76, 0x59, 0xd7, 0xad, 0xcb,
		0x92, 0xbc, 0xc9, 0xbf, 0x5a, 0x9f, 0xfe, 0x55, 0x92, 0x57, 0xf9, 0xd8, 0xfa, 0x4f, 0x93, 0x68,
		0x59, 0xb6, 0x08, 0x53, 0x98, 0x36, 0xc5, 0x5e, 0xcd, 0xdc, 0x28, 0xc0, 0x15, 0xc0, 0x15, 0xd8,
		0xac, 0x89, 0xc3, 0x14, 0xdb, 0xbd, 0x59, 0x63, 0xda, 0x83, 0xa1, 0xaf, 0x0f, 0x9c, 0xff, 0x31,
		0x57, 0xef, 0xea, 0xcf, 0x86, 0xdd, 0x93, 0x31, 0x3a, 0x4b, 0x63, 0xa1, 0xc3, 0x18, 0x4c, 0x0f,
		0x3a, 0x8c, 0x2d, 0xc9, 0x0c, 0x3a, 0x8c, 0xe1, 0x34, 0x9f, 0xac, 0x62, 0xa1, 0x18, 0x01, 0x8a,
		0x11, 0x90, 0x06, 0x6e, 0xbb, 0x28, 0x46, 0x80, 0x62, 0x04, 0x25, 0x58, 0x02, 0x14, 0x23, 0x58,
		0x81, 0xf2, 0xd1, 0x61, 0x0c, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0,
		0x05, 0xe0, 0xa5, 0x50, 0xe0, 0x05, 0x1d, 0xc6, 0x00, 0x5f, 0x00, 0x5f, 0xd0, 0x61, 0x6c, 0x76,
		0x08, 0xd4, 0x52, 0x52, 0x6f, 0xb1, 0x00, 0x62, 0xf2, 0xbb, 0x04, 0xa8, 0xa5, 0x54, 0x74, 0x5c,
		0x83, 0x0e, 0x63, 0x40, 0x33, 0x40, 0x33, 0x20, 0x63, 0x40, 0xc6, 0x80, 0x8c, 0x01, 0x19, 0x03,
		0xd0, 0x52, 0x14, 0xd0, 0x82, 0x0e, 0x63, 0x80, 0x2f, 0x80, 0x2f, 0x28, 0x6b, 0x0d, 0x2a, 0x06,
		0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x65, 0x40, 0x35, 0xe8, 0x30, 0x06, 0x2c, 0x03, 0x2c, 0x03,
		0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x00, 0x2d, 0x05, 0x01, 0x2d, 0xe8, 0x30, 0x06,
		0xf8, 0x02, 0xf8, 0x02, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0xf2, 0x86,
		0x6a, 0xb6, 0xb3, 0xc3, 0x98, 0x74, 0x1d, 0x84, 0x5d, 0xae, 0x1e, 0x63, 0xad, 0xd1, 0xed, 0xee,
		0x46, 0x77, 0xbb, 0xf8, 0x30, 0xba, 0x57, 0xce, 0xaa, 0x4a, 0x58, 0x84, 0x55, 0x25, 0x2c, 0x54,
		0x95, 0x48, 0x03, 0x80, 0xa2, 0xaa, 0x84, 0xa0, 0x49, 0x42, 0x55, 0x09, 0x44, 0x70, 0x88, 0xe0,
		0x0a, 0x18, 0xc1, 0x81, 0x80, 0x2e, 0x5c, 0xf4, 0x06, 0x02, 0x3a, 0xf3, 0xe8, 0x0d, 0x04, 0x74,
		0x79, 0x42, 0x35, 0x54, 0x95, 0x00, 0x78, 0x01, 0x78, 0x01, 0x78, 0x01, 0x78, 0x01, 0x78, 0x01,
		0x78, 0x01, 0x78, 0x29, 0x3f, 0x78, 0x41, 0x55, 0x09, 0xc0, 0x17, 0xc0, 0x17, 0x54, 0x95, 0x98,
		0x1d, 0x02, 0xfb, 0xe7, 0xea, 0x2d, 0x16, 0x40, 0x4c, 0x7e, 0x97, 0x00, 0xfb, 0xe7, 0x45, 0xc7,
		0x35, 0xa8, 0x2a, 0x01, 0x34, 0x03, 0x34, 0x03, 0x32, 0x06, 0x64, 0x0c, 0xc8, 0x18, 0x90, 0x31,
		0x00, 0x2d, 0x45, 0x01, 0x2d, 0xa8, 0x2a, 0x01, 0xf8, 0x02, 0xf8, 0x82, 0xa3, 0x0c, 0xa0, 0x62,
		0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x53, 0x06, 0x54, 0x83, 0xaa, 0x12, 0xc0, 0x32, 0xc0, 0x32,
		0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x03, 0xd0, 0x52, 0x10, 0xd0, 0x82, 0xaa, 0x12,
		0x80, 0x2f, 0x80, 0x2f, 0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x26, 0x6f,
		0xa8, 0x06, 0x55, 0x25, 0xac, 0x34, 0xab, 0x4a, 0x5c, 0xe5, 0xb1, 0xaa, 0x84, 0xef, 0xf8, 0x02,
		0xb9, 0xdb, 0x2b, 0x8b, 0x4a, 0x8c, 0x87, 0x42, 0x4d, 0x09, 0xb5, 0xf0, 0x13, 0x35, 0x25, 0x04,
		0x0d, 0x12, 0x6a, 0x4a, 0x20, 0x7e, 0x43, 0xfc, 0x56, 0xc0, 0xf8, 0x0d, 0xf4, 0x73, 0xe1, 0x62,
		0x37, 0xd0, 0xcf, 0x99, 0xc7, 0x6e, 0xa0, 0x9f, 0xcb, 0x13, 0xa8, 0xa1, 0xa6, 0x04, 0xc0, 0x0b,
		0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x4b, 0xf9, 0xc1, 0x0b, 0x6a,
		0x4a, 0x00, 0xbe, 0x00, 0xbe, 0xa0, 0xa6, 0xc4, 0xec, 0x10, 0xd8, 0x3d, 0x57, 0x6f, 0xb1, 0x00,
		0x62, 0xf2, 0xbb, 0x04, 0xd8, 0x3d, 0x2f, 0x3a, 0xae, 0x41, 0x4d, 0x09, 0xa0, 0x19, 0xa0, 0x19,
		0x90, 0x31, 0x20, 0x63, 0x40, 0xc6, 0x80, 0x8c, 0x01, 0x68, 0x29, 0x0a, 0x68, 0x41, 0x4d, 0x09,
		0xc0, 0x17, 0xc0, 0x17, 0x1c, 0x64, 0x00, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x98, 0x32,
		0xa0, 0x1a, 0xd4, 0x94, 0x00, 0x96, 0x01, 0x96, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8,
		0x18, 0x80, 0x96, 0x82, 0x80, 0x16, 0xd4, 0x94, 0x00, 0x7c, 0x01, 0x7c, 0x01, 0x15, 0x03, 0x2a,
		0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x79, 0x43, 0x35, 0xa8, 0x29, 0x21, 0x52, 0x06, 0x61,
		0x57, 0xb0, 0xa4, 0x44, 0x3b, 0xb8, 0x57, 0x0e, 0x4a, 0x4a, 0x58, 0x86, 0xc7, 0x5c, 0xfd, 0xd9,
		0x34, 0x3c, 0xbd, 0x3b, 0x74, 0x5d, 0x26, 0x70, 0xf2, 0x2c, 0xf2, 0xad, 0x2b, 0xc6, 0x42, 0x51,
		0x09, 0xb5, 0xf8, 0x13, 0x45, 0x25, 0x04, 0x2d, 0x12, 0x8a, 0x4a, 0x20, 0x80, 0x43, 0x00, 0x57,
		0xc0, 0x00, 0x0e, 0xfc, 0x73, 0xe1, 0x82, 0x37, 0xf0, 0xcf, 0x99, 0x07, 0x6f, 0xe0, 0x9f, 0xcb,
		0x13, 0xa9, 0xa1, 0xa8, 0x04, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0, 0x0b, 0xc0,
		0x0b, 0xc0, 0x4b, 0xf9, 0xc1, 0x0b, 0x8a, 0x4a, 0x00, 0xbe, 0x00, 0xbe, 0xa0, 0xa8, 0xc4, 0xec,
		0x10, 0xd8, 0x3e, 0x57, 0x6f, 0xb1, 0x00, 0x62, 0xf2, 0xbb, 0x04, 0xd8, 0x3e, 0x2f, 0x3a, 0xae,
		0x41, 0x51, 0x09, 0xa0, 0x19, 0xa0, 0x19, 0x90, 0x31, 0x20, 0x63, 0x40, 0xc6, 0x80, 0x8c, 0x01,
		0x68, 0x29, 0x0a, 0x68, 0x41, 0x51, 0x09, 0xc0, 0x17, 0xc0, 0x17, 0x9c, 0x64, 0x00, 0x15, 0x03,
		0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x98, 0x32, 0xa0, 0x1a, 0x14, 0x95, 0x00, 0x96, 0x01, 0x96, 0x01,
		0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x80, 0x96, 0x82, 0x80, 0x16, 0x14, 0x95, 0x00,
		0x7c, 0x01, 0x7c, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x79, 0x43,
		0x35, 0xdb, 0x59, 0x54, 0x42, 0xba, 0x0e, 0xc2, 0x2e, 0x57, 0x55, 0x89, 0xab, 0xd1, 0xed, 0x3e,
		0x98, 0x86, 0x77, 0x11, 0xde, 0x2c, 0x07, 0x65, 0x25, 0x5e, 0x8d, 0x6f, 0xfa, 0x8b, 0x21, 0x60,
		0xb3, 0xe7, 0xb6, 0x07, 0x83, 0x11, 0xc4, 0x4a, 0x48, 0x54, 0x50, 0x42, 0x22, 0x6d, 0x94, 0xb9,
		0x6d, 0x25, 0x24, 0x84, 0xf1, 0x23, 0x09, 0xed, 0x25, 0x43, 0x77, 0x91, 0xd0, 0x5c, 0x92, 0xd8,
		0x50, 0x02, 0x76, 0x53, 0x60, 0x41, 0x22, 0x1a, 0x8b, 0x0a, 0xfb, 0x51, 0xa2, 0x0b, 0x09, 0xac,
		0x47, 0x82, 0xf1, 0x88, 0xe8, 0xa9, 0x5c, 0x4e, 0x6d, 0x4a, 0xc0, 0xa9, 0x93, 0x13, 0x17, 0xee,
		0x0c, 0xfd, 0xa8, 0x3e, 0x96, 0x9c, 0x2b, 0x9f, 0x1b, 0x09, 0x2e, 0x1d, 0x2e, 0x1d, 0x2e, 0x1d,
		0x2e, 0x1d, 0x2e, 0x1d, 0x2e, 0x1d, 0x2e, 0x3d, 0x45, 0x97, 0x6e, 0xda, 0xb2, 0x51, 0xf9, 0x64,
		0x04, 0xb8, 0x70, 0xb8, 0x70, 0xb8, 0x70, 0xb8, 0x70, 0xb8, 0x70, 0xb8, 0x70, 0xb8, 0xf0, 0xf4,
		0x5c, 0x78, 0xb8, 0x1f, 0x20, 0xe8, 0xbe, 0x83, 0xab, 0xe1, 0xba, 0xe1, 0xba, 0x4b, 0xea, 0xba,
		0x3d, 0xdf, 0x35, 0xed, 0x17, 0x19, 0xbf, 0xfd, 0x3e, 0x07, 0x3a, 0x3e, 0xd9, 0x6c, 0x74, 0x99,
		0x3f, 0x74, 0x6d, 0xdd, 0x72, 0x3c, 0x4f, 0x5c, 0xe5, 0x57, 0x0d, 0x86, 0xaa, 0xec, 0xb0, 0x00,
		0xa8, 0xca, 0xbe, 0x24, 0x33, 0xa8, 0xca, 0x8e, 0x0c, 0x48, 0x59, 0xc5, 0xc2, 0x01, 0x0e, 0x1c,
		0xe0, 0x20, 0x8b, 0xa9, 0x49, 0x63, 0x6b, 0xe2, 0x18, 0x9b, 0x3a, 0x20, 0x54, 0x11, 0x18, 0x12,
		0xc4, 0xde, 0xa4, 0x31, 0x38, 0x71, 0x2c, 0x5e, 0xa8, 0x25, 0xc0, 0x01, 0x8e, 0xa5, 0x69, 0x46,
		0x55, 0x76, 0x80, 0x17, 0x80, 0x17, 0x80, 0x17, 0x80, 0x17, 0x80, 0x17, 0x80, 0x17, 0x80, 0x97,
		0x82, 0x81, 0x17, 0x54, 0x65, 0x07, 0x7c, 0x01, 0x7c, 0x41, 0x55, 0xf6, 0xd9, 0x21, 0x70, 0xfe,
		0x54, 0xbd, 0xc5, 0x02, 0x88, 0xc9, 0xef, 0x12, 0xe0, 0xfc, 0x69, 0xd1, 0x71, 0x0d, 0xaa, 0xb2,
		0x03, 0xcd, 0x00, 0xcd, 0x80, 0x8c, 0x01, 0x19, 0x03, 0x32, 0x06, 0x64, 0x0c, 0x40, 0x4b, 0x51,
		0x40, 0x0b, 0xaa, 0xb2, 0x03, 0xbe, 0x00, 0xbe, 0xa0, 0x14, 0x18, 0xa8, 0x18, 0x50, 0x31, 0xa0,
		0x62, 0x40, 0xc5, 0x94, 0x01, 0xd5, 0xa0, 0x2a, 0x3b, 0xb0, 0x0c, 0xb0, 0x0c, 0xa8, 0x18, 0x50,
		0x31, 0xa0, 0x62, 0x40, 0xc5, 0x00, 0xb4, 0x14, 0x04, 0xb4, 0xa0, 0x2a, 0x3b, 0xe0, 0x0b, 0xe0,
		0x0b, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0xc9, 0x1b, 0xaa, 0xd9, 0xce,
		0xaa, 0xec, 0xf2, 0x85, 0x10, 0x76, 0xb9, 0xca, 0xb2, 0x87, 0x7f, 0xba, 0x0f, 0x6e, 0x77, 0x35,
		0xba, 0x5b, 0x1e, 0x4a, 0x4b, 0xcc, 0x94, 0x61, 0xd5, 0xbb, 0xfa, 0xb3, 0x11, 0xe8, 0xbb, 0x68,
		0x69, 0x89, 0x15, 0x83, 0xa1, 0xb4, 0x84, 0x5a, 0x14, 0x8a, 0xd2, 0x12, 0x82, 0x76, 0x09, 0xa5,
		0x25, 0x10, 0xc6, 0x21, 0x8c, 0x2b, 0x60, 0x18, 0x07, 0x16, 0xba, 0x70, 0x21, 0x1c, 0x58, 0xe8,
		0xcc, 0x43, 0x38, 0xb0, 0xd0, 0xe5, 0x89, 0xd7, 0x50, 0x5a, 0x02, 0xe0, 0x05, 0xe0, 0x05, 0xe0,
		0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0xa5, 0xfc, 0xe0, 0x05, 0xa5, 0x25, 0x00, 0x5f,
		0x00, 0x5f, 0x50, 0x5a, 0x62, 0x76, 0x08, 0x6c, 0xa2, 0xab, 0xb7, 0x58, 0x00, 0x31, 0xf9, 0x5d,
		0x02, 0x6c, 0xa2, 0x17, 0x1d, 0xd7, 0xa0, 0xb4, 0x04, 0xd0, 0x0c, 0xd0, 0x0c, 0xc8, 0x18, 0x90,
		0x31, 0x20, 0x63, 0x40, 0xc6, 0x00, 0xb4, 0x14, 0x05, 0xb4, 0xa0, 0xb4, 0x04, 0xe0, 0x0b, 0xe0,
		0x0b, 0xce, 0x33, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x4c, 0x19, 0x50, 0x0d, 0x4a,
		0x4b, 0x00, 0xcb, 0x00, 0xcb, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0x40, 0x4b,
		0x41, 0x40, 0x0b, 0x4a, 0x4b, 0x00, 0xbe, 0x00, 0xbe, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06,
		0x54, 0x0c, 0xa8, 0x98, 0xbc, 0xa1, 0x9a, 0x2d, 0x2d, 0x2d, 0x21, 0x5d, 0x08, 0x61, 0x97, 0xaf,
		0xb4, 0x44, 0x70, 0xbf, 0xbb, 0xd1, 0xed, 0x2e, 0x3e, 0x8c, 0x6e, 0x96, 0xb7, 0xca, 0x12, 0x16,
		0x65, 0x65, 0x09, 0x0b, 0x95, 0x25, 0xd2, 0x00, 0xa1, 0xa8, 0x2c, 0x21, 0x68, 0x96, 0x50, 0x59,
		0x02, 0x51, 0x1c, 0xa2, 0xb8, 0x02, 0x46, 0x71, 0x20, 0xa1, 0x0b, 0x17, 0xc1, 0x81, 0x84, 0xce,
		0x3c, 0x82, 0x03, 0x09, 0x5d, 0x9e, 0x70, 0x0d, 0x95, 0x25, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e,
		0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0xca, 0x0f, 0x5e, 0x50, 0x59, 0x02, 0xf0, 0x05,
		0xf0, 0x05, 0x95, 0x25, 0x66, 0x87, 0xc0, 0x1e, 0xba, 0x7a, 0x8b, 0x05, 0x10, 0x93, 0xdf, 0x25,
		0xc0, 0x1e, 0x7a, 0xd1, 0x71, 0x0d, 0x2a, 0x4b, 0x00, 0xcd, 0x00, 0xcd, 0x80, 0x8c, 0x01, 0x19,
		0x03, 0x32, 0x06, 0x64, 0x0c, 0x40, 0x4b, 0x51, 0x40, 0x0b, 0x2a, 0x4b, 0x00, 0xbe, 0x00, 0xbe,
		0xe0, 0x38, 0x03, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0x40, 0xc5, 0x94, 0x01, 0xd5, 0xa0, 0xb2,
		0x04, 0xb0, 0x0c, 0xb0, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0x40, 0xc5, 0x00, 0xb4, 0x14,
		0x04, 0xb4, 0xa0, 0xb2, 0x04, 0xe0, 0x0b, 0xe0, 0x0b, 0xa8, 0x18, 0x50, 0x31, 0xa0, 0x62, 0x40,
		0xc5, 0x80, 0x8a, 0xc9, 0x1b, 0xaa, 0x41, 0x65, 0x09, 0xb1, 0x42, 0x08, 0xbb, 0xa2, 0x95, 0x25,
		0xae, 0x72, 0x59, 0x59, 0xc2, 0x77, 0x7c, 0x81, 0xf4, 0xed, 0xd5, 0x85, 0x25, 0xc6, 0x63, 0xa1,
		0xae, 0x84, 0x5a, 0x08, 0x8a, 0xba, 0x12, 0x82, 0x46, 0x09, 0x75, 0x25, 0x10, 0xc3, 0x21, 0x86,
		0x2b, 0x60, 0x0c, 0x07, 0x0a, 0xba, 0x70, 0xf1, 0x1b, 0x28, 0xe8, 0xcc, 0xe3, 0x37, 0x50, 0xd0,
		0xe5, 0x09, 0xd6, 0x50, 0x57, 0x02, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05,
		0xe0, 0x05, 0xe0, 0xa5, 0xfc, 0xe0, 0x05, 0x75, 0x25, 0x00, 0x5f, 0x00, 0x5f, 0x50, 0x57, 0x62,
		0x76, 0x08, 0xec, 0xa0, 0xab, 0xb7, 0x58, 0x00, 0x31, 0xf9, 0x5d, 0x02, 0xec, 0xa0, 0x17, 0x1d,
		0xd7, 0xa0, 0xae, 0x04, 0xd0, 0x0c, 0xd0, 0x0c, 0xc8, 0x18, 0x90, 0x31, 0x20, 0x63, 0x40, 0xc6,
		0x00, 0xb4, 0x14, 0x05, 0xb4, 0xa0, 0xae, 0x04, 0xe0, 0x0b, 0xe0, 0x0b, 0x0e, 0x33, 0x80, 0x8a,
		0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x4c, 0x19, 0x50, 0x0d, 0xea, 0x4a, 0x00, 0xcb, 0x00, 0xcb,
		0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0x40, 0x4b, 0x41, 0x40, 0x0b, 0xea, 0x4a,
		0x00, 0xbe, 0x00, 0xbe, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x98, 0xbc,
		0xa1, 0x1a, 0xd4, 0x95, 0x10, 0xaa, 0x83, 0xb0, 0x2b, 0x5a, 0x56, 0xa2, 0x1d, 0xdc, 0x2c, 0x07,
		0x65, 0x25, 0x7c, 0xc3, 0x7d, 0x61, 0xbe, 0xfe, 0x62, 0x08, 0x98, 0xed, 0xa9, 0x5b, 0x9d, 0x19,
		0x44, 0xac, 0x90, 0x44, 0x05, 0x85, 0x24, 0xd2, 0xc6, 0x9a, 0xdb, 0x56, 0x48, 0x42, 0x18, 0x45,
		0x92, 0x90, 0x5f, 0x32, 0xa4, 0x17, 0x09, 0xd9, 0x25, 0x89, 0x10, 0x25, 0xc0, 0x37, 0x05, 0x22,
		0x24, 0x82, 0x21, 0x54, 0x08, 0x70, 0xc5, 0x8a, 0xec, 0x64, 0x80, 0xf8, 0x48, 0x90, 0x1e, 0x11,
		0x49, 0xa5, 0x6e, 0x6a, 0x2b, 0x69, 0x87, 0xa9, 0x3b, 0x6a, 0x61, 0x9a, 0x72, 0x47, 0xae, 0xfb,
		0xa6, 0xe5, 0x93, 0x78, 0xf3, 0xf1, 0x48, 0x70, 0xe9, 0x70, 0xe9, 0x70, 0xe9, 0x70, 0xe9, 0x6a,
		0x5c, 0x7a, 0xad, 0x84, 0x7e, 0x07, 0x2e, 0x1d, 0x2e, 0x9d, 0xcc, 0xa5, 0xcf, 0xb2, 0x14, 0xd2,
		0x5e, 0x7d, 0x6e, 0x30, 0x38, 0x76, 0x38, 0x76, 0x38, 0x76, 0x38, 0x76, 0x38, 0x76, 0x38, 0x76,
		0x38, 0xf6, 0x14, 0x1d, 0xbb, 0x88, 0x79, 0x9b, 0x7a, 0xf2, 0xd1, 0xd5, 0x70, 0xdd, 0x70, 0xdd,
		0x25, 0x75, 0xdd, 0x66, 0x8f, 0xd9, 0xbe, 0xe9, 0x7f, 0x77, 0x59, 0x5f, 0xc6, 0x79, 0x0b, 0x6c,
		0x27, 0x6b, 0xad, 0xf0, 0xd6, 0x1f, 0x0c, 0x8f, 0x20, 0x5b, 0xeb, 0xf6, 0xae, 0xdd, 0xba, 0x68,
		0x5c, 0x3d, 0x35, 0xae, 0xef, 0xae, 0x5a, 0x1f, 0x5b, 0xcd, 0xfb, 0xa7, 0xf6, 0x1f, 0x77, 0x4d,
		0x51, 0x39, 0x0a, 0x6c, 0xb6, 0x27, 0x95, 0xe2, 0x21, 0xe9, 0x7c, 0x26, 0xef, 0xf5, 0xaf, 0x3f,
		0x3e, 0xdc, 0xb7, 0x2e, 0xb5, 0x2c, 0xbc, 0x28, 0xd1, 0x1b, 0x7c, 0x68, 0x5c, 0xfc, 0xfa, 0x7b,
		0xe3, 0xfe, 0xf2, 0xe9, 0xbe, 0x71, 0xdd, 0xb8, 0x29, 0xf2, 0x9b, 0x7c, 0xbc, 0xbd, 0x2f, 0xc7,
		0x8b, 0x34, 0x2f, 0x3f, 0x36, 0xd2, 0x4e, 0x48, 0xeb, 0xa8, 0xb6, 0x9d, 0x3b, 0xb4, 0xdf, 0x4c,
		0xb8, 0x4a, 0xa2, 0x09, 0x17, 0xca, 0x12, 0x2d, 0x92, 0xad, 0xeb, 0xe6, 0x39, 0x58, 0xff, 0x8d,
		0x0d, 0xb3, 0x33, 0xf2, 0xe8, 0xe3, 0x84, 0xbb, 0x8d, 0xf9, 0xb3, 0xda, 0x95, 0xe9, 0xf9, 0x0d,
		0xdf, 0x4f, 0x46, 0xb7, 0x8c, 0x82, 0xa6, 0xa6, 0xc5, 0x46, 0xae, 0xd9, 0x4b, 0x06, 0x95, 0x46,
		0xb1, 0xc0, 0xcc, 0x15, 0x62, 0xb9, 0x50, 0xda, 0xad, 0xdb, 0x63, 0x2e, 0xeb, 0x7d, 0x18, 0xbd,
		0x95, 0x3d, 0xb4, 0x2c, 0xa9, 0xc9, 0xe1, 0x14, 0x19, 0x05, 0xa2, 0x92, 0xc0, 0x2f, 0x26, 0x4e,
		0xb5, 0x59, 0x2f, 0x70, 0xf1, 0x62, 0xb4, 0xfa, 0x2f, 0x31, 0x73, 0x97, 0x74, 0xce, 0xc8, 0xe6,
		0x6a, 0xf5, 0x5b, 0x2d, 0x3f, 0xf3, 0x8a, 0xe7, 0xd5, 0xbc, 0xe1, 0x80, 0xb9, 0x5f, 0x4d, 0xcf,
		0x71, 0xbf, 0xeb, 0xdd, 0x2f, 0x86, 0x6d, 0x33, 0xcb, 0x8b, 0x7d, 0xea, 0x69, 0x1d, 0xb9, 0x55,
		0x57, 0xc5, 0xcc, 0xc6, 0xfa, 0x96, 0x30, 0x1b, 0x43, 0x89, 0x24, 0x21, 0x03, 0x5f, 0x68, 0x90,
		0x34, 0x04, 0xe0, 0x86, 0xfa, 0xdc, 0x90, 0x9e, 0x1b, 0xba, 0xf3, 0xc9, 0xe1, 0xa6, 0x16, 0x29,
		0xab, 0x96, 0x71, 0xf3, 0xac, 0xac, 0x91, 0x81, 0x4d, 0xf3, 0x93, 0xac, 0x3b, 0x50, 0xe2, 0xe8,
		0x92, 0x27, 0x9a, 0x14, 0x8b, 0x1e, 0x79, 0xa3, 0x45, 0xe1, 0xe8, 0x50, 0x38, 0x1a, 0x14, 0x8e,
		0xfe, 0xe4, 0x7c, 0x66, 0xd2, 0xee, 0x3b, 0x5a, 0x77, 0xb2, 0x96, 0x09, 0x27, 0x70, 0xb2, 0x4c,
		0xe1, 0x75, 0x09, 0x27, 0x81, 0xaf, 0xed, 0x14, 0x37, 0x7d, 0x21, 0x42, 0x5b, 0xcc, 0x0a, 0x9c,
		0x65, 0xda, 0x4c, 0xef, 0x3a, 0xaf, 0x1c, 0x21, 0x9e, 0x28, 0x4f, 0x21, 0xcd, 0x4f, 0x48, 0xf3,
		0x12, 0x8b, 0x12, 0x19, 0xbd, 0x7c, 0x46, 0xa0, 0x97, 0xb7, 0x51, 0xd4, 0xb8, 0xc8, 0x70, 0xdf,
		0xe8, 0x4a, 0x50, 0x71, 0xd3, 0x21, 0xb6, 0x83, 0x8f, 0x13, 0x10, 0xf0, 0xed, 0x21, 0xe4, 0xf8,
		0x15, 0xa0, 0x28, 0x8c, 0xdc, 0xb3, 0xe1, 0x31, 0x3d, 0x92, 0x75, 0x5d, 0x92, 0x98, 0x3b, 0x15,
		0xb8, 0xf6, 0x2e, 0x02, 0xcf, 0x5d, 0xdd, 0xec, 0x9f, 0x47, 0xcf, 0xe2, 0x2d, 0xfe, 0x22, 0xfc,
		0x39, 0x08, 0x11, 0x10, 0xab, 0xc7, 0x06, 0x15, 0xab, 0x80, 0xfd, 0xaa, 0x5f, 0x1e, 0x86, 0xfe,
		0x99, 0x2a, 0x80, 0x4f, 0x00, 0xc5, 0xf8, 0xcd, 0xb2, 0xb0, 0x39, 0xe6, 0x34, 0xc3, 0xa9, 0xe3,
		0x09, 0xfe, 0xed, 0x8f, 0xf2, 0xc0, 0x09, 0xee, 0xed, 0x0d, 0x5a, 0xb5, 0xe4, 0x36, 0x9a, 0xd1,
		0xba, 0x59, 0xcc, 0xe8, 0xf3, 0x59, 0x48, 0x11, 0xcb, 0x18, 0x59, 0xc4, 0x83, 0x83, 0xf0, 0x30,
		0xd3, 0x54, 0xf8, 0x53, 0x54, 0xd6, 0x31, 0xbd, 0xc7, 0xad, 0xa8, 0xe3, 0xcb, 0x14, 0x83, 0xfe,
		0x1a, 0x40, 0x3f, 0x40, 0xff, 0xb2, 0x77, 0x21, 0xc8, 0xa5, 0x9b, 0x1d, 0x64, 0x3b, 0x1a, 0x27,
		0x03, 0xf8, 0x17, 0x10, 0xf8, 0xa3, 0x75, 0x32, 0xca, 0x94, 0x28, 0xd1, 0x24, 0x72, 0x8d, 0x8a,
		0xd3, 0x2c, 0x54, 0x59, 0x43, 0x95, 0xb5, 0x85, 0xff, 0x50, 0x65, 0x4d, 0x6e, 0x05, 0x51, 0x65,
		0xad, 0x0c, 0x4b, 0x80, 0x2a, 0x6b, 0x2b, 0x90, 0x3d, 0x5a, 0x27, 0x03, 0xbc, 0x00, 0xbc, 0x00,
		0xbc, 0x00, 0xbc, 0x00, 0xbc, 0x00, 0xbc, 0x00, 0xbc, 0x14, 0x0a, 0xbc, 0xa0, 0x75, 0x32, 0xe0,
		0x0b, 0xe0, 0x0b, 0x5a, 0x27, 0xcf, 0x0e, 0x81, 0x22, 0xb1, 0xea, 0x2d, 0x16, 0x40, 0x4c, 0x7e,
		0x97, 0x00, 0x45, 0x62, 0x8b, 0x8e, 0x6b, 0xd0, 0x3a, 0x19, 0x68, 0x06, 0x68, 0x06, 0x64, 0x0c,
		0xc8, 0x18, 0x90, 0x31, 0x20, 0x63, 0x00, 0x5a, 0x8a, 0x02, 0x5a, 0xd0, 0x3a, 0x19, 0xf0, 0x05,
		0xf0, 0x05, 0xfd, 0x7a, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0xa6, 0x0c, 0xa8, 0x06,
		0xad, 0x93, 0x81, 0x65, 0x80, 0x65, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0xa0,
		0xa5, 0x20, 0xa0, 0x05, 0xad, 0x93, 0x01, 0x5f, 0x00, 0x5f, 0x40, 0xc5, 0x80, 0x8a, 0x01, 0x15,
		0x03, 0x2a, 0x06, 0x54, 0x4c, 0xde, 0x50, 0x4d, 0x89, 0x5b, 0x27, 0x27, 0xae, 0x12, 0x34, 0xa9,
		0x40, 0x22, 0x5a, 0x16, 0x61, 0x37, 0x41, 0x71, 0xd7, 0x87, 0xe9, 0x7d, 0x2f, 0xc6, 0xb7, 0x7d,
		0x6a, 0xd9, 0x93, 0x7e, 0xca, 0x79, 0x68, 0xa5, 0x8c, 0x7a, 0x72, 0xdc, 0x28, 0x14, 0x65, 0x25,
		0xd6, 0x00, 0x4d, 0xd4, 0x93, 0x4b, 0xc6, 0x85, 0x15, 0xbe, 0x9e, 0x1c, 0x87, 0x8d, 0xb1, 0x0c,
		0x8f, 0xb9, 0xfa, 0xb3, 0x69, 0x78, 0x7a, 0x77, 0xe8, 0xba, 0xcc, 0x96, 0xe8, 0xf3, 0xba, 0x62,
		0x2c, 0x14, 0xb3, 0x81, 0xd5, 0x41, 0x31, 0x9b, 0x15, 0x52, 0x83, 0x62, 0x36, 0x20, 0x8e, 0x40,
		0x1c, 0x09, 0xc9, 0x0c, 0xf6, 0xbd, 0x0a, 0x47, 0x1a, 0x61, 0xdf, 0x2b, 0x73, 0xd2, 0x08, 0xfb,
		0x5e, 0xe5, 0x61, 0x88, 0x50, 0xcc, 0x06, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0, 0x05, 0xe0,
		0x05, 0xe0, 0x05, 0xe0, 0xa5, 0xfc, 0xe0, 0x05, 0xc5, 0x6c, 0x00, 0x5f, 0x00, 0x5f, 0x50, 0xcc,
		0x66, 0x76, 0x08, 0xa4, 0xed, 0xa8, 0xb7, 0x58, 0x00, 0x31, 0xf9, 0x5d, 0x02, 0xa4, 0xed, 0x14,
		0x1d, 0xd7, 0xa0, 0x98, 0x0d, 0xd0, 0x0c, 0xd0, 0x0c, 0xc8, 0x18, 0x90, 0x31, 0x20, 0x63, 0x40,
		0xc6, 0x00, 0xb4, 0x14, 0x05, 0xb4, 0xa0, 0x98, 0x0d, 0xe0, 0x0b, 0xe0, 0x0b, 0x4e, 0x50, 0x81,
		0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x4c, 0x19, 0x50, 0x0d, 0x8a, 0xd9, 0x00, 0xcb, 0x00,
		0xcb, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0x40, 0x4b, 0x41, 0x40, 0x0b, 0x8a,
		0xd9, 0x00, 0xbe, 0x00, 0xbe, 0x80, 0x8a, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x98,
		0xbc, 0xa1, 0x1a, 0x14, 0xb3, 0x99, 0x14, 0xb3, 0x91, 0xae, 0x8e, 0xb0, 0x2b, 0x56, 0xd3, 0xe6,
		0x6a, 0x74, 0xdf, 0x0f, 0xa6, 0xe1, 0x5d, 0x84, 0x77, 0xcd, 0x41, 0xd5, 0x09, 0x67, 0xe8, 0x0f,
		0x86, 0xbe, 0xde, 0x77, 0xd9, 0x7f, 0x87, 0xcc, 0xee, 0x7e, 0x17, 0xaf, 0x39, 0xb1, 0x34, 0xd2,
		0x76, 0xd4, 0xb9, 0xf1, 0x5d, 0xc3, 0xf6, 0xba, 0xcc, 0xfc, 0x2a, 0x56, 0x19, 0xa9, 0xf4, 0x45,
		0x27, 0x66, 0xe7, 0xa7, 0x74, 0xd5, 0x6e, 0x22, 0x61, 0x0f, 0xd0, 0xb6, 0x44, 0xa5, 0x1b, 0x01,
		0x9c, 0x39, 0xc5, 0x97, 0xd7, 0xff, 0xfa, 0xff, 0x45, 0x6e, 0x2d, 0x87, 0x27, 0x25, 0xa0, 0x3a,
		0x05, 0x7e, 0x24, 0x02, 0x2d, 0x54, 0x78, 0x91, 0x12, 0x91, 0x48, 0xe0, 0x43, 0x12, 0x5c, 0x48,
		0x3d, 0xb5, 0xf4, 0x38, 0x90, 0x74, 0xb6, 0x53, 0xc2, 0x5f, 0x9d, 0xfc, 0x38, 0xfb, 0x71, 0x19,
		0x3f, 0x59, 0x47, 0x2f, 0x52, 0x0c, 0x10, 0x65, 0xa5, 0x4a, 0xe8, 0xe1, 0x51, 0x56, 0x6a, 0x95,
		0xd4, 0xa0, 0xac, 0x14, 0x28, 0x5c, 0x69, 0xec, 0x8c, 0x1d, 0x68, 0x59, 0x10, 0x83, 0x1d, 0x68,
		0x25, 0xf0, 0x7b, 0x71, 0x9a, 0xb1, 0x03, 0x9d, 0x3a, 0x4c, 0x5f, 0x5c, 0x02, 0xec, 0x40, 0x2b,
		0xbf, 0x1a, 0x65, 0xa5, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e, 0x00, 0x5e,
		0x00, 0x5e, 0x00, 0x5e, 0xc8, 0xc0, 0x0b, 0xca, 0x4a, 0x01, 0xbe, 0x00, 0xbe, 0xa0, 0xac, 0xd4,
		0xec, 0x10, 0x48, 0xa0, 0x53, 0x6f, 0xb1, 0x00, 0x62, 0xf2, 0xbb, 0x04, 0x48, 0xa0, 0x2b, 0x3a,
		0xae, 0x41, 0x59, 0x29, 0xa0, 0x19, 0xa0, 0x19, 0x90, 0x31, 0x20, 0x63, 0x40, 0xc6, 0x80, 0x8c,
		0x01, 0x68, 0x29, 0x0a, 0x68, 0x41, 0x59, 0x29, 0xc0, 0x17, 0xc0, 0x17, 0x9c, 0x65, 0x04, 0x15,
		0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x98, 0x32, 0xa0, 0x1a, 0x94, 0x95, 0x02, 0x96, 0x01, 0x96,
		0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x80, 0x96, 0x82, 0x80, 0x16, 0x94, 0x95,
		0x02, 0x7c, 0x01, 0x7c, 0x01, 0x15, 0x03, 0x2a, 0x06, 0x54, 0x0c, 0xa8, 0x18, 0x50, 0x31, 0x79,
		0x43, 0x35, 0x28, 0x2b, 0x35, 0x29, 0x2b, 0x25, 0x51, 0x17, 0x61, 0x57, 0xac, 0xa0, 0xd4, 0x6d,
		0x70, 0xc7, 0xbb, 0xe0, 0x86, 0xaa, 0xca, 0x4b, 0xec, 0x10, 0xae, 0xab, 0xe8, 0x7a, 0xa6, 0xba,
		0x8e, 0xc9, 0x66, 0x72, 0xf3, 0xbc, 0xac, 0xff, 0xc6, 0x86, 0x19, 0x1b, 0xe1, 0xc2, 0x28, 0x9d,
		0xbd, 0x6f, 0x74, 0x37, 0xe1, 0x76, 0xed, 0xca, 0xf4, 0xfc, 0x86, 0xef, 0x27, 0xab, 0x78, 0x30,
		0x72, 0xb5, 0x4d, 0x8b, 0x8d, 0x50, 0x9d, 0x97, 0xcc, 0x42, 0x8f, 0x3c, 0xc3, 0xcc, 0x15, 0x62,
		0x36, 0x58, 0xbb, 0x75, 0x7b, 0xcc, 0x65, 0xbd, 0x0f, 0xa3, 0x57, 0xb3, 0x87, 0x96, 0x25, 0x35,
		0x43, 0x9c, 0xb2, 0x94, 0x92, 0x0c, 0x25, 0x50, 0x7c, 0x7e, 0x45, 0x5f, 0x2f, 0x92, 0xf1, 0x82,
		0xb6, 0xfa, 0x2f, 0x31, 0x13, 0x9b, 0x74, 0x42, 0x15, 0x4c, 0xe4, 0xea, 0xf7, 0x5b, 0x7e, 0xfa,
		0xf9, 0xdf, 0x2c, 0xbc, 0xc7, 0xa6, 0xe7, 0x97, 0x7b, 0xee, 0x15, 0xeb, 0xba, 0x61, 0x1d, 0xe7,
		0x5f, 0x6a, 0xfa, 0xe8, 0x33, 0x8f, 0xad, 0xb9, 0xcc, 0x32, 0xbe, 0xeb, 0xc6, 0x0b, 0x5b, 0x71,
		0x70, 0x37, 0x0a, 0x3d, 0x66, 0xbf, 0xb4, 0xf0, 0xca, 0xab, 0xcb, 0xe9, 0xc4, 0x46, 0xdb, 0xeb,
		0xa2, 0xe8, 0xd9, 0xe8, 0x38, 0xb8, 0xe3, 0xaa, 0x37, 0xde, 0x10, 0xf5, 0x26, 0x8e, 0x66, 0x13,
		0x47, 0xa9, 0x8b, 0xd1, 0xe7, 0xf8, 0xc9, 0x38, 0x05, 0x23, 0xae, 0x10, 0x8c, 0xd6, 0xfb, 0xd2,
		0x1d, 0xc4, 0xbf, 0x4c, 0xc4, 0x5c, 0x8f, 0xbe, 0x15, 0xf3, 0x78, 0xeb, 0xeb, 0x19, 0x6d, 0xa4,
		0x3d, 0x92, 0xd0, 0x1a, 0x49, 0x16, 0x86, 0x97, 0x96, 0xe0, 0xa6, 0x1d, 0xb8, 0x69, 0x85, 0x84,
		0x0b, 0x27, 0x66, 0xa9, 0x36, 0x55, 0xf6, 0xd1, 0x02, 0x65, 0xd1, 0x4d, 0xbb, 0xef, 0xb8, 0xaf,
		0x81, 0x45, 0x08, 0x54, 0x3c, 0x81, 0xa7, 0x98, 0x96, 0xef, 0x89, 0x1b, 0x61, 0x93, 0xdf, 0x4e,
		0x54, 0xe0, 0x2a, 0x31, 0x1f, 0xc6, 0xc3, 0x7b, 0xf1, 0x08, 0x8a, 0x28, 0x8f, 0x25, 0xcc, 0x57,
		0x09, 0xf3, 0x52, 0x9c, 0x82, 0x44, 0x83, 0xbe, 0x92, 0x96, 0x8e, 0xd2, 0xba, 0x93, 0x75, 0x4c,
		0x38, 0x7d, 0x93, 0x25, 0x0a, 0xaf, 0x4b, 0x38, 0x05, 0x7c, 0x55, 0xd3, 0xb8, 0xc9, 0x56, 0x11,
		0x72, 0x55, 0x44, 0xd8, 0x64, 0xc9, 0x53, 0x69, 0xb2, 0x54, 0x9a, 0x1c, 0x15, 0x14, 0x46, 0x35,
		0xc1, 0x14, 0x6f, 0x7d, 0x33, 0x8d, 0xd9, 0xc6, 0xb3, 0xc5, 0xc4, 0x0b, 0xff, 0x85, 0xd7, 0xf3,
		0x96, 0x61, 0x63, 0x7d, 0x63, 0x68, 0x05, 0x33, 0xd6, 0x37, 0x2c, 0x8f, 0x6d, 0x49, 0x5d, 0x60,
		0x5e, 0xa5, 0xa0, 0xda, 0x59, 0xc8, 0x7f, 0xbd, 0x40, 0x4e, 0xa5, 0x49, 0x87, 0x69, 0x92, 0xaf,
		0x05, 0xfc, 0xec, 0x38, 0x16, 0x33, 0x6c, 0x89, 0x22, 0xc0, 0xd5, 0xea, 0x96, 0x92, 0x38, 0x33,
		0x11, 0xce, 0xe1, 0xec, 0xe7, 0x11, 0xf2, 0x3e, 0x8c, 0x43, 0x62, 0x87, 0xa1, 0x0f, 0xa5, 0xa2,
		0x6b, 0x12, 0x05, 0xee, 0x86, 0xcf, 0xf8, 0x9d, 0xfd, 0xf8, 0x32, 0xc5, 0xbe, 0xbe, 0x06, 0x5f,
		0x0f, 0x5f, 0x0f, 0x5f, 0x0f, 0x5f, 0x0f, 0x5f, 0x0f, 0x5f, 0x5f, 0x3a, 0x5f, 0x9f, 0xa3, 0x9d,
		0x19, 0xba, 0x7d, 0x07, 0xa1, 0xa9, 0xe0, 0xdf, 0x60, 0xb8, 0x1f, 0x0d, 0xdd, 0x18, 0x0d, 0xf7,
		0x74, 0xf9, 0xa5, 0x3b, 0x78, 0x0a, 0x3e, 0xb6, 0xa6, 0x03, 0xdf, 0x8e, 0xc7, 0x15, 0xdd, 0x63,
		0x58, 0xc3, 0x46, 0x26, 0x64, 0x47, 0xf8, 0x58, 0x11, 0x50, 0x6c, 0xdb, 0x45, 0xb1, 0x8d, 0x91,
		0x88, 0xbe, 0x6e, 0xab, 0x24, 0x21, 0x9a, 0xd1, 0xe3, 0x77, 0x52, 0xa8, 0x11, 0x0d, 0x27, 0x92,
		0x01, 0x65, 0xb7, 0x1d, 0x30, 0x9e, 0x1b, 0x79, 0x48, 0x20, 0x0e, 0x4e, 0xa4, 0x51, 0x12, 0xb7,
		0x99, 0x84, 0x14, 0x10, 0x73, 0x66, 0x51, 0x2a, 0x86, 0x97, 0xdc, 0xa1, 0xcd, 0x5c, 0x03, 0xa7,
		0x06, 0xa7, 0xb6, 0x42, 0x98, 0xf8, 0x7d, 0x59, 0xd2, 0x94, 0x20, 0x69, 0x46, 0x09, 0xae, 0x08,
		0x8c, 0xd2, 0xcc, 0x05, 0xc2, 0x7b, 0xea, 0xb1, 0x8b, 0x2f, 0x11, 0xe2, 0x48, 0x08, 0x38, 0x58,
		0x23, 0xb0, 0x46, 0xbb, 0x69, 0xb6, 0x93, 0xe2, 0xcc, 0x11, 0x90, 0x8b, 0x8e, 0x89, 0x95, 0x44,
		0x5a, 0x59, 0x28, 0x94, 0x86, 0x52, 0x79, 0xa8, 0x94, 0x88, 0x5c, 0x99, 0xc8, 0x95, 0x8a, 0x58,
		0xb9, 0xc4, 0x94, 0x4c, 0x50, 0xd9, 0xa4, 0x95, 0x6e, 0xaa, 0x7c, 0xa6, 0xdb, 0x1d, 0x9a, 0xbe,
		0x6e, 0xf6, 0xe4, 0x97, 0x3a, 0x52, 0xc4, 0xe9, 0x98, 0xef, 0x72, 0xd1, 0x69, 0x53, 0x56, 0x39,
		0x29, 0x95, 0x54, 0x85, 0xb2, 0x52, 0x2b, 0xad, 0x32, 0xe5, 0x55, 0xa6, 0xc4, 0x8a, 0x94, 0x59,
		0x4e, 0xa9, 0x25, 0x95, 0x5b, 0x9c, 0x15, 0xd9, 0x28, 0x73, 0x9e, 0xef, 0x9a, 0xf6, 0x0b, 0x85,
		0xc4, 0x4d, 0xdc, 0xe6, 0xfb, 0x8c, 0xce, 0x71, 0xc9, 0x34, 0x03, 0x16, 0xdc, 0x03, 0xde, 0xc0,
		0xa2, 0xca, 0xda, 0x3c, 0xc9, 0x3d, 0x62, 0xd8, 0x50, 0xd8, 0x50, 0xd8, 0xd0, 0x14, 0x6c, 0xa8,
		0xf8, 0x1e, 0x77, 0xac, 0x11, 0xad, 0x16, 0xd0, 0x88, 0xba, 0xec, 0xd5, 0xf1, 0x19, 0x29, 0x7e,
		0x9c, 0x0e, 0x09, 0xd3, 0x07, 0xd3, 0x07, 0xd3, 0x07, 0xf8, 0xa8, 0xce, 0xf2, 0xa5, 0x1a, 0xad,
		0x4b, 0x1e, 0xd7, 0x8f, 0xc6, 0x11, 0xdc, 0xfb, 0x9b, 0xee, 0xb6, 0x4d, 0x3f, 0xd2, 0xa4, 0x0f,
		0xcb, 0x4f, 0xeb, 0x9b, 0x50, 0x41, 0x00, 0x9e, 0x74, 0xe3, 0x35, 0xd2, 0x9c, 0x3c, 0xfd, 0x58,
		0x19, 0x6d, 0x58, 0x03, 0x6d, 0x08, 0xda, 0x10, 0xb4, 0x21, 0x68, 0x43, 0xe0, 0x3e, 0xe0, 0x3e,
		0xe0, 0x3e, 0xd0, 0x86, 0xa0, 0x0d, 0x61, 0x43, 0x61, 0x43, 0x41, 0x1b, 0x82, 0x36, 0x04, 0x6d,
		0x08, 0xd3, 0x07, 0xd3, 0x07, 0xf8, 0x58, 0x12, 0xf8, 0xe8, 0x31, 0xdb, 0xd7, 0x55, 0xc4, 0xcf,
		0x8b, 0x03, 0xc3, 0x0a, 0xc2, 0x0a, 0xc2, 0x0a, 0xc2, 0x0a, 0xe6, 0xd7, 0x0a, 0x2a, 0x00, 0x81,
		0x0b, 0xe3, 0xc2, 0x06, 0xc2, 0x06, 0xc2, 0x06, 0xc2, 0x06, 0xaa, 0xb3, 0x81, 0xd8, 0x40, 0x26,
		0xa8, 0x49, 0x21, 0x3f, 0xab, 0x45, 0xad, 0xb3, 0x4f, 0x37, 0xdf, 0xf2, 0x25, 0xf5, 0x17, 0x0b,
		0x61, 0xb4, 0x26, 0xf7, 0x14, 0x2a, 0x89, 0x21, 0xbe, 0x42, 0x1c, 0xab, 0x23, 0x7a, 0x78, 0x48,
		0xee, 0xd0, 0x10, 0x4e, 0xd4, 0x65, 0xe4, 0xc7, 0x71, 0xa2, 0x2e, 0xd1, 0x85, 0x92, 0x3b, 0x54,
		0x34, 0x3b, 0x53, 0x65, 0x6b, 0x89, 0x86, 0xd4, 0x98, 0x8c, 0x40, 0x70, 0x51, 0x5b, 0xa2, 0xc9,
		0xef, 0xf4, 0x48, 0xee, 0xf0, 0xa4, 0x93, 0x85, 0xf7, 0x85, 0x59, 0x03, 0xe6, 0xea, 0x46, 0xaf,
		0xe7, 0x32, 0xcf, 0x93, 0x37, 0x3a, 0x0b, 0xe3, 0xc1, 0xf8, 0xc0, 0xf8, 0xc0, 0xf8, 0x70, 0xcb,
		0x8c, 0x39, 0x90, 0xd4, 0xa0, 0x39, 0xfb, 0x73, 0x26, 0x31, 0x46, 0xf8, 0x4e, 0x99, 0xb7, 0x4f,
		0x9c, 0xce, 0xcc, 0xd7, 0x3a, 0xc1, 0xdc, 0x2c, 0x33, 0x10, 0x04, 0x63, 0xdd, 0x19, 0xbe, 0xcf,
		0x5c, 0x5b, 0x7a, 0xba, 0xa2, 0x01, 0xf7, 0xf6, 0x1e, 0x2b, 0xfa, 0x59, 0xe7, 0xe7, 0x63, 0x55,
		0x3f, 0xeb, 0x8c, 0x3f, 0x56, 0x83, 0xff, 0x1b, 0x7f, 0xae, 0x3d, 0x56, 0xf4, 0xfa, 0xe4, 0xf3,
		0xf1, 0x63, 0x45, 0x3f, 0xee, 0xec, 0x7f, 0xfe, 0x7c, 0xb0, 0xff, 0xe3, 0xe8, 0x8d, 0xff, 0xc2,
		0xbd, 0xbf, 0x3f, 0x7e, 0xfe, 0x3c, 0xf8, 0x71, 0xf3, 0x36, 0xfa, 0xf7, 0xea, 0xad, 0xf3, 0xcf,
		0xfd, 0x5f, 0xe4, 0x99, 0xaf, 0x4e, 0x96, 0xcc, 0x17, 0xad, 0xd4, 0x9d, 0x6c, 0x91, 0xd4, 0x9d,
		0xff, 0x1c, 0xc9, 0x86, 0xa1, 0xf7, 0x1b, 0xfa, 0xc7, 0xce, 0x8f, 0xca, 0xbb, 0xfa, 0xdb, 0xfe,
		0xf9, 0xfe, 0xde, 0xe2, 0xef, 0xce, 0xf7, 0x7f, 0x54, 0xde, 0x1d, 0xbf, 0xed, 0xed, 0xad, 0xf8,
		0xcb, 0x2f, 0xab, 0xc6, 0xd8, 0xff, 0xb9, 0xb7, 0xb7, 0x17, 0xca, 0xdb, 0x9c, 0x0c, 0x3e, 0x56,
		0xaa, 0x9d, 0x5f, 0x82, 0x8f, 0xe3, 0x7f, 0x23, 0x29, 0x4e, 0xf4, 0xe5, 0xfd, 0x95, 0xb2, 0xfb,
		0x8e, 0x4c, 0x05, 0xff, 0x3c, 0xef, 0xfc, 0xf3, 0x7c, 0xff, 0xc7, 0xc9, 0xdb, 0xe4, 0x73, 0xf0,
		0xef, 0xfe, 0xcf, 0xbd, 0x83, 0x7f, 0x7c, 0xfe, 0x7c, 0x70, 0xf0, 0x8f, 0xfd, 0xf1, 0x8b, 0x85,
		0xdf, 0xfb, 0xc7, 0xf8, 0xaf, 0xbf, 0x9c, 0x9f, 0x2f, 0xfd, 0x6a, 0x7f, 0xef, 0xef, 0x07, 0x79,
		0x50, 0xab, 0xb4, 0xdb, 0x6e, 0x0a, 0xba, 0x53, 0xae, 0xa6, 0x7f, 0xb1, 0xa3, 0x70, 0x37, 0x03,
		0x8c, 0x1f, 0x89, 0xa0, 0x49, 0x60, 0xec, 0xe0, 0x5c, 0xcd, 0x03, 0xb3, 0x0d, 0x19, 0x24, 0x36,
		0xfc, 0xa6, 0x06, 0xb5, 0x87, 0xd0, 0x00, 0xa1, 0x01, 0x42, 0x03, 0x01, 0xcd, 0x99, 0xd0, 0xfa,
		0x72, 0x1b, 0xe4, 0x92, 0x5b, 0x6f, 0xd8, 0xe2, 0x89, 0xdf, 0xe2, 0x11, 0x39, 0x7a, 0xa9, 0x66,
		0x7b, 0x45, 0xc0, 0x52, 0x8b, 0x5b, 0x68, 0xb4, 0xb7, 0xc8, 0xc8, 0xe2, 0xa2, 0xbd, 0x05, 0xdf,
		0x9a, 0x5b, 0xcc, 0xe8, 0xbb, 0xac, 0x2f, 0xd3, 0xde, 0xe2, 0x54, 0xe0, 0xda, 0xbb, 0xd0, 0xb8,
		0x1c, 0x1c, 0x84, 0x1d, 0xd5, 0xcd, 0x5e, 0x2e, 0x6c, 0x44, 0xe4, 0x4f, 0x46, 0x73, 0x22, 0x6e,
		0x2e, 0xe6, 0x86, 0xd9, 0x8e, 0x0d, 0x59, 0xb3, 0x0f, 0xb3, 0xb1, 0xc2, 0x6c, 0x98, 0x7d, 0x14,
		0x37, 0x5d, 0x10, 0x16, 0x14, 0x37, 0x95, 0x55, 0x1b, 0xc4, 0x3b, 0x22, 0x6a, 0x95, 0x4d, 0xb0,
		0x23, 0x5d, 0x9f, 0x80, 0xbf, 0x7e, 0x7c, 0x72, 0xff, 0x84, 0xa4, 0x62, 0xf5, 0x4a, 0x4a, 0xad,
		0xac, 0xca, 0x94, 0x56, 0x99, 0xf2, 0xaa, 0x50, 0x62, 0x39, 0x65, 0x96, 0x54, 0x6a, 0x3a, 0x26,
		0x83, 0x10, 0x8f, 0x53, 0xe2, 0xf3, 0x58, 0xbc, 0x7e, 0x18, 0x2c, 0xdb, 0xf9, 0x4c, 0xa8, 0xbf,
		0xf0, 0x8b, 0xf0, 0xe7, 0x20, 0x0f, 0xb3, 0x88, 0x67, 0x39, 0x86, 0xcf, 0x0a, 0xec, 0xed, 0xdc,
		0xa8, 0x30, 0xb9, 0x30, 0xb9, 0x30, 0xb9, 0x30, 0xb9, 0x64, 0x26, 0xf7, 0x71, 0x6a, 0x72, 0xff,
		0xaf, 0x3b, 0x74, 0x5d, 0x66, 0xfb, 0x7b, 0xfb, 0x87, 0x07, 0x07, 0x53, 0x16, 0xb6, 0x13, 0x5e,
		0x32, 0x6b, 0x87, 0xbc, 0x15, 0xbf, 0x8b, 0x46, 0xee, 0xb1, 0x6f, 0xda, 0x56, 0x9c, 0x42, 0x69,
		0x7e, 0x0b, 0xf6, 0x2f, 0xc5, 0x93, 0x05, 0xe8, 0x02, 0x2f, 0xa7, 0xab, 0xb3, 0x6f, 0xfe, 0xb9,
		0xcf, 0x2c, 0xf6, 0xca, 0x7c, 0xf7, 0xbb, 0xee, 0xd8, 0x7a, 0xf7, 0x8b, 0x61, 0xbf, 0x30, 0xda,
		0x60, 0x2c, 0x28, 0xa9, 0x43, 0x18, 0x8d, 0xa5, 0x1d, 0x88, 0x75, 0x4a, 0x74, 0xe0, 0x68, 0x8e,
		0x28, 0x44, 0x99, 0xca, 0x54, 0x09, 0xa0, 0x1a, 0x08, 0x20, 0x10, 0x40, 0x20, 0x80, 0x10, 0x8d,
		0x20, 0x1a, 0x41, 0x34, 0x82, 0x68, 0x04, 0x04, 0x10, 0x08, 0x20, 0x98, 0x5c, 0x98, 0x5c, 0x98,
		0x5c, 0x10, 0x40, 0x5b, 0x44, 0x00, 0xe5, 0x9f, 0x15, 0x40, 0xed, 0x11, 0xf5, 0x93, 0xac, 0xb2,
		0xe0, 0x48, 0xf4, 0xe9, 0x9e, 0xf5, 0xf3, 0x90, 0xe3, 0x26, 0xc6, 0xe1, 0x48, 0x71, 0x37, 0xd2,
		0x39, 0x6d, 0x35, 0x64, 0xc3, 0x22, 0x1b, 0x56, 0x19, 0xd3, 0xa2, 0x75, 0x9d, 0xe1, 0x48, 0x49,
		0x3d, 0x8a, 0xdc, 0xb6, 0x70, 0x24, 0x64, 0xb7, 0xe1, 0x40, 0x4f, 0x06, 0x0a, 0x56, 0x50, 0x8a,
		0xf3, 0xd9, 0x71, 0x7c, 0x97, 0x0d, 0xac, 0xef, 0xba, 0x37, 0x9e, 0x02, 0xa2, 0xb8, 0x7b, 0x61,
		0x5c, 0x44, 0xde, 0x69, 0x28, 0x2d, 0x82, 0x6f, 0x45, 0x4a, 0x5d, 0xd6, 0xf8, 0x3b, 0x74, 0x9a,
		0x27, 0x75, 0xc2, 0x08, 0x9c, 0xa2, 0x98, 0xc0, 0x7d, 0xb0, 0xf9, 0x4e, 0x55, 0x4a, 0x80, 0x46,
		0x09, 0x76, 0xc3, 0x63, 0xdc, 0x64, 0x5a, 0x45, 0x6c, 0xdd, 0x96, 0x86, 0xfd, 0xcd, 0xb0, 0x86,
		0x4c, 0xc1, 0xb8, 0x1f, 0x5d, 0xa3, 0x3b, 0x8a, 0x24, 0x2f, 0xcd, 0x17, 0x73, 0x7c, 0x9a, 0x9d,
		0x6c, 0xfc, 0xb7, 0x77, 0x84, 0x4b, 0x65, 0x7c, 0x2b, 0xdc, 0x52, 0xd1, 0x9e, 0xe6, 0x4f, 0x7d,
		0xf5, 0x76, 0xf2, 0x31, 0x4a, 0xa7, 0x80, 0xbb, 0x1f, 0x63, 0xbc, 0xf4, 0xdf, 0x21, 0xf3, 0x7c,
		0xdd, 0x65, 0x5d, 0x66, 0x7e, 0x65, 0x3d, 0x6a, 0x34, 0xb6, 0x30, 0x3a, 0x30, 0x19, 0x30, 0x19,
		0x30, 0x19, 0x30, 0x19, 0x30, 0x19, 0x30, 0x19, 0x30, 0x19, 0x30, 0x19, 0x30, 0xd9, 0x1a, 0x4c,
		0xa6, 0x82, 0x1d, 0x9b, 0x19, 0x19, 0x58, 0x0c, 0x58, 0x0c, 0x58, 0x0c, 0x58, 0x0c, 0x58, 0x0c,
		0x58, 0x0c, 0x58, 0x0c, 0x58, 0x0c, 0x58, 0x6c, 0x61, 0x59, 0x7a, 0x5f, 0xba, 0x03, 0xdd, 0xe8,
		0xfe, 0x45, 0x0c, 0xc4, 0xe6, 0x87, 0x05, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a,
		0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x5b, 0x85, 0xc2, 0x7a, 0xac, 0x6b, 0x99, 0x36,
		0x53, 0xb0, 0x4d, 0xb9, 0x7a, 0x78, 0xa0, 0x32, 0xa0, 0x32, 0xa0, 0x32, 0xa0, 0x32, 0xa0, 0x32,
		0xa0, 0x32, 0xa0, 0x32, 0xa0, 0x32, 0xa0, 0xb2, 0x95, 0xa8, 0xcc, 0xf4, 0xba, 0xce, 0x57, 0xe6,
		0x2a, 0x83, 0x65, 0x4b, 0xe3, 0x03, 0x97, 0x01, 0x97, 0x01, 0x97, 0x01, 0x97, 0x01, 0x97, 0x01,
		0x97, 0x01, 0x97, 0x01, 0x97, 0x01, 0x97, 0xad, 0xc2, 0x65, 0xa6, 0xdd, 0x77, 0xdc, 0x57, 0x55,
		0xa8, 0x6c, 0x71, 0x74, 0x60, 0x32, 0x60, 0x32, 0x60, 0x32, 0x60, 0x32, 0x60, 0x32, 0x60, 0x32,
		0x60, 0x32, 0x60, 0x32, 0x60, 0xb2, 0x55, 0x98, 0xcc, 0x56, 0x94, 0x48, 0x66, 0x23, 0x93, 0x0c,
		0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x0c, 0x38, 0x6c,
		0x2d, 0x0e, 0x73, 0xfa, 0x7d, 0xe6, 0xaa, 0x00, 0x62, 0x33, 0x03, 0x03, 0x89, 0x01, 0x89, 0x01,
		0x89, 0x01, 0x89, 0x01, 0x89, 0x01, 0x89, 0x01, 0x89, 0x01, 0x89, 0x01, 0x89, 0xad, 0x42, 0x62,
		0x2e, 0xb3, 0x98, 0xe1, 0x29, 0xcb, 0xe9, 0x5f, 0x1a, 0x1e, 0xa8, 0x0c, 0xa8, 0x0c, 0xa8, 0x0c,
		0xa8, 0x0c, 0xa8, 0x0c, 0xa8, 0x0c, 0xa8, 0x0c, 0xa8, 0x0c, 0xa8, 0x6c, 0x35, 0x2a, 0x53, 0x55,
		0x10, 0x76, 0xf5, 0xf0, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65,
		0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x0b, 0xcb, 0x62, 0xda, 0x5f, 0x0d, 0xcb, 0xec, 0xe9, 0xce,
		0xa0, 0xeb, 0xf4, 0x48, 0xbb, 0xc2, 0xcf, 0x8d, 0x0b, 0x1c, 0x06, 0x1c, 0x06, 0x1c, 0x06, 0x1c,
		0x06, 0x1c, 0x06, 0x1c, 0x06, 0x1c, 0x06, 0x1c, 0x06, 0x1c, 0x16, 0x8b, 0xc3, 0x46, 0x8b, 0xe3,
		0xa9, 0x00, 0x62, 0xe3, 0x81, 0x81, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80,
		0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x80, 0xc4, 0x16, 0x96, 0xc5, 0x77, 0x7c, 0xc3, 0xd2, 0x7b, 0xae,
		0x33, 0x18, 0x50, 0xee, 0x4f, 0xce, 0x0f, 0x0b, 0x14, 0x06, 0x14, 0x06, 0x14, 0x06, 0x14, 0x06,
		0x14, 0x06, 0x14, 0x06, 0x14, 0x06, 0x14, 0x56, 0x4e, 0x14, 0xb6, 0x93, 0xa2, 0xcc, 0x6b, 0x0d,
		0xdb, 0x76, 0x7c, 0x63, 0xb4, 0x94, 0x52, 0x62, 0xae, 0x79, 0xdd, 0x2f, 0xec, 0xd5, 0x18, 0x18,
		0xfe, 0x97, 0x91, 0x47, 0x38, 0x74, 0x06, 0xcc, 0xee, 0x06, 0x38, 0x69, 0xec, 0x34, 0x75, 0xe3,
		0x85, 0xd9, 0xfe, 0xe1, 0xec, 0xe7, 0xde, 0x97, 0xee, 0xe0, 0xd0, 0x1c, 0x39, 0x8e, 0xbe, 0xd1,
		0x65, 0xde, 0xf4, 0xe3, 0xa1, 0xe7, 0x1b, 0x3e, 0x3b, 0x0c, 0xbd, 0x8a, 0x0c, 0xf7, 0xa6, 0x79,
		0xbe, 0x3b, 0xec, 0xfa, 0x76, 0xe8, 0xa7, 0xee, 0x47, 0x77, 0x6f, 0x8c, 0x6e, 0xfe, 0x74, 0xf9,
		0xa5, 0x3b, 0x78, 0x6a, 0x4d, 0xee, 0xf8, 0x74, 0x31, 0xb9, 0xd7, 0x4e, 0x3a, 0x2b, 0x26, 0xb0,
		0x5a, 0x1a, 0xb3, 0x8d, 0x67, 0x4b, 0xdc, 0x73, 0x47, 0xde, 0x3a, 0x1c, 0x47, 0x50, 0x5e, 0xe4,
		0x4c, 0x97, 0x34, 0x76, 0xa6, 0xc0, 0xcc, 0x94, 0x58, 0x99, 0x0a, 0x23, 0x93, 0x63, 0x63, 0x72,
		0x4c, 0x4c, 0x8c, 0x85, 0xd3, 0xb5, 0x72, 0xd2, 0x98, 0x77, 0xb6, 0x63, 0xaf, 0xc5, 0x0c, 0x5b,
		0x46, 0x64, 0x42, 0x15, 0xaa, 0x56, 0x73, 0x6c, 0x6c, 0xbe, 0x30, 0x6b, 0xc0, 0x5c, 0xdd, 0xe8,
		0xf5, 0x5c, 0xe6, 0x79, 0xf2, 0x46, 0x67, 0x61, 0x3c, 0x18, 0x1f, 0x18, 0x1f, 0x18, 0x1f, 0x6e,
		0x99, 0x31, 0x07, 0x92, 0x1a, 0x34, 0x67, 0x7f, 0xce, 0x24, 0xc6, 0x08, 0xdf, 0x49, 0x2e, 0xb2,
		0x26, 0xa4, 0x20, 0xcc, 0xc1, 0xd7, 0x3a, 0xc1, 0xdc, 0x2c, 0xcd, 0x11, 0x05, 0x0d, 0x71, 0x67,
		0xf8, 0x3e, 0x73, 0x6d, 0x32, 0x22, 0x42, 0xdb, 0xdb, 0x7b, 0xac, 0xe8, 0x67, 0x9d, 0x9f, 0x8f,
		0x55, 0xfd, 0xac, 0x33, 0xfe, 0x58, 0x0d, 0xfe, 0x6f, 0xfc, 0xb9, 0xf6, 0x58, 0xd1, 0xeb, 0x93,
		0xcf, 0xc7, 0x8f, 0x15, 0xfd, 0xb8, 0xb3, 0xff, 0xf9, 0xf3, 0xc1, 0xfe, 0x8f, 0xa3, 0x37, 0xfe,
		0x0b, 0xf7, 0xfe, 0xfe, 0xf8, 0xf9, 0xf3, 0xe0, 0xc7, 0xcd, 0xdb, 0xe8, 0xdf, 0xab, 0xb7, 0xce,
		0x3f, 0xf7, 0x7f, 0xd1, 0xb2, 0x0e, 0xad, 0xde, 0xe5, 0x48, 0xea, 0x4e, 0xb6, 0x48, 0xea, 0xce,
		0x7f, 0x8e, 0x64, 0xc3, 0xd0, 0xfb, 0x0d, 0xfd, 0x63, 0xe7, 0x47, 0xe5, 0x5d, 0xfd, 0x6d, 0xff,
		0x7c, 0x7f, 0x6f, 0xf1, 0x77, 0xe7, 0xfb, 0x3f, 0x2a, 0xef, 0x8e, 0xdf, 0xf6, 0xf6, 0x56, 0xfc,
		0xe5, 0x97, 0x55, 0x63, 0xec, 0xff, 0xdc, 0xdb, 0xdb, 0x0b, 0xe5, 0x6d, 0x4e, 0x06, 0x1f, 0x2b,
		0xd5, 0xce, 0x2f, 0xc1, 0xc7, 0xf1, 0xbf, 0x91, 0x14, 0x27, 0xfa, 0xf2, 0xfe, 0x4a, 0xd9, 0x7d,
		0x47, 0xa6, 0x82, 0x7f, 0x9e, 0x77, 0xfe, 0x79, 0xbe, 0xff, 0xe3, 0xe4, 0x6d, 0xf2, 0x39, 0xf8,
		0x77, 0xff, 0xe7, 0xde, 0xc1, 0x3f, 0x3e, 0x7f, 0x3e, 0x38, 0xf8, 0xc7, 0xfe, 0xf8, 0xc5, 0xc2,
		0xef, 0xfd, 0x63, 0xfc, 0xd7, 0x5f, 0xce, 0xcf, 0x97, 0x7e, 0xb5, 0xbf, 0xf7, 0xf7, 0x83, 0x3c,
		0xa8, 0xd5, 0x4e, 0xba, 0xf7, 0x15, 0x75, 0xa7, 0x57, 0xa6, 0xe7, 0x37, 0x7c, 0xdf, 0x95, 0x73,
		0xa9, 0xd7, 0xa6, 0xdd, 0xb4, 0xd8, 0x08, 0x52, 0x78, 0x72, 0x4c, 0x9c, 0x76, 0x6d, 0x7c, 0x9b,
		0x19, 0x89, 0x96, 0x7b, 0xd3, 0x6e, 0xdd, 0x1e, 0x73, 0x59, 0xef, 0xc3, 0x77, 0xed, 0x7c, 0xd7,
		0x1e, 0x5a, 0x56, 0x8e, 0x43, 0x06, 0xb3, 0x27, 0x1f, 0x26, 0x98, 0x3d, 0x84, 0x06, 0x08, 0x0d,
		0x10, 0x1a, 0x08, 0x68, 0xce, 0x84, 0xcb, 0xd4, 0xcd, 0x1e, 0x45, 0x70, 0xf0, 0x3e, 0x2d, 0x4b,
		0xb3, 0xa3, 0x70, 0x9e, 0x65, 0xd9, 0x6d, 0x7a, 0x56, 0x9b, 0x4f, 0x30, 0x93, 0x4f, 0x4e, 0xb2,
		0x6f, 0x26, 0x9c, 0xbe, 0x91, 0xd2, 0x73, 0x59, 0x63, 0x31, 0x9f, 0x2c, 0xee, 0x83, 0x49, 0x7d,
		0xae, 0x98, 0x8f, 0x4d, 0x3a, 0x95, 0x82, 0x12, 0x48, 0x29, 0x79, 0x1c, 0xe6, 0x20, 0xe9, 0x86,
		0x49, 0x32, 0x31, 0xde, 0x2c, 0x94, 0xeb, 0xbf, 0xb1, 0x61, 0x8e, 0x79, 0xe7, 0x56, 0x7e, 0x4e,
		0xd7, 0xbf, 0x76, 0xfc, 0xcb, 0xac, 0x79, 0x11, 0x6d, 0x6c, 0x16, 0x36, 0x3d, 0x7f, 0x64, 0xe7,
		0xc7, 0x5f, 0xdf, 0x30, 0x31, 0x13, 0x23, 0xbe, 0xe1, 0x6b, 0x11, 0xe8, 0xa9, 0x6d, 0xf8, 0x22,
		0x07, 0xb8, 0x11, 0x01, 0x31, 0xbc, 0x60, 0x45, 0x18, 0x94, 0x08, 0x83, 0x0f, 0x41, 0x90, 0x21,
		0x27, 0xde, 0x97, 0x66, 0x32, 0x7b, 0x1a, 0xee, 0xe8, 0xcd, 0x0a, 0x71, 0xf2, 0xa9, 0x9c, 0xdf,
		0x15, 0x9c, 0x1b, 0x23, 0xe1, 0xd4, 0x5c, 0xb2, 0xbe, 0x31, 0xb4, 0x82, 0x99, 0xe9, 0x1b, 0x96,
		0x97, 0xd4, 0xdc, 0x70, 0x22, 0x76, 0x6e, 0x84, 0x2e, 0x82, 0xc8, 0x65, 0x10, 0xb8, 0x28, 0xe2,
		0x96, 0x46, 0xd8, 0xd2, 0x88, 0x5a, 0x12, 0x41, 0xd3, 0x42, 0x0f, 0x6e, 0x44, 0x2c, 0xb1, 0x33,
		0xc7, 0xb9, 0x13, 0x57, 0x12, 0x77, 0x96, 0x00, 0x87, 0xae, 0xf1, 0x64, 0x3b, 0x1c, 0x6f, 0x96,
		0xf4, 0x8d, 0x04, 0xdf, 0x44, 0x5b, 0xeb, 0x55, 0xd7, 0xe0, 0x98, 0xd5, 0x2f, 0xbf, 0xfc, 0x6a,
		0x2b, 0x5e, 0x2b, 0x28, 0x98, 0xf4, 0xf5, 0x24, 0xf6, 0x75, 0xe6, 0x0a, 0x2b, 0x7d, 0x3d, 0x89,
		0x79, 0xc4, 0x0d, 0x0e, 0x7a, 0xa3, 0xad, 0x4b, 0x62, 0xdb, 0x78, 0x6c, 0x59, 0x52, 0xdb, 0xc5,
		0x6d, 0xab, 0xb8, 0x6d, 0x13, 0xa7, 0x2d, 0xe2, 0x13, 0xc7, 0x4d, 0x0e, 0x55, 0xeb, 0x4e, 0xe6,
		0x3d, 0x21, 0x18, 0x0b, 0xbf, 0x4f, 0x8c, 0xc6, 0x2a, 0x40, 0x63, 0x40, 0x63, 0x40, 0x63, 0x40,
		0x63, 0x40, 0x63, 0xa5, 0x47, 0x63, 0x5f, 0x4f, 0x0e, 0x43, 0x27, 0xa2, 0x80, 0x5a, 0x98, 0x21,
		0x2e, 0x12, 0xbb, 0xb4, 0x99, 0x6b, 0xe0, 0xd6, 0xe0, 0xd6, 0x56, 0x08, 0x13, 0xbf, 0x37, 0xe3,
		0x65, 0x22, 0x13, 0x8a, 0x16, 0x9c, 0xd1, 0x76, 0x39, 0xa3, 0xa4, 0xa2, 0xca, 0x0b, 0xe7, 0xe5,
		0xe0, 0xbd, 0xa4, 0xf0, 0x0a, 0x0b, 0xb1, 0x8c, 0x30, 0x53, 0x08, 0xb5, 0xac, 0x70, 0x93, 0x09,
		0x39, 0x99, 0xb0, 0x13, 0x09, 0x3d, 0x9f, 0xf0, 0x73, 0x2a, 0x81, 0xb0, 0x32, 0x2c, 0x84, 0x27,
		0x38, 0x46, 0x82, 0x74, 0x8d, 0x54, 0x95, 0x8a, 0x58, 0xb9, 0xc4, 0x94, 0x4c, 0x50, 0xd9, 0xc4,
		0xc3, 0x21, 0xc2, 0xf0, 0x48, 0x32, 0x5c, 0x92, 0x9f, 0x38, 0x1c, 0x23, 0x81, 0xf1, 0x81, 0xf1,
		0x29, 0x83, 0xf1, 0x21, 0x4a, 0x5b, 0xa7, 0x48, 0x57, 0x27, 0x4b, 0x53, 0x47, 0x7a, 0x7a, 0xee,
		0xd2, 0xd2, 0x91, 0x16, 0x8e, 0xb4, 0x70, 0xa4, 0x85, 0xc3, 0xd5, 0xc3, 0xd5, 0x67, 0xe8, 0xea,
		0x91, 0x16, 0xbe, 0x4a, 0x36, 0x32, 0x49, 0x0b, 0xff, 0x7a, 0xb2, 0x3a, 0x31, 0x3c, 0xc9, 0x06,
		0x90, 0xf8, 0xfc, 0x70, 0xcc, 0x8d, 0x88, 0xad, 0x16, 0xb7, 0xd1, 0x82, 0xb6, 0x19, 0x44, 0x29,
		0x88, 0xd2, 0x54, 0x6c, 0x69, 0xb4, 0xe6, 0x16, 0x33, 0xfa, 0x2e, 0xeb, 0x8b, 0x2c, 0xf9, 0xc4,
		0x6c, 0x9e, 0x0a, 0x5c, 0x7b, 0x17, 0x9a, 0x97, 0x83, 0x83, 0xb0, 0x20, 0x92, 0xd9, 0xcb, 0x85,
		0x8d, 0x88, 0x3c, 0xca, 0x68, 0x4e, 0xc4, 0xcd, 0xc5, 0xdc, 0x30, 0xdb, 0xb1, 0xc5, 0x62, 0xf6,
		0x61, 0x36, 0x56, 0x98, 0x0d, 0xb3, 0x5f, 0x9a, 0xcd, 0x15, 0xc1, 0x1d, 0xc7, 0x25, 0x61, 0x11,
		0xda, 0x79, 0x94, 0x54, 0x8f, 0xdc, 0x06, 0x3d, 0x42, 0x6a, 0x83, 0x88, 0x47, 0x44, 0xad, 0xb2,
		0x09, 0x77, 0x44, 0xd5, 0x6d, 0xd9, 0x27, 0x51, 0x36, 0x00, 0xe1, 0x3f, 0x3d, 0xa7, 0x80, 0x81,
		0x20, 0x53, 0x4a, 0x4a, 0xe5, 0x24, 0x57, 0x52, 0x6a, 0x65, 0x55, 0xa6, 0xb4, 0xca, 0x94, 0x57,
		0x85, 0x12, 0xcb, 0x29, 0xb3, 0xa4, 0x52, 0xd3, 0x71, 0x19, 0x84, 0x78, 0x9c, 0x12, 0x9f, 0xc7,
		0xe2, 0xf5, 0xc3, 0x60, 0xd9, 0xce, 0x67, 0x42, 0xfd, 0x85, 0x5f, 0x84, 0x3f, 0x07, 0x87, 0x53,
		0x0a, 0x58, 0xe9, 0xdf, 0x1b, 0x3e, 0x2b, 0xb0, 0xb7, 0x73, 0xa3, 0xc2, 0xe4, 0xc2, 0xe4, 0xc2,
		0xe4, 0xc2, 0xe4, 0x92, 0x99, 0xdc, 0xc7, 0xa9, 0xc9, 0xfd, 0xbf, 0xee, 0xd0, 0x75, 0x99, 0xed,
		0xef, 0xed, 0x1f, 0x1e, 0x1c, 0x4c, 0x59, 0xd8, 0x4e, 0x78, 0xc9, 0xac, 0x1d, 0xf2, 0x56, 0xfc,
		0x2e, 0x1a, 0xb9, 0xc7, 0xbe, 0x69, 0x5b, 0x51, 0x21, 0xbc, 0xf9, 0x2d, 0xd8, 0xc1, 0x14, 0xdf,
		0x9e, 0xa7, 0x0b, 0xbc, 0x9c, 0xae, 0xce, 0xbe, 0xf9, 0xe7, 0x3e, 0xb3, 0xd8, 0x2b, 0xf3, 0xdd,
		0xef, 0xba, 0x63, 0xeb, 0xdd, 0x2f, 0x41, 0x97, 0x07, 0xd2, 0x60, 0x2c, 0x38, 0x39, 0x45, 0x18,
		0x8d, 0xa5, 0x1d, 0x88, 0x75, 0x0a, 0x59, 0x0c, 0x3e, 0x6e, 0x7f, 0x64, 0x8e, 0x2a, 0x14, 0xda,
		0x2d, 0x11, 0x9f, 0x4d, 0x91, 0x1d, 0xef, 0x64, 0x15, 0x3d, 0x36, 0x23, 0xa2, 0x04, 0x95, 0x3e,
		0x94, 0x53, 0x40, 0x35, 0x50, 0x40, 0xa0, 0x80, 0x40, 0x01, 0x21, 0x1e, 0x41, 0x3c, 0x82, 0x78,
		0x04, 0xf1, 0x08, 0x28, 0x20, 0x50, 0x40, 0x30, 0xb9, 0x30, 0xb9, 0x30, 0xb9, 0xa0, 0x80, 0xb6,
		0x88, 0x02, 0x2a, 0x02, 0x2f, 0x20, 0x50, 0x5e, 0x57, 0x82, 0x16, 0xd8, 0xa2, 0xf4, 0x54, 0x99,
		0x4c, 0xad, 0xdd, 0x8d, 0xb5, 0xd8, 0xbe, 0x9e, 0xcc, 0xb4, 0xe1, 0x8b, 0x3e, 0xdd, 0xb3, 0x7e,
		0x1e, 0x72, 0xdd, 0x9c, 0xc1, 0x68, 0x11, 0x3c, 0xf1, 0x2c, 0xb7, 0xc9, 0x00, 0x28, 0x21, 0xa0,
		0x12, 0x80, 0x20, 0x33, 0x56, 0xc8, 0xcc, 0x20, 0xcb, 0x0d, 0x47, 0x7b, 0xca, 0xc0, 0x72, 0x16,
		0xea, 0x68, 0x8f, 0x34, 0xd1, 0x19, 0x96, 0x06, 0x9c, 0x3b, 0xd8, 0x43, 0x16, 0x82, 0xaf, 0x1a,
		0x5c, 0x72, 0xb1, 0x04, 0x0b, 0x12, 0x6e, 0x7b, 0x64, 0x2f, 0x6b, 0x0e, 0x10, 0xdc, 0x2b, 0x32,
		0x17, 0x65, 0x8d, 0xef, 0xe5, 0x2b, 0x92, 0x2c, 0x79, 0xe6, 0x6a, 0x01, 0xa9, 0xcd, 0xa8, 0xf2,
		0xea, 0xab, 0xe3, 0x2b, 0xb1, 0xad, 0xd3, 0x91, 0x61, 0x58, 0x61, 0x58, 0x61, 0x58, 0x61, 0x58,
		0xb7, 0xc3, 0xb0, 0xaa, 0x01, 0xac, 0x94, 0x48, 0x15, 0x06, 0x10, 0x06, 0x10, 0x06, 0x90, 0xde,
		0x00, 0x7a, 0xbe, 0x6b, 0xda, 0x2f, 0xa4, 0xfd, 0x91, 0x0b, 0x68, 0xff, 0x14, 0x20, 0x4a, 0x32,
		0x28, 0x09, 0xcb, 0x07, 0xcb, 0x07, 0xcb, 0x07, 0xcb, 0x47, 0x7d, 0x65, 0xb9, 0xf6, 0x9b, 0xc3,
		0xcd, 0x3c, 0x64, 0xa0, 0x73, 0x49, 0x6c, 0x49, 0x32, 0xd0, 0xb1, 0x3d, 0x93, 0x91, 0x6f, 0xc0,
		0xf6, 0x0c, 0xb6, 0x67, 0x00, 0x25, 0x01, 0x25, 0xc1, 0x22, 0x82, 0x45, 0xc4, 0xf6, 0x0c, 0x0c,
		0x2b, 0x0c, 0x2b, 0x0c, 0x2b, 0x0c, 0x2b, 0xb9, 0x61, 0xc5, 0xf6, 0x0c, 0x0c, 0x20, 0x0c, 0x20,
		0x48, 0xca, 0x42, 0x93, 0x94, 0xd8, 0x9e, 0x81, 0xe5, 0x83, 0xe5, 0x83, 0xe5, 0x83, 0xe5, 0xe3,
		0x78, 0x76, 0x8f, 0xd9, 0xbe, 0x22, 0xbe, 0x72, 0x79, 0x68, 0x58, 0x42, 0x58, 0x42, 0x58, 0x42,
		0x58, 0xc2, 0xfc, 0x5a, 0x42, 0x05, 0x40, 0x70, 0x61, 0x5c, 0xd8, 0x40, 0xd8, 0x40, 0xd8, 0x40,
		0xd8, 0x40, 0x75, 0x36, 0x10, 0xc9, 0x3a, 0x51, 0xb2, 0x0e, 0xca, 0x42, 0xa8, 0x9d, 0x60, 0xb5,
		0x05, 0x21, 0x6e, 0xc3, 0x9b, 0xe4, 0xa0, 0x16, 0x84, 0x58, 0x4e, 0x95, 0x54, 0x2e, 0x95, 0x74,
		0x1d, 0x88, 0x1a, 0xea, 0x40, 0xa0, 0x0e, 0xc4, 0xc6, 0x67, 0x94, 0xa8, 0x03, 0x31, 0x1c, 0x69,
		0xaa, 0x47, 0x51, 0x09, 0x22, 0x1c, 0x09, 0xb5, 0x20, 0x90, 0x6c, 0x98, 0x21, 0xb6, 0x2d, 0x58,
		0xb2, 0xe1, 0xd8, 0x3f, 0xeb, 0x46, 0xef, 0x2b, 0x73, 0x3d, 0xdf, 0xf4, 0x98, 0xee, 0x8d, 0xa7,
		0x82, 0x28, 0x70, 0x8d, 0x19, 0x1f, 0x01, 0x2c, 0x02, 0x58, 0x04, 0xb0, 0xb9, 0x0b, 0x60, 0x43,
		0x27, 0x7a, 0x52, 0x27, 0x8c, 0x61, 0xdf, 0x13, 0x0c, 0x75, 0x1f, 0x34, 0x68, 0x90, 0xe9, 0x20,
		0x31, 0xfb, 0x1f, 0x8d, 0x12, 0xec, 0x86, 0xcd, 0xfe, 0xc9, 0xb4, 0x8a, 0xd8, 0xba, 0x2d, 0x0d,
		0xfb, 0x9b, 0x61, 0x0d, 0x99, 0x82, 0x71, 0x3f, 0xba, 0x46, 0x77, 0x14, 0x63, 0x5d, 0x9a, 0x2f,
		0x66, 0xd0, 0xe7, 0xa3, 0x42, 0x36, 0xfe, 0xdb, 0x3b, 0xc2, 0xa5, 0x32, 0xbe, 0x15, 0x6e, 0xa9,
		0xaa, 0xef, 0xeb, 0xf5, 0x93, 0xd3, 0x7a, 0xbd, 0x72, 0x7a, 0x74, 0x5a, 0x39, 0x3b, 0x3e, 0xae,
		0x9e, 0x54, 0x8f, 0x0b, 0xb4, 0x7a, 0x3b, 0xf9, 0x18, 0xa5, 0x53, 0xc0, 0x8d, 0x84, 0x10, 0x37,
		0x05, 0xec, 0x8a, 0xfb, 0xaa, 0xbb, 0xac, 0xcb, 0xcc, 0xaf, 0xac, 0x47, 0x0e, 0xcc, 0x96, 0x6e,
		0x00, 0x64, 0x06, 0x64, 0x06, 0x64, 0x06, 0x64, 0x06, 0x64, 0x06, 0x64, 0x06, 0x64, 0x06, 0x64,
		0x06, 0x64, 0xb6, 0x1a, 0x99, 0xf5, 0x58, 0xd7, 0x32, 0x6d, 0xa6, 0x0e, 0x99, 0x2d, 0xdd, 0x00,
		0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c,
		0xc8, 0x6c, 0x35, 0x32, 0x33, 0xed, 0xbe, 0xa3, 0xbb, 0xec, 0xbf, 0x43, 0xe6, 0xf9, 0xea, 0xe0,
		0xd9, 0xea, 0xbb, 0x00, 0xa3, 0x01, 0xa3, 0x01, 0xa3, 0x01, 0xa3, 0x01, 0xa3, 0x01, 0xa3, 0x01,
		0xa3, 0x01, 0xa3, 0x01, 0xa3, 0xad, 0xc6, 0x68, 0x2e, 0x7b, 0x36, 0xed, 0x9e, 0x3a, 0x74, 0xb6,
		0x38, 0x3e, 0x70, 0x19, 0x70, 0x19, 0x70, 0x19, 0x70, 0x19, 0x70, 0x19, 0x70, 0x19, 0x70, 0x19,
		0x70, 0x19, 0x70, 0x59, 0x1c, 0x2e, 0x1b, 0x9f, 0xe7, 0x1b, 0xba, 0x8a, 0x0e, 0x02, 0x2c, 0xdd,
		0x00, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8, 0x0c, 0xc8,
		0x0c, 0xc8, 0x2c, 0x0e, 0x99, 0x59, 0xc6, 0x77, 0xbd, 0xef, 0xb8, 0xff, 0x53, 0x05, 0xcc, 0xe6,
		0xc7, 0x07, 0x2e, 0x03, 0x2e, 0x03, 0x2e, 0x03, 0x2e, 0x03, 0x2e, 0x03, 0x2e, 0x03, 0x2e, 0x03,
		0x2e, 0x03, 0x2e, 0x5b, 0x87, 0xcb, 0x5c, 0x36, 0xb0, 0xbe, 0xab, 0xdc, 0xce, 0x5c, 0x71, 0x13,
		0x20, 0x34, 0x20, 0x34, 0x20, 0x34, 0x20, 0x34, 0x20, 0x34, 0x20, 0x34, 0x20, 0x34, 0x20, 0x34,
		0x20, 0xb4, 0x58, 0x84, 0xc6, 0x0c, 0x8f, 0x29, 0x45, 0x67, 0xf3, 0x37, 0x00, 0x32, 0x03, 0x32,
		0x03, 0x32, 0x03, 0x32, 0x03, 0x32, 0x03, 0x32, 0x03, 0x32, 0x03, 0x32, 0x03, 0x32, 0x8b, 0x43,
		0x66, 0x03, 0xeb, 0xbb, 0xaa, 0xed, 0xcc, 0x68, 0x68, 0xa0, 0x31, 0xa0, 0x31, 0xa0, 0x31, 0xa0,
		0x31, 0xa0, 0x31, 0xa0, 0x31, 0xa0, 0x31, 0xa0, 0x31, 0xa0, 0xb1, 0x38, 0x34, 0xa6, 0xb8, 0x64,
		0x06, 0xaa, 0x65, 0x00, 0x99, 0x01, 0x99, 0x01, 0x99, 0x01, 0x99, 0x01, 0x99, 0x01, 0x99, 0x01,
		0x99, 0x01, 0x99, 0x25, 0x44, 0x66, 0x9e, 0x63, 0x99, 0x5d, 0x53, 0x21, 0x32, 0x5b, 0xba, 0x01,
		0x90, 0x19, 0x90, 0x19, 0x90, 0x19, 0x90, 0x19, 0x90, 0x19, 0x90, 0x19, 0x90, 0x19, 0x90, 0x19,
		0x90, 0xd9, 0xc2, 0xb2, 0x98, 0xf6, 0x57, 0xc3, 0x32, 0x7b, 0xba, 0x33, 0xe8, 0x3a, 0x3d, 0x46,
		0x07, 0xc8, 0x16, 0xc6, 0x05, 0x0e, 0x03, 0x0e, 0x03, 0x0e, 0x03, 0x0e, 0x03, 0x0e, 0x03, 0x0e,
		0x03, 0x0e, 0x03, 0x0e, 0x03, 0x0e, 0x8b, 0xc5, 0x61, 0xa3, 0xc5, 0xf1, 0x54, 0x00, 0xb1, 0xf1,
		0xc0, 0x40, 0x62, 0x40, 0x62, 0x40, 0x62, 0x40, 0x62, 0x40, 0x62, 0x40, 0x62, 0x40, 0x62, 0x40,
		0x62, 0x40, 0x62, 0x0b, 0xcb, 0xe2, 0x3b, 0xbe, 0x61, 0xe9, 0x3d, 0xd7, 0x19, 0x0c, 0x28, 0x77,
		0x28, 0xe7, 0x87, 0x05, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03,
		0x0a, 0x03, 0x0a, 0x2b, 0x27, 0x0a, 0xdb, 0x49, 0x51, 0xe6, 0xb5, 0x86, 0x6d, 0x3b, 0xbe, 0x31,
		0x5a, 0x4a, 0x29, 0x31, 0xd7, 0xbc, 0xee, 0x17, 0xf6, 0x6a, 0x0c, 0x0c, 0xff, 0xcb, 0xc8, 0x23,
		0x1c, 0x3a, 0x03, 0x66, 0x8f, 0x4b, 0xfd, 0x87, 0xd5, 0xcb, 0x8c, 0x17, 0x66, 0xfb, 0x87, 0xb3,
		0x9f, 0xc7, 0xc9, 0x67, 0x87, 0xe6, 0xc8, 0x75, 0xf4, 0x8d, 0x2e, 0xf3, 0xa6, 0x1f, 0x0f, 0x3d,
		0xdf, 0xf0, 0xd9, 0x61, 0xe8, 0x57, 0x64, 0xd8, 0x37, 0xcd, 0xf3, 0xdd, 0x61, 0xd7, 0xb7, 0x43,
		0x4f, 0x75, 0x3f, 0xba, 0x7f, 0x63, 0x74, 0xfb, 0xa7, 0xcb, 0xe0, 0xf6, 0x4f, 0xad, 0xc9, 0x3d,
		0x9f, 0x2e, 0x26, 0x77, 0xdb, 0x49, 0x67, 0xd5, 0x04, 0x56, 0x4c, 0x63, 0xb6, 0xf1, 0x6c, 0x89,
		0x7b, 0xef, 0xc8, 0x63, 0x87, 0xe3, 0x08, 0xca, 0x8c, 0x9c, 0xf9, 0x92, 0xc6, 0xcf, 0x14, 0xb8,
		0x99, 0x12, 0x2f, 0x53, 0xe1, 0x64, 0x72, 0x7c, 0x4c, 0x8e, 0x8b, 0x89, 0xf1, 0x70, 0xba, 0x96,
		0x4e, 0x1a, 0xf7, 0x46, 0x32, 0xf3, 0xec, 0x38, 0x16, 0x33, 0x6c, 0x19, 0x91, 0x09, 0x55, 0xa8,
		0x5a, 0xcd, 0xb1, 0xb1, 0xf9, 0xc2, 0xac, 0x01, 0x73, 0x75, 0xa3, 0xd7, 0x73, 0x99, 0xe7, 0xc9,
		0x1b, 0x9d, 0x85, 0xf1, 0x60, 0x7c, 0x60, 0x7c, 0x60, 0x7c, 0xb8, 0x65, 0xc6, 0x1c, 0x7c, 0x3d,
		0x91, 0xd4, 0xa1, 0x39, 0x0b, 0x24, 0x11, 0x68, 0x6b, 0x77, 0x86, 0xef, 0x33, 0xd7, 0x96, 0x0e,
		0xb1, 0xb5, 0xbd, 0xbd, 0xf3, 0x9f, 0x8f, 0x15, 0xfd, 0xcc, 0xd0, 0xfb, 0x0d, 0xfd, 0x63, 0xe7,
		0x47, 0xe5, 0x5d, 0xfd, 0x6d, 0xff, 0x7c, 0x7f, 0x6f, 0xf1, 0x77, 0xe7, 0xfb, 0x3f, 0x2a, 0xef,
		0x8e, 0xdf, 0xf6, 0xf6, 0x56, 0xfc, 0xe5, 0x97, 0x55, 0x63, 0xec, 0xff, 0xdc, 0xdb, 0xdb, 0xab,
		0x1d, 0x3f, 0x56, 0xf4, 0xe3, 0xce, 0xcf, 0xda, 0x63, 0x45, 0xaf, 0x77, 0x46, 0xdf, 0xe9, 0xfc,
		0x7c, 0xac, 0x54, 0x3b, 0xbf, 0x04, 0x1f, 0xc7, 0xff, 0xee, 0x7f, 0xfe, 0x7c, 0xb0, 0xff, 0xe3,
		0xe8, 0x2d, 0xd9, 0x97, 0xf7, 0xf7, 0xf7, 0xfe, 0xfe, 0xf8, 0xf9, 0xf3, 0xe0, 0xc7, 0xcd, 0xdb,
		0xe8, 0xdf, 0xab, 0xb7, 0xce, 0x3f, 0xf7, 0x7f, 0x91, 0x55, 0x98, 0xbd, 0xbd, 0xc7, 0x3f, 0xcf,
		0x3b, 0xff, 0x3c, 0xdf, 0xff, 0x71, 0xf2, 0x36, 0xf9, 0x1c, 0xfc, 0xbb, 0xff, 0x73, 0xef, 0xe0,
		0x1f, 0x9f, 0x3f, 0x1f, 0x1c, 0xfc, 0x63, 0x7f, 0xfc, 0x42, 0xe1, 0xf7, 0xfe, 0x31, 0xfe, 0xeb,
		0x2f, 0xe7, 0xe7, 0x4b, 0xbf, 0xda, 0xdf, 0xfb, 0xfb, 0xc1, 0xe8, 0x91, 0x76, 0xd2, 0x8d, 0x7e,
		0x44, 0xd5, 0xe3, 0xca, 0xf4, 0xfc, 0x86, 0xef, 0xbb, 0x72, 0x2a, 0x72, 0x6d, 0xda, 0x4d, 0x8b,
		0x8d, 0x4c, 0x84, 0x27, 0x17, 0x5d, 0x8f, 0xa2, 0xfe, 0x99, 0x91, 0x68, 0xe3, 0x69, 0xed, 0xd6,
		0xed, 0x31, 0x97, 0xf5, 0x3e, 0x7c, 0xd7, 0xce, 0x77, 0xed, 0xa1, 0x65, 0xe5, 0x18, 0x02, 0x98,
		0x3d, 0x79, 0xb7, 0x6f, 0xf6, 0xe0, 0xea, 0xe1, 0xea, 0xe1, 0xea, 0x05, 0x34, 0x67, 0xc2, 0x4d,
		0xe8, 0x66, 0x8f, 0xc4, 0xd5, 0xa7, 0x65, 0x69, 0x76, 0x14, 0xce, 0xb3, 0x2c, 0x63, 0xa5, 0x82,
		0xa9, 0xe2, 0x13, 0xcd, 0xe4, 0xd3, 0x93, 0xec, 0x9b, 0x09, 0x27, 0x70, 0xa4, 0xf6, 0x5c, 0xf6,
		0x58, 0xcc, 0x2b, 0x8b, 0x7b, 0x61, 0x52, 0xaf, 0x2b, 0xe6, 0x65, 0x93, 0x4e, 0xa5, 0xa0, 0x0c,
		0xd2, 0xca, 0x1e, 0x87, 0x49, 0x48, 0x4e, 0x83, 0x26, 0x13, 0xe5, 0xcd, 0x82, 0xb9, 0xfe, 0x1b,
		0x1b, 0xe6, 0x99, 0x77, 0x7e, 0x29, 0xe6, 0x75, 0xfd, 0x8b, 0xc7, 0xbf, 0xce, 0x9a, 0x57, 0xd1,
		0x92, 0xa6, 0xa5, 0x4e, 0x51, 0x42, 0xa2, 0x74, 0xd3, 0xc8, 0xa0, 0x6f, 0xf8, 0x5a, 0x52, 0x00,
		0xc4, 0x03, 0x74, 0x44, 0x00, 0x0d, 0x2f, 0x70, 0x11, 0x06, 0x28, 0xc2, 0x40, 0x44, 0x10, 0x70,
		0xc8, 0x09, 0xf9, 0xa5, 0x99, 0xcc, 0xb2, 0x6a, 0xdd, 0xc9, 0x3a, 0x26, 0x9c, 0xbe, 0xe9, 0xbe,
		0x7c, 0x70, 0x5d, 0x52, 0xf7, 0x90, 0x48, 0xa8, 0x84, 0xd1, 0xb5, 0x08, 0x9a, 0x96, 0x41, 0xcf,
		0xa2, 0x68, 0x59, 0x1a, 0x1d, 0x4b, 0xa3, 0x61, 0x49, 0xf4, 0x4b, 0x0b, 0x1a, 0x92, 0x0a, 0x69,
		0x74, 0xc1, 0x78, 0x6b, 0x49, 0x9f, 0xc3, 0xae, 0xdc, 0x6b, 0x30, 0xbf, 0x4f, 0xa5, 0x4b, 0x00,
		0x61, 0xed, 0x92, 0xf5, 0x8d, 0xa1, 0x15, 0xcc, 0x65, 0xdf, 0xb0, 0x3c, 0xde, 0x4d, 0x2f, 0xc1,
		0x20, 0x54, 0x38, 0xf8, 0x94, 0x09, 0x3a, 0x29, 0x82, 0x4d, 0xd9, 0x20, 0x93, 0x2c, 0xb8, 0x24,
		0x0b, 0x2a, 0x89, 0x82, 0x49, 0xb5, 0x41, 0x8d, 0x70, 0xd0, 0x48, 0xb0, 0x29, 0x25, 0xb8, 0x19,
		0xc5, 0x11, 0xc6, 0xbc, 0xe3, 0x36, 0x1f, 0x2e, 0x7b, 0x75, 0x7c, 0x12, 0xdb, 0x31, 0x1d, 0x09,
		0x86, 0x03, 0x86, 0x03, 0x86, 0xa3, 0x50, 0x86, 0xa3, 0xd8, 0x41, 0x7b, 0x18, 0xcd, 0x1d, 0x86,
		0x38, 0x9c, 0x2a, 0xb2, 0x4e, 0x10, 0x70, 0x8d, 0x59, 0x29, 0xee, 0x80, 0x61, 0x7c, 0x99, 0xe2,
		0x78, 0xa1, 0x86, 0x78, 0x01, 0xf1, 0x02, 0xe2, 0x05, 0xb8, 0x7d, 0xb8, 0x7d, 0xb8, 0x7d, 0xc4,
		0x0b, 0x30, 0x1c, 0x30, 0x1c, 0x30, 0x1c, 0x88, 0x17, 0x66, 0xe2, 0x05, 0x8e, 0x3d, 0xe5, 0xd2,
		0x6c, 0xc4, 0x25, 0x2f, 0xb4, 0xb2, 0x71, 0x2f, 0xf3, 0x36, 0x1c, 0x4a, 0xc1, 0x86, 0x5e, 0xb2,
		0xb8, 0x8a, 0x2b, 0x9e, 0xe2, 0xde, 0xcc, 0xab, 0x61, 0x33, 0x4f, 0x89, 0x1d, 0x4e, 0x69, 0x33,
		0x2f, 0x82, 0x19, 0x91, 0x0a, 0xf0, 0xc7, 0xe9, 0x2b, 0xc6, 0x48, 0x1a, 0x9e, 0x89, 0x81, 0x14,
		0x4e, 0x70, 0x82, 0xcd, 0xc1, 0xed, 0x08, 0xf6, 0xb9, 0xc1, 0x84, 0x04, 0x88, 0xe0, 0x04, 0x0f,
		0xa5, 0x71, 0x8c, 0x09, 0xc0, 0xc0, 0x1a, 0x5f, 0xb6, 0xc3, 0xf1, 0x6e, 0x49, 0xdf, 0x49, 0xf8,
		0x5d, 0xb4, 0xb5, 0x9e, 0x75, 0xad, 0x53, 0x5f, 0x3d, 0x01, 0xcb, 0xaf, 0x37, 0xff, 0x9b, 0x85,
		0x17, 0xdd, 0xf4, 0x82, 0xfc, 0x2f, 0xb6, 0xe2, 0x8d, 0x62, 0xdf, 0x64, 0xfe, 0x15, 0xa6, 0x0f,
		0x3a, 0xf3, 0x90, 0x9a, 0xeb, 0x0c, 0x7d, 0xd3, 0x7e, 0xd1, 0x07, 0x8e, 0x65, 0x76, 0xbf, 0x2f,
		0x3d, 0x64, 0xa4, 0x3e, 0x0b, 0xdf, 0x5b, 0x78, 0xcd, 0xd5, 0x88, 0x22, 0xd6, 0x28, 0xaf, 0x33,
		0xbe, 0x73, 0x46, 0x76, 0xe0, 0x58, 0xab, 0x5e, 0x78, 0x83, 0x2d, 0x4d, 0x6c, 0x33, 0x13, 0xdb,
		0xc6, 0x25, 0x1b, 0x38, 0x7a, 0x30, 0x4e, 0x51, 0x88, 0xf3, 0xd7, 0x5a, 0x8f, 0xf5, 0x4d, 0x9b,
		0xf5, 0x74, 0x8f, 0xf9, 0xf1, 0x89, 0x5b, 0xd3, 0x0e, 0x1a, 0xb3, 0xdf, 0x8e, 0x79, 0xda, 0xf5,
		0x00, 0x6f, 0xa3, 0xaf, 0x4c, 0xe2, 0x1b, 0x13, 0x2c, 0x13, 0xaf, 0xeb, 0xe3, 0x76, 0x75, 0xdc,
		0xae, 0x2d, 0xd9, 0x32, 0x8a, 0x99, 0xb2, 0x4d, 0x70, 0x4c, 0xb3, 0x99, 0xf9, 0xf2, 0xe5, 0xd9,
		0x71, 0xd7, 0xaf, 0xf3, 0xd2, 0xfc, 0xce, 0x5f, 0x56, 0x90, 0x34, 0xbd, 0xf5, 0x02, 0x51, 0x60,
		0x60, 0xbf, 0x56, 0x60, 0x52, 0xc6, 0xf5, 0xb3, 0x92, 0xc1, 0x8f, 0xe8, 0xe7, 0xae, 0x2e, 0x49,
		0xc2, 0x5e, 0x32, 0xb1, 0x2b, 0x21, 0x24, 0x4f, 0x24, 0x96, 0x6a, 0x10, 0x39, 0xf7, 0xf6, 0x1b,
		0x67, 0x6e, 0xe9, 0xd2, 0x42, 0x73, 0xe5, 0x98, 0x0a, 0x8a, 0x6e, 0x7e, 0xb8, 0x6e, 0x3e, 0x91,
		0xde, 0x22, 0xaa, 0x9b, 0x4b, 0xe4, 0xd3, 0x61, 0xba, 0x79, 0x55, 0x21, 0xba, 0x90, 0xac, 0xe0,
		0x01, 0x2a, 0x1d, 0x10, 0x28, 0x0f, 0x95, 0x12, 0x91, 0x2b, 0x13, 0xb9, 0x52, 0xd1, 0x2a, 0x97,
		0x98, 0x92, 0x09, 0x2a, 0x9b, 0x38, 0x23, 0x14, 0x2b, 0x31, 0xe6, 0x80, 0xb2, 0xca, 0xc1, 0x99,
		0xc4, 0x18, 0xe1, 0x3b, 0xc9, 0x95, 0x38, 0x20, 0x2c, 0xb7, 0x68, 0x0e, 0xbe, 0xd6, 0x09, 0xe6,
		0x66, 0x69, 0x8e, 0x28, 0x4a, 0x2e, 0x52, 0x55, 0x84, 0x88, 0x06, 0xfc, 0x73, 0x5c, 0xea, 0xa1,
		0xf3, 0xf3, 0xb1, 0xaa, 0x9f, 0x85, 0xe5, 0x18, 0xaa, 0xc1, 0xff, 0x8d, 0x3f, 0xcf, 0x96, 0x69,
		0x08, 0x4b, 0x37, 0x44, 0xa5, 0x1c, 0xb8, 0x2f, 0xfc, 0x9b, 0x7c, 0x6d, 0xcf, 0x0e, 0xc5, 0x24,
		0xde, 0x3e, 0xb4, 0xfe, 0x83, 0x99, 0xcc, 0xb2, 0x4a, 0x2a, 0xad, 0xba, 0x9e, 0x6c, 0x9b, 0xba,
		0x4e, 0x6a, 0xb0, 0x54, 0xc7, 0x35, 0x5b, 0x4e, 0xdf, 0x16, 0x7f, 0xf9, 0x73, 0xd5, 0xd7, 0xaa,
		0xef, 0x4e, 0xdf, 0xce, 0x63, 0xfe, 0x72, 0xf2, 0x76, 0x9e, 0x70, 0x8c, 0xe3, 0xb7, 0xbd, 0xa5,
		0xaf, 0x8e, 0x7e, 0x5f, 0x8b, 0xbb, 0xa0, 0x1e, 0x73, 0xc1, 0x51, 0xdc, 0x05, 0x47, 0x31, 0x17,
		0xc4, 0x3e, 0x52, 0x2d, 0xe6, 0x82, 0xe3, 0xb7, 0x9f, 0x4b, 0xdf, 0xdf, 0x5b, 0xfd, 0xd5, 0x93,
		0xb7, 0xfd, 0x9f, 0x71, 0x7f, 0x3b, 0x7d, 0xfb, 0x79, 0xbe, 0xbf, 0x15, 0xc6, 0x0b, 0x72, 0x55,
		0x4c, 0xb9, 0xca, 0xa8, 0x94, 0x2a, 0x8a, 0x18, 0xa1, 0x88, 0xd1, 0xae, 0x16, 0x6e, 0xc5, 0x49,
		0x06, 0xf3, 0xc1, 0x28, 0x88, 0xe4, 0x11, 0xc9, 0x23, 0x92, 0xe7, 0x94, 0x18, 0xcf, 0x77, 0x4d,
		0xfb, 0x05, 0x05, 0x8c, 0x22, 0xa1, 0x50, 0x57, 0xc0, 0x68, 0x2e, 0x2d, 0xe0, 0x70, 0xe1, 0xc7,
		0xd9, 0xbd, 0xea, 0xc3, 0xb9, 0x8d, 0xcc, 0xb9, 0x9f, 0xb8, 0x8e, 0xab, 0xf1, 0xcf, 0x18, 0x4f,
		0x72, 0xbf, 0x90, 0xe5, 0x96, 0xb1, 0xd8, 0x85, 0x4d, 0xc2, 0xc7, 0xc6, 0x44, 0x71, 0x36, 0x26,
		0xe4, 0x53, 0xf0, 0x2d, 0x66, 0xf4, 0x5d, 0xd6, 0x97, 0x49, 0xc1, 0x3f, 0x15, 0xb8, 0xf6, 0x2e,
		0x34, 0x39, 0x07, 0x07, 0x61, 0x81, 0xfe, 0x40, 0xc3, 0x72, 0x60, 0x27, 0xf8, 0x8e, 0xbb, 0xae,
		0x70, 0x50, 0xc9, 0x8f, 0xbd, 0x2e, 0x4d, 0xa4, 0xa8, 0xa5, 0xa8, 0xc1, 0x52, 0xc0, 0x52, 0x6c,
		0x78, 0x44, 0x6c, 0x61, 0x22, 0xf0, 0x41, 0xe0, 0x83, 0x2d, 0x4c, 0x6c, 0x61, 0x26, 0x0d, 0x10,
		0xb1, 0x85, 0x89, 0x2d, 0x4c, 0x6c, 0x61, 0x2a, 0x50, 0x57, 0x6c, 0x61, 0x62, 0xab, 0x09, 0x5b,
		0x98, 0x90, 0x2b, 0x6c, 0x61, 0xa6, 0x87, 0x60, 0x77, 0xb1, 0x85, 0x89, 0x2d, 0xcc, 0x5d, 0x6c,
		0x61, 0x22, 0x92, 0x47, 0x24, 0x9f, 0x6d, 0x24, 0x8f, 0x2d, 0xcc, 0x05, 0xa1, 0xc8, 0xf9, 0x16,
		0x66, 0xf1, 0xba, 0xb2, 0x70, 0xd8, 0x66, 0xf4, 0x65, 0xa1, 0x96, 0x4b, 0xd5, 0xf2, 0x28, 0xd1,
		0xa9, 0x65, 0x7c, 0xbf, 0xbb, 0xe0, 0x76, 0x4f, 0x97, 0xe3, 0xdb, 0x3d, 0x30, 0xdf, 0x7b, 0xba,
		0x09, 0xc7, 0x7f, 0x60, 0x7e, 0xe9, 0x4a, 0x45, 0x09, 0xce, 0xb9, 0x8a, 0x8a, 0x4f, 0x63, 0xaf,
		0xcc, 0x79, 0x4a, 0x7c, 0xf6, 0x22, 0x9c, 0x11, 0xc7, 0x19, 0xf1, 0x65, 0x61, 0xe2, 0x3f, 0x21,
		0x3e, 0x73, 0x2d, 0xce, 0x87, 0xa7, 0x09, 0xb1, 0x71, 0x3e, 0x1c, 0xe7, 0xc3, 0xd5, 0x46, 0x95,
		0x48, 0xae, 0xc8, 0x22, 0x86, 0x11, 0x4e, 0xae, 0x78, 0x75, 0x7a, 0x04, 0x64, 0x4c, 0x30, 0x0a,
		0xc8, 0x18, 0x90, 0x31, 0x20, 0x63, 0x38, 0x25, 0x86, 0xd9, 0xc3, 0x57, 0xe6, 0x8e, 0x23, 0x0d,
		0x02, 0x46, 0xa6, 0x2e, 0x31, 0x46, 0xd3, 0x1e, 0xbe, 0x8e, 0x5e, 0xea, 0x0d, 0xdc, 0x31, 0xcc,
		0x15, 0xcc, 0x15, 0xcc, 0x15, 0xb8, 0xe3, 0x62, 0x70, 0xc7, 0x33, 0x0c, 0xcd, 0xcc, 0x67, 0x1c,
		0x7d, 0xc1, 0xd1, 0x17, 0xc4, 0x5c, 0x0a, 0x75, 0x1f, 0x47, 0x5f, 0xa8, 0xed, 0xc4, 0x58, 0xf6,
		0x98, 0x27, 0x6e, 0x2b, 0xa2, 0x11, 0xc0, 0xd1, 0xc0, 0x5e, 0x94, 0x85, 0xa3, 0x19, 0xc8, 0x41,
		0xfe, 0x05, 0xe5, 0x90, 0x0c, 0x7c, 0xaa, 0x08, 0x7c, 0x10, 0xf8, 0x14, 0x25, 0xf0, 0x11, 0x55,
		0xb9, 0x68, 0x00, 0xc1, 0x1d, 0x83, 0x58, 0xc1, 0x13, 0xda, 0x41, 0x20, 0x56, 0x45, 0x32, 0x95,
		0xa4, 0x54, 0x4d, 0x05, 0x2a, 0x4a, 0xad, 0xaa, 0xca, 0x54, 0x56, 0x99, 0xea, 0xaa, 0x51, 0x61,
		0x39, 0x55, 0x96, 0x54, 0x69, 0x32, 0xd5, 0x8e, 0x06, 0x32, 0x07, 0xfa, 0x80, 0x4e, 0x7e, 0x77,
		0x17, 0xce, 0xcc, 0xd1, 0x0a, 0x88, 0x1c, 0xf9, 0xa8, 0xcc, 0x00, 0xa8, 0x30, 0x04, 0x0a, 0x0d,
		0x82, 0x2a, 0xc3, 0xa0, 0xdc, 0x40, 0x28, 0x37, 0x14, 0x6a, 0x0d, 0x06, 0x8d, 0xe1, 0x20, 0x32,
		0x20, 0x74, 0xe4, 0x68, 0x6a, 0xea, 0xbf, 0x4b, 0x74, 0x82, 0x36, 0x6e, 0x0a, 0x1e, 0x49, 0x65,
		0x88, 0x56, 0xa7, 0x76, 0x97, 0x4e, 0xdc, 0x2a, 0xd1, 0xac, 0x5d, 0xe2, 0x13, 0x7d, 0xab, 0xb8,
		0x17, 0xd2, 0x93, 0x58, 0x4b, 0x37, 0x48, 0xf5, 0x58, 0xe9, 0x61, 0x78, 0xb3, 0xfd, 0x9f, 0x7b,
		0x8f, 0x55, 0xbd, 0xd6, 0x99, 0xfc, 0x70, 0xf4, 0x58, 0xd1, 0x6b, 0x1d, 0x92, 0xb3, 0x4a, 0x8b,
		0xff, 0x75, 0x54, 0x2c, 0x8a, 0x8a, 0x33, 0x72, 0xdb, 0xb7, 0x32, 0xa4, 0x23, 0xbe, 0xbd, 0x2b,
		0x90, 0x35, 0x3a, 0x81, 0x35, 0x5a, 0x2b, 0xf3, 0x38, 0x27, 0x9a, 0xfe, 0x39, 0xd1, 0xc3, 0xbd,
		0xea, 0xc8, 0x30, 0xbc, 0x1f, 0xdb, 0x8a, 0x6a, 0x67, 0xc9, 0x84, 0x8c, 0x4d, 0x02, 0x4c, 0x34,
		0xc4, 0x75, 0xcb, 0xc5, 0x95, 0xd6, 0x6f, 0xed, 0xe4, 0xeb, 0xb9, 0xe4, 0x9f, 0x87, 0xc0, 0x13,
		0x6b, 0xaf, 0x86, 0xf7, 0x97, 0xc5, 0xec, 0x17, 0xff, 0x8b, 0xee, 0x1a, 0xf6, 0x0b, 0xa3, 0xe7,
		0x5a, 0x96, 0xee, 0x00, 0xca, 0x05, 0x94, 0x0b, 0x28, 0x97, 0x2d, 0xa3, 0x5c, 0xa4, 0xf3, 0xd3,
		0xd2, 0x80, 0xdf, 0xca, 0x60, 0x77, 0x14, 0x62, 0xfe, 0xf3, 0xf3, 0xe7, 0x83, 0xcf, 0x9f, 0x0f,
		0xc6, 0x9f, 0xf7, 0x7f, 0xb2, 0x6f, 0x46, 0xd7, 0xa7, 0x74, 0x9d, 0x1d, 0xca, 0xc9, 0x50, 0x89,
		0xec, 0xd2, 0x9b, 0x91, 0xbc, 0x38, 0xeb, 0x4c, 0x37, 0x65, 0x24, 0xd3, 0x21, 0x97, 0xc6, 0x53,
		0x99, 0x1e, 0x39, 0x49, 0x15, 0x0a, 0x3f, 0x08, 0xa5, 0x4b, 0xd2, 0xcd, 0xbe, 0xc4, 0xcc, 0x13,
		0xee, 0x60, 0x91, 0x53, 0xd7, 0x44, 0xf0, 0x09, 0x5b, 0xd5, 0x39, 0x83, 0x45, 0xd8, 0xaa, 0xce,
		0x02, 0xee, 0x10, 0x24, 0x8e, 0xc6, 0xe2, 0x9b, 0x53, 0x9a, 0xf2, 0x85, 0xf3, 0x89, 0xa5, 0x53,
		0x33, 0x52, 0x40, 0xb3, 0x4a, 0x1e, 0xb3, 0xaa, 0x8a, 0x55, 0x61, 0x64, 0x61, 0x64, 0x61, 0x64,
		0xb7, 0xd6, 0xc8, 0x2e, 0x59, 0x93, 0x02, 0xda, 0x5a, 0xb1, 0xa6, 0x17, 0x6b, 0x68, 0x00, 0xfe,
		0x26, 0x18, 0xb1, 0x8b, 0x46, 0x65, 0x55, 0x6b, 0xb0, 0xaa, 0xb0, 0xaa, 0x05, 0xb3, 0xaa, 0xc8,
		0xb2, 0x94, 0x1f, 0x0e, 0x94, 0x3f, 0x28, 0xff, 0x14, 0x0d, 0x06, 0x1d, 0x97, 0xb8, 0x8b, 0x2c,
		0x4b, 0x64, 0x59, 0x22, 0xaf, 0x69, 0xd5, 0x0d, 0x90, 0x65, 0x29, 0xb0, 0x28, 0xc8, 0xb2, 0xa4,
		0x58, 0x19, 0x64, 0x59, 0xc2, 0x1a, 0xad, 0x96, 0x79, 0xa4, 0xad, 0x21, 0xcb, 0xb2, 0x40, 0x26,
		0x1a, 0xe2, 0x8a, 0x2c, 0xcb, 0x6c, 0x83, 0x9b, 0x5d, 0x64, 0x59, 0x72, 0x7a, 0x61, 0x64, 0x59,
		0x82, 0x72, 0x01, 0xe5, 0xb2, 0xed, 0x94, 0x0b, 0xb2, 0x2c, 0x91, 0x65, 0x99, 0xcd, 0x8c, 0x20,
		0xcb, 0xb2, 0xe0, 0x59, 0x96, 0x02, 0xcd, 0x8c, 0xe8, 0x26, 0x3f, 0xdd, 0xe2, 0x43, 0x61, 0x33,
		0xa4, 0x88, 0x9f, 0xde, 0x25, 0x02, 0x4f, 0x68, 0x6c, 0x98, 0xda, 0x12, 0x12, 0x69, 0x5a, 0x9a,
		0x1a, 0xa6, 0x49, 0x65, 0x61, 0x24, 0x6b, 0xd7, 0x34, 0x46, 0xc3, 0x0f, 0xcc, 0x0f, 0x3f, 0x69,
		0xa8, 0xe5, 0x9b, 0xd2, 0x22, 0xe7, 0xa1, 0x4a, 0xa7, 0x58, 0xae, 0x8e, 0x54, 0x6e, 0x8e, 0x74,
		0x7d, 0xce, 0x1a, 0xea, 0x73, 0x66, 0x1a, 0x8f, 0xa1, 0x87, 0xca, 0x66, 0x6a, 0x05, 0x3d, 0x54,
		0x50, 0x9b, 0x33, 0x53, 0x3a, 0x03, 0x3d, 0x54, 0xd0, 0x43, 0x25, 0xf1, 0xa4, 0xa3, 0x87, 0x0a,
		0xcc, 0x15, 0xcc, 0x55, 0x26, 0xec, 0x29, 0x7a, 0xa8, 0xa4, 0x16, 0x77, 0xa1, 0xf7, 0x36, 0x21,
		0x71, 0x84, 0xde, 0xdb, 0x32, 0xb2, 0xa8, 0xa2, 0xef, 0x76, 0x44, 0xe4, 0x6c, 0x71, 0xd7, 0xed,
		0xd9, 0xfe, 0xd6, 0x0a, 0x7a, 0x6e, 0xfb, 0xc6, 0x0b, 0x67, 0xc3, 0xed, 0xe8, 0x0a, 0x74, 0xdb,
		0x46, 0xb7, 0xed, 0x05, 0x31, 0xe2, 0x6f, 0xb5, 0x3d, 0xb9, 0x10, 0x7d, 0xb6, 0xd3, 0x84, 0xd2,
		0xe8, 0xb3, 0x8d, 0x3e, 0xdb, 0xe0, 0x88, 0xc1, 0x11, 0x83, 0x74, 0x01, 0xe9, 0x02, 0xd2, 0x05,
		0xa4, 0x4b, 0x4a, 0xd4, 0xee, 0x08, 0xec, 0x7d, 0x35, 0xac, 0x21, 0x81, 0xa9, 0x99, 0x0e, 0x05,
		0x7b, 0x03, 0x7b, 0x03, 0x7b, 0x23, 0xa0, 0x3e, 0xfe, 0x68, 0x34, 0x02, 0x8b, 0x23, 0x71, 0x08,
		0x99, 0xe6, 0xd0, 0x31, 0x61, 0xc1, 0x91, 0xa1, 0x69, 0xfb, 0x47, 0x35, 0xc2, 0x9a, 0x3a, 0x14,
		0x25, 0x75, 0xee, 0xc3, 0xc3, 0x12, 0x34, 0x59, 0xb1, 0x84, 0x09, 0xd7, 0xd7, 0xa6, 0xad, 0x20,
		0x89, 0x9f, 0xf4, 0xac, 0x45, 0x34, 0xec, 0x6f, 0xa1, 0xdf, 0xa1, 0x1e, 0xf7, 0xa3, 0x6b, 0x74,
		0x7d, 0xd3, 0xb1, 0x2f, 0xcd, 0x17, 0x73, 0xcc, 0x38, 0xd3, 0xe5, 0xeb, 0x13, 0x26, 0x58, 0x5f,
		0x1b, 0xdf, 0x0a, 0xb7, 0x54, 0xf5, 0xda, 0x59, 0xfd, 0xec, 0xe4, 0xb4, 0x76, 0x76, 0x5c, 0xa0,
		0x35, 0xcb, 0x49, 0x0a, 0x78, 0x27, 0xcb, 0x14, 0x70, 0x42, 0x83, 0xfc, 0x85, 0x7d, 0xd3, 0xc9,
		0xce, 0x73, 0x50, 0x9e, 0xe3, 0x20, 0x3f, 0xbf, 0xa1, 0xcd, 0x9d, 0xbb, 0x5c, 0x3c, 0x6e, 0x59,
		0x7b, 0xdb, 0xff, 0xc7, 0xfe, 0x2f, 0x5a, 0xd6, 0x72, 0xb1, 0x93, 0xee, 0x7d, 0xdf, 0x90, 0x82,
		0xbe, 0x79, 0x70, 0x9a, 0x14, 0x74, 0xec, 0xba, 0x2f, 0xef, 0xbd, 0x4d, 0xb6, 0xba, 0x26, 0x1f,
		0x84, 0x8a, 0x70, 0xab, 0xc9, 0x72, 0x16, 0x22, 0xec, 0x64, 0x88, 0x3a, 0x41, 0x67, 0x0f, 0xfe,
		0x1a, 0xfc, 0x75, 0x0a, 0x01, 0x2e, 0x41, 0x55, 0x54, 0x99, 0x2a, 0xa8, 0xcb, 0x55, 0x4f, 0x03,
		0x0d, 0xc3, 0x69, 0x08, 0x21, 0x4b, 0x81, 0xd3, 0x10, 0xb0, 0x14, 0x9b, 0x1e, 0x11, 0x3b, 0x5d,
		0x60, 0x9e, 0xd5, 0xa8, 0x11, 0xb9, 0x3a, 0xd1, 0xaa, 0x95, 0x5c, 0x28, 0x86, 0x9d, 0x2e, 0xec,
		0x74, 0xc1, 0xde, 0xc0, 0xde, 0x6c, 0x8f, 0xbd, 0xc1, 0x4e, 0xd7, 0xea, 0x79, 0xc1, 0x4e, 0x17,
		0x27, 0x15, 0x88, 0x9d, 0x2e, 0xec, 0x74, 0x61, 0xa7, 0x4b, 0xd6, 0x21, 0xd0, 0x8f, 0x82, 0x9d,
		0xae, 0xb5, 0x20, 0x19, 0x3b, 0x5d, 0x29, 0xcb, 0x25, 0x76, 0xba, 0xb0, 0xd3, 0xc5, 0x85, 0xd2,
		0x73, 0xb9, 0xd3, 0x85, 0x93, 0xa5, 0x84, 0x5a, 0x82, 0x93, 0xa5, 0x62, 0x52, 0xa8, 0xe2, 0x4c,
		0x69, 0xdb, 0x78, 0xd9, 0xee, 0x03, 0xa5, 0xd1, 0xf9, 0x4d, 0xd1, 0xd3, 0xa4, 0x3b, 0x1c, 0xaf,
		0x9a, 0xf4, 0x15, 0x49, 0x5e, 0x6d, 0x8d, 0xb8, 0x24, 0x15, 0x8f, 0xd5, 0x93, 0xb2, 0xfc, 0xca,
		0x2b, 0x5e, 0x57, 0x1b, 0x3f, 0x91, 0x1e, 0x3c, 0x91, 0x39, 0x7a, 0xe3, 0xf8, 0x43, 0xb5, 0x11,
		0xe8, 0x5b, 0x71, 0x4d, 0xcc, 0x44, 0xae, 0xdf, 0x54, 0xdb, 0xc8, 0xd2, 0x25, 0x61, 0xe1, 0x38,
		0x58, 0xb6, 0xa4, 0x2c, 0x1a, 0x37, 0x4b, 0xc6, 0xcd, 0x82, 0xf1, 0xb1, 0x5c, 0x7c, 0xc2, 0xbb,
		0x69, 0x93, 0x69, 0x79, 0xf9, 0x92, 0x1f, 0xa3, 0x5e, 0xbe, 0x14, 0xe7, 0xa9, 0x71, 0x9e, 0x7a,
		0xf2, 0x45, 0xce, 0x23, 0xaa, 0x62, 0x47, 0x53, 0x71, 0x9a, 0x5a, 0x4e, 0xf4, 0xa4, 0x45, 0x50,
		0x4e, 0x14, 0xd5, 0xa0, 0x69, 0xee, 0xd3, 0xd4, 0xc8, 0x44, 0x53, 0x23, 0xce, 0xb2, 0x62, 0x4d,
		0x26, 0xde, 0x64, 0x62, 0x4e, 0x23, 0xee, 0xe9, 0x44, 0xe5, 0xf2, 0x99, 0x68, 0xc2, 0x5c, 0x9e,
		0xe0, 0x06, 0x77, 0x56, 0xe1, 0x77, 0xda, 0x11, 0xe3, 0x32, 0x64, 0x5e, 0xfe, 0x15, 0x57, 0xa2,
		0x6e, 0x82, 0x28, 0x2f, 0x01, 0xde, 0xe1, 0x32, 0x83, 0x22, 0xe6, 0x8f, 0xd3, 0xec, 0xc1, 0x5b,
		0x6f, 0x83, 0xb7, 0xe6, 0x36, 0x53, 0x12, 0x89, 0xb2, 0x22, 0x09, 0xb2, 0x32, 0x89, 0xb1, 0x34,
		0x7a, 0xc9, 0x97, 0x00, 0x2b, 0x94, 0xf8, 0x2a, 0x8c, 0xa3, 0x6b, 0xd0, 0x4c, 0xe0, 0x68, 0xe0,
		0x68, 0xe0, 0x68, 0xe0, 0x68, 0xe0, 0xe8, 0x5c, 0xe2, 0x68, 0x8e, 0x6d, 0x40, 0x42, 0x77, 0x3d,
		0xd9, 0x28, 0x13, 0xf1, 0xd9, 0xe3, 0x6b, 0x41, 0x80, 0xc1, 0x71, 0xa7, 0xe5, 0xb8, 0x23, 0xb1,
		0x93, 0x3c, 0x66, 0x15, 0x0c, 0x81, 0xa2, 0x82, 0x70, 0xe1, 0x65, 0x39, 0x6a, 0x35, 0x4e, 0x3d,
		0xf4, 0xe4, 0x8f, 0x40, 0x4c, 0x06, 0x92, 0x3b, 0x00, 0x51, 0xc5, 0x01, 0x88, 0x5d, 0x1c, 0x80,
		0x28, 0xc8, 0x01, 0x08, 0x51, 0xa5, 0x8b, 0x06, 0x10, 0x2c, 0x72, 0x1b, 0x2b, 0x78, 0x42, 0x45,
		0x6f, 0x89, 0x55, 0x91, 0x4c, 0x25, 0x29, 0x55, 0x53, 0x81, 0x8a, 0x52, 0xab, 0xaa, 0x32, 0x95,
		0x55, 0xa6, 0xba, 0x6a, 0x54, 0x58, 0x4e, 0x95, 0x25, 0x55, 0x9a, 0x4c, 0xb5, 0xa3, 0x81, 0xc2,
		0x70, 0xcd, 0x65, 0xde, 0xd0, 0xf2, 0xe9, 0x9b, 0xe9, 0xcf, 0x0f, 0x8f, 0x4e, 0xfa, 0x39, 0x32,
		0x0c, 0xaa, 0x0c, 0x84, 0x72, 0x43, 0xa1, 0xdc, 0x60, 0xa8, 0x35, 0x1c, 0x34, 0x06, 0x84, 0xc8,
		0x90, 0xc8, 0x73, 0x6c, 0x7c, 0x26, 0x40, 0xf6, 0x18, 0x65, 0x2c, 0x18, 0xa8, 0x13, 0x8e, 0x29,
		0xd7, 0xe1, 0x8e, 0x7e, 0x9d, 0xd1, 0x8a, 0x9d, 0x8f, 0x6b, 0x0c, 0xe8, 0xbb, 0xe9, 0xc7, 0xc3,
		0x30, 0xf4, 0x13, 0xaa, 0xbc, 0x45, 0xb7, 0x16, 0x6f, 0x32, 0x5d, 0xab, 0x99, 0xaf, 0xfb, 0x06,
		0x21, 0x12, 0x9f, 0x0c, 0x08, 0x28, 0x0e, 0x28, 0x0e, 0x28, 0x9e, 0x0f, 0x28, 0x4e, 0x14, 0x6d,
		0xab, 0x89, 0xba, 0x89, 0x55, 0x1e, 0xe0, 0x1b, 0xe0, 0x1b, 0xe0, 0x9b, 0xda, 0x84, 0x44, 0x03,
		0x4a, 0xb5, 0x6b, 0xdf, 0xa8, 0x06, 0x12, 0x6d, 0xdc, 0x53, 0x8a, 0xe9, 0x95, 0x99, 0x17, 0x95,
		0x66, 0x26, 0x05, 0x73, 0xa3, 0xda, 0xec, 0xa4, 0x66, 0x7e, 0x52, 0x33, 0x43, 0xe9, 0x98, 0x23,
		0x5a, 0xb3, 0x44, 0x6c, 0x9e, 0xd4, 0x71, 0x04, 0x4b, 0x12, 0x4f, 0xd3, 0xe6, 0x3e, 0x4d, 0xb2,
		0x40, 0x11, 0x69, 0x40, 0x2f, 0x10, 0xf9, 0xf2, 0x78, 0xc4, 0xa4, 0x42, 0x0e, 0xc8, 0x85, 0x30,
		0xa2, 0x26, 0x21, 0x19, 0x08, 0xa9, 0x23, 0x82, 0xa8, 0xd5, 0xb4, 0x2d, 0xd3, 0x66, 0xf4, 0x71,
		0x49, 0x38, 0x2e, 0xe2, 0x12, 0xc4, 0x25, 0x88, 0x4b, 0xb6, 0x23, 0x2e, 0x21, 0xa6, 0x38, 0xd4,
		0x52, 0x1d, 0x8a, 0x4c, 0x0b, 0x62, 0x13, 0xc4, 0x26, 0x88, 0x4d, 0xa8, 0x63, 0x13, 0x6a, 0x53,
		0x15, 0x0d, 0x4c, 0xb1, 0xed, 0xb2, 0x51, 0x9b, 0xe4, 0xb7, 0x62, 0x52, 0x26, 0x56, 0x94, 0x1b,
		0xb1, 0x34, 0x8c, 0x59, 0x8a, 0x46, 0x2d, 0x2d, 0xe3, 0x96, 0xba, 0x91, 0x4b, 0xdd, 0xd8, 0xa5,
		0x6b, 0xf4, 0xd4, 0x18, 0x3f, 0x45, 0x46, 0x50, 0x3d, 0x51, 0xb3, 0xca, 0x70, 0x51, 0xa7, 0x74,
		0xc4, 0xc2, 0xaf, 0x33, 0x85, 0xf7, 0x20, 0xa9, 0xac, 0xbd, 0xe9, 0x3f, 0xb5, 0x2a, 0xbf, 0xab,
		0xa4, 0x32, 0x77, 0xd2, 0xd5, 0x39, 0x4d, 0xe1, 0x56, 0xb4, 0x95, 0xbd, 0xb3, 0x5f, 0xad, 0xe8,
		0xc5, 0x54, 0x54, 0x06, 0xcf, 0x18, 0x18, 0xc4, 0xde, 0x56, 0x51, 0x65, 0xf1, 0x8d, 0xf7, 0x55,
		0x58, 0xc5, 0x3a, 0x23, 0x33, 0xbf, 0x5a, 0x94, 0x8c, 0x6f, 0x5b, 0x27, 0x4a, 0xaa, 0x2a, 0x9f,
		0xe7, 0x5a, 0xa6, 0x76, 0xca, 0x71, 0x97, 0xce, 0x4e, 0x81, 0x35, 0x2f, 0x45, 0x87, 0x4e, 0x5a,
		0xd9, 0x3d, 0x31, 0xe4, 0x7a, 0x9f, 0xc2, 0xbd, 0xa8, 0x2b, 0xc3, 0x6f, 0xbc, 0x61, 0x2a, 0x95,
		0xe3, 0x33, 0x96, 0xfb, 0x9d, 0x62, 0x3d, 0xb7, 0xaa, 0x40, 0x88, 0xa4, 0xb2, 0x7d, 0x12, 0xf8,
		0x46, 0x53, 0xf9, 0x3e, 0x89, 0x77, 0x57, 0x56, 0x19, 0x7f, 0xe3, 0xcd, 0x49, 0x2a, 0xe7, 0xa7,
		0x2f, 0xb9, 0xf9, 0xe6, 0x2d, 0x15, 0x6d, 0x84, 0x47, 0xe3, 0x67, 0xbf, 0x21, 0x3e, 0xde, 0xe6,
		0x25, 0xdd, 0x17, 0xa7, 0x5f, 0x5a, 0xca, 0xe6, 0x41, 0x62, 0xed, 0x72, 0x13, 0x23, 0x01, 0x91,
		0x76, 0xba, 0x89, 0x1d, 0xbe, 0xaa, 0x2d, 0xae, 0x1a, 0xb6, 0xb8, 0x66, 0x6f, 0x81, 0x2d, 0x2e,
		0x6e, 0x3b, 0x89, 0x2d, 0x2e, 0x6c, 0x71, 0x65, 0x42, 0x3f, 0x60, 0x8b, 0x2b, 0x5f, 0xc6, 0x2d,
		0x75, 0x23, 0x97, 0xba, 0xb1, 0x4b, 0xd7, 0xe8, 0xa9, 0x8d, 0x19, 0xb1, 0xc5, 0xc5, 0x03, 0xbf,
		0xb0, 0xc5, 0x95, 0x7c, 0x5d, 0xb0, 0xc5, 0x55, 0x80, 0xd5, 0x9a, 0xe5, 0x48, 0xb0, 0xc5, 0xa5,
		0xf8, 0xbe, 0xd8, 0xe2, 0x2a, 0xad, 0x28, 0x61, 0x8b, 0xab, 0xb8, 0x77, 0xc1, 0x16, 0x57, 0x32,
		0x87, 0x8e, 0x2d, 0x2e, 0xb2, 0x1b, 0x62, 0x8b, 0x2b, 0x77, 0xcf, 0x8d, 0x2d, 0xae, 0xc4, 0xde,
		0x1d, 0x5b, 0x5c, 0x99, 0x8e, 0x88, 0x2d, 0x2e, 0xc1, 0x2d, 0x2e, 0x81, 0x7e, 0xd7, 0xe9, 0xad,
		0x2c, 0xce, 0xff, 0xa6, 0x29, 0x0b, 0x1a, 0xe9, 0x7e, 0x62, 0x7c, 0xdb, 0xe1, 0xf1, 0xff, 0x5d,
		0x46, 0xcf, 0xf8, 0xf4, 0x30, 0x79, 0xb0, 0xa7, 0xc6, 0xf8, 0xc1, 0x9e, 0x1e, 0x98, 0xdf, 0x36,
		0x5e, 0x9e, 0x5a, 0xe3, 0xe7, 0x2a, 0xd1, 0xb9, 0x64, 0x97, 0xf5, 0x99, 0xcb, 0xec, 0xae, 0x82,
		0xa3, 0xc9, 0xd3, 0xa1, 0x71, 0x3a, 0x59, 0x7a, 0x32, 0x71, 0x3a, 0x79, 0x7a, 0x03, 0x9c, 0x4e,
		0xc6, 0xe9, 0x64, 0x9c, 0x4e, 0x46, 0xea, 0x46, 0x76, 0x26, 0x28, 0x35, 0x53, 0x94, 0x8e, 0x49,
		0x2a, 0x46, 0x08, 0xa4, 0x32, 0x75, 0x43, 0xf7, 0x98, 0x9f, 0x4a, 0xfa, 0x46, 0x70, 0x23, 0xa4,
		0x70, 0xa4, 0x6d, 0xd4, 0x52, 0x34, 0x6e, 0x69, 0x19, 0xb9, 0xd4, 0x8d, 0x5d, 0xea, 0x46, 0x2f,
		0x5d, 0xe3, 0xa7, 0x8e, 0x59, 0xda, 0x2d, 0x45, 0x0a, 0x07, 0x7f, 0x9f, 0x62, 0x61, 0x14, 0xa6,
		0x30, 0x49, 0x60, 0xb6, 0x0f, 0x72, 0xdc, 0xff, 0x02, 0xb6, 0x82, 0xf5, 0x46, 0xa6, 0xda, 0x3b,
		0x0c, 0x6d, 0x76, 0xf4, 0x81, 0xbb, 0x7b, 0x72, 0xf6, 0xf2, 0x07, 0x66, 0x33, 0x5b, 0x36, 0x2b,
		0x22, 0x42, 0x90, 0xbf, 0x4f, 0x65, 0x8c, 0x90, 0xbf, 0x8f, 0x20, 0x10, 0x41, 0x20, 0x82, 0x40,
		0x04, 0x81, 0x08, 0x02, 0x11, 0x04, 0x22, 0x08, 0x44, 0x10, 0x88, 0x20, 0x10, 0x41, 0x20, 0x82,
		0xc0, 0x22, 0x04, 0x81, 0xc8, 0x70, 0xc9, 0x5a, 0x2c, 0xf2, 0x24, 0x0e, 0xf9, 0x4b, 0x72, 0xb9,
		0x8f, 0x1e, 0xad, 0x44, 0x79, 0x2e, 0xb4, 0x7c, 0x84, 0x12, 0x1e, 0x42, 0x59, 0x7e, 0x4b, 0x0d,
		0xf9, 0x2d, 0x45, 0x82, 0xda, 0xc8, 0x6f, 0x41, 0x57, 0xb0, 0xfc, 0x33, 0x02, 0xc8, 0x6d, 0xc9,
		0x26, 0xe2, 0x07, 0xad, 0x59, 0xc6, 0xf8, 0x07, 0x5d, 0xc1, 0xd6, 0x8c, 0x8d, 0xae, 0x60, 0x88,
		0x99, 0x46, 0x31, 0x13, 0x61, 0xe0, 0x8c, 0x7e, 0xf2, 0x39, 0x5b, 0x5c, 0x8d, 0x24, 0xc6, 0x23,
		0x08, 0x7f, 0x0b, 0xd9, 0xd9, 0x9e, 0x24, 0xb8, 0x25, 0x0d, 0x6a, 0xc9, 0xbb, 0xda, 0xd7, 0xd0,
		0xd5, 0x3e, 0x0f, 0x28, 0x11, 0x5d, 0xed, 0x33, 0x08, 0x3e, 0xb5, 0xd0, 0xa6, 0xba, 0xcc, 0x1b,
		0x5a, 0x3e, 0x3d, 0x8b, 0x35, 0x3f, 0x3c, 0x2d, 0x9b, 0x55, 0xc1, 0x69, 0x2d, 0xb0, 0x59, 0x60,
		0xb3, 0x76, 0xf2, 0x19, 0x26, 0xae, 0x36, 0x01, 0xd4, 0xa5, 0xda, 0x54, 0x44, 0x87, 0xc4, 0x51,
		0x21, 0x02, 0x82, 0xdc, 0x04, 0x04, 0xf2, 0x51, 0x9e, 0x04, 0x0a, 0xdf, 0x49, 0x71, 0xf1, 0xa8,
		0x16, 0x2d, 0xbb, 0xc5, 0xd2, 0xa4, 0x82, 0x16, 0x99, 0x68, 0x4d, 0x4c, 0x40, 0xf8, 0x97, 0x57,
		0x60, 0x69, 0xb5, 0xae, 0x63, 0xf7, 0xc6, 0xd3, 0x29, 0xbc, 0xac, 0xb3, 0xc7, 0x5d, 0x27, 0x63,
		0x09, 0x0a, 0x99, 0x5c, 0x20, 0x26, 0x8d, 0xbb, 0x28, 0x70, 0x16, 0x21, 0xae, 0xa2, 0xc2, 0x51,
		0xe4, 0xb8, 0x89, 0x1c, 0x27, 0xd1, 0xe2, 0xa2, 0x74, 0x0d, 0xa3, 0x6c, 0xe0, 0x44, 0x75, 0x0a,
		0x9d, 0xf6, 0xd4, 0x39, 0x39, 0x27, 0x52, 0x01, 0x27, 0x02, 0x4e, 0x64, 0x5b, 0x39, 0x91, 0xae,
		0x61, 0x59, 0x21, 0x90, 0xa1, 0x67, 0x44, 0x66, 0x07, 0x07, 0x1f, 0x02, 0x3e, 0x04, 0x7c, 0xc8,
		0x96, 0xf1, 0x21, 0xf4, 0x89, 0xee, 0x2a, 0x12, 0xdb, 0xd7, 0x27, 0xb2, 0x87, 0x8b, 0x7f, 0xbe,
		0x22, 0xcc, 0x8b, 0xfd, 0x53, 0xf4, 0x17, 0xba, 0xdc, 0xf6, 0x7c, 0x24, 0x80, 0x9a, 0xb6, 0xe7,
		0x07, 0x46, 0xdd, 0x75, 0x7c, 0xa7, 0xeb, 0x58, 0x3a, 0xfb, 0x2f, 0xbd, 0xdb, 0x58, 0x75, 0x13,
		0xb8, 0x0f, 0xb8, 0x0f, 0xb8, 0x8f, 0x2d, 0x73, 0x1f, 0x66, 0x8f, 0xd9, 0xbe, 0xe9, 0x7f, 0x57,
		0xe4, 0x42, 0x08, 0xcb, 0xf7, 0x6a, 0xad, 0xf0, 0x51, 0x3f, 0x18, 0x9e, 0xc2, 0xc4, 0xd6, 0xd6,
		0xcd, 0x43, 0xbb, 0x71, 0x75, 0xf5, 0x74, 0x77, 0x7f, 0xdb, 0xbe, 0xbd, 0xb8, 0xbd, 0x7a, 0x6a,
		0xff, 0x71, 0xd7, 0xa4, 0xd6, 0x8d, 0xa0, 0xd0, 0xbf, 0xa7, 0xa4, 0x42, 0xb8, 0xe2, 0x43, 0xc1,
		0x77, 0xad, 0x6b, 0x05, 0x29, 0x8f, 0xef, 0x8a, 0x36, 0x0d, 0xad, 0x4f, 0xd7, 0x77, 0x98, 0x87,
		0x5d, 0xed, 0xb2, 0x75, 0xdf, 0xbc, 0x68, 0x5f, 0xfd, 0xf1, 0x74, 0x71, 0x7b, 0x73, 0xd3, 0xbc,
		0x68, 0x37, 0x2f, 0x31, 0x2b, 0xbb, 0xda, 0xed, 0xc3, 0xdd, 0xc7, 0x23, 0x4c, 0xc4, 0xae, 0xf6,
		0xd0, 0x6e, 0xb4, 0x5b, 0x17, 0x98, 0x89, 0x5d, 0xad, 0xf5, 0xd0, 0x7a, 0xc0, 0x3c, 0xec, 0x6a,
		0x1f, 0x3e, 0xc1, 0x6e, 0x86, 0x16, 0x02, 0xf3, 0xb0, 0xab, 0x5d, 0xdd, 0x5e, 0x34, 0xae, 0x9e,
		0x1a, 0x9f, 0x3e, 0xdd, 0x37, 0x3f, 0x35, 0xda, 0xcd, 0xbc, 0x9f, 0xa6, 0xe8, 0xe4, 0x2d, 0xbe,
		0x40, 0x32, 0xc8, 0xdc, 0x78, 0xe9, 0xe7, 0x17, 0x4c, 0xb7, 0xbd, 0x49, 0x6a, 0xa6, 0x65, 0x93,
		0x96, 0xfd, 0x6a, 0xf8, 0xdd, 0x2f, 0xba, 0x69, 0xfb, 0xcc, 0xed, 0x1b, 0x5d, 0xc2, 0x04, 0xed,
		0xc5, 0x81, 0xb1, 0x2d, 0x99, 0x22, 0x85, 0x84, 0x6d, 0x49, 0x6c, 0x4b, 0xae, 0x19, 0x88, 0xb8,
		0xfe, 0xbd, 0x9a, 0xba, 0xf7, 0x68, 0xa5, 0x01, 0x36, 0x79, 0x17, 0x6c, 0x32, 0x29, 0xbc, 0xa7,
		0x2f, 0x35, 0x40, 0x87, 0x1c, 0x62, 0x75, 0x81, 0x0a, 0x43, 0xc4, 0x19, 0x18, 0x14, 0x1d, 0x98,
		0x37, 0x3c, 0x66, 0x1f, 0x25, 0x07, 0x32, 0x34, 0x47, 0x71, 0x66, 0xc9, 0xec, 0xa3, 0xe0, 0x00,
		0xb5, 0xb4, 0xab, 0x2b, 0x15, 0xa8, 0xb2, 0x44, 0x60, 0x94, 0x51, 0x71, 0x18, 0x88, 0xc5, 0x79,
		0x64, 0x20, 0xbd, 0xc5, 0x5f, 0x84, 0x3f, 0xd3, 0xd7, 0x00, 0xcc, 0x69, 0x41, 0xef, 0xe1, 0x73,
		0x0a, 0xfe, 0x68, 0xee, 0x2e, 0x70, 0x49, 0x70, 0x49, 0x70, 0x49, 0x70, 0x49, 0x70, 0x49, 0x09,
		0x5d, 0xd2, 0xe3, 0xd4, 0x25, 0xfd, 0x5f, 0x77, 0xe8, 0xba, 0xcc, 0xf6, 0xf7, 0xf6, 0x0f, 0x0f,
		0x0e, 0x0e, 0xa3, 0x6f, 0x74, 0xc2, 0x4b, 0x66, 0xed, 0xac, 0xb7, 0xe2, 0x77, 0xd1, 0xc8, 0x3d,
		0xf6, 0x0d, 0xa5, 0x4a, 0x13, 0xa9, 0x6f, 0x69, 0xca, 0xee, 0xcc, 0x70, 0xef, 0x0b, 0x44, 0x33,
		0x69, 0xff, 0x12, 0xd4, 0x05, 0xcd, 0x9a, 0xac, 0x43, 0x5d, 0x50, 0x90, 0x75, 0x20, 0xeb, 0x40,
		0xd6, 0x21, 0x32, 0x42, 0x64, 0x84, 0xc8, 0x08, 0x91, 0x11, 0xc8, 0x3a, 0x90, 0x75, 0x20, 0xeb,
		0xe0, 0x92, 0xe0, 0x92, 0xe0, 0x92, 0xe0, 0x92, 0x40, 0xd6, 0x81, 0xac, 0x2b, 0x34, 0x59, 0x87,
		0x72, 0xd9, 0xaa, 0xd6, 0x3b, 0x57, 0xeb, 0x9c, 0x61, 0xe5, 0xec, 0x8b, 0xe8, 0xa1, 0x9e, 0xae,
		0x47, 0x0f, 0xd5, 0x8a, 0x9e, 0xa9, 0xb0, 0xd9, 0xda, 0x36, 0x33, 0x5f, 0xbe, 0x3c, 0x3b, 0x2e,
		0x49, 0x2f, 0xd8, 0x85, 0x84, 0xed, 0xb9, 0xb1, 0x91, 0xb3, 0x9d, 0x04, 0xef, 0x22, 0x67, 0x1b,
		0x39, 0xdb, 0xb1, 0xaf, 0x84, 0x9c, 0xed, 0x3c, 0x85, 0xc2, 0xd8, 0x06, 0x4a, 0x27, 0xd8, 0xc5,
		0x36, 0x50, 0xae, 0xdb, 0xc3, 0x05, 0x9e, 0xde, 0x63, 0xbe, 0xee, 0x0c, 0xe4, 0x4a, 0xc0, 0x26,
		0x04, 0x15, 0xb3, 0xb7, 0x02, 0x07, 0x87, 0xc6, 0x71, 0x5b, 0xcc, 0xc2, 0xa1, 0x71, 0x5c, 0x2a,
		0x66, 0x46, 0x77, 0x99, 0xe7, 0xbb, 0x66, 0xd7, 0x67, 0x3d, 0xea, 0x46, 0x01, 0x4b, 0x58, 0x47,
		0x69, 0x3b, 0x39, 0x05, 0x63, 0x5f, 0xb2, 0xbe, 0x31, 0x6e, 0xd1, 0xa2, 0x35, 0x6e, 0xfe, 0xd8,
		0x86, 0xad, 0x26, 0xd2, 0x80, 0x39, 0x56, 0x08, 0x09, 0x43, 0x67, 0xb8, 0x39, 0xb8, 0x39, 0xb8,
		0x39, 0xb8, 0xb9, 0x05, 0x89, 0x2f, 0xf8, 0x76, 0xd3, 0xca, 0x02, 0xb0, 0x07, 0x07, 0x87, 0x01,
		0xaf, 0xcc, 0x7a, 0x23, 0xbb, 0xe9, 0x1d, 0xce, 0x5a, 0xd1, 0xf9, 0x9f, 0x0e, 0x73, 0x9d, 0x19,
		0x81, 0xbd, 0xa3, 0x74, 0xf6, 0x14, 0xe6, 0x24, 0x02, 0xb9, 0xde, 0x09, 0x2d, 0x07, 0x72, 0xbd,
		0x41, 0xf2, 0x81, 0xe4, 0x03, 0xc9, 0x07, 0x92, 0x0f, 0xd1, 0x0f, 0xa2, 0x1f, 0x44, 0x3f, 0x20,
		0xf9, 0x40, 0xf2, 0x81, 0xe4, 0x03, 0xc9, 0x07, 0x37, 0x07, 0x37, 0x07, 0x37, 0x07, 0x92, 0x0f,
		0x24, 0x1f, 0x48, 0xbe, 0xbc, 0x92, 0x7c, 0xc8, 0x11, 0x57, 0xb5, 0xe4, 0x79, 0x5b, 0xea, 0x1c,
		0xa5, 0x89, 0xdf, 0x84, 0x8f, 0xf5, 0xc0, 0xfc, 0xe2, 0x26, 0x8a, 0x8f, 0x61, 0x87, 0x8a, 0x34,
		0xf1, 0x99, 0x91, 0x91, 0x24, 0x9e, 0x22, 0x88, 0x45, 0x92, 0x38, 0x92, 0xc4, 0xd7, 0x0c, 0x84,
		0x24, 0xf1, 0x9c, 0xc6, 0xb5, 0xd8, 0x3f, 0xca, 0x20, 0x6e, 0xc5, 0xfe, 0x91, 0xc4, 0x80, 0xd8,
		0x3f, 0x02, 0xb1, 0x06, 0x62, 0x0d, 0xc4, 0x5a, 0x79, 0x88, 0x35, 0xec, 0x1f, 0xf1, 0xf8, 0x93,
		0xad, 0xdb, 0x3f, 0x22, 0x0c, 0x96, 0x63, 0x45, 0x90, 0x2c, 0x6c, 0x86, 0x8b, 0x83, 0x8b, 0x83,
		0x8b, 0x83, 0x8b, 0x5b, 0x90, 0xf8, 0x6d, 0xd8, 0x3b, 0x9a, 0xda, 0xd0, 0xd9, 0xcf, 0x63, 0x8a,
		0x19, 0xbb, 0x47, 0xc9, 0xf5, 0xb1, 0xbc, 0xbb, 0x47, 0x33, 0x52, 0x81, 0x04, 0xf1, 0x84, 0x96,
		0x03, 0x09, 0xe2, 0x20, 0xf8, 0x40, 0xf0, 0x81, 0xe0, 0x03, 0xc1, 0x87, 0xe8, 0x07, 0xd1, 0x0f,
		0xa2, 0x1f, 0x10, 0x7c, 0x20, 0xf8, 0x40, 0xf0, 0x81, 0xe0, 0x83, 0x8b, 0x83, 0x8b, 0x83, 0x8b,
		0x03, 0xc1, 0x07, 0x82, 0x0f, 0x04, 0x5f, 0x1e, 0x09, 0x3e, 0x24, 0x87, 0xab, 0x5a, 0xf0, 0x7c,
		0x2d, 0x74, 0x8e, 0x52, 0xc3, 0xc7, 0xc8, 0xa6, 0xd0, 0x89, 0xe1, 0xbe, 0xf1, 0xa2, 0x22, 0x2b,
		0x7c, 0x32, 0x2c, 0x52, 0xc2, 0x53, 0x84, 0xae, 0x48, 0x09, 0x47, 0x4a, 0xf8, 0x9a, 0x81, 0x90,
		0x12, 0x9e, 0xd3, 0x68, 0x16, 0x3b, 0x46, 0x19, 0x44, 0xab, 0xd8, 0x31, 0x92, 0x18, 0x10, 0x3b,
		0x46, 0xa0, 0xd3, 0x40, 0xa7, 0x81, 0x4e, 0x2b, 0x0f, 0x9d, 0x86, 0x1d, 0x23, 0x1e, 0x7f, 0xb2,
		0x75, 0x3b, 0x46, 0x54, 0x61, 0x72, 0xac, 0xfc, 0xd1, 0x04, 0xcc, 0x70, 0x6e, 0x70, 0x6e, 0x70,
		0x6e, 0x70, 0x6e, 0x0b, 0x12, 0xbf, 0x0d, 0x7b, 0x45, 0xa1, 0x01, 0x8d, 0x3e, 0x60, 0x7f, 0x28,
		0xb9, 0x0e, 0x96, 0x77, 0x7f, 0x68, 0x22, 0x0c, 0xc8, 0xfe, 0x4e, 0x68, 0x2a, 0x90, 0xfd, 0x0d,
		0x2e, 0x0f, 0x5c, 0x1e, 0xb8, 0x3c, 0x70, 0x79, 0x08, 0x77, 0x10, 0xee, 0x20, 0xdc, 0x01, 0x97,
		0x07, 0x2e, 0x0f, 0x5c, 0x1e, 0xb8, 0x3c, 0x38, 0x37, 0x38, 0x37, 0x38, 0x37, 0x70, 0x79, 0xe0,
		0xf2, 0xc0, 0xe5, 0x65, 0xcc, 0xe5, 0x21, 0xd1, 0x5b, 0xd5, 0x6a, 0xe7, 0x68, 0x95, 0x73, 0x94,
		0xe5, 0xdd, 0x36, 0x5e, 0x0a, 0x9a, 0xe2, 0x4d, 0xc3, 0x11, 0x93, 0x72, 0xc3, 0xe4, 0x29, 0xdd,
		0x35, 0xa4, 0x74, 0xe7, 0x01, 0x75, 0x22, 0xa5, 0x9b, 0x27, 0xe6, 0x26, 0x4b, 0xe9, 0x36, 0x2c,
		0x2b, 0xb4, 0xc1, 0x0a, 0xf2, 0xba, 0x67, 0x06, 0xa7, 0xdd, 0x10, 0xaa, 0x20, 0xb9, 0x3b, 0xcf,
		0x21, 0x2a, 0x36, 0x84, 0x8a, 0x84, 0xf8, 0xc9, 0x43, 0x4e, 0x85, 0xa1, 0xa6, 0x8a, 0x10, 0x73,
		0x7d, 0x68, 0x19, 0x2e, 0xfe, 0xf9, 0x0a, 0x84, 0x1a, 0xfb, 0xa7, 0xe8, 0x2f, 0x74, 0x61, 0x67,
		0x3e, 0x72, 0x06, 0x4c, 0xdb, 0xf3, 0x03, 0xa3, 0xee, 0x3a, 0xbe, 0xd3, 0x75, 0x2c, 0x9d, 0xfd,
		0x97, 0xde, 0x6d, 0xac, 0xba, 0x09, 0xdc, 0x07, 0xdc, 0x07, 0xdc, 0xc7, 0x96, 0xb9, 0x0f, 0xb3,
		0xc7, 0x6c, 0xdf, 0xf4, 0xbf, 0x2b, 0x72, 0x21, 0xc7, 0x84, 0x63, 0xb6, 0xc2, 0x47, 0xfd, 0x60,
		0x78, 0x4c, 0xdd, 0xbe, 0x50, 0xeb, 0xe6, 0xa1, 0xdd, 0xb8, 0xba, 0x7a, 0xba, 0xbb, 0xbf, 0x6d,
		0xdf, 0x5e, 0xdc, 0x5e, 0x3d, 0xb5, 0xff, 0xb8, 0x6b, 0x52, 0xeb, 0xc6, 0x6f, 0x86, 0x35, 0x64,
		0x9e, 0x76, 0xbe, 0xfb, 0x48, 0x4e, 0xe2, 0x2a, 0xda, 0x08, 0x99, 0x4c, 0xcf, 0x5d, 0xeb, 0x5a,
		0xc1, 0x76, 0xc1, 0xbb, 0xa2, 0x4d, 0x43, 0xeb, 0xd3, 0xf5, 0x1d, 0xe6, 0x61, 0x57, 0xbb, 0x6c,
		0xdd, 0x37, 0x2f, 0xda, 0x57, 0x7f, 0x3c, 0x5d, 0xdc, 0xde, 0xdc, 0x34, 0x2f, 0xda, 0xcd, 0x4b,
		0xcc, 0xca, 0xae, 0x76, 0xfb, 0x70, 0xf7, 0xf1, 0x08, 0x13, 0xb1, 0xab, 0x3d, 0xb4, 0x1b, 0xed,
		0xd6, 0x05, 0x66, 0x62, 0x57, 0x6b, 0x3d, 0xb4, 0x1e, 0x30, 0x0f, 0xbb, 0xda, 0x87, 0x4f, 0xb0,
		0x9b, 0xa1, 0x85, 0xc0, 0x3c, 0xec, 0x6a, 0x57, 0xb7, 0x17, 0x8d, 0xab, 0xa7, 0xc6, 0xa7, 0x4f,
		0xf7, 0xcd, 0x4f, 0x8d, 0x76, 0x33, 0xef, 0x99, 0x08, 0x9d, 0xbc, 0xc5, 0x17, 0xd8, 0x1a, 0x9d,
		0x1b, 0x2f, 0xd3, 0xad, 0x51, 0x82, 0x2d, 0x6f, 0x89, 0x1d, 0xc8, 0x9d, 0x14, 0xd7, 0x8f, 0x6a,
		0xdd, 0x32, 0x5d, 0x2f, 0x4d, 0x6a, 0xcf, 0x56, 0x72, 0xd3, 0x5a, 0x4c, 0x4c, 0xf8, 0x17, 0x59,
		0x60, 0x81, 0x65, 0x4b, 0x10, 0xd1, 0x94, 0x1c, 0x92, 0xdc, 0x82, 0x96, 0xa6, 0x0d, 0x29, 0x68,
		0x42, 0x42, 0x5a, 0x90, 0x8a, 0x06, 0x24, 0xa7, 0xfd, 0xc8, 0x69, 0x3e, 0x5a, 0x5a, 0x2f, 0x5d,
		0xb3, 0x28, 0xbb, 0x65, 0xac, 0x85, 0x16, 0x85, 0x28, 0x15, 0x24, 0x18, 0x8d, 0x26, 0x13, 0xa4,
		0x82, 0xe2, 0x7e, 0x69, 0xaa, 0xa9, 0x32, 0x75, 0x55, 0xa6, 0xb6, 0x6a, 0xd4, 0x37, 0x1f, 0x28,
		0x95, 0x8c, 0x7d, 0x9f, 0x49, 0xd2, 0x72, 0x4d, 0x9b, 0xa2, 0x1a, 0x5f, 0xe4, 0x26, 0xdf, 0x03,
		0x77, 0xe6, 0x1d, 0x77, 0x0a, 0x9f, 0x6d, 0x4f, 0x07, 0xf6, 0x49, 0xf9, 0x1e, 0x0a, 0x9f, 0x23,
		0xe9, 0x6b, 0x00, 0xf9, 0x00, 0xf9, 0xd2, 0xb7, 0x48, 0xd2, 0xbe, 0x81, 0x30, 0x91, 0x87, 0x22,
		0x71, 0x67, 0x36, 0x51, 0x47, 0xb6, 0x84, 0x7f, 0x3a, 0x76, 0x4b, 0x2e, 0x7f, 0x9a, 0x24, 0x6f,
		0x9a, 0x2c, 0x58, 0xad, 0xc1, 0x72, 0xc1, 0x72, 0x21, 0x58, 0x45, 0xb0, 0x8a, 0x60, 0x15, 0xc1,
		0x2a, 0x82, 0x55, 0x04, 0xab, 0xd9, 0x04, 0xab, 0x12, 0x3b, 0x59, 0x02, 0x98, 0x6f, 0x47, 0xe1,
		0x62, 0x8c, 0x6c, 0x92, 0xa0, 0x77, 0xd1, 0xae, 0x4c, 0xcf, 0x6f, 0xf8, 0xbe, 0x98, 0x97, 0xd4,
		0xae, 0x4d, 0xbb, 0x69, 0x8d, 0x67, 0x56, 0xcc, 0x93, 0x68, 0xd7, 0xc6, 0xb7, 0x99, 0x11, 0xaa,
		0xef, 0xeb, 0xf5, 0x93, 0xd3, 0x7a, 0xbd, 0x72, 0x7a, 0x74, 0x5a, 0x39, 0x3b, 0x3e, 0xae, 0x9e,
		0x88, 0x24, 0x57, 0x6a, 0xb7, 0x6e, 0x8f, 0xb9, 0xac, 0xf7, 0xe1, 0xbb, 0x3c, 0x62, 0x1e, 0x7a,
		0xcc, 0x15, 0x05, 0xcc, 0x04, 0xae, 0x67, 0xd6, 0xdd, 0x38, 0xe3, 0xb7, 0xd2, 0x9f, 0x65, 0x0e,
		0x41, 0x91, 0xba, 0x99, 0x39, 0xd7, 0x12, 0xcc, 0x54, 0x29, 0xd4, 0x49, 0xd2, 0xa6, 0xa5, 0x6f,
		0xcb, 0x34, 0xa1, 0x88, 0x52, 0x64, 0x77, 0x97, 0x6f, 0x81, 0x93, 0x2f, 0x53, 0xb2, 0x6f, 0x26,
		0x5c, 0x48, 0xd1, 0x05, 0x4c, 0x6b, 0xe1, 0x92, 0x4d, 0xe2, 0xe6, 0x29, 0x59, 0xff, 0x8d, 0x0d,
		0x93, 0xc5, 0xe1, 0x34, 0xf8, 0x9c, 0x04, 0xbf, 0x53, 0x20, 0x71, 0x02, 0x73, 0x46, 0xdf, 0x1e,
		0x5a, 0x96, 0xd4, 0xe4, 0x70, 0x4a, 0x90, 0x52, 0xc9, 0x49, 0xa0, 0xdd, 0x5c, 0xda, 0xbc, 0x5e,
		0xfc, 0xe2, 0x85, 0x6a, 0xf5, 0x5f, 0x62, 0x66, 0x32, 0xe9, 0x0c, 0x12, 0xce, 0xdc, 0xea, 0xf7,
		0x5a, 0x7e, 0xea, 0xf9, 0xdf, 0x2c, 0x3c, 0xff, 0xa6, 0xe7, 0x16, 0x7d, 0xde, 0x15, 0x8b, 0xb8,
		0x6e, 0xd1, 0xe6, 0xdf, 0x65, 0xfa, 0xc4, 0x33, 0x4f, 0xab, 0x79, 0xfe, 0x60, 0xe9, 0x11, 0x67,
		0xe2, 0x99, 0xc1, 0xc2, 0x2d, 0x63, 0xf8, 0xbb, 0x58, 0x22, 0x60, 0x5d, 0x60, 0x3f, 0x1b, 0xa8,
		0x2f, 0xdf, 0x29, 0x09, 0xf8, 0x49, 0x1c, 0x47, 0x27, 0x06, 0x2c, 0x8b, 0x71, 0xee, 0xe8, 0xb9,
		0x38, 0xd7, 0x3e, 0x8e, 0x2d, 0xd2, 0x5e, 0x2c, 0xe7, 0xd9, 0xb0, 0xe2, 0x5f, 0x66, 0x32, 0x1d,
		0xe1, 0xf7, 0x62, 0x1e, 0x70, 0x3d, 0x81, 0xba, 0x91, 0x91, 0x49, 0xc2, 0xb4, 0x6c, 0x5e, 0x18,
		0x5e, 0x74, 0xca, 0x4d, 0x78, 0x70, 0x23, 0xcc, 0x44, 0x0b, 0x27, 0x66, 0x84, 0x36, 0xd1, 0x7f,
		0x49, 0xd3, 0xc0, 0xf8, 0xd2, 0xbd, 0x12, 0x32, 0xe5, 0x89, 0x29, 0x38, 0x1e, 0x8a, 0x2d, 0xb9,
		0x00, 0x88, 0x86, 0x29, 0xc2, 0x0c, 0x98, 0x70, 0xe8, 0xc1, 0x25, 0x20, 0x34, 0xe0, 0x28, 0x29,
		0x6f, 0xac, 0x3d, 0x0f, 0x7a, 0x43, 0xbd, 0x6f, 0x5a, 0x3e, 0x4b, 0x1e, 0x42, 0x47, 0x6b, 0x34,
		0x7b, 0x71, 0xc2, 0xa9, 0xe0, 0x63, 0x7f, 0xb9, 0x59, 0x5e, 0x11, 0x36, 0x97, 0x5f, 0xe4, 0x64,
		0x23, 0x64, 0x69, 0x12, 0x56, 0x3a, 0x0a, 0x16, 0x12, 0x49, 0x35, 0xc1, 0x0e, 0x37, 0x17, 0x3a,
		0x15, 0x3f, 0xc7, 0xb1, 0x98, 0x61, 0xf3, 0x2c, 0xd8, 0xc4, 0xb2, 0x55, 0xa9, 0x42, 0x98, 0x77,
		0x09, 0x55, 0xec, 0x65, 0x68, 0x04, 0xeb, 0x2d, 0xa2, 0x61, 0xe3, 0x6b, 0xa1, 0x60, 0x50, 0x30,
		0x28, 0x58, 0x9c, 0x82, 0x05, 0x3a, 0xa2, 0xfb, 0xe6, 0x2b, 0x73, 0x86, 0xbe, 0xee, 0xb2, 0xae,
		0xf3, 0x95, 0xb9, 0xdf, 0xc5, 0x14, 0x2e, 0x66, 0x2c, 0x28, 0x20, 0x14, 0x30, 0x65, 0x05, 0x1c,
		0x9a, 0xb6, 0xff, 0x5e, 0x40, 0xfd, 0x38, 0x36, 0x1d, 0xb4, 0x7b, 0xc3, 0x7e, 0x61, 0xdc, 0x55,
		0x0e, 0xc4, 0x36, 0x5b, 0xc4, 0xf7, 0x33, 0x24, 0xd3, 0x0e, 0x83, 0x5a, 0x0e, 0x12, 0xd7, 0x7f,
		0x74, 0x8d, 0xae, 0x6f, 0x3a, 0xf6, 0xa5, 0xf9, 0x62, 0x8e, 0x69, 0xc1, 0x54, 0xd2, 0xa6, 0xae,
		0x8d, 0x6f, 0x99, 0x4f, 0x59, 0xed, 0xf8, 0x38, 0xc3, 0x49, 0x53, 0xc4, 0xd7, 0x77, 0xd2, 0x74,
		0x4f, 0xae, 0xd9, 0x7b, 0x61, 0xba, 0xe1, 0x79, 0x43, 0xd7, 0xb0, 0x79, 0x22, 0xd5, 0xc8, 0x29,
		0x2d, 0x8e, 0x00, 0x57, 0x04, 0x57, 0x04, 0x2c, 0xb8, 0xea, 0x9e, 0xcc, 0x36, 0x9e, 0x2d, 0xd6,
		0x8b, 0x6a, 0xa6, 0xf1, 0x2b, 0xdb, 0xd2, 0x08, 0x50, 0x36, 0x28, 0x5b, 0xca, 0xca, 0x26, 0x56,
		0xf0, 0x4b, 0xa4, 0xa0, 0x97, 0x5c, 0xc1, 0xae, 0x99, 0x1a, 0x32, 0x77, 0x51, 0x31, 0x2e, 0xde,
		0x15, 0x97, 0xa8, 0xb3, 0x25, 0x99, 0x1c, 0x73, 0xfd, 0xd0, 0x16, 0x28, 0x74, 0x22, 0x00, 0xe4,
		0x24, 0x9f, 0xf3, 0xbe, 0x71, 0xd7, 0xba, 0x7c, 0xba, 0xfb, 0xed, 0xa1, 0x5d, 0x88, 0xa7, 0x15,
		0x9b, 0x55, 0xae, 0x2b, 0x3a, 0x19, 0xa9, 0xb4, 0x50, 0xba, 0x99, 0x78, 0x9a, 0x19, 0x69, 0x7a,
		0x19, 0x5f, 0x86, 0x01, 0xb1, 0x5b, 0xf6, 0xbf, 0x30, 0xb7, 0xfb, 0xc5, 0xb0, 0x6d, 0x66, 0xe9,
		0xaf, 0xa6, 0x17, 0x6e, 0x39, 0x0b, 0xb2, 0xa2, 0x6b, 0x47, 0x83, 0xbb, 0x86, 0xbb, 0x06, 0x36,
		0x5e, 0x75, 0x4f, 0xcb, 0x71, 0x06, 0xa2, 0x2a, 0x37, 0x73, 0x2d, 0x14, 0x0c, 0x0a, 0xb6, 0x85,
		0x0a, 0x96, 0x93, 0x7c, 0x3c, 0x6f, 0x60, 0xd8, 0xb6, 0x69, 0xbf, 0xe8, 0xbe, 0xcb, 0xd8, 0xa1,
		0xe7, 0x0f, 0x0e, 0xc7, 0x49, 0x3b, 0x89, 0x0e, 0xaf, 0xaf, 0x49, 0x8e, 0x5b, 0x93, 0x69, 0x93,
		0xec, 0xf0, 0x26, 0xd7, 0x21, 0x4d, 0xee, 0x14, 0x93, 0x1a, 0x52, 0x4c, 0xc8, 0xb5, 0x1c, 0x29,
		0x26, 0x70, 0x3c, 0x70, 0x3c, 0x65, 0x40, 0x76, 0x48, 0x31, 0x81, 0x82, 0x41, 0xc1, 0x14, 0x2b,
		0x18, 0x52, 0x4c, 0xa0, 0x80, 0xe5, 0x53, 0x40, 0xa4, 0x98, 0x88, 0x69, 0xd5, 0xd2, 0xe5, 0x48,
		0x31, 0x11, 0x9e, 0x32, 0xa4, 0x98, 0xc8, 0xba, 0x27, 0xa4, 0x98, 0xc0, 0x15, 0x01, 0x0b, 0xa6,
		0xa3, 0x6c, 0x48, 0x31, 0x81, 0xb2, 0x21, 0xc5, 0x04, 0x29, 0x26, 0x89, 0x9e, 0x1a, 0x29, 0x26,
		0x4a, 0x9e, 0x16, 0x29, 0x26, 0xcb, 0x91, 0x0f, 0x52, 0x4c, 0x90, 0x62, 0x02, 0x77, 0x0d, 0x6c,
		0x9c, 0x25, 0x36, 0x46, 0x8a, 0x09, 0x14, 0x0c, 0x0a, 0x26, 0xaa, 0x60, 0x79, 0x4f, 0x31, 0x49,
		0x50, 0x72, 0x32, 0x3f, 0xe5, 0x97, 0xe2, 0xde, 0x42, 0x5b, 0x9b, 0xe9, 0x32, 0x5b, 0xd1, 0xe8,
		0xc1, 0x1f, 0x3c, 0x7d, 0x1a, 0x5f, 0x93, 0xb4, 0x34, 0xd3, 0x8a, 0x42, 0x42, 0xa6, 0xed, 0x33,
		0xb7, 0x6f, 0x74, 0x83, 0xf8, 0x63, 0x43, 0xfd, 0x9d, 0x99, 0xef, 0xa2, 0x06, 0x4f, 0x51, 0x6a,
		0xf0, 0x44, 0x8b, 0x96, 0x3c, 0x45, 0x6a, 0x7a, 0x09, 0x2a, 0xf1, 0x20, 0x4d, 0x6a, 0xfc, 0x45,
		0xce, 0x8e, 0x7e, 0x62, 0x1d, 0xfc, 0x38, 0x9b, 0x20, 0x00, 0x32, 0x95, 0x1f, 0x32, 0xf1, 0xb6,
		0x18, 0x10, 0xca, 0xe7, 0x5b, 0x86, 0x5b, 0xdc, 0x79, 0x7d, 0x82, 0xa8, 0x5f, 0x58, 0x94, 0x65,
		0x44, 0x5a, 0x5e, 0xb4, 0x65, 0x45, 0x9c, 0x4c, 0xd4, 0xc9, 0x44, 0x9e, 0x44, 0xf4, 0xc5, 0xa8,
		0x3c, 0xde, 0x02, 0xca, 0xc2, 0xe5, 0xf9, 0x25, 0xa2, 0x09, 0xc1, 0xa8, 0x82, 0x7f, 0x42, 0x38,
		0x26, 0x43, 0x24, 0xaf, 0x70, 0xb5, 0xa6, 0xf3, 0x84, 0xf5, 0x50, 0x74, 0x28, 0x3a, 0x14, 0x3d,
		0x5d, 0x45, 0x67, 0xbd, 0x17, 0xa6, 0x0f, 0x1c, 0xd7, 0x17, 0xd7, 0xf3, 0xe9, 0x10, 0x50, 0x73,
		0xa8, 0x79, 0xc9, 0xd4, 0x5c, 0x6c, 0xb7, 0x7c, 0x49, 0xd5, 0x45, 0x9a, 0x81, 0x48, 0xed, 0x9e,
		0x2f, 0xbd, 0xc8, 0x43, 0xfb, 0xee, 0xa9, 0x79, 0xf9, 0xa9, 0xf9, 0x74, 0x77, 0x7b, 0xdf, 0xd6,
		0x64, 0xf2, 0xf6, 0xc4, 0xb6, 0xd3, 0x27, 0xff, 0x11, 0x35, 0x24, 0x0b, 0x5e, 0xa5, 0xf1, 0xef,
		0xf6, 0xad, 0x44, 0x43, 0xb7, 0x77, 0xb9, 0x78, 0x89, 0xe6, 0x4d, 0xe3, 0xc3, 0x55, 0xb3, 0xf0,
		0xaf, 0x71, 0xd9, 0x7a, 0x90, 0x7c, 0x0f, 0xa1, 0x2b, 0x3b, 0xb9, 0x49, 0xfb, 0xe4, 0xf1, 0xba,
		0x92, 0xc8, 0x1a, 0xa0, 0x1a, 0xde, 0xb6, 0x94, 0xde, 0xd6, 0xf3, 0xc3, 0x8d, 0x60, 0xdd, 0x1f,
		0x8d, 0x25, 0xe1, 0x70, 0xeb, 0x02, 0xd7, 0x36, 0xed, 0xe1, 0xeb, 0xe8, 0xf9, 0xf3, 0x60, 0x21,
		0x2c, 0xd3, 0xfe, 0x6b, 0x3c, 0x09, 0xc2, 0x56, 0x62, 0x3a, 0x04, 0x2c, 0x05, 0x2c, 0x45, 0x09,
		0x2d, 0x85, 0xa8, 0x80, 0x97, 0xca, 0x50, 0x08, 0xf5, 0xf9, 0x95, 0xe9, 0xeb, 0x0b, 0xf3, 0x00,
		0xf3, 0x90, 0x7f, 0x76, 0xce, 0xf0, 0x98, 0x1e, 0x6d, 0xb6, 0xeb, 0x92, 0xd1, 0xbb, 0x40, 0xc7,
		0xfe, 0xa8, 0x53, 0xff, 0xa1, 0xd3, 0xd5, 0xcd, 0xfe, 0xf9, 0x34, 0xc1, 0x63, 0xf1, 0x17, 0xe1,
		0xcf, 0xfc, 0x8d, 0xfc, 0xcb, 0xd3, 0xa4, 0x70, 0x39, 0x63, 0x67, 0x66, 0xba, 0xa6, 0x13, 0x95,
		0xa4, 0xd0, 0x4d, 0xf2, 0x57, 0x4e, 0x92, 0xd5, 0xc8, 0x65, 0x5c, 0x45, 0x8c, 0x2a, 0x32, 0x19,
		0x77, 0xb1, 0x2d, 0x2f, 0x69, 0xfc, 0xa6, 0x80, 0x9f, 0x19, 0x7d, 0xc1, 0x53, 0x3d, 0x1c, 0x16,
		0x2e, 0xb2, 0x6c, 0x07, 0x07, 0xe3, 0xbc, 0xc0, 0xc3, 0xe4, 0xa6, 0x8b, 0x46, 0x2b, 0x93, 0x95,
		0xa5, 0x5a, 0x01, 0x19, 0x37, 0x97, 0xa7, 0x5a, 0x9a, 0x18, 0x5e, 0xbd, 0xac, 0x41, 0x2f, 0x4b,
		0xaa, 0x97, 0x48, 0x97, 0x01, 0x4e, 0x07, 0x4e, 0xa7, 0xc6, 0xe9, 0x48, 0x97, 0x41, 0xba, 0x0c,
		0x14, 0x1d, 0x8a, 0x5e, 0x10, 0x45, 0x47, 0xba, 0x0c, 0xd4, 0x1c, 0x6a, 0x1e, 0xbf, 0xde, 0x48,
		0x97, 0x99, 0x1d, 0x0c, 0xe9, 0x32, 0xf4, 0x2f, 0x81, 0x74, 0x19, 0x11, 0x4b, 0x30, 0xf9, 0x0f,
		0xe9, 0x32, 0xf0, 0xb6, 0xf0, 0xb6, 0x65, 0xf1, 0xb6, 0x48, 0x97, 0x99, 0x3c, 0x0b, 0xd2, 0x65,
		0x60, 0x29, 0x60, 0x29, 0xd6, 0x5b, 0x0a, 0xa4, 0xcb, 0x20, 0x5d, 0x06, 0xe6, 0x01, 0xe6, 0x61,
		0x15, 0x3b, 0x87, 0x74, 0x19, 0xee, 0x6f, 0xe6, 0x3e, 0x5d, 0x26, 0x41, 0xd1, 0x9e, 0xe4, 0x6f,
		0x2c, 0x57, 0x0b, 0xe3, 0x57, 0xf6, 0x3d, 0xa1, 0xf9, 0xe4, 0xab, 0x82, 0xc8, 0x5f, 0xfd, 0x90,
		0xa4, 0xea, 0x21, 0x5f, 0xb5, 0xc3, 0x2c, 0xeb, 0x37, 0xad, 0x12, 0x0c, 0x2d, 0x51, 0x8a, 0xc5,
		0x62, 0x3d, 0xa4, 0x56, 0x74, 0x79, 0x61, 0xcb, 0x40, 0xcd, 0x14, 0x59, 0x92, 0x28, 0xeb, 0xf4,
		0x3a, 0xf2, 0x00, 0x1b, 0x0b, 0x3a, 0xbd, 0xc6, 0xfb, 0x4f, 0x94, 0x72, 0x22, 0xf0, 0xb4, 0xc4,
		0xa5, 0x9c, 0x12, 0xd6, 0xe0, 0xe1, 0xab, 0xbd, 0x83, 0x22, 0x4e, 0xb4, 0xd0, 0x2c, 0xcf, 0x45,
		0x9c, 0xfa, 0x8e, 0xfb, 0x3f, 0xc3, 0xed, 0x8d, 0xec, 0x4d, 0x8f, 0x59, 0x86, 0x40, 0x77, 0xa0,
		0xa5, 0x11, 0x90, 0x41, 0x9a, 0x62, 0xdc, 0x80, 0x0c, 0x52, 0xf4, 0x04, 0x92, 0x8f, 0xda, 0xa3,
		0xcb, 0x27, 0x0d, 0x6e, 0xea, 0xe8, 0x09, 0xc4, 0x3b, 0x65, 0x47, 0x15, 0xb4, 0x04, 0x92, 0x58,
		0x53, 0xed, 0x0b, 0xb3, 0x2c, 0x27, 0xe8, 0x30, 0xc7, 0xef, 0x83, 0x66, 0xae, 0x85, 0xf7, 0x81,
		0xf7, 0x81, 0xf7, 0x29, 0xb6, 0xf7, 0xa9, 0xc2, 0xfb, 0x70, 0x4f, 0x19, 0xbc, 0x8f, 0x9c, 0xf7,
		0x71, 0xac, 0x9e, 0xde, 0x75, 0x86, 0xb6, 0x2f, 0xe0, 0x7d, 0xa6, 0xd7, 0x26, 0x3d, 0x93, 0xc1,
		0xfa, 0xc6, 0xd0, 0x0a, 0x8c, 0xde, 0x09, 0x3c, 0x16, 0x3c, 0x16, 0x3c, 0x16, 0x3c, 0x16, 0x3c,
		0x16, 0x3c, 0x16, 0x8f, 0xc7, 0x7a, 0x35, 0xbe, 0xe9, 0xc6, 0x8b, 0x40, 0xb0, 0x34, 0xb9, 0x10,
		0x7e, 0x07, 0x7e, 0x07, 0x7e, 0xa7, 0xd8, 0x7e, 0xe7, 0x04, 0x7e, 0x87, 0x9b, 0xda, 0x84, 0xdf,
		0x91, 0xf6, 0x3b, 0x5f, 0x9c, 0x81, 0x98, 0xdf, 0x19, 0x5d, 0x08, 0xbf, 0x03, 0xbf, 0x03, 0xbf,
		0x83, 0x78, 0x67, 0xcb, 0xfc, 0x4e, 0xed, 0xf8, 0x18, 0x8e, 0x47, 0xc6, 0xf1, 0xa0, 0xa8, 0x15,
		0x5c, 0x4e, 0x71, 0x5c, 0x8e, 0xe7, 0xbb, 0xa6, 0xfd, 0x22, 0x52, 0xd3, 0xea, 0x3d, 0xc7, 0x35,
		0x57, 0xcc, 0x7e, 0x09, 0x52, 0x08, 0xe1, 0x75, 0xe0, 0x75, 0x56, 0x4d, 0xd9, 0x51, 0x0d, 0x4e,
		0x47, 0xc6, 0xe9, 0xb8, 0xec, 0xab, 0xe9, 0xf1, 0xe4, 0xc0, 0x47, 0x06, 0x20, 0xba, 0x12, 0xce,
		0x07, 0xce, 0x27, 0x83, 0x78, 0xe7, 0xa8, 0x26, 0xe0, 0x7c, 0x4e, 0x11, 0xf0, 0xac, 0xb6, 0xa3,
		0x15, 0xb8, 0x1e, 0x6e, 0xa2, 0xad, 0x76, 0x56, 0x3f, 0x3b, 0x39, 0xad, 0x9d, 0x21, 0xee, 0x11,
		0xfc, 0x46, 0x96, 0x27, 0x70, 0x5e, 0x47, 0xff, 0x24, 0xa9, 0x5c, 0xbc, 0xe6, 0xe4, 0xcc, 0x9a,
		0xd3, 0x1b, 0xaf, 0x9e, 0xaf, 0x9b, 0xb6, 0xe7, 0x1b, 0xf6, 0xba, 0x3e, 0xe3, 0xcb, 0x1c, 0xe2,
		0xdc, 0x65, 0x38, 0xc6, 0x80, 0x63, 0x0c, 0xcb, 0xe2, 0x24, 0xc0, 0x4c, 0xcf, 0x5e, 0x8d, 0xbe,
		0xd4, 0x80, 0x6b, 0x42, 0x70, 0x8d, 0xbb, 0xd0, 0x2e, 0x67, 0x03, 0xf5, 0xa5, 0x65, 0xe6, 0x6a,
		0xa4, 0x2e, 0x28, 0xb8, 0xc2, 0x02, 0x2c, 0x23, 0xc8, 0xf2, 0x02, 0x2d, 0x2b, 0xd8, 0x64, 0x02,
		0x4e, 0x26, 0xe8, 0x24, 0x02, 0x2f, 0x08, 0x8b, 0x38, 0x57, 0x9c, 0x57, 0x11, 0xa2, 0x0b, 0x9f,
		0x5d, 0x33, 0x28, 0x32, 0xe9, 0x9a, 0x8e, 0x6b, 0xfa, 0xdf, 0xe5, 0xab, 0xe1, 0x2d, 0x0e, 0xf8,
		0x2e, 0x13, 0x40, 0x2c, 0xaa, 0x3a, 0x14, 0x2a, 0x44, 0xa7, 0x4a, 0x54, 0x2a, 0x45, 0xae, 0x5a,
		0xe4, 0x2a, 0x46, 0xaa, 0x6a, 0x62, 0x2a, 0x27, 0x11, 0xfb, 0xed, 0x4a, 0x95, 0xd6, 0x58, 0x92,
		0x17, 0xcf, 0x1f, 0xe8, 0x0b, 0x6a, 0x24, 0x5a, 0x8c, 0x47, 0x82, 0x6c, 0x20, 0x22, 0x1f, 0xe4,
		0xc9, 0x08, 0x52, 0x72, 0x82, 0xd8, 0xd0, 0xc4, 0x46, 0xe2, 0x55, 0xa2, 0xf1, 0x08, 0x02, 0x72,
		0x22, 0x01, 0x27, 0x23, 0x3b, 0xd2, 0x5a, 0x82, 0x93, 0x6a, 0xb5, 0x5e, 0xaf, 0xe4, 0x78, 0x1d,
		0x76, 0xb2, 0xb9, 0xba, 0xb3, 0x93, 0xce, 0xfd, 0x44, 0x48, 0xb4, 0x20, 0x2c, 0xec, 0xc9, 0xa3,
		0x90, 0x70, 0x1c, 0x80, 0x0f, 0x80, 0x0f, 0x80, 0x0f, 0x2e, 0x79, 0x19, 0x9a, 0xb6, 0x5f, 0x3d,
		0x21, 0x80, 0x1a, 0x27, 0x80, 0x1a, 0x80, 0x1a, 0x5b, 0x02, 0x35, 0xea, 0x95, 0xb3, 0x3a, 0x80,
		0x46, 0x91, 0x80, 0xc6, 0x57, 0xcb, 0xb0, 0xe5, 0x61, 0x46, 0x30, 0x0a, 0x40, 0x06, 0x40, 0x06,
		0x40, 0x06, 0x1f, 0xc8, 0xb0, 0x93, 0x67, 0xe9, 0xac, 0x53, 0x9e, 0xea, 0x99, 0xc4, 0x18, 0xe1,
		0xeb, 0x64, 0x8e, 0x31, 0x66, 0x8d, 0x89, 0x78, 0xd0, 0x42, 0x0c, 0xc1, 0x88, 0xa1, 0x18, 0xdd,
		0x74, 0x29, 0x81, 0x66, 0x8a, 0xf0, 0x81, 0x2a, 0xa8, 0xa6, 0x12, 0x2c, 0x10, 0x42, 0x37, 0x25,
		0x10, 0x2e, 0xad, 0xa5, 0xa2, 0x83, 0x74, 0xa9, 0xac, 0xd6, 0x4e, 0x3e, 0x46, 0xe9, 0xec, 0x64,
		0x28, 0x73, 0xd4, 0xb6, 0xd8, 0x0d, 0x4c, 0x1f, 0x9d, 0x39, 0xe6, 0x49, 0x33, 0x8f, 0x87, 0x6d,
		0x86, 0xef, 0x33, 0xd7, 0x26, 0xb3, 0xc8, 0xda, 0x9f, 0x7b, 0xf5, 0xca, 0xd9, 0x63, 0x45, 0xaf,
		0x77, 0x7e, 0xd6, 0x2b, 0x8f, 0x15, 0xfd, 0x7d, 0xe7, 0xb1, 0xa2, 0x9f, 0x75, 0x7e, 0x3e, 0x56,
		0xf5, 0xa3, 0xf1, 0xc7, 0x1f, 0x47, 0x6f, 0xa3, 0x9f, 0xce, 0xc2, 0x9f, 0xaa, 0xef, 0x6a, 0xe1,
		0xcf, 0xfb, 0x9f, 0x3f, 0x1f, 0x7c, 0xfe, 0x7c, 0x20, 0x31, 0xc0, 0xdf, 0x34, 0x79, 0x91, 0xa3,
		0x98, 0xd4, 0xdb, 0x87, 0xd6, 0x7f, 0x30, 0xb3, 0xb4, 0xca, 0x9c, 0x76, 0xdc, 0x28, 0x88, 0x6a,
		0xb9, 0xaa, 0x88, 0xaf, 0x43, 0x23, 0x7c, 0xd5, 0xc5, 0xd7, 0x39, 0x4b, 0xe9, 0xaa, 0xe3, 0xb1,
		0x83, 0x73, 0x55, 0x23, 0x27, 0x8c, 0xd0, 0x95, 0x26, 0x3f, 0x08, 0x96, 0xcd, 0x8f, 0xae, 0xe7,
		0xce, 0xd1, 0x9c, 0x4b, 0x89, 0x9c, 0xfb, 0x29, 0x51, 0xfa, 0xa6, 0xf8, 0xec, 0xf0, 0xb4, 0x2f,
		0x99, 0x29, 0x61, 0x2e, 0x9c, 0xee, 0x34, 0x33, 0x06, 0x52, 0x9e, 0xd4, 0xb1, 0x17, 0x48, 0x79,
		0x4a, 0x33, 0xe5, 0x69, 0xda, 0xdd, 0x40, 0x9a, 0xff, 0xe3, 0x69, 0x94, 0x40, 0xa8, 0x26, 0x20,
		0x01, 0x41, 0x02, 0x66, 0x45, 0x02, 0x8a, 0xaa, 0x5d, 0x34, 0x80, 0x60, 0x0a, 0x6e, 0xac, 0xd8,
		0x09, 0xa5, 0xe4, 0x12, 0x2b, 0x22, 0x99, 0x42, 0x52, 0x2a, 0x26, 0xbd, 0x82, 0x52, 0x2b, 0xaa,
		0x32, 0x85, 0x55, 0xa6, 0xb8, 0x4a, 0x14, 0x98, 0x86, 0x7e, 0x91, 0x24, 0x4f, 0xa4, 0x15, 0x7b,
		0x46, 0xc1, 0x3d, 0x9f, 0x4e, 0x34, 0xa6, 0x6a, 0xee, 0xf9, 0x54, 0x52, 0x41, 0xbc, 0x0b, 0x4c,
		0xa5, 0xf4, 0x2a, 0x94, 0x5f, 0x9d, 0x11, 0x50, 0x65, 0x0c, 0x94, 0x1b, 0x05, 0xe5, 0xc6, 0x41,
		0xa9, 0x91, 0xa0, 0xe3, 0x6a, 0x77, 0xe9, 0x58, 0x7e, 0xf9, 0xad, 0xc1, 0x58, 0x79, 0xe5, 0x3e,
		0x57, 0x9d, 0x54, 0xfb, 0x4f, 0x09, 0x87, 0xa4, 0xdd, 0x24, 0x9b, 0xfc, 0x47, 0xab, 0x4f, 0xbb,
		0xaa, 0x36, 0xcd, 0x14, 0x99, 0xd5, 0xa5, 0xe1, 0x15, 0x6d, 0xa2, 0x45, 0xe3, 0x2b, 0xdc, 0x9e,
		0x21, 0x56, 0xb7, 0x45, 0xbe, 0xb0, 0xf0, 0x4b, 0x5a, 0xab, 0x84, 0xff, 0x15, 0x78, 0x69, 0x77,
		0xf2, 0x39, 0x5a, 0x27, 0x27, 0x3b, 0x83, 0x14, 0xa9, 0x80, 0x42, 0x1d, 0x99, 0x37, 0x7a, 0x18,
		0x81, 0x4e, 0xcd, 0x40, 0x96, 0x40, 0x96, 0x40, 0x96, 0x05, 0x47, 0x96, 0x24, 0x9d, 0xac, 0x37,
		0x12, 0x4a, 0x94, 0x30, 0x53, 0x7d, 0xe7, 0xeb, 0x7c, 0xdb, 0xff, 0x81, 0xe3, 0xfa, 0xf2, 0x47,
		0x95, 0x63, 0x05, 0x62, 0x7e, 0x78, 0x78, 0x04, 0x78, 0x04, 0x78, 0x84, 0xad, 0xf2, 0x08, 0x9e,
		0x3f, 0xd0, 0xe7, 0x8c, 0x80, 0xec, 0xb1, 0xeb, 0x38, 0x6b, 0x70, 0x0c, 0xee, 0x01, 0xdc, 0x03,
		0xb8, 0x87, 0x7c, 0x70, 0x0f, 0x75, 0xb0, 0x0e, 0xe5, 0x65, 0x1d, 0x32, 0xdd, 0x52, 0x93, 0x4c,
		0x4c, 0x5b, 0x1a, 0x8f, 0x32, 0x51, 0x6d, 0x26, 0x78, 0x98, 0x86, 0x0d, 0x22, 0xd9, 0x6b, 0x74,
		0x53, 0x2e, 0x31, 0xdd, 0x34, 0xd4, 0x10, 0x25, 0x25, 0x44, 0x64, 0xbe, 0x90, 0x51, 0x90, 0x2f,
		0x40, 0x8f, 0x8c, 0x82, 0x0c, 0x80, 0x7a, 0x24, 0x6f, 0x16, 0x33, 0xfa, 0x34, 0x3c, 0x0d, 0x25,
		0x3f, 0x13, 0xf1, 0x32, 0x07, 0x07, 0x87, 0x9e, 0x6f, 0xf8, 0xec, 0x50, 0x9e, 0x78, 0xc9, 0xc6,
		0x8a, 0x06, 0x4f, 0x4f, 0x67, 0x46, 0xc7, 0xc3, 0xe5, 0x2c, 0x33, 0xab, 0x06, 0x3b, 0x0a, 0x3b,
		0x5a, 0x28, 0x3b, 0x8a, 0xcc, 0xac, 0xac, 0xc1, 0x93, 0x0a, 0xe5, 0x57, 0x67, 0x04, 0x54, 0x19,
		0x03, 0xe5, 0x46, 0x41, 0xb9, 0x71, 0x50, 0x6a, 0x24, 0x68, 0xa3, 0x68, 0x64, 0x66, 0x91, 0x0c,
		0x09, 0x76, 0x14, 0xec, 0x68, 0x8a, 0xea, 0x36, 0xbf, 0xa4, 0xc8, 0xcc, 0xca, 0xc5, 0xd2, 0x82,
		0x23, 0x55, 0x2d, 0xfa, 0x5a, 0xd7, 0x19, 0xda, 0x3e, 0x73, 0x3d, 0x15, 0xe8, 0x32, 0x1c, 0x99,
		0x16, 0x61, 0x56, 0x81, 0x30, 0x81, 0x30, 0x81, 0x30, 0x29, 0xde, 0x94, 0x2a, 0x3c, 0x8d, 0x06,
		0x7c, 0x1e, 0xf4, 0x86, 0xba, 0xcb, 0xba, 0xcc, 0xfc, 0xca, 0x7a, 0xf4, 0xb2, 0x15, 0xe5, 0x7f,
		0xcd, 0xdd, 0xe6, 0x5d, 0x21, 0xaa, 0x13, 0x51, 0x9b, 0x1b, 0x95, 0x66, 0x47, 0xbd, 0xf9, 0x51,
		0x6d, 0x86, 0x52, 0x33, 0x47, 0xa9, 0x99, 0xa5, 0x54, 0xcc, 0x93, 0x22, 0xe0, 0x45, 0x2c, 0xf1,
		0xe4, 0x81, 0x71, 0x1c, 0x74, 0x39, 0xa9, 0xab, 0x10, 0xf9, 0xd0, 0xc0, 0xbc, 0x57, 0x30, 0xb4,
		0x9a, 0x98, 0x59, 0x5d, 0xec, 0x9c, 0x4a, 0x0c, 0x9d, 0x52, 0xe0, 0xb5, 0x14, 0x80, 0xa9, 0xbe,
		0x4f, 0x0a, 0x01, 0x98, 0xc2, 0x18, 0x3b, 0x95, 0x58, 0x3b, 0xab, 0xa5, 0xa7, 0xad, 0xfd, 0x94,
		0x3b, 0x69, 0xd8, 0x29, 0xc6, 0xa8, 0x9d, 0x9c, 0xd2, 0x07, 0x94, 0x05, 0x3a, 0x03, 0x28, 0xec,
		0x8d, 0xe1, 0x80, 0x4a, 0xb4, 0x1d, 0xdc, 0x02, 0x48, 0x1b, 0x48, 0x1b, 0x48, 0x1b, 0x48, 0x1b,
		0x48, 0x1b, 0x48, 0x1b, 0x48, 0x1b, 0x48, 0x1b, 0x48, 0x1b, 0x48, 0x3b, 0xdf, 0x48, 0x3b, 0x57,
		0x74, 0x3b, 0xf1, 0xa1, 0x82, 0x68, 0x5c, 0xe5, 0x87, 0x0b, 0xc6, 0xa9, 0xb1, 0xc4, 0xfb, 0x79,
		0xe3, 0x47, 0xf7, 0xdd, 0x61, 0xd7, 0x0f, 0x8f, 0x00, 0x68, 0x0f, 0xfe, 0xe0, 0xe9, 0xda, 0x1b,
		0xff, 0xd3, 0x0a, 0x9f, 0xe8, 0xa9, 0x35, 0x79, 0x8c, 0xa7, 0x8b, 0xc9, 0x03, 0x94, 0x68, 0xfb,
		0xb5, 0xc7, 0x3c, 0xf3, 0xc5, 0x36, 0x7c, 0xd6, 0x9b, 0x34, 0x8e, 0x35, 0x7a, 0x3d, 0x97, 0x79,
		0x0a, 0xf6, 0x63, 0xe3, 0x6f, 0x85, 0x14, 0xc0, 0xfc, 0xc5, 0x6d, 0xd8, 0xa0, 0xcd, 0x24, 0x2e,
		0xdb, 0x96, 0x14, 0xc0, 0x57, 0xa3, 0x4b, 0xac, 0xfe, 0xbb, 0xc4, 0xfd, 0x32, 0xa6, 0x6a, 0x4b,
		0xdc, 0xdd, 0x21, 0x1a, 0xf8, 0xcf, 0xc7, 0x8a, 0x7e, 0x66, 0xe8, 0xfd, 0x86, 0xfe, 0xb1, 0xf3,
		0xa3, 0xf6, 0xb6, 0x77, 0x3e, 0xff, 0xf3, 0xfe, 0x8f, 0xe3, 0xb7, 0xbf, 0xd1, 0x49, 0x56, 0x87,
		0x72, 0x4a, 0x54, 0x74, 0xbd, 0xc8, 0x6a, 0x5e, 0x4a, 0xed, 0xcd, 0xd5, 0xd5, 0x3c, 0x59, 0x73,
		0x2f, 0xf8, 0x73, 0xf8, 0x73, 0xf8, 0xf3, 0xad, 0xf2, 0xe7, 0x9e, 0x3f, 0x58, 0x34, 0x03, 0xaa,
		0x4a, 0xa0, 0x20, 0xc9, 0xbf, 0x58, 0x9c, 0x19, 0x92, 0xfc, 0x63, 0x96, 0xb4, 0x04, 0x49, 0xfe,
		0x27, 0xd5, 0x6a, 0x1d, 0x55, 0x50, 0xe8, 0x47, 0x2b, 0x29, 0x28, 0x55, 0x73, 0x8c, 0x74, 0xf1,
		0x06, 0x80, 0x9f, 0x80, 0x9f, 0x80, 0x9f, 0x5b, 0x05, 0x3f, 0x71, 0xa2, 0x14, 0x60, 0x73, 0x1e,
		0x99, 0x54, 0x00, 0x36, 0xcb, 0x06, 0x36, 0xeb, 0xb5, 0xb3, 0xfa, 0xd9, 0xc9, 0x69, 0xed, 0xec,
		0x18, 0x80, 0x13, 0x80, 0x33, 0x11, 0xe0, 0x0c, 0x6a, 0xb2, 0xda, 0xc3, 0x57, 0xa5, 0xa0, 0x33,
		0xba, 0x09, 0x80, 0x27, 0x80, 0x27, 0x80, 0xe7, 0xd6, 0x01, 0xcf, 0xea, 0x89, 0x02, 0xe0, 0x79,
		0x02, 0xe0, 0x09, 0xe0, 0x09, 0xe0, 0x99, 0x8b, 0x25, 0x3d, 0x39, 0x3e, 0x3e, 0x02, 0xe6, 0x04,
		0xe6, 0xe4, 0xc0, 0x9c, 0xa9, 0xec, 0xbb, 0xa3, 0xed, 0x08, 0xd0, 0x27, 0xd0, 0xe7, 0x16, 0xa3,
		0x4f, 0xb4, 0x1d, 0x01, 0x1a, 0x5d, 0x0f, 0x5d, 0xb0, 0xe7, 0x5e, 0x3a, 0x34, 0x8a, 0xb6, 0x23,
		0xc0, 0xa2, 0x49, 0xb1, 0xa8, 0xeb, 0x38, 0x7e, 0x2a, 0x27, 0x3a, 0xe6, 0x6e, 0x04, 0x24, 0x0a,
		0x24, 0x0a, 0x24, 0xba, 0x55, 0x48, 0x14, 0xe7, 0x39, 0x70, 0x9e, 0x23, 0x27, 0xf3, 0x52, 0x62,
		0x4f, 0x9e, 0x0a, 0xab, 0x34, 0x7f, 0x27, 0xf8, 0x72, 0xf8, 0x72, 0xf8, 0xf2, 0xad, 0x63, 0x95,
		0x70, 0x96, 0x03, 0xbc, 0x12, 0x78, 0xa5, 0xad, 0xe2, 0x95, 0x70, 0x96, 0x03, 0xd4, 0xd2, 0xa6,
		0x65, 0xec, 0x3b, 0xee, 0xff, 0x0c, 0xb7, 0xa7, 0xfb, 0xae, 0x61, 0x7b, 0xa6, 0x67, 0x8e, 0x96,
		0x54, 0x01, 0xb1, 0xb4, 0xfa, 0x36, 0x80, 0xa2, 0x80, 0xa2, 0x80, 0xa2, 0x5b, 0x05, 0x45, 0x55,
		0x94, 0x67, 0x54, 0x50, 0x96, 0x11, 0xd8, 0x73, 0x17, 0x19, 0x76, 0xc0, 0x9e, 0x12, 0xe1, 0x44,
		0x6a, 0x65, 0x14, 0x81, 0x44, 0xcb, 0x81, 0x44, 0x49, 0xda, 0xf6, 0x2f, 0xf9, 0x1b, 0x82, 0xf6,
		0xfd, 0xc0, 0x99, 0xc0, 0x99, 0xc0, 0x99, 0x05, 0xc3, 0x99, 0xcf, 0x86, 0xc7, 0xf4, 0xa8, 0xe0,
		0xa8, 0xee, 0xb2, 0xbe, 0x8a, 0x5d, 0xcc, 0x53, 0xda, 0x5d, 0xcc, 0xb0, 0xdc, 0x6a, 0x57, 0x37,
		0xfb, 0xe7, 0x33, 0x75, 0x53, 0x17, 0x7e, 0x11, 0xfe, 0x1c, 0x58, 0xb6, 0x12, 0xd9, 0x7f, 0x75,
		0x27, 0xfb, 0x70, 0x9c, 0x0f, 0x7e, 0x00, 0x7e, 0x60, 0x3b, 0xfd, 0x00, 0x8e, 0xf3, 0x81, 0x6c,
		0x00, 0xd9, 0x50, 0x72, 0xb2, 0x01, 0xc7, 0xf9, 0xc0, 0x2e, 0x24, 0x41, 0x97, 0xea, 0xb2, 0xad,
		0x70, 0x70, 0x0f, 0x38, 0x13, 0x38, 0x73, 0x8b, 0x71, 0x26, 0x0e, 0xee, 0x01, 0x77, 0xae, 0x07,
		0x29, 0x48, 0xb0, 0x2a, 0x1d, 0xee, 0xc4, 0xc1, 0x3d, 0xa0, 0xce, 0xcd, 0xa8, 0x33, 0x68, 0x76,
		0xa5, 0x08, 0x72, 0x8e, 0xc7, 0x06, 0xde, 0x04, 0xde, 0x04, 0xde, 0xdc, 0x2a, 0xbc, 0x69, 0xf6,
		0x98, 0xed, 0x9b, 0xfe, 0x77, 0x45, 0x1b, 0x5b, 0x94, 0x28, 0xb3, 0x15, 0x3e, 0xea, 0x07, 0xc3,
		0x63, 0xea, 0x9a, 0x8a, 0x3f, 0xb4, 0xef, 0x9e, 0xee, 0x6e, 0xef, 0xdb, 0x4f, 0x0f, 0xed, 0x46,
		0xbb, 0x49, 0xad, 0x13, 0x81, 0xc7, 0xf7, 0x94, 0xb4, 0xe7, 0x55, 0x04, 0x81, 0x26, 0xf3, 0x72,
		0xd5, 0x7a, 0x68, 0x37, 0x6f, 0x5a, 0x37, 0x9f, 0xb4, 0x22, 0xc0, 0x42, 0xd5, 0x93, 0xd1, 0x6c,
		0xdc, 0x63, 0x2e, 0xc6, 0x73, 0xf1, 0xf1, 0xf6, 0xfe, 0xf7, 0xc6, 0xfd, 0x25, 0x66, 0x23, 0x98,
		0x8d, 0x0f, 0x57, 0xb7, 0x17, 0xbf, 0x62, 0x2e, 0x82, 0xb9, 0xb8, 0x6c, 0x3d, 0x34, 0x3e, 0x5c,
		0x35, 0x2f, 0xf3, 0xde, 0x9c, 0xbe, 0x93, 0x37, 0xd4, 0x90, 0x8b, 0x98, 0xc3, 0x75, 0x2c, 0x05,
		0xd1, 0x46, 0x30, 0x2a, 0xe2, 0x0c, 0xc4, 0x19, 0x88, 0x33, 0x10, 0x67, 0x20, 0xce, 0xb8, 0x6f,
		0x3f, 0xdd, 0xdf, 0x5e, 0x21, 0xcc, 0x88, 0xa6, 0xe5, 0xfe, 0xf6, 0xb6, 0x0d, 0xec, 0xb4, 0xab,
		0x7d, 0x68, 0x5c, 0xfc, 0xfa, 0xef, 0x3b, 0xcc, 0xc4, 0xae, 0x76, 0xd9, 0x7c, 0x68, 0x7d, 0xba,
		0x69, 0xb4, 0x95, 0xe0, 0xc8, 0xc2, 0xcd, 0x46, 0xe3, 0xaa, 0xdd, 0xbc, 0x1f, 0xcd, 0x06, 0x40,
		0x75, 0xea, 0xa0, 0x7a, 0x27, 0x43, 0x51, 0xd3, 0x1a, 0xb6, 0xed, 0xf8, 0x86, 0x6f, 0x3a, 0x34,
		0x3b, 0x98, 0x9a, 0xd7, 0xfd, 0xc2, 0x5e, 0x8d, 0x41, 0x94, 0x2c, 0x3e, 0x60, 0x76, 0x37, 0x00,
		0xc0, 0xba, 0x37, 0x30, 0x6c, 0xdb, 0xb4, 0x5f, 0x74, 0xdf, 0x65, 0xec, 0xd0, 0xf3, 0x07, 0x87,
		0xaf, 0xe1, 0x3f, 0xba, 0x69, 0x7b, 0xbe, 0x61, 0x77, 0x99, 0x37, 0xf7, 0xd3, 0xe1, 0x4c, 0x8e,
		0xf9, 0x34, 0xbb, 0x7c, 0xbc, 0xa5, 0xb0, 0x93, 0xcd, 0x8c, 0x8b, 0x5d, 0x29, 0xb8, 0x46, 0x23,
		0x88, 0x2b, 0x79, 0x46, 0x48, 0xbb, 0x32, 0x3d, 0xbf, 0xe1, 0xfb, 0xae, 0xd4, 0xe2, 0x6a, 0xd7,
		0xa6, 0xdd, 0xb4, 0xd8, 0x08, 0xab, 0x7a, 0x72, 0x71, 0x8c, 0x76, 0x6d, 0x7c, 0x9b, 0x19, 0x89,
		0xf6, 0x14, 0x9e, 0x76, 0xeb, 0xf6, 0x98, 0xcb, 0x7a, 0x1f, 0x46, 0xb3, 0x66, 0x0f, 0x2d, 0x2b,
		0xd5, 0xc5, 0x22, 0x52, 0x24, 0xe5, 0x0a, 0x24, 0x81, 0x09, 0x35, 0xcf, 0x77, 0x87, 0x5d, 0xdf,
		0x9e, 0x40, 0x4d, 0x7f, 0xf0, 0x74, 0xed, 0x8d, 0xff, 0x69, 0x85, 0xb7, 0x7c, 0x6a, 0x45, 0xf7,
		0xd9, 0x49, 0x47, 0xc1, 0xf8, 0xae, 0xe0, 0x5c, 0x5d, 0xd9, 0x55, 0x55, 0xb4, 0x9a, 0x7c, 0x73,
		0x9b, 0x7c, 0x86, 0x38, 0x66, 0x47, 0x0b, 0x1e, 0xad, 0xc7, 0x3d, 0x2b, 0xd3, 0x02, 0x8e, 0xe3,
		0xeb, 0x39, 0xd7, 0x43, 0x8c, 0x9b, 0x11, 0xe6, 0x60, 0x64, 0xb8, 0x16, 0x79, 0x4e, 0x45, 0x96,
		0x3b, 0x21, 0xe3, 0x48, 0xc8, 0xb8, 0x10, 0x12, 0xce, 0x43, 0xad, 0xc6, 0x0b, 0x73, 0x15, 0xd1,
		0x7a, 0x5b, 0xcc, 0xe8, 0x8b, 0xf1, 0x11, 0x32, 0x07, 0xf7, 0xa2, 0x03, 0x7a, 0x07, 0x07, 0x63,
		0x8c, 0x74, 0x18, 0x6a, 0x58, 0x0e, 0x6c, 0x85, 0x58, 0x8a, 0xc9, 0x4c, 0xf2, 0x22, 0x7f, 0x16,
		0x49, 0x34, 0x95, 0xa2, 0x96, 0xa2, 0x06, 0x4b, 0x01, 0x4b, 0xb1, 0xf6, 0x09, 0x2f, 0x4d, 0x31,
		0x58, 0xad, 0x85, 0xb5, 0x0e, 0x65, 0xcb, 0xa4, 0x4f, 0x0f, 0x13, 0xcf, 0x8f, 0x27, 0x1a, 0x6d,
		0x48, 0x6d, 0x7b, 0x48, 0x6f, 0x73, 0x50, 0x6c, 0x6b, 0xd0, 0x6d, 0x63, 0x50, 0x6d, 0x5b, 0x90,
		0x6f, 0x53, 0x90, 0x6f, 0x4b, 0x90, 0x6e, 0x43, 0xa4, 0x1b, 0x1f, 0x4b, 0x6f, 0x2b, 0x10, 0x57,
		0x13, 0xa7, 0xa8, 0x1e, 0x4e, 0x56, 0x2d, 0x5c, 0x71, 0x15, 0xec, 0x8e, 0xcc, 0x2b, 0x52, 0x56,
		0xff, 0x56, 0xfd, 0x9e, 0x69, 0x85, 0xb1, 0xef, 0x84, 0xfd, 0x88, 0xf4, 0xb1, 0xb1, 0x45, 0x47,
		0x22, 0x79, 0x50, 0x0c, 0x9e, 0x04, 0x9e, 0x64, 0x6b, 0x3d, 0x89, 0x82, 0x5a, 0xd6, 0x04, 0xb5,
		0xab, 0x89, 0x8e, 0x52, 0x11, 0xec, 0x0f, 0x50, 0x1e, 0x95, 0xa2, 0xce, 0xd4, 0x21, 0x3e, 0x0a,
		0xa5, 0xe2, 0x94, 0x0c, 0x45, 0x06, 0x16, 0xe5, 0xd1, 0x26, 0x55, 0x4b, 0x40, 0x59, 0x1b, 0x5a,
		0xc9, 0x3a, 0x64, 0xb4, 0x01, 0x95, 0x67, 0x38, 0x42, 0xdd, 0x06, 0x4c, 0x51, 0xdb, 0x2f, 0xc0,
		0x13, 0xc0, 0x13, 0x04, 0xba, 0x08, 0x74, 0x11, 0xe8, 0x16, 0xd6, 0xb3, 0xd0, 0x45, 0xbc, 0xc4,
		0x6d, 0xa8, 0xe0, 0x5b, 0xe0, 0x5b, 0x10, 0xfa, 0x22, 0xf4, 0x45, 0xe8, 0x8b, 0xd0, 0x17, 0xa1,
		0xef, 0xf6, 0x84, 0xbe, 0x5f, 0x1c, 0xab, 0xa7, 0xfb, 0xa6, 0x44, 0x85, 0xf8, 0xc8, 0x8a, 0x4e,
		0x87, 0x02, 0x04, 0x01, 0x04, 0x01, 0x04, 0xe1, 0x92, 0x97, 0xa1, 0x69, 0xfb, 0xef, 0x09, 0xf0,
		0xc6, 0x31, 0xf0, 0x46, 0x3a, 0xce, 0xae, 0x02, 0xbc, 0x91, 0xf5, 0x12, 0xd4, 0x8e, 0x8f, 0x01,
		0x36, 0x8a, 0x04, 0x36, 0x2c, 0xc3, 0xf3, 0x75, 0xdf, 0x19, 0x38, 0x96, 0xf3, 0xf2, 0x5d, 0xef,
		0x7e, 0x09, 0xed, 0x8d, 0x24, 0xee, 0x58, 0x39, 0x2a, 0x20, 0x08, 0x20, 0x08, 0x20, 0x08, 0x97,
		0xbc, 0x8c, 0xa0, 0xbb, 0x6f, 0x76, 0xff, 0xf2, 0xa4, 0x7a, 0x08, 0x12, 0xf4, 0x0c, 0xd4, 0xfe,
		0x6d, 0x8f, 0xad, 0xb0, 0x66, 0x1b, 0xb6, 0xe3, 0xb1, 0xae, 0x63, 0xf7, 0xa4, 0x48, 0x7f, 0x00,
		0x1b, 0x00, 0x9b, 0x22, 0x01, 0x1b, 0x75, 0x3d, 0xfe, 0x80, 0x74, 0xd2, 0x41, 0x3a, 0x82, 0x67,
		0xcc, 0x96, 0x6c, 0xb2, 0xd0, 0x59, 0x33, 0xa0, 0x19, 0xa0, 0x19, 0x10, 0x2a, 0xb2, 0xfd, 0x89,
		0x08, 0xfa, 0x11, 0x01, 0x78, 0x70, 0x79, 0x3d, 0x00, 0x8f, 0xac, 0x97, 0xa0, 0x5e, 0x39, 0xab,
		0x03, 0x68, 0x14, 0x09, 0x68, 0x04, 0xb9, 0x1f, 0x5d, 0xc7, 0xf3, 0xe5, 0xb1, 0xc6, 0x74, 0x28,
		0xc0, 0x0d, 0xc0, 0x0d, 0xc0, 0x0d, 0x6e, 0xb8, 0x71, 0x54, 0x43, 0xc2, 0x08, 0x78, 0x0e, 0xc0,
		0x8d, 0xe4, 0x70, 0xa3, 0x76, 0x56, 0x3f, 0x3b, 0x39, 0xad, 0x9d, 0x81, 0xdd, 0x28, 0x1e, 0xe8,
		0x18, 0x38, 0x2e, 0x15, 0xe8, 0x08, 0x86, 0x02, 0xe8, 0x00, 0xe8, 0x00, 0xe8, 0x00, 0xc7, 0x01,
		0xd0, 0x01, 0xd0, 0xa1, 0x72, 0x09, 0x08, 0x7b, 0x1a, 0x03, 0x6f, 0xa4, 0x83, 0x37, 0x16, 0x92,
		0x3b, 0x08, 0x0e, 0x66, 0x2e, 0x8d, 0x08, 0xf4, 0x01, 0xf4, 0x01, 0xf4, 0xc1, 0x25, 0x2f, 0x5d,
		0x67, 0x68, 0xfb, 0xcc, 0xcd, 0x3c, 0x5b, 0x04, 0x00, 0x04, 0x00, 0xa4, 0x48, 0x00, 0x04, 0xd9,
		0x1d, 0x45, 0xc7, 0x23, 0x5f, 0x2d, 0xc3, 0x96, 0xc7, 0x20, 0xc1, 0x28, 0xc0, 0x1d, 0xc0, 0x1d,
		0xc0, 0x1d, 0x7c, 0xac, 0x87, 0x6d, 0x3a, 0x36, 0x45, 0x0d, 0x88, 0x33, 0x89, 0x31, 0xc2, 0xd7,
		0xc9, 0x1c, 0x73, 0xcc, 0x1a, 0x13, 0xf1, 0x4c, 0x31, 0x62, 0x4e, 0x88, 0x18, 0x9a, 0xd1, 0x4d,
		0x97, 0x12, 0xa8, 0xa6, 0x08, 0x2f, 0x2c, 0xe3, 0x06, 0xe2, 0x71, 0x15, 0xb6, 0xc2, 0x27, 0x6c,
		0x23, 0x44, 0x0a, 0xe9, 0xd2, 0x5a, 0x2a, 0xba, 0x3c, 0x9a, 0x54, 0x56, 0x2b, 0x27, 0xfd, 0x84,
		0x3a, 0x59, 0xf6, 0x13, 0xa2, 0xb6, 0xc5, 0xae, 0xc4, 0x31, 0xa4, 0x95, 0xde, 0xea, 0x3d, 0xc1,
		0x58, 0x54, 0x15, 0x7d, 0xa2, 0x01, 0xff, 0xdc, 0xab, 0x57, 0xce, 0x1e, 0x2b, 0x7a, 0xbd, 0xf3,
		0xb3, 0x5e, 0x79, 0xac, 0xe8, 0xef, 0x3b, 0x8f, 0x15, 0xfd, 0xac, 0xf3, 0xf3, 0xb1, 0xaa, 0x1f,
		0x8d, 0x3f, 0xfe, 0x38, 0x7a, 0x1b, 0xfd, 0x74, 0x16, 0xfe, 0x54, 0x7d, 0x57, 0x0b, 0x7f, 0xde,
		0xff, 0xfc, 0xf9, 0xe0, 0xf3, 0xe7, 0x03, 0x89, 0x01, 0xfe, 0x26, 0xdf, 0xf2, 0xab, 0x43, 0x31,
		0xa9, 0x94, 0xb5, 0x92, 0xca, 0x33, 0xb3, 0xc5, 0x8a, 0x1b, 0xd1, 0xa5, 0x6a, 0xf3, 0xe0, 0x34,
		0x5d, 0xaa, 0xd0, 0x27, 0x29, 0xb6, 0x4f, 0x92, 0x40, 0x87, 0x38, 0x8e, 0xb6, 0x27, 0x3b, 0x84,
		0xd3, 0x37, 0xe9, 0xf0, 0xc6, 0x75, 0x3e, 0x45, 0x4c, 0x5b, 0xc4, 0xb5, 0x83, 0x54, 0x1b, 0xc4,
		0xa4, 0x3f, 0xe9, 0x74, 0x0a, 0x4a, 0x21, 0xa5, 0xf4, 0x69, 0x5c, 0x6d, 0x71, 0x36, 0xb5, 0x53,
		0x4b, 0x26, 0xc5, 0x9b, 0x65, 0x72, 0xfd, 0x37, 0x36, 0x4c, 0x2f, 0xef, 0xb4, 0x4a, 0x4e, 0xe7,
		0xfa, 0x77, 0x8e, 0x7f, 0x93, 0x35, 0x6f, 0x91, 0xb0, 0x01, 0x11, 0x57, 0xc3, 0xa1, 0x84, 0x0d,
		0x86, 0x12, 0x37, 0x14, 0xe2, 0x21, 0x03, 0xf9, 0x49, 0x3f, 0x5e, 0x72, 0x4f, 0x98, 0xc4, 0x13,
		0x26, 0xeb, 0x84, 0x48, 0x39, 0x39, 0xb9, 0x4e, 0xda, 0xc0, 0x47, 0xeb, 0x3b, 0xee, 0xff, 0x0c,
		0xb7, 0x37, 0x12, 0xdc, 0x1e, 0xb3, 0x8c, 0xe4, 0x75, 0x27, 0xa3, 0x85, 0x5a, 0x1a, 0x21, 0xa9,
		0x83, 0xe0, 0x8a, 0xb0, 0xb9, 0x19, 0x69, 0x11, 0x06, 0x5a, 0x9c, 0x71, 0x16, 0x65, 0x98, 0xa5,
		0x19, 0x65, 0x69, 0x06, 0x59, 0x8a, 0x31, 0xa6, 0x85, 0x0c, 0xdc, 0x0c, 0xb0, 0x70, 0x71, 0x24,
		0x81, 0x62, 0x48, 0x82, 0x54, 0xa5, 0x00, 0x60, 0x94, 0xa1, 0x1e, 0x65, 0xf7, 0x7d, 0x22, 0x7e,
		0x4a, 0xf0, 0x7a, 0x02, 0x12, 0x4a, 0x64, 0xbf, 0x4d, 0x86, 0x02, 0xa4, 0x9a, 0xb2, 0xa3, 0x4a,
		0x86, 0x73, 0xa6, 0x28, 0x24, 0xe8, 0x50, 0x81, 0xb4, 0x04, 0x6e, 0xfc, 0x0b, 0xb3, 0x2c, 0x87,
		0xaf, 0xd2, 0xe0, 0xb4, 0xb2, 0xe0, 0xf4, 0x5a, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x9f, 0x62, 0x7b,
		0x9f, 0x2a, 0xbc, 0x0f, 0xf7, 0x94, 0xc1, 0xfb, 0xc8, 0x79, 0x1f, 0xc7, 0xea, 0xe9, 0x41, 0xc2,
		0xa2, 0x80, 0xf7, 0x99, 0x5e, 0x9b, 0xd0, 0xd6, 0x5c, 0xb2, 0xbe, 0x31, 0xb4, 0x02, 0xa3, 0x77,
		0x02, 0x8f, 0x05, 0x8f, 0x05, 0x8f, 0x05, 0x8f, 0x05, 0x8f, 0x05, 0x8f, 0xc5, 0xe3, 0xb1, 0x5e,
		0x8d, 0x6f, 0xba, 0xf1, 0x22, 0x10, 0x2c, 0x4d, 0x2e, 0x84, 0xdf, 0x81, 0xdf, 0x81, 0xdf, 0x29,
		0xb6, 0xdf, 0x39, 0x81, 0xdf, 0xe1, 0xa6, 0x36, 0xe1, 0x77, 0xa4, 0xfd, 0xce, 0x17, 0x67, 0x20,
		0xe6, 0x77, 0x46, 0x17, 0xc2, 0xef, 0xc0, 0xef, 0xc0, 0xef, 0x20, 0xde, 0xd9, 0x32, 0xbf, 0x23,
		0xdc, 0x8c, 0x02, 0x8e, 0x67, 0x3c, 0x0d, 0x61, 0x36, 0x11, 0xa7, 0xd7, 0x09, 0xae, 0x82, 0xcb,
		0x81, 0xcb, 0x49, 0xd9, 0xe5, 0x78, 0xbe, 0x6b, 0xda, 0x2f, 0x02, 0x3e, 0x87, 0x27, 0x8f, 0x5f,
		0xbb, 0x62, 0xf6, 0x4b, 0x90, 0x8b, 0x06, 0xaf, 0x03, 0xaf, 0xb3, 0x6a, 0xca, 0x8e, 0x6a, 0x70,
		0x3a, 0x32, 0x4e, 0xc7, 0x65, 0x5f, 0x4d, 0x8f, 0x27, 0xeb, 0x76, 0x5a, 0xb8, 0x6e, 0x72, 0x25,
		0x9c, 0x0f, 0x9c, 0x4f, 0x06, 0xf1, 0x0e, 0x57, 0xb1, 0x59, 0x81, 0xe2, 0xb2, 0xdb, 0x15, 0xf0,
		0x54, 0xe0, 0x7a, 0xb8, 0x89, 0x36, 0xc9, 0xe2, 0xad, 0x5b, 0xe1, 0x82, 0xf2, 0x7d, 0x7a, 0x21,
		0xc1, 0x79, 0xa3, 0x35, 0xa7, 0x16, 0x76, 0x38, 0xde, 0x29, 0xe9, 0xbb, 0x70, 0xbf, 0x83, 0xb6,
		0xf6, 0xec, 0xc4, 0xaa, 0x53, 0x2a, 0xab, 0xdf, 0x77, 0xf9, 0x6d, 0x56, 0xbc, 0x89, 0xe6, 0x1a,
		0x03, 0xb3, 0xa7, 0x0f, 0xbe, 0xae, 0x29, 0xb7, 0x3f, 0x05, 0x08, 0xd3, 0xef, 0xc6, 0xcc, 0xc9,
		0xfa, 0x73, 0x18, 0x1b, 0x21, 0x40, 0x12, 0x97, 0x9f, 0xdc, 0xc5, 0x27, 0x75, 0xe9, 0xdc, 0x2e,
		0x9c, 0xdb, 0x65, 0x73, 0xb9, 0x68, 0x3e, 0x29, 0xdc, 0x74, 0x6e, 0x22, 0x59, 0x65, 0x1f, 0x9e,
		0x0a, 0x3e, 0xdc, 0x87, 0x6d, 0x2a, 0x38, 0x6c, 0x43, 0x8e, 0xdf, 0x52, 0x3a, 0x6c, 0xd3, 0x9d,
		0xac, 0x21, 0x67, 0x28, 0x11, 0x5e, 0xc7, 0x17, 0x48, 0x54, 0x11, 0x48, 0x20, 0x90, 0xe0, 0x13,
		0xd0, 0xe8, 0x82, 0x67, 0xd7, 0xec, 0xbd, 0x30, 0x7d, 0xe0, 0x9a, 0x8e, 0x6b, 0xfa, 0xdf, 0xf9,
		0x67, 0x7f, 0xb2, 0xde, 0x8b, 0x03, 0x71, 0x4e, 0xa1, 0x18, 0x12, 0x15, 0xae, 0x5e, 0x26, 0x53,
		0xb5, 0x4c, 0xbe, 0x5a, 0x99, 0x6c, 0x95, 0x32, 0xb2, 0xea, 0x64, 0x64, 0x55, 0xc9, 0x48, 0xaa,
		0x91, 0xa9, 0x3d, 0xdd, 0x2f, 0x5c, 0x75, 0x6c, 0x86, 0xe8, 0x1d, 0xe8, 0x0b, 0x62, 0xae, 0xfb,
		0xa3, 0x51, 0x05, 0x24, 0x40, 0xbc, 0xc5, 0x8b, 0x64, 0x25, 0x2d, 0xb9, 0xda, 0x14, 0x04, 0x85,
		0xf5, 0x48, 0xca, 0x2d, 0x51, 0x55, 0xc2, 0xa2, 0xac, 0xa5, 0xf4, 0x26, 0x57, 0xac, 0x23, 0x77,
		0x53, 0x7b, 0x52, 0xad, 0xd6, 0xeb, 0x95, 0x1c, 0xcd, 0x6f, 0x4a, 0x45, 0x46, 0x3a, 0xaa, 0xaa,
		0x6e, 0x70, 0x60, 0x21, 0xe1, 0xc3, 0xda, 0x4b, 0x46, 0x4b, 0xf0, 0xd0, 0x36, 0x1c, 0x33, 0x1c,
		0x73, 0x61, 0x1c, 0x33, 0x6f, 0xd2, 0xcf, 0xa2, 0x70, 0x1f, 0xc3, 0x0b, 0xcb, 0xb9, 0x8a, 0x3a,
		0xbc, 0xb0, 0xaa, 0xa9, 0x3d, 0x82, 0x07, 0xce, 0xc4, 0x03, 0x0b, 0x1c, 0x52, 0x5f, 0xb2, 0x4b,
		0xdc, 0x87, 0xd5, 0xe1, 0x75, 0xe1, 0x75, 0xe1, 0x75, 0xe1, 0x75, 0x11, 0xfb, 0x66, 0x3d, 0xb5,
		0xf0, 0xba, 0xd9, 0x78, 0x5d, 0xfe, 0xc3, 0xf9, 0xcb, 0x5e, 0x97, 0xf7, 0x90, 0x7e, 0x34, 0x82,
		0xc0, 0x61, 0x7d, 0x78, 0x6c, 0x78, 0x6c, 0x78, 0x6c, 0x78, 0x6c, 0x78, 0x6c, 0x78, 0xec, 0xad,
		0xf4, 0xd8, 0xbc, 0xc5, 0x09, 0x96, 0x8c, 0x12, 0x5f, 0x91, 0x02, 0xf8, 0x5b, 0xf8, 0x5b, 0xf8,
		0x5b, 0xf8, 0xdb, 0x64, 0x4e, 0xe1, 0x04, 0xfe, 0x56, 0xd5, 0xd4, 0x62, 0x67, 0x38, 0x1b, 0x7f,
		0x3b, 0xe9, 0xee, 0x26, 0xec, 0x6f, 0xc5, 0xda, 0xc3, 0xc1, 0xdf, 0xc2, 0xdf, 0xe6, 0xde, 0xdf,
		0x8a, 0x77, 0x3e, 0x94, 0xe8, 0x74, 0x08, 0x8f, 0x8b, 0x08, 0x37, 0x25, 0x8f, 0x7b, 0x56, 0x87,
		0xcf, 0x25, 0xf3, 0xb9, 0x85, 0x6b, 0xda, 0x33, 0x3d, 0x45, 0x74, 0x38, 0x32, 0x74, 0x87, 0xe1,
		0x59, 0x81, 0x14, 0x8f, 0x48, 0x9b, 0xb6, 0xcf, 0xdc, 0xbe, 0xd1, 0x65, 0x1e, 0xff, 0xc9, 0x86,
		0x99, 0x6b, 0x71, 0xba, 0x21, 0x45, 0x24, 0xb1, 0xd5, 0xa7, 0x1b, 0x22, 0xa1, 0x13, 0x87, 0xcb,
		0xd3, 0x21, 0xc4, 0x00, 0x73, 0x15, 0x80, 0x19, 0x80, 0x59, 0x0d, 0x60, 0xe6, 0x55, 0x87, 0xe8,
		0x42, 0xce, 0xd3, 0x69, 0xb1, 0xe2, 0xc2, 0x75, 0x5a, 0x8d, 0x48, 0x41, 0xa4, 0x15, 0x85, 0x42,
		0x61, 0xe8, 0x14, 0x87, 0x4a, 0x81, 0xc8, 0x15, 0x89, 0x5c, 0xa1, 0x48, 0x15, 0x4b, 0x12, 0x85,
		0x0a, 0x4a, 0x8c, 0xa8, 0xc2, 0xcd, 0x28, 0x9e, 0xe7, 0xcb, 0x2f, 0xf1, 0x54, 0xfd, 0x3c, 0x5f,
		0x76, 0x75, 0x89, 0x62, 0x14, 0x59, 0x65, 0xa4, 0x54, 0x4a, 0x7a, 0xe5, 0xa4, 0x56, 0x52, 0x65,
		0xca, 0xaa, 0x4c, 0x69, 0x95, 0x28, 0xaf, 0x9c, 0x12, 0x13, 0x84, 0xf9, 0x72, 0xb4, 0x53, 0xac,
		0xbc, 0x71, 0xd7, 0xe4, 0xd9, 0xa4, 0x9d, 0xa7, 0x04, 0x43, 0xc9, 0xb1, 0x54, 0x74, 0xac, 0x95,
		0x12, 0x16, 0x4b, 0x91, 0x59, 0x53, 0xc5, 0x72, 0xa9, 0xe4, 0x65, 0x88, 0xd5, 0x83, 0x9c, 0x15,
		0x4b, 0x7b, 0xa9, 0x6a, 0x95, 0xf0, 0xbf, 0x02, 0x2d, 0xd9, 0x4e, 0x3e, 0x46, 0xc9, 0xaa, 0x6f,
		0xbf, 0x0c, 0x71, 0xcb, 0x55, 0x3a, 0x76, 0xa3, 0x25, 0xe7, 0x28, 0x29, 0x0b, 0x84, 0x05, 0x84,
		0x05, 0x84, 0x95, 0x12, 0xc2, 0x7a, 0x36, 0x3c, 0xa6, 0x47, 0xcc, 0x9c, 0xee, 0xb2, 0x3e, 0x21,
		0xda, 0xaa, 0x52, 0xc0, 0xad, 0xbb, 0x88, 0xd2, 0xef, 0xea, 0x66, 0xff, 0x7c, 0xca, 0x7e, 0x2f,
		0xfe, 0x22, 0xfc, 0x39, 0xb0, 0x34, 0x05, 0xb4, 0xb7, 0x03, 0xc7, 0xf5, 0xc5, 0xab, 0xc7, 0xc4,
		0x2e, 0xf0, 0xfc, 0xb0, 0xb0, 0xc0, 0xb0, 0xc0, 0xb0, 0xc0, 0xb9, 0xb2, 0xc0, 0x9e, 0x3f, 0xd0,
		0xe7, 0x94, 0x54, 0xb4, 0x12, 0x4e, 0x9c, 0xb6, 0x1e, 0x23, 0xe6, 0x45, 0xcc, 0x8b, 0x98, 0x57,
		0x2c, 0xe6, 0xad, 0x23, 0xda, 0x2d, 0x4e, 0xb4, 0x9b, 0xea, 0x16, 0x86, 0x60, 0xa2, 0xca, 0xd2,
		0x38, 0x32, 0x89, 0x2b, 0x33, 0x60, 0x78, 0x0a, 0x83, 0x79, 0xb2, 0x59, 0xe4, 0xa7, 0x50, 0xa4,
		0xd2, 0xb6, 0x14, 0xb5, 0x40, 0x41, 0x29, 0xc8, 0x96, 0xeb, 0xc6, 0x8e, 0x69, 0x2a, 0x00, 0x15,
		0x3b, 0xa6, 0x84, 0xc0, 0x33, 0x92, 0x17, 0x8b, 0x19, 0x7d, 0xb9, 0x38, 0x9f, 0x22, 0xbe, 0x8f,
		0xe2, 0xfa, 0x83, 0x83, 0x71, 0xc9, 0xf4, 0x43, 0xf1, 0xc0, 0x3d, 0x1d, 0xab, 0x35, 0x2e, 0xec,
		0x2e, 0x6d, 0xb6, 0xc6, 0xc3, 0x64, 0x9c, 0xe9, 0x51, 0x83, 0xdd, 0x82, 0xdd, 0x4a, 0xc5, 0x6e,
		0x21, 0xd3, 0x03, 0x2c, 0x18, 0x58, 0x30, 0xb0, 0x60, 0x1b, 0xe4, 0x0d, 0x99, 0x1e, 0x60, 0xbd,
		0xc0, 0x7a, 0xe5, 0x85, 0xf5, 0x42, 0xa6, 0x47, 0xe1, 0xb8, 0xaf, 0x77, 0x32, 0x08, 0x6b, 0x68,
		0xfb, 0xcc, 0xf5, 0x28, 0x51, 0x56, 0x38, 0x22, 0x0d, 0xd2, 0xaa, 0x02, 0x69, 0x01, 0x69, 0x6d,
		0x27, 0xd2, 0x92, 0x0d, 0x9f, 0xa2, 0x81, 0x9e, 0x07, 0xbd, 0xa1, 0xee, 0xb2, 0x2e, 0x33, 0xbf,
		0xb2, 0x1e, 0x9d, 0x8c, 0x44, 0x79, 0x24, 0x73, 0xc3, 0x13, 0x2d, 0x27, 0xad, 0x9b, 0x23, 0x33,
		0x03, 0x2a, 0xcc, 0x81, 0x3a, 0xb3, 0xa0, 0xca, 0x3c, 0x28, 0x37, 0x13, 0xca, 0xcd, 0x85, 0x52,
		0xb3, 0x41, 0x0c, 0x4c, 0x88, 0x24, 0x96, 0x2c, 0x70, 0x8b, 0x73, 0xf9, 0x27, 0x75, 0x4a, 0x91,
		0x0d, 0x0d, 0xc0, 0x7b, 0xc2, 0x21, 0x69, 0x63, 0x3a, 0xfa, 0xd8, 0x4e, 0x69, 0x8c, 0xa7, 0x38,
		0x80, 0x58, 0x0a, 0x24, 0x54, 0x8d, 0xaf, 0x30, 0x90, 0x50, 0x10, 0x03, 0x2a, 0x8d, 0x05, 0xd3,
		0x5e, 0xd2, 0xea, 0xfb, 0x7a, 0xfd, 0xe4, 0xb4, 0x5e, 0xaf, 0x9c, 0x1e, 0x9d, 0x56, 0xce, 0x8e,
		0x8f, 0xab, 0x27, 0xd5, 0xe3, 0x02, 0xaf, 0xf2, 0x4e, 0x3e, 0x47, 0xeb, 0xe4, 0x24, 0x9c, 0x25,
		0xd0, 0x82, 0x31, 0x34, 0xf4, 0x98, 0xed, 0x2b, 0x42, 0x9d, 0xc1, 0xd0, 0x40, 0x9c, 0x40, 0x9c,
		0x40, 0x9c, 0x40, 0x9c, 0x40, 0x9c, 0x40, 0x9c, 0x40, 0x9c, 0x40, 0x9c, 0x40, 0x9c, 0x45, 0x45,
		0x9c, 0x99, 0xd2, 0xad, 0x44, 0x49, 0xbd, 0xd1, 0x78, 0xe4, 0xc9, 0xbd, 0xe3, 0x54, 0x39, 0xa2,
		0xfd, 0x95, 0xf1, 0x23, 0xfa, 0xee, 0xb0, 0xeb, 0x87, 0x29, 0xb9, 0xda, 0x83, 0x3f, 0x78, 0xfa,
		0xcd, 0x32, 0xec, 0xa7, 0xd6, 0xe4, 0x96, 0x4f, 0x17, 0x93, 0x9b, 0x15, 0x70, 0x6b, 0xab, 0xc7,
		0x3c, 0xf3, 0xc5, 0x36, 0x7c, 0xd6, 0x9b, 0xf4, 0x9b, 0x36, 0x7a, 0x3d, 0x97, 0x79, 0x84, 0x7b,
		0x5d, 0xf1, 0xb7, 0x40, 0x9a, 0x51, 0x7a, 0x31, 0x07, 0x36, 0xbf, 0x90, 0x66, 0x94, 0x40, 0xde,
		0x5e, 0x8d, 0x2e, 0x91, 0x7a, 0xce, 0xaa, 0x68, 0xf5, 0x3d, 0xcd, 0x39, 0x67, 0x9f, 0xb9, 0x36,
		0x59, 0xa0, 0xa0, 0xfd, 0xf9, 0x58, 0xd1, 0xcf, 0x0c, 0xbd, 0xdf, 0xd0, 0x3f, 0x76, 0x7e, 0xd4,
		0xde, 0xf6, 0xce, 0xe7, 0x7f, 0xde, 0xff, 0x71, 0xfc, 0xf6, 0x37, 0x79, 0x09, 0xe9, 0x50, 0xbc,
		0xfa, 0xed, 0x43, 0xeb, 0x3f, 0x45, 0x7d, 0xff, 0x52, 0x78, 0x45, 0xfa, 0x73, 0xe7, 0x6b, 0xee,
		0x01, 0xbf, 0x08, 0xbf, 0x08, 0xbf, 0x98, 0x2b, 0xbf, 0xe8, 0xf9, 0x83, 0x45, 0x35, 0xa5, 0x3e,
		0x86, 0x8e, 0x84, 0xdc, 0x7c, 0xf0, 0x2b, 0x48, 0xc8, 0x2d, 0x5e, 0x42, 0xee, 0x49, 0xb5, 0x5a,
		0xc7, 0x49, 0xf4, 0xad, 0x03, 0x67, 0xb4, 0x47, 0x9f, 0x16, 0x07, 0x06, 0x0c, 0x03, 0x0c, 0x03,
		0x0c, 0xcb, 0x15, 0x0c, 0xc3, 0x29, 0xa8, 0xb2, 0x83, 0xae, 0x0a, 0x40, 0x57, 0x51, 0x96, 0xaa,
		0x5e, 0x3b, 0xab, 0x9f, 0x9d, 0x9c, 0xd6, 0xce, 0x8e, 0x01, 0xbc, 0xb6, 0x0c, 0x78, 0x05, 0xf5,
		0xd8, 0xec, 0xe1, 0xab, 0x12, 0xf0, 0x15, 0x0d, 0x0e, 0x00, 0x06, 0x00, 0x06, 0x00, 0x96, 0x3b,
		0x00, 0x56, 0x3d, 0x21, 0x04, 0x60, 0x27, 0x00, 0x60, 0x00, 0x60, 0x00, 0x60, 0x62, 0xac, 0xd7,
		0xf1, 0xf1, 0x11, 0xb0, 0xd7, 0x56, 0x62, 0x2f, 0xa5, 0xfb, 0x91, 0x28, 0x89, 0x0d, 0x14, 0x06,
		0x14, 0x96, 0x63, 0x14, 0x86, 0x92, 0xd8, 0xdb, 0x86, 0xca, 0xb0, 0x17, 0x59, 0x98, 0xa5, 0x42,
		0x49, 0xec, 0xed, 0xc3, 0x64, 0xae, 0xe3, 0xf8, 0x4a, 0x33, 0xa7, 0xe7, 0x6e, 0x00, 0x44, 0x06,
		0x44, 0x06, 0x44, 0x96, 0x2b, 0x44, 0x86, 0xbc, 0x69, 0xe4, 0x4d, 0x23, 0x6f, 0x7a, 0xd1, 0x61,
		0x29, 0x65, 0x29, 0xe6, 0xef, 0x00, 0x9f, 0x08, 0x9f, 0x08, 0x9f, 0x98, 0x3b, 0x96, 0x02, 0x39,
		0xd3, 0xe0, 0x29, 0xc0, 0x53, 0xe4, 0x72, 0xa9, 0x90, 0x33, 0xbd, 0x3d, 0xc0, 0xac, 0xef, 0xb8,
		0xff, 0x33, 0xdc, 0x9e, 0xee, 0xbb, 0x86, 0xed, 0x99, 0x9e, 0x39, 0x5a, 0x22, 0x42, 0xa2, 0x62,
		0xf5, 0xf0, 0x80, 0x64, 0x80, 0x64, 0x80, 0x64, 0xb9, 0x82, 0x64, 0x94, 0x25, 0xa1, 0x08, 0x4b,
		0x41, 0x01, 0x83, 0x51, 0x3a, 0x76, 0x64, 0xf0, 0x14, 0x07, 0x2e, 0x2b, 0x2f, 0xdd, 0x04, 0x44,
		0x96, 0x4f, 0x44, 0x26, 0xd5, 0xe2, 0x73, 0xc9, 0xae, 0x4b, 0xb4, 0xfa, 0x04, 0xde, 0x02, 0xde,
		0x02, 0xde, 0x52, 0x84, 0xb7, 0x9e, 0x0d, 0x8f, 0xe9, 0x51, 0x71, 0x32, 0x5d, 0xae, 0xab, 0xe8,
		0xa2, 0xa6, 0x56, 0x4f, 0x69, 0x76, 0x87, 0xc2, 0xd2, 0x6b, 0x5d, 0xdd, 0xec, 0x9f, 0xcf, 0xd4,
		0x54, 0x5b, 0xf8, 0x45, 0xf8, 0xb3, 0x78, 0x13, 0xd2, 0x6c, 0xed, 0x2d, 0xfd, 0x89, 0x15, 0x1c,
		0x53, 0x81, 0xdd, 0x85, 0xdd, 0xdd, 0xc5, 0x31, 0x15, 0x04, 0xb9, 0x08, 0x72, 0x11, 0xe4, 0xc6,
		0x2f, 0x15, 0x8e, 0xa9, 0x6c, 0x4d, 0x54, 0xab, 0xe8, 0x6c, 0x0a, 0x0e, 0xa4, 0x00, 0x6f, 0x01,
		0x6f, 0xe5, 0x18, 0x6f, 0xe1, 0x40, 0xca, 0xb6, 0xe1, 0x2f, 0x24, 0x7a, 0x14, 0x66, 0xa9, 0x70,
		0x20, 0x65, 0x9b, 0xd0, 0x57, 0xd0, 0x00, 0x81, 0x18, 0x7a, 0x8d, 0xc7, 0x04, 0xee, 0x02, 0xee,
		0x02, 0xee, 0xca, 0x15, 0xee, 0x32, 0x7b, 0xcc, 0xf6, 0x4d, 0xff, 0x3b, 0xf1, 0xc6, 0x02, 0x05,
		0xda, 0x6a, 0x85, 0x8f, 0xf6, 0xc1, 0xf0, 0x18, 0x7d, 0x63, 0xc3, 0x87, 0xf6, 0xdd, 0xd3, 0xdd,
		0xed, 0x7d, 0xfb, 0xe9, 0xa1, 0xdd, 0x68, 0x37, 0xa9, 0x64, 0x39, 0xf0, 0x98, 0x1e, 0x69, 0x2b,
		0x32, 0x62, 0xa8, 0x30, 0x79, 0xff, 0xab, 0xd6, 0x43, 0xbb, 0x79, 0xd3, 0xba, 0xf9, 0xa4, 0xe5,
		0x11, 0x26, 0xa9, 0x7a, 0xe9, 0x66, 0xe3, 0x7e, 0xdb, 0xde, 0xf9, 0xe3, 0xed, 0xfd, 0xef, 0x8d,
		0xfb, 0xcb, 0x2d, 0x7b, 0xeb, 0x0f, 0x57, 0xb7, 0x17, 0xbf, 0x6e, 0xd9, 0x3b, 0x5f, 0xb6, 0x1e,
		0x1a, 0x1f, 0xae, 0x9a, 0x97, 0x79, 0x6b, 0x74, 0xd9, 0xc9, 0xda, 0xeb, 0x66, 0x82, 0xa5, 0x5d,
		0xc7, 0x22, 0x44, 0xd1, 0xc1, 0x68, 0xc0, 0xcf, 0xc0, 0xcf, 0xc0, 0xcf, 0xc0, 0xcf, 0xb9, 0xc2,
		0xcf, 0xf7, 0xb7, 0x57, 0x5b, 0x08, 0x9f, 0xef, 0x6f, 0x6f, 0xdb, 0x5b, 0x85, 0xa7, 0x1a, 0x17,
		0xbf, 0xfe, 0xfb, 0x6e, 0xab, 0xd0, 0x54, 0xf3, 0xa1, 0xf5, 0xe9, 0xa6, 0xd1, 0x26, 0xc5, 0x53,
		0xb9, 0x7f, 0xeb, 0xc6, 0x55, 0xbb, 0x79, 0x3f, 0x7a, 0x6b, 0x80, 0x48, 0x32, 0x10, 0xb9, 0x93,
		0xa2, 0xa8, 0x50, 0xf5, 0xd7, 0x55, 0xd4, 0x57, 0x57, 0x4c, 0xaa, 0xf8, 0x67, 0x90, 0xef, 0x0a,
		0xce, 0xb9, 0x1e, 0x41, 0x39, 0xc1, 0x9c, 0x79, 0xed, 0xca, 0xf4, 0xfc, 0x86, 0xef, 0xbb, 0x42,
		0x8b, 0xa3, 0x5d, 0x9b, 0x76, 0xd3, 0x62, 0x23, 0x4c, 0xe6, 0x89, 0xe1, 0x6f, 0xed, 0xda, 0xf8,
		0x36, 0x33, 0x02, 0xcd, 0xe9, 0x11, 0xed, 0xd6, 0xed, 0x31, 0x97, 0xf5, 0x3e, 0x8c, 0x66, 0xc5,
		0x1e, 0x5a, 0x96, 0xd2, 0xc9, 0x97, 0x14, 0x70, 0x72, 0xc1, 0x16, 0xc0, 0x3e, 0x1b, 0x3b, 0x42,
		0xf3, 0xa9, 0x49, 0x72, 0x61, 0x4f, 0xf6, 0xcd, 0x84, 0x2b, 0x22, 0xba, 0x12, 0x44, 0x2b, 0x90,
		0x6c, 0x8e, 0x36, 0xbf, 0x71, 0x82, 0xb7, 0xd5, 0xf8, 0xb6, 0xc4, 0x66, 0x92, 0x1a, 0x92, 0xef,
		0x7a, 0x45, 0xd0, 0x3f, 0xe1, 0xd7, 0xa3, 0x28, 0xbc, 0x96, 0xf0, 0x02, 0x81, 0x68, 0x5b, 0x3c,
		0xaa, 0x16, 0x8d, 0x9e, 0xa5, 0xa3, 0x64, 0xe9, 0x68, 0x58, 0x2a, 0xea, 0xa5, 0xd5, 0xaf, 0x4b,
		0x93, 0xcf, 0x4d, 0x68, 0x92, 0x0d, 0xd8, 0xa7, 0x87, 0x4e, 0x64, 0xba, 0xac, 0x0b, 0xd2, 0x4c,
		0xc2, 0xb4, 0x92, 0x0c, 0x8d, 0x24, 0x4f, 0x1b, 0xc9, 0xd2, 0x44, 0x64, 0xb4, 0x10, 0x19, 0x0d,
		0x44, 0x42, 0xfb, 0xa8, 0xc5, 0x5f, 0xc2, 0x34, 0x0e, 0x51, 0xb5, 0x3d, 0x99, 0xea, 0x7a, 0xd2,
		0xd5, 0xf4, 0x14, 0x55, 0x8f, 0xeb, 0x88, 0xbc, 0x0a, 0x45, 0x75, 0x3c, 0x55, 0xef, 0xa3, 0x0a,
		0x42, 0xbd, 0xe3, 0xb6, 0xc7, 0xc2, 0xe9, 0xcc, 0x8b, 0x06, 0x59, 0x30, 0x81, 0x19, 0x16, 0x19,
		0x16, 0x39, 0xf7, 0x16, 0x99, 0xb0, 0xd6, 0x9b, 0x44, 0x6d, 0x37, 0xc9, 0x14, 0x5f, 0x09, 0xbe,
		0x85, 0x22, 0x85, 0x97, 0x6a, 0x87, 0x8f, 0x28, 0x45, 0x97, 0x32, 0xcb, 0x53, 0x66, 0x27, 0x96,
		0x22, 0xe5, 0x96, 0x7a, 0x6a, 0x29, 0x6a, 0xa7, 0x91, 0xce, 0x6f, 0x4a, 0xc4, 0x5c, 0x1e, 0xdc,
		0x32, 0x55, 0xd9, 0x75, 0xe2, 0x32, 0xeb, 0x70, 0xd3, 0x70, 0xd3, 0x08, 0x9c, 0x10, 0x38, 0x21,
		0x70, 0xa2, 0x2b, 0x03, 0x4e, 0x5d, 0xf6, 0x1b, 0x36, 0x1a, 0x36, 0x1a, 0xa1, 0x14, 0x42, 0x29,
		0x84, 0x52, 0x08, 0xa5, 0x10, 0x4a, 0x45, 0x75, 0x9b, 0x4d, 0xfb, 0x45, 0xef, 0x31, 0xcb, 0x90,
		0x70, 0xd0, 0x4b, 0x23, 0xc1, 0x31, 0xc3, 0x31, 0x97, 0xcc, 0x31, 0x0f, 0x4d, 0xdb, 0x7f, 0x2f,
		0xe1, 0x85, 0x8f, 0xe1, 0x85, 0xe5, 0x5c, 0x45, 0x1d, 0x5e, 0x58, 0xd5, 0xd4, 0x1e, 0xc1, 0x03,
		0x67, 0xe2, 0x81, 0xbf, 0x30, 0xcb, 0x72, 0x74, 0xdf, 0x14, 0x28, 0x06, 0x1c, 0xd9, 0xa5, 0x99,
		0x31, 0xe0, 0x75, 0xe1, 0x75, 0xe1, 0x75, 0xe1, 0x75, 0x11, 0xfb, 0x16, 0xc2, 0xeb, 0x56, 0xe1,
		0x75, 0xb3, 0xf1, 0xba, 0x8e, 0xd5, 0xd3, 0x83, 0x5e, 0x28, 0x12, 0x5e, 0x77, 0x3a, 0x06, 0xa7,
		0x4d, 0xbc, 0x64, 0x7d, 0x63, 0x68, 0x05, 0x46, 0xfb, 0x04, 0x1e, 0x1b, 0x1e, 0x1b, 0x1e, 0x1b,
		0x1e, 0x1b, 0x1e, 0x1b, 0x1e, 0x1b, 0x1e, 0x7b, 0x83, 0xc7, 0x96, 0x0c, 0x93, 0xa3, 0x21, 0xe0,
		0x73, 0xe1, 0x73, 0xe1, 0x73, 0xe1, 0x73, 0x29, 0x1d, 0x43, 0x05, 0x3e, 0x57, 0xd5, 0xd4, 0xd6,
		0x8e, 0x8f, 0xe1, 0x74, 0xb3, 0x70, 0xba, 0x96, 0xe1, 0xf9, 0xba, 0xef, 0x0c, 0x1c, 0xcb, 0x79,
		0xf9, 0xae, 0x77, 0xbf, 0x84, 0xfa, 0x2e, 0xe8, 0x7f, 0x57, 0x8e, 0x06, 0x57, 0x0c, 0x57, 0x5c,
		0x32, 0x57, 0x3c, 0x82, 0x98, 0xbe, 0xd9, 0xfd, 0xcb, 0x13, 0xea, 0xb2, 0x2b, 0xd1, 0x55, 0x57,
		0xfb, 0xb7, 0x3d, 0xb6, 0x6e, 0x9a, 0x6d, 0xd8, 0x8e, 0xc7, 0xba, 0x8e, 0xdd, 0x13, 0x4a, 0xf3,
		0x85, 0x63, 0x87, 0x63, 0x4f, 0x25, 0x98, 0x26, 0xef, 0x7e, 0x0b, 0x4f, 0x2f, 0xe6, 0xe9, 0x5f,
		0x8d, 0x6f, 0xba, 0x21, 0xe3, 0xdc, 0x27, 0x03, 0xc0, 0x9f, 0xc3, 0x9f, 0x23, 0xb4, 0x46, 0x68,
		0x4d, 0x9a, 0x21, 0x0c, 0x0f, 0xac, 0x6a, 0x6a, 0x91, 0x78, 0x9d, 0x8d, 0xbf, 0x0d, 0x0e, 0x31,
		0x75, 0x1d, 0x4f, 0x62, 0xff, 0x79, 0x3a, 0x04, 0x7c, 0x2e, 0x7c, 0x6e, 0x09, 0x7d, 0xee, 0x51,
		0x0d, 0x27, 0x9e, 0x10, 0xf6, 0x96, 0xd1, 0xe9, 0xd6, 0xce, 0xea, 0x67, 0x27, 0xa7, 0xb5, 0x33,
		0x04, 0xbb, 0xd9, 0x39, 0xdf, 0x81, 0xe3, 0xca, 0x3a, 0xdf, 0x60, 0x08, 0x38, 0x5f, 0x38, 0xdf,
		0x12, 0x3a, 0x5f, 0xa1, 0xe6, 0xf9, 0x12, 0xcd, 0xf2, 0xe1, 0x7c, 0xe1, 0x7c, 0xd3, 0x21, 0x13,
		0xe4, 0x9b, 0xd1, 0xc3, 0xef, 0x8a, 0xf9, 0xdd, 0x85, 0xbd, 0x5f, 0x89, 0x8a, 0x4d, 0x4b, 0x23,
		0xc1, 0x0b, 0xc3, 0x0b, 0x97, 0xcc, 0x0b, 0x07, 0x47, 0x0b, 0x98, 0x9b, 0xfa, 0x26, 0x32, 0x1c,
		0x31, 0x1c, 0x71, 0x1a, 0x53, 0x8b, 0xcd, 0xdf, 0xbc, 0xf8, 0xe5, 0xaf, 0x96, 0x61, 0xeb, 0x66,
		0x4f, 0xdc, 0x1d, 0x4f, 0x06, 0x80, 0x17, 0x86, 0x17, 0x2e, 0x99, 0x17, 0x16, 0x13, 0x6d, 0x04,
		0xc3, 0x38, 0xcd, 0x54, 0x04, 0x1f, 0x5c, 0xaf, 0x9c, 0xd5, 0xe1, 0x73, 0xc9, 0x7c, 0x6e, 0xe1,
		0xdb, 0x33, 0x71, 0x34, 0x79, 0xa3, 0xe9, 0xcc, 0xc4, 0x0b, 0x3d, 0x04, 0xed, 0x32, 0xa7, 0xde,
		0x70, 0x43, 0x0c, 0x74, 0x67, 0x4a, 0x01, 0x32, 0xd0, 0xaa, 0x17, 0x37, 0x34, 0x98, 0x9e, 0x63,
		0x60, 0x46, 0x9f, 0xaf, 0x5f, 0x70, 0x54, 0x37, 0x99, 0x63, 0x57, 0x5a, 0xbb, 0x0b, 0x35, 0xf8,
		0xe0, 0x60, 0xac, 0x96, 0x87, 0x13, 0x91, 0xa7, 0x52, 0xcf, 0x1d, 0x89, 0x69, 0x9c, 0xf4, 0x50,
		0x4c, 0xa6, 0x86, 0x7c, 0x6d, 0x13, 0xf9, 0xdb, 0x24, 0x92, 0xb4, 0x45, 0xe4, 0x6b, 0x83, 0xb8,
		0x69, 0x7e, 0x38, 0xad, 0xb7, 0x8c, 0xd5, 0xd6, 0x12, 0x75, 0xc0, 0x5b, 0xd5, 0xb1, 0x70, 0xbd,
		0x28, 0xc5, 0x0b, 0xc8, 0xea, 0xbf, 0xc4, 0x4c, 0x49, 0xd2, 0xa9, 0x10, 0x9c, 0x82, 0xd5, 0xef,
		0xb0, 0xfc, 0x84, 0x2b, 0x9e, 0x4e, 0x73, 0x47, 0xf6, 0x27, 0xee, 0x99, 0xa6, 0x7b, 0xbd, 0xf1,
		0xd6, 0x79, 0x43, 0xd7, 0xbf, 0x8d, 0x7e, 0x24, 0x89, 0xdf, 0x48, 0xee, 0x27, 0x92, 0xfa, 0x05,
		0x6e, 0x3f, 0xc0, 0x6d, 0xf7, 0xb9, 0xec, 0x3c, 0x9f, 0x34, 0x6d, 0xea, 0xaa, 0xa7, 0x75, 0x27,
		0x73, 0xbe, 0x61, 0x12, 0xa6, 0x3c, 0x6b, 0xf0, 0xfd, 0x4d, 0xf6, 0x2e, 0x51, 0x7b, 0xc7, 0xc4,
		0xc0, 0x81, 0x07, 0x30, 0xf0, 0x03, 0x05, 0x5e, 0x80, 0x20, 0x0c, 0x0c, 0x84, 0x01, 0x81, 0x10,
		0x10, 0x90, 0xf3, 0x58, 0x49, 0xdb, 0x31, 0x0a, 0xb7, 0xfd, 0x92, 0x6c, 0xf7, 0x05, 0x8c, 0x0a,
		0x8c, 0x4a, 0x86, 0x51, 0x09, 0x6a, 0xc8, 0x0b, 0x64, 0x52, 0x0a, 0xf2, 0x56, 0x62, 0x9d, 0xb4,
		0x25, 0x98, 0x54, 0x29, 0x12, 0x45, 0x96, 0x97, 0xa2, 0x60, 0x4c, 0xde, 0xc4, 0x5a, 0x87, 0x67,
		0x3e, 0x65, 0x32, 0xb5, 0xde, 0x49, 0xe6, 0x4d, 0x11, 0xf3, 0xd3, 0x49, 0x91, 0x32, 0x11, 0xae,
		0xd9, 0x2e, 0x5b, 0xab, 0x1d, 0x0e, 0x0a, 0x0e, 0x8a, 0xcc, 0x41, 0xf1, 0x1e, 0xaa, 0x13, 0x38,
		0x4c, 0xb7, 0x5d, 0xde, 0xa8, 0x0e, 0x6f, 0xc4, 0x3b, 0x65, 0x47, 0xf0, 0x44, 0x52, 0x9e, 0x48,
		0xa0, 0x76, 0xb9, 0x78, 0xcd, 0x72, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x1f, 0xc4, 0x42, 0xa5, 0xf1,
		0x3e, 0x55, 0x78, 0x1f, 0x39, 0xef, 0xc3, 0x5f, 0xc3, 0x5b, 0xbc, 0x76, 0xb7, 0x48, 0xcd, 0x6e,
		0x78, 0x2c, 0x78, 0x2c, 0x78, 0x2c, 0x78, 0x2c, 0x78, 0x2c, 0x78, 0xac, 0x5d, 0x91, 0x22, 0x5b,
		0x82, 0xc5, 0xb5, 0xe0, 0x77, 0xe0, 0x77, 0xe0, 0x77, 0xf2, 0xea, 0x77, 0x4e, 0xe0, 0x77, 0xb8,
		0xa9, 0x4d, 0xf8, 0x1d, 0xc1, 0x6f, 0x64, 0x9a, 0xa5, 0x36, 0xfa, 0x27, 0x4c, 0xae, 0x11, 0xcd,
		0x33, 0x5b, 0x93, 0xeb, 0x64, 0xda, 0x3e, 0x73, 0xfb, 0x46, 0x37, 0xc1, 0x31, 0xe2, 0xc8, 0x98,
		0xcd, 0x5c, 0x83, 0x74, 0x1f, 0xa4, 0xfb, 0x2c, 0x08, 0x12, 0x3f, 0x2e, 0x9b, 0x5e, 0xca, 0x87,
		0xcc, 0xaa, 0x40, 0x66, 0x40, 0x66, 0x7c, 0x62, 0x1a, 0x5d, 0x90, 0x30, 0xbd, 0x31, 0x76, 0x99,
		0x13, 0xa5, 0x3b, 0x4a, 0x0a, 0xae, 0xb0, 0x00, 0xcb, 0x08, 0xb2, 0xbc, 0x40, 0xcb, 0x0a, 0x36,
		0x99, 0x80, 0x93, 0x09, 0x3a, 0x89, 0xc0, 0x0b, 0x42, 0x21, 0xde, 0xa6, 0x88, 0x9c, 0x8a, 0x30,
		0xa3, 0x10, 0x02, 0x55, 0x34, 0x57, 0xa8, 0x05, 0x77, 0x21, 0x4d, 0x2a, 0x98, 0x2b, 0xaa, 0x24,
		0x14, 0xca, 0x42, 0xa7, 0x34, 0x54, 0xca, 0x43, 0xae, 0x44, 0xe4, 0xca, 0x44, 0xaa, 0x54, 0x62,
		0xca, 0x25, 0x11, 0xd1, 0xed, 0x4a, 0x9d, 0x8b, 0x5e, 0xc9, 0x0f, 0x08, 0x15, 0xea, 0x5c, 0xd4,
		0x9e, 0x53, 0x89, 0x21, 0xe4, 0x8e, 0x4b, 0x8b, 0x13, 0x0a, 0xa4, 0x04, 0x03, 0xb1, 0x59, 0x89,
		0x67, 0x71, 0x89, 0xc6, 0x23, 0x3c, 0xf8, 0x2b, 0x29, 0xce, 0x64, 0x84, 0x45, 0x5a, 0x4b, 0x50,
		0xab, 0x84, 0xff, 0xe5, 0x78, 0x29, 0x76, 0xb2, 0xb9, 0xba, 0x93, 0xd2, 0x19, 0x70, 0x11, 0x2e,
		0x2c, 0x3c, 0x3e, 0x27, 0x89, 0x34, 0x82, 0x51, 0x80, 0x34, 0x80, 0x34, 0x80, 0x34, 0xb8, 0xe4,
		0xe5, 0xd9, 0xf0, 0x98, 0x1e, 0x31, 0x2e, 0x3a, 0xdf, 0x09, 0xec, 0xd8, 0x80, 0x56, 0x06, 0x76,
		0xdc, 0x45, 0x3c, 0x68, 0x57, 0x37, 0xfb, 0xe7, 0x53, 0x76, 0x71, 0xf1, 0x17, 0xe1, 0xcf, 0x81,
		0xe6, 0xe7, 0xd8, 0xbe, 0x0d, 0x1c, 0xd7, 0xe7, 0x3f, 0xf6, 0x16, 0xbb, 0x60, 0xf3, 0xc3, 0xc1,
		0xe2, 0xc1, 0xe2, 0xc1, 0xe2, 0x71, 0xc9, 0x8b, 0xe7, 0x0f, 0xf4, 0x39, 0x25, 0xe2, 0x3d, 0xc2,
		0x17, 0xa7, 0x4d, 0xc7, 0x88, 0xb5, 0x10, 0x6b, 0x6d, 0x4b, 0xac, 0x55, 0x47, 0x94, 0x95, 0x5d,
		0x94, 0xa5, 0x94, 0x32, 0x16, 0xac, 0x90, 0x15, 0x5d, 0xcf, 0xbd, 0x9b, 0x3d, 0x83, 0xf0, 0xa6,
		0xd8, 0x2e, 0xc9, 0x16, 0xb7, 0xf8, 0xbc, 0xf0, 0xd4, 0xf1, 0x14, 0x8a, 0x4f, 0x65, 0xe2, 0x52,
		0x54, 0xf0, 0xcc, 0x04, 0x75, 0xa1, 0x82, 0x27, 0xcf, 0x7a, 0xf3, 0x97, 0xeb, 0xa2, 0x08, 0x12,
		0x97, 0xcb, 0x77, 0xf1, 0x47, 0x7f, 0x6a, 0xac, 0xc4, 0xb8, 0xc6, 0x9f, 0xb0, 0x99, 0x18, 0x5f,
		0x9e, 0xf2, 0xf6, 0x71, 0x0d, 0x76, 0x02, 0x76, 0x62, 0xed, 0x13, 0x62, 0xfb, 0x18, 0x14, 0x07,
		0x28, 0x8e, 0xc2, 0x51, 0x1c, 0xd8, 0x3e, 0x06, 0xa5, 0x01, 0x4a, 0x83, 0x97, 0xd2, 0xc0, 0xf6,
		0x71, 0xe6, 0xc4, 0xc6, 0x3b, 0x11, 0xa4, 0x11, 0x34, 0xf4, 0xf1, 0x28, 0xd0, 0x46, 0x38, 0x92,
		0x1c, 0xe2, 0xa8, 0x02, 0x71, 0x00, 0x71, 0x14, 0x03, 0x71, 0x88, 0xc2, 0xfb, 0x68, 0x80, 0xe7,
		0x41, 0x6f, 0xa8, 0xbb, 0xac, 0xcb, 0xcc, 0xaf, 0xac, 0x27, 0xbf, 0xd6, 0xd1, 0xa6, 0xf4, 0xdc,
		0xb0, 0xef, 0x72, 0xd1, 0xdc, 0x41, 0x56, 0x3d, 0x29, 0xd5, 0x94, 0x5e, 0x5d, 0xa9, 0xd5, 0x56,
		0x99, 0xfa, 0x2a, 0x53, 0x63, 0x25, 0xea, 0x4c, 0xe4, 0xb8, 0x25, 0x25, 0x4e, 0x3a, 0xb0, 0x88,
		0x73, 0x95, 0x42, 0x5d, 0xf4, 0xe2, 0x14, 0xf4, 0x3d, 0xc1, 0x50, 0x34, 0x31, 0x07, 0x5d, 0xec,
		0xa1, 0x24, 0x06, 0x51, 0x04, 0x84, 0x97, 0x00, 0x31, 0xf5, 0xb8, 0x0a, 0x00, 0x31, 0x61, 0x8c,
		0xa2, 0x24, 0x56, 0x49, 0x6b, 0xa9, 0xe8, 0xbb, 0xfe, 0xa5, 0xba, 0x7a, 0x3b, 0xf9, 0x18, 0xa5,
		0x93, 0x51, 0x78, 0x25, 0xd3, 0xff, 0x2a, 0x80, 0x4a, 0x1e, 0xb3, 0x7d, 0x62, 0xf4, 0x15, 0x0c,
		0x09, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4, 0x05, 0xe4,
		0x55, 0x3e, 0xe4, 0x95, 0x2a, 0xdd, 0x26, 0x99, 0x59, 0x17, 0x8d, 0x43, 0x93, 0x61, 0x37, 0xce,
		0x9f, 0x91, 0x24, 0xbd, 0x77, 0x57, 0xb7, 0x41, 0xbb, 0xf7, 0xfc, 0xc1, 0x53, 0x6b, 0x72, 0xab,
		0xa7, 0x8b, 0xc9, 0x4d, 0x72, 0xbc, 0x8f, 0xd0, 0x63, 0x9e, 0xf9, 0x62, 0x1b, 0x3e, 0xeb, 0x4d,
		0x5a, 0xbc, 0x18, 0xbd, 0x9e, 0xcb, 0x3c, 0x82, 0x8d, 0x85, 0xf8, 0xa1, 0x91, 0xdb, 0x80, 0x9d,
		0x86, 0x8c, 0x00, 0x72, 0x51, 0x73, 0x1b, 0x5e, 0x8d, 0xae, 0xa4, 0xfa, 0xcc, 0xaa, 0x50, 0xf5,
		0xbd, 0xdc, 0x49, 0x35, 0x9f, 0xb9, 0xb6, 0x34, 0xea, 0xd5, 0xfe, 0x7c, 0xac, 0xe8, 0x67, 0x86,
		0xde, 0x6f, 0xe8, 0x1f, 0x3b, 0x3f, 0x6a, 0x6f, 0x7b, 0xe7, 0xf3, 0x3f, 0xef, 0xff, 0x38, 0x7e,
		0xfb, 0x9b, 0xf8, 0x4a, 0x77, 0x64, 0x5e, 0xf1, 0xf6, 0xa1, 0xf5, 0x9f, 0xa2, 0xbc, 0x67, 0xa1,
		0xbc, 0x0b, 0xdd, 0x89, 0xc0, 0x35, 0x63, 0xc3, 0xbf, 0xc0, 0xbf, 0xc0, 0xbf, 0x70, 0xc9, 0x0b,
		0x41, 0x8f, 0xbf, 0x38, 0x7d, 0x42, 0x36, 0x9d, 0xda, 0xe0, 0x1c, 0xd9, 0x74, 0xf9, 0x59, 0x02,
		0x99, 0x9e, 0x84, 0xa9, 0xac, 0x03, 0x52, 0xe9, 0xd6, 0x81, 0x14, 0x9a, 0xfc, 0xfd, 0xc5, 0x01,
		0x01, 0x47, 0x00, 0x47, 0x00, 0x47, 0xb8, 0xe4, 0x05, 0xa9, 0xfc, 0x45, 0x03, 0x1f, 0x15, 0x80,
		0x8f, 0xac, 0x97, 0xa0, 0x5e, 0x3b, 0xab, 0x9f, 0x9d, 0x9c, 0xd6, 0xce, 0x8e, 0x01, 0x40, 0x0a,
		0x0a, 0x40, 0x82, 0x0a, 0x2d, 0xf6, 0xf0, 0x95, 0x14, 0x84, 0x44, 0x83, 0x02, 0x88, 0x00, 0x88,
		0x00, 0x88, 0x70, 0x03, 0x91, 0xea, 0x09, 0x01, 0x10, 0x39, 0x01, 0x10, 0x01, 0x10, 0xd9, 0x16,
		0x16, 0xe4, 0xf8, 0xf8, 0x08, 0x18, 0xa4, 0xd0, 0x18, 0x44, 0xc9, 0x3e, 0x0d, 0x8a, 0x38, 0x02,
		0x8d, 0x00, 0x8d, 0x48, 0xc8, 0x0b, 0x8a, 0x38, 0x16, 0x1d, 0x9d, 0x60, 0x8f, 0x26, 0xf3, 0x25,
		0x40, 0x11, 0xc7, 0xe2, 0x62, 0x13, 0xd7, 0x71, 0x7c, 0x25, 0x19, 0x8a, 0x73, 0x03, 0x03, 0x99,
		0x00, 0x99, 0x00, 0x99, 0x70, 0xc9, 0x0b, 0xf2, 0x13, 0xb9, 0x2d, 0x2e, 0xf2, 0x13, 0x73, 0xe7,
		0x59, 0x94, 0x44, 0xbd, 0xf3, 0x23, 0xc3, 0xb7, 0xc0, 0xb7, 0xc0, 0xb7, 0x70, 0x47, 0xbd, 0xc8,
		0x4d, 0x44, 0xdc, 0x8b, 0xb8, 0x57, 0x6a, 0x09, 0x90, 0x9b, 0x58, 0x3c, 0x80, 0xd2, 0x77, 0xdc,
		0xff, 0x19, 0x6e, 0x4f, 0xf7, 0x5d, 0xc3, 0xf6, 0x4c, 0xcf, 0x1c, 0x4d, 0x39, 0x41, 0xe0, 0xbb,
		0x7a, 0x58, 0x40, 0x13, 0x40, 0x13, 0x40, 0x13, 0x2e, 0x79, 0xa1, 0xa8, 0x4b, 0x41, 0x50, 0x8f,
		0x02, 0x58, 0x84, 0xc7, 0x11, 0x22, 0x43, 0x20, 0x7b, 0x38, 0xa8, 0xac, 0x7e, 0x04, 0x90, 0x09,
		0xfa, 0xd7, 0x02, 0x77, 0x00, 0x77, 0x94, 0x1b, 0x77, 0xa0, 0x7f, 0xad, 0x6a, 0xfb, 0x46, 0x97,
		0x89, 0x8d, 0xf4, 0x6b, 0xd8, 0x39, 0xd8, 0x39, 0x31, 0x79, 0x41, 0xfa, 0x35, 0x82, 0x2b, 0x04,
		0x57, 0x9c, 0x4b, 0x80, 0xf4, 0xeb, 0xc2, 0x45, 0x53, 0xe8, 0x96, 0x0f, 0xdc, 0x01, 0xdc, 0x91,
		0x1f, 0xdc, 0x81, 0x44, 0xeb, 0xa2, 0xe3, 0x10, 0x6c, 0x38, 0x67, 0xbe, 0x04, 0x48, 0xb4, 0x2e,
		0x22, 0x0a, 0x11, 0x6b, 0xe9, 0xbc, 0x1a, 0x82, 0x88, 0xf4, 0x77, 0x06, 0xfe, 0x00, 0xfe, 0xd8,
		0x7a, 0xfc, 0x61, 0xf6, 0x98, 0xed, 0x9b, 0xfe, 0x77, 0x22, 0x62, 0x57, 0x06, 0x75, 0xb4, 0xc2,
		0x47, 0xf9, 0x60, 0x78, 0x8c, 0xae, 0xdb, 0xca, 0x43, 0xfb, 0xee, 0xe9, 0xee, 0xf6, 0xbe, 0xfd,
		0xf4, 0xd0, 0x6e, 0xb4, 0x9b, 0xb2, 0x32, 0x18, 0x78, 0x1c, 0x8f, 0xa4, 0x0f, 0x03, 0x91, 0x4b,
		0x9d, 0xbc, 0xe7, 0x55, 0xeb, 0xa1, 0xdd, 0xbc, 0x69, 0xdd, 0x7c, 0xd2, 0xf2, 0x00, 0x1b, 0xa8,
		0x5f, 0xae, 0xd9, 0xb8, 0x2f, 0xeb, 0xbb, 0x7d, 0xbc, 0xbd, 0xff, 0xbd, 0x71, 0x7f, 0x59, 0xd2,
		0xb7, 0xfb, 0x70, 0x75, 0x7b, 0xf1, 0x6b, 0x49, 0xdf, 0xed, 0xb2, 0xf5, 0xd0, 0xf8, 0x70, 0xd5,
		0xbc, 0xcc, 0xba, 0x8b, 0x4e, 0x27, 0x6d, 0xaf, 0x95, 0x0a, 0x46, 0x74, 0x1d, 0x8b, 0x00, 0x1d,
		0x06, 0xa3, 0x00, 0x17, 0x02, 0x17, 0x02, 0x17, 0x02, 0x17, 0xae, 0xc4, 0x85, 0xf7, 0xb7, 0x57,
		0x25, 0x86, 0x85, 0xf7, 0xb7, 0xb7, 0xed, 0x52, 0xe2, 0x8a, 0xc6, 0xc5, 0xaf, 0xff, 0xbe, 0x2b,
		0x25, 0xaa, 0x68, 0x3e, 0xb4, 0x3e, 0xdd, 0x34, 0xda, 0x24, 0xb8, 0x22, 0x77, 0x6f, 0xd7, 0xb8,
		0x6a, 0x37, 0xef, 0x47, 0x6f, 0x07, 0xd0, 0x44, 0x7b, 0x05, 0xe7, 0x52, 0xcb, 0x36, 0xcb, 0xa2,
		0x6c, 0x92, 0xc5, 0x27, 0x0a, 0xc9, 0xa7, 0x25, 0xd9, 0x37, 0x13, 0x4e, 0xdc, 0x08, 0xb7, 0x70,
		0x26, 0x92, 0x6a, 0x57, 0xa6, 0xe7, 0x37, 0x7c, 0xdf, 0xe5, 0x9a, 0x61, 0xed, 0xda, 0xb4, 0x9b,
		0x16, 0x1b, 0x01, 0x10, 0x8f, 0x0f, 0x3c, 0x6a, 0xd7, 0xc6, 0xb7, 0x99, 0x2b, 0xe5, 0x52, 0x9f,
		0xb5, 0x5b, 0xb7, 0xc7, 0x5c, 0xd6, 0xfb, 0x30, 0x7a, 0x6b, 0x7b, 0x68, 0x59, 0xa4, 0x93, 0x29,
		0x28, 0x7d, 0x34, 0x52, 0xc7, 0xe1, 0xed, 0x37, 0xf6, 0x5e, 0x4b, 0x26, 0xbb, 0x9b, 0x25, 0x71,
		0xfd, 0x37, 0x36, 0x4c, 0x2b, 0xef, 0x74, 0xca, 0x4c, 0xe3, 0xfa, 0x17, 0x8e, 0x7f, 0x8d, 0x35,
		0xaf, 0xa0, 0x25, 0xdb, 0x09, 0x98, 0xd9, 0x33, 0xdd, 0x4c, 0xf6, 0x47, 0xc8, 0x73, 0xc3, 0xd7,
		0xa2, 0x20, 0xad, 0xb6, 0xe1, 0x8b, 0x1c, 0xc1, 0x18, 0x7f, 0xd0, 0xc5, 0x1b, 0x5c, 0x09, 0x07,
		0x51, 0xc2, 0xc1, 0x92, 0x50, 0x50, 0x24, 0x27, 0xd4, 0x97, 0x66, 0x32, 0xc3, 0xa9, 0x09, 0xf6,
		0x13, 0x9c, 0xe6, 0x38, 0x8b, 0x34, 0x0d, 0xe4, 0x64, 0x07, 0xb8, 0xd9, 0x00, 0x91, 0xe8, 0x5f,
		0x3c, 0xda, 0x17, 0x8d, 0xee, 0xa5, 0xa3, 0x79, 0xe9, 0xe8, 0x5d, 0x2a, 0x5a, 0xa7, 0x45, 0x08,
		0xdc, 0xd1, 0xb7, 0x64, 0x51, 0x1b, 0x91, 0x22, 0x36, 0xc2, 0x45, 0x6b, 0x88, 0x8b, 0xb7, 0x74,
		0x78, 0x1e, 0x59, 0xa6, 0x08, 0x0d, 0xf5, 0x73, 0x53, 0xf9, 0xfb, 0x77, 0x89, 0xed, 0x1a, 0x77,
		0xb6, 0xde, 0xa2, 0x61, 0xe3, 0xcc, 0xcf, 0x83, 0x65, 0x83, 0x65, 0x23, 0xb3, 0x6c, 0x04, 0x25,
		0x55, 0x04, 0x4a, 0xa8, 0x08, 0x66, 0xb0, 0x09, 0x84, 0xc1, 0x32, 0x19, 0x6a, 0xb2, 0x1b, 0x0c,
		0x92, 0x19, 0x68, 0xff, 0x8f, 0xbd, 0x77, 0xfd, 0x6a, 0x1b, 0xc9, 0xf6, 0xfe, 0xdf, 0xe7, 0xaf,
		0x60, 0x79, 0xcd, 0x8b, 0x30, 0x27, 0x4a, 0xb0, 0xb1, 0x4d, 0xc8, 0x9b, 0x5e, 0x74, 0x42, 0x67,
		0xf8, 0x0d, 0x09, 0x79, 0x80, 0x9e, 0x73, 0x7a, 0x82, 0xc7, 0x4b, 0xb1, 0x05, 0xd1, 0xd3, 0x46,
		0xf6, 0x23, 0xc9, 0x39, 0xa1, 0x13, 0xfe, 0xf7, 0xdf, 0xf2, 0x15, 0x83, 0x6f, 0xaa, 0xaa, 0x5d,
		0xb2, 0x24, 0x7f, 0xb2, 0xd6, 0x4c, 0x68, 0xe2, 0xda, 0x96, 0xaa, 0xf6, 0xe5, 0xbb, 0x77, 0xed,
		0x8b, 0x44, 0xb2, 0x93, 0xce, 0xc5, 0x8e, 0x49, 0x46, 0x99, 0xd4, 0x96, 0x99, 0xb4, 0x28, 0x11,
		0xd9, 0x37, 0x4b, 0x21, 0x8f, 0x34, 0xcd, 0x93, 0x69, 0xb7, 0x4c, 0xa1, 0xee, 0x98, 0x98, 0x2b,
		0xcc, 0x15, 0x40, 0x1c, 0x20, 0x9e, 0xa2, 0xa6, 0xd3, 0x47, 0xe4, 0x86, 0xdd, 0x1a, 0xd1, 0x75,
		0xe8, 0x3a, 0xa0, 0x39, 0xd0, 0x1c, 0x68, 0x0e, 0x34, 0x5f, 0xb5, 0x0d, 0xe3, 0xb6, 0x7b, 0x7e,
		0x70, 0xe3, 0xb4, 0xbd, 0x8e, 0xab, 0x61, 0xa8, 0xe6, 0x28, 0x60, 0xa0, 0x30, 0x50, 0x29, 0x1b,
		0xa8, 0xbe, 0x1f, 0xc4, 0xaf, 0x35, 0xac, 0x51, 0x0d, 0x6b, 0xb4, 0x58, 0xb5, 0x56, 0xb1, 0x46,
		0xaa, 0x5b, 0xb6, 0x8f, 0x25, 0x32, 0xb2, 0x44, 0x5f, 0xbd, 0x4e, 0xa7, 0xeb, 0xc4, 0xbe, 0x42,
		0x0f, 0xb7, 0xa9, 0xfc, 0xcf, 0xac, 0xc5, 0xfa, 0x60, 0x7d, 0xb0, 0x3e, 0xf8, 0x42, 0x5b, 0x66,
		0x7d, 0xca, 0x58, 0x1f, 0x33, 0xeb, 0xd3, 0xed, 0xb4, 0x9d, 0x61, 0xeb, 0x64, 0x0d, 0xeb, 0xf3,
		0xb0, 0x36, 0xa1, 0xae, 0x79, 0xe7, 0x5d, 0xbb, 0xfd, 0xce, 0x50, 0xe9, 0xd5, 0xb1, 0x58, 0x58,
		0x2c, 0x2c, 0x16, 0x16, 0x0b, 0x8b, 0x85, 0xc5, 0x52, 0xb6, 0x58, 0x9a, 0xee, 0xd2, 0x74, 0x29,
		0xb6, 0x07, 0xdb, 0x83, 0xed, 0xc9, 0xb7, 0xed, 0xd9, 0xc3, 0xf6, 0xa8, 0x6e, 0x59, 0xa5, 0x56,
		0xc3, 0xf8, 0x98, 0x18, 0x9f, 0x8e, 0x1b, 0xc5, 0x4e, 0xdc, 0xed, 0x75, 0x3b, 0xdd, 0x9b, 0x3b,
		0xa7, 0xf5, 0x75, 0x2c, 0x6f, 0x8a, 0x76, 0x68, 0x21, 0x15, 0x4c, 0x12, 0x26, 0x29, 0x65, 0x93,
		0x34, 0x80, 0x42, 0xb1, 0xdf, 0xfa, 0x33, 0x52, 0x1a, 0x9a, 0xa4, 0x31, 0x24, 0xa9, 0xf4, 0x7b,
		0x30, 0xd2, 0x1a, 0xa5, 0xc0, 0x0d, 0xba, 0x91, 0xd7, 0xea, 0x06, 0x6d, 0xa5, 0xf4, 0x31, 0x0c,
		0x1b, 0x86, 0x6d, 0xa5, 0x53, 0x25, 0x36, 0xc4, 0x08, 0x4b, 0x37, 0xda, 0x86, 0x5b, 0xf7, 0xbb,
		0xe3, 0xea, 0x18, 0xb7, 0xc9, 0x42, 0xec, 0x19, 0xf6, 0x0c, 0x17, 0x2b, 0xdf, 0x96, 0xa8, 0x8e,
		0x25, 0x52, 0xdd, 0x32, 0x12, 0xf3, 0xcc, 0xec, 0xce, 0x30, 0xe9, 0xbb, 0xd5, 0x8d, 0x34, 0xee,
		0xa3, 0x1e, 0x96, 0x62, 0x7b, 0xb0, 0x3d, 0x1b, 0xb0, 0x3d, 0xfb, 0x15, 0x32, 0xc3, 0x71, 0x83,
		0x36, 0x69, 0x7c, 0x2a, 0x87, 0xd5, 0xc3, 0xfa, 0x41, 0xe5, 0x10, 0xe7, 0xc7, 0xdc, 0x08, 0xf5,
		0xba, 0xa1, 0xae, 0x11, 0x1a, 0x2e, 0xc5, 0x08, 0x61, 0x84, 0x36, 0x60, 0x84, 0x94, 0x66, 0xf4,
		0x69, 0xcc, 0xe4, 0xc3, 0x08, 0x61, 0x84, 0x56, 0x3b, 0x8d, 0xfa, 0x33, 0xef, 0xb0, 0x3f, 0xa3,
		0x6d, 0x78, 0x72, 0x37, 0xa4, 0xd1, 0x31, 0x60, 0x8e, 0x02, 0xd6, 0x08, 0x6b, 0x94, 0xb2, 0x35,
		0x1a, 0xa6, 0x86, 0x7a, 0xa1, 0xf5, 0xcb, 0x25, 0x0c, 0x12, 0x06, 0x69, 0xd5, 0x96, 0x71, 0x39,
		0xa4, 0x64, 0x9f, 0xb2, 0xdd, 0x67, 0x35, 0x41, 0x3f, 0xe4, 0x15, 0x2d, 0x56, 0x9f, 0x29, 0xbc,
		0x53, 0xd2, 0x77, 0x51, 0x7e, 0x87, 0xd2, 0xca, 0x46, 0xaf, 0x8b, 0xba, 0xe9, 0x2e, 0x7e, 0xdf,
		0xf9, 0xb7, 0x79, 0xfc, 0x9b, 0x27, 0xef, 0xb5, 0xee, 0x7d, 0x54, 0xde, 0x63, 0xc1, 0x2b, 0xcc,
		0x3f, 0xfa, 0xe3, 0xa7, 0x7e, 0x78, 0xb6, 0x99, 0xe7, 0x2a, 0x45, 0x77, 0x51, 0xec, 0xcd, 0x4f,
		0xf6, 0x7f, 0x68, 0xc1, 0x30, 0xfa, 0xf7, 0x27, 0x6f, 0xb2, 0xb8, 0x75, 0xed, 0x52, 0x34, 0xb2,
		0x0a, 0x75, 0x3c, 0x42, 0x17, 0x77, 0x8b, 0x70, 0xd2, 0x3a, 0x14, 0x91, 0x18, 0x2d, 0x24, 0x46,
		0x05, 0x73, 0xd6, 0xff, 0x6e, 0x41, 0x53, 0xe1, 0xd5, 0x67, 0xbd, 0xac, 0x35, 0x6c, 0xc9, 0x75,
		0xdd, 0xe5, 0x6f, 0x32, 0xd9, 0x8b, 0xc1, 0x87, 0x96, 0x3c, 0xda, 0xea, 0xae, 0xc1, 0x6b, 0x01,
		0x61, 0x12, 0x00, 0x38, 0x7b, 0x24, 0xcb, 0x9f, 0x44, 0x05, 0xe0, 0x29, 0x03, 0x3a, 0x65, 0x00,
		0xf7, 0xf4, 0xc8, 0x06, 0xcf, 0x2d, 0xa4, 0x86, 0xd6, 0x75, 0xf9, 0x2d, 0xb9, 0xad, 0x21, 0xd2,
		0xf2, 0x83, 0x9b, 0xe4, 0x1d, 0xa2, 0x67, 0xd6, 0x08, 0xb7, 0x89, 0xde, 0xb3, 0xd3, 0x26, 0x7a,
		0x35, 0x23, 0xe8, 0x22, 0xfe, 0xcd, 0xb7, 0x89, 0x5e, 0xc9, 0x28, 0x32, 0x36, 0x39, 0x71, 0x9b,
		0xe8, 0xd6, 0xe4, 0x0c, 0x15, 0x9d, 0xcd, 0xf1, 0x3a, 0x35, 0x17, 0xb3, 0x9c, 0x51, 0x17, 0x33,
		0x19, 0xa3, 0x15, 0xcf, 0xc5, 0x4c, 0xc4, 0x88, 0x76, 0x5c, 0xcc, 0xa4, 0x0c, 0xba, 0x40, 0xe3,
		0x39, 0xb7, 0x5e, 0xfc, 0xb5, 0xdb, 0x56, 0xdf, 0xff, 0x79, 0x45, 0x38, 0x21, 0xa5, 0xb8, 0x8d,
		0x7a, 0x4e, 0x8a, 0xf6, 0xec, 0x33, 0x93, 0x99, 0x67, 0xfa, 0x6c, 0x6e, 0xca, 0xee, 0x62, 0x6c,
		0x2f, 0xc6, 0xfe, 0x22, 0x62, 0xa0, 0xe9, 0xd3, 0x29, 0x9e, 0xb8, 0xf6, 0xcc, 0xb2, 0x87, 0x7b,
		0x81, 0x60, 0x00, 0xfa, 0x35, 0x8e, 0x7b, 0xa2, 0xab, 0x0f, 0x35, 0xd6, 0x8e, 0x1f, 0x5b, 0x6f,
		0xe0, 0x17, 0x03, 0xda, 0xd6, 0xbf, 0xe0, 0xd1, 0xd1, 0x51, 0xf3, 0xc3, 0xf1, 0xe5, 0x3f, 0xce,
		0xde, 0x35, 0x2f, 0xff, 0xf8, 0x54, 0xe4, 0xc9, 0xbd, 0x67, 0x6f, 0x8f, 0x4e, 0x8b, 0x38, 0xeb,
		0xeb, 0xf2, 0xe8, 0xed, 0xd1, 0xdb, 0x8b, 0xe6, 0xd1, 0x69, 0x21, 0xdf, 0xee, 0xfc, 0xe8, 0xdd,
		0xc9, 0xef, 0x52, 0x6f, 0x97, 0xaf, 0x51, 0x66, 0x2f, 0x36, 0xa5, 0xf4, 0xa2, 0x38, 0x5c, 0xef,
		0xd3, 0x25, 0xd2, 0x77, 0xaf, 0x53, 0x1a, 0xe2, 0xd6, 0xb0, 0x6a, 0x3b, 0xb5, 0x06, 0x8c, 0x3d,
		0x44, 0xaf, 0x75, 0x07, 0x8d, 0xcd, 0xc6, 0xbf, 0xc5, 0x06, 0x8e, 0x4d, 0x89, 0xce, 0x0e, 0x1e,
		0x33, 0x9c, 0xfe, 0xdb, 0x8f, 0xbc, 0x50, 0x17, 0x82, 0x09, 0xcc, 0xbb, 0x9d, 0xc5, 0x83, 0xdd,
		0xd1, 0x5b, 0x39, 0x5f, 0xee, 0x4c, 0xd8, 0x57, 0x72, 0xd6, 0xed, 0x23, 0x6c, 0x38, 0xdc, 0xa9,
		0x6c, 0x0e, 0x36, 0xdc, 0x90, 0xdb, 0x66, 0x61, 0x44, 0xdd, 0x30, 0xda, 0xfb, 0x6a, 0xfc, 0x97,
		0xeb, 0xba, 0xaf, 0x1e, 0xdc, 0xb3, 0x57, 0xe3, 0x28, 0x43, 0x8a, 0xd7, 0xf0, 0xde, 0xb7, 0xb1,
		0xdc, 0x2a, 0xc6, 0x43, 0xc6, 0xeb, 0x88, 0x87, 0x10, 0x0f, 0x49, 0x27, 0x1e, 0x32, 0x64, 0x38,
		0xfd, 0x18, 0xc8, 0x68, 0xb9, 0x5e, 0xdc, 0xa3, 0x4c, 0xdc, 0x83, 0xb8, 0x87, 0x1d, 0xec, 0xa6,
		0x2a, 0x06, 0xd3, 0x85, 0x8a, 0x71, 0xec, 0xa5, 0xec, 0xa2, 0x14, 0xd7, 0x16, 0x12, 0x10, 0x63,
		0x41, 0x91, 0x10, 0x18, 0x39, 0xc1, 0x91, 0x04, 0x8b, 0xa2, 0x82, 0x64, 0x05, 0x30, 0x8a, 0x09,
		0xd6, 0x46, 0xdc, 0x4f, 0x6d, 0x81, 0x7b, 0x6c, 0x87, 0x46, 0x23, 0x12, 0xc4, 0xa2, 0x5c, 0x33,
		0x34, 0x0d, 0x0f, 0xc6, 0x2c, 0x9d, 0x48, 0x4c, 0x30, 0x25, 0x05, 0x54, 0x5e, 0x50, 0xa5, 0x05,
		0xd6, 0x9a, 0xe0, 0x5a, 0x13, 0x60, 0x2b, 0x82, 0x2c, 0x13, 0xc7, 0x32, 0x8c, 0xf1, 0xe9, 0xdf,
		0x24, 0x2c, 0xe5, 0x37, 0x99, 0x20, 0xfb, 0x9c, 0xcd, 0xac, 0x09, 0xd0, 0x12, 0x0d, 0xba, 0xcf,
		0xbd, 0xf8, 0xd1, 0xd1, 0x51, 0xf3, 0xe8, 0xed, 0xdb, 0xb3, 0xdf, 0x3f, 0x5e, 0x9e, 0x7c, 0x7c,
		0xdf, 0x3c, 0xfe, 0xd7, 0xf1, 0xc7, 0x4b, 0x89, 0x30, 0xfc, 0xf4, 0x8b, 0x04, 0xc3, 0xf1, 0xe6,
		0xf1, 0x45, 0xf5, 0xad, 0x38, 0x3d, 0x7b, 0x7f, 0xf2, 0xb1, 0x24, 0xf6, 0x85, 0xf7, 0x2f, 0x72,
		0xb9, 0x0b, 0x6f, 0xcf, 0x3e, 0x7c, 0x38, 0xfa, 0xf8, 0x4e, 0x70, 0x1f, 0x44, 0x28, 0x35, 0x36,
		0xad, 0xc7, 0x9e, 0x6d, 0x80, 0x0f, 0x4a, 0xa1, 0xd7, 0x1a, 0x19, 0x20, 0x21, 0x64, 0x32, 0xa6,
		0x07, 0x2a, 0x01, 0x95, 0x80, 0x4a, 0x32, 0x85, 0x4a, 0xbc, 0xa0, 0x7f, 0xeb, 0x85, 0xa3, 0xd0,
		0xb4, 0x20, 0x2a, 0xa9, 0x0a, 0xd0, 0x3a, 0x0e, 0xfa, 0xc3, 0x74, 0xe7, 0x8d, 0x29, 0xd0, 0x54,
		0x3d, 0x4a, 0xcd, 0x2b, 0x82, 0x39, 0x3a, 0x9a, 0x57, 0x06, 0xa3, 0x40, 0xfc, 0xe8, 0x2f, 0xa5,
		0xfb, 0x03, 0xf3, 0x5d, 0xd3, 0x29, 0x96, 0x11, 0x70, 0x9f, 0xe5, 0xdc, 0x66, 0xd3, 0xea, 0x1b,
		0xe2, 0x57, 0xc4, 0xaf, 0x52, 0xd6, 0x36, 0xc6, 0x86, 0xe4, 0xa1, 0x43, 0xab, 0xe7, 0x5e, 0x0b,
		0xe5, 0x8d, 0x1d, 0x18, 0xd0, 0xf8, 0x34, 0x56, 0x78, 0x2f, 0x5f, 0x8e, 0xea, 0x9e, 0x5e, 0xcd,
		0x48, 0x75, 0x86, 0xf5, 0xd8, 0xa8, 0x46, 0xcb, 0x58, 0x85, 0x8d, 0xc8, 0x6c, 0x38, 0xfa, 0x5e,
		0x41, 0x7b, 0xa1, 0xbd, 0x52, 0xd1, 0x5e, 0x44, 0xdf, 0xf1, 0x73, 0xf1, 0x73, 0xf1, 0x73, 0x15,
		0xf8, 0x8d, 0xe8, 0x3b, 0xd1, 0x77, 0xa2, 0xef, 0x44, 0xdf, 0x53, 0x0b, 0x1e, 0x11, 0x7d, 0x07,
		0x95, 0x80, 0x4a, 0x40, 0x25, 0xab, 0x7d, 0x06, 0xa2, 0xef, 0xd9, 0xf0, 0x28, 0xb3, 0x14, 0x7d,
		0x4f, 0xd0, 0xb7, 0x47, 0x30, 0x68, 0x65, 0x35, 0x2f, 0xf5, 0x9f, 0xde, 0x9d, 0x91, 0x6b, 0x5c,
		0xfc, 0xa2, 0xa4, 0xa0, 0xdf, 0xe9, 0x58, 0x3d, 0x02, 0x43, 0xce, 0x96, 0xe0, 0xe8, 0x92, 0x56,
		0x60, 0xf4, 0x51, 0x8b, 0xa4, 0xe1, 0x77, 0x34, 0x8f, 0x5c, 0xb7, 0x79, 0x34, 0xfd, 0x8e, 0xe6,
		0xf1, 0x90, 0x38, 0x05, 0x40, 0xcb, 0x76, 0x3f, 0xcd, 0x02, 0x20, 0xb5, 0x40, 0xb6, 0x56, 0xe0,
		0x5a, 0xbb, 0xfc, 0xa7, 0x42, 0xf9, 0x8f, 0x24, 0xe2, 0xa3, 0x1d, 0x0a, 0xed, 0x50, 0x28, 0x0b,
		0xa2, 0x1d, 0x4a, 0x22, 0x5d, 0x4d, 0x3b, 0x14, 0xda, 0xa1, 0xa4, 0x1e, 0xf3, 0xa4, 0x1d, 0x4a,
		0xbe, 0xdf, 0x8e, 0x76, 0x28, 0xe9, 0x2b, 0x3d, 0xda, 0xa1, 0x6c, 0x59, 0xe4, 0x81, 0x76, 0x28,
		0x76, 0x70, 0xe1, 0x0e, 0xed, 0x50, 0x32, 0x16, 0x0d, 0x51, 0x08, 0xa8, 0xe6, 0xa8, 0xe9, 0xfb,
		0x8a, 0x37, 0x2e, 0x25, 0x0a, 0xd8, 0xac, 0x0d, 0xb0, 0x69, 0xf7, 0x8e, 0x5f, 0xd1, 0x86, 0xda,
		0xed, 0xc7, 0x5f, 0x07, 0x90, 0xb6, 0x95, 0x6c, 0x13, 0x1e, 0xbc, 0xed, 0xc7, 0xeb, 0xe8, 0xc4,
		0x4c, 0x27, 0xe6, 0x31, 0x43, 0xb5, 0x6f, 0xfd, 0xc0, 0x19, 0xea, 0x58, 0xe5, 0xe8, 0xe3, 0xcc,
		0x5a, 0x3a, 0x10, 0x11, 0x82, 0x4c, 0x27, 0x04, 0xa9, 0xd9, 0x72, 0xc5, 0xac, 0xd5, 0x0a, 0x3d,
		0x88, 0x08, 0x36, 0x66, 0xb5, 0x07, 0xd1, 0x48, 0x0b, 0xf7, 0xdc, 0x28, 0xfa, 0x5f, 0x93, 0xb4,
		0xa7, 0x27, 0x5a, 0x7d, 0x4a, 0x8f, 0x9a, 0x2e, 0xaa, 0x22, 0x52, 0x16, 0xb4, 0x8d, 0xc4, 0x80,
		0x04, 0x6b, 0xba, 0x36, 0x1e, 0x0b, 0xd2, 0xdc, 0x81, 0xe3, 0xef, 0xb1, 0x59, 0x18, 0x5a, 0x8e,
		0xbb, 0xbb, 0x2d, 0xc7, 0xfb, 0x1e, 0xbf, 0x99, 0x71, 0xd8, 0xbe, 0xba, 0xd1, 0x57, 0xaf, 0xed,
		0x7c, 0x1b, 0x8e, 0x5a, 0x13, 0xe5, 0xfa, 0x6b, 0xb7, 0x13, 0x49, 0xb2, 0x7d, 0xda, 0x0c, 0xdf,
		0x48, 0xa5, 0xd4, 0xee, 0xb1, 0x59, 0x18, 0x1f, 0x87, 0xb4, 0xb5, 0x99, 0x90, 0xc5, 0xe8, 0x60,
		0x74, 0x30, 0x3a, 0x6a, 0x7e, 0x4d, 0x78, 0xd7, 0x8b, 0x1f, 0x04, 0xc9, 0xb0, 0x90, 0x2e, 0xf5,
		0xdb, 0x88, 0xfb, 0xe2, 0x64, 0xf1, 0x3d, 0x0a, 0xb5, 0xbd, 0x7a, 0x08, 0x92, 0x68, 0xf5, 0x85,
		0x50, 0x88, 0x31, 0x2b, 0x44, 0x2e, 0xf4, 0xea, 0xa6, 0x8d, 0xea, 0xa5, 0x8d, 0x5d, 0xe8, 0x0a,
		0x2e, 0x34, 0x2e, 0x34, 0x2e, 0x34, 0x68, 0x06, 0x34, 0x83, 0x0b, 0x8d, 0x0b, 0x8d, 0x0b, 0x8d,
		0x0b, 0x8d, 0x0b, 0x8d, 0xd1, 0xc1, 0xe8, 0xe0, 0x42, 0x9b, 0xaa, 0xa4, 0x81, 0x77, 0x3a, 0x4e,
		0x65, 0x11, 0xd1, 0x45, 0x53, 0x7a, 0x28, 0x21, 0x94, 0x10, 0x4a, 0x28, 0x5f, 0xc8, 0x97, 0xd0,
		0xdd, 0x82, 0xd0, 0x9d, 0x46, 0x51, 0x79, 0xa1, 0xb3, 0x43, 0x97, 0x6d, 0x54, 0x49, 0x29, 0x08,
		0xb9, 0x2c, 0x85, 0xf2, 0x11, 0xf5, 0xe6, 0xd1, 0x80, 0xfa, 0xef, 0x89, 0xb3, 0x80, 0x65, 0x0a,
		0x72, 0x15, 0xd3, 0x8c, 0xf4, 0xd2, 0x8b, 0xc8, 0x87, 0xdb, 0x21, 0x1f, 0xce, 0x2c, 0x86, 0xf9,
		0x24, 0xb3, 0xd7, 0xbc, 0x2c, 0x77, 0x21, 0x39, 0x4a, 0x73, 0xed, 0xe1, 0x33, 0x42, 0xfd, 0x94,
		0xe6, 0x5a, 0x0e, 0x0d, 0x52, 0x9a, 0xab, 0x49, 0x96, 0xd2, 0xdc, 0xd4, 0x5f, 0x8c, 0xd2, 0x5c,
		0xbb, 0x1e, 0xee, 0xe4, 0x0f, 0xa5, 0xb9, 0xd9, 0xf5, 0xa8, 0x29, 0xcd, 0x55, 0x26, 0x4a, 0x69,
		0x6e, 0x3a, 0x71, 0x3a, 0x4a, 0x73, 0xb3, 0x16, 0x7c, 0x51, 0xc9, 0x2a, 0xa3, 0x59, 0x19, 0x91,
		0x11, 0x22, 0x23, 0x44, 0x46, 0x88, 0x8c, 0x10, 0x19, 0x21, 0x32, 0x42, 0x64, 0x84, 0xc8, 0x08,
		0x91, 0x11, 0x22, 0x23, 0x44, 0x46, 0x88, 0x8c, 0x10, 0x19, 0x21, 0x32, 0x42, 0x64, 0xa4, 0x58,
		0x91, 0x11, 0xd9, 0xc6, 0x65, 0x09, 0x02, 0x23, 0x83, 0x53, 0x8f, 0xd4, 0x03, 0x23, 0xa3, 0x65,
		0xa4, 0x8c, 0x10, 0x18, 0x49, 0x27, 0x30, 0xa2, 0xd4, 0xed, 0x4b, 0xc2, 0x08, 0xd0, 0x3e, 0x89,
		0xb0, 0x47, 0x56, 0x6b, 0x3f, 0x35, 0xfb, 0x89, 0xcd, 0xb1, 0x8b, 0x56, 0x5f, 0x31, 0x43, 0x01,
		0x31, 0x16, 0x14, 0x09, 0x81, 0x91, 0x13, 0x1c, 0x49, 0xac, 0xb8, 0x43, 0xc6, 0xbb, 0x55, 0xef,
		0xd3, 0x7c, 0x88, 0xb4, 0x71, 0xb9, 0xf5, 0x1c, 0xe3, 0x19, 0x16, 0x5c, 0x3f, 0x15, 0x46, 0x46,
		0x35, 0xa6, 0x29, 0xac, 0xd6, 0x84, 0xd6, 0x9a, 0xf0, 0x5a, 0x11, 0x62, 0x99, 0x10, 0x56, 0xf6,
		0x46, 0x35, 0x1a, 0x87, 0x9a, 0x84, 0x42, 0x4e, 0x52, 0x3b, 0x64, 0x5c, 0xe8, 0x6d, 0x1e, 0xc6,
		0x5b, 0x1a, 0x1a, 0xb1, 0x59, 0xf8, 0xbd, 0x44, 0x9a, 0x04, 0x0a, 0xc0, 0x17, 0x8a, 0x53, 0x8e,
		0x63, 0xc1, 0x2f, 0xcc, 0x4d, 0xa3, 0x69, 0x89, 0xf8, 0x52, 0x0b, 0x69, 0x56, 0x24, 0x8e, 0xa1,
		0xc4, 0x50, 0x62, 0x28, 0x2d, 0x19, 0x4a, 0xd9, 0x22, 0x74, 0x69, 0xab, 0xb9, 0x99, 0x81, 0xee,
		0xdd, 0x8e, 0xe0, 0x45, 0xf8, 0x90, 0x1a, 0x8a, 0x0f, 0xc5, 0x87, 0xe2, 0xcb, 0x94, 0xe2, 0xd3,
		0x4d, 0x3b, 0x5a, 0xaa, 0xea, 0x0e, 0x05, 0x68, 0x19, 0xa5, 0x25, 0xd9, 0x81, 0xfa, 0x76, 0xdc,
		0x2a, 0x61, 0x43, 0x21, 0xc4, 0x66, 0x16, 0x77, 0x4e, 0x26, 0xe1, 0x6b, 0xe9, 0xf6, 0xd5, 0x04,
		0x69, 0x8a, 0x26, 0x84, 0x2d, 0xdd, 0x90, 0x8b, 0x3f, 0x2e, 0x2e, 0x8f, 0x3f, 0x34, 0xdf, 0x1d,
		0xff, 0x76, 0xf2, 0xf1, 0xf8, 0x5d, 0xf3, 0xfc, 0xec, 0xf4, 0xf8, 0x42, 0x70, 0x67, 0x76, 0x84,
		0xb3, 0xc6, 0xec, 0xb1, 0xc8, 0xaa, 0xdd, 0x19, 0xec, 0x4a, 0xf3, 0xe8, 0xdd, 0x87, 0x93, 0x8f,
		0x25, 0xf1, 0xef, 0xbb, 0x17, 0xa5, 0xd8, 0x78, 0x96, 0xad, 0xe7, 0x32, 0xa7, 0xd2, 0xc8, 0x21,
		0x74, 0x8d, 0xa2, 0xaf, 0xce, 0x9f, 0xde, 0x9d, 0x1c, 0x7a, 0x9d, 0x10, 0x04, 0xc0, 0x02, 0x60,
		0x01, 0xb0, 0x99, 0x02, 0xb0, 0x99, 0x0b, 0x71, 0x6f, 0x44, 0xe3, 0x19, 0xf7, 0x92, 0x9b, 0x77,
		0x0c, 0xcc, 0xba, 0xc9, 0xa1, 0xf3, 0xd0, 0x79, 0xe8, 0x3c, 0x74, 0x9e, 0x95, 0x95, 0xba, 0xd9,
		0x13, 0x86, 0x5d, 0xed, 0x1e, 0xf0, 0xa5, 0x7e, 0x76, 0xec, 0x30, 0xeb, 0xf4, 0x95, 0xf6, 0x60,
		0x0a, 0xfd, 0x7d, 0xd3, 0xe9, 0x53, 0xaa, 0x37, 0xb0, 0x62, 0x01, 0xbb, 0xaa, 0x0f, 0xae, 0x98,
		0xe3, 0x50, 0xd3, 0x1c, 0xad, 0x0a, 0x39, 0x5a, 0x16, 0xed, 0x02, 0x39, 0x5a, 0x0f, 0x4f, 0x4e,
		0x8e, 0x16, 0x60, 0x0e, 0x30, 0x07, 0x98, 0xcb, 0x2b, 0x98, 0x23, 0x47, 0x4b, 0x52, 0x9a, 0xc8,
		0xd1, 0x92, 0x8c, 0x73, 0x90, 0xa3, 0x85, 0xa1, 0xc4, 0x50, 0x6e, 0xa7, 0xa1, 0x24, 0x47, 0x6b,
		0xee, 0xd9, 0xc9, 0xd1, 0x42, 0xf1, 0xa1, 0xf8, 0x8a, 0xae, 0xf8, 0xc8, 0xd1, 0xda, 0xa4, 0x5b,
		0x25, 0x6c, 0x28, 0x84, 0xd8, 0xcc, 0xe2, 0xce, 0x91, 0xa3, 0xf5, 0x64, 0x43, 0xc8, 0xd1, 0x4a,
		0xb0, 0x3b, 0xe4, 0x68, 0x6d, 0x8e, 0x0a, 0x39, 0x5a, 0xe4, 0x68, 0x01, 0x60, 0x01, 0xb0, 0x59,
		0x05, 0xb0, 0xe4, 0x68, 0x91, 0xa3, 0x85, 0xce, 0x43, 0xe7, 0xa1, 0xf3, 0x72, 0xa9, 0xf3, 0xb6,
		0x38, 0x47, 0x4b, 0x63, 0x02, 0xa9, 0xfe, 0xb6, 0xe9, 0xa4, 0x68, 0xc9, 0x0d, 0x91, 0x66, 0x7c,
		0x34, 0x89, 0x5a, 0x9b, 0x36, 0x06, 0x79, 0x1d, 0x1f, 0xdd, 0xf1, 0xdc, 0x6b, 0xa1, 0x1e, 0xf6,
		0x07, 0x06, 0x34, 0x3e, 0x8d, 0xb5, 0xdd, 0xcb, 0x97, 0x23, 0xc5, 0xf5, 0x6a, 0x2a, 0xd3, 0x85,
		0x18, 0x4a, 0xfd, 0xcf, 0x61, 0xb8, 0x40, 0x57, 0x51, 0x15, 0xbf, 0xcf, 0x74, 0xd0, 0xef, 0x74,
		0x8a, 0x3a, 0x15, 0xfc, 0xc1, 0x26, 0x97, 0xb4, 0x12, 0x99, 0x93, 0x0d, 0xbd, 0xfe, 0x5d, 0xb9,
		0x81, 0xf4, 0x16, 0x35, 0x76, 0x1e, 0x35, 0x4c, 0x96, 0x6a, 0xec, 0xfc, 0xcc, 0x60, 0x17, 0x54,
		0xdf, 0xde, 0xe0, 0xad, 0x4b, 0x89, 0x26, 0x73, 0x25, 0xe2, 0xae, 0xd5, 0x5b, 0xb7, 0x7c, 0x43,
		0x56, 0x6c, 0xc6, 0x70, 0x3c, 0x52, 0x37, 0xf4, 0xff, 0x4a, 0xb6, 0x17, 0x8f, 0xa6, 0x2a, 0x3d,
		0x2c, 0x5b, 0xb3, 0xd9, 0xc9, 0x32, 0xf0, 0x13, 0x03, 0x38, 0x15, 0xa0, 0xa6, 0x0e, 0xc8, 0x54,
		0x81, 0x97, 0x36, 0xc0, 0xd2, 0x06, 0x52, 0x5a, 0x80, 0xc9, 0x4c, 0x5c, 0x92, 0x66, 0xa4, 0x33,
		0x7f, 0x9f, 0x66, 0xea, 0x1b, 0xb1, 0x66, 0x5a, 0x53, 0xe6, 0xa6, 0x0a, 0x4c, 0x64, 0xc8, 0xdc,
		0x1c, 0x35, 0x66, 0xcc, 0xd9, 0x73, 0x6f, 0x69, 0xb6, 0xce, 0x8c, 0xb9, 0x44, 0x7f, 0x98, 0x31,
		0xb7, 0xfe, 0x05, 0x99, 0x31, 0x97, 0x4a, 0xb8, 0xc8, 0xe2, 0x8b, 0x31, 0x63, 0xce, 0x6e, 0x80,
		0x70, 0xf2, 0x87, 0x19, 0x73, 0xea, 0xfa, 0x8e, 0x19, 0x73, 0xcc, 0x98, 0xb3, 0x8a, 0x05, 0x77,
		0x98, 0x31, 0x27, 0x84, 0x27, 0x0b, 0x1e, 0x8a, 0x9c, 0x7a, 0x68, 0x1b, 0x18, 0xbe, 0xef, 0x7d,
		0x1b, 0x8b, 0xae, 0x62, 0x60, 0x64, 0xbc, 0x8e, 0xc0, 0x08, 0x81, 0x91, 0x74, 0x02, 0x23, 0x43,
		0x86, 0xd3, 0x8f, 0x84, 0x8c, 0x96, 0x33, 0x67, 0x8e, 0xd0, 0x47, 0xa6, 0x42, 0x1f, 0xcc, 0x99,
		0x23, 0x35, 0xc6, 0x9a, 0x20, 0x59, 0xc1, 0x8c, 0x3b, 0x5b, 0xde, 0xc3, 0x68, 0x68, 0x48, 0x46,
		0x35, 0xda, 0x62, 0x81, 0xae, 0x19, 0x9a, 0x24, 0x3c, 0xdb, 0x17, 0x54, 0x69, 0x81, 0xb5, 0x26,
		0xb8, 0xd6, 0x04, 0xd8, 0x8a, 0x20, 0xcb, 0x84, 0xb2, 0xb2, 0x97, 0xf0, 0x2c, 0x5b, 0x36, 0x2a,
		0x59, 0x2e, 0x6a, 0xa7, 0x4c, 0xf4, 0x51, 0xfc, 0xfd, 0xe8, 0xf7, 0xcb, 0x7f, 0x9c, 0x9d, 0x9f,
		0xfc, 0xfb, 0xe8, 0xf2, 0xe4, 0xec, 0x63, 0xf3, 0xf8, 0x5f, 0xc7, 0x1f, 0x2f, 0x25, 0x82, 0xf1,
		0xd3, 0xef, 0xb2, 0x50, 0x1e, 0x6a, 0xa9, 0x58, 0x76, 0xd9, 0x6e, 0xbc, 0x3d, 0xfb, 0xf0, 0xe1,
		0xe8, 0xe3, 0x3b, 0xb9, 0xe2, 0xd0, 0xfb, 0x17, 0xf9, 0xdd, 0x8a, 0x8f, 0xbf, 0x9d, 0xbc, 0x2f,
		0x65, 0xac, 0x0c, 0xb5, 0xb1, 0x69, 0x8d, 0x46, 0x81, 0x42, 0xc2, 0xf0, 0xd7, 0x28, 0xa8, 0x34,
		0xfa, 0x2b, 0x07, 0x5d, 0x64, 0x05, 0xa0, 0xa0, 0x1c, 0x04, 0xa4, 0x4c, 0x01, 0x5f, 0x8c, 0x32,
		0x85, 0x8c, 0x95, 0x29, 0xcc, 0x48, 0x35, 0xdd, 0xb0, 0x53, 0x89, 0x24, 0xd1, 0x0d, 0x1b, 0xed,
		0x45, 0x24, 0x89, 0x48, 0x12, 0x91, 0x24, 0x22, 0x49, 0x44, 0x92, 0x88, 0x24, 0x11, 0x49, 0x22,
		0x92, 0x44, 0x24, 0x69, 0xbb, 0x23, 0x49, 0xe9, 0xf6, 0xba, 0x48, 0xa3, 0x52, 0x5c, 0x1b, 0xe6,
		0x51, 0x2b, 0x6e, 0x7c, 0x04, 0x69, 0xd7, 0x8a, 0x2f, 0x66, 0x6a, 0xf1, 0x62, 0xf1, 0xe9, 0xd7,
		0x34, 0x8f, 0x87, 0xf4, 0xc9, 0xd0, 0x5c, 0x71, 0x06, 0x69, 0x66, 0x68, 0xaa, 0x45, 0x67, 0xb4,
		0xa2, 0x31, 0xda, 0xf9, 0x99, 0x15, 0xf2, 0x33, 0x25, 0x9d, 0x2b, 0x0a, 0x57, 0x29, 0x5c, 0x25,
		0x7b, 0x53, 0x32, 0xa2, 0x40, 0xe1, 0xea, 0xf2, 0xc7, 0xa6, 0x70, 0x95, 0xc2, 0x55, 0xc3, 0x17,
		0xa5, 0x70, 0x35, 0x97, 0x6f, 0x47, 0xe1, 0x6a, 0xfa, 0x4a, 0x8f, 0xc2, 0xd5, 0x2d, 0x0b, 0x44,
		0x50, 0xb8, 0x6a, 0x07, 0x17, 0xee, 0x50, 0xb8, 0x9a, 0xbd, 0xb0, 0x88, 0x42, 0x88, 0x35, 0xef,
		0x2d, 0xf4, 0x92, 0xb6, 0x97, 0x53, 0x08, 0xb9, 0xd9, 0x68, 0xa0, 0x97, 0xb0, 0x40, 0x4c, 0xad,
		0x10, 0x8c, 0x96, 0x79, 0xb2, 0xba, 0x6d, 0x03, 0x2d, 0xf3, 0x6c, 0x8a, 0x47, 0x92, 0x94, 0x5d,
		0x3d, 0x6e, 0x8e, 0xbc, 0xf0, 0x9b, 0x17, 0x3a, 0x37, 0x61, 0xb7, 0xdf, 0x8b, 0x92, 0x33, 0xf5,
		0xe3, 0x65, 0xf0, 0x36, 0xed, 0x20, 0xe7, 0xd9, 0x49, 0x23, 0xb4, 0x3e, 0xbb, 0x9a, 0x0e, 0x08,
		0x29, 0x06, 0x19, 0xb7, 0x3a, 0xc2, 0xae, 0x59, 0xf2, 0x6d, 0x56, 0xea, 0x4d, 0x0f, 0x84, 0x54,
		0x19, 0x5c, 0xdc, 0x5b, 0x2a, 0x72, 0x0f, 0x04, 0x99, 0xf1, 0x20, 0x8c, 0x06, 0x21, 0x6b, 0x7d,
		0x13, 0x42, 0xb5, 0x91, 0x40, 0xa6, 0x60, 0xcd, 0x4d, 0xfe, 0x02, 0x9a, 0x3a, 0xb5, 0x31, 0x32,
		0xd5, 0x7d, 0xd4, 0xf5, 0xa1, 0x63, 0xd0, 0x31, 0xea, 0xfc, 0xb2, 0x15, 0x37, 0xc5, 0x17, 0xc7,
		0xe7, 0xff, 0x3a, 0x3e, 0x2f, 0xf8, 0x4d, 0xf1, 0xe8, 0x42, 0xb5, 0xb8, 0x97, 0xa9, 0x5b, 0x77,
		0x91, 0x9a, 0x31, 0x27, 0x22, 0xcd, 0xac, 0xdc, 0x47, 0x51, 0xc5, 0x47, 0xff, 0xa5, 0xd5, 0xb4,
		0x40, 0xe1, 0x96, 0x48, 0x21, 0x44, 0xa3, 0xe5, 0x1c, 0x99, 0x38, 0x45, 0xe4, 0xdb, 0x11, 0x29,
		0xc8, 0x7c, 0xbe, 0x9d, 0x7e, 0xa3, 0x00, 0x93, 0x06, 0x01, 0xf3, 0x8d, 0x01, 0xd4, 0x67, 0x17,
		0xda, 0xd1, 0x12, 0x23, 0xe5, 0x15, 0xe9, 0x2b, 0x8a, 0x09, 0x01, 0xa2, 0x8a, 0xe8, 0x8a, 0x62,
		0x44, 0x15, 0x47, 0x1c, 0x2d, 0xd0, 0x0e, 0x63, 0x44, 0x87, 0xce, 0xaa, 0x78, 0xfd, 0x5b, 0xe1,
		0xf5, 0x1b, 0xf7, 0xc3, 0x70, 0xdb, 0xed, 0xd0, 0x8b, 0x22, 0x39, 0xe7, 0x7a, 0x42, 0x90, 0x4e,
		0x18, 0xf6, 0x45, 0x54, 0x5a, 0x54, 0xad, 0x89, 0xac, 0x35, 0xd1, 0xb5, 0x22, 0xc2, 0x32, 0xc1,
		0x81, 0xec, 0x75, 0xc2, 0x30, 0x6f, 0xd8, 0x25, 0x81, 0xcb, 0xd7, 0xe3, 0xf4, 0x89, 0x0a, 0xd9,
		0x54, 0xd9, 0xbe, 0x81, 0xcd, 0x34, 0xec, 0x10, 0x3f, 0x77, 0x64, 0x46, 0x9d, 0xe2, 0x85, 0x70,
		0x0d, 0xca, 0x14, 0x65, 0x9a, 0x77, 0x65, 0x6a, 0x8a, 0x93, 0xc4, 0xf1, 0x92, 0x25, 0xdc, 0x24,
		0x8c, 0x9f, 0xc4, 0x45, 0xdf, 0x86, 0x0a, 0xb0, 0xa7, 0x0a, 0x6c, 0xa9, 0x04, 0xeb, 0xaa, 0xc1,
		0xba, 0x8a, 0xb0, 0xaa, 0x2a, 0x64, 0x54, 0x86, 0x90, 0xea, 0x90, 0xc7, 0x63, 0x73, 0xfc, 0xea,
		0xf7, 0x1c, 0x59, 0xe9, 0xdf, 0x31, 0x2c, 0x56, 0x5e, 0xb7, 0x07, 0x9f, 0x45, 0x79, 0x48, 0x56,
		0xa6, 0x9e, 0xec, 0xec, 0xb7, 0xaa, 0x85, 0xbd, 0x9d, 0xdb, 0xe3, 0xd7, 0x16, 0x68, 0x7f, 0x72,
		0xe3, 0xd8, 0x0b, 0x03, 0xf1, 0xed, 0x9e, 0x7e, 0xc1, 0x7f, 0x9e, 0x3f, 0xff, 0xbc, 0xe7, 0x1c,
		0x36, 0x7e, 0x7e, 0x2e, 0x3b, 0x87, 0x8d, 0xd1, 0x8f, 0xe5, 0xe1, 0x5f, 0xa3, 0x9f, 0x2b, 0x9f,
		0xf7, 0x9c, 0xea, 0xe4, 0xe7, 0xda, 0xe7, 0x3d, 0xa7, 0xd6, 0xd8, 0xbd, 0xba, 0x7a, 0xb9, 0xfb,
		0x63, 0xff, 0x5e, 0x7d, 0xe1, 0xdf, 0x4a, 0xe2, 0x2f, 0xd1, 0xb0, 0xb1, 0xe9, 0x67, 0x17, 0x27,
		0xff, 0xc3, 0xce, 0xaf, 0xdb, 0x79, 0x51, 0x8a, 0xf7, 0x2f, 0x72, 0xa4, 0x4e, 0xea, 0xa8, 0x93,
		0xd5, 0x4c, 0xed, 0x3a, 0xd7, 0x47, 0xce, 0x6f, 0x8d, 0x1f, 0xe5, 0x17, 0xd5, 0xfb, 0x37, 0xbb,
		0x3f, 0x0e, 0xee, 0x9f, 0xfe, 0xf2, 0xe7, 0xa2, 0x8f, 0x95, 0x5f, 0x1c, 0xdc, 0xbf, 0x59, 0xf2,
		0x2f, 0xf5, 0xfb, 0x37, 0x09, 0x69, 0xd4, 0xee, 0x9f, 0xcf, 0x7d, 0x74, 0xf0, 0xfb, 0xca, 0xb2,
		0x05, 0xd5, 0x25, 0x0b, 0xf6, 0x97, 0x2d, 0xd8, 0x5f, 0xb2, 0x60, 0xe9, 0x23, 0x55, 0x96, 0x2c,
		0xa8, 0xdd, 0xff, 0x9c, 0xfb, 0xfc, 0xf3, 0xc5, 0x1f, 0xad, 0xdf, 0xef, 0xfe, 0x5c, 0xf6, 0x6f,
		0x07, 0xf7, 0x3f, 0xdf, 0xec, 0xa2, 0x5c, 0xe1, 0xc3, 0xc2, 0xf2, 0xa1, 0xac, 0xa9, 0x79, 0x96,
		0xad, 0xe7, 0xba, 0xcf, 0x42, 0x6a, 0x9e, 0x59, 0x49, 0xc7, 0x52, 0x63, 0x69, 0x50, 0xe2, 0x41,
		0x34, 0x83, 0x68, 0x06, 0xd1, 0x8c, 0x9c, 0x46, 0x33, 0x8c, 0x4b, 0x54, 0x96, 0xc3, 0xe2, 0x02,
		0xe9, 0xdc, 0xd8, 0xbf, 0xf5, 0xba, 0xfd, 0x58, 0x5e, 0xed, 0x4e, 0x08, 0xa3, 0x79, 0xd1, 0xbc,
		0x68, 0xde, 0xad, 0xd2, 0xbc, 0x7d, 0x3f, 0x88, 0xcb, 0x75, 0x0b, 0x9a, 0xb7, 0x2e, 0x48, 0xf2,
		0xdc, 0x0d, 0x6e, 0x72, 0x11, 0x43, 0xfe, 0xe0, 0x07, 0xe2, 0x82, 0x6a, 0x49, 0xad, 0xce, 0x91,
		0x1f, 0x96, 0x24, 0x59, 0xa4, 0xff, 0x5b, 0xe8, 0xb6, 0x62, 0xbf, 0x1b, 0xbc, 0xf3, 0x6f, 0xfc,
		0x51, 0x33, 0x38, 0xf1, 0xef, 0xb9, 0xb7, 0x10, 0x80, 0xf8, 0xe0, 0x7e, 0xcf, 0xfd, 0x91, 0xd6,
		0x6b, 0xb5, 0xfd, 0x5a, 0x8e, 0x8f, 0x15, 0x7f, 0xde, 0x22, 0x05, 0xd3, 0x34, 0x09, 0xa1, 0x19,
		0x22, 0x53, 0x7a, 0x42, 0x05, 0x5e, 0xe3, 0x7a, 0x87, 0xf1, 0xdf, 0x46, 0x43, 0x6a, 0xcd, 0xf7,
		0xd9, 0x24, 0x3d, 0x2c, 0x74, 0xdb, 0x7e, 0x5f, 0x30, 0xd9, 0x76, 0x4c, 0x8f, 0xf4, 0xb0, 0xf4,
		0xb0, 0x3c, 0xe9, 0x61, 0xa4, 0x87, 0x2d, 0x27, 0x24, 0x94, 0xff, 0x39, 0xc7, 0xbe, 0x22, 0x79,
		0xa0, 0xc2, 0x02, 0x8f, 0x53, 0x8f, 0x53, 0x8f, 0x53, 0x2f, 0xab, 0x40, 0xa6, 0x04, 0xdd, 0x56,
		0x2b, 0x76, 0x7a, 0xdd, 0x30, 0x96, 0xe7, 0xab, 0x69, 0xc6, 0xe9, 0xf4, 0x2b, 0x84, 0x8f, 0xfd,
		0x9d, 0x77, 0xed, 0xf6, 0x3b, 0xc3, 0x53, 0x2f, 0xbf, 0x2e, 0xef, 0x4b, 0x93, 0xb7, 0xe3, 0x68,
		0x89, 0x6b, 0x31, 0x9b, 0xda, 0xcc, 0xbe, 0x56, 0xb3, 0xad, 0xdd, 0x52, 0xd3, 0x72, 0xa9, 0x69,
		0xbb, 0x54, 0xb4, 0x9e, 0x25, 0x37, 0x5a, 0x98, 0xe3, 0xc5, 0x43, 0x9c, 0x73, 0xfc, 0x3e, 0x50,
		0x5b, 0x4e, 0xd0, 0xbf, 0xfd, 0xa2, 0x5d, 0xec, 0x9b, 0x44, 0xc5, 0xd4, 0x2d, 0x90, 0xb6, 0x13,
		0xff, 0x9c, 0xfc, 0xb1, 0x23, 0xa4, 0x3b, 0xb6, 0xe3, 0xa1, 0x29, 0x05, 0xd1, 0xe6, 0x82, 0x69,
		0xb6, 0xbf, 0x27, 0x85, 0x80, 0x9a, 0x25, 0x19, 0x7e, 0x7c, 0xf4, 0x16, 0xe3, 0xa6, 0x9b, 0x3a,
		0x7a, 0x8b, 0x71, 0xd4, 0x8d, 0x1c, 0xff, 0xb3, 0x7c, 0x50, 0xcd, 0x6a, 0x3e, 0x97, 0xa0, 0xf8,
		0x0c, 0xe7, 0x28, 0xda, 0xc6, 0xee, 0xd3, 0xaf, 0xb0, 0x8a, 0xdd, 0x2b, 0x60, 0x77, 0xb0, 0x3b,
		0xd8, 0x1d, 0xec, 0x0e, 0x76, 0x07, 0xbb, 0x83, 0xdd, 0xc1, 0xee, 0x60, 0x77, 0xb0, 0x7b, 0xa1,
		0xb1, 0x7b, 0xe8, 0xc5, 0xa1, 0x1b, 0x44, 0xb7, 0x7e, 0xec, 0xb8, 0x71, 0xec, 0xdd, 0xf6, 0xe2,
		0xc8, 0x1e, 0x8a, 0x5f, 0xf4, 0x65, 0x00, 0x6e, 0x00, 0x37, 0x80, 0x1b, 0xc0, 0x2d, 0xc8, 0xef,
		0x7d, 0x3f, 0x88, 0x5f, 0x5b, 0x84, 0xda, 0x35, 0xa0, 0x36, 0x50, 0x1b, 0xa8, 0x5d, 0x48, 0xa8,
		0x5d, 0xa9, 0x01, 0xb4, 0x01, 0xda, 0x16, 0x80, 0x76, 0xe4, 0xb5, 0x42, 0x2f, 0x76, 0xfe, 0xf4,
		0xee, 0xec, 0xe1, 0xeb, 0x99, 0xef, 0x00, 0x56, 0x03, 0xab, 0x81, 0xd5, 0xc0, 0x6a, 0x49, 0xef,
		0xbd, 0xdb, 0x8f, 0xfd, 0xe0, 0xc6, 0xe9, 0xb9, 0x51, 0x34, 0x64, 0x1f, 0x9b, 0x1d, 0x81, 0xb6,
		0xca, 0x22, 0x38, 0x5f, 0xdd, 0xe8, 0xab, 0xd7, 0x4e, 0xc3, 0x30, 0x4c, 0xbe, 0x0a, 0xfb, 0x80,
		0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0x04, 0xf9, 0xbd, 0x15, 0xde, 0xf5, 0xe2, 0xa9, 0x75, 0x70, 0x0c,
		0xc6, 0x91, 0x62, 0x22, 0x26, 0x26, 0x62, 0x28, 0xe8, 0x8e, 0x74, 0x13, 0xe6, 0x79, 0xfb, 0xf0,
		0xf8, 0x7b, 0x30, 0x0e, 0x18, 0x07, 0x8c, 0x03, 0xc6, 0x41, 0x90, 0xdf, 0xad, 0xf4, 0x7c, 0x9e,
		0xb3, 0x09, 0x87, 0x16, 0x68, 0x5b, 0xe9, 0x01, 0x3d, 0xf9, 0x63, 0x31, 0x30, 0x9f, 0x52, 0x4f,
		0xe8, 0x79, 0xbb, 0x6c, 0xf1, 0x3b, 0x6c, 0x37, 0xd3, 0x9c, 0x7e, 0x51, 0xde, 0x3b, 0x16, 0x4f,
		0xfe, 0x34, 0x6c, 0x1e, 0x46, 0x1a, 0xed, 0x4d, 0x8b, 0x77, 0x22, 0x76, 0x62, 0xf2, 0x2f, 0x72,
		0xac, 0x9e, 0xea, 0xa8, 0x27, 0x3d, 0x61, 0xa0, 0xe7, 0x6f, 0x21, 0x7a, 0xfe, 0x16, 0x56, 0x59,
		0xc3, 0x9f, 0xc5, 0xe2, 0x4f, 0xae, 0x93, 0x33, 0x40, 0x49, 0xaa, 0x85, 0x83, 0x70, 0xef, 0xab,
		0x87, 0x98, 0x95, 0x95, 0x1e, 0x58, 0xa3, 0xce, 0x4f, 0x22, 0xad, 0xb0, 0xe4, 0x8e, 0x43, 0xa2,
		0x31, 0xee, 0x70, 0x04, 0xa4, 0x7c, 0x03, 0x9d, 0x11, 0xd9, 0x8c, 0xf7, 0xcf, 0xa9, 0xd0, 0x3f,
		0x27, 0x47, 0x81, 0x39, 0xfa, 0xe7, 0xd0, 0x3f, 0x87, 0xfe, 0x39, 0xf3, 0x5a, 0x8c, 0xeb, 0x87,
		0x14, 0xb4, 0x5b, 0x6a, 0x5a, 0x2e, 0x35, 0x6d, 0x97, 0x8a, 0xd6, 0xb3, 0x03, 0xb2, 0xa9, 0xc1,
		0x5d, 0xac, 0x62, 0xa8, 0xc1, 0x9d, 0x79, 0x70, 0x0a, 0x03, 0xd4, 0xbf, 0x87, 0xc2, 0x80, 0xcc,
		0x1e, 0x3d, 0x35, 0xb8, 0xc4, 0x72, 0xec, 0x88, 0x0f, 0xfd, 0x73, 0xc0, 0xee, 0x60, 0x77, 0xb0,
		0x3b, 0xd8, 0x1d, 0xec, 0x0e, 0x76, 0x07, 0xbb, 0x83, 0xdd, 0xc1, 0xee, 0x60, 0xf7, 0x9c, 0x60,
		0xf7, 0x56, 0xb7, 0x1f, 0xc4, 0x5e, 0x68, 0x31, 0x37, 0x7f, 0xfa, 0x0d, 0x76, 0xa0, 0x75, 0x19,
		0x68, 0x0d, 0xb4, 0x06, 0x5a, 0x67, 0x11, 0x5a, 0x4b, 0x5f, 0x12, 0x3e, 0x04, 0x1c, 0x5a, 0x2d,
		0x2f, 0x8a, 0x9c, 0xc1, 0x5f, 0x36, 0xfa, 0x7d, 0xcd, 0x47, 0x1f, 0x1e, 0x7f, 0xdf, 0x8b, 0x5c,
		0x0e, 0x24, 0xb4, 0xa5, 0xd8, 0xd2, 0x50, 0x70, 0xe9, 0x29, 0xba, 0xb4, 0x14, 0x5e, 0xea, 0x8a,
		0x2f, 0x75, 0x05, 0x98, 0xaa, 0x22, 0xb4, 0x0c, 0x2d, 0x2d, 0x49, 0x8c, 0xb5, 0xd8, 0xc3, 0x32,
		0x10, 0x56, 0xaf, 0xa6, 0x90, 0xa2, 0x6e, 0x33, 0x43, 0xdd, 0x6e, 0x44, 0xc2, 0x7e, 0x64, 0x22,
		0xd5, 0x08, 0x45, 0xca, 0xee, 0x6a, 0xda, 0x11, 0x8b, 0x4d, 0xb8, 0xae, 0x29, 0x44, 0x30, 0x52,
		0x8d, 0x64, 0x6c, 0x9a, 0x45, 0xca, 0xaf, 0xab, 0xd5, 0xfa, 0x41, 0xb5, 0xba, 0x77, 0xb0, 0x7f,
		0xb0, 0x77, 0x58, 0xab, 0x95, 0xeb, 0xe5, 0x5a, 0x81, 0xb9, 0xe6, 0x59, 0x3e, 0xa9, 0xe7, 0x25,
		0x71, 0xde, 0xc6, 0x0c, 0xf2, 0x31, 0xf6, 0x0f, 0xbd, 0xff, 0xeb, 0xb5, 0x52, 0xf4, 0x35, 0x26,
		0xdf, 0x87, 0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x81,
		0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x81, 0xaf, 0x51, 0x50, 0x5f, 0x23, 0xf4, 0xe2, 0xd0, 0xf7, 0xda,
		0xce, 0xd4, 0x07, 0xf8, 0x7f, 0x7d, 0x2f, 0x4a, 0xc3, 0xe9, 0x58, 0xf6, 0xc5, 0x78, 0x1f, 0x78,
		0x1f, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x1f, 0x78, 0x1f, 0x78,
		0x1f, 0x78, 0x1f, 0x05, 0xf5, 0x3e, 0x62, 0xff, 0xd6, 0xeb, 0xf6, 0xe3, 0xf4, 0xbd, 0x8f, 0x65,
		0x5f, 0x8c, 0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x81,
		0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x81, 0xf7, 0x91, 0x05, 0xef, 0x23, 0xd3, 0x65, 0x27, 0x96, 0x1a,
		0x83, 0x4e, 0xe9, 0x5b, 0x6d, 0x10, 0x3a, 0xec, 0x7b, 0xf9, 0xca, 0x52, 0xcd, 0xdc, 0xe8, 0xf1,
		0xe3, 0xb0, 0xdf, 0x8a, 0x83, 0x31, 0x60, 0xb9, 0x18, 0x3e, 0x6b, 0xf3, 0xc8, 0x75, 0x9b, 0x17,
		0xc3, 0x07, 0x79, 0x3f, 0x78, 0xb8, 0xf1, 0xcf, 0xcd, 0xf3, 0xe1, 0x43, 0x35, 0xdf, 0x4e, 0x1e,
		0x67, 0x0b, 0x0a, 0x22, 0x17, 0xcd, 0xf8, 0xb7, 0x56, 0x1b, 0xb9, 0xe8, 0xcb, 0xe8, 0x40, 0x42,
		0x99, 0xe4, 0xc6, 0xbd, 0x58, 0xca, 0x24, 0xd3, 0xb3, 0x57, 0xf6, 0x3b, 0x90, 0xf4, 0xfd, 0x20,
		0x7e, 0x6d, 0xb1, 0xf7, 0x48, 0x8d, 0xde, 0x23, 0xe9, 0x7a, 0x9c, 0xf4, 0x1e, 0xc9, 0xa2, 0x47,
		0x59, 0xc8, 0xde, 0x23, 0x95, 0x1a, 0x9d, 0x47, 0x52, 0xa7, 0xda, 0xd8, 0xaa, 0xf1, 0xd1, 0x69,
		0xcc, 0x8d, 0x06, 0x56, 0x03, 0xab, 0x81, 0xd5, 0xc0, 0x6a, 0x51, 0xef, 0xbd, 0xdb, 0x8f, 0xfd,
		0xe0, 0x66, 0x3a, 0x32, 0x9a, 0x69, 0xd1, 0x52, 0x16, 0x61, 0x32, 0xe5, 0x3f, 0x05, 0xc3, 0x30,
		0xf9, 0x2a, 0xec, 0x03, 0xf6, 0x01, 0xfb, 0x80, 0x7d, 0x10, 0xe4, 0xf7, 0x56, 0x78, 0xd7, 0x8b,
		0xa7, 0xd6, 0xc1, 0x89, 0x07, 0x5f, 0x88, 0x89, 0x30, 0x33, 0x11, 0x8f, 0x07, 0xfd, 0xdb, 0xb3,
		0x0f, 0x8f, 0xbf, 0x07, 0xe3, 0x80, 0x71, 0xc0, 0x38, 0x60, 0x1c, 0x04, 0xf9, 0xdd, 0xef, 0x59,
		0x9c, 0x1a, 0x3d, 0xb5, 0x09, 0x87, 0x16, 0x68, 0x8f, 0xf7, 0xe6, 0x73, 0x8e, 0x27, 0x76, 0x57,
		0x99, 0xd8, 0xad, 0xf8, 0x45, 0x85, 0x19, 0x5f, 0x5f, 0xb4, 0x19, 0xd5, 0xf9, 0x3f, 0x91, 0x3c,
		0xa5, 0x12, 0xa7, 0xa3, 0x9e, 0xea, 0xa8, 0x27, 0x3d, 0x61, 0x60, 0x60, 0x7b, 0xb1, 0x06, 0xb6,
		0x17, 0x4d, 0x59, 0xc3, 0x9f, 0xc5, 0xe2, 0x4f, 0xae, 0x93, 0x33, 0x40, 0x49, 0x6a, 0xa6, 0xb5,
		0xa5, 0xbc, 0xe1, 0x14, 0xf2, 0x85, 0x65, 0x38, 0xdc, 0xfc, 0x34, 0xcc, 0x28, 0x18, 0x9e, 0xa3,
		0xf4, 0xf9, 0x59, 0x3d, 0x37, 0x01, 0x60, 0xa7, 0x91, 0xc8, 0x6d, 0xc6, 0x27, 0xfa, 0xa7, 0x6b,
		0x70, 0xb2, 0xa5, 0x11, 0x83, 0x9b, 0x1e, 0xe8, 0x43, 0x60, 0x77, 0x48, 0xce, 0x90, 0xd3, 0x64,
		0x46, 0xcf, 0x3c, 0xc4, 0x6b, 0x2b, 0x86, 0x84, 0x04, 0xe3, 0xb3, 0xf2, 0xf1, 0x58, 0xe9, 0xf8,
		0xab, 0xb5, 0x78, 0xab, 0xb5, 0xf8, 0xaa, 0x95, 0x78, 0xea, 0x66, 0x75, 0xad, 0xd4, 0x68, 0x97,
		0x92, 0xf4, 0x4d, 0xce, 0x43, 0x1f, 0x65, 0x51, 0x0f, 0x5a, 0xf8, 0xca, 0x46, 0xfc, 0xaa, 0xc6,
		0xc6, 0x15, 0x8d, 0xbd, 0xab, 0x19, 0x5b, 0x57, 0x32, 0xd6, 0xaf, 0x62, 0xac, 0x5f, 0xc1, 0x58,
		0xbd, 0x7a, 0xc9, 0x16, 0xdc, 0x16, 0xbf, 0x62, 0xb1, 0x7b, 0xb5, 0x62, 0xe3, 0x4a, 0xc5, 0xce,
		0x55, 0x8a, 0xd5, 0x4b, 0x2b, 0xab, 0x57, 0x27, 0x36, 0x63, 0x92, 0xd6, 0x63, 0x91, 0xb9, 0x0f,
		0xc8, 0x37, 0x6c, 0x6c, 0x7a, 0x1a, 0x51, 0xb6, 0xfc, 0xef, 0x7c, 0x96, 0xef, 0xc2, 0xed, 0xaa,
		0x93, 0x3a, 0xea, 0x84, 0x90, 0xf1, 0x16, 0x84, 0x8c, 0x73, 0xaf, 0x5c, 0xe1, 0xc3, 0x62, 0xf0,
		0x61, 0x46, 0xaf, 0x02, 0x1a, 0x59, 0x09, 0x61, 0x0b, 0x04, 0xbc, 0x5a, 0xdd, 0x20, 0xf0, 0x86,
		0x25, 0x8d, 0x8e, 0xfb, 0xa5, 0x1b, 0xc6, 0x16, 0xa2, 0x1b, 0xf3, 0x5f, 0x41, 0x9c, 0x83, 0x38,
		0x07, 0x71, 0x8e, 0xad, 0x8a, 0x73, 0xd8, 0x68, 0x36, 0x68, 0xa1, 0xb9, 0xa0, 0xa5, 0x56, 0x0e,
		0x16, 0xfc, 0x12, 0x9b, 0xad, 0x1b, 0x6c, 0xb7, 0x9d, 0xb5, 0xdc, 0xaa, 0x21, 0x8d, 0x2a, 0x7d,
		0x1b, 0x4d, 0x8d, 0x6d, 0xb6, 0x64, 0x48, 0xeb, 0x48, 0xd3, 0x6b, 0xde, 0x97, 0xca, 0x29, 0x83,
		0x40, 0xd3, 0x44, 0xa0, 0xad, 0x4e, 0x37, 0xf2, 0xec, 0x22, 0xd0, 0xf1, 0x57, 0x80, 0x40, 0x41,
		0xa0, 0x20, 0x50, 0x10, 0x28, 0x08, 0x14, 0x04, 0x0a, 0x02, 0x05, 0x81, 0x82, 0x40, 0x41, 0xa0,
		0x03, 0x78, 0x78, 0xed, 0xfa, 0x9d, 0x7e, 0x68, 0x19, 0x83, 0x4e, 0xbf, 0x04, 0x14, 0x0a, 0x0a,
		0x05, 0x85, 0x82, 0x42, 0x41, 0xa1, 0xa0, 0x50, 0x50, 0x28, 0x28, 0x14, 0x14, 0x0a, 0x0a, 0x1d,
		0x00, 0xc4, 0x6e, 0xcf, 0x0b, 0xec, 0x42, 0xd0, 0xd1, 0x37, 0x80, 0x3f, 0xc1, 0x9f, 0xe0, 0x4f,
		0xf0, 0x27, 0xf8, 0x13, 0xfc, 0x09, 0xfe, 0x04, 0x7f, 0x82, 0x3f, 0xc1, 0x9f, 0x03, 0x74, 0x38,
		0x1e, 0x72, 0x6d, 0x17, 0x82, 0x4e, 0xbf, 0x04, 0x14, 0x0a, 0x0a, 0x05, 0x85, 0x82, 0x42, 0x41,
		0xa1, 0xa0, 0x50, 0x50, 0x28, 0x28, 0x14, 0x14, 0xba, 0xc5, 0x28, 0xd4, 0x0b, 0xc3, 0x6e, 0x18,
		0x39, 0xa1, 0xd7, 0xf2, 0xfc, 0x6f, 0x82, 0x53, 0x55, 0xa6, 0xa6, 0xe7, 0xe9, 0x17, 0x80, 0x3e,
		0x41, 0x9f, 0xa0, 0x4f, 0xd0, 0x27, 0xe8, 0x13, 0xf4, 0x09, 0xfa, 0x04, 0x7d, 0x82, 0x3e, 0xb7,
		0x18, 0x7d, 0xde, 0x7a, 0x51, 0xe4, 0xde, 0x78, 0x36, 0xf1, 0xe7, 0xfc, 0x57, 0x80, 0x40, 0x41,
		0xa0, 0x20, 0x50, 0x10, 0x28, 0x08, 0x14, 0x04, 0x0a, 0x02, 0x05, 0x81, 0x82, 0x40, 0x41, 0xa0,
		0x91, 0x13, 0x8d, 0x4c, 0xac, 0x2d, 0xf4, 0x39, 0x24, 0x0f, 0xf2, 0x04, 0x79, 0x82, 0x3c, 0x41,
		0x9e, 0x20, 0x4f, 0x90, 0x27, 0xc8, 0x13, 0xe4, 0x09, 0xf2, 0xdc, 0x62, 0xe4, 0x39, 0x1e, 0xce,
		0x24, 0x0c, 0x38, 0x87, 0x54, 0xc1, 0x99, 0xe0, 0x4c, 0x70, 0xe6, 0x56, 0xe1, 0xcc, 0x28, 0x0e,
		0xfd, 0xe0, 0xc6, 0xc6, 0x4c, 0x93, 0xd7, 0x05, 0xd2, 0xb9, 0xe3, 0x1c, 0x78, 0x79, 0xb5, 0x3b,
		0x21, 0x8c, 0xe6, 0x45, 0xf3, 0xa2, 0x79, 0xb7, 0x4a, 0xf3, 0xf6, 0xfd, 0x20, 0x2e, 0xd7, 0x2d,
		0x68, 0xde, 0x3a, 0xee, 0x3d, 0xee, 0x3d, 0xee, 0x7d, 0x26, 0x8e, 0xb4, 0x5e, 0xab, 0xed, 0xe3,
		0xcf, 0x17, 0xd7, 0x9f, 0x67, 0x38, 0xf5, 0xda, 0xe1, 0xd4, 0x02, 0xd3, 0xc4, 0x37, 0x33, 0x25,
		0x3a, 0x76, 0x5b, 0x6e, 0x2b, 0x92, 0x1b, 0x13, 0x3d, 0xa6, 0x97, 0xb1, 0x39, 0xd1, 0x7b, 0xcc,
		0x89, 0xce, 0x00, 0x74, 0x67, 0x4e, 0x74, 0xf2, 0x37, 0x12, 0x9b, 0x13, 0xdd, 0x9a, 0xc8, 0x80,
		0x7c, 0xf1, 0xfc, 0x80, 0xae, 0xac, 0x4f, 0x5f, 0xc6, 0xa7, 0xc7, 0xa7, 0xc7, 0xa7, 0x97, 0x78,
		0x53, 0x29, 0x05, 0x32, 0x25, 0xd8, 0xeb, 0x86, 0xb1, 0x3c, 0x4b, 0x4d, 0x84, 0x60, 0x48, 0x5d,
		0xf8, 0xb0, 0xdf, 0x79, 0xd7, 0x6e, 0xbf, 0x33, 0x3c, 0xeb, 0xea, 0xa1, 0x34, 0x71, 0x3b, 0xbe,
		0x95, 0xb8, 0xe6, 0xb2, 0xa9, 0xc1, 0xec, 0x6b, 0x32, 0xdb, 0x1a, 0x2d, 0x35, 0xcd, 0x96, 0x9a,
		0x86, 0x4b, 0x45, 0xd3, 0x59, 0xf2, 0x9c, 0x85, 0x39, 0x5e, 0x3c, 0xaa, 0xb9, 0x50, 0x69, 0x39,
		0x41, 0xff, 0xf6, 0x8b, 0x17, 0x5a, 0x9c, 0xc2, 0x5c, 0xb7, 0x40, 0xda, 0x4e, 0xc8, 0x73, 0xf2,
		0xc7, 0x8e, 0x90, 0xee, 0xd8, 0x0e, 0x81, 0xa6, 0x14, 0x37, 0x9b, 0x8b, 0x9f, 0xd9, 0xfe, 0x9e,
		0x14, 0x62, 0x68, 0x96, 0x64, 0xf8, 0xf1, 0xd1, 0x5b, 0x0c, 0x95, 0x6e, 0xea, 0xe8, 0x2d, 0x86,
		0x4e, 0x37, 0x72, 0xfc, 0xcf, 0xf2, 0x41, 0x35, 0xab, 0xc3, 0x9c, 0x05, 0xc5, 0xa7, 0x14, 0x79,
		0xad, 0xd0, 0x8b, 0x9d, 0x3f, 0xbd, 0x3b, 0x7b, 0xa8, 0x7d, 0xe6, 0x3b, 0x80, 0xd7, 0xc0, 0x6b,
		0xe0, 0x35, 0xf0, 0x5a, 0x90, 0xdf, 0xc3, 0x6e, 0x3f, 0xf6, 0x83, 0x1b, 0xa7, 0xe7, 0x46, 0xd1,
		0x90, 0x7d, 0xec, 0x61, 0x6c, 0xa1, 0x44, 0xae, 0xbc, 0x58, 0x04, 0xe7, 0xab, 0x1b, 0x7d, 0x15,
		0x6c, 0x28, 0xb0, 0xc2, 0x30, 0x4c, 0xbe, 0x0a, 0xfb, 0x80, 0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0x04,
		0xf9, 0xbd, 0x15, 0xde, 0xf5, 0xe2, 0xa9, 0x75, 0x70, 0xe2, 0xc1, 0x17, 0x62, 0x22, 0xcc, 0x4c,
		0xc4, 0x50, 0xd0, 0x1d, 0xb7, 0xdd, 0x0e, 0xbd, 0x28, 0xb2, 0x68, 0x1f, 0x1e, 0x7f, 0x0f, 0xc6,
		0x01, 0xe3, 0x80, 0x71, 0xc0, 0x38, 0x08, 0xf2, 0xbb, 0xdf, 0xb3, 0xa4, 0x5d, 0x1e, 0xd9, 0x84,
		0x43, 0x0b, 0xb4, 0xc7, 0x7b, 0x93, 0xbb, 0xd0, 0xfc, 0xc3, 0xce, 0x7f, 0xab, 0x5a, 0xdc, 0xfb,
		0x79, 0xbb, 0x6c, 0xf1, 0x3b, 0x3e, 0xb9, 0x71, 0xec, 0x85, 0x81, 0xb5, 0xe3, 0x98, 0x7e, 0xd1,
		0x7f, 0x9e, 0x3f, 0xff, 0xbc, 0xe7, 0x1c, 0x36, 0x7e, 0x7e, 0x2e, 0x3b, 0x87, 0x8d, 0xd1, 0x8f,
		0xe5, 0xe1, 0x5f, 0xa3, 0x9f, 0x2b, 0x9f, 0xf7, 0x9c, 0xea, 0xe4, 0xe7, 0xda, 0xe7, 0x3d, 0xa7,
		0xd6, 0xd8, 0xbd, 0xba, 0x7a, 0xb9, 0xfb, 0x63, 0xff, 0x5e, 0x7d, 0xe1, 0xdf, 0x4a, 0xd6, 0x5e,
		0xa6, 0x61, 0xf3, 0x30, 0xce, 0x2e, 0x4e, 0xfe, 0x87, 0x13, 0x51, 0x3d, 0x11, 0x3b, 0x31, 0xf9,
		0x17, 0x39, 0x56, 0x4f, 0x75, 0xd4, 0x93, 0x9e, 0x30, 0xb8, 0xce, 0xf5, 0x91, 0xf3, 0x5b, 0xe3,
		0x47, 0xf9, 0x45, 0xf5, 0xfe, 0xcd, 0xee, 0x8f, 0x83, 0xfb, 0xa7, 0xbf, 0xfc, 0xb9, 0xe8, 0x63,
		0xe5, 0x17, 0x07, 0xf7, 0x6f, 0x96, 0xfc, 0x4b, 0xfd, 0xfe, 0x4d, 0x42, 0x1a, 0xb5, 0xfb, 0xe7,
		0x73, 0x1f, 0x1d, 0xfc, 0xbe, 0xb2, 0x6c, 0x41, 0x75, 0xc9, 0x82, 0xfd, 0x65, 0x0b, 0xf6, 0x97,
		0x2c, 0x58, 0xfa, 0x48, 0x95, 0x25, 0x0b, 0x6a, 0xf7, 0x3f, 0xe7, 0x3e, 0xff, 0x7c, 0xf1, 0x47,
		0xeb, 0xf7, 0xbb, 0x3f, 0x97, 0xfd, 0xdb, 0xc1, 0xfd, 0xcf, 0x37, 0xbb, 0x28, 0x6b, 0xf8, 0x73,
		0x6b, 0xf9, 0x93, 0xeb, 0xe4, 0x0c, 0x50, 0x92, 0xca, 0x48, 0x15, 0xae, 0xe4, 0x79, 0x88, 0x59,
		0x59, 0xa9, 0xe8, 0x19, 0x15, 0xb2, 0xbc, 0x1a, 0xa7, 0xb9, 0x17, 0xa8, 0xcc, 0x7f, 0x54, 0xaa,
		0x24, 0x5e, 0x0f, 0x30, 0x22, 0x9b, 0xf1, 0x72, 0x80, 0x0a, 0xe5, 0x00, 0x39, 0x0a, 0xcc, 0x51,
		0x0e, 0x40, 0x39, 0x80, 0x20, 0x6d, 0xca, 0x01, 0xec, 0x6a, 0x30, 0xfb, 0x9a, 0xcc, 0xb6, 0x46,
		0x4b, 0x4d, 0xb3, 0xa5, 0xa6, 0xe1, 0x52, 0xd1, 0x74, 0x76, 0x80, 0x35, 0xe5, 0x00, 0x8b, 0x55,
		0x0c, 0xe5, 0x00, 0x33, 0x0f, 0x4e, 0x39, 0x80, 0xfa, 0xf7, 0x50, 0x0e, 0x90, 0xd9, 0xa3, 0xa7,
		0x1c, 0x80, 0xf8, 0x8d, 0x1d, 0xf1, 0xa1, 0x1c, 0x00, 0x78, 0x0d, 0xbc, 0x06, 0x5e, 0xe7, 0x18,
		0x5e, 0x53, 0x0e, 0x40, 0x39, 0x00, 0xf6, 0x01, 0xfb, 0x80, 0x7d, 0xc0, 0x3e, 0x2c, 0xe2, 0x77,
		0xca, 0x01, 0xe4, 0x4d, 0x04, 0xe5, 0x00, 0x18, 0x07, 0x8c, 0x03, 0xc6, 0x21, 0xf7, 0xc6, 0x81,
		0x72, 0x80, 0x85, 0x7f, 0x28, 0x07, 0x50, 0xd3, 0xcc, 0x24, 0x9f, 0xab, 0xfd, 0xa1, 0x1c, 0x80,
		0x72, 0x80, 0xcc, 0xab, 0x27, 0xca, 0x01, 0x34, 0x85, 0x81, 0x74, 0x6b, 0xca, 0x01, 0xb2, 0xac,
		0xac, 0xe1, 0x4f, 0xca, 0x01, 0x52, 0xf6, 0x8c, 0x76, 0x28, 0x07, 0x48, 0xea, 0xf5, 0xe6, 0xb1,
		0x1c, 0x40, 0x60, 0xce, 0x87, 0xdc, 0x69, 0x30, 0x98, 0x25, 0xe9, 0xb9, 0x95, 0x44, 0xea, 0x26,
		0xc2, 0x7e, 0x2b, 0x1e, 0x0f, 0xa6, 0x2d, 0x5d, 0x0c, 0x1f, 0xa6, 0x79, 0xe4, 0xba, 0xcd, 0x8b,
		0xe1, 0x37, 0xbd, 0x1f, 0x7c, 0xfb, 0xf8, 0xe7, 0xe6, 0xe5, 0xe8, 0x5b, 0x37, 0x35, 0x0f, 0xe6,
		0x59, 0x8a, 0xfc, 0x50, 0xfa, 0xe7, 0x30, 0xa3, 0xa4, 0x64, 0x06, 0xa1, 0x4b, 0xa7, 0x7e, 0x14,
		0x1f, 0xc5, 0xb1, 0x59, 0x92, 0x7a, 0xe9, 0x83, 0x1f, 0x1c, 0x77, 0xbc, 0x5b, 0x2f, 0x18, 0x25,
		0x36, 0x19, 0xcc, 0xc5, 0xf9, 0xe0, 0x7e, 0x9f, 0xa1, 0x24, 0x3b, 0xc0, 0xba, 0x74, 0x16, 0xb6,
		0xbd, 0xd0, 0x6b, 0xff, 0x3a, 0xd8, 0xb8, 0xa0, 0xdf, 0xe9, 0xa4, 0x7a, 0x5e, 0x42, 0x72, 0x6b,
		0x47, 0x5e, 0x0d, 0x04, 0x55, 0x45, 0x40, 0xf5, 0x24, 0x53, 0x5d, 0xae, 0xd4, 0x56, 0x28, 0x9e,
		0xa8, 0xe9, 0x49, 0x0a, 0x9f, 0xa0, 0xda, 0x9e, 0x26, 0xdf, 0x19, 0x85, 0x5d, 0xd1, 0xac, 0x6d,
		0x33, 0xaa, 0x61, 0xd3, 0xac, 0x55, 0xd3, 0xae, 0x49, 0x33, 0xb9, 0x1d, 0x32, 0xbf, 0xfd, 0x31,
		0xbd, 0xdd, 0x11, 0xbb, 0xbd, 0x11, 0xbb, 0x9d, 0x11, 0xb9, 0x7d, 0xb1, 0x2b, 0xe7, 0xba, 0xb5,
		0x5b, 0x66, 0x53, 0xf4, 0x25, 0xa6, 0xe6, 0x1b, 0x5e, 0xbd, 0x1a, 0x5f, 0xb1, 0x4a, 0x5c, 0xa5,
		0xca, 0x5d, 0x99, 0x4a, 0x5d, 0x8d, 0x8a, 0x5f, 0x81, 0x8a, 0x5f, 0x75, 0x8a, 0x5e, 0x69, 0xa6,
		0x0b, 0x67, 0x8d, 0xaf, 0x22, 0xe5, 0xa6, 0xce, 0x1b, 0xa6, 0x9a, 0x68, 0xc0, 0x15, 0x0d, 0x83,
		0x10, 0x9b, 0xec, 0xd7, 0xc3, 0xd8, 0x48, 0xfd, 0x64, 0x1d, 0x74, 0x0c, 0x3a, 0x66, 0x6b, 0x75,
		0x8c, 0xdf, 0xf6, 0x82, 0xd8, 0x8f, 0xef, 0x42, 0xef, 0x5a, 0x42, 0xd1, 0x98, 0x38, 0xb5, 0x27,
		0xe3, 0x47, 0xf9, 0xd5, 0x8d, 0x3c, 0xb9, 0x79, 0xb2, 0x47, 0x47, 0x47, 0xcd, 0x8b, 0xe3, 0xf3,
		0x7f, 0x1d, 0x9f, 0x37, 0x2f, 0xff, 0xf8, 0x74, 0x6c, 0xca, 0x84, 0xc3, 0x42, 0xab, 0x48, 0xe4,
		0x02, 0x42, 0xb8, 0x7f, 0xc6, 0xe5, 0xd1, 0xdb, 0xa3, 0xb7, 0x17, 0xa5, 0x2c, 0xb4, 0x08, 0x11,
		0x7e, 0xb3, 0xf3, 0xa3, 0x77, 0x27, 0xbf, 0x5f, 0x6c, 0x7a, 0x20, 0x6b, 0x23, 0x6d, 0xdd, 0x40,
		0xb0, 0x60, 0x61, 0xb0, 0x40, 0x3d, 0x80, 0xae, 0x10, 0x2a, 0x78, 0x26, 0xb8, 0x73, 0x93, 0xc0,
		0xa6, 0x82, 0xfb, 0xa3, 0x17, 0xc5, 0xd4, 0x8f, 0x5a, 0x8a, 0x46, 0x29, 0xf5, 0xa2, 0x92, 0x49,
		0x37, 0x53, 0x93, 0xfd, 0x84, 0xd8, 0xae, 0xa4, 0x14, 0x43, 0x5a, 0x1f, 0x46, 0x4c, 0xc6, 0xc0,
		0xeb, 0xd9, 0x71, 0xf5, 0x27, 0xd6, 0xec, 0xad, 0xea, 0x9e, 0xea, 0xef, 0xe5, 0xea, 0xd7, 0x5d,
		0xfe, 0x12, 0x2b, 0x5e, 0x20, 0x61, 0xa8, 0x4e, 0x29, 0x34, 0x97, 0x30, 0x14, 0x97, 0x38, 0xf4,
		0xa6, 0x82, 0xec, 0xd5, 0x11, 0xbc, 0x2a, 0x52, 0xd7, 0x46, 0xe4, 0xda, 0xc8, 0x5b, 0x0b, 0x61,
		0x67, 0x98, 0xa5, 0xd7, 0x9b, 0x9e, 0x15, 0xac, 0xfc, 0x4c, 0xe1, 0x75, 0x92, 0xbe, 0x86, 0xca,
		0xe3, 0x97, 0x56, 0xca, 0xd2, 0x62, 0x95, 0xb5, 0xf8, 0x65, 0xe7, 0x5f, 0x65, 0xc1, 0x6b, 0x94,
		0xdc, 0x8e, 0x1b, 0xde, 0x2e, 0x2f, 0xf9, 0x98, 0xf2, 0xfb, 0xf8, 0x73, 0x4b, 0x36, 0x62, 0xb5,
		0x44, 0xae, 0x95, 0xc4, 0x24, 0x12, 0xf8, 0x48, 0xf2, 0x56, 0x3d, 0x8c, 0x8a, 0xd0, 0x29, 0x0b,
		0x9b, 0xb2, 0x90, 0xcd, 0x09, 0xd7, 0xe8, 0xd1, 0x85, 0x18, 0x70, 0x5d, 0xc8, 0x78, 0x74, 0x6c,
		0xc9, 0xd5, 0xef, 0xe8, 0xe3, 0xc2, 0xea, 0x77, 0xcf, 0x92, 0xfa, 0x5d, 0xc7, 0x04, 0x39, 0xd6,
		0xc0, 0x6b, 0x98, 0x44, 0x46, 0x09, 0x27, 0xbd, 0x6f, 0x28, 0xb5, 0x26, 0x27, 0x99, 0x70, 0xff,
		0xa6, 0x95, 0x7a, 0xa3, 0x75, 0x49, 0x71, 0xb8, 0xd2, 0x05, 0x9b, 0x72, 0x3c, 0x4f, 0x27, 0x7e,
		0xa7, 0xc5, 0x6e, 0xa6, 0x21, 0x3a, 0xe3, 0x90, 0x9c, 0x71, 0x08, 0x4e, 0x97, 0x1d, 0xed, 0xf8,
		0x67, 0xd6, 0x5d, 0x8a, 0xe1, 0xdb, 0x8d, 0xfe, 0x52, 0xea, 0x03, 0x9b, 0x00, 0xf7, 0x27, 0x50,
		0x4e, 0x7e, 0x5b, 0x5d, 0xb0, 0xfc, 0xb6, 0xa2, 0x50, 0xed, 0x21, 0x54, 0x08, 0x95, 0x51, 0x68,
		0x7a, 0x7a, 0x6a, 0x1d, 0xcf, 0xbd, 0x56, 0x0b, 0x43, 0x4f, 0x35, 0xfb, 0x81, 0xc2, 0x9a, 0x4f,
		0x63, 0xb9, 0x7d, 0xf9, 0x72, 0x04, 0xe8, 0x5f, 0xf9, 0xed, 0x34, 0xa5, 0x52, 0x2d, 0xc3, 0x44,
		0x2b, 0xb3, 0x44, 0xdb, 0xe0, 0x55, 0x90, 0xcd, 0x42, 0xcb, 0xa6, 0x6a, 0x1e, 0x88, 0x8a, 0x09,
		0xd1, 0x37, 0x25, 0x9a, 0x26, 0x45, 0xdb, 0xb4, 0x98, 0xb0, 0xb1, 0x08, 0x3b, 0x9b, 0xb2, 0xb5,
		0x18, 0x7b, 0x8b, 0xb1, 0xb9, 0x14, 0xbb, 0xa7, 0x73, 0x93, 0xa1, 0x7d, 0x7b, 0x6a, 0x9e, 0x99,
		0xa1, 0x99, 0x91, 0x61, 0x27, 0xd9, 0x31, 0xf4, 0x22, 0x4d, 0xbd, 0x3a, 0xed, 0xa8, 0x35, 0xa1,
		0x80, 0xa4, 0x23, 0xe9, 0x48, 0x7a, 0x66, 0x25, 0x3d, 0xf2, 0xbe, 0x79, 0xa1, 0x1f, 0xdf, 0x19,
		0x64, 0x36, 0x4f, 0x28, 0x20, 0xe9, 0x48, 0x7a, 0x21, 0x25, 0xdd, 0x2c, 0x13, 0xca, 0x24, 0x03,
		0x4a, 0x26, 0xf3, 0x69, 0xfa, 0x22, 0x67, 0x9f, 0x8e, 0x3f, 0xbe, 0x3d, 0xfb, 0xf8, 0xdb, 0xc9,
		0xfb, 0xe6, 0xd1, 0xe9, 0xd1, 0xf9, 0x87, 0xe6, 0xc5, 0xf1, 0xbf, 0x8e, 0xcf, 0x4f, 0x2e, 0xff,
		0xd0, 0xe5, 0x24, 0x81, 0x9c, 0x27, 0xa1, 0x64, 0xae, 0x0f, 0x27, 0x1f, 0xcf, 0xce, 0x0d, 0x92,
		0xf4, 0x5e, 0x6c, 0xfa, 0x05, 0x7e, 0xff, 0xf8, 0xcf, 0x8f, 0x67, 0xff, 0xfd, 0x31, 0xcf, 0xaf,
		0xf0, 0xe1, 0xe8, 0xff, 0xcb, 0xf7, 0x19, 0xbc, 0x3d, 0x3f, 0xb9, 0x3c, 0x79, 0x7b, 0x74, 0x9a,
		0xe7, 0x77, 0xf8, 0xef, 0xa3, 0xf3, 0x8f, 0x27, 0x1f, 0xdf, 0xa7, 0x9d, 0xaf, 0xda, 0xb0, 0xad,
		0xf5, 0xad, 0xa0, 0x9f, 0xd8, 0xfb, 0x1e, 0xeb, 0x23, 0x9f, 0xe1, 0x6a, 0x50, 0x0f, 0xa8, 0x07,
		0xff, 0x26, 0xb3, 0xfe, 0x4d, 0xec, 0xdf, 0x7a, 0x4e, 0x2b, 0xf4, 0xdc, 0xd8, 0x33, 0x88, 0x58,
		0x3e, 0xa2, 0x82, 0xc4, 0x23, 0xf1, 0x85, 0x94, 0xf8, 0x01, 0x97, 0xc7, 0x7e, 0xeb, 0xcf, 0xa8,
		0x5e, 0x35, 0x10, 0x7b, 0x8d, 0x2e, 0x64, 0xa5, 0xdf, 0x83, 0xd1, 0xbc, 0x98, 0x52, 0xe0, 0x06,
		0xdd, 0xc8, 0x6b, 0x75, 0x83, 0xb6, 0x16, 0xeb, 0x99, 0x0d, 0x9b, 0x32, 0xeb, 0x0e, 0x21, 0x50,
		0x17, 0x25, 0xd2, 0x4c, 0x58, 0x6a, 0xd8, 0x93, 0xe4, 0x34, 0x9f, 0x7b, 0xb3, 0x76, 0x19, 0x99,
		0xdb, 0x5a, 0xd9, 0xa6, 0x1d, 0xe2, 0xbb, 0x9d, 0x52, 0x55, 0x49, 0x23, 0x0b, 0xf6, 0xfd, 0xae,
		0xe7, 0x39, 0x26, 0x97, 0x91, 0x13, 0x02, 0x58, 0x75, 0xac, 0x7a, 0x21, 0xad, 0x7a, 0x3f, 0xf0,
		0xbb, 0x81, 0x09, 0x8c, 0xd7, 0xe8, 0x3c, 0x6d, 0xd6, 0x59, 0xba, 0x08, 0x05, 0xf2, 0x2f, 0x36,
		0xf5, 0xe6, 0x85, 0x2f, 0xdb, 0x9d, 0x0b, 0x62, 0x5f, 0xfe, 0xf1, 0xe9, 0xb8, 0x79, 0xf2, 0xae,
		0xb8, 0xf5, 0xbb, 0xa7, 0x67, 0x85, 0x2c, 0xde, 0x3d, 0x3a, 0x29, 0xe4, 0x6b, 0x1d, 0xff, 0x9f,
		0x4f, 0x97, 0x45, 0x7c, 0xaf, 0xb3, 0x4b, 0x0a, 0xad, 0x37, 0x07, 0x89, 0xf3, 0x9b, 0xde, 0xae,
		0x50, 0x96, 0x6d, 0xbb, 0xaa, 0x75, 0x5c, 0x76, 0xbd, 0x16, 0xed, 0xab, 0x15, 0x5b, 0xab, 0x17,
		0x59, 0x8b, 0x14, 0x57, 0xab, 0x15, 0x55, 0x6f, 0xac, 0x3a, 0x72, 0x86, 0x15, 0x4a, 0x89, 0x92,
		0xa0, 0x17, 0xd5, 0x1b, 0x0e, 0x57, 0xe7, 0xb3, 0xbc, 0x72, 0x85, 0x57, 0x91, 0xac, 0x5a, 0xb2,
		0xd5, 0xe9, 0xb6, 0xfe, 0x5c, 0x5f, 0x2c, 0x39, 0xfa, 0x98, 0x61, 0xad, 0xe4, 0x9e, 0x4c, 0xad,
		0x64, 0x74, 0x97, 0xcf, 0x42, 0xc9, 0xc1, 0x73, 0xa7, 0x55, 0x25, 0x99, 0xb0, 0xc0, 0x4d, 0xad,
		0xb0, 0x2d, 0x2b, 0x75, 0x92, 0xab, 0x19, 0x40, 0x37, 0xa6, 0xb0, 0xf9, 0x22, 0xc9, 0x95, 0x0c,
		0x22, 0x63, 0xa3, 0x12, 0x57, 0x48, 0xc6, 0xfe, 0xad, 0xf7, 0x57, 0x37, 0xf0, 0x1c, 0xa5, 0x56,
		0x8c, 0x8f, 0x82, 0xfd, 0x0f, 0xcb, 0x8b, 0x51, 0xda, 0x95, 0x8c, 0xed, 0x4c, 0x43, 0x5a, 0xd9,
		0xab, 0x1d, 0x49, 0xc4, 0x96, 0x76, 0xa0, 0xa4, 0x7e, 0x51, 0xd7, 0x23, 0x06, 0x54, 0x1d, 0xa9,
		0xa9, 0x18, 0x9e, 0xc9, 0x6b, 0xbb, 0x94, 0xa1, 0x51, 0x4f, 0x54, 0x20, 0x4a, 0xa7, 0x14, 0x4c,
		0x10, 0x26, 0x08, 0x13, 0x84, 0x09, 0xc2, 0x04, 0x59, 0x30, 0x41, 0x39, 0x6e, 0x70, 0xb4, 0xca,
		0x31, 0x5e, 0x1e, 0x72, 0x78, 0x3b, 0x5c, 0x65, 0xe2, 0xb6, 0xaf, 0xf6, 0xef, 0x92, 0xf9, 0x75,
		0x38, 0xee, 0xd9, 0x73, 0xdc, 0xdb, 0xdd, 0x5b, 0xd7, 0x0f, 0x92, 0x99, 0xbc, 0xe9, 0xde, 0xce,
		0x2e, 0x4a, 0x86, 0x9f, 0xf6, 0x70, 0xe1, 0xf3, 0x8a, 0x9f, 0x12, 0x1b, 0x24, 0x0d, 0xf6, 0xd8,
		0x51, 0x1c, 0xf8, 0x59, 0x3a, 0xf5, 0x82, 0x9b, 0xa1, 0x8a, 0x4c, 0x76, 0xad, 0xa9, 0xd6, 0x5b,
		0x54, 0x03, 0xb8, 0xe8, 0xe5, 0xcd, 0x4c, 0x13, 0xaf, 0x14, 0xd7, 0x19, 0x64, 0x55, 0xdd, 0xab,
		0x35, 0x4b, 0x4d, 0x7d, 0x2b, 0x2a, 0xb5, 0xfd, 0x14, 0x37, 0x43, 0x08, 0xe3, 0x24, 0x98, 0x03,
		0xaa, 0x3c, 0x6a, 0xb6, 0xf4, 0x9f, 0xe7, 0xcf, 0x9f, 0x3f, 0xff, 0xec, 0x3a, 0x7f, 0x1d, 0x39,
		0xff, 0xde, 0x73, 0x0e, 0x9b, 0x8d, 0x99, 0xff, 0xb8, 0xba, 0x72, 0x9a, 0x8d, 0xdd, 0x1f, 0x7b,
		0x2f, 0xea, 0xe5, 0xfb, 0xdd, 0x5f, 0x1e, 0x7e, 0xdf, 0xb8, 0xba, 0x7a, 0xb9, 0xfb, 0x77, 0x9d,
		0x55, 0xbf, 0xec, 0xfe, 0x1c, 0xac, 0x4d, 0x30, 0x8c, 0x32, 0xd1, 0xcb, 0xea, 0x0c, 0x2f, 0xcd,
		0xee, 0x1b, 0x5b, 0x88, 0x51, 0x7c, 0xed, 0x46, 0xb1, 0x9a, 0xb1, 0x9d, 0xae, 0xc0, 0xd2, 0x62,
		0x69, 0xb1, 0xb4, 0x58, 0x5a, 0x2c, 0x2d, 0x96, 0x16, 0x4b, 0xbb, 0xd6, 0xd2, 0x76, 0xba, 0x37,
		0x7e, 0xe0, 0x7c, 0x71, 0x83, 0xc0, 0x0b, 0x93, 0x5b, 0xdb, 0x47, 0xab, 0xb0, 0xb8, 0x58, 0xdc,
		0x27, 0xfb, 0x9d, 0x38, 0x15, 0x3b, 0x61, 0x40, 0x55, 0x8f, 0xb7, 0x6f, 0xbb, 0x71, 0x5b, 0x99,
		0xb5, 0x67, 0x17, 0xc1, 0xd9, 0x70, 0xf6, 0xe6, 0x38, 0x7b, 0xb3, 0x11, 0xf4, 0x15, 0xf7, 0xcf,
		0x09, 0x83, 0xe1, 0xbd, 0x7e, 0x82, 0x7e, 0xff, 0xc3, 0x4f, 0x65, 0xa3, 0xdb, 0x3f, 0x81, 0xf0,
		0x04, 0x19, 0x6c, 0xbd, 0xbe, 0x42, 0xfa, 0x5a, 0xaf, 0x4f, 0xee, 0x1a, 0x89, 0x03, 0xe3, 0x0f,
		0xfa, 0x41, 0xdb, 0xfb, 0xae, 0xd1, 0x83, 0x7c, 0xb8, 0x8c, 0x44, 0x01, 0x15, 0xd7, 0x97, 0x44,
		0x01, 0x75, 0x0b, 0x3f, 0xef, 0xe3, 0x6c, 0xaa, 0x01, 0xf9, 0x90, 0xe1, 0xe9, 0x41, 0x8e, 0x60,
		0x16, 0x5a, 0x30, 0x95, 0xbb, 0x8f, 0x7f, 0x75, 0xc3, 0xf6, 0xff, 0xba, 0xa1, 0xe7, 0xf8, 0x41,
		0xec, 0x85, 0x61, 0xbf, 0x67, 0xd0, 0xc5, 0x6b, 0x01, 0x2d, 0xbd, 0x5e, 0x00, 0xe5, 0x9c, 0xf5,
		0x02, 0x50, 0x63, 0x74, 0x53, 0x86, 0x17, 0x63, 0x7c, 0x31, 0x01, 0x10, 0x11, 0x04, 0x35, 0x81,
		0xd0, 0x88, 0x78, 0x6b, 0x09, 0xc8, 0x74, 0xa1, 0xfb, 0xed, 0xc6, 0xbc, 0x6d, 0xe8, 0x80, 0x08,
		0x03, 0xd4, 0x07, 0xac, 0x11, 0xdf, 0xf5, 0xbc, 0x88, 0x11, 0xea, 0x1a, 0x42, 0x35, 0xda, 0xb9,
		0xad, 0x1b, 0xa2, 0xde, 0xf3, 0xc2, 0x96, 0x17, 0xc4, 0xee, 0x8d, 0x27, 0xd0, 0x8c, 0xc1, 0xa4,
		0x17, 0x83, 0x59, 0x67, 0xac, 0xc9, 0x1f, 0xf3, 0x92, 0x72, 0x91, 0x4e, 0x59, 0x42, 0xea, 0x65,
		0x8e, 0x9c, 0x50, 0xe7, 0xac, 0x29, 0x3d, 0xc1, 0x9e, 0x4e, 0x86, 0x2c, 0xfd, 0xf8, 0x08, 0x04,
		0x3a, 0x6a, 0xd9, 0x3e, 0x82, 0xf2, 0x5e, 0x96, 0x0f, 0xe1, 0xd9, 0x66, 0x56, 0x37, 0xd2, 0x1a,
		0x17, 0xaf, 0x01, 0x0b, 0xfd, 0x20, 0x8a, 0xdd, 0x20, 0x36, 0x47, 0x1b, 0x13, 0x42, 0x20, 0x0e,
		0x10, 0x07, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0x00, 0x71, 0x80, 0x38, 0x40, 0x1c, 0x0b, 0x10, 0x47,
		0xec, 0x85, 0xdf, 0xdc, 0x8e, 0x04, 0xe4, 0x18, 0x53, 0x02, 0x73, 0x80, 0x39, 0xc0, 0x1c, 0xca,
		0x3c, 0x13, 0xc5, 0x6e, 0xec, 0x18, 0x0a, 0xd1, 0x8e, 0x59, 0x0b, 0xf1, 0x29, 0x09, 0xa1, 0x56,
		0xe2, 0xc0, 0x18, 0x60, 0x4c, 0x3e, 0x61, 0x8c, 0x78, 0x6b, 0x72, 0x70, 0x4d, 0xba, 0xb8, 0xe6,
		0xd6, 0x80, 0xcb, 0x1e, 0x52, 0x57, 0xdd, 0xef, 0xa0, 0x19, 0xd0, 0x0c, 0x68, 0x86, 0x08, 0x0a,
		0xd0, 0x03, 0xe8, 0x41, 0x04, 0x05, 0xa4, 0xb1, 0x10, 0x69, 0x38, 0xb1, 0x7f, 0xeb, 0x89, 0xc0,
		0x8d, 0x11, 0x25, 0x30, 0x07, 0x98, 0x03, 0xcc, 0xa1, 0xcc, 0x33, 0x66, 0xa3, 0xd7, 0x88, 0x9f,
		0x00, 0x62, 0x00, 0x31, 0xc4, 0x4f, 0x40, 0x35, 0x43, 0x54, 0x63, 0x20, 0xe8, 0x0f, 0x80, 0xc6,
		0x0f, 0xc0, 0x32, 0x60, 0x19, 0xb0, 0x0c, 0xf1, 0x13, 0xa0, 0x07, 0xd0, 0x83, 0xf8, 0x09, 0x48,
		0x63, 0x21, 0xd2, 0x90, 0x8a, 0x9f, 0x4c, 0x28, 0x81, 0x39, 0xc0, 0x1c, 0x60, 0x0e, 0xe2, 0x27,
		0x80, 0x18, 0x40, 0x0c, 0xf1, 0x13, 0x50, 0x8d, 0x29, 0xaa, 0xb1, 0x5a, 0x96, 0xac, 0x39, 0x47,
		0x74, 0xba, 0x3e, 0x71, 0x03, 0xaa, 0x5e, 0x3f, 0x1a, 0xfc, 0xdf, 0xb8, 0x2b, 0x86, 0x71, 0xc5,
		0xfe, 0xce, 0xf2, 0xb1, 0x0f, 0xbd, 0x7e, 0xf3, 0x1f, 0x63, 0xf2, 0x27, 0x53, 0xea, 0xb6, 0x86,
		0xba, 0x2a, 0xb4, 0x99, 0xf0, 0xdb, 0x1d, 0x4f, 0xbf, 0xc7, 0xc1, 0x70, 0x35, 0x5d, 0x0d, 0xec,
		0x01, 0x46, 0xba, 0x1a, 0xd0, 0xd5, 0x00, 0x6f, 0x0b, 0x6f, 0x6b, 0x3b, 0xbc, 0x2d, 0x22, 0xbc,
		0x38, 0x47, 0x38, 0x47, 0x3a, 0xce, 0x11, 0x11, 0xde, 0x0d, 0xfa, 0x42, 0x74, 0x35, 0x00, 0x71,
		0x80, 0x38, 0x40, 0x1c, 0x20, 0x0e, 0x10, 0x07, 0x88, 0x03, 0xc4, 0x91, 0x51, 0xc4, 0x41, 0x57,
		0x03, 0x30, 0x07, 0x98, 0x83, 0xae, 0x06, 0xb3, 0x24, 0xb8, 0x55, 0x06, 0xc6, 0x6c, 0x35, 0x8c,
		0xe1, 0x56, 0x39, 0xe7, 0xb8, 0x86, 0xae, 0x06, 0xa0, 0x19, 0xd0, 0x0c, 0x11, 0x14, 0xa0, 0x07,
		0xd0, 0x83, 0x08, 0x0a, 0x48, 0xc3, 0x2a, 0xd2, 0xa0, 0xab, 0x01, 0x98, 0x03, 0xcc, 0x41, 0x56,
		0x3e, 0xf1, 0x13, 0x40, 0x0c, 0x20, 0x86, 0xf8, 0x49, 0x11, 0x50, 0x0d, 0x5d, 0x0d, 0xc0, 0x32,
		0x60, 0x19, 0xe2, 0x27, 0x40, 0x0f, 0xa0, 0x07, 0xf1, 0x13, 0x90, 0x86, 0x4d, 0xa4, 0x41, 0x57,
		0x03, 0x30, 0x07, 0x98, 0x83, 0xf8, 0x09, 0xf1, 0x13, 0x40, 0x0c, 0x20, 0x86, 0xf8, 0x49, 0xd6,
		0x50, 0x4d, 0x11, 0xbb, 0x1a, 0x68, 0xd4, 0xe8, 0xef, 0xac, 0xec, 0x63, 0x70, 0x32, 0x20, 0x98,
		0x85, 0xd6, 0x05, 0x41, 0xdb, 0xfb, 0x6e, 0xd0, 0xbb, 0x60, 0xb8, 0x5c, 0xaf, 0x79, 0xc1, 0x1e,
		0xcd, 0x0b, 0xd2, 0xc4, 0x83, 0xdb, 0xd4, 0xbc, 0x40, 0x1b, 0xe5, 0x4d, 0xcf, 0xbb, 0x1f, 0x0c,
		0x54, 0x8c, 0xc6, 0x71, 0x4f, 0x3a, 0x73, 0x1c, 0x6a, 0xac, 0x1d, 0x3f, 0xb6, 0x1e, 0xee, 0x12,
		0x80, 0xb4, 0x5e, 0xd0, 0xbf, 0xf5, 0xc2, 0x91, 0x76, 0x35, 0x87, 0xb4, 0xe5, 0xaa, 0x01, 0x8d,
		0xe3, 0xa0, 0x7f, 0x3b, 0x38, 0xc1, 0x54, 0xbd, 0x03, 0x81, 0x2d, 0xec, 0xfb, 0x41, 0xbc, 0x5f,
		0x11, 0xd8, 0xbd, 0x03, 0x00, 0x3c, 0x00, 0x7e, 0x4b, 0x00, 0x7c, 0xb5, 0x72, 0x58, 0x3d, 0xac,
		0x1f, 0x54, 0x0e, 0x81, 0xed, 0x1b, 0x83, 0xed, 0x8d, 0x0c, 0x80, 0xd1, 0x3f, 0xbd, 0x30, 0xf0,
		0x3a, 0xfa, 0x68, 0x74, 0xbc, 0x9e, 0x5e, 0x5a, 0xc0, 0xd1, 0x4c, 0xc1, 0x51, 0x7a, 0x69, 0x11,
		0xe3, 0xb7, 0x22, 0x44, 0xe2, 0xc2, 0xb4, 0x4c, 0xa8, 0xc8, 0x2b, 0x20, 0xaf, 0x00, 0x44, 0x0f,
		0xa2, 0x4f, 0x7a, 0x04, 0xe4, 0x15, 0x6c, 0x10, 0xca, 0xd3, 0x4b, 0x0b, 0xc4, 0x01, 0xe2, 0x00,
		0x71, 0x80, 0x38, 0x40, 0x1c, 0x20, 0x0e, 0x10, 0x47, 0x56, 0x11, 0x07, 0xbd, 0xb4, 0xc0, 0x1c,
		0x60, 0x0e, 0x7a, 0x69, 0xcd, 0x92, 0x20, 0x97, 0x11, 0x18, 0xb3, 0xd5, 0x30, 0x86, 0x5c, 0xc6,
		0x9c, 0xe3, 0x1a, 0x7a, 0x69, 0x81, 0x66, 0x40, 0x33, 0x44, 0x50, 0x80, 0x1e, 0x40, 0x0f, 0x22,
		0x28, 0x20, 0x0d, 0xab, 0x48, 0x83, 0x5e, 0x5a, 0x60, 0x0e, 0x30, 0x07, 0xb5, 0xa0, 0xc4, 0x4f,
		0x00, 0x31, 0x80, 0x18, 0xe2, 0x27, 0x45, 0x40, 0x35, 0xf4, 0xd2, 0x02, 0xcb, 0x80, 0x65, 0x88,
		0x9f, 0x00, 0x3d, 0x80, 0x1e, 0xc4, 0x4f, 0x40, 0x1a, 0x36, 0x91, 0x06, 0xbd, 0xb4, 0xc0, 0x1c,
		0x60, 0x0e, 0xe2, 0x27, 0xc4, 0x4f, 0x00, 0x31, 0x80, 0x18, 0xe2, 0x27, 0x59, 0x43, 0x35, 0x45,
		0xec, 0xa5, 0xa5, 0x55, 0xa5, 0xbf, 0xb3, 0xb2, 0x9b, 0xd6, 0x3f, 0x47, 0x24, 0x33, 0xd0, 0xc2,
		0x20, 0xf0, 0x35, 0x70, 0xcb, 0xd4, 0x0e, 0x0e, 0x57, 0xd3, 0xbe, 0xc0, 0x1e, 0x32, 0xa4, 0x7d,
		0x01, 0xed, 0x0b, 0x70, 0xab, 0x70, 0xab, 0xb6, 0xc3, 0xad, 0x22, 0x94, 0x8b, 0x17, 0x84, 0x17,
		0xa4, 0xe3, 0x05, 0x11, 0xca, 0xdd, 0xa0, 0xd3, 0x43, 0xfb, 0x02, 0x10, 0x07, 0x88, 0x03, 0xc4,
		0x01, 0xe2, 0x00, 0x71, 0x80, 0x38, 0x40, 0x1c, 0x19, 0x45, 0x1c, 0xb4, 0x2f, 0x00, 0x73, 0x80,
		0x39, 0x68, 0x5f, 0x30, 0x4b, 0x82, 0xeb, 0x63, 0x60, 0xcc, 0x56, 0xc3, 0x18, 0xae, 0x8f, 0x73,
		0x8e, 0x6b, 0x68, 0x5f, 0x00, 0x9a, 0x01, 0xcd, 0x10, 0x41, 0x01, 0x7a, 0x00, 0x3d, 0x88, 0xa0,
		0x80, 0x34, 0xac, 0x22, 0x0d, 0xda, 0x17, 0x80, 0x39, 0xc0, 0x1c, 0xa4, 0xdf, 0x13, 0x3f, 0x01,
		0xc4, 0x00, 0x62, 0x88, 0x9f, 0x14, 0x01, 0xd5, 0xd0, 0xbe, 0x00, 0x2c, 0x03, 0x96, 0x21, 0x7e,
		0x02, 0xf4, 0x00, 0x7a, 0x10, 0x3f, 0x01, 0x69, 0xd8, 0x44, 0x1a, 0xb4, 0x2f, 0x00, 0x73, 0x80,
		0x39, 0x88, 0x9f, 0x10, 0x3f, 0x01, 0xc4, 0x00, 0x62, 0x88, 0x9f, 0x64, 0x0d, 0xd5, 0x14, 0xb1,
		0x7d, 0x81, 0x46, 0x8d, 0xfe, 0xce, 0xca, 0xe6, 0x05, 0x1f, 0x07, 0x04, 0x33, 0xd0, 0xba, 0x20,
		0xea, 0x5e, 0xc7, 0xff, 0xeb, 0x86, 0xde, 0x28, 0x97, 0x32, 0xec, 0xf7, 0x62, 0xfd, 0x46, 0x06,
		0x0b, 0x68, 0xd1, 0xd6, 0xc0, 0x1e, 0x62, 0xa4, 0xad, 0x01, 0x6d, 0x0d, 0x70, 0xb7, 0x70, 0xb7,
		0xb6, 0xc3, 0xdd, 0x22, 0xc4, 0x8b, 0x77, 0x84, 0x77, 0xa4, 0xe3, 0x1d, 0x11, 0xe2, 0xdd, 0xa0,
		0x33, 0x44, 0x5b, 0x03, 0x10, 0x07, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0x00, 0x71, 0x80, 0x38, 0x40,
		0x1c, 0x19, 0x45, 0x1c, 0xb4, 0x35, 0x00, 0x73, 0x80, 0x39, 0x68, 0x6b, 0x30, 0x4b, 0x82, 0x6b,
		0x65, 0x60, 0xcc, 0x56, 0xc3, 0x18, 0xae, 0x95, 0x73, 0x8e, 0x6b, 0x68, 0x6b, 0x00, 0x9a, 0x01,
		0xcd, 0x10, 0x41, 0x01, 0x7a, 0x00, 0x3d, 0x88, 0xa0, 0x80, 0x34, 0xac, 0x22, 0x0d, 0xda, 0x1a,
		0x80, 0x39, 0xc0, 0x1c, 0xa4, 0xe5, 0x13, 0x3f, 0x01, 0xc4, 0x00, 0x62, 0x88, 0x9f, 0x14, 0x01,
		0xd5, 0xd0, 0xd6, 0x00, 0x2c, 0x03, 0x96, 0x21, 0x7e, 0x02, 0xf4, 0x00, 0x7a, 0x10, 0x3f, 0x01,
		0x69, 0xd8, 0x44, 0x1a, 0xb4, 0x35, 0x00, 0x73, 0x80, 0x39, 0x88, 0x9f, 0x10, 0x3f, 0x01, 0xc4,
		0x00, 0x62, 0x88, 0x9f, 0x64, 0x0d, 0xd5, 0x14, 0xb1, 0xad, 0x81, 0x71, 0xc5, 0xfe, 0xce, 0xca,
		0x26, 0x07, 0x17, 0x63, 0xf2, 0x27, 0x53, 0xea, 0x19, 0xe8, 0x78, 0x10, 0x77, 0x63, 0x8d, 0x4c,
		0xe7, 0x07, 0xfb, 0x38, 0x5c, 0x4e, 0x5f, 0x03, 0x7b, 0x90, 0x91, 0xbe, 0x06, 0xf4, 0x35, 0xc0,
		0xdf, 0xc2, 0xdf, 0xda, 0x0e, 0x7f, 0x8b, 0x18, 0x2f, 0xee, 0x11, 0xee, 0x91, 0x8e, 0x7b, 0x44,
		0x8c, 0x77, 0x83, 0xde, 0x10, 0x7d, 0x0d, 0x40, 0x1c, 0x20, 0x0e, 0x10, 0x07, 0x88, 0x03, 0xc4,
		0x01, 0xe2, 0x00, 0x71, 0x64, 0x14, 0x71, 0xd0, 0xd7, 0x00, 0xcc, 0x01, 0xe6, 0xa0, 0xaf, 0xc1,
		0x2c, 0x09, 0xee, 0x95, 0x81, 0x31, 0x5b, 0x0d, 0x63, 0xb8, 0x57, 0xce, 0x39, 0xae, 0xa1, 0xaf,
		0x01, 0x68, 0x06, 0x34, 0x43, 0x04, 0x05, 0xe8, 0x01, 0xf4, 0x20, 0x82, 0x02, 0xd2, 0xb0, 0x8a,
		0x34, 0xe8, 0x6b, 0x00, 0xe6, 0x00, 0x73, 0x90, 0x97, 0x4f, 0xfc, 0x04, 0x10, 0x03, 0x88, 0x21,
		0x7e, 0x52, 0x04, 0x54, 0x43, 0x5f, 0x03, 0xb0, 0x0c, 0x58, 0x86, 0xf8, 0x09, 0xd0, 0x03, 0xe8,
		0x41, 0xfc, 0x04, 0xa4, 0x61, 0x13, 0x69, 0xd0, 0xd7, 0x00, 0xcc, 0x01, 0xe6, 0x20, 0x7e, 0x42,
		0xfc, 0x04, 0x10, 0x03, 0x88, 0x21, 0x7e, 0x92, 0x35, 0x54, 0x53, 0xc4, 0xbe, 0x06, 0x3a, 0x45,
		0xfa, 0x3b, 0x2b, 0x5b, 0x19, 0x5c, 0x0e, 0x29, 0x66, 0xa0, 0x7d, 0x41, 0x3f, 0xf2, 0x42, 0xfd,
		0xee, 0x05, 0xc3, 0xd5, 0x34, 0x2f, 0xb0, 0x87, 0x0b, 0x69, 0x5e, 0x40, 0xf3, 0x02, 0x9c, 0x2a,
		0x9c, 0xaa, 0xed, 0x70, 0xaa, 0x08, 0xe4, 0xe2, 0x03, 0xe1, 0x03, 0xe9, 0xf8, 0x40, 0x04, 0x72,
		0x37, 0xe8, 0xf2, 0xd0, 0xbc, 0x00, 0xc4, 0x01, 0xe2, 0x00, 0x71, 0x80, 0x38, 0x40, 0x1c, 0x20,
		0x0e, 0x10, 0x47, 0x46, 0x11, 0x07, 0xcd, 0x0b, 0xc0, 0x1c, 0x60, 0x0e, 0x9a, 0x17, 0xcc, 0x92,
		0xe0, 0xf2, 0x18, 0x18, 0xb3, 0xd5, 0x30, 0x86, 0xcb, 0xe3, 0x9c, 0xe3, 0x1a, 0x9a, 0x17, 0x80,
		0x66, 0x40, 0x33, 0x44, 0x50, 0x80, 0x1e, 0x40, 0x0f, 0x22, 0x28, 0x20, 0x0d, 0xab, 0x48, 0x83,
		0xe6, 0x05, 0x60, 0x0e, 0x30, 0x07, 0xc9, 0xf7, 0xc4, 0x4f, 0x00, 0x31, 0x80, 0x18, 0xe2, 0x27,
		0x45, 0x40, 0x35, 0x34, 0x2f, 0x00, 0xcb, 0x80, 0x65, 0x88, 0x9f, 0x00, 0x3d, 0x80, 0x1e, 0xc4,
		0x4f, 0x40, 0x1a, 0x36, 0x91, 0x06, 0xcd, 0x0b, 0xc0, 0x1c, 0x60, 0x0e, 0xe2, 0x27, 0xc4, 0x4f,
		0x00, 0x31, 0x80, 0x18, 0xe2, 0x27, 0x59, 0x43, 0x35, 0x45, 0x6c, 0x5e, 0xa0, 0x51, 0xa3, 0xbf,
		0xb3, 0xb2, 0x77, 0xc1, 0xef, 0x03, 0x82, 0x19, 0x68, 0x5d, 0xf0, 0xbf, 0xae, 0x1f, 0xeb, 0xb7,
		0x2e, 0x18, 0xae, 0xa6, 0x75, 0x81, 0x3d, 0x54, 0x48, 0xeb, 0x02, 0x5a, 0x17, 0xe0, 0x52, 0xe1,
		0x52, 0x6d, 0x87, 0x4b, 0x45, 0x18, 0x17, 0x0f, 0x08, 0x0f, 0x48, 0xc7, 0x03, 0x22, 0x8c, 0xbb,
		0x41, 0x87, 0x87, 0xd6, 0x05, 0x20, 0x0e, 0x10, 0x07, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0x00, 0x71,
		0x80, 0x38, 0x32, 0x8a, 0x38, 0x68, 0x5d, 0x00, 0xe6, 0x00, 0x73, 0xd0, 0xba, 0x60, 0x96, 0x04,
		0x57, 0xc7, 0xc0, 0x98, 0xad, 0x86, 0x31, 0x5c, 0x1d, 0xe7, 0x1c, 0xd7, 0xd0, 0xba, 0x00, 0x34,
		0x03, 0x9a, 0x21, 0x82, 0x02, 0xf4, 0x00, 0x7a, 0x10, 0x41, 0x01, 0x69, 0x58, 0x45, 0x1a, 0xb4,
		0x2e, 0x00, 0x73, 0x80, 0x39, 0x48, 0xbd, 0x27, 0x7e, 0x02, 0x88, 0x01, 0xc4, 0x10, 0x3f, 0x29,
		0x02, 0xaa, 0xa1, 0x75, 0x01, 0x58, 0x06, 0x2c, 0x43, 0xfc, 0x04, 0xe8, 0x01, 0xf4, 0x20, 0x7e,
		0x02, 0xd2, 0xb0, 0x89, 0x34, 0x68, 0x5d, 0x00, 0xe6, 0x00, 0x73, 0x10, 0x3f, 0x21, 0x7e, 0x02,
		0x88, 0x01, 0xc4, 0x10, 0x3f, 0xc9, 0x1a, 0xaa, 0x29, 0x62, 0xeb, 0x02, 0x8d, 0x1a, 0xfd, 0x9d,
		0x95, 0xad, 0x0b, 0xfe, 0x7b, 0x40, 0xd0, 0x56, 0xeb, 0x82, 0x67, 0x82, 0x3b, 0xaf, 0xbb, 0xe3,
		0x9a, 0x3b, 0x9d, 0x6c, 0x4f, 0xd6, 0xbf, 0xe1, 0xea, 0x4f, 0xac, 0x79, 0xf7, 0x01, 0x06, 0x1b,
		0x25, 0x69, 0xb7, 0xbd, 0x75, 0xf0, 0xab, 0x74, 0xea, 0x47, 0xf1, 0x51, 0x1c, 0x27, 0xab, 0x96,
		0x1f, 0x98, 0xb4, 0xe3, 0x8e, 0x37, 0x40, 0x4f, 0x51, 0x32, 0x4d, 0x38, 0xd0, 0xc0, 0x33, 0x2b,
		0xf4, 0x74, 0x5d, 0xe9, 0x2c, 0x6c, 0x7b, 0xa1, 0xd7, 0xfe, 0x75, 0xf0, 0x5a, 0x41, 0xbf, 0xd3,
		0x31, 0xda, 0x1d, 0x45, 0x8e, 0x50, 0xe6, 0x84, 0x04, 0x82, 0xb6, 0x54, 0xb0, 0x56, 0xf3, 0xcf,
		0x72, 0xae, 0x58, 0xfc, 0x2f, 0x4b, 0x76, 0x22, 0xe9, 0x0e, 0x28, 0xbd, 0xf9, 0xe2, 0x27, 0x9f,
		0x7f, 0xae, 0x05, 0xcf, 0x54, 0x6a, 0x07, 0xd1, 0xd2, 0x07, 0x99, 0x02, 0xd6, 0xc1, 0x87, 0x96,
		0xbc, 0xcf, 0xea, 0x76, 0x22, 0x6b, 0x7d, 0xb5, 0x24, 0xbe, 0x58, 0xf2, 0x36, 0x20, 0x49, 0x3d,
		0x29, 0x65, 0x4f, 0x49, 0xd9, 0x13, 0x52, 0x6a, 0xd3, 0xa1, 0xc6, 0x41, 0xeb, 0xda, 0x6b, 0x94,
		0x5a, 0x93, 0x3d, 0x5f, 0xb3, 0x09, 0x93, 0x6d, 0x1d, 0x7f, 0x7e, 0x9d, 0x62, 0x4b, 0xd4, 0x37,
		0x26, 0xb1, 0x73, 0xae, 0xe2, 0x84, 0xab, 0xf7, 0x81, 0x51, 0x75, 0xa9, 0xb5, 0x5d, 0x67, 0x6d,
		0x17, 0x59, 0xab, 0x8f, 0x8b, 0x99, 0x69, 0x4a, 0xda, 0x97, 0xa5, 0x14, 0x79, 0x6e, 0xd8, 0xfa,
		0x9a, 0x7c, 0xf3, 0xa6, 0x95, 0x15, 0xa3, 0x75, 0x09, 0x37, 0x40, 0x0d, 0xd2, 0x2b, 0x47, 0x7d,
		0x74, 0xa2, 0x3c, 0xfa, 0x0d, 0x87, 0x74, 0x63, 0x38, 0xc6, 0x31, 0x1b, 0xe3, 0x18, 0x8d, 0x51,
		0x43, 0x21, 0x59, 0xbc, 0xa8, 0x1c, 0x61, 0x79, 0x30, 0x50, 0xdd, 0x5b, 0xd7, 0x0f, 0x9c, 0xa1,
		0x51, 0x57, 0x38, 0xb4, 0x89, 0x4e, 0x53, 0x08, 0xa1, 0x94, 0x4e, 0xbd, 0xe0, 0x66, 0x68, 0x94,
		0xd5, 0x62, 0x1c, 0x1a, 0x0e, 0x87, 0x49, 0x0c, 0xc3, 0x34, 0xc6, 0x3a, 0x75, 0x90, 0x35, 0xd7,
		0x0b, 0x78, 0xbf, 0x3a, 0x31, 0x6e, 0x93, 0x98, 0x83, 0xd4, 0x96, 0x55, 0x6a, 0xfb, 0x1b, 0xdc,
		0x34, 0x4b, 0x8e, 0x61, 0x43, 0x41, 0x42, 0x3e, 0xb9, 0x71, 0xec, 0x85, 0x81, 0xb2, 0x88, 0x94,
		0xfe, 0xf3, 0xfc, 0xf9, 0xf3, 0xe7, 0x9f, 0x5d, 0xe7, 0xaf, 0x23, 0xe7, 0xdf, 0x7b, 0xce, 0x61,
		0xb3, 0x31, 0xf3, 0x1f, 0x57, 0x57, 0x4e, 0xb3, 0xb1, 0xfb, 0x63, 0xef, 0x45, 0xbd, 0x7c, 0xbf,
		0xfb, 0xcb, 0xc3, 0xef, 0x1b, 0x57, 0x57, 0x2f, 0x77, 0xff, 0xae, 0xb3, 0xea, 0x97, 0xdd, 0x9f,
		0x83, 0xb5, 0x7f, 0x2b, 0xd9, 0xd9, 0x84, 0xb3, 0x8b, 0x93, 0xff, 0x29, 0xee, 0x4e, 0x88, 0xea,
		0x7d, 0x25, 0x3f, 0x58, 0xdf, 0x1f, 0x16, 0xf5, 0x8b, 0x17, 0xfa, 0xc7, 0x9a, 0x6d, 0x1c, 0x35,
		0xba, 0x5b, 0x9a, 0xdc, 0x19, 0xcd, 0x62, 0x8e, 0xee, 0xe8, 0xe9, 0x9d, 0x2f, 0x77, 0x3a, 0x31,
		0x2a, 0x89, 0xfb, 0xa1, 0x47, 0xf8, 0xa3, 0x6f, 0xb3, 0x2d, 0x67, 0x26, 0xe2, 0x43, 0xb6, 0x22,
		0x20, 0xed, 0x20, 0x7a, 0x35, 0x76, 0xe4, 0x74, 0xe3, 0x18, 0x2b, 0xfc, 0xea, 0xaf, 0xdd, 0x28,
		0x76, 0xbc, 0x20, 0x0e, 0x7d, 0x2f, 0x4a, 0xee, 0x58, 0x3e, 0x5a, 0x85, 0x7b, 0x89, 0x7b, 0xf9,
		0x84, 0x99, 0xee, 0xd4, 0x5d, 0xcc, 0x99, 0xb5, 0x6a, 0x6e, 0x66, 0x19, 0x37, 0x13, 0x37, 0x53,
		0x8d, 0x51, 0x55, 0x03, 0x6a, 0x66, 0x01, 0x36, 0x43, 0xc6, 0xd5, 0x66, 0x60, 0x13, 0x46, 0x36,
		0x67, 0x68, 0x09, 0x3c, 0xb3, 0x43, 0xa3, 0x66, 0x2d, 0x8f, 0xd9, 0xa0, 0x51, 0x73, 0xc7, 0x77,
		0x23, 0x81, 0x56, 0xcd, 0x43, 0x32, 0x24, 0x91, 0xe9, 0x8b, 0x8d, 0x94, 0xf8, 0x88, 0x8b, 0x91,
		0xb8, 0x38, 0x89, 0x8a, 0x95, 0x9e, 0x78, 0x19, 0x04, 0xa6, 0x76, 0xa4, 0x5b, 0x18, 0x85, 0x7e,
		0x70, 0x23, 0x90, 0x3b, 0x56, 0x7e, 0x9d, 0xea, 0x0e, 0x68, 0x39, 0xfa, 0x72, 0x8e, 0xbf, 0xd5,
		0x40, 0xc0, 0xca, 0xc0, 0xc0, 0xda, 0x8b, 0x73, 0x39, 0x0e, 0xd5, 0x09, 0x9b, 0x0e, 0x50, 0xf5,
		0xf8, 0x42, 0xdc, 0x50, 0xa5, 0x4f, 0x29, 0xa1, 0xd5, 0xd1, 0xea, 0x68, 0xf5, 0x7c, 0x69, 0xf5,
		0x74, 0x1a, 0x61, 0xf6, 0xbe, 0x55, 0x1d, 0xb7, 0xdd, 0x0e, 0xbd, 0x48, 0x00, 0x42, 0x3e, 0xa2,
		0x86, 0xce, 0x41, 0xe7, 0xa0, 0x73, 0xd2, 0x96, 0x9f, 0x1d, 0xcd, 0x9b, 0xf4, 0x79, 0x39, 0xd0,
		0xbc, 0x2d, 0x9b, 0x23, 0xf4, 0x9f, 0xe7, 0xcf, 0x3f, 0xef, 0x39, 0x87, 0x8d, 0x9f, 0x9f, 0xcb,
		0xce, 0x61, 0x63, 0xf4, 0x63, 0x79, 0xf8, 0xd7, 0xe8, 0xe7, 0xca, 0xe7, 0x3d, 0xa7, 0x3a, 0xf9,
		0xb9, 0xf6, 0x79, 0xcf, 0xa9, 0x35, 0x76, 0xaf, 0xae, 0x5e, 0xee, 0xfe, 0xd8, 0xbf, 0x57, 0x5f,
		0xf8, 0x37, 0x7d, 0xa6, 0x69, 0x98, 0x6c, 0x96, 0xc9, 0xfd, 0x62, 0x7e, 0x77, 0x0c, 0x77, 0x05,
		0x77, 0x65, 0xa0, 0xb4, 0xea, 0xa2, 0x10, 0xa2, 0x0e, 0x84, 0x00, 0x42, 0x00, 0x21, 0x36, 0x26,
		0x3f, 0x99, 0x85, 0x10, 0xae, 0x73, 0x7d, 0xe4, 0xfc, 0xd6, 0xf8, 0x51, 0x7e, 0x51, 0xbd, 0x7f,
		0xb3, 0xfb, 0xe3, 0xe0, 0xfe, 0xe9, 0x2f, 0x7f, 0x2e, 0xfa, 0x58, 0xf9, 0xc5, 0xc1, 0xfd, 0x9b,
		0x25, 0xff, 0x52, 0xbf, 0x7f, 0x93, 0x90, 0x46, 0xed, 0xfe, 0xf9, 0xdc, 0x47, 0x07, 0xbf, 0xaf,
		0x2c, 0x5b, 0x50, 0x5d, 0xb2, 0x60, 0x7f, 0xd9, 0x82, 0xfd, 0x25, 0x0b, 0x96, 0x3e, 0x52, 0x65,
		0xc9, 0x82, 0xda, 0xfd, 0xcf, 0xb9, 0xcf, 0x3f, 0x5f, 0xfc, 0xd1, 0xfa, 0xfd, 0xee, 0xcf, 0x65,
		0xff, 0x76, 0x70, 0xff, 0xf3, 0xcd, 0x6e, 0xa1, 0x00, 0x15, 0xfc, 0x93, 0x2f, 0xfe, 0x01, 0x5e,
		0x16, 0x0d, 0x5e, 0x16, 0xa2, 0xa4, 0xb4, 0x1d, 0x44, 0xaf, 0x66, 0x93, 0xa9, 0x1e, 0xfe, 0xe3,
		0x2e, 0x51, 0xd2, 0x97, 0xfe, 0xae, 0xa8, 0xcc, 0xb2, 0xd6, 0xbe, 0x45, 0x30, 0xbd, 0x3d, 0xd0,
		0x84, 0xdf, 0xa4, 0x4a, 0x90, 0x2a, 0x61, 0x1d, 0x2e, 0x4f, 0xcf, 0xbb, 0xe3, 0xb9, 0xd7, 0xa1,
		0x77, 0xad, 0x73, 0xe0, 0x13, 0x64, 0x7c, 0xa0, 0xb1, 0xf6, 0xd3, 0x58, 0xb9, 0xbc, 0x7c, 0x39,
		0xae, 0x47, 0x9f, 0xca, 0x58, 0x06, 0x34, 0xc6, 0xa8, 0x6e, 0x5b, 0x5b, 0x5d, 0x8c, 0x96, 0xa7,
		0x9c, 0x56, 0x55, 0x41, 0x57, 0xa0, 0x2b, 0x56, 0x3e, 0x21, 0x69, 0x55, 0x44, 0xb2, 0x88, 0x64,
		0xe5, 0x30, 0x92, 0x45, 0x5a, 0x15, 0x8e, 0xa4, 0xe0, 0xd9, 0x90, 0x56, 0x85, 0x56, 0x47, 0xab,
		0xa3, 0xd5, 0x49, 0xab, 0x42, 0xe7, 0xa0, 0x73, 0xb6, 0x4a, 0xe7, 0x90, 0x56, 0x45, 0x5a, 0x15,
		0x69, 0x55, 0xb8, 0x2b, 0xa4, 0x55, 0x01, 0x21, 0x80, 0x10, 0x40, 0x88, 0xcd, 0xc8, 0xcf, 0x0e,
		0x69, 0x55, 0xa4, 0xc5, 0x90, 0x56, 0x05, 0xff, 0x90, 0x56, 0x05, 0xbc, 0x94, 0x85, 0x97, 0x85,
		0x4f, 0xab, 0x52, 0x68, 0x29, 0xaf, 0xbe, 0x29, 0xb2, 0xfd, 0x6c, 0xc6, 0x2d, 0xe7, 0x15, 0xef,
		0x08, 0x8a, 0xd3, 0x75, 0x2f, 0x31, 0xdf, 0x67, 0x65, 0x6e, 0xc1, 0x0a, 0xbe, 0x2b, 0x29, 0x65,
		0xcf, 0x2c, 0x68, 0x64, 0xff, 0x2e, 0x88, 0x9a, 0xff, 0xe8, 0x46, 0xf1, 0xf1, 0x90, 0x5a, 0xe1,
		0x5b, 0xde, 0x3d, 0x6a, 0x31, 0x67, 0xa1, 0xf1, 0x5d, 0xe4, 0x85, 0xdf, 0xbc, 0x50, 0xa1, 0xe7,
		0xdd, 0x64, 0x01, 0xed, 0xee, 0x68, 0x77, 0x37, 0xcb, 0x42, 0x3a, 0xdd, 0xd4, 0x87, 0xeb, 0x68,
		0x73, 0x97, 0x62, 0x68, 0x63, 0xab, 0xdb, 0xdc, 0xe9, 0x86, 0xfe, 0x1e, 0x12, 0xcf, 0xb4, 0xa2,
		0x15, 0x64, 0x6f, 0x6f, 0x24, 0x7a, 0x47, 0xf6, 0xb6, 0xca, 0x79, 0x67, 0x25, 0x7b, 0x7b, 0x22,
		0x62, 0x19, 0x48, 0xde, 0xa6, 0x2b, 0x26, 0xca, 0xa2, 0x88, 0xca, 0x42, 0x3f, 0x7d, 0x5b, 0xea,
		0xea, 0x8c, 0x5b, 0x33, 0x6e, 0xcd, 0x36, 0x24, 0x5a, 0xfa, 0x21, 0xc1, 0x9d, 0x8c, 0xdc, 0x9a,
		0x49, 0xde, 0x99, 0x1d, 0x1a, 0xd0, 0x18, 0xbf, 0xd3, 0xc6, 0x27, 0x21, 0x0b, 0xa7, 0x24, 0xcd,
		0xed, 0xd1, 0x6b, 0x01, 0x5a, 0x52, 0xf7, 0x43, 0x53, 0x82, 0x79, 0x49, 0xbc, 0x99, 0xfc, 0x69,
		0x48, 0x6c, 0xa2, 0xe4, 0x4d, 0x5b, 0x7e, 0x77, 0xd2, 0x6c, 0x46, 0xf2, 0x8b, 0x0c, 0x89, 0x6b,
		0x7d, 0xdb, 0xc4, 0x95, 0x6b, 0xdd, 0x5c, 0x5d, 0xeb, 0xe6, 0x46, 0x79, 0xc1, 0x57, 0xf9, 0xe4,
		0xab, 0xa2, 0x8f, 0xbb, 0xd7, 0x08, 0x08, 0xf4, 0xba, 0x61, 0x6c, 0xee, 0x60, 0x0e, 0xa9, 0x68,
		0x62, 0xf5, 0x77, 0xde, 0xb5, 0xdb, 0xef, 0x0c, 0x9d, 0x8c, 0xda, 0x3e, 0x2e, 0x2a, 0x2e, 0x2a,
		0x2e, 0xaa, 0xba, 0xf0, 0x39, 0x41, 0xff, 0xf6, 0x8b, 0xf2, 0xd0, 0xbf, 0x45, 0x22, 0x54, 0x37,
		0x20, 0x71, 0xee, 0x06, 0x37, 0x99, 0xf0, 0x51, 0x4d, 0x26, 0xdd, 0x0a, 0xeb, 0x96, 0x39, 0x72,
		0x93, 0xb1, 0xae, 0x52, 0xf4, 0x04, 0x86, 0xbc, 0x0a, 0x7b, 0x2d, 0x3b, 0xa6, 0x93, 0x73, 0xd3,
		0x3a, 0x82, 0x7a, 0xad, 0xb6, 0x5f, 0xcb, 0xf0, 0x31, 0x14, 0x1d, 0xaf, 0x14, 0x26, 0xe9, 0x6f,
		0x9c, 0xa4, 0x33, 0xfe, 0x3b, 0x43, 0x2d, 0xd4, 0x68, 0x88, 0x64, 0x19, 0x73, 0x71, 0xa3, 0xb6,
		0x01, 0xd1, 0xe6, 0x46, 0x0d, 0x77, 0x05, 0x77, 0x85, 0x1b, 0x35, 0x6e, 0xd4, 0x12, 0xed, 0x11,
		0x37, 0x6a, 0xdc, 0xa8, 0x71, 0xa3, 0x66, 0x43, 0x5c, 0xb9, 0x51, 0xe3, 0xe6, 0x83, 0x1b, 0x35,
		0xf8, 0x8a, 0x1b, 0xb5, 0x82, 0x46, 0xa8, 0xb8, 0x51, 0xc3, 0x45, 0xc5, 0x45, 0xdd, 0x36, 0x17,
		0x95, 0x1b, 0xb5, 0xb9, 0x07, 0xe1, 0x46, 0x6d, 0x67, 0x83, 0x5e, 0xcb, 0x0e, 0x37, 0x6a, 0xdc,
		0xa8, 0x6d, 0x3c, 0xec, 0xbe, 0xc1, 0x1b, 0xb5, 0xfc, 0x75, 0xcf, 0x50, 0x0b, 0x0c, 0x14, 0xa7,
		0x79, 0x86, 0xe6, 0x4d, 0x63, 0x3f, 0x52, 0xb6, 0xb5, 0x26, 0xa0, 0x6c, 0x16, 0x88, 0x75, 0x47,
		0x4f, 0xef, 0x7c, 0xb9, 0xd3, 0xb9, 0xff, 0x93, 0x00, 0x60, 0x8f, 0x40, 0xd7, 0x70, 0x27, 0x72,
		0xc1, 0xe9, 0x69, 0xb4, 0x35, 0x79, 0xac, 0x07, 0x44, 0xba, 0x99, 0x5c, 0x8c, 0x48, 0x15, 0xbe,
		0x95, 0xc9, 0xa4, 0x73, 0x88, 0x8d, 0x2e, 0x26, 0x89, 0xd2, 0x0a, 0x94, 0xd2, 0x08, 0x94, 0x3b,
		0x98, 0x54, 0xe8, 0x60, 0x22, 0xee, 0xc8, 0xa5, 0xd6, 0xc1, 0xc4, 0x0d, 0x5b, 0x5f, 0x75, 0x3a,
		0x98, 0x0c, 0xd7, 0xa9, 0x75, 0x30, 0xd9, 0xa3, 0x83, 0x09, 0x1d, 0x4c, 0x34, 0x23, 0x04, 0xd3,
		0xf3, 0x6a, 0x77, 0x6f, 0x5d, 0x3f, 0x70, 0x14, 0x47, 0xa6, 0xe8, 0x5c, 0xe9, 0x94, 0x4e, 0xbd,
		0xe0, 0x66, 0xa8, 0xde, 0xd5, 0x7c, 0x7e, 0x0d, 0x0c, 0x64, 0xe2, 0xd3, 0x9b, 0xc6, 0x07, 0x27,
		0x0e, 0x63, 0x59, 0x73, 0xbd, 0x80, 0x73, 0xa8, 0x13, 0xdc, 0x35, 0xf1, 0xc1, 0xa5, 0xb6, 0xac,
		0x52, 0xdb, 0xdf, 0xe0, 0xa6, 0x59, 0x42, 0xa6, 0x0a, 0x37, 0x54, 0xda, 0x97, 0x9b, 0xa5, 0xff,
		0x3c, 0x7f, 0xfe, 0xfc, 0xf9, 0x67, 0xd7, 0xf9, 0xeb, 0xc8, 0xf9, 0xf7, 0x9e, 0x73, 0xd8, 0x6c,
		0xcc, 0xfc, 0xc7, 0xd5, 0x95, 0xd3, 0x6c, 0xec, 0xfe, 0xd8, 0x7b, 0x51, 0x2f, 0xdf, 0xef, 0xfe,
		0xf2, 0xf0, 0xfb, 0xc6, 0xd5, 0xd5, 0xcb, 0xdd, 0xbf, 0xeb, 0xac, 0xfa, 0x65, 0xf7, 0xe7, 0x60,
		0xad, 0xc2, 0x35, 0x8b, 0xd2, 0x26, 0x98, 0x5c, 0xc7, 0x65, 0x7f, 0x27, 0x44, 0xf5, 0x3e, 0xce,
		0x35, 0xce, 0x75, 0x66, 0x9c, 0xeb, 0x3c, 0x7b, 0x94, 0xeb, 0xa3, 0x70, 0x2b, 0xfc, 0xc9, 0x67,
		0x0a, 0xaf, 0x93, 0xf4, 0x35, 0x54, 0x1e, 0xbf, 0xb4, 0xd2, 0xa1, 0x5d, 0x1c, 0x2c, 0x58, 0xfc,
		0xb2, 0xf3, 0xaf, 0xb2, 0xe0, 0x35, 0x4a, 0x37, 0x61, 0xaf, 0xe5, 0xac, 0x69, 0xd6, 0x38, 0x15,
		0xd1, 0xd9, 0x0f, 0x2f, 0xd9, 0x92, 0xd5, 0x0e, 0xf2, 0x5a, 0xff, 0x25, 0x89, 0xbf, 0xf2, 0xc4,
		0x3f, 0x71, 0x6e, 0x6f, 0x6e, 0x57, 0xdd, 0x42, 0x27, 0x55, 0x12, 0xca, 0x4e, 0x88, 0xb2, 0xe0,
		0x2f, 0x70, 0x32, 0x46, 0x0f, 0x2f, 0xc4, 0x8e, 0xeb, 0x5c, 0xdb, 0xa4, 0xcd, 0xcb, 0xd4, 0x9a,
		0x95, 0x65, 0xa8, 0xab, 0xeb, 0x3a, 0x56, 0xc8, 0x75, 0x60, 0x64, 0x0d, 0xab, 0xa4, 0x1c, 0x1d,
		0x69, 0x79, 0x61, 0xec, 0x5f, 0xfb, 0x2d, 0x37, 0xf6, 0x1c, 0xbf, 0xad, 0x1e, 0x25, 0x79, 0xb2,
		0xbe, 0x30, 0xd1, 0x92, 0xa4, 0x2c, 0x58, 0xc8, 0x90, 0x49, 0x42, 0x16, 0xcd, 0x5a, 0xdc, 0x44,
		0x79, 0x56, 0xa6, 0xe2, 0x6c, 0xcc, 0x04, 0x68, 0x2a, 0x81, 0xce, 0xf2, 0x02, 0xf7, 0x4b, 0xc7,
		0x53, 0x97, 0xb4, 0xf1, 0xba, 0xa4, 0xfd, 0x73, 0x1f, 0xd2, 0xb2, 0x06, 0x2c, 0x81, 0x60, 0x22,
		0x98, 0x9b, 0x13, 0xcc, 0x2f, 0xdd, 0x6e, 0xc7, 0x73, 0x03, 0x1d, 0xc9, 0x2c, 0xa7, 0x28, 0x99,
		0x1d, 0x3f, 0x8a, 0xbd, 0x60, 0x92, 0x65, 0xef, 0x45, 0xea, 0x32, 0x3a, 0x47, 0x01, 0xb1, 0x43,
		0xec, 0x36, 0x26, 0x76, 0xfd, 0x60, 0xe0, 0xd1, 0x6a, 0x08, 0x9d, 0x42, 0x9d, 0x9b, 0x5e, 0x5d,
		0x9b, 0x41, 0xf1, 0xb4, 0x51, 0x45, 0x9f, 0x49, 0x25, 0x9f, 0x59, 0x05, 0x1f, 0x63, 0x79, 0x97,
		0xc6, 0x86, 0x19, 0xcb, 0x5b, 0xcc, 0x1d, 0x4b, 0x33, 0x1f, 0x9b, 0x91, 0x95, 0x2b, 0x99, 0x85,
		0x8a, 0x27, 0x46, 0x56, 0xc2, 0x3f, 0x8c, 0xac, 0x14, 0xba, 0x7c, 0xd2, 0xfb, 0x1e, 0x45, 0xd5,
		0x6e, 0x80, 0x11, 0xbd, 0xa0, 0x7f, 0xeb, 0x85, 0xa3, 0x0b, 0x1d, 0x03, 0x90, 0x58, 0xd5, 0x58,
		0x7b, 0x1c, 0xf4, 0x6f, 0x07, 0x68, 0xdd, 0x5a, 0xea, 0x02, 0x77, 0xd5, 0x13, 0x62, 0x7a, 0x53,
		0x14, 0x45, 0x22, 0x05, 0xb7, 0x5e, 0xec, 0xb6, 0xdd, 0xd8, 0x75, 0xdc, 0x7e, 0xfc, 0xd5, 0x0b,
		0x62, 0xbf, 0xa5, 0x96, 0x99, 0x3c, 0xe5, 0xd4, 0x65, 0x84, 0xd4, 0xa3, 0x7c, 0xd7, 0x6e, 0x27,
		0x22, 0xcc, 0x47, 0xbc, 0x81, 0x30, 0xdf, 0xba, 0xef, 0x54, 0xaa, 0x99, 0xd6, 0xa9, 0x91, 0x9e,
		0x15, 0xcb, 0xc3, 0xfd, 0xfd, 0x43, 0xa4, 0x12, 0xa9, 0xdc, 0x9c, 0x54, 0xea, 0xd5, 0x17, 0x6b,
		0xd4, 0x13, 0x6b, 0xd6, 0x0f, 0xe7, 0x34, 0x97, 0x78, 0x8f, 0x5c, 0x62, 0xd5, 0x2d, 0x33, 0xa8,
		0xd7, 0xcd, 0x74, 0x36, 0x71, 0x8a, 0xb6, 0x2b, 0x0e, 0xdd, 0x20, 0x1a, 0x4a, 0x74, 0xe4, 0xb5,
		0xfa, 0xa1, 0x1f, 0xdf, 0xa9, 0x5b, 0xb2, 0x05, 0x34, 0xb8, 0x54, 0xc6, 0xae, 0x81, 0x36, 0xd5,
		0x25, 0x36, 0x93, 0xc9, 0xb3, 0x33, 0xd9, 0x9d, 0x89, 0x9a, 0x43, 0x53, 0x95, 0x49, 0x06, 0xa2,
		0x3c, 0x77, 0x93, 0x81, 0x88, 0x4d, 0xda, 0x3a, 0x9b, 0x44, 0x06, 0x22, 0x60, 0x11, 0xc1, 0x04,
		0x2c, 0xea, 0x4a, 0x26, 0x19, 0x88, 0x88, 0x1d, 0x19, 0x88, 0x64, 0x20, 0x4a, 0xbe, 0xa9, 0xfe,
		0x1b, 0x2f, 0x78, 0x73, 0x32, 0x10, 0xc9, 0x40, 0x24, 0x03, 0xd1, 0x9e, 0x78, 0x91, 0x81, 0x48,
		0x06, 0x19, 0x19, 0x88, 0xf0, 0x0f, 0x19, 0x88, 0x36, 0xbe, 0x87, 0x0c, 0x44, 0x81, 0xad, 0x27,
		0x03, 0x71, 0x4a, 0x8c, 0x0c, 0x44, 0x32, 0x10, 0x89, 0x37, 0x10, 0xe6, 0x53, 0x15, 0x5e, 0x32,
		0x10, 0x91, 0xca, 0x2d, 0x92, 0x4a, 0x32, 0x10, 0x4d, 0xa4, 0x6c, 0x6e, 0x39, 0x19, 0x88, 0xda,
		0x5b, 0x46, 0x06, 0xa2, 0xb1, 0xed, 0x22, 0x03, 0x11, 0xbb, 0x86, 0x5d, 0x23, 0x03, 0x31, 0x69,
		0x06, 0x62, 0x8e, 0xdb, 0x78, 0xae, 0x6f, 0x93, 0xb9, 0xb3, 0xb4, 0x9d, 0xe7, 0xfb, 0xb0, 0xd7,
		0x5a, 0x35, 0xfb, 0x23, 0x59, 0x57, 0xcf, 0x8e, 0xdf, 0xf2, 0x82, 0xc8, 0x5b, 0xdf, 0xd1, 0x73,
		0xf2, 0xc1, 0x6c, 0x74, 0xf3, 0x5c, 0xfd, 0x34, 0x3b, 0x99, 0x6e, 0xe6, 0x39, 0x79, 0xf6, 0xb4,
		0x7a, 0x79, 0x8e, 0xbf, 0x2f, 0x4a, 0x9e, 0x4a, 0x3b, 0x5d, 0x91, 0x8f, 0x7e, 0x9e, 0xeb, 0x99,
		0x41, 0xd7, 0xa6, 0x6d, 0x3e, 0x99, 0x76, 0x2d, 0xb3, 0xc8, 0xe8, 0xe9, 0xc4, 0xb9, 0xb4, 0xeb,
		0xf4, 0x85, 0xa6, 0xfe, 0xd0, 0x64, 0xad, 0x8d, 0xe1, 0x29, 0xb5, 0xb7, 0x29, 0x16, 0x9c, 0x4a,
		0xcc, 0x92, 0x76, 0xd0, 0x54, 0x52, 0x56, 0x9d, 0x2e, 0x48, 0xd8, 0xcb, 0x78, 0xe9, 0x71, 0x27,
		0xea, 0x6d, 0x6c, 0xc8, 0xc0, 0xda, 0x8c, 0x6c, 0xc2, 0xd0, 0x32, 0x8c, 0x6d, 0xca, 0xe0, 0x62,
		0x8c, 0x2e, 0xc6, 0xf0, 0x62, 0x8c, 0xaf, 0xe9, 0x95, 0x2b, 0x9e, 0xbc, 0xaa, 0x40, 0x4c, 0x17,
		0xba, 0xad, 0xd8, 0xff, 0xe6, 0x99, 0x0f, 0xf7, 0x1e, 0xd3, 0x31, 0x1f, 0xef, 0xad, 0x72, 0xbf,
		0x23, 0x1d, 0xc0, 0xc9, 0xda, 0x84, 0x6f, 0x7d, 0x41, 0x94, 0x12, 0x48, 0x71, 0xc1, 0x14, 0x17,
		0x50, 0x71, 0x41, 0xd5, 0x13, 0x58, 0x83, 0x98, 0xe5, 0x8e, 0xec, 0xa4, 0x6f, 0xf5, 0x78, 0x81,
		0x61, 0xfc, 0xc0, 0x7c, 0xe3, 0x74, 0x02, 0xbd, 0xe3, 0xf3, 0x75, 0xda, 0x6e, 0xec, 0x9a, 0xab,
		0xaf, 0x47, 0xd4, 0x50, 0x3e, 0x28, 0x1f, 0x94, 0x8f, 0x16, 0xdf, 0xa8, 0xa6, 0xe2, 0x2f, 0x55,
		0x3d, 0x87, 0x06, 0x34, 0x8c, 0x12, 0xd8, 0x27, 0x7f, 0xcc, 0x87, 0xd2, 0x3f, 0x68, 0x64, 0x3f,
		0x70, 0xc3, 0xbb, 0x92, 0xc0, 0xbc, 0xfc, 0xf1, 0xee, 0x1c, 0x9a, 0xcd, 0x7c, 0x7f, 0x91, 0x95,
		0x8d, 0x51, 0x2e, 0x64, 0x5c, 0xcb, 0x36, 0xaf, 0x8b, 0x3e, 0x0d, 0xdf, 0xc0, 0x52, 0x2a, 0x94,
		0x3d, 0xaf, 0xb5, 0x93, 0x89, 0x4b, 0xa0, 0xb1, 0x92, 0x58, 0x49, 0xac, 0xa4, 0xb4, 0xde, 0x33,
		0xd4, 0x77, 0xf7, 0x19, 0x8b, 0x5e, 0x68, 0x4e, 0xdd, 0x9f, 0xae, 0x4f, 0x7a, 0xd5, 0x36, 0x66,
		0xb8, 0xc9, 0xdf, 0xd1, 0xf4, 0x17, 0x49, 0x1a, 0x98, 0xe8, 0x6f, 0x89, 0xc2, 0x76, 0x98, 0x28,
		0x6b, 0x73, 0x25, 0xad, 0xa9, 0x9c, 0x09, 0x58, 0x12, 0xb0, 0x54, 0x15, 0x79, 0x6d, 0x65, 0xfa,
		0xc0, 0xe5, 0x9e, 0x7b, 0x1d, 0x7a, 0xd7, 0x26, 0x85, 0x0f, 0x07, 0x1a, 0x6b, 0x3f, 0x8d, 0xb5,
		0xcc, 0xcb, 0x97, 0xa3, 0xa4, 0x83, 0x57, 0x33, 0xd2, 0x96, 0x01, 0xfd, 0x91, 0xac, 0x61, 0xd2,
		0x0a, 0xcb, 0xb4, 0xbe, 0x81, 0xd2, 0xd2, 0xed, 0xd4, 0xd5, 0x1a, 0x15, 0xb4, 0x06, 0x5a, 0x23,
		0xd1, 0x53, 0x72, 0xcd, 0x81, 0x0f, 0x85, 0x0f, 0x85, 0x0f, 0xb5, 0x3d, 0xd7, 0x1c, 0x6d, 0x2f,
		0x6a, 0x85, 0x7e, 0x4f, 0xdb, 0x37, 0x7a, 0xb4, 0x67, 0xb3, 0xc4, 0x50, 0x3d, 0xa8, 0x1e, 0x54,
		0xcf, 0xb6, 0x84, 0x6f, 0x34, 0x34, 0x8f, 0xf7, 0xbd, 0xe7, 0x8f, 0x6a, 0xcb, 0x9d, 0xb6, 0x8e,
		0x4f, 0x31, 0xb7, 0x6d, 0x4f, 0x09, 0xa2, 0x81, 0xd0, 0x40, 0x68, 0x20, 0x2d, 0xbe, 0xe9, 0xfb,
		0x41, 0x5c, 0xaf, 0x0a, 0x68, 0x20, 0x93, 0xe6, 0x3d, 0x7a, 0x65, 0x90, 0x4f, 0xff, 0x08, 0x5c,
		0x27, 0x9a, 0x94, 0x49, 0x0a, 0xab, 0x97, 0x39, 0x72, 0x86, 0x65, 0x94, 0x73, 0xf4, 0x04, 0xea,
		0x03, 0x85, 0xd8, 0xf9, 0xf1, 0x11, 0xb8, 0xdf, 0x33, 0x7f, 0x04, 0x66, 0x6d, 0x38, 0x52, 0x3f,
		0x15, 0x6e, 0xb2, 0x17, 0x43, 0x12, 0xaf, 0x2d, 0x04, 0x45, 0x3c, 0xee, 0xb0, 0x81, 0x20, 0x40,
		0x10, 0xe2, 0x2f, 0xab, 0x9e, 0xd1, 0x0f, 0x9c, 0x7e, 0x24, 0xe0, 0xfc, 0x8c, 0xe9, 0xa0, 0x70,
		0x50, 0x38, 0x28, 0x1c, 0x14, 0xce, 0x0a, 0x85, 0x13, 0x45, 0x7d, 0x4f, 0x28, 0xe2, 0x32, 0x43,
		0x0b, 0xc5, 0x83, 0xe2, 0x41, 0xf1, 0x10, 0x6c, 0x21, 0xd8, 0x42, 0xb0, 0x85, 0x60, 0x0b, 0xc1,
		0x96, 0xf5, 0xdb, 0x4c, 0x81, 0x1d, 0x60, 0x04, 0x30, 0x92, 0x39, 0x30, 0x42, 0x81, 0xdd, 0x02,
		0xd7, 0x90, 0x02, 0xbb, 0xc5, 0x1b, 0x43, 0x81, 0x5d, 0x9a, 0x96, 0x92, 0x02, 0x3b, 0xac, 0x24,
		0x56, 0x92, 0x0c, 0xad, 0xb4, 0xf4, 0xce, 0x37, 0xb7, 0x23, 0xa1, 0x72, 0x46, 0x64, 0xd0, 0x36,
		0x68, 0x1b, 0xb4, 0x8d, 0x1e, 0xfc, 0xcc, 0xe1, 0xcd, 0x44, 0xb1, 0xeb, 0x79, 0x13, 0xb4, 0x03,
		0xd6, 0xdf, 0x11, 0xd9, 0x56, 0x86, 0xff, 0xf4, 0xee, 0xb4, 0x70, 0xdf, 0x36, 0xce, 0x34, 0x4a,
		0xda, 0x3e, 0x55, 0x8f, 0xfd, 0x8c, 0xd9, 0xae, 0xa4, 0x54, 0xa7, 0xb9, 0xa0, 0x9d, 0xf3, 0xe9,
		0x88, 0xce, 0xe4, 0xef, 0x52, 0xa1, 0xdb, 0x77, 0x3f, 0xdd, 0xc5, 0x7c, 0x76, 0xef, 0x4e, 0xd0,
		0x84, 0x7a, 0xd5, 0x51, 0x1b, 0xb5, 0xed, 0xee, 0xde, 0xdc, 0x0c, 0x50, 0xee, 0xfa, 0xb6, 0xdd,
		0xe3, 0x0f, 0x66, 0xa4, 0x6d, 0x77, 0xf7, 0x26, 0x9f, 0x2d, 0xbb, 0xbb, 0x37, 0xa9, 0xb5, 0xeb,
		0x6e, 0x75, 0x83, 0xa8, 0xdb, 0xf1, 0x92, 0x77, 0xeb, 0x9e, 0x2c, 0xc8, 0x49, 0xb3, 0xee, 0xee,
		0x4d, 0x31, 0x1b, 0x75, 0x77, 0x6f, 0x32, 0xd3, 0xa4, 0x5b, 0xb1, 0xe3, 0xb1, 0x5e, 0xa7, 0xe3,
		0xcc, 0xb7, 0xe8, 0xee, 0xde, 0x6c, 0x67, 0x7b, 0xee, 0xee, 0xcd, 0xa6, 0x5a, 0x73, 0x5b, 0x07,
		0x5f, 0x23, 0x63, 0xf6, 0x6a, 0xac, 0xf1, 0x94, 0x5a, 0xf7, 0xc8, 0xcc, 0x26, 0x8a, 0xbc, 0x8e,
		0xd7, 0x8a, 0xbb, 0x61, 0xa4, 0x2e, 0x5c, 0x0f, 0x4b, 0x91, 0x2f, 0xe4, 0x4b, 0x4b, 0xbe, 0x94,
		0x5b, 0xdf, 0x4f, 0x78, 0xce, 0xa0, 0x29, 0xcc, 0x84, 0xc2, 0x96, 0xb4, 0xbf, 0xef, 0xde, 0xd0,
		0x13, 0xc6, 0x94, 0xe9, 0xd3, 0x09, 0x34, 0x69, 0xf7, 0x83, 0xd1, 0x9c, 0x07, 0x61, 0x86, 0x96,
		0x84, 0x04, 0x24, 0xbb, 0xc1, 0xf3, 0xee, 0x0d, 0x81, 0xf3, 0xb4, 0x04, 0x6b, 0x33, 0x41, 0x73,
		0x5d, 0x81, 0x9b, 0x12, 0xb8, 0x76, 0x5b, 0x7e, 0x47, 0x65, 0x9c, 0xe3, 0x5a, 0xc6, 0x9b, 0x52,
		0x34, 0x3c, 0x14, 0x99, 0x44, 0x48, 0x63, 0xa1, 0x94, 0x14, 0x4e, 0x79, 0x21, 0x95, 0x16, 0x56,
		0x6b, 0x42, 0x6b, 0x4d, 0x78, 0xad, 0x08, 0xb1, 0x99, 0x30, 0x1b, 0x0a, 0xf5, 0xf4, 0x8d, 0x8c,
		0x6f, 0xc4, 0xe6, 0xf8, 0xcd, 0x6f, 0x7b, 0x41, 0xec, 0xc7, 0x77, 0x7a, 0x7d, 0x1a, 0x97, 0xda,
		0x4b, 0x81, 0x4c, 0xe2, 0xd2, 0xc9, 0xf8, 0xd1, 0x7e, 0x75, 0x23, 0x41, 0x36, 0x9e, 0xbc, 0xf8,
		0xc5, 0x1f, 0x17, 0xa7, 0x67, 0xef, 0x9b, 0xbf, 0x1d, 0xbd, 0x3d, 0x39, 0x3d, 0xb9, 0xfc, 0xa3,
		0x24, 0x99, 0x5d, 0x1d, 0x19, 0xa7, 0xde, 0xcd, 0xfe, 0xf9, 0x21, 0x46, 0x69, 0xc1, 0x06, 0x94,
		0xc4, 0x88, 0xdf, 0xbf, 0xc8, 0xfa, 0x1b, 0x9f, 0x9e, 0xbd, 0x3d, 0x3a, 0xad, 0x6e, 0xdd, 0x1b,
		0x97, 0xb7, 0xe9, 0x8d, 0x8f, 0x7e, 0x7f, 0x77, 0x72, 0xb9, 0x5d, 0x2f, 0x7c, 0xf9, 0x8f, 0x4f,
		0xe7, 0x27, 0xff, 0xda, 0x3a, 0xb6, 0x3e, 0xd8, 0xa6, 0x37, 0x7e, 0x7b, 0xf6, 0xf1, 0xe2, 0xec,
		0xf4, 0x78, 0x9b, 0x5e, 0xf9, 0xf7, 0x8b, 0xe3, 0xf3, 0xad, 0x63, 0xea, 0xfd, 0x6d, 0x53, 0x5d,
		0x5b, 0x77, 0xc2, 0xf5, 0x6d, 0x7a, 0xe3, 0x7f, 0x1e, 0x9f, 0x7f, 0x3c, 0x3e, 0xdd, 0xa6, 0x37,
		0xbe, 0xf8, 0xe3, 0xe2, 0xf2, 0xf8, 0x43, 0xf3, 0xdd, 0xd1, 0xf1, 0x87, 0xb3, 0x8f, 0x5b, 0xc7,
		0xdc, 0x95, 0xad, 0x7b, 0xe3, 0xbd, 0xad, 0x52, 0xd8, 0xa7, 0x5b, 0x25, 0xcb, 0x1f, 0x8e, 0x4e,
		0xb6, 0xea, 0x7d, 0x3f, 0x5e, 0x7e, 0xda, 0x3a, 0xf9, 0xad, 0x09, 0xbe, 0xb1, 0x08, 0xa5, 0x46,
		0x6e, 0x4b, 0xe5, 0x0d, 0x4e, 0xbc, 0x14, 0x79, 0xdf, 0xbc, 0x50, 0xf4, 0xd2, 0x61, 0x4a, 0x91,
		0x4b, 0x87, 0xb5, 0x7b, 0xc5, 0xa5, 0x03, 0x97, 0x0e, 0xcb, 0xdf, 0x48, 0xfe, 0xd2, 0x21, 0xba,
		0x8b, 0x3a, 0xdd, 0x1b, 0x47, 0x48, 0x44, 0x67, 0xc5, 0xb4, 0x5c, 0x15, 0xa0, 0x75, 0x1c, 0xf4,
		0x6f, 0x07, 0x2f, 0xbc, 0x31, 0x45, 0x9a, 0xea, 0x85, 0xb1, 0x61, 0x29, 0xd0, 0x83, 0x0a, 0xd7,
		0x4c, 0x0f, 0x9c, 0x66, 0xdc, 0x4d, 0x7f, 0xd2, 0x1a, 0xf6, 0xa7, 0xbf, 0x79, 0x3a, 0x85, 0x9d,
		0xc6, 0x97, 0xe4, 0x52, 0x97, 0xe3, 0x85, 0x2b, 0xef, 0x24, 0x43, 0x25, 0x7d, 0x3b, 0x93, 0xd7,
		0xb2, 0x4e, 0xfd, 0x01, 0x83, 0x73, 0x76, 0xe3, 0xc0, 0x80, 0xc6, 0xdc, 0xc0, 0xc1, 0xa9, 0x4c,
		0x67, 0x58, 0x83, 0x19, 0x23, 0x6e, 0x29, 0xa4, 0x8d, 0x06, 0x43, 0x83, 0xa1, 0xc1, 0x32, 0xa6,
		0xc1, 0xa6, 0x32, 0x9d, 0x65, 0x0d, 0x16, 0x8b, 0xb4, 0xe0, 0xd5, 0x19, 0xa8, 0x3a, 0xb7, 0xf9,
		0xa6, 0xba, 0xab, 0x82, 0xee, 0x42, 0x77, 0xa5, 0xa2, 0xbb, 0xc8, 0x0f, 0x26, 0x54, 0x47, 0xa8,
		0x8e, 0x50, 0x5d, 0x42, 0x7e, 0x23, 0x3f, 0x98, 0xfc, 0x60, 0x99, 0x3f, 0xe4, 0x07, 0x67, 0xf4,
		0x8d, 0xc9, 0x0f, 0x2e, 0xf6, 0x0b, 0x93, 0x1f, 0x5c, 0xfc, 0x37, 0x26, 0x3f, 0x78, 0x3b, 0x98,
		0x9a, 0xfc, 0xe0, 0xa2, 0x9f, 0x30, 0xf9, 0xc1, 0x85, 0x7e, 0x63, 0xf2, 0x83, 0xb7, 0xeb, 0x8d,
		0xc9, 0x0f, 0x2e, 0xee, 0xeb, 0x92, 0x1f, 0x5c, 0x7c, 0xf9, 0x25, 0x3f, 0x58, 0x6c, 0x35, 0xf9,
		0xc1, 0x2b, 0xc8, 0x70, 0xe9, 0xa0, 0xb7, 0xfb, 0x5c, 0x3a, 0x90, 0x1f, 0xac, 0x20, 0xa6, 0xe4,
		0x07, 0xab, 0x33, 0x6c, 0xf6, 0xf2, 0x83, 0x35, 0x86, 0x07, 0xe8, 0xef, 0x9d, 0xdd, 0xfe, 0x78,
		0xe3, 0xe1, 0x02, 0x93, 0x2b, 0xf0, 0x1d, 0x4d, 0x9e, 0xd7, 0x9b, 0x35, 0x30, 0x5d, 0xad, 0x3d,
		0x73, 0xe0, 0x81, 0x82, 0xe0, 0xec, 0x81, 0x29, 0x51, 0xad, 0x19, 0x04, 0xba, 0x27, 0x91, 0xda,
		0x48, 0x8c, 0xb5, 0xfc, 0x5d, 0xd2, 0x4a, 0x86, 0x5a, 0xd4, 0xc2, 0x7e, 0xf4, 0x55, 0xcd, 0xb7,
		0xa3, 0xaf, 0x6a, 0x5e, 0x4c, 0xbe, 0x20, 0x17, 0x73, 0x37, 0xd2, 0xee, 0x53, 0xfc, 0xd0, 0xfa,
		0x37, 0xcd, 0x56, 0xc5, 0x4a, 0x49, 0x6c, 0x5a, 0x49, 0x6b, 0xda, 0x2d, 0x8a, 0x2b, 0xb4, 0x28,
		0x96, 0x84, 0x84, 0x5b, 0xdc, 0x02, 0x5c, 0xc1, 0x60, 0xe7, 0x76, 0x58, 0xca, 0xe3, 0x57, 0x2e,
		0x25, 0x92, 0xfd, 0xf5, 0x3a, 0x5b, 0x7b, 0xe6, 0xca, 0x8a, 0x01, 0x1e, 0xa1, 0x77, 0xdb, 0x8d,
		0x3d, 0x27, 0xf2, 0xc2, 0x6f, 0x5e, 0x82, 0x1e, 0xe9, 0x53, 0x59, 0x7d, 0xb2, 0x8e, 0x49, 0x16,
		0x4c, 0xb2, 0x58, 0xc0, 0x50, 0xea, 0xc6, 0xec, 0xf1, 0x72, 0xfa, 0xee, 0x63, 0xd4, 0xb4, 0x8c,
		0x9a, 0x72, 0xdf, 0x7d, 0xcd, 0x16, 0xe3, 0x66, 0xad, 0xc5, 0xe9, 0xb9, 0xbf, 0x91, 0x00, 0x1f,
		0x3d, 0xf7, 0x13, 0x2c, 0xfc, 0xda, 0x8d, 0x62, 0xf3, 0x82, 0x9a, 0x21, 0x15, 0x6a, 0x01, 0xa9,
		0xa7, 0xd9, 0x50, 0x54, 0x3c, 0xaf, 0xb5, 0x80, 0x06, 0x72, 0xf3, 0xc8, 0xb0, 0x1c, 0x1a, 0xd0,
		0x18, 0xbf, 0x8d, 0x59, 0x72, 0xba, 0x64, 0xf9, 0x41, 0xcf, 0x71, 0xdb, 0xed, 0xd0, 0x8b, 0x22,
		0xc9, 0x4b, 0x80, 0x43, 0x01, 0x5a, 0x22, 0x3b, 0x25, 0xb7, 0x63, 0x0b, 0x76, 0xee, 0x5b, 0x55,
		0x70, 0xef, 0xe6, 0xf6, 0xf0, 0xb5, 0x20, 0xcd, 0x4f, 0x6e, 0x1c, 0x7b, 0x61, 0x20, 0x5a, 0x15,
		0x31, 0x24, 0xfc, 0x9f, 0xe7, 0xcf, 0x3f, 0xef, 0x39, 0x87, 0x8d, 0x9f, 0x9f, 0xcb, 0xce, 0x61,
		0x63, 0xf4, 0x63, 0x79, 0xf8, 0xd7, 0xe8, 0xe7, 0xca, 0xe7, 0x3d, 0xa7, 0x3a, 0xf9, 0xb9, 0xf6,
		0x79, 0xcf, 0xa9, 0x35, 0x76, 0xaf, 0xae, 0x5e, 0xee, 0xfe, 0xd8, 0xbf, 0x57, 0x5f, 0xf8, 0x37,
		0xb9, 0x54, 0x81, 0x86, 0xe4, 0xe6, 0x9e, 0x5d, 0x9c, 0xfc, 0x0f, 0x3b, 0xfc, 0x74, 0x87, 0x45,
		0x28, 0x09, 0x25, 0xb1, 0xd8, 0x11, 0xff, 0x3a, 0xe2, 0x3f, 0x62, 0x4e, 0xd7, 0xb9, 0x3e, 0x72,
		0x7e, 0x6b, 0xfc, 0x28, 0xbf, 0xa8, 0xde, 0xbf, 0xd9, 0xfd, 0x71, 0x70, 0xff, 0xf4, 0x97, 0x3f,
		0x17, 0x7d, 0xac, 0xfc, 0xe2, 0xe0, 0xfe, 0xcd, 0x92, 0x7f, 0xa9, 0xdf, 0xbf, 0x49, 0x48, 0xa3,
		0x76, 0xff, 0x7c, 0xee, 0xa3, 0x83, 0xdf, 0x57, 0x96, 0x2d, 0xa8, 0x2e, 0x59, 0xb0, 0xbf, 0x6c,
		0xc1, 0xfe, 0x92, 0x05, 0x4b, 0x1f, 0xa9, 0xb2, 0x64, 0x41, 0xed, 0xfe, 0xe7, 0xdc, 0xe7, 0x9f,
		0x2f, 0xfe, 0x68, 0xfd, 0x7e, 0xf7, 0xe7, 0xb2, 0x7f, 0x3b, 0xb8, 0xff, 0xf9, 0x66, 0x77, 0xab,
		0x95, 0x21, 0xfc, 0x96, 0x6f, 0x7e, 0x93, 0x31, 0x0d, 0xcf, 0x36, 0xfb, 0x1c, 0x86, 0xa6, 0x49,
		0x10, 0xc3, 0xb7, 0xbb, 0xb7, 0xae, 0x1f, 0x38, 0xc3, 0x7b, 0x0e, 0x41, 0x10, 0x2f, 0x60, 0x81,
		0x4a, 0xa7, 0x5e, 0x70, 0x33, 0xbc, 0xd8, 0xc9, 0x1c, 0x8c, 0xff, 0xe0, 0x07, 0x62, 0x59, 0x72,
		0x42, 0xd1, 0x95, 0xa5, 0x64, 0x87, 0x35, 0xcd, 0xfa, 0x5d, 0x50, 0x96, 0xd2, 0xfd, 0x2d, 0x74,
		0x5b, 0xb1, 0xdf, 0x0d, 0xde, 0xf9, 0x37, 0xfe, 0x28, 0x31, 0x25, 0x8b, 0xd9, 0xc7, 0xa5, 0x0f,
		0xee, 0xf7, 0xdc, 0x1d, 0x55, 0xa5, 0xb6, 0x9f, 0xa3, 0xc3, 0xca, 0x8a, 0x42, 0x16, 0xd0, 0x38,
		0xd2, 0xd8, 0x63, 0x80, 0x39, 0x9e, 0x3f, 0xff, 0xec, 0x3a, 0x7f, 0x1d, 0x39, 0xff, 0xde, 0x73,
		0x0e, 0x9b, 0x8d, 0x99, 0xff, 0xb8, 0xba, 0x72, 0x9a, 0x8d, 0xdd, 0x1f, 0x7b, 0x2f, 0xea, 0xe5,
		0xfb, 0xdd, 0x5f, 0x1e, 0x7e, 0xdf, 0x18, 0x78, 0x60, 0x7f, 0xd7, 0x59, 0xf5, 0xcb, 0xee, 0xcf,
		0xc1, 0x5a, 0x01, 0x6b, 0x2b, 0xb2, 0x99, 0x36, 0xd0, 0x5c, 0x7e, 0x77, 0x74, 0x43, 0xe9, 0xa8,
		0x8d, 0x0c, 0xf7, 0x08, 0x1b, 0x5f, 0x2d, 0xf7, 0xba, 0xa1, 0xc0, 0xc5, 0xc6, 0x2c, 0x31, 0xdd,
		0xee, 0x4b, 0xde, 0xb5, 0xdb, 0xef, 0x0c, 0xc3, 0xdc, 0xb5, 0x72, 0x95, 0x5b, 0x12, 0x6e, 0x49,
		0x54, 0x08, 0x72, 0x4b, 0xb2, 0x53, 0x1a, 0x48, 0x9f, 0x13, 0xf4, 0x6f, 0xbf, 0x78, 0xa1, 0xc0,
		0x65, 0x49, 0xdd, 0x80, 0xc4, 0xb9, 0x1b, 0xdc, 0x64, 0xe2, 0xb2, 0x44, 0xd2, 0x57, 0x10, 0x06,
		0x9e, 0x53, 0xc0, 0x29, 0x45, 0xcf, 0x02, 0xcc, 0x14, 0xf0, 0x05, 0x44, 0x7d, 0x00, 0x5b, 0x47,
		0x50, 0xaf, 0xd5, 0xf6, 0x6b, 0x19, 0x3e, 0x06, 0xe0, 0xcb, 0xdc, 0x36, 0x47, 0x43, 0xd3, 0x36,
		0x8d, 0xe3, 0x9b, 0xf7, 0x3a, 0x7d, 0x4c, 0x0f, 0xf8, 0x01, 0xfc, 0x00, 0x7e, 0x28, 0xf1, 0x8b,
		0x48, 0x42, 0x42, 0x41, 0x53, 0x35, 0x44, 0x13, 0x0e, 0x44, 0xe3, 0xbc, 0x36, 0x62, 0x04, 0xb9,
		0xba, 0xf6, 0xce, 0x74, 0xb4, 0x25, 0x5f, 0x3b, 0x59, 0x90, 0x5b, 0x19, 0xe1, 0x04, 0x81, 0x5c,
		0x88, 0x2b, 0x17, 0xb3, 0xb9, 0xbc, 0x98, 0xcd, 0xbc, 0xf2, 0x82, 0xaf, 0xf2, 0xc9, 0x57, 0x45,
		0xf7, 0x38, 0x0b, 0x55, 0x2f, 0xff, 0xb8, 0xfa, 0xf0, 0xf1, 0x7f, 0x6a, 0x4d, 0x8c, 0x53, 0xa8,
		0x6b, 0x57, 0xa8, 0xe4, 0xd2, 0xaa, 0xa1, 0x30, 0xc9, 0x01, 0xd7, 0x74, 0xc7, 0x29, 0x28, 0xa2,
		0xa0, 0xc8, 0xba, 0xfb, 0x2c, 0x30, 0xe7, 0xc8, 0x64, 0xbe, 0xd1, 0xfc, 0x5c, 0xa3, 0xa1, 0x7c,
		0x65, 0x40, 0x4b, 0x3c, 0xf4, 0x9a, 0xd0, 0x56, 0x15, 0x0f, 0x24, 0x28, 0x40, 0x44, 0x5f, 0x64,
		0x4a, 0x5f, 0x68, 0x17, 0x20, 0x4e, 0x3b, 0xe0, 0x08, 0x0c, 0x25, 0xd4, 0xee, 0xa5, 0xb3, 0x23,
		0x39, 0xd8, 0x8b, 0x18, 0x37, 0x31, 0xee, 0x74, 0x62, 0xdc, 0xc6, 0x83, 0xbd, 0x34, 0xcb, 0xe1,
		0x97, 0xb2, 0x9d, 0x56, 0x79, 0xbc, 0xb0, 0x20, 0x8a, 0x09, 0xa4, 0xa4, 0x60, 0xca, 0x0b, 0xa8,
		0xb4, 0xa0, 0x5a, 0x13, 0x58, 0x6b, 0x82, 0x6b, 0x45, 0x80, 0xcd, 0x5d, 0x7d, 0x81, 0x98, 0xaf,
		0xb1, 0x60, 0x4f, 0x09, 0x89, 0x4d, 0xee, 0x9b, 0x63, 0x60, 0xa1, 0x09, 0x7e, 0x86, 0x2e, 0xad,
		0x75, 0xe1, 0xb7, 0xa1, 0x04, 0xec, 0x29, 0x03, 0x5b, 0x4a, 0xc1, 0xba, 0x72, 0xb0, 0xae, 0x24,
		0xac, 0x2a, 0x0b, 0x19, 0xa5, 0x21, 0xa4, 0x3c, 0xcc, 0x5d, 0xf8, 0xb5, 0xfc, 0x2a, 0x3b, 0x21,
		0x70, 0xce, 0xee, 0xd7, 0x04, 0x69, 0x5a, 0x99, 0x18, 0x38, 0xb7, 0x21, 0x76, 0x26, 0x07, 0x4e,
		0xbf, 0xc6, 0xc2, 0x04, 0xc1, 0xc9, 0x9f, 0x1f, 0xe2, 0x14, 0x77, 0x6c, 0x4e, 0x14, 0x14, 0x96,
		0x91, 0x14, 0x77, 0x42, 0x7a, 0xd2, 0x60, 0xce, 0x77, 0xa2, 0xcc, 0x4e, 0x88, 0x4f, 0x26, 0xcc,
		0xf3, 0x46, 0x48, 0x4f, 0x2c, 0xcc, 0xb9, 0x78, 0x1c, 0xb0, 0x13, 0x16, 0x26, 0x1c, 0xe6, 0x77,
		0x2b, 0x64, 0x27, 0x1f, 0xe6, 0x5c, 0x38, 0xf6, 0xd9, 0x09, 0xe9, 0x49, 0x89, 0x39, 0xe7, 0x88,
		0x3a, 0x3b, 0x21, 0x3f, 0x59, 0x31, 0xbf, 0x3b, 0x61, 0x69, 0xe2, 0x62, 0xce, 0x85, 0xa4, 0xc2,
		0x4e, 0xc8, 0x4f, 0x68, 0xcc, 0xb1, 0x01, 0x39, 0x45, 0x57, 0x88, 0x4f, 0x74, 0xcc, 0xef, 0x3e,
		0x88, 0x4e, 0x7a, 0xcc, 0xb9, 0x7e, 0xa8, 0x59, 0xd8, 0x09, 0x51, 0x8a, 0x8d, 0xc2, 0x35, 0x5a,
		0x91, 0xa8, 0xc8, 0x15, 0x9b, 0x18, 0x39, 0xc7, 0x15, 0x82, 0x63, 0xe9, 0x76, 0xb8, 0xec, 0xe2,
		0xb2, 0x6b, 0xfc, 0x05, 0x5c, 0x76, 0xe5, 0xe0, 0xb2, 0x4b, 0x7e, 0x32, 0xe5, 0x53, 0x35, 0x20,
		0x31, 0xa1, 0x72, 0x4a, 0x53, 0x66, 0x52, 0xa5, 0xa0, 0x62, 0xdf, 0x68, 0x22, 0x85, 0xd0, 0x24,
		0xcb, 0x07, 0x13, 0x23, 0x59, 0xc1, 0xb0, 0x60, 0xcc, 0xa5, 0x4e, 0x51, 0x83, 0xdc, 0x8e, 0x9b,
		0x8c, 0x6b, 0x16, 0xcb, 0x34, 0x91, 0xce, 0x30, 0x61, 0x5c, 0xf3, 0x26, 0x8d, 0x29, 0xe9, 0x64,
		0x19, 0xd0, 0x82, 0xf2, 0xe3, 0x9a, 0xf5, 0x8b, 0x3b, 0x96, 0x1a, 0xc1, 0x03, 0x99, 0x2a, 0xe2,
		0xc7, 0xc5, 0x1f, 0x53, 0x1d, 0xc2, 0x00, 0x7c, 0x06, 0xe0, 0xa3, 0x51, 0xd1, 0xa8, 0x68, 0x54,
		0x43, 0x8d, 0x3a, 0xd5, 0x21, 0x79, 0xd4, 0xa8, 0x4a, 0x93, 0x97, 0xd7, 0xab, 0x53, 0x85, 0x89,
		0xcc, 0x6b, 0x0f, 0x4b, 0x4a, 0x97, 0x56, 0xd0, 0xa5, 0xe8, 0xd2, 0x5c, 0xe9, 0x52, 0x8a, 0x1d,
		0x4c, 0xc9, 0x11, 0xff, 0x25, 0xfe, 0x9b, 0x9a, 0xb2, 0x90, 0x0b, 0x0d, 0xee, 0x50, 0xec, 0x40,
		0xb1, 0xc3, 0xdc, 0xd7, 0x50, 0xec, 0x60, 0x49, 0x46, 0x52, 0xdc, 0x09, 0x8a, 0x1d, 0x28, 0x76,
		0x78, 0xba, 0x13, 0x14, 0x3b, 0x50, 0xec, 0xb0, 0x58, 0x3c, 0x28, 0x76, 0xa0, 0xd8, 0x81, 0x62,
		0x87, 0x25, 0xc2, 0x41, 0xb1, 0x03, 0xc5, 0x0e, 0x14, 0x3b, 0xcc, 0xed, 0x04, 0xc5, 0x0e, 0x14,
		0x3b, 0xac, 0x12, 0x12, 0x8a, 0x1d, 0x28, 0x76, 0xa0, 0xd8, 0xe1, 0xe9, 0x36, 0x50, 0xec, 0x40,
		0xb1, 0x03, 0xc5, 0x0e, 0x1b, 0xa7, 0x42, 0xb1, 0x83, 0x01, 0x39, 0x2e, 0xbb, 0xb8, 0xec, 0x5a,
		0xf8, 0x05, 0x5c, 0x76, 0x09, 0xc8, 0x3e, 0xc5, 0x0e, 0x9b, 0xa3, 0xb0, 0x6d, 0xc5, 0x0e, 0xa3,
		0xfc, 0xa9, 0x4d, 0xe5, 0x91, 0xa5, 0xda, 0xa9, 0xf7, 0x9f, 0xde, 0xdd, 0x6c, 0x1e, 0xc9, 0x8e,
		0xa1, 0x80, 0x95, 0x4e, 0xfd, 0x28, 0x3e, 0x8a, 0x63, 0xc3, 0xf6, 0xbf, 0x1f, 0xfc, 0xe0, 0xb8,
		0xe3, 0x0d, 0x74, 0x66, 0x64, 0x66, 0x4f, 0x4b, 0x1f, 0xdc, 0xef, 0x33, 0x94, 0xca, 0xaf, 0xab,
		0xd5, 0xfa, 0x41, 0xb5, 0xba, 0x77, 0xb0, 0x7f, 0xb0, 0x77, 0x58, 0xab, 0x95, 0xeb, 0x26, 0xd7,
		0xdc, 0xa5, 0xb3, 0xb0, 0xed, 0x85, 0x5e, 0xfb, 0xd7, 0xc1, 0x16, 0x06, 0xfd, 0x4e, 0x27, 0xd5,
		0x93, 0x13, 0x12, 0x2a, 0xdb, 0xc2, 0x54, 0x32, 0x4a, 0x8b, 0x0c, 0xfb, 0xad, 0x38, 0x98, 0xc4,
		0x93, 0x86, 0xcf, 0xd1, 0x3c, 0x1d, 0x3d, 0x47, 0xf3, 0x7c, 0xf8, 0xc5, 0x17, 0xc3, 0xef, 0x6d,
		0x5e, 0x4c, 0xbe, 0x8d, 0x71, 0x36, 0xd6, 0x8e, 0x34, 0x13, 0xb3, 0x2a, 0xb4, 0x12, 0x65, 0x8d,
		0x12, 0x63, 0x8d, 0x67, 0x54, 0x54, 0x98, 0x51, 0xb1, 0x49, 0x58, 0x5e, 0xe4, 0x19, 0x15, 0x5a,
		0x03, 0x9e, 0xe6, 0x98, 0x45, 0x63, 0xd0, 0x93, 0x90, 0x0f, 0xcd, 0x6c, 0x8a, 0x74, 0x7c, 0x5e,
		0x66, 0x53, 0x08, 0xfa, 0xa8, 0x12, 0x72, 0xb3, 0x53, 0xdc, 0xc9, 0xcb, 0x36, 0x06, 0xb9, 0x1e,
		0x0a, 0xd0, 0x12, 0xd9, 0x29, 0xb9, 0x1d, 0x5b, 0xb0, 0x73, 0xa2, 0x33, 0xab, 0xe7, 0xf6, 0xf0,
		0xb5, 0x20, 0x4d, 0xe9, 0xe1, 0xa5, 0x53, 0xc2, 0x79, 0x9b, 0xc0, 0x3c, 0xf9, 0xd3, 0x90, 0xdc,
		0x5c, 0x1b, 0xe3, 0x61, 0xf3, 0xbf, 0xc3, 0x59, 0x0a, 0x74, 0xda, 0x11, 0xff, 0x3a, 0xe2, 0xcf,
		0x0c, 0xe3, 0x1c, 0xcf, 0x30, 0xce, 0xad, 0x32, 0x84, 0xdf, 0xf2, 0xcd, 0x6f, 0x19, 0xb9, 0x64,
		0x69, 0x6c, 0xf2, 0x92, 0x45, 0x10, 0xc3, 0xb7, 0xbb, 0xb7, 0xae, 0x1f, 0x38, 0xc3, 0xb8, 0xab,
		0x20, 0x88, 0x17, 0xb0, 0x40, 0xa5, 0x53, 0x2f, 0xb8, 0x19, 0x46, 0x35, 0x33, 0x07, 0xe3, 0x3f,
		0xf8, 0x81, 0x85, 0xbb, 0x6f, 0xd1, 0x0c, 0x85, 0x29, 0xd9, 0x61, 0x25, 0x9b, 0x79, 0x6d, 0xff,
		0x1c, 0xdd, 0xdf, 0x42, 0xb7, 0x15, 0xfb, 0xdd, 0xe0, 0x9d, 0x7f, 0xe3, 0x8f, 0x6e, 0x6e, 0xe4,
		0xee, 0xb9, 0x05, 0x6d, 0xca, 0x07, 0xf7, 0x7b, 0xee, 0x8e, 0xaa, 0x52, 0xdb, 0xcf, 0xd1, 0x61,
		0x65, 0x45, 0x21, 0xcb, 0xf4, 0x19, 0x11, 0xc5, 0x1e, 0x03, 0xcc, 0xf1, 0xfc, 0xf9, 0x67, 0xd7,
		0xf9, 0xeb, 0xc8, 0xf9, 0xf7, 0x9e, 0x73, 0xd8, 0x6c, 0xcc, 0xfc, 0xc7, 0xd5, 0x95, 0xd3, 0x6c,
		0xec, 0xfe, 0xd8, 0x7b, 0x51, 0x2f, 0xdf, 0xef, 0xfe, 0xf2, 0xf0, 0xfb, 0xc6, 0xc0, 0x03, 0xfb,
		0xbb, 0xce, 0xaa, 0x5f, 0x76, 0x7f, 0x0e, 0xd6, 0x0a, 0x58, 0x5b, 0x91, 0xcd, 0xb4, 0x81, 0xe6,
		0xf2, 0xbb, 0xa3, 0x1b, 0xca, 0x30, 0x68, 0xa4, 0x75, 0x49, 0xaa, 0x71, 0xfd, 0x34, 0xbe, 0x7b,
		0xec, 0x75, 0x43, 0x81, 0x8b, 0x8d, 0x59, 0x62, 0xba, 0x93, 0x8c, 0xbd, 0x6b, 0xb7, 0xdf, 0x19,
		0x86, 0xb9, 0x6b, 0xe5, 0x2a, 0xb7, 0x24, 0xdc, 0x92, 0xa8, 0x10, 0xe4, 0x96, 0x64, 0xa7, 0x34,
		0x90, 0x3e, 0x27, 0xe8, 0xdf, 0x7e, 0xf1, 0x42, 0x81, 0xcb, 0x92, 0xba, 0x01, 0x89, 0x73, 0x37,
		0xb8, 0xc9, 0xc4, 0x65, 0x89, 0xa4, 0xaf, 0x20, 0x9d, 0xc5, 0x3c, 0x01, 0x9c, 0x52, 0xf4, 0x2c,
		0xc0, 0x4c, 0x89, 0x2c, 0x75, 0x49, 0x1f, 0xc0, 0xd6, 0x11, 0xd4, 0x6b, 0xb5, 0xfd, 0x5a, 0x86,
		0x8f, 0x01, 0xf8, 0x32, 0xb7, 0xcd, 0xd1, 0xd0, 0xb4, 0x4d, 0xe3, 0xf8, 0xc6, 0x08, 0xe6, 0x09,
		0x3d, 0xe0, 0x07, 0xf0, 0x03, 0xf8, 0xa1, 0xc4, 0x2f, 0x22, 0x09, 0x09, 0x05, 0x4d, 0xd5, 0x10,
		0x4d, 0x38, 0x10, 0x8d, 0xf3, 0xda, 0x88, 0x11, 0xe4, 0xea, 0xda, 0x3b, 0xd3, 0xd1, 0x96, 0x7c,
		0xed, 0x64, 0x41, 0x6e, 0x65, 0x84, 0x13, 0x04, 0x72, 0x21, 0xae, 0x5c, 0xcc, 0xe6, 0xf2, 0x62,
		0x36, 0xf3, 0xca, 0x0b, 0xbe, 0xca, 0x27, 0x5f, 0x15, 0xdd, 0xe3, 0xdc, 0xa2, 0xaa, 0x22, 0xf5,
		0x12, 0x4b, 0x85, 0x8a, 0xa2, 0x67, 0x82, 0xfb, 0x37, 0x29, 0x91, 0x54, 0xc8, 0xf6, 0xd6, 0xab,
		0x82, 0xd4, 0xaf, 0x7a, 0x14, 0xad, 0x72, 0xd4, 0xab, 0x6a, 0x4c, 0xba, 0x99, 0x9a, 0x4c, 0x28,
		0xca, 0x7c, 0x25, 0xa5, 0x82, 0xb3, 0x84, 0x25, 0x88, 0xc9, 0x78, 0x79, 0x3d, 0x67, 0xae, 0xfe,
		0xc4, 0x9a, 0x6d, 0x56, 0xdd, 0x5e, 0xc3, 0x6d, 0x5d, 0xfd, 0xce, 0xcb, 0xdf, 0x64, 0xf1, 0xbf,
		0x2c, 0x79, 0xb7, 0xa4, 0xef, 0xa4, 0xfa, 0x2e, 0x2b, 0xb8, 0x60, 0xe5, 0xa9, 0x2f, 0x7e, 0xe9,
		0xf9, 0x57, 0x5a, 0xf0, 0x3a, 0xa5, 0x5b, 0xef, 0xb6, 0x1b, 0x2e, 0xef, 0x8c, 0x32, 0xc5, 0xfa,
		0xe3, 0xcf, 0x2d, 0xd9, 0x90, 0xd5, 0x05, 0x89, 0x6b, 0xc3, 0x75, 0x49, 0xc2, 0x71, 0xb3, 0xe1,
		0xb6, 0xe8, 0x6e, 0x95, 0xbf, 0x91, 0x34, 0x9c, 0xa6, 0x1c, 0x2e, 0x53, 0x0e, 0x87, 0x3d, 0x0d,
		0x77, 0x0d, 0x9e, 0x5b, 0x88, 0x05, 0xd7, 0x15, 0xe8, 0x95, 0x5a, 0x93, 0x3d, 0x5f, 0xb3, 0x09,
		0x93, 0x6d, 0x1d, 0x7f, 0x7e, 0xcd, 0x0b, 0x25, 0xab, 0x3c, 0x4d, 0x1c, 0x9f, 0x55, 0x89, 0xc3,
		0x26, 0x67, 0x00, 0xdd, 0xb8, 0xaa, 0x76, 0xfc, 0x54, 0x3b, 0x4e, 0xaa, 0xc4, 0x20, 0xd9, 0xd6,
		0xc7, 0x23, 0x05, 0x91, 0x68, 0x2a, 0xe7, 0x0a, 0x35, 0xbc, 0x52, 0x03, 0x26, 0x29, 0xb4, 0x56,
		0x2a, 0xac, 0x56, 0x66, 0xe7, 0x0a, 0xec, 0x9c, 0x31, 0x76, 0x4e, 0x5a, 0xa8, 0x5c, 0xea, 0x7d,
		0xbd, 0x8b, 0xfc, 0x96, 0xdb, 0x49, 0xbe, 0x7d, 0xd3, 0x74, 0x81, 0xc9, 0xca, 0xa4, 0xe8, 0x5c,
		0xe9, 0x6e, 0x4b, 0xf9, 0x2e, 0x4b, 0xe7, 0xee, 0x4a, 0x9d, 0xd9, 0x4c, 0xef, 0xa6, 0x8c, 0xef,
		0xa2, 0x8c, 0xef, 0x9e, 0xb4, 0x98, 0xd1, 0x8e, 0xbf, 0xa6, 0x7c, 0x77, 0x34, 0x3d, 0xaf, 0xbe,
		0x1f, 0xc4, 0x75, 0x95, 0x24, 0xaf, 0x09, 0xf7, 0x29, 0xc4, 0x50, 0x35, 0xb3, 0x50, 0x34, 0xfc,
		0x75, 0x93, 0x2c, 0x13, 0xd3, 0x2b, 0x63, 0xc3, 0x2c, 0x12, 0x89, 0x74, 0x05, 0x9d, 0xeb, 0x7b,
		0x93, 0xac, 0x10, 0xa9, 0x2d, 0x93, 0xeb, 0x51, 0x24, 0xb2, 0x8b, 0x96, 0x42, 0x34, 0x0d, 0x29,
		0x77, 0x39, 0x81, 0x25, 0x0f, 0xbd, 0xa1, 0xbf, 0xda, 0x56, 0x37, 0x46, 0xd3, 0x95, 0x18, 0x23,
		0x8c, 0x11, 0xc6, 0x08, 0x63, 0x84, 0x31, 0xc2, 0x18, 0xe5, 0x34, 0x56, 0x90, 0xe0, 0xc6, 0x25,
		0xab, 0x11, 0xdb, 0x95, 0xe1, 0xd0, 0xe5, 0x01, 0xdb, 0x0f, 0xa3, 0x65, 0x46, 0xf1, 0xda, 0x28,
		0x72, 0x6f, 0xbc, 0x28, 0x49, 0xc4, 0x76, 0xfc, 0xc9, 0x6c, 0xc4, 0x6c, 0xd7, 0x3c, 0x4e, 0xb6,
		0x03, 0xb7, 0xd3, 0x87, 0x27, 0x7a, 0x2b, 0x10, 0xee, 0x4a, 0xc0, 0x0a, 0xf9, 0x8d, 0x79, 0xad,
		0x67, 0x95, 0x94, 0x03, 0x5f, 0xca, 0xdd, 0xef, 0x75, 0xbb, 0xdb, 0x67, 0xdd, 0xd7, 0x50, 0x60,
		0xbb, 0xe2, 0x39, 0x1c, 0xc9, 0xd9, 0x32, 0x6b, 0x5e, 0x87, 0x7e, 0x9f, 0x75, 0x9d, 0x3e, 0xea,
		0x8a, 0x7d, 0xd2, 0xf3, 0x8b, 0xc0, 0x46, 0xec, 0x60, 0xf1, 0xbe, 0xa6, 0xed, 0x7d, 0xe9, 0xdf,
		0x38, 0x5e, 0x10, 0x87, 0xbe, 0x17, 0x25, 0xb7, 0x64, 0x8f, 0x97, 0x61, 0xd0, 0x30, 0x68, 0x8b,
		0x19, 0x2b, 0xf2, 0xc2, 0x6f, 0xbe, 0xca, 0x46, 0x3e, 0x66, 0xb0, 0xc9, 0x72, 0x35, 0xd3, 0x56,
		0xc6, 0xb4, 0x61, 0xda, 0x74, 0x19, 0x57, 0x15, 0xdc, 0x9b, 0x81, 0x7d, 0x43, 0x16, 0xd6, 0x66,
		0x65, 0x13, 0x96, 0x16, 0x62, 0x6d, 0x53, 0x16, 0x17, 0x63, 0x75, 0x31, 0x96, 0x97, 0x63, 0x7d,
		0xcd, 0xc0, 0x55, 0x5a, 0xed, 0xc3, 0xbd, 0xc0, 0xfd, 0xd2, 0x51, 0xb8, 0x17, 0x59, 0xca, 0x39,
		0x13, 0x42, 0xe6, 0x4d, 0x36, 0xae, 0xdd, 0x4e, 0xe4, 0x51, 0xe7, 0x6a, 0x2a, 0x8c, 0x52, 0x42,
		0x29, 0x2e, 0x9c, 0xe2, 0x42, 0x2a, 0x2f, 0xac, 0x7a, 0x42, 0x6b, 0x10, 0xe9, 0xdf, 0x91, 0xad,
		0x78, 0xfd, 0xd2, 0xed, 0x76, 0x3c, 0x37, 0x90, 0x28, 0x77, 0x2d, 0x67, 0xb9, 0xd4, 0x5e, 0x11,
		0x92, 0xae, 0x08, 0xbc, 0xa8, 0x80, 0x53, 0x94, 0x0e, 0x4a, 0x07, 0xa5, 0x33, 0xc7, 0x39, 0x7e,
		0xdb, 0x0b, 0x62, 0x3f, 0xbe, 0x0b, 0xbd, 0x6b, 0x09, 0xc5, 0x63, 0x32, 0x95, 0xeb, 0x64, 0xfc,
		0x28, 0xbf, 0xba, 0x91, 0x00, 0x0f, 0x4e, 0x5e, 0xf0, 0xdd, 0xf1, 0xaf, 0xbf, 0xbf, 0x6f, 0x5e,
		0x1c, 0x9f, 0xff, 0xeb, 0xe4, 0xed, 0x71, 0xea, 0xe7, 0xbb, 0xa5, 0xa5, 0x64, 0xd3, 0xc0, 0xd9,
		0xa3, 0x38, 0xd5, 0xab, 0x47, 0x41, 0x85, 0x44, 0x41, 0x35, 0xfd, 0xed, 0x51, 0x9a, 0x4e, 0xa5,
		0x69, 0x92, 0x0c, 0x4d, 0x91, 0xa6, 0x09, 0xc2, 0xd9, 0xc4, 0xd9, 0x54, 0x17, 0x7d, 0x6d, 0x93,
		0x31, 0x3d, 0xf9, 0x8e, 0xe7, 0x5e, 0xeb, 0x99, 0x89, 0xa9, 0x79, 0x38, 0xd0, 0x58, 0xfb, 0x69,
		0xac, 0x6d, 0x5e, 0xbe, 0x1c, 0xa5, 0x42, 0xbc, 0x9a, 0x08, 0x1b, 0x63, 0xed, 0xb4, 0x94, 0x46,
		0x05, 0xa5, 0x81, 0xd2, 0x20, 0x42, 0x85, 0xb3, 0x88, 0xb3, 0x88, 0xb3, 0x48, 0x84, 0x8a, 0x08,
		0x15, 0x4a, 0x07, 0xa5, 0x43, 0x84, 0x8a, 0x08, 0x15, 0x11, 0xaa, 0xa7, 0x11, 0xaa, 0xfc, 0x35,
		0x3b, 0x52, 0x4c, 0xd8, 0xa1, 0xdf, 0x91, 0x30, 0x1f, 0x8a, 0xf2, 0x9f, 0x71, 0xbf, 0xa3, 0x0f,
		0xe3, 0x2f, 0x69, 0xbe, 0x1b, 0x90, 0xbd, 0x50, 0x89, 0x9b, 0xe4, 0x3e, 0x65, 0xf3, 0x71, 0x86,
		0x24, 0x9d, 0x36, 0x2c, 0x21, 0x35, 0x32, 0x35, 0x4d, 0x63, 0x27, 0x93, 0x12, 0x24, 0xf5, 0x1c,
		0xcd, 0xc9, 0x42, 0xcb, 0xd9, 0x99, 0x15, 0xb2, 0x33, 0xc5, 0xe1, 0x7e, 0xee, 0xb3, 0x33, 0xdd,
		0x5e, 0xcf, 0x19, 0x5b, 0x1b, 0xcd, 0xe0, 0xf7, 0x94, 0x02, 0x97, 0x66, 0xc4, 0xbf, 0x0b, 0x7b,
		0x69, 0x16, 0xc5, 0xe1, 0xea, 0x9e, 0x85, 0x6b, 0xd5, 0xf5, 0xeb, 0x0c, 0xdc, 0x73, 0xdd, 0x46,
		0x06, 0x89, 0xd8, 0x83, 0xc5, 0xc8, 0x38, 0x32, 0x8e, 0x8c, 0x67, 0x5d, 0xc6, 0xfd, 0xb6, 0x91,
		0x94, 0xfb, 0x6d, 0xe4, 0x1c, 0x39, 0x47, 0xce, 0xb3, 0x2d, 0xe7, 0xbd, 0xd0, 0xef, 0x2a, 0x55,
		0xba, 0xcf, 0xed, 0xc3, 0x94, 0x02, 0xd2, 0x8e, 0xb4, 0x17, 0x56, 0xda, 0xfb, 0x7e, 0x10, 0xbf,
		0x36, 0x10, 0x76, 0x8d, 0x8b, 0x26, 0xc3, 0x49, 0xa7, 0x06, 0x97, 0x6d, 0x12, 0x93, 0x4d, 0x85,
		0xc6, 0x69, 0x4a, 0x4d, 0x32, 0x95, 0x1c, 0x9d, 0x69, 0x30, 0x4d, 0x4a, 0x64, 0x62, 0xa9, 0xf4,
		0xd6, 0x56, 0x6a, 0xb5, 0x0c, 0x6d, 0x6e, 0x4a, 0x17, 0x97, 0x8d, 0x4c, 0x18, 0xdf, 0x6e, 0xcb,
		0x04, 0x65, 0x8f, 0xd7, 0x63, 0x78, 0x31, 0xbc, 0xc0, 0xec, 0xf4, 0x61, 0xb6, 0x68, 0xcc, 0xfd,
		0xf8, 0xfb, 0x50, 0x71, 0x26, 0xb7, 0xf5, 0xfa, 0x97, 0x1c, 0xdd, 0x96, 0xe3, 0x7d, 0x8f, 0xdf,
		0xc4, 0x5e, 0xc7, 0xbb, 0xf5, 0xe2, 0xf0, 0xce, 0x71, 0xe3, 0xee, 0xad, 0xdf, 0x32, 0xbb, 0xf5,
		0x18, 0x26, 0xd4, 0x1a, 0x5c, 0x7b, 0x48, 0xdf, 0x75, 0x34, 0xb2, 0x76, 0xb5, 0x3f, 0x2a, 0x57,
		0x50, 0xbb, 0xa5, 0xdb, 0x59, 0x7f, 0x99, 0x3f, 0xfe, 0xa1, 0x94, 0x62, 0x27, 0x66, 0xba, 0xa3,
		0x71, 0x49, 0x49, 0x77, 0xb4, 0xc4, 0x6b, 0xb6, 0xac, 0x3b, 0x5a, 0xae, 0x3b, 0xd4, 0xae, 0xef,
		0xb7, 0xba, 0x52, 0x1b, 0x9b, 0x74, 0xa9, 0x0d, 0xe2, 0xde, 0xfa, 0x06, 0xb5, 0x83, 0x0f, 0x31,
		0x4f, 0x8c, 0x79, 0x62, 0xcc, 0x13, 0x13, 0xb3, 0x6f, 0x59, 0x1e, 0xc0, 0x34, 0xaa, 0x77, 0x73,
		0x82, 0xb8, 0xe7, 0xb8, 0xfd, 0xa1, 0xf6, 0x52, 0x04, 0x5c, 0x4f, 0x09, 0x24, 0x4d, 0x00, 0xd2,
		0x2b, 0x94, 0x63, 0x72, 0xc6, 0x0e, 0x93, 0x33, 0xa4, 0x50, 0x9a, 0x7a, 0x79, 0x99, 0x62, 0x39,
		0x99, 0x8c, 0x33, 0xa4, 0x5a, 0xdb, 0xaa, 0x59, 0xcb, 0x8a, 0x48, 0x22, 0x92, 0x88, 0x64, 0x32,
		0x91, 0x1c, 0x58, 0xbb, 0x68, 0xc8, 0x28, 0x8e, 0xdb, 0x6e, 0x87, 0x5e, 0x14, 0xa9, 0x4b, 0xe7,
		0x02, 0x1a, 0x08, 0x1c, 0x02, 0x97, 0xb2, 0xc0, 0xf9, 0x3d, 0x45, 0xee, 0x7b, 0x24, 0x73, 0x87,
		0x0a, 0x6b, 0xc6, 0xcf, 0x68, 0x7d, 0x82, 0xd4, 0xc3, 0x9b, 0x7d, 0xab, 0x6a, 0xbc, 0xdb, 0x7c,
		0x70, 0x5f, 0xaf, 0x87, 0x4c, 0xec, 0x85, 0x81, 0xf6, 0xcd, 0x7a, 0xe9, 0x3f, 0xcf, 0x9f, 0x7f,
		0xde, 0x73, 0x0e, 0x1b, 0x3f, 0x3f, 0x97, 0x9d, 0xc3, 0xc6, 0xe8, 0xc7, 0xf2, 0xf0, 0xaf, 0xd1,
		0xcf, 0x95, 0xcf, 0x7b, 0x4e, 0x75, 0xf2, 0x73, 0xed, 0xf3, 0x9e, 0x53, 0x6b, 0xec, 0x5e, 0x5d,
		0xbd, 0xdc, 0xfd, 0xb1, 0x7f, 0xaf, 0xbe, 0xf0, 0x6f, 0xea, 0x77, 0x3a, 0x0d, 0x9d, 0x4d, 0x39,
		0xbb, 0x38, 0xf9, 0x9f, 0xe2, 0xef, 0x8c, 0xcd, 0xdb, 0x2e, 0x33, 0x71, 0xa8, 0xe7, 0x5d, 0x1c,
		0x5c, 0xe7, 0xfa, 0xc8, 0xf9, 0xad, 0xf1, 0xa3, 0xfc, 0xa2, 0x7a, 0xff, 0x66, 0xf7, 0xc7, 0xc1,
		0xfd, 0xd3, 0x5f, 0xfe, 0x5c, 0xf4, 0xb1, 0xf2, 0x8b, 0x83, 0xfb, 0x37, 0x4b, 0xfe, 0xa5, 0x7e,
		0xff, 0x26, 0x21, 0x8d, 0xda, 0xfd, 0xf3, 0xb9, 0x8f, 0x0e, 0x7e, 0x5f, 0x59, 0xb6, 0xa0, 0xba,
		0x64, 0xc1, 0xfe, 0xb2, 0x05, 0xfb, 0x4b, 0x16, 0x2c, 0x7d, 0xa4, 0xca, 0x92, 0x05, 0xb5, 0xfb,
		0x9f, 0x73, 0x9f, 0x7f, 0xbe, 0xf8, 0xa3, 0xf5, 0xfb, 0xdd, 0x9f, 0xcb, 0xfe, 0xed, 0xe0, 0xfe,
		0xe7, 0x9b, 0xdd, 0x5c, 0x2a, 0x07, 0xf8, 0x24, 0x1f, 0x7c, 0xc2, 0x98, 0x3e, 0x8d, 0x2b, 0x84,
		0x20, 0xee, 0x59, 0x9c, 0x0f, 0x33, 0xf0, 0x4a, 0xfe, 0xf4, 0xee, 0x14, 0x46, 0xc3, 0x4c, 0x57,
		0x10, 0x54, 0x26, 0xa8, 0xfc, 0x88, 0x89, 0xf4, 0x7c, 0xe2, 0xc1, 0xc2, 0x62, 0xcc, 0x7f, 0xc1,
		0x11, 0x4e, 0xdd, 0x11, 0x66, 0xea, 0x8b, 0x14, 0x23, 0x9b, 0x33, 0xb4, 0x29, 0x63, 0x8b, 0x31,
		0xb8, 0x18, 0xa3, 0x8b, 0x30, 0xbc, 0x3a, 0x9e, 0xd9, 0x49, 0xb3, 0x93, 0xe6, 0x9f, 0xde, 0x9d,
		0xe3, 0x0b, 0x34, 0xd2, 0x1c, 0xd3, 0xa1, 0x15, 0x9d, 0xbe, 0xe0, 0x48, 0x09, 0x90, 0xb8, 0x20,
		0x89, 0x0b, 0x94, 0xa8, 0x60, 0xe9, 0x09, 0x98, 0xa6, 0xa0, 0xe9, 0x87, 0x60, 0x97, 0xf2, 0x4b,
		0xdf, 0x0f, 0xe2, 0x72, 0x5d, 0xa0, 0xf7, 0x5c, 0xdd, 0x80, 0x84, 0x59, 0x65, 0x90, 0x7e, 0xbc,
		0x6a, 0xee, 0x41, 0x24, 0x2a, 0x85, 0x84, 0xd4, 0xca, 0x1c, 0x39, 0xa1, 0xca, 0xa1, 0x29, 0x3d,
		0xc1, 0x22, 0x17, 0x43, 0x76, 0x7e, 0x7c, 0x04, 0x02, 0x15, 0x45, 0xb6, 0x8f, 0xa0, 0x5e, 0xab,
		0xed, 0xd7, 0x32, 0x7c, 0x0c, 0xcf, 0x36, 0xb3, 0xba, 0x91, 0xe1, 0xb6, 0xb7, 0x03, 0x84, 0x10,
		0x9b, 0x68, 0xcd, 0x47, 0x58, 0x63, 0x48, 0x09, 0xb4, 0x01, 0xda, 0x00, 0x6d, 0x28, 0xf1, 0x4b,
		0xe1, 0xdb, 0xdd, 0x7e, 0xbc, 0xfc, 0xd4, 0x3c, 0xfa, 0xfd, 0xf2, 0x1f, 0xcd, 0xcb, 0x3f, 0x3e,
		0x1d, 0x97, 0x24, 0x0a, 0x5a, 0x23, 0x63, 0x5c, 0x24, 0x83, 0x8d, 0x16, 0xbf, 0xe6, 0x87, 0x77,
		0xb5, 0xd2, 0x86, 0xed, 0x55, 0x23, 0xfb, 0x4d, 0x85, 0x35, 0xed, 0xd5, 0xb7, 0x31, 0xdc, 0x10,
		0x30, 0x58, 0x23, 0x52, 0x58, 0x2c, 0x2c, 0x16, 0x16, 0x4b, 0x89, 0x5f, 0xb4, 0xeb, 0x75, 0xe7,
		0x8c, 0xd5, 0x6b, 0x5a, 0x98, 0x2b, 0x5e, 0x3c, 0x4e, 0x2e, 0xfb, 0x26, 0x3f, 0x64, 0x68, 0xa8,
		0x9e, 0x66, 0xe0, 0xd2, 0x2c, 0x60, 0x99, 0xd7, 0x56, 0x07, 0x44, 0xf2, 0x05, 0x15, 0x2a, 0x83,
		0xf4, 0x16, 0xb3, 0xea, 0xd3, 0x41, 0x7a, 0x63, 0x09, 0x63, 0x8e, 0x9e, 0x96, 0xa6, 0xa8, 0xa0,
		0x29, 0xd0, 0x14, 0x2b, 0x9f, 0x90, 0x3b, 0x3f, 0x7c, 0x1a, 0x7c, 0x9a, 0x5c, 0xfa, 0x34, 0xdc,
		0xf9, 0xcd, 0x3e, 0x08, 0x77, 0x7e, 0x66, 0xc1, 0x3b, 0xee, 0xfc, 0x32, 0x71, 0x0c, 0xdc, 0xf9,
		0x2d, 0x44, 0x1a, 0xdc, 0xf9, 0x81, 0x36, 0x40, 0x1b, 0x9b, 0x44, 0x1b, 0xdc, 0xf9, 0x29, 0x9b,
		0x1b, 0xee, 0xfc, 0xac, 0x58, 0x9d, 0x1d, 0xee, 0xfc, 0xb0, 0x58, 0x58, 0x2c, 0x2c, 0xd6, 0x1a,
		0x7e, 0xe1, 0xce, 0xef, 0x09, 0x4f, 0x6c, 0xf2, 0xce, 0x2f, 0x7f, 0x63, 0x8a, 0x95, 0x02, 0x93,
		0x4c, 0x29, 0x96, 0x66, 0x3b, 0x23, 0x76, 0x33, 0x6e, 0x64, 0xfc, 0x31, 0xee, 0x0d, 0xfe, 0x37,
		0x60, 0x85, 0xc2, 0x17, 0x06, 0x4f, 0x8b, 0x71, 0x6d, 0x0c, 0x20, 0xf6, 0xc2, 0x6f, 0x5e, 0xa8,
		0x50, 0x19, 0x3c, 0x59, 0x40, 0x61, 0x30, 0x85, 0xc1, 0xb3, 0x2c, 0xa4, 0xd3, 0xd5, 0x7b, 0xb8,
		0x8e, 0xb2, 0xe0, 0x14, 0x81, 0xed, 0x56, 0x97, 0x05, 0xab, 0x76, 0x75, 0x9b, 0x3b, 0x67, 0xbd,
		0x4e, 0x3b, 0xa4, 0x13, 0x6d, 0xc4, 0x77, 0x23, 0x9d, 0x48, 0xe5, 0xbc, 0xb3, 0x92, 0x4e, 0x34,
		0x11, 0xb1, 0x0c, 0xe4, 0x13, 0xd1, 0x45, 0x00, 0x65, 0x51, 0x44, 0x65, 0xa1, 0x9d, 0x51, 0xa4,
		0x6b, 0x3f, 0x85, 0xec, 0x28, 0x31, 0x53, 0x62, 0xa6, 0x5b, 0x1f, 0x33, 0xfd, 0xda, 0x8d, 0x62,
		0x89, 0x88, 0xe9, 0xa1, 0x01, 0x0d, 0xad, 0xa6, 0xaf, 0x4f, 0xff, 0x08, 0x64, 0x14, 0x19, 0xb5,
		0xbb, 0xb5, 0xb9, 0x43, 0xb2, 0x3b, 0x25, 0xb7, 0x63, 0x0b, 0x76, 0xce, 0xa8, 0x9d, 0xee, 0xda,
		0x3d, 0x7c, 0x2d, 0x48, 0xd3, 0xb4, 0x8f, 0xe4, 0x52, 0xc2, 0x59, 0x6f, 0x3e, 0xbb, 0xec, 0x4f,
		0x43, 0x72, 0x73, 0x25, 0x3a, 0x75, 0x16, 0x6f, 0x87, 0x45, 0x28, 0xdd, 0xbf, 0xc8, 0xb0, 0xf8,
		0xd7, 0x11, 0x7f, 0xda, 0xcb, 0xe6, 0xa8, 0xbd, 0x6c, 0x61, 0x94, 0x21, 0xfc, 0x96, 0x6f, 0x7e,
		0x93, 0x31, 0x0d, 0xcf, 0x36, 0xfb, 0x1c, 0x86, 0xa6, 0x49, 0x10, 0xc3, 0xb7, 0xbb, 0xb7, 0xae,
		0x1f, 0x38, 0xc3, 0x5b, 0x5e, 0x41, 0x10, 0x2f, 0x60, 0x81, 0x4a, 0xa7, 0x5e, 0x70, 0x33, 0x8c,
		0x52, 0x66, 0x0e, 0xc6, 0x4b, 0x96, 0x54, 0x08, 0x45, 0x57, 0x96, 0x92, 0x9d, 0xe4, 0xf7, 0x97,
		0x85, 0xe9, 0x5a, 0xc8, 0xf1, 0x17, 0x06, 0x6e, 0x3b, 0xd2, 0xa5, 0x17, 0x69, 0x1d, 0x55, 0xa5,
		0xb6, 0x9f, 0xa3, 0xc3, 0xca, 0x8a, 0x42, 0x16, 0xd0, 0x38, 0xd2, 0xd8, 0x63, 0x80, 0x39, 0x9e,
		0x3f, 0xff, 0xec, 0x3a, 0x7f, 0x1d, 0x39, 0xff, 0xde, 0x73, 0x0e, 0x9b, 0x8d, 0x99, 0xff, 0xb8,
		0xba, 0x72, 0x9a, 0x8d, 0xdd, 0x1f, 0x7b, 0x2f, 0xea, 0xe5, 0xfb, 0xdd, 0x5f, 0x1e, 0x7e, 0xdf,
		0x18, 0x78, 0x60, 0x7f, 0xd7, 0x59, 0xf5, 0xcb, 0xee, 0xcf, 0xc1, 0x5a, 0x01, 0x6b, 0x2b, 0xb2,
		0x99, 0x36, 0xd0, 0x5c, 0x7e, 0x77, 0x94, 0xfa, 0xa5, 0xb9, 0xb3, 0x74, 0xa3, 0xa8, 0xdb, 0xf2,
		0x87, 0xc9, 0x5b, 0x42, 0x75, 0x4c, 0x73, 0x14, 0x35, 0xe3, 0xc6, 0x33, 0xd3, 0x1b, 0x2f, 0x8e,
		0xcf, 0xff, 0x75, 0x7c, 0xce, 0x95, 0x09, 0x57, 0x26, 0x2a, 0x04, 0xb9, 0x32, 0xd9, 0x29, 0x79,
		0x41, 0xff, 0xd6, 0x0b, 0x47, 0xb9, 0x99, 0x02, 0x37, 0x27, 0x55, 0x03, 0x1a, 0x6a, 0x33, 0xfd,
		0x37, 0xa3, 0x0d, 0xfd, 0x2f, 0xfd, 0x30, 0x8a, 0xcd, 0x75, 0xe0, 0x98, 0x8e, 0xb9, 0xe6, 0x53,
		0x99, 0x5b, 0x8b, 0xe2, 0x43, 0xf1, 0xa1, 0xf8, 0xb4, 0xe7, 0xee, 0x2e, 0x55, 0x7a, 0xe5, 0x0c,
		0x2b, 0xac, 0x5e, 0x37, 0x14, 0x50, 0x57, 0x43, 0x2a, 0xe6, 0xca, 0xaa, 0x5c, 0xd9, 0x47, 0x55,
		0xa1, 0xaa, 0x50, 0x55, 0xea, 0xd2, 0xe7, 0x04, 0xfd, 0xdb, 0x2f, 0x89, 0x0b, 0x02, 0x56, 0x89,
		0x10, 0xfd, 0x72, 0xec, 0x46, 0x0a, 0xe9, 0x97, 0x93, 0x9d, 0x23, 0xa0, 0x5f, 0x4e, 0xee, 0xe2,
		0x4d, 0x03, 0x3b, 0xe4, 0x85, 0x02, 0x90, 0x65, 0x44, 0x07, 0x0f, 0x0b, 0xd8, 0x02, 0x6c, 0xc1,
		0xc3, 0xb2, 0xa7, 0xb0, 0xbe, 0x79, 0x61, 0xa4, 0xdb, 0x95, 0xe0, 0xd1, 0x7e, 0x4d, 0x08, 0x99,
		0xab, 0xac, 0x2a, 0xea, 0x0a, 0x75, 0x85, 0xba, 0x52, 0xe3, 0x97, 0xbe, 0x1f, 0xc4, 0xaf, 0x05,
		0x94, 0x55, 0x0d, 0xff, 0x2a, 0x1d, 0x70, 0x5f, 0xc6, 0xbf, 0xda, 0xf4, 0x11, 0x54, 0xf1, 0xad,
		0x36, 0xe6, 0x5b, 0x15, 0xa6, 0xdb, 0xd2, 0xb8, 0x69, 0xca, 0xf8, 0xef, 0x0c, 0xcd, 0x57, 0x61,
		0x66, 0x82, 0x65, 0xa4, 0x45, 0x85, 0xf3, 0x06, 0x44, 0x9b, 0x0a, 0x67, 0x9c, 0x14, 0x9c, 0x14,
		0x2a, 0x9c, 0xb5, 0x69, 0x50, 0xe1, 0x9c, 0xea, 0x4e, 0xc9, 0xed, 0xd8, 0x82, 0x9d, 0xa3, 0xc2,
		0x99, 0x0a, 0x67, 0x2a, 0x9c, 0x45, 0x5d, 0x39, 0x0b, 0xb1, 0x80, 0x1d, 0x2a, 0x9c, 0xa9, 0x38,
		0xa5, 0xe2, 0xb4, 0x48, 0xca, 0x10, 0x7e, 0xa3, 0xc2, 0x99, 0x0a, 0x67, 0x2a, 0x9c, 0x4d, 0x9e,
		0x8c, 0x0a, 0x67, 0x2a, 0x9c, 0xa9, 0x70, 0x96, 0x52, 0xa5, 0x3b, 0x54, 0x38, 0x53, 0xe1, 0x5c,
		0xf8, 0x1d, 0x25, 0xe3, 0x74, 0xee, 0x2c, 0xa9, 0x70, 0x5e, 0xb7, 0x9c, 0x2b, 0x93, 0xc5, 0xbb,
		0xca, 0x95, 0x89, 0x2d, 0x10, 0x45, 0x85, 0xf3, 0xa6, 0xb4, 0x21, 0x15, 0xce, 0x28, 0x3e, 0x14,
		0x5f, 0x11, 0x14, 0xdf, 0x96, 0xe4, 0xdf, 0x77, 0xaf, 0xaf, 0x23, 0x4f, 0x40, 0x61, 0x8d, 0xe9,
		0xa0, 0x68, 0x50, 0x34, 0x28, 0x1a, 0x25, 0x7e, 0xe9, 0xfb, 0x41, 0x5c, 0xaf, 0x0a, 0xe8, 0x99,
		0xd7, 0xa4, 0xce, 0x5b, 0x0d, 0xf1, 0x51, 0x9a, 0x9c, 0x9d, 0x23, 0x30, 0x1b, 0x7a, 0x9a, 0xfa,
		0xa9, 0x10, 0x37, 0x9a, 0xdb, 0xe6, 0x5e, 0xb7, 0xd3, 0x71, 0xfc, 0x20, 0xf6, 0xc2, 0x6f, 0x6e,
		0x47, 0xa2, 0xc7, 0xca, 0x2c, 0x39, 0x60, 0x08, 0x30, 0x04, 0x18, 0xa2, 0x0c, 0x43, 0xf6, 0x2b,
		0x02, 0x30, 0xe4, 0x00, 0x18, 0x02, 0x0c, 0xd9, 0x96, 0x0a, 0xbe, 0xca, 0x61, 0xf5, 0xb0, 0x7e,
		0x50, 0x39, 0x04, 0x7c, 0xe4, 0x0c, 0x7c, 0xd0, 0xd7, 0x0d, 0xc0, 0x02, 0x60, 0xd9, 0xa1, 0xaf,
		0x1b, 0x7d, 0xdd, 0x40, 0x2d, 0x5b, 0x86, 0x5a, 0xe8, 0xeb, 0x96, 0x3f, 0xc0, 0x42, 0x5f, 0x37,
		0x60, 0x0b, 0xb0, 0xa5, 0x00, 0xb0, 0x65, 0x4b, 0xee, 0x95, 0xc3, 0x6e, 0x37, 0x76, 0xda, 0x5e,
		0xc7, 0xbd, 0x33, 0x57, 0x5a, 0x33, 0xb4, 0x50, 0x38, 0x28, 0x1c, 0x14, 0x8e, 0x12, 0xbf, 0x10,
		0xd8, 0xc5, 0x45, 0xc2, 0x45, 0x52, 0x3c, 0x02, 0x02, 0xbb, 0xf9, 0xf4, 0x93, 0x46, 0x50, 0xc1,
		0x8f, 0x7a, 0x52, 0x6d, 0x65, 0x9f, 0x12, 0x04, 0x80, 0x00, 0x40, 0x00, 0x20, 0xca, 0x00, 0x84,
		0x04, 0x37, 0x00, 0x08, 0x00, 0x44, 0xe1, 0x08, 0x48, 0x70, 0xcb, 0x3b, 0x14, 0x89, 0xe2, 0xd0,
		0x8d, 0x47, 0x15, 0x4b, 0x66, 0x10, 0x64, 0x42, 0x08, 0xe8, 0x01, 0xf4, 0x00, 0x7a, 0x28, 0x43,
		0x0f, 0xba, 0xd2, 0x83, 0x3c, 0x40, 0x1e, 0xc9, 0x8f, 0xa0, 0x52, 0x03, 0x68, 0xe4, 0x0a, 0x68,
		0x30, 0x42, 0x07, 0xb0, 0x02, 0x58, 0x01, 0xac, 0x00, 0x56, 0xd2, 0xf6, 0xd1, 0x01, 0x2b, 0x9b,
		0x3e, 0x02, 0x46, 0xe8, 0x6c, 0x0e, 0xaa, 0x14, 0x75, 0x84, 0xce, 0x68, 0xf2, 0x8c, 0xad, 0x09,
		0x3a, 0xcf, 0x04, 0x77, 0x6b, 0x60, 0xd8, 0xd5, 0x47, 0x82, 0x94, 0x4e, 0xfd, 0x28, 0x3e, 0x8a,
		0x63, 0xb5, 0x74, 0xc2, 0x81, 0x46, 0x3e, 0xee, 0x78, 0x03, 0x23, 0x1d, 0xa9, 0x09, 0xf2, 0x40,
		0x91, 0xcc, 0xac, 0x34, 0x8b, 0x6c, 0x96, 0xce, 0xc2, 0xb6, 0x17, 0x7a, 0xed, 0x5f, 0x07, 0x2f,
		0x1e, 0xf4, 0x3b, 0x1d, 0xd1, 0xfd, 0xd4, 0xe4, 0x3a, 0x03, 0x6e, 0x2b, 0x29, 0x4d, 0x54, 0x0a,
		0xfb, 0xad, 0x38, 0x18, 0xc3, 0x85, 0x8b, 0x21, 0xc9, 0xe6, 0xc7, 0xb8, 0xd7, 0xbc, 0x18, 0x91,
		0x7a, 0x26, 0xc3, 0x80, 0xab, 0x3f, 0xb1, 0x66, 0x2b, 0x55, 0xb7, 0x50, 0x67, 0xeb, 0x56, 0xbf,
		0xe8, 0xf2, 0xc7, 0x5f, 0xf1, 0xe8, 0x09, 0xa7, 0x55, 0x29, 0x4d, 0xa7, 0x4a, 0x38, 0x8d, 0x2a,
		0xf1, 0xf4, 0x29, 0x15, 0xe7, 0x44, 0xdd, 0x09, 0x51, 0x75, 0x36, 0xb4, 0x9d, 0x0a, 0x6d, 0xe7,
		0x41, 0xcb, 0x49, 0x30, 0x63, 0xe6, 0xa4, 0xd3, 0x9e, 0x4a, 0x6e, 0x3f, 0xfe, 0xea, 0xdc, 0xfa,
		0xd1, 0xad, 0x1b, 0xb7, 0xbe, 0x26, 0xdf, 0xc3, 0x69, 0xcb, 0xc3, 0x47, 0xcb, 0x93, 0x2a, 0x7f,
		0x25, 0x48, 0xa5, 0xec, 0x1b, 0xeb, 0xf8, 0xc2, 0xfa, 0xbe, 0xaf, 0xae, 0xaf, 0x6b, 0xec, 0xdb,
		0x1a, 0xfb, 0xb2, 0x46, 0xbe, 0xab, 0x2c, 0x1c, 0x50, 0xf6, 0x45, 0xa7, 0xe7, 0xd5, 0xea, 0xf6,
		0x83, 0xd8, 0x0b, 0x95, 0xae, 0xe9, 0x35, 0xae, 0xe5, 0x35, 0xfd, 0x4b, 0x0d, 0xfc, 0x67, 0xe2,
		0x3f, 0x9a, 0x46, 0xa1, 0x0c, 0x83, 0xd9, 0x12, 0xce, 0x88, 0x4e, 0x1c, 0xd1, 0xc4, 0xdf, 0x93,
		0xda, 0x32, 0xb9, 0x6b, 0x6f, 0x91, 0x5d, 0xb4, 0xe4, 0x04, 0x34, 0xa4, 0x90, 0x5a, 0x02, 0xb3,
		0xee, 0x05, 0xee, 0x97, 0x8e, 0xe7, 0x04, 0x71, 0xcf, 0x19, 0x58, 0x19, 0x75, 0xdb, 0xf4, 0x94,
		0x40, 0x42, 0x5d, 0xa4, 0x59, 0x2b, 0x84, 0x55, 0xc3, 0xaa, 0x89, 0x59, 0x35, 0xf5, 0x5a, 0x1b,
		0xc5, 0xda, 0x1a, 0x49, 0x11, 0x6d, 0xeb, 0x8a, 0x66, 0x1b, 0x91, 0x44, 0x24, 0x11, 0x49, 0x51,
		0x91, 0x1c, 0x58, 0xbb, 0x68, 0xc8, 0x28, 0x8e, 0xea, 0xe0, 0xde, 0xe9, 0xab, 0x2e, 0xa0, 0x81,
		0xc0, 0x21, 0x70, 0x29, 0x0b, 0x9c, 0xd6, 0x7c, 0x57, 0x9d, 0x39, 0xae, 0x7a, 0xf3, 0x5a, 0x0d,
		0x06, 0xa7, 0x1b, 0xce, 0x5f, 0x35, 0x19, 0x73, 0x65, 0x3c, 0x64, 0x26, 0xf3, 0x53, 0x3d, 0x1b,
		0x3a, 0x9b, 0x22, 0x31, 0x2c, 0x26, 0xfb, 0x3b, 0x63, 0xf3, 0xde, 0xcb, 0x4c, 0x1c, 0xea, 0x79,
		0x17, 0x07, 0xe6, 0x3a, 0xe6, 0x62, 0xae, 0xe3, 0xc6, 0x95, 0x03, 0x7c, 0x92, 0x0f, 0x3e, 0xc9,
		0x7a, 0xfc, 0x2c, 0xbb, 0x37, 0x9d, 0xeb, 0x73, 0x10, 0x56, 0xdc, 0x73, 0x3e, 0x53, 0x78, 0x9d,
		0xa4, 0xaf, 0xa1, 0xf2, 0xf8, 0xa5, 0x95, 0x17, 0xad, 0x8b, 0x2f, 0xb1, 0x17, 0xbf, 0xec, 0xfc,
		0xab, 0x2c, 0x78, 0x8d, 0x52, 0x2f, 0xec, 0xb6, 0xbc, 0x28, 0xf2, 0x96, 0x3b, 0x69, 0x33, 0x0d,
		0x90, 0x26, 0x1f, 0x5d, 0xb2, 0x1d, 0xab, 0x2f, 0x6d, 0xd7, 0xfa, 0x5a, 0x49, 0x7c, 0xab, 0x59,
		0x5f, 0x6a, 0xf0, 0x3c, 0xab, 0xb6, 0x2b, 0xa1, 0xf3, 0xa4, 0xec, 0x2c, 0x29, 0x3b, 0x47, 0x4f,
		0x9d, 0xa1, 0xe1, 0x83, 0x0b, 0xb1, 0xe0, 0xba, 0x6b, 0xd6, 0xc9, 0xa9, 0x25, 0xbf, 0x9f, 0x9f,
		0x2c, 0xc8, 0xc7, 0x0d, 0xfd, 0x1a, 0x26, 0xd0, 0xf5, 0xa4, 0x37, 0x7f, 0x45, 0xbf, 0x9a, 0x49,
		0x64, 0xd4, 0x70, 0xe2, 0x3b, 0xfa, 0x9e, 0xaf, 0x11, 0x62, 0x1d, 0x2c, 0x2a, 0x46, 0xd4, 0x26,
		0x21, 0x93, 0x15, 0x2f, 0x6c, 0x93, 0x8c, 0x09, 0xb3, 0x16, 0xb7, 0xe9, 0x78, 0xee, 0x75, 0xe8,
		0x5d, 0xeb, 0x04, 0x6d, 0x14, 0x1a, 0xf5, 0x0c, 0x3c, 0xb7, 0xa1, 0x3d, 0x7f, 0xf9, 0x72, 0x84,
		0x39, 0x5e, 0x0d, 0x18, 0x3e, 0xc5, 0x40, 0x6b, 0xb2, 0xbc, 0xab, 0xb9, 0xdd, 0x49, 0x92, 0x7f,
		0xa5, 0xa8, 0xe5, 0x95, 0xb5, 0x3d, 0x82, 0x99, 0x63, 0xc1, 0x4c, 0x6a, 0x35, 0xa6, 0x0b, 0xdc,
		0xf0, 0x26, 0x52, 0xdf, 0xf3, 0x69, 0x82, 0xd7, 0x60, 0xb5, 0xe2, 0x6e, 0xe9, 0xa5, 0x54, 0x68,
		0xd7, 0x40, 0x99, 0xd4, 0x3e, 0x19, 0xb0, 0xb3, 0x29, 0x5b, 0x8b, 0xb1, 0xb7, 0x18, 0x9b, 0xcb,
		0xb0, 0xbb, 0xba, 0x57, 0xac, 0x11, 0x6e, 0xd4, 0xaf, 0x5e, 0x9a, 0xed, 0x4e, 0xe0, 0x07, 0x37,
		0x46, 0x01, 0x47, 0xab, 0x6f, 0xa8, 0x95, 0xec, 0x3e, 0x5d, 0xad, 0x9d, 0xf4, 0xfe, 0x40, 0x41,
		0x30, 0xf9, 0x7d, 0x4a, 0x54, 0x2b, 0x09, 0x5e, 0x9d, 0xa3, 0x14, 0xf6, 0xba, 0xd4, 0xea, 0xf5,
		0x9d, 0x7e, 0xe4, 0xde, 0x78, 0xe3, 0x70, 0x80, 0xbe, 0xae, 0x9c, 0xa3, 0x84, 0xde, 0x44, 0x6f,
		0x16, 0x4e, 0x6f, 0xea, 0x64, 0xdc, 0x3e, 0x65, 0x71, 0x9d, 0xab, 0x1a, 0xb3, 0x0a, 0x4f, 0x83,
		0x32, 0x57, 0x89, 0x8a, 0x4e, 0xa1, 0x32, 0x42, 0xa9, 0x76, 0x13, 0x92, 0x65, 0x83, 0x06, 0x15,
		0x9b, 0x22, 0x95, 0x9a, 0xd2, 0x5b, 0x2b, 0xdf, 0xc0, 0x4a, 0x74, 0xb7, 0x53, 0x2a, 0x92, 0x6c,
		0x64, 0xca, 0x32, 0xf7, 0x23, 0x8d, 0x19, 0x02, 0x0b, 0xec, 0xf2, 0x90, 0x0e, 0x56, 0x19, 0xab,
		0x8c, 0x55, 0xc6, 0x2a, 0x63, 0x95, 0xb1, 0xca, 0x58, 0x65, 0x3d, 0xab, 0x1c, 0xfb, 0x1d, 0xff,
		0x2f, 0xbd, 0x2e, 0x07, 0x8f, 0xcd, 0xf2, 0x0c, 0x21, 0xec, 0x32, 0x76, 0xb9, 0x70, 0x76, 0xb9,
		0xe7, 0x85, 0x2d, 0x2f, 0x88, 0xdd, 0x1b, 0xcf, 0xc0, 0x30, 0xd7, 0x30, 0xcc, 0x18, 0xe6, 0xac,
		0x1a, 0xe6, 0xbd, 0x3d, 0xec, 0xf0, 0x26, 0xec, 0xf0, 0xad, 0x77, 0xdb, 0x0d, 0xef, 0x46, 0x8e,
		0xad, 0xbe, 0x11, 0x7e, 0x44, 0x05, 0x0b, 0x8c, 0x05, 0x2e, 0x9c, 0x05, 0xd6, 0x9e, 0xe2, 0x80,
		0x5b, 0x8c, 0xf5, 0xc5, 0x2d, 0xc6, 0x1c, 0xab, 0x99, 0x63, 0x09, 0xcf, 0x78, 0x01, 0x2d, 0x4c,
		0x33, 0xa6, 0x19, 0xe7, 0x18, 0xe7, 0x18, 0xf3, 0x8c, 0x73, 0x8c, 0x35, 0x5e, 0xbb, 0x6d, 0xe3,
		0x32, 0x2d, 0x4d, 0xfb, 0x3b, 0x5c, 0x8d, 0xc5, 0xc5, 0xe2, 0x92, 0xf4, 0xfa, 0x94, 0xbf, 0x55,
		0x93, 0x5e, 0xad, 0x48, 0xb7, 0x4a, 0x41, 0xd4, 0x3c, 0xe8, 0x48, 0x5c, 0x18, 0x85, 0x6c, 0x23,
		0xdb, 0x04, 0xba, 0x40, 0xd2, 0x20, 0x69, 0x02, 0x5d, 0x40, 0xeb, 0xc9, 0xb6, 0x45, 0xb1, 0x1b,
		0xc6, 0x4e, 0xec, 0x9b, 0x00, 0xec, 0x19, 0x1a, 0x98, 0x62, 0x4c, 0x71, 0xe1, 0x4c, 0xf1, 0x80,
		0xb3, 0x63, 0xbf, 0xf5, 0x67, 0x94, 0xba, 0x3d, 0xfe, 0x3d, 0x18, 0xe9, 0xb2, 0x52, 0xe0, 0x06,
		0xdd, 0xc8, 0x6b, 0x75, 0x83, 0xb6, 0x56, 0x53, 0x2d, 0xec, 0x3a, 0x76, 0x1d, 0xbb, 0x9e, 0x7b,
		0xbb, 0x9e, 0xab, 0x21, 0x43, 0xd3, 0x16, 0x47, 0x93, 0x9f, 0x54, 0x26, 0x5a, 0xd9, 0x6e, 0x9a,
		0x35, 0x9e, 0x58, 0xb5, 0x3e, 0x7a, 0xa0, 0x56, 0xb8, 0xab, 0x5e, 0xa8, 0x2b, 0x52, 0x98, 0xab,
		0x56, 0x88, 0xbb, 0xa9, 0x86, 0x62, 0x73, 0x0c, 0x51, 0x4a, 0xd4, 0x98, 0x63, 0x41, 0x9f, 0xae,
		0x4f, 0xe3, 0xf5, 0xb9, 0x6c, 0x4c, 0xf6, 0xd0, 0xfa, 0xcb, 0xa0, 0xd5, 0x58, 0x14, 0x7d, 0x75,
		0xc6, 0x93, 0xbb, 0xd6, 0xf6, 0x1a, 0x9b, 0xf9, 0x6c, 0x36, 0x9a, 0x8d, 0x45, 0x77, 0x91, 0x13,
		0x7b, 0xe1, 0x6d, 0x2e, 0x1b, 0x8e, 0x4d, 0x1f, 0x3e, 0xad, 0xa6, 0x63, 0xad, 0xc9, 0xee, 0x27,
		0xec, 0x39, 0x36, 0xfe, 0xbc, 0x70, 0xcb, 0xb1, 0x3d, 0x6b, 0x43, 0xc1, 0xd6, 0xb1, 0x82, 0xae,
		0xf7, 0x94, 0x89, 0xc9, 0x60, 0x6b, 0x58, 0x45, 0xc6, 0x98, 0x25, 0x6e, 0x3d, 0x36, 0x1a, 0xd4,
		0xa0, 0x3b, 0xe0, 0x41, 0x63, 0xbe, 0xc3, 0x60, 0xef, 0x8a, 0xd3, 0x6d, 0x3e, 0x29, 0xa7, 0x9a,
		0xfa, 0xfb, 0x99, 0x6c, 0x39, 0x9f, 0x90, 0x93, 0xed, 0x60, 0xd5, 0xc2, 0x0f, 0x7a, 0xe8, 0x85,
		0xdd, 0xb8, 0xdb, 0xea, 0x76, 0x1c, 0xd5, 0x29, 0xfa, 0xb3, 0xad, 0x26, 0x1f, 0x53, 0x50, 0x97,
		0xd6, 0x7f, 0x55, 0x90, 0x55, 0x64, 0x75, 0x73, 0xb2, 0xea, 0x05, 0xfd, 0x5b, 0x2f, 0x54, 0xcd,
		0x90, 0x9c, 0xca, 0xab, 0xc2, 0x10, 0xee, 0xd2, 0x71, 0xd0, 0x1f, 0xb6, 0x06, 0xba, 0x4f, 0x51,
		0xc6, 0x43, 0x37, 0xf6, 0x9c, 0x8e, 0x7f, 0xeb, 0xc7, 0xea, 0xd2, 0x3d, 0xb3, 0x16, 0x11, 0x45,
		0x44, 0x37, 0x26, 0xa2, 0x7d, 0x3f, 0x88, 0xcb, 0x75, 0x0d, 0xe9, 0xac, 0x33, 0x9d, 0x53, 0x34,
		0x1a, 0xbd, 0xcd, 0xd3, 0x39, 0xeb, 0xb5, 0xda, 0x3e, 0xe3, 0x38, 0x8d, 0x6c, 0x51, 0xe4, 0x45,
		0x03, 0x90, 0xa8, 0x6b, 0x8e, 0x1e, 0x2f, 0xc7, 0x22, 0x61, 0x91, 0xb0, 0x48, 0x58, 0x24, 0x2c,
		0x12, 0x16, 0x49, 0xdb, 0x22, 0xc5, 0xfe, 0xad, 0xd7, 0xed, 0x6b, 0xd8, 0xa2, 0xc9, 0x42, 0xac,
		0x10, 0x56, 0x08, 0x2b, 0x84, 0x15, 0xc2, 0x0a, 0x61, 0x85, 0x34, 0x3e, 0xb1, 0xa9, 0xac, 0x88,
		0x87, 0xdb, 0xf9, 0x57, 0xe3, 0x9b, 0x5b, 0xdd, 0xac, 0x86, 0x95, 0xd3, 0xce, 0x92, 0x8c, 0x37,
		0x51, 0x1a, 0x6b, 0x92, 0x95, 0xa1, 0x55, 0xdc, 0x20, 0x0b, 0x30, 0x37, 0x37, 0xc8, 0x40, 0x3b,
		0xa0, 0xdd, 0xe2, 0x93, 0xe3, 0x06, 0x39, 0xb9, 0xb4, 0x72, 0x83, 0x8c, 0xac, 0x6e, 0x52, 0x56,
		0xb9, 0x41, 0x5e, 0xba, 0x35, 0xdc, 0x20, 0x23, 0xa2, 0x44, 0x4a, 0x88, 0x94, 0x10, 0x29, 0x21,
		0x52, 0x22, 0x61, 0x8b, 0xb8, 0x41, 0xc6, 0x22, 0x61, 0x91, 0xb0, 0x48, 0x58, 0x24, 0x2c, 0x52,
		0x36, 0x2c, 0x12, 0x37, 0xc8, 0x58, 0x21, 0xac, 0x10, 0x56, 0x08, 0x2b, 0x84, 0x15, 0xb2, 0x64,
		0x85, 0xb2, 0x7e, 0x83, 0x9c, 0xa0, 0xc3, 0x42, 0x56, 0xcb, 0xe2, 0xd7, 0x56, 0xa9, 0xef, 0x2c,
		0x6d, 0x07, 0x70, 0x11, 0x7d, 0xbd, 0x18, 0xad, 0x34, 0xa9, 0xa8, 0x5f, 0x79, 0x45, 0x9e, 0xe8,
		0x6a, 0x3c, 0x71, 0x1d, 0x7d, 0x45, 0xac, 0x8e, 0x3e, 0xaf, 0x25, 0xf4, 0xa9, 0x55, 0xcf, 0x7f,
		0xe9, 0x76, 0x13, 0xb6, 0x37, 0x9b, 0xbd, 0xf0, 0x4b, 0xd4, 0xcd, 0x2c, 0xa1, 0xd2, 0x4d, 0xa3,
		0x86, 0xbe, 0xa8, 0xc9, 0x0f, 0xb6, 0xf3, 0x1e, 0x12, 0xc3, 0x35, 0xcd, 0x5e, 0x60, 0x0a, 0xbd,
		0xbf, 0x74, 0x7b, 0x7d, 0x29, 0x62, 0x3a, 0x05, 0x64, 0xaa, 0x83, 0xe1, 0x74, 0x3b, 0xfa, 0x69,
		0x62, 0x36, 0x13, 0xd0, 0xa1, 0xd2, 0x25, 0x51, 0x07, 0x9b, 0x99, 0x6e, 0x85, 0x79, 0x2f, 0x2d,
		0xa3, 0xdd, 0x11, 0x82, 0x4c, 0x0d, 0x0b, 0xd9, 0x6c, 0xad, 0x7e, 0x18, 0x7a, 0x41, 0xec, 0xb4,
		0xdd, 0xd8, 0x53, 0x53, 0xed, 0x73, 0x2b, 0xd1, 0xf0, 0x68, 0xf8, 0x27, 0xfb, 0x3d, 0xe0, 0x0d,
		0xc7, 0x0d, 0xda, 0x49, 0x1b, 0x9a, 0x3e, 0xf4, 0x52, 0x4f, 0xf0, 0xd9, 0x4f, 0x6e, 0x1c, 0x7b,
		0x61, 0x90, 0x58, 0x5d, 0x97, 0xfe, 0xf3, 0x79, 0xcf, 0x39, 0x6c, 0xfc, 0xa8, 0xde, 0x5f, 0x5d,
		0x39, 0xa3, 0x1f, 0x2b, 0xb3, 0x3f, 0x5e, 0x4e, 0x7e, 0x78, 0x33, 0xf7, 0xc3, 0xf3, 0xab, 0xab,
		0x97, 0xc3, 0x9f, 0xff, 0x6b, 0xf7, 0x97, 0x7f, 0x7f, 0xfe, 0x2f, 0xa7, 0x31, 0xf7, 0x89, 0xbf,
		0xad, 0xdf, 0xfc, 0x46, 0x92, 0x77, 0x3a, 0xbb, 0x38, 0xf9, 0x9f, 0xdc, 0xbd, 0x98, 0x05, 0xbd,
		0xd4, 0xee, 0xde, 0xba, 0x7e, 0xe0, 0x24, 0x9a, 0x56, 0xf1, 0xc0, 0x6e, 0x33, 0x8b, 0xd0, 0x46,
		0x68, 0x23, 0x6d, 0xf6, 0x50, 0xd6, 0x45, 0xa7, 0x5e, 0x70, 0x33, 0xf4, 0xca, 0x0b, 0x81, 0x1c,
		0xcb, 0x20, 0xc7, 0xc9, 0x56, 0x54, 0x6a, 0xfb, 0x39, 0x04, 0x8a, 0x56, 0xac, 0xe7, 0xf3, 0xe7,
		0xcf, 0x9f, 0x7f, 0x76, 0x9d, 0xbf, 0x8e, 0x9c, 0x7f, 0xef, 0x39, 0x87, 0xcd, 0xc6, 0xcc, 0x7f,
		0x5c, 0x5d, 0x39, 0xcd, 0xc6, 0xee, 0x8f, 0xbd, 0x17, 0xf5, 0xf2, 0xfd, 0xee, 0x2f, 0x0f, 0xbf,
		0x6f, 0x5c, 0x5d, 0xbd, 0xdc, 0xfd, 0xbb, 0xce, 0xaa, 0x5f, 0x76, 0x7f, 0x0e, 0xd6, 0x6e, 0xd6,
		0xac, 0x66, 0xf5, 0x8d, 0x2d, 0xd8, 0xdb, 0xaf, 0xdd, 0x28, 0x56, 0x33, 0xb6, 0xd3, 0x15, 0x58,
		0x5a, 0x2c, 0x2d, 0x96, 0x16, 0x4b, 0x8b, 0xa5, 0xc5, 0xd2, 0x62, 0x69, 0xd7, 0x5a, 0xda, 0x4e,
		0xf7, 0xc6, 0x0f, 0x9c, 0x2f, 0x6e, 0x10, 0x78, 0x61, 0x72, 0x6b, 0xfb, 0x68, 0x15, 0x16, 0x17,
		0x8b, 0xfb, 0x64, 0xbf, 0x13, 0x8f, 0x2f, 0x4c, 0x38, 0xae, 0x50, 0x8f, 0xb7, 0x6f, 0xbb, 0x71,
		0x5b, 0x99, 0xb5, 0x67, 0x17, 0xc1, 0xd9, 0x70, 0xf6, 0xe6, 0x38, 0x7b, 0xb3, 0x49, 0x1b, 0xcb,
		0xf3, 0x4d, 0x92, 0x65, 0x5d, 0xc4, 0x5e, 0x27, 0xf0, 0xe2, 0xc4, 0xa3, 0x0c, 0x1e, 0x7f, 0x9c,
		0x69, 0x06, 0x4c, 0x33, 0x48, 0x72, 0xe4, 0x69, 0xea, 0x58, 0x7a, 0x51, 0x14, 0xb7, 0x17, 0xc5,
		0xb5, 0xdb, 0x89, 0x68, 0x46, 0x41, 0x96, 0xb8, 0x69, 0xb8, 0xa2, 0xf8, 0xcd, 0x28, 0x28, 0x54,
		0x47, 0xd4, 0x28, 0xc8, 0x48, 0xb0, 0x84, 0x82, 0x0c, 0xbb, 0x31, 0x53, 0x8d, 0x40, 0xb2, 0x51,
		0x40, 0x59, 0x7a, 0xcb, 0x28, 0xc8, 0x30, 0xb6, 0x45, 0x14, 0xaa, 0x63, 0x91, 0xb0, 0x48, 0x58,
		0x24, 0x2c, 0x12, 0x16, 0x29, 0x1b, 0x16, 0x89, 0x42, 0x75, 0xac, 0x10, 0x56, 0x08, 0x2b, 0x84,
		0x15, 0xc2, 0x0a, 0x59, 0xb2, 0x42, 0x99, 0x2c, 0x54, 0x7f, 0x74, 0x7b, 0x47, 0xb7, 0x73, 0x6e,
		0x98, 0xb8, 0x61, 0xe2, 0x86, 0x09, 0x78, 0x97, 0x2d, 0x78, 0xc7, 0x0d, 0x13, 0xa2, 0x86, 0xa8,
		0xe1, 0x49, 0xe1, 0x49, 0xe1, 0x49, 0xe1, 0x49, 0x71, 0xc3, 0x84, 0x45, 0xc2, 0x22, 0x61, 0x91,
		0xb0, 0x48, 0x58, 0xa4, 0x1c, 0x59, 0x24, 0x6e, 0x98, 0xb0, 0x42, 0x58, 0x21, 0xac, 0x10, 0x56,
		0x08, 0x2b, 0x64, 0xc9, 0x0a, 0xe5, 0xe0, 0x86, 0x29, 0xc7, 0xdd, 0x90, 0x93, 0x14, 0xba, 0xed,
		0x2c, 0x6d, 0x88, 0x7c, 0x39, 0x5c, 0xad, 0xd8, 0x13, 0xf9, 0xd9, 0x8a, 0xf7, 0x5c, 0xf7, 0x7e,
		0x49, 0xdf, 0xab, 0xb4, 0xb0, 0xf1, 0xf2, 0xfc, 0x1b, 0x3c, 0x7e, 0xe8, 0x87, 0x47, 0x9b, 0x79,
		0xac, 0xd2, 0xc0, 0xb6, 0xf9, 0x81, 0xdb, 0x71, 0xda, 0xde, 0x37, 0x7f, 0x81, 0xc5, 0x9e, 0x29,
		0x1a, 0x7c, 0xfc, 0xc1, 0x27, 0xaf, 0xb6, 0xf8, 0x66, 0x6f, 0x29, 0x56, 0x59, 0x85, 0x49, 0x66,
		0xb1, 0x47, 0xb7, 0x17, 0x2f, 0xc3, 0x1e, 0xeb, 0x30, 0x46, 0x62, 0x2c, 0x91, 0x18, 0x33, 0x3c,
		0xc5, 0x06, 0xd3, 0x87, 0x53, 0x64, 0x83, 0x65, 0x37, 0x67, 0xeb, 0xca, 0xfa, 0x92, 0x95, 0xf3,
		0xa5, 0x5d, 0xb9, 0xb9, 0xe2, 0x88, 0x54, 0xe1, 0x60, 0xfa, 0x95, 0x9b, 0xcb, 0x8f, 0x70, 0x53,
		0x1a, 0xec, 0x89, 0x9c, 0xbd, 0x7a, 0xfa, 0xdf, 0xab, 0x2e, 0xfc, 0x93, 0x55, 0x0b, 0x77, 0xba,
		0x37, 0x7e, 0xcb, 0xed, 0x38, 0xad, 0xaf, 0x6e, 0x10, 0x78, 0x9d, 0x68, 0x3d, 0xbf, 0xcd, 0xad,
		0x80, 0xf3, 0x32, 0xc7, 0x79, 0xeb, 0x6b, 0x86, 0x47, 0x87, 0xa7, 0x50, 0x34, 0x3c, 0x5e, 0x90,
		0x8f, 0xaa, 0xe1, 0x04, 0xcc, 0xa0, 0xeb, 0x9d, 0x6e, 0x3e, 0xa7, 0x63, 0x3d, 0xb3, 0xc8, 0x20,
		0xca, 0xc4, 0x39, 0x1d, 0x09, 0x0b, 0xd0, 0xd5, 0x2c, 0x97, 0x26, 0x6b, 0x6d, 0x2c, 0x30, 0xa2,
		0xc0, 0x72, 0xc5, 0x0b, 0x8c, 0x24, 0x67, 0x49, 0x3b, 0x81, 0x91, 0xa4, 0xac, 0x3a, 0x5d, 0xe0,
		0xb6, 0x6f, 0xfd, 0xc0, 0x49, 0x96, 0xd5, 0xb6, 0xf4, 0xd4, 0x67, 0x89, 0xbc, 0x48, 0xa5, 0x49,
		0x9a, 0x2a, 0x53, 0x9b, 0x30, 0xb7, 0x10, 0x93, 0x9b, 0x32, 0xbb, 0x18, 0xd3, 0x8b, 0x31, 0xbf,
		0x9c, 0x10, 0x68, 0x46, 0x26, 0x14, 0xcf, 0x5e, 0x39, 0x6a, 0xb8, 0x8a, 0xd1, 0x9d, 0x78, 0x40,
		0x4d, 0xe3, 0xf8, 0x35, 0x06, 0xc2, 0x4f, 0xd7, 0xaa, 0x0d, 0x86, 0x57, 0xdf, 0x55, 0x95, 0x9e,
		0x88, 0x6d, 0x2f, 0x6a, 0x85, 0x7e, 0x2f, 0x71, 0xa0, 0x65, 0xe1, 0x86, 0xce, 0x12, 0x41, 0x73,
		0xa0, 0x39, 0x0a, 0xab, 0x39, 0x12, 0x77, 0xed, 0x5a, 0xaa, 0x2f, 0x5e, 0x67, 0x40, 0xe6, 0xfd,
		0xa0, 0xed, 0x7d, 0xd7, 0x97, 0xf6, 0xd1, 0x72, 0xe4, 0x1c, 0x39, 0x2f, 0xac, 0x9c, 0xf7, 0xfd,
		0x20, 0xde, 0xaf, 0x18, 0xc8, 0xf9, 0x81, 0xc6, 0x52, 0xbd, 0xfb, 0xc6, 0xc9, 0x1f, 0x3d, 0x26,
		0xdb, 0x31, 0xbd, 0x7f, 0x34, 0x14, 0xf0, 0x39, 0x32, 0x86, 0xf7, 0x91, 0x53, 0x3a, 0x02, 0x17,
		0x6c, 0x9a, 0xec, 0xf7, 0x78, 0x6b, 0x0d, 0xee, 0x29, 0x6d, 0x6d, 0x6d, 0xb5, 0x72, 0x58, 0x3d,
		0xac, 0x1f, 0x54, 0x0e, 0x6b, 0x19, 0xda, 0xe3, 0x67, 0xe9, 0xac, 0x6a, 0x64, 0xc0, 0xfc, 0x3e,
		0x89, 0x38, 0x8f, 0x5c, 0x10, 0x6d, 0x6b, 0xbc, 0x90, 0x1a, 0xc6, 0x19, 0xe3, 0x5c, 0x58, 0xe3,
		0xec, 0xb7, 0xbd, 0x20, 0xf6, 0xe3, 0xbb, 0xd0, 0xbb, 0x36, 0x41, 0xe2, 0x1a, 0xda, 0xaf, 0x74,
		0x32, 0xfe, 0xea, 0x5f, 0xdd, 0xc8, 0x80, 0x77, 0x26, 0x2f, 0x72, 0x7a, 0xf6, 0xfe, 0xe4, 0xed,
		0xd1, 0x69, 0xf3, 0xf8, 0xf4, 0xf8, 0xc3, 0xf1, 0xc7, 0xcb, 0xe6, 0xa7, 0xf3, 0xb3, 0xcb, 0xb3,
		0xb7, 0x67, 0xa7, 0xcd, 0xcb, 0x3f, 0x3e, 0x1d, 0x97, 0x4c, 0xb2, 0x53, 0x22, 0x6d, 0x18, 0x61,
		0x06, 0x25, 0x1e, 0xbd, 0xde, 0xe0, 0x75, 0x9a, 0x67, 0x97, 0x1f, 0x4b, 0x9b, 0xb0, 0xbc, 0x92,
		0xef, 0x70, 0x7c, 0xf9, 0x8f, 0xe3, 0xf3, 0x8f, 0xc7, 0x97, 0xa5, 0x94, 0xcd, 0x5b, 0x23, 0x33,
		0x39, 0x41, 0x6a, 0xe6, 0xad, 0xdb, 0xfb, 0xe2, 0xb6, 0xfe, 0x74, 0x6e, 0xbb, 0x6d, 0x23, 0xbb,
		0x36, 0x4b, 0x06, 0x83, 0x86, 0x41, 0x2b, 0xac, 0x41, 0x7b, 0xc4, 0xea, 0x9b, 0x8d, 0x48, 0x6b,
		0xac, 0x9d, 0x29, 0x4e, 0xff, 0x78, 0xf6, 0xf1, 0xb8, 0x94, 0x01, 0x15, 0x34, 0x2c, 0xdf, 0x6d,
		0x75, 0xdc, 0x28, 0xd2, 0xd7, 0x3f, 0x33, 0x34, 0x50, 0x3e, 0x28, 0x1f, 0xd0, 0x74, 0xd6, 0xd1,
		0xf4, 0xe5, 0xf9, 0xc9, 0xaf, 0xbf, 0x5f, 0x1e, 0x9d, 0xff, 0xd1, 0x3c, 0x3f, 0xba, 0x3c, 0x6e,
		0xbe, 0x3d, 0x3d, 0xba, 0xb8, 0x28, 0x08, 0x92, 0x1e, 0xbc, 0xda, 0xe8, 0xad, 0xaa, 0x7b, 0xef,
		0xf3, 0x0c, 0xa7, 0x1f, 0x5e, 0xa4, 0x5c, 0xd9, 0x2b, 0xca, 0xab, 0xbc, 0x2e, 0xcc, 0x9b, 0xd4,
		0x6b, 0x85, 0x79, 0x93, 0xc2, 0x9c, 0xc9, 0x7e, 0x61, 0xce, 0xa4, 0x5a, 0x98, 0x37, 0x29, 0x17,
		0x87, 0xbd, 0x0e, 0x0b, 0xf3, 0x26, 0xe5, 0x5a, 0x71, 0x0e, 0xa5, 0x30, 0x92, 0x52, 0x2b, 0x10,
		0x7b, 0x15, 0x47, 0x7d, 0x95, 0x0b, 0xf3, 0x2a, 0xfb, 0x85, 0xe1, 0xaf, 0xe2, 0xb0, 0x57, 0xa5,
		0x38, 0x6f, 0x52, 0x1c, 0xed, 0x55, 0x94, 0x13, 0x79, 0x59, 0x2b, 0xca, 0x89, 0xec, 0x15, 0x86,
		0xb9, 0x0e, 0x8a, 0x23, 0x26, 0x05, 0xf2, 0x51, 0x8a, 0xf3, 0x26, 0xd5, 0xe2, 0xf0, 0x57, 0x71,
		0xf0, 0x4a, 0xb9, 0x38, 0xf1, 0xbb, 0xe2, 0x48, 0x4a, 0x71, 0xa0, 0x57, 0xb9, 0x38, 0x71, 0xaf,
		0x72, 0x61, 0xec, 0x7c, 0x81, 0x3c, 0xe0, 0xc2, 0x68, 0xaf, 0x02, 0x19, 0xc7, 0x3d, 0x33, 0xfe,
		0xda, 0xa2, 0x1c, 0xab, 0xd8, 0x8b, 0x62, 0x27, 0xf2, 0x6f, 0x02, 0xb7, 0xa3, 0x9f, 0xe1, 0x30,
		0x4b, 0x84, 0x14, 0x87, 0x75, 0x64, 0x48, 0x71, 0x90, 0x92, 0x88, 0xd4, 0x53, 0x1c, 0xd4, 0x07,
		0x16, 0x3c, 0x65, 0xf4, 0x84, 0x83, 0x0b, 0x2c, 0x0b, 0x7d, 0xe8, 0x7f, 0x71, 0x7a, 0x61, 0x37,
		0xee, 0xb6, 0xba, 0x26, 0x62, 0xff, 0x88, 0x0c, 0x82, 0x8f, 0xe0, 0x93, 0xdb, 0xb4, 0x5a, 0xf8,
		0xb3, 0x94, 0xdb, 0x54, 0xc4, 0x1a, 0x81, 0xea, 0xde, 0xfb, 0xe3, 0xdc, 0x17, 0x09, 0x9c, 0x5d,
		0xfe, 0x5e, 0xce, 0xff, 0x5b, 0x0c, 0xbc, 0x89, 0x02, 0x9c, 0xc5, 0xdb, 0xf2, 0x61, 0xa5, 0x08,
		0x1c, 0x95, 0xff, 0x97, 0xb8, 0xb8, 0xfc, 0x50, 0xaf, 0x16, 0xe1, 0x28, 0xde, 0xe6, 0xbf, 0x8e,
		0xe9, 0xec, 0x5d, 0x11, 0xde, 0xe2, 0xe2, 0xf2, 0x43, 0xb9, 0x9e, 0xfb, 0xb7, 0x28, 0x17, 0x43,
		0xd1, 0xbe, 0x2b, 0x80, 0x8a, 0x2a, 0xef, 0xbd, 0x3f, 0x6e, 0x9e, 0x1e, 0x15, 0x40, 0xbe, 0xdf,
		0x1e, 0xd4, 0x5f, 0x17, 0xe0, 0x2d, 0xaa, 0xaf, 0x8b, 0x60, 0x30, 0xf2, 0x6f, 0xf5, 0xca, 0xc5,
		0x80, 0xe5, 0x95, 0x62, 0xe8, 0xd9, 0x42, 0xbc, 0xc5, 0x7e, 0x11, 0xe0, 0x47, 0xa5, 0x56, 0x2f,
		0x82, 0x5c, 0xec, 0x17, 0xc3, 0x72, 0xff, 0xf7, 0x51, 0x21, 0x90, 0x79, 0xb5, 0x10, 0x90, 0xb6,
		0xf9, 0xe1, 0x74, 0x9b, 0xaf, 0xf0, 0x44, 0xbb, 0x00, 0x2b, 0x8e, 0x40, 0x99, 0xae, 0xd3, 0xef,
		0xbf, 0xff, 0xb4, 0x17, 0xfe, 0xab, 0xf1, 0x0f, 0x89, 0x26, 0xf1, 0x27, 0xdf, 0x84, 0x24, 0xf3,
		0xc9, 0xbc, 0xf8, 0xab, 0x17, 0x06, 0x9e, 0xc6, 0x80, 0xb2, 0xe9, 0x4a, 0x1a, 0x71, 0xd3, 0x88,
		0xdb, 0x50, 0x04, 0x95, 0x1b, 0x71, 0x2b, 0xf6, 0x8e, 0x9f, 0x3b, 0x70, 0xa5, 0x1e, 0xf2, 0x9a,
		0x2c, 0xac, 0xcd, 0xca, 0x26, 0x2c, 0x2d, 0xc4, 0xda, 0xa6, 0x2c, 0x2e, 0xc6, 0xea, 0x62, 0x2c,
		0x2f, 0xc7, 0xfa, 0x9a, 0xd6, 0x4d, 0xf1, 0xec, 0x55, 0x45, 0x62, 0xba, 0xd0, 0xed, 0x44, 0x4e,
		0xdb, 0xeb, 0xb8, 0x77, 0xe6, 0xd7, 0x61, 0x0f, 0xa4, 0x34, 0xf7, 0x7a, 0xa6, 0x67, 0xc9, 0x9e,
		0x2e, 0x0d, 0xc3, 0x29, 0x72, 0xba, 0xc2, 0x27, 0x21, 0x84, 0xc2, 0xc2, 0x28, 0x25, 0x94, 0xe2,
		0xc2, 0x29, 0x2e, 0xa4, 0xf2, 0xc2, 0x6a, 0x06, 0x7d, 0x35, 0x91, 0xbf, 0xfe, 0xd5, 0xfa, 0x1c,
		0xe7, 0x68, 0x77, 0xca, 0x7d, 0x2a, 0x47, 0x07, 0x06, 0x24, 0xcc, 0x3a, 0xe7, 0xca, 0xf8, 0x42,
		0x3b, 0x52, 0x9d, 0x74, 0x85, 0x14, 0xcc, 0x1c, 0x39, 0xa1, 0xce, 0xba, 0x53, 0x7a, 0x82, 0xdd,
		0x5f, 0x05, 0x1c, 0xd9, 0x87, 0x23, 0x10, 0xe8, 0xb8, 0x6b, 0xfb, 0x08, 0xa4, 0x3a, 0xf0, 0x5a,
		0x3d, 0x8b, 0x67, 0x9b, 0x59, 0xdd, 0x48, 0xa9, 0x13, 0xb0, 0x4e, 0xab, 0xb3, 0x56, 0xc7, 0xf7,
		0x82, 0xd8, 0x71, 0x3b, 0x91, 0x39, 0x86, 0x99, 0xa1, 0x65, 0x0e, 0x62, 0xa6, 0x1d, 0x2a, 0xc1,
		0x32, 0x60, 0x19, 0xb0, 0x8c, 0x26, 0xe7, 0x78, 0x41, 0xff, 0xd6, 0x0b, 0x5d, 0x8d, 0x31, 0x36,
		0x0b, 0xbd, 0xf1, 0xaa, 0x01, 0x0d, 0xbd, 0x11, 0x41, 0x06, 0xda, 0xd0, 0xaa, 0xcf, 0xa8, 0x19,
		0xc9, 0xb4, 0x19, 0xd1, 0x9c, 0x44, 0x09, 0x95, 0x42, 0x9b, 0xea, 0xbb, 0xa5, 0xd4, 0x38, 0xb7,
		0xd3, 0xee, 0x19, 0xf4, 0xcb, 0x1d, 0xac, 0x26, 0x6e, 0x44, 0xdc, 0xa8, 0x68, 0x71, 0x23, 0xcd,
		0x90, 0xaa, 0x4c, 0x68, 0xd5, 0x50, 0x54, 0x40, 0x48, 0x20, 0xa4, 0xcd, 0x23, 0x24, 0x5d, 0xd1,
		0x9b, 0x12, 0xf0, 0x02, 0xf7, 0x4b, 0xc7, 0x6b, 0x9b, 0x1f, 0xf5, 0x03, 0xd2, 0x1a, 0x11, 0x34,
		0x3c, 0x97, 0x19, 0x0f, 0xe8, 0xda, 0xed, 0x44, 0x9e, 0x29, 0x3d, 0xa1, 0x41, 0x3b, 0xa6, 0xc2,
		0x2e, 0x29, 0xf4, 0x96, 0x84, 0x5f, 0x5a, 0x09, 0x58, 0x53, 0x06, 0xd6, 0x94, 0x82, 0x3d, 0xe5,
		0x20, 0x14, 0x81, 0x31, 0xe4, 0x3d, 0x63, 0xb7, 0x6a, 0x8e, 0xf3, 0xf4, 0xcb, 0x30, 0x97, 0x5a,
		0xe3, 0xf2, 0x86, 0x82, 0x54, 0x26, 0x23, 0xc1, 0xa2, 0xa0, 0xdb, 0xed, 0xf9, 0xc1, 0x8d, 0x9c,
		0x36, 0x9d, 0x52, 0x44, 0x9d, 0xa2, 0x4e, 0x51, 0xa7, 0xa8, 0xd3, 0xdc, 0xa9, 0xd3, 0x54, 0xe1,
		0xb0, 0x61, 0x34, 0x2a, 0x95, 0xa8, 0x54, 0xa7, 0xd3, 0xee, 0x69, 0x85, 0xa6, 0x0c, 0x42, 0x80,
		0x1a, 0xd1, 0x94, 0xc0, 0xf3, 0x6f, 0xbe, 0x7e, 0xe9, 0x86, 0x02, 0xf7, 0x21, 0x0f, 0xa4, 0x36,
		0xec, 0xa1, 0x57, 0xf0, 0xd0, 0xf1, 0xd0, 0xf3, 0xe6, 0xa1, 0x4f, 0xa4, 0x47, 0x0e, 0x54, 0x4e,
		0x29, 0xca, 0x80, 0xc0, 0x32, 0x20, 0x10, 0x10, 0xb8, 0xed, 0x20, 0xd0, 0x54, 0xcc, 0xa7, 0x84,
		0x0c, 0x63, 0xe2, 0x4b, 0x19, 0xd9, 0x28, 0x46, 0x6e, 0x49, 0xf4, 0xc5, 0x55, 0x80, 0x0d, 0x55,
		0x60, 0x59, 0x25, 0xd8, 0x52, 0x0d, 0xd6, 0x55, 0x84, 0x75, 0x55, 0x61, 0x5f, 0x65, 0xc8, 0xa8,
		0x0e, 0x21, 0x15, 0x22, 0xed, 0xc4, 0xa4, 0xef, 0xd4, 0x4c, 0x71, 0xfe, 0xf4, 0x27, 0x23, 0x3f,
		0x47, 0xfe, 0x94, 0x24, 0x92, 0x10, 0x5b, 0xfd, 0x28, 0xee, 0xde, 0x3a, 0x71, 0xe7, 0x5b, 0x64,
		0x41, 0x49, 0xcf, 0x10, 0xcf, 0xb8, 0xa6, 0xae, 0xe4, 0x43, 0x53, 0x6b, 0xe4, 0x4e, 0xa0, 0xa5,
		0x25, 0xb4, 0xf4, 0x70, 0xe3, 0x0b, 0xaa, 0xa1, 0xa5, 0xc0, 0xde, 0x94, 0x60, 0xdc, 0xf9, 0x26,
		0xcf, 0x52, 0xd3, 0xae, 0x90, 0x9d, 0x6f, 0xd2, 0xcc, 0x24, 0xab, 0x54, 0xac, 0xc1, 0x40, 0x9b,
		0x4a, 0x26, 0x05, 0x65, 0x63, 0x5b, 0xe9, 0xa4, 0xa6, 0x7c, 0x52, 0x53, 0x42, 0xe9, 0x28, 0x23,
		0x59, 0xa5, 0x24, 0xac, 0x9c, 0xac, 0x29, 0x29, 0x5b, 0x1e, 0x6a, 0x3a, 0x1e, 0x6b, 0x4a, 0x2a,
		0xcc, 0xba, 0x2a, 0x4b, 0x43, 0xa5, 0xa5, 0xa8, 0xda, 0xd2, 0x52, 0x71, 0xa9, 0xab, 0xba, 0xd4,
		0x55, 0x5e, 0xba, 0xaa, 0xcf, 0x8e, 0x0a, 0xb4, 0xa4, 0x0a, 0x6d, 0x7b, 0xd6, 0xd9, 0xf0, 0xb4,
		0x1f, 0x5c, 0xc7, 0x57, 0x71, 0xe7, 0x9b, 0xa8, 0xe7, 0x6d, 0xff, 0xd4, 0x2d, 0x9c, 0x78, 0xa9,
		0xdb, 0xf7, 0xed, 0x1b, 0xa9, 0xc1, 0x97, 0xd8, 0xb5, 0x50, 0x7b, 0x58, 0x28, 0x2c, 0x14, 0x16,
		0x6a, 0x3b, 0x2c, 0x94, 0x58, 0x2e, 0xd1, 0x5a, 0x89, 0xe9, 0x78, 0xee, 0xb5, 0x5e, 0xf3, 0x7c,
		0x65, 0x88, 0x7d, 0x60, 0xf1, 0x3b, 0x3e, 0x8d, 0x8d, 0xec, 0xcb, 0x97, 0xaf, 0xa2, 0xd8, 0x8d,
		0xbd, 0x57, 0x03, 0x85, 0xbc, 0xdd, 0x46, 0xcf, 0x89, 0xfa, 0x5f, 0x62, 0x9b, 0x7c, 0x34, 0x6b,
		0xfc, 0xa6, 0x5f, 0x86, 0x11, 0xc4, 0x08, 0x62, 0x04, 0x31, 0x82, 0x18, 0xc1, 0x6c, 0x18, 0xc1,
		0xa9, 0x62, 0xde, 0x62, 0x63, 0x38, 0xdc, 0x0c, 0xfb, 0x66, 0x70, 0xf4, 0x35, 0x39, 0x8f, 0x53,
		0x56, 0x30, 0x80, 0x18, 0x40, 0x0c, 0x60, 0x26, 0x0c, 0xa0, 0xad, 0xab, 0x9b, 0x54, 0x42, 0x63,
		0x8b, 0xbc, 0x04, 0xdb, 0xcc, 0x6b, 0xd7, 0x4b, 0x48, 0xcd, 0x5b, 0x48, 0x53, 0x69, 0x6e, 0x40,
		0x79, 0xa6, 0xad, 0x44, 0x37, 0xa6, 0x4c, 0x37, 0xa6, 0x54, 0x37, 0xa3, 0x5c, 0xed, 0x2a, 0x59,
		0xcb, 0xca, 0x36, 0x3d, 0xaf, 0x63, 0x01, 0x6e, 0x0c, 0xcd, 0x4b, 0x7b, 0x95, 0x40, 0xe4, 0xeb,
		0x67, 0xf9, 0x3c, 0x7f, 0x8b, 0x67, 0x9f, 0x4a, 0xc4, 0x6c, 0x91, 0x4d, 0xb4, 0x1c, 0x39, 0xc3,
		0x36, 0x62, 0x1b, 0xb1, 0x8d, 0xd8, 0x46, 0x6c, 0x23, 0xb6, 0x51, 0x7b, 0x6f, 0xd2, 0x35, 0x8a,
		0x58, 0x43, 0xac, 0x21, 0xd6, 0x10, 0x6b, 0x88, 0x35, 0x7c, 0x2a, 0x71, 0xa6, 0x93, 0x18, 0x54,
		0xd5, 0xe3, 0x7e, 0x0a, 0x5f, 0x25, 0x33, 0xd9, 0x21, 0xe9, 0x9f, 0x74, 0xf4, 0xc7, 0x8e, 0xf4,
		0xa4, 0x08, 0x65, 0x14, 0xf3, 0x22, 0xdd, 0xaf, 0x9d, 0x8c, 0x3d, 0xa8, 0x94, 0xab, 0x07, 0xd5,
		0xd7, 0xfb, 0xf5, 0xea, 0xeb, 0x94, 0x1f, 0xc0, 0xc2, 0x78, 0x84, 0x8c, 0xa8, 0x99, 0xc7, 0x3c,
		0xe5, 0x7e, 0xdf, 0x18, 0x4f, 0xed, 0x6d, 0x9a, 0xa7, 0x0e, 0xb6, 0x88, 0xa7, 0x9e, 0x15, 0xe3,
		0x5b, 0x1a, 0x38, 0x53, 0x73, 0x6c, 0xf5, 0x6d, 0xcc, 0xd7, 0x29, 0x79, 0x53, 0xa3, 0xaf, 0xc3,
		0x9d, 0xc2, 0x9d, 0xc2, 0x9d, 0xc2, 0x9d, 0xc2, 0x9d, 0x9a, 0xed, 0xaf, 0xe9, 0x07, 0x6e, 0x78,
		0x97, 0xa2, 0x3f, 0x75, 0x98, 0x57, 0x73, 0x48, 0x79, 0xdf, 0x82, 0xef, 0xc9, 0x42, 0x79, 0xdf,
		0x28, 0xe7, 0x70, 0x8b, 0x73, 0x3b, 0xd3, 0xa9, 0x70, 0xa0, 0xb4, 0x61, 0xa3, 0x58, 0x89, 0xcc,
		0xce, 0x1c, 0x62, 0x21, 0x32, 0x3b, 0x37, 0x88, 0x75, 0x0a, 0x5f, 0xda, 0x90, 0xab, 0x9a, 0x86,
		0x4c, 0x37, 0x88, 0xf9, 0xa7, 0x77, 0x37, 0x31, 0x71, 0x3b, 0xdd, 0xbe, 0xbf, 0x63, 0x2f, 0x27,
		0xa9, 0x74, 0xea, 0x47, 0xf1, 0x51, 0x1c, 0x5b, 0x6a, 0x48, 0xf3, 0xc1, 0x0f, 0x8e, 0x3b, 0xde,
		0x40, 0xe3, 0x44, 0x76, 0xcc, 0x5d, 0xe9, 0x83, 0xfb, 0x7d, 0xe6, 0x1b, 0xca, 0xaf, 0xab, 0xd5,
		0xfa, 0x41, 0xb5, 0xba, 0x77, 0xb0, 0x7f, 0xb0, 0x77, 0x58, 0xab, 0x95, 0xeb, 0xe5, 0x9a, 0x85,
		0x2f, 0x3d, 0x0b, 0xdb, 0x5e, 0xe8, 0xb5, 0x7f, 0x1d, 0x9c, 0x52, 0xd0, 0xef, 0x74, 0x32, 0xcd,
		0x4c, 0x96, 0xb1, 0x77, 0x16, 0x30, 0x77, 0xc9, 0x4a, 0x85, 0x52, 0xd8, 0x6f, 0xc5, 0xc1, 0x58,
		0x67, 0x5f, 0x8e, 0x1f, 0xfd, 0xdd, 0xf0, 0xc9, 0x9b, 0x6f, 0x47, 0x0f, 0xda, 0x3c, 0x1e, 0x3f,
		0x68, 0xf3, 0xb4, 0xd3, 0xee, 0x35, 0x3f, 0x8e, 0x1f, 0xaf, 0x79, 0xd9, 0xf9, 0x26, 0xab, 0x08,
		0xef, 0x69, 0xa8, 0x9a, 0x27, 0x9e, 0x2c, 0x52, 0x57, 0x55, 0xbf, 0x2d, 0xdf, 0x4c, 0xd5, 0x6f,
		0x0b, 0xf7, 0x50, 0xdd, 0xa3, 0xdb, 0x75, 0xd6, 0xbd, 0x2d, 0xba, 0x5d, 0xe7, 0x4d, 0x39, 0x8b,
		0x7b, 0x44, 0x16, 0x3d, 0x20, 0x1b, 0x1e, 0xcf, 0xbc, 0x87, 0xe3, 0xb7, 0x8b, 0xa4, 0xd9, 0x65,
		0x6b, 0xb0, 0xad, 0xd4, 0x5c, 0x6f, 0x7b, 0x8f, 0x6c, 0xf4, 0x3b, 0xfa, 0xdd, 0x9a, 0x7e, 0x17,
		0xef, 0x95, 0xed, 0xde, 0x78, 0xf6, 0x7a, 0x65, 0x0f, 0x88, 0xdb, 0xe9, 0x95, 0xbd, 0x47, 0xaf,
		0x6c, 0x7a, 0x65, 0x67, 0x49, 0x11, 0x2d, 0x53, 0x48, 0xdb, 0xd8, 0x2b, 0xdb, 0x5a, 0x58, 0x7e,
		0xca, 0xf1, 0x7d, 0x3f, 0x88, 0xeb, 0x55, 0x1b, 0x0c, 0x3f, 0xd6, 0x2f, 0x16, 0x12, 0x6f, 0x2d,
		0xa7, 0x68, 0x5b, 0xbc, 0x04, 0x49, 0x23, 0x05, 0x3b, 0xad, 0xdc, 0xb7, 0x49, 0x3a, 0xac, 0xed,
		0xef, 0x49, 0x31, 0xeb, 0xd5, 0x66, 0x96, 0x65, 0x1a, 0x99, 0xd2, 0x69, 0x1f, 0x7d, 0x3a, 0x17,
		0x0e, 0x1b, 0xe3, 0x86, 0x9c, 0xdc, 0xe6, 0x35, 0xb2, 0x1a, 0x6c, 0x17, 0x74, 0xdb, 0x5a, 0x5f,
		0xdd, 0x28, 0xf2, 0x23, 0x47, 0x30, 0x1e, 0x3b, 0x67, 0x0a, 0x67, 0xbe, 0x03, 0xa8, 0x0d, 0xd4,
		0x06, 0x6a, 0x03, 0xb5, 0x45, 0x39, 0xde, 0x5a, 0xeb, 0x00, 0x4b, 0xad, 0x02, 0xb2, 0x6e, 0x09,
		0x1c, 0x2b, 0xa9, 0x96, 0x0b, 0xcc, 0x81, 0x63, 0x23, 0xf5, 0x04, 0x9b, 0x80, 0x4d, 0xc0, 0x26,
		0x6c, 0xbb, 0x4d, 0xb0, 0xab, 0x64, 0x1e, 0x19, 0x87, 0xaa, 0x05, 0xda, 0xc7, 0x41, 0xff, 0x76,
		0xb0, 0x41, 0xf7, 0x5b, 0x60, 0x78, 0x6c, 0xba, 0x1e, 0xb8, 0x1c, 0x98, 0x17, 0xcc, 0x0b, 0xe6,
		0x05, 0x97, 0x23, 0x8b, 0x9a, 0xbf, 0xe3, 0x46, 0xb1, 0xd3, 0xef, 0xb5, 0x6d, 0x34, 0xed, 0x7f,
		0xc8, 0x0a, 0x9a, 0xf9, 0x12, 0x6c, 0x01, 0xb6, 0x00, 0x5b, 0x80, 0x2d, 0x90, 0xc5, 0x98, 0x96,
		0x2f, 0x7a, 0xab, 0x5c, 0xf4, 0x3e, 0x3c, 0x78, 0x9a, 0x17, 0xbd, 0xe5, 0x94, 0x6e, 0xfb, 0x0e,
		0x2b, 0x95, 0xfd, 0xfd, 0x83, 0xca, 0xde, 0x7e, 0xfd, 0x75, 0xad, 0x7a, 0x70, 0x50, 0x7b, 0xbd,
		0xf7, 0x9a, 0xab, 0xdf, 0x44, 0xcc, 0x50, 0xc0, 0xab, 0xdf, 0x79, 0x66, 0x38, 0xe0, 0xe6, 0x37,
		0x6d, 0xaa, 0xdb, 0x70, 0xf3, 0x7b, 0xeb, 0x06, 0xee, 0xcd, 0xb0, 0xc4, 0xd1, 0x71, 0xdb, 0xed,
		0xd0, 0x8b, 0x22, 0x7b, 0x18, 0x7c, 0xc1, 0x77, 0x01, 0xc5, 0x81, 0xe2, 0x40, 0x71, 0xa0, 0x38,
		0x61, 0x99, 0x1c, 0x58, 0x06, 0xcb, 0x37, 0xc2, 0xcb, 0xbe, 0x10, 0x1b, 0x81, 0x8d, 0xc0, 0x46,
		0x60, 0x23, 0xb0, 0x11, 0x99, 0xb3, 0x11, 0xbd, 0x6e, 0x18, 0x3b, 0x6d, 0x2f, 0x6a, 0x85, 0x7e,
		0xcf, 0x4a, 0x13, 0x90, 0xe9, 0x79, 0xcd, 0x7d, 0x13, 0x56, 0x01, 0xab, 0x80, 0x55, 0xc0, 0x2a,
		0x60, 0x15, 0xb2, 0x69, 0x15, 0x6c, 0xe6, 0xf3, 0x4c, 0xbe, 0x00, 0x1b, 0x80, 0x0d, 0xc0, 0x06,
		0x60, 0x03, 0xb0, 0x01, 0x59, 0xb5, 0x01, 0x96, 0x43, 0x46, 0x8f, 0xbe, 0x05, 0x6b, 0x80, 0x35,
		0xc0, 0x1a, 0x60, 0x0d, 0xf2, 0xa2, 0x61, 0x76, 0x28, 0x1f, 0x10, 0x6c, 0xca, 0x79, 0x17, 0xc5,
		0xde, 0x6d, 0x3a, 0xb1, 0xa8, 0x05, 0xdf, 0x85, 0xed, 0xc1, 0xf6, 0x60, 0x7b, 0xb0, 0x3d, 0x79,
		0xf3, 0x44, 0x2c, 0xd0, 0x3e, 0xf5, 0x82, 0x9b, 0x61, 0x6b, 0x4b, 0xb2, 0x4a, 0xd3, 0x53, 0xed,
		0x73, 0x5f, 0x43, 0xfb, 0x20, 0xb5, 0xa3, 0x2f, 0x60, 0x0e, 0x69, 0xa5, 0x46, 0xb7, 0xa0, 0xd4,
		0xa9, 0x36, 0xb6, 0x07, 0x6b, 0x8f, 0xc7, 0x17, 0xd8, 0x05, 0xd9, 0xc3, 0x2f, 0x01, 0x5d, 0x83,
		0xae, 0x41, 0xd7, 0xa0, 0x6b, 0xd0, 0x35, 0xe8, 0x1a, 0x74, 0x0d, 0xba, 0x06, 0x5d, 0x83, 0xae,
		0x0b, 0x8b, 0xae, 0xe3, 0xb8, 0x63, 0x0f, 0x55, 0x0f, 0x88, 0x83, 0xa6, 0x41, 0xd3, 0xa0, 0x69,
		0xd0, 0xb4, 0x28, 0xc7, 0xf7, 0xfd, 0x20, 0x2e, 0xd7, 0x2d, 0xa2, 0xe9, 0x3a, 0xfd, 0x0f, 0xc0,
		0xd2, 0x60, 0xe9, 0x42, 0x62, 0xe9, 0x7a, 0xad, 0xb6, 0x0f, 0x9a, 0x06, 0x4d, 0x8b, 0x52, 0x62,
		0x8c, 0xec, 0xfc, 0x18, 0xd9, 0xd1, 0xf8, 0xbc, 0xac, 0x8c, 0x19, 0x7c, 0xb6, 0xc1, 0xe3, 0x9d,
		0x8c, 0x41, 0x37, 0xae, 0x22, 0x90, 0x1d, 0x72, 0x2e, 0x3f, 0xd4, 0x3c, 0x95, 0x21, 0xe6, 0xb2,
		0x43, 0xcb, 0x4d, 0x8f, 0x56, 0x58, 0x62, 0x37, 0x21, 0xa9, 0x25, 0x91, 0x11, 0x9c, 0xda, 0x43,
		0xc6, 0xcd, 0x54, 0x84, 0xbe, 0x60, 0xeb, 0xad, 0xd4, 0xe4, 0x17, 0x29, 0x3e, 0x49, 0x91, 0x3f,
		0xf4, 0xce, 0x45, 0x7d, 0x57, 0x35, 0x76, 0xd4, 0x70, 0xe2, 0xab, 0xc8, 0x84, 0x57, 0xc3, 0x96,
		0x6d, 0xc6, 0x13, 0x5c, 0x25, 0x62, 0x4b, 0xc2, 0x13, 0x5a, 0xa5, 0xe2, 0x45, 0xe2, 0x71, 0x21,
		0xf1, 0xf8, 0x8f, 0xfc, 0x84, 0xd5, 0x74, 0xb5, 0x91, 0xe9, 0xc4, 0xd4, 0x52, 0xab, 0xdb, 0x0f,
		0x62, 0x2f, 0x34, 0x6f, 0xe0, 0xf5, 0xd0, 0x3e, 0x7f, 0x42, 0xd1, 0x14, 0x6b, 0x89, 0x74, 0x52,
		0x14, 0x0b, 0x09, 0x4b, 0x86, 0x80, 0x2d, 0x84, 0x7c, 0xa5, 0x43, 0xbc, 0xd6, 0x42, 0xba, 0xd6,
		0x42, 0xb8, 0x76, 0x42, 0xb6, 0x9b, 0xf5, 0x37, 0xa4, 0x06, 0x22, 0x97, 0xae, 0x43, 0xf7, 0xd6,
		0x73, 0xda, 0x7e, 0xd4, 0x72, 0xc3, 0xb6, 0xfc, 0x84, 0xf5, 0xc7, 0xe4, 0x65, 0x27, 0xad, 0xef,
		0x49, 0x4f, 0x5a, 0xdf, 0xcb, 0xc7, 0xa4, 0x75, 0xe1, 0xbb, 0x20, 0xa6, 0xac, 0xa7, 0xab, 0x38,
		0xb2, 0x19, 0x97, 0x12, 0xbf, 0xd3, 0x79, 0x6a, 0xf6, 0x45, 0xdb, 0x59, 0x5b, 0x98, 0x57, 0x6c,
		0xe9, 0xfa, 0xc6, 0xc2, 0x25, 0x99, 0xcd, 0xeb, 0x1a, 0xcb, 0xb1, 0x7a, 0xdb, 0xd7, 0x33, 0x69,
		0xc4, 0xe5, 0x2d, 0x5c, 0xc7, 0x58, 0xbd, 0x86, 0x49, 0xeb, 0x48, 0xd3, 0x9b, 0x2f, 0x9c, 0xca,
		0x29, 0x67, 0xf4, 0x36, 0xa3, 0x91, 0x95, 0x70, 0xfb, 0x0b, 0x29, 0xec, 0xe9, 0x85, 0x61, 0x37,
		0x74, 0x04, 0x75, 0xda, 0x13, 0xf0, 0x39, 0xa5, 0x0f, 0xfa, 0x04, 0x7d, 0x82, 0x3e, 0x41, 0x9f,
		0xa0, 0x4f, 0xd0, 0x27, 0xe8, 0x13, 0xf4, 0x09, 0xfa, 0x04, 0x7d, 0x8e, 0xd1, 0x61, 0xb7, 0x1f,
		0xdb, 0x85, 0x9f, 0x83, 0x2f, 0x00, 0x7f, 0x82, 0x3f, 0xc1, 0x9f, 0xe0, 0x4f, 0xf0, 0x27, 0xf8,
		0x13, 0xfc, 0x09, 0xfe, 0x04, 0x7f, 0x82, 0x3f, 0x2d, 0xc6, 0x3d, 0x89, 0x78, 0x82, 0x38, 0x41,
		0x9c, 0x20, 0x4e, 0x10, 0x27, 0x88, 0x13, 0xc4, 0x09, 0xe2, 0x04, 0x71, 0x82, 0x38, 0x07, 0xb8,
		0xd0, 0x62, 0xac, 0x93, 0x28, 0x27, 0x98, 0x13, 0xcc, 0x09, 0xe6, 0x04, 0x73, 0x82, 0x39, 0xc1,
		0x9c, 0x60, 0x4e, 0x30, 0xe7, 0xd6, 0x63, 0xce, 0x8e, 0x1b, 0xc5, 0x4e, 0xab, 0xe3, 0xb9, 0xa1,
		0x3c, 0xe8, 0x9c, 0xa1, 0x0d, 0xea, 0x04, 0x75, 0x82, 0x3a, 0xb7, 0x0c, 0x75, 0xb6, 0xdd, 0xd8,
		0x73, 0xdc, 0xa0, 0xed, 0xc4, 0xbe, 0x68, 0x5b, 0x77, 0x1b, 0x2d, 0x97, 0x4b, 0x9f, 0xdc, 0x38,
		0xf6, 0xc2, 0x40, 0x1c, 0x7c, 0x96, 0xae, 0xae, 0xda, 0x3f, 0xaa, 0xf7, 0xce, 0xe0, 0xaf, 0xca,
		0xe4, 0xaf, 0xcb, 0xd1, 0x5f, 0x6f, 0x1e, 0xfd, 0xf5, 0xfc, 0xea, 0xea, 0xe5, 0xd5, 0x55, 0xfb,
		0xbf, 0x76, 0x7f, 0x79, 0xfe, 0xef, 0x9f, 0x9f, 0xaf, 0xae, 0xfe, 0xeb, 0xea, 0xca, 0x69, 0x3c,
		0xfa, 0xc4, 0x6e, 0x09, 0x1b, 0xb6, 0x60, 0x87, 0xe3, 0xce, 0x37, 0x7b, 0x15, 0xb2, 0xb3, 0xc4,
		0xb1, 0x62, 0x58, 0x31, 0xac, 0x18, 0xb1, 0x13, 0x62, 0x27, 0xc4, 0x4e, 0x88, 0x9d, 0x10, 0x3b,
		0x21, 0x76, 0xb2, 0xf5, 0xb8, 0xb3, 0x1f, 0xfc, 0x19, 0x74, 0xff, 0x37, 0xb0, 0x83, 0x3b, 0x27,
		0xc4, 0xc1, 0x9d, 0xe0, 0x4e, 0x70, 0x27, 0xb8, 0x13, 0xdc, 0x09, 0xee, 0x04, 0x77, 0x82, 0x3b,
		0xc1, 0x9d, 0xf9, 0xc5, 0x9d, 0xf4, 0xca, 0x56, 0xe9, 0x85, 0x3c, 0xec, 0x0f, 0xfc, 0x4a, 0xa8,
		0x33, 0xe9, 0x8e, 0x66, 0x9f, 0xec, 0xb7, 0x93, 0xaf, 0xdf, 0x54, 0x9f, 0x6c, 0x83, 0x86, 0xc0,
		0x5e, 0xe0, 0x7e, 0xe9, 0x78, 0x6d, 0xb9, 0x2e, 0xb1, 0x13, 0x82, 0xa6, 0x0d, 0x32, 0xbd, 0x6b,
		0xb7, 0xdf, 0x19, 0x22, 0xc4, 0x6b, 0xb7, 0x13, 0x79, 0x42, 0x4d, 0x67, 0xf7, 0x0a, 0xde, 0x74,
		0x56, 0xa0, 0x47, 0xb4, 0x2d, 0xff, 0x25, 0xff, 0x8d, 0x67, 0xcd, 0x7b, 0x48, 0x67, 0x43, 0xcb,
		0x8b, 0xf9, 0x24, 0x53, 0xce, 0xfb, 0xd2, 0xed, 0x76, 0x3c, 0x57, 0x22, 0x10, 0x31, 0xbd, 0xbb,
		0x2d, 0xe7, 0x50, 0x99, 0x46, 0x41, 0xb7, 0xdb, 0xf3, 0x83, 0x1b, 0x39, 0x6d, 0x3a, 0xa5, 0x88,
		0x3a, 0x45, 0x9d, 0xa2, 0x4e, 0x51, 0xa7, 0xb9, 0x53, 0xa7, 0xcc, 0x70, 0x59, 0xea, 0xb7, 0xa4,
		0x36, 0xbf, 0xe5, 0x99, 0xc5, 0xbd, 0x37, 0xdd, 0x73, 0xeb, 0x7b, 0x5d, 0xd2, 0x9a, 0x5e, 0xa3,
		0xea, 0x04, 0xaa, 0x9d, 0x65, 0xf2, 0x13, 0x51, 0x38, 0x0d, 0xcd, 0x99, 0x3b, 0x46, 0xb3, 0x76,
		0x34, 0x87, 0x79, 0x68, 0xcf, 0xd6, 0x31, 0x31, 0xf4, 0x42, 0x86, 0xdd, 0xd4, 0x90, 0x8b, 0x19,
		0x6e, 0x31, 0x43, 0x2d, 0x67, 0x98, 0xed, 0x6a, 0x1a, 0xdd, 0xa1, 0x19, 0x25, 0xb7, 0x13, 0x39,
		0x6d, 0xaf, 0xe3, 0xde, 0x99, 0x0f, 0xa4, 0x7a, 0x20, 0xa5, 0x3b, 0xd8, 0xe7, 0x01, 0x89, 0xef,
		0x19, 0x0e, 0xb6, 0xda, 0x33, 0x1d, 0x6c, 0xb5, 0xc7, 0x60, 0x2b, 0xdb, 0xa8, 0x9a, 0xc1, 0x56,
		0xd2, 0x68, 0xf9, 0xd1, 0x90, 0xf1, 0xfd, 0x8a, 0x09, 0xd3, 0x8c, 0xe5, 0xe8, 0xc0, 0x80, 0x84,
		0xcc, 0xed, 0xa6, 0xcc, 0xa8, 0x50, 0x41, 0xdf, 0x52, 0x36, 0x13, 0x44, 0xf8, 0x76, 0xd2, 0xc6,
		0x3d, 0xd5, 0xbd, 0xcc, 0x6c, 0xd5, 0xcc, 0x1f, 0x41, 0xb5, 0x72, 0x58, 0x3d, 0xac, 0x1f, 0x54,
		0x0e, 0x6b, 0x19, 0x3e, 0x8b, 0x0d, 0xf9, 0xaa, 0x8d, 0x0c, 0xcf, 0xd3, 0x6c, 0x75, 0x7c, 0x2f,
		0x88, 0x1d, 0xb7, 0x13, 0x99, 0x63, 0x98, 0x19, 0x5a, 0xe6, 0x20, 0xe6, 0xf8, 0xf2, 0x1f, 0xc7,
		0xe7, 0x1f, 0x8f, 0x2f, 0xc1, 0x32, 0x60, 0x19, 0xb0, 0x8c, 0x2e, 0xe7, 0x78, 0x41, 0xff, 0xd6,
		0x0b, 0x47, 0x51, 0x14, 0x73, 0x40, 0x53, 0xae, 0x1a, 0xd0, 0x38, 0x0e, 0xfa, 0xb7, 0x83, 0x97,
		0xba, 0xcf, 0xb0, 0x36, 0xf4, 0x03, 0xe7, 0xf5, 0x5e, 0xa5, 0xfc, 0xff, 0x9c, 0x61, 0xdf, 0x1a,
		0x01, 0x95, 0xf8, 0x94, 0x20, 0xca, 0x6c, 0x20, 0x8f, 0x5e, 0xfc, 0x15, 0x3d, 0xa6, 0xa1, 0xc7,
		0x06, 0xfb, 0xb6, 0x75, 0x2a, 0x4c, 0x22, 0x1f, 0x55, 0x20, 0xff, 0x14, 0x8f, 0x0c, 0x8f, 0x2c,
		0x57, 0x1e, 0x99, 0xbd, 0xfc, 0x4e, 0x7c, 0xb3, 0xd4, 0xd0, 0xc8, 0x97, 0x4e, 0xb7, 0xf5, 0xe7,
		0x68, 0x56, 0x88, 0x0c, 0x1a, 0x79, 0x44, 0x10, 0x34, 0x02, 0x1a, 0x01, 0x8d, 0x80, 0x46, 0x40,
		0x23, 0xa0, 0x11, 0xd0, 0x08, 0x68, 0x64, 0x1d, 0x1a, 0x69, 0x85, 0x2d, 0x49, 0x2c, 0x32, 0x43,
		0x0e, 0x24, 0x02, 0x12, 0x01, 0x89, 0x80, 0x44, 0x40, 0x22, 0x20, 0x11, 0x90, 0x08, 0x48, 0x64,
		0x1d, 0x12, 0xb9, 0x0e, 0xdd, 0x9b, 0x81, 0x01, 0x90, 0xbc, 0xa8, 0x79, 0x4a, 0x13, 0x4c, 0x02,
		0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98, 0x64, 0x1d, 0x26, 0xf9,
		0xbf, 0xee, 0x97, 0x2f, 0x5e, 0x28, 0x89, 0x48, 0x1e, 0x53, 0x04, 0x8f, 0x80, 0x47, 0xc0, 0x23,
		0xe0, 0x11, 0xf0, 0x08, 0x78, 0x04, 0x3c, 0x02, 0x1e, 0x59, 0x87, 0x47, 0x6e, 0xdd, 0x96, 0xd3,
		0xea, 0x06, 0x71, 0xd8, 0xed, 0x48, 0x82, 0x92, 0x05, 0x64, 0x41, 0x26, 0x20, 0x13, 0x90, 0x09,
		0xc8, 0x04, 0x64, 0x02, 0x32, 0x01, 0x99, 0x80, 0x4c, 0x92, 0x20, 0x93, 0x9e, 0xdb, 0x8f, 0x3c,
		0x69, 0x5c, 0xf2, 0x88, 0x28, 0xa8, 0x04, 0x54, 0x02, 0x2a, 0x01, 0x95, 0x80, 0x4a, 0x40, 0x25,
		0xa0, 0x12, 0x50, 0xc9, 0x3a, 0x54, 0xd2, 0xfd, 0xe6, 0x85, 0x91, 0xff, 0x97, 0x28, 0x28, 0x79,
		0x4a, 0x13, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98,
		0x64, 0x1d, 0x26, 0xe9, 0xb5, 0x22, 0xe7, 0x8b, 0xdf, 0x93, 0xac, 0xba, 0x79, 0x42, 0x12, 0x44,
		0x42, 0x7b, 0x25, 0x43, 0x58, 0xb2, 0xbd, 0xed, 0x95, 0xc0, 0x26, 0x60, 0x13, 0xb0, 0x09, 0xd8,
		0x64, 0x6b, 0xb1, 0xc9, 0x10, 0x44, 0x78, 0x6d, 0x27, 0xf2, 0x5a, 0xdd, 0xa0, 0x2d, 0x07, 0x50,
		0x9e, 0xd2, 0x05, 0xa5, 0x80, 0x52, 0x40, 0x29, 0xa0, 0x14, 0x50, 0x0a, 0x28, 0x05, 0x94, 0x02,
		0x4a, 0x51, 0x43, 0x29, 0x91, 0xf7, 0xcd, 0x0b, 0xbd, 0xce, 0x9d, 0x35, 0xb8, 0xb2, 0xf4, 0x0b,
		0xc0, 0x2d, 0xe0, 0x16, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0x02, 0x6e, 0x01, 0xb7, 0x80, 0x5b, 0xd4,
		0x70, 0x4b, 0x3f, 0x70, 0xbf, 0xb9, 0x7e, 0xc7, 0xfd, 0xd2, 0xf1, 0xc4, 0x21, 0xcb, 0x22, 0xda,
		0xa0, 0x15, 0xd0, 0x0a, 0x68, 0x05, 0xb4, 0x02, 0x5a, 0x01, 0xad, 0x80, 0x56, 0x40, 0x2b, 0xc9,
		0xd1, 0x4a, 0x3f, 0x68, 0xcb, 0x27, 0xcf, 0xce, 0x11, 0x05, 0x9f, 0x90, 0x3d, 0xab, 0x0f, 0x4d,
		0xc8, 0x9e, 0x05, 0x95, 0x80, 0x4a, 0x40, 0x25, 0xa0, 0x92, 0xad, 0x40, 0x25, 0xdd, 0x7e, 0x2c,
		0x3c, 0xcc, 0x6f, 0x8e, 0x22, 0x78, 0x04, 0x3c, 0x02, 0x1e, 0x01, 0x8f, 0x80, 0x47, 0xc0, 0x23,
		0xe0, 0x11, 0xf0, 0xc8, 0x5a, 0x3c, 0x22, 0x3b, 0xce, 0x6f, 0x8e, 0x22, 0x78, 0x84, 0xfb, 0x1b,
		0x43, 0x50, 0xc2, 0xfd, 0x0d, 0xc8, 0x04, 0x64, 0x02, 0x32, 0x01, 0x99, 0x6c, 0x17, 0x32, 0x91,
		0x1c, 0xed, 0xf7, 0x84, 0x1e, 0xa8, 0x04, 0x54, 0x02, 0x2a, 0x01, 0x95, 0x80, 0x4a, 0x40, 0x25,
		0xa0, 0x12, 0x50, 0x89, 0x02, 0x2a, 0xb1, 0xd1, 0xc2, 0x7e, 0x09, 0x5d, 0x50, 0x0a, 0x77, 0x39,
		0xfa, 0x00, 0x85, 0xbb, 0x1c, 0xb0, 0x09, 0xd8, 0x04, 0x6c, 0x02, 0x36, 0xd9, 0x2a, 0x6c, 0x22,
		0xdb, 0xc4, 0x7e, 0x21, 0x55, 0x70, 0x09, 0xb8, 0x04, 0x5c, 0x02, 0x2e, 0x01, 0x97, 0x80, 0x4b,
		0xc0, 0x25, 0xe0, 0x92, 0xb5, 0xb8, 0x44, 0xba, 0x65, 0xec, 0x02, 0x9a, 0x60, 0x12, 0x6e, 0x74,
		0x0c, 0x81, 0x09, 0x37, 0x3a, 0xa0, 0x13, 0xd0, 0x09, 0xe8, 0x04, 0x74, 0x92, 0x53, 0x74, 0xf2,
		0xcc, 0x22, 0x8f, 0x96, 0x8e, 0x82, 0xa0, 0x1b, 0xbb, 0x83, 0x23, 0xd1, 0x62, 0xcb, 0x52, 0xd4,
		0xfa, 0xea, 0xdd, 0xba, 0x3d, 0x37, 0xfe, 0x3a, 0xd0, 0xb8, 0xaf, 0xba, 0x3d, 0x2f, 0x68, 0x0d,
		0xd1, 0xc3, 0xd0, 0xe6, 0xf8, 0x81, 0xdb, 0x71, 0xda, 0xde, 0x37, 0xbf, 0xe5, 0xbd, 0x7a, 0xfa,
		0xdf, 0x9d, 0xee, 0x8d, 0xdf, 0x72, 0x3b, 0x4e, 0xeb, 0xab, 0x1b, 0x04, 0x5e, 0x27, 0x7a, 0x35,
		0xfe, 0xe1, 0x95, 0x17, 0x7f, 0xf5, 0xc2, 0xc0, 0x8b, 0x5f, 0x45, 0xb1, 0x1b, 0x7b, 0x6a, 0x66,
		0x2b, 0xf9, 0x66, 0x25, 0xfb, 0x64, 0xc2, 0xed, 0xd4, 0xdd, 0x46, 0x9b, 0xdb, 0xa7, 0x60, 0xf4,
		0x4a, 0x51, 0x1c, 0xf6, 0x5b, 0x71, 0x30, 0xb6, 0x9b, 0x97, 0xe3, 0xaf, 0x7a, 0x37, 0xfc, 0xa6,
		0xe6, 0xdb, 0x11, 0xe1, 0xe6, 0xf1, 0x84, 0xf0, 0x33, 0x99, 0xfd, 0x4d, 0xb0, 0xb7, 0x25, 0x3f,
		0x68, 0x7b, 0xc9, 0x15, 0xe6, 0x4c, 0x49, 0xfb, 0x60, 0x59, 0xc2, 0xb3, 0x53, 0xd3, 0xa2, 0xca,
		0xe0, 0x58, 0x07, 0x0c, 0x1b, 0x82, 0x5f, 0x5d, 0xb0, 0x6b, 0x0c, 0x6e, 0x8d, 0xc1, 0xac, 0x39,
		0x78, 0x95, 0x95, 0x6b, 0x65, 0x30, 0x3a, 0x3d, 0xb9, 0x8e, 0xe7, 0x5e, 0x87, 0xde, 0xb5, 0xca,
		0xa9, 0x8d, 0x19, 0xb1, 0x7c, 0xa0, 0xb0, 0xe6, 0xd3, 0x58, 0x75, 0xbc, 0x7c, 0x39, 0x52, 0x97,
		0xaf, 0x46, 0xac, 0x9f, 0xaa, 0x88, 0xde, 0x84, 0x5e, 0x14, 0xe9, 0x08, 0xe9, 0x68, 0xa1, 0x9a,
		0x98, 0x96, 0x11, 0x53, 0xc4, 0xf4, 0xe9, 0xe3, 0xbc, 0xf3, 0x43, 0xb5, 0x83, 0x6b, 0x4d, 0xb8,
		0x43, 0x71, 0xe7, 0x1f, 0x5c, 0xcb, 0xe1, 0x7a, 0xc5, 0x5d, 0x53, 0x63, 0x61, 0xe3, 0x70, 0x8c,
		0x49, 0x18, 0x46, 0x28, 0xfc, 0x62, 0x1a, 0x76, 0x11, 0x0b, 0xb7, 0x88, 0x85, 0x59, 0xe4, 0xc2,
		0x2b, 0x76, 0x81, 0xbd, 0xaa, 0x48, 0x4c, 0x17, 0xf6, 0xbe, 0xde, 0x45, 0xb3, 0xc8, 0xd2, 0x3c,
		0xae, 0x39, 0x47, 0x91, 0xa8, 0x26, 0x51, 0x4d, 0xa2, 0x9a, 0x9a, 0x9c, 0xa3, 0x0e, 0x2c, 0x25,
		0x80, 0xe6, 0x52, 0xe0, 0xf9, 0xaa, 0xdb, 0x72, 0x7a, 0x1d, 0x37, 0xbe, 0xee, 0x86, 0xb7, 0x6f,
		0x5a, 0xdd, 0xdb, 0x5e, 0x37, 0xf0, 0x82, 0x38, 0x5a, 0xfc, 0xeb, 0xc1, 0x6f, 0xe3, 0xd0, 0x0d,
		0xa2, 0x96, 0xe7, 0x7f, 0xf3, 0xc2, 0x37, 0x33, 0x3f, 0x3f, 0xfd, 0xa7, 0xa7, 0x4a, 0x23, 0x7a,
		0xfa, 0x81, 0x89, 0xbf, 0xfb, 0xe4, 0xd7, 0x0a, 0xf8, 0x57, 0xea, 0x6c, 0x4f, 0xfd, 0x28, 0x3e,
		0x8a, 0xe3, 0xd0, 0xec, 0x7c, 0x3f, 0xf8, 0xc1, 0x71, 0xc7, 0x1b, 0xb0, 0x78, 0x64, 0x16, 0xd3,
		0x2b, 0x7d, 0x70, 0xbf, 0xcf, 0x50, 0x92, 0x8d, 0xe6, 0x95, 0xce, 0xc2, 0xb6, 0x17, 0x7a, 0xed,
		0x5f, 0xef, 0x4a, 0x6f, 0x76, 0x82, 0x7e, 0xa7, 0x93, 0xe1, 0x3b, 0xba, 0x19, 0xb6, 0x30, 0x37,
		0x62, 0xb3, 0xc4, 0xb0, 0x5f, 0xd8, 0x2f, 0xec, 0xd7, 0x96, 0xda, 0xaf, 0xe9, 0x6f, 0x87, 0xe1,
		0x52, 0x2e, 0x01, 0xec, 0x44, 0xb1, 0xc7, 0xc1, 0xa1, 0x57, 0x63, 0x47, 0xdb, 0xd6, 0x25, 0x80,
		0x52, 0x8c, 0xdc, 0x8d, 0x3d, 0xfd, 0x88, 0xc1, 0x68, 0x79, 0xca, 0x01, 0x83, 0x0a, 0x01, 0x03,
		0x02, 0x06, 0x04, 0x0c, 0x00, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x01, 0x03, 0x02, 0x06, 0x04, 0x0c,
		0x08, 0x18, 0x60, 0xbf, 0xb0, 0x5f, 0xd8, 0x2f, 0x02, 0x06, 0xc5, 0x0c, 0x18, 0x90, 0x34, 0x68,
		0xb0, 0x7b, 0xe2, 0x39, 0x83, 0x27, 0x63, 0xba, 0x29, 0xe6, 0x23, 0x3d, 0x79, 0x47, 0xc7, 0x8d,
		0x22, 0xff, 0x26, 0x98, 0x80, 0x1b, 0xc5, 0x1c, 0xa5, 0x55, 0xc4, 0xc8, 0x5b, 0x22, 0x6f, 0xc9,
		0x50, 0x03, 0x28, 0xe7, 0x2d, 0x3d, 0xf0, 0x9f, 0x7e, 0x24, 0x72, 0x86, 0x06, 0xf9, 0x4b, 0x84,
		0x23, 0x8b, 0x16, 0x8e, 0xd4, 0x4c, 0xed, 0x9b, 0x63, 0x1c, 0xad, 0x14, 0x3f, 0x43, 0x51, 0xc1,
		0x75, 0xc3, 0x75, 0xdb, 0xbc, 0xeb, 0xa6, 0x2b, 0x7a, 0x0f, 0x56, 0xaa, 0xd3, 0xe9, 0xb6, 0xf4,
		0xdd, 0x83, 0xc5, 0x56, 0xeb, 0x81, 0xa6, 0xe1, 0xe9, 0xc8, 0x54, 0xcd, 0x19, 0x8b, 0xa8, 0xa4,
		0xa8, 0x5a, 0x12, 0x59, 0x69, 0xd1, 0xb5, 0x26, 0xc2, 0xd6, 0x44, 0xd9, 0x9e, 0x48, 0x9b, 0x89,
		0xb6, 0xa1, 0x88, 0xcb, 0x45, 0x69, 0xe6, 0x38, 0xaf, 0xed, 0xb5, 0xfc, 0x5b, 0xb7, 0x63, 0x54,
		0x74, 0x3d, 0x67, 0x45, 0x2b, 0x02, 0xb4, 0xe6, 0x4a, 0x4f, 0xf7, 0x05, 0x88, 0xca, 0x94, 0x76,
		0x4f, 0xfe, 0xc8, 0x48, 0xd7, 0x8e, 0x74, 0xa9, 0xf7, 0xd3, 0xe3, 0xa8, 0xbc, 0x90, 0x25, 0x2b,
		0x5c, 0xfa, 0xbd, 0xfc, 0xc4, 0xf7, 0xc4, 0xe8, 0xdf, 0xbf, 0x10, 0x3c, 0x2a, 0xc1, 0x92, 0xf0,
		0xa7, 0x47, 0xb5, 0xcf, 0x51, 0xdd, 0x3f, 0xcb, 0x06, 0x95, 0xc6, 0x86, 0xea, 0xd4, 0x0d, 0x58,
		0x75, 0x26, 0x54, 0xe0, 0xc4, 0x12, 0x96, 0x62, 0x41, 0x0c, 0x62, 0x44, 0x18, 0x48, 0x07, 0xa4,
		0x03, 0xd2, 0x65, 0x14, 0xd2, 0x79, 0x41, 0xff, 0xd6, 0x0b, 0x25, 0x7c, 0xaf, 0x47, 0xa0, 0xae,
		0x2a, 0x40, 0xeb, 0x38, 0xe8, 0xdf, 0x0e, 0x5e, 0xf6, 0x3e, 0x87, 0xca, 0xb5, 0xed, 0x45, 0xad,
		0xd0, 0xef, 0xc9, 0xba, 0xc9, 0xb3, 0x44, 0x51, 0xaa, 0x28, 0x55, 0x94, 0x6a, 0x46, 0x95, 0x6a,
		0x14, 0x87, 0x7e, 0x70, 0x23, 0xa9, 0x4f, 0x5f, 0xe7, 0x50, 0x07, 0xaa, 0xf5, 0x77, 0x59, 0xbb,
		0xa9, 0x2a, 0x7d, 0x5f, 0xd0, 0x7b, 0xe8, 0x3d, 0xf4, 0x5e, 0xea, 0x7a, 0xaf, 0xef, 0x07, 0xf1,
		0x7e, 0x45, 0x50, 0xef, 0x1d, 0x10, 0xc6, 0xdb, 0x88, 0x82, 0x23, 0x8c, 0x97, 0x5e, 0x18, 0xcf,
		0xd6, 0x51, 0x55, 0x2b, 0x87, 0xd5, 0xc3, 0xfa, 0x41, 0xe5, 0xb0, 0x46, 0x3c, 0x6f, 0x1b, 0xe2,
		0x79, 0x4f, 0xd2, 0xd9, 0xe4, 0x80, 0xd7, 0x53, 0xc2, 0x40, 0x30, 0x20, 0x18, 0x10, 0x2c, 0xa3,
		0x10, 0xcc, 0x3c, 0xa1, 0x7e, 0xce, 0xf7, 0x94, 0x00, 0x61, 0xb3, 0x09, 0xf6, 0x93, 0xc3, 0x7b,
		0xf3, 0x34, 0x83, 0x79, 0xf6, 0xdf, 0xe6, 0xb2, 0x99, 0x67, 0xff, 0x71, 0xa6, 0xda, 0x6b, 0xfa,
		0x3b, 0x83, 0x52, 0xaf, 0xcd, 0xea, 0xed, 0x5b, 0xb7, 0xd7, 0xf3, 0x83, 0x1b, 0x39, 0x7d, 0x3d,
		0x21, 0x88, 0x9e, 0x46, 0x4f, 0xa3, 0xa7, 0x33, 0xaa, 0xa7, 0xfd, 0xb6, 0x17, 0xc4, 0x7e, 0x7c,
		0x27, 0xac, 0xab, 0x05, 0xb0, 0x7e, 0xe9, 0x64, 0xfc, 0x68, 0xbf, 0xba, 0x91, 0x20, 0x2f, 0x4f,
		0x5e, 0xfc, 0xb7, 0xf3, 0xa3, 0x0f, 0xc7, 0xcd, 0x0f, 0x47, 0x9f, 0x3e, 0x9d, 0x7c, 0x7c, 0xdf,
		0xfc, 0x74, 0x7e, 0x76, 0x79, 0xf6, 0xf6, 0xec, 0xb4, 0x24, 0xd9, 0xe6, 0x3e, 0x12, 0xf3, 0xf6,
		0x65, 0x3d, 0xfe, 0x47, 0xfb, 0xf0, 0xeb, 0x87, 0x4f, 0xa5, 0x2c, 0xfa, 0xba, 0x96, 0x5e, 0xf7,
		0xfd, 0x6f, 0x9f, 0x9a, 0xbf, 0x6d, 0xd3, 0x0b, 0x1f, 0x6d, 0xdf, 0xf9, 0x5e, 0x6e, 0xd3, 0x0b,
		0xbf, 0xfd, 0xf5, 0x7c, 0xab, 0xce, 0x57, 0x94, 0x9d, 0x45, 0x28, 0x35, 0x72, 0x3b, 0x5e, 0xc4,
		0xc4, 0x5d, 0xe8, 0xf6, 0x62, 0x3b, 0x61, 0x9e, 0xa7, 0x84, 0x71, 0x1f, 0x70, 0x1f, 0x70, 0x1f,
		0x08, 0xf3, 0xe8, 0x86, 0x79, 0xd2, 0xee, 0xa3, 0xb0, 0x59, 0xb5, 0x1c, 0x87, 0xfe, 0x97, 0x7e,
		0xec, 0x86, 0x77, 0x4e, 0xd4, 0xe9, 0xc6, 0x8e, 0x70, 0xee, 0xc3, 0x42, 0xea, 0x28, 0x68, 0x14,
		0x34, 0x0a, 0x3a, 0xab, 0xf1, 0x1d, 0xe1, 0x4c, 0x08, 0x0a, 0x9a, 0x74, 0xed, 0x9a, 0xa5, 0xeb,
		0xf5, 0x4a, 0xb9, 0x7a, 0x50, 0x7d, 0xbd, 0x5f, 0xaf, 0xbe, 0x26, 0x25, 0x42, 0xfa, 0xcc, 0xf6,
		0x6c, 0x9f, 0xd9, 0x01, 0x29, 0x11, 0xe9, 0x7a, 0xdb, 0xf7, 0x39, 0x29, 0x8f, 0x37, 0x6c, 0x7e,
		0x35, 0xa5, 0x63, 0xa1, 0x8d, 0xd3, 0x8a, 0x76, 0x45, 0xaf, 0x1e, 0x7e, 0xd6, 0x6a, 0xaa, 0xad,
		0xbf, 0xd7, 0x3a, 0x9d, 0x18, 0xcd, 0xb0, 0xb1, 0x48, 0x3e, 0x30, 0xdd, 0x17, 0xad, 0x81, 0x5b,
		0x5a, 0x78, 0xd8, 0xd6, 0x51, 0x85, 0xed, 0xbe, 0xa8, 0x33, 0xe7, 0x72, 0x33, 0x2a, 0x4c, 0x6f,
		0x5e, 0xc0, 0xdc, 0xfe, 0xeb, 0xcc, 0x0d, 0x10, 0xc2, 0xb7, 0xda, 0x73, 0x04, 0x50, 0x61, 0xa8,
		0x30, 0x63, 0x15, 0x46, 0x17, 0x22, 0x42, 0x6b, 0x84, 0xd6, 0x08, 0xad, 0x69, 0x71, 0x1e, 0x5d,
		0x88, 0x0a, 0x1f, 0xb4, 0xa3, 0x0b, 0x11, 0x5d, 0x88, 0x08, 0xd1, 0xe5, 0x26, 0x44, 0x47, 0x17,
		0x22, 0x20, 0x1d, 0x90, 0x0e, 0x48, 0xa7, 0xcd, 0x79, 0x74, 0x21, 0xb2, 0xa2, 0x5c, 0xe9, 0x42,
		0x84, 0x52, 0x45, 0xa9, 0x6e, 0xab, 0x52, 0xa5, 0x0b, 0x11, 0x5d, 0x88, 0xd0, 0x7b, 0xe8, 0xbd,
		0x6d, 0xd3, 0x7b, 0x74, 0x21, 0xca, 0x4a, 0x18, 0x8f, 0x2e, 0x44, 0x74, 0x21, 0xa2, 0x0b, 0xd1,
		0x56, 0xc5, 0xf3, 0xe8, 0x42, 0x04, 0x04, 0x03, 0x82, 0x6d, 0x3b, 0x04, 0xa3, 0x0b, 0x51, 0xde,
		0xf4, 0x36, 0x5d, 0x88, 0xd0, 0xd3, 0xe8, 0xe9, 0x6d, 0xd3, 0xd3, 0x74, 0x21, 0xa2, 0x0b, 0x11,
		0x5d, 0x88, 0x0a, 0xfc, 0xc2, 0x74, 0x21, 0x2a, 0xf6, 0x0b, 0xd3, 0x85, 0x68, 0xd3, 0x61, 0x1e,
		0xba, 0x10, 0xd1, 0x85, 0x08, 0xf7, 0x01, 0xf7, 0x81, 0x30, 0x4f, 0x26, 0xc3, 0x3c, 0x74, 0x21,
		0xa2, 0x0b, 0x11, 0x0a, 0x1a, 0x05, 0xbd, 0xa5, 0xf1, 0x1d, 0xba, 0x10, 0x25, 0x7f, 0x30, 0xba,
		0x10, 0xcd, 0x7c, 0x01, 0x29, 0x11, 0x74, 0x21, 0x12, 0xf7, 0x95, 0xe9, 0x42, 0x94, 0xd0, 0xbe,
		0xe5, 0xbe, 0x0b, 0xd1, 0xa8, 0xb3, 0x45, 0x5a, 0x1d, 0x3c, 0x9e, 0x59, 0x3c, 0x94, 0x01, 0x3c,
		0xd2, 0x4d, 0xfc, 0x2d, 0x9d, 0xfa, 0x51, 0x7c, 0x14, 0xc7, 0x7a, 0xcd, 0x0e, 0x06, 0x06, 0xe9,
		0xb8, 0xe3, 0x0d, 0xf7, 0x56, 0x4f, 0x1d, 0x0d, 0xd4, 0xe3, 0x0c, 0x85, 0xf2, 0xeb, 0x6a, 0xb5,
		0x7e, 0x50, 0xad, 0xee, 0x1d, 0xec, 0x1f, 0xec, 0x1d, 0xd6, 0x6a, 0xe5, 0xba, 0xce, 0x4d, 0x4d,
		0xe9, 0x2c, 0x6c, 0x7b, 0xa1, 0xd7, 0xfe, 0x75, 0xb0, 0x2d, 0x41, 0xbf, 0xd3, 0xb1, 0xba, 0xfb,
		0x86, 0xa2, 0xb0, 0x39, 0x11, 0x28, 0x69, 0xb5, 0x95, 0x09, 0xfb, 0xad, 0x38, 0x18, 0x83, 0xb7,
		0xcb, 0xf1, 0x03, 0xbd, 0x1b, 0x3e, 0x4f, 0xf3, 0xed, 0xe8, 0xeb, 0x9a, 0x47, 0x0f, 0x5f, 0xf1,
		0xcc, 0x8e, 0x94, 0x24, 0xfb, 0x64, 0xc2, 0x93, 0xd4, 0x3d, 0xc1, 0x94, 0x4f, 0x2e, 0xd9, 0x5e,
		0xae, 0xdf, 0x99, 0x04, 0xbb, 0x52, 0xea, 0xc6, 0xc9, 0xb7, 0xe2, 0xc1, 0x89, 0x8c, 0x93, 0x96,
		0x5b, 0x29, 0x62, 0x4e, 0x65, 0xdf, 0x59, 0xc7, 0x47, 0x36, 0xf4, 0x85, 0x75, 0x7d, 0x5e, 0x63,
		0xdf, 0xd6, 0xd8, 0x87, 0x35, 0xf7, 0x55, 0x65, 0xa5, 0x51, 0xb5, 0xf3, 0x4e, 0xa9, 0x35, 0xe1,
		0x0e, 0xc5, 0x9d, 0x9f, 0x1c, 0xf8, 0x78, 0xbd, 0xaa, 0xd1, 0xd5, 0x72, 0x9b, 0xb4, 0xc3, 0x40,
		0x26, 0x61, 0x1f, 0xa1, 0x30, 0x8f, 0x69, 0x58, 0x47, 0x2c, 0x8c, 0x23, 0x16, 0xb6, 0x91, 0x0b,
		0xd3, 0xd8, 0x05, 0x78, 0xba, 0xcd, 0xa8, 0x9e, 0xc6, 0x43, 0x6f, 0x42, 0x37, 0xe8, 0x77, 0xdc,
		0xd0, 0x8f, 0xef, 0xcc, 0x5b, 0xc3, 0xad, 0xa0, 0x4d, 0xcb, 0x4b, 0xfa, 0xc5, 0x6d, 0x3c, 0x62,
		0x9a, 0xd7, 0x96, 0x97, 0x32, 0x19, 0x6f, 0x12, 0x99, 0x6e, 0xb2, 0x19, 0x6e, 0xd3, 0x17, 0xbc,
		0x3c, 0x3f, 0xf9, 0xf5, 0xf7, 0xcb, 0xa3, 0xf3, 0x3f, 0x9a, 0x17, 0xa7, 0x67, 0x97, 0xcd, 0xf7,
		0xe7, 0x47, 0x1f, 0x7f, 0x3f, 0x3d, 0x3a, 0x3f, 0xb9, 0xfc, 0xc3, 0x94, 0x29, 0x05, 0xb3, 0xda,
		0x84, 0xb3, 0xf9, 0x06, 0xef, 0x3c, 0x7a, 0xdd, 0xf2, 0xcb, 0x4a, 0xed, 0xbd, 0xc0, 0x3d, 0xc0,
		0x8b, 0xec, 0xbe, 0x62, 0xd1, 0xdf, 0xaf, 0xf2, 0x52, 0xe4, 0x0d, 0x9f, 0x6d, 0x26, 0xcc, 0x78,
		0x9f, 0xe1, 0xae, 0xb5, 0x71, 0xec, 0x3b, 0xb7, 0xd1, 0x8d, 0xe3, 0xf6, 0xe3, 0xae, 0x00, 0x42,
		0x99, 0xa5, 0x06, 0x26, 0x01, 0x93, 0x80, 0x49, 0x34, 0x39, 0xe7, 0x4b, 0xb7, 0xdb, 0xf1, 0xdc,
		0x40, 0x02, 0x8f, 0x94, 0x73, 0xa0, 0x7e, 0xbc, 0xef, 0x3d, 0xaf, 0x15, 0x7b, 0x6d, 0x39, 0x15,
		0x34, 0xa5, 0x88, 0x1a, 0x42, 0x0d, 0xa1, 0x86, 0x34, 0x39, 0xc7, 0xb8, 0x5f, 0x90, 0x61, 0x9f,
		0xa0, 0x74, 0xb5, 0x50, 0x1c, 0xba, 0x41, 0x74, 0xeb, 0xc7, 0x72, 0x5a, 0x68, 0x4a, 0x11, 0x2d,
		0x84, 0x16, 0x42, 0x0b, 0x6d, 0x8f, 0x16, 0xda, 0xb6, 0x0b, 0xf0, 0x6e, 0x1c, 0x68, 0x8d, 0x99,
		0x52, 0xb8, 0x81, 0x56, 0xb8, 0x1a, 0xd4, 0x9b, 0xc5, 0x62, 0x34, 0x83, 0xc5, 0xf8, 0x7a, 0xaa,
		0xc2, 0xf5, 0x14, 0xd7, 0x53, 0x09, 0x1f, 0x53, 0xfb, 0x7a, 0xea, 0x8b, 0xdb, 0xfa, 0xf3, 0x26,
		0xec, 0xf6, 0x83, 0xb6, 0xf3, 0xa5, 0xd3, 0x6d, 0xfd, 0xe9, 0x78, 0x61, 0xd8, 0x0d, 0x23, 0x73,
		0xc0, 0xb3, 0x8c, 0x30, 0xb8, 0x07, 0xdc, 0x03, 0xee, 0xd1, 0xe4, 0x9c, 0x56, 0xb7, 0x1f, 0xc4,
		0x5e, 0x68, 0x34, 0xd5, 0x64, 0x22, 0x4a, 0x06, 0xc9, 0xe0, 0x42, 0xe9, 0xf9, 0x02, 0x35, 0x0c,
		0x92, 0xe9, 0xf8, 0xc2, 0x29, 0xdd, 0xd2, 0x8d, 0x08, 0x6d, 0x64, 0x6e, 0x0b, 0x5c, 0xf1, 0x88,
		0x66, 0xd7, 0xdb, 0x3a, 0x02, 0x99, 0xa4, 0xd6, 0xd4, 0x4e, 0x65, 0x43, 0xf9, 0xeb, 0x8d, 0x0c,
		0x47, 0x64, 0x5a, 0xdd, 0xb6, 0xe7, 0x7c, 0xf3, 0xbb, 0x9d, 0xa1, 0x97, 0x23, 0x80, 0x4f, 0x9e,
		0x12, 0x04, 0x97, 0x80, 0x4b, 0xc0, 0x25, 0xe0, 0x12, 0x70, 0x09, 0xb8, 0x04, 0x5c, 0x02, 0x2e,
		0x49, 0xb8, 0xcd, 0xc3, 0xa8, 0x86, 0x37, 0x8e, 0x71, 0x08, 0xc0, 0x92, 0x27, 0xf4, 0x40, 0x25,
		0xa0, 0x12, 0x50, 0x09, 0xa8, 0x04, 0x54, 0x02, 0x2a, 0x01, 0x95, 0x80, 0x4a, 0x14, 0x51, 0x49,
		0xe4, 0xb5, 0xba, 0x41, 0x5b, 0x10, 0x96, 0x4c, 0x08, 0x82, 0x4b, 0xc0, 0x25, 0xe0, 0x12, 0x70,
		0x09, 0xb8, 0x04, 0x5c, 0x02, 0x2e, 0x01, 0x97, 0x24, 0xc5, 0x25, 0x51, 0x10, 0x0a, 0x80, 0x91,
		0x01, 0x15, 0x33, 0x04, 0x52, 0x06, 0x81, 0x80, 0x40, 0xf2, 0x86, 0x40, 0x74, 0x93, 0xbc, 0xa6,
		0x04, 0xdc, 0x6f, 0x82, 0xb3, 0x7b, 0x06, 0xc4, 0xe8, 0xeb, 0x9a, 0x44, 0x48, 0xe3, 0xbb, 0x9e,
		0x17, 0xd1, 0xd4, 0x55, 0x82, 0xf0, 0x13, 0x09, 0x1e, 0xed, 0x2c, 0x1d, 0x5d, 0x9f, 0xf0, 0x5c,
		0xdb, 0x6b, 0xf9, 0xb7, 0x6e, 0xc7, 0xc8, 0xc1, 0x98, 0xb3, 0x98, 0x15, 0x01, 0x5a, 0x73, 0x30,
		0xab, 0x42, 0xaf, 0x58, 0xbd, 0xe3, 0xa8, 0x30, 0x35, 0x37, 0x2f, 0x2d, 0x62, 0xf7, 0x39, 0x2a,
		0x86, 0xe5, 0xea, 0x83, 0x36, 0x3f, 0x88, 0x62, 0x37, 0x88, 0xe5, 0x80, 0xdb, 0x84, 0x20, 0xe0,
		0x0d, 0xf0, 0x06, 0x78, 0x03, 0xbc, 0x01, 0xde, 0x00, 0x6f, 0x80, 0x37, 0xc0, 0x1b, 0xe0, 0xcd,
		0x06, 0x78, 0x8b, 0xbd, 0xf0, 0x9b, 0xdb, 0x91, 0x44, 0x6f, 0x63, 0x8a, 0xc0, 0x37, 0xe0, 0x1b,
		0xf0, 0x2d, 0x73, 0xf0, 0x2d, 0x8a, 0xdd, 0xd8, 0x11, 0x12, 0xd2, 0x1d, 0x99, 0x8b, 0xfe, 0x29,
		0xa9, 0xdf, 0x83, 0x91, 0x6d, 0x28, 0x05, 0x6e, 0xd0, 0x35, 0x4b, 0xe5, 0x01, 0xc4, 0xed, 0x81,
		0x0c, 0xb6, 0x7d, 0x48, 0x93, 0xbd, 0x84, 0x04, 0x70, 0x5d, 0xb6, 0x71, 0xdd, 0xad, 0x2b, 0x38,
		0x32, 0x73, 0x40, 0x0c, 0x34, 0x07, 0x9a, 0x03, 0xcd, 0x11, 0x8c, 0x23, 0x18, 0x47, 0x30, 0x0e,
		0x1c, 0x47, 0x30, 0x0e, 0xd0, 0x66, 0x05, 0xb4, 0x39, 0xb1, 0x7f, 0xeb, 0x89, 0x22, 0xb7, 0x11,
		0x45, 0xe0, 0x1b, 0xf0, 0x0d, 0xf8, 0x96, 0x39, 0xf8, 0x36, 0x90, 0xcd, 0xd8, 0x6f, 0xfd, 0x19,
		0x89, 0x02, 0x38, 0x42, 0x71, 0x84, 0xe2, 0x80, 0x70, 0x84, 0xe2, 0x40, 0x75, 0x99, 0x40, 0x75,
		0x02, 0x8a, 0xe5, 0x01, 0xd0, 0xf9, 0x01, 0x58, 0x0e, 0x2c, 0x07, 0x96, 0x23, 0x14, 0x47, 0x28,
		0x8e, 0x50, 0x1c, 0x38, 0x8e, 0x50, 0x1c, 0xa0, 0xcd, 0x0e, 0x68, 0x93, 0x0e, 0xc5, 0x4d, 0x28,
		0x02, 0xdf, 0x80, 0x6f, 0xc0, 0x37, 0x42, 0x71, 0x84, 0xe2, 0x08, 0xc5, 0x01, 0xe1, 0x08, 0xc5,
		0x81, 0xea, 0x52, 0x58, 0xa9, 0xdb, 0xd2, 0xc4, 0x70, 0x70, 0xdd, 0x94, 0x8e, 0xa5, 0x01, 0x76,
		0xc3, 0xb9, 0x6f, 0xaf, 0x0c, 0xfa, 0x0d, 0x8d, 0x1e, 0x2e, 0x0e, 0xfb, 0xad, 0x38, 0x98, 0x0c,
		0xb1, 0x1f, 0x3f, 0xc0, 0xbb, 0xe1, 0xf7, 0x37, 0xdf, 0x8e, 0xbe, 0xae, 0x79, 0x16, 0x07, 0xcd,
		0xe3, 0xc1, 0x17, 0x65, 0xb8, 0x7d, 0xd3, 0xb5, 0xd7, 0x72, 0x5a, 0xdd, 0x30, 0x1c, 0xce, 0x51,
		0x76, 0xbe, 0x8c, 0x44, 0xcf, 0xb0, 0x99, 0xd3, 0x02, 0x9a, 0x34, 0x97, 0xa4, 0xb5, 0x93, 0x21,
		0x08, 0xa7, 0xb9, 0x24, 0xcd, 0x25, 0x2d, 0xa0, 0x5d, 0x9a, 0x4b, 0x6e, 0x1c, 0xc5, 0xd2, 0x5c,
		0x72, 0x87, 0xe6, 0x92, 0x49, 0xd0, 0xc9, 0x5d, 0xec, 0xc9, 0xc3, 0x93, 0x21, 0x51, 0xf0, 0x09,
		0xf8, 0x04, 0x7c, 0x02, 0x3e, 0x01, 0x9f, 0x80, 0x4f, 0xc0, 0x27, 0xe0, 0x13, 0x05, 0x7c, 0xd2,
		0x0f, 0xc6, 0x60, 0xc2, 0xfd, 0xd2, 0xf1, 0xc4, 0x86, 0x86, 0x2d, 0xa5, 0x0c, 0x52, 0x01, 0xa9,
		0x80, 0x54, 0x40, 0x2a, 0x20, 0x15, 0x90, 0x0a, 0x48, 0x05, 0xa4, 0xa2, 0x8d, 0x54, 0x06, 0x36,
		0xcb, 0x0a, 0x50, 0x19, 0x11, 0x06, 0xa7, 0x80, 0x53, 0xc0, 0x29, 0xe0, 0x14, 0x70, 0x0a, 0x38,
		0x05, 0x9c, 0x02, 0x4e, 0x49, 0xb8, 0xcd, 0xbd, 0x6e, 0x14, 0x3b, 0x03, 0x4c, 0xf1, 0xc5, 0x13,
		0x18, 0x2b, 0xf6, 0x88, 0x1a, 0xe3, 0xc5, 0x40, 0x24, 0x5b, 0x86, 0x48, 0x18, 0x2f, 0x66, 0x47,
		0x28, 0x25, 0x85, 0x73, 0xa9, 0x90, 0x52, 0xce, 0x61, 0xa9, 0x9c, 0xe3, 0x61, 0x77, 0x29, 0xe9,
		0x78, 0xc2, 0x7b, 0xf9, 0xa9, 0xc8, 0x2d, 0xbf, 0xa6, 0x9e, 0x43, 0xef, 0x3c, 0x28, 0xc9, 0xa5,
		0x24, 0x97, 0xe2, 0x8d, 0x74, 0x9c, 0x26, 0xf3, 0xef, 0x67, 0xce, 0x18, 0x28, 0x0e, 0x14, 0x07,
		0x8a, 0x03, 0xc5, 0x81, 0xe2, 0x40, 0x71, 0xa0, 0x38, 0x50, 0xdc, 0xf6, 0xa1, 0x38, 0x06, 0x8e,
		0x6d, 0x14, 0xc7, 0x81, 0xe1, 0x68, 0xac, 0x92, 0x2a, 0x7e, 0x63, 0xe0, 0xd8, 0x96, 0x80, 0x38,
		0x5a, 0xab, 0xd0, 0x5a, 0x85, 0xd6, 0x2a, 0x0c, 0x1c, 0x33, 0x37, 0x19, 0x0c, 0x1c, 0x23, 0x2a,
		0x47, 0x54, 0x8e, 0xa8, 0x1c, 0x51, 0x39, 0xa2, 0x72, 0x00, 0x3a, 0xa2, 0x72, 0xa0, 0x37, 0xfb,
		0xe8, 0x8d, 0xc9, 0x63, 0x44, 0xe5, 0x88, 0xca, 0x6d, 0x0d, 0x7e, 0xa3, 0xdd, 0x31, 0x31, 0x39,
		0x20, 0x1c, 0x31, 0x39, 0x50, 0x5d, 0x81, 0x51, 0x1d, 0x93, 0xc7, 0x88, 0xc9, 0x11, 0x93, 0x23,
		0x26, 0x47, 0x4c, 0x8e, 0x98, 0x1c, 0x80, 0x8e, 0x98, 0x1c, 0xe8, 0x2d, 0x5f, 0xe8, 0x8d, 0x11,
		0x64, 0xc4, 0xe4, 0x88, 0xc9, 0x11, 0x93, 0x23, 0x26, 0x47, 0x4c, 0x0e, 0x08, 0x47, 0x4c, 0x0e,
		0x54, 0x97, 0x0d, 0x54, 0xc7, 0x08, 0xb2, 0xa7, 0x23, 0xc8, 0x04, 0x7a, 0x13, 0xed, 0x28, 0x8d,
		0x22, 0xfb, 0xd4, 0x8d, 0xe2, 0xdf, 0xbc, 0xd6, 0xaf, 0x5e, 0xa6, 0x07, 0x92, 0xf5, 0x42, 0x4f,
		0xb0, 0xff, 0xd3, 0x0c, 0x31, 0xda, 0x3f, 0xd1, 0xfe, 0xc9, 0x10, 0x84, 0xd3, 0xfe, 0xc9, 0x84,
		0xfb, 0x68, 0xff, 0xa4, 0x24, 0xa4, 0xb8, 0xd2, 0x5c, 0x87, 0xa4, 0xed, 0x4e, 0x73, 0x1d, 0x52,
		0x7c, 0x5f, 0x9a, 0xeb, 0x10, 0xae, 0x43, 0x70, 0x9c, 0x73, 0xe3, 0x38, 0xd3, 0xfe, 0x09, 0x14,
		0x07, 0x8a, 0x03, 0xc5, 0x81, 0xe2, 0x40, 0x71, 0xa0, 0x38, 0x50, 0x1c, 0x28, 0x6e, 0xeb, 0x50,
		0x1c, 0xed, 0x9f, 0x36, 0x8a, 0xe3, 0xc0, 0x70, 0x24, 0xb5, 0xa4, 0x8a, 0xdf, 0x68, 0xff, 0xb4,
		0x25, 0x20, 0x8e, 0xb4, 0x16, 0xd2, 0x5a, 0x48, 0x6b, 0xa1, 0xfd, 0x93, 0xb9, 0xc9, 0xa0, 0xfd,
		0x13, 0x51, 0x39, 0xa2, 0x72, 0x44, 0xe5, 0x88, 0xca, 0x11, 0x95, 0x03, 0xd0, 0x11, 0x95, 0x03,
		0xbd, 0xd9, 0x47, 0x6f, 0xb4, 0x7f, 0x22, 0x2a, 0x47, 0x54, 0x6e, 0x6b, 0xf0, 0x1b, 0xa5, 0x66,
		0xc4, 0xe4, 0x80, 0x70, 0xc4, 0xe4, 0x40, 0x75, 0x05, 0x46, 0x75, 0xb4, 0x7f, 0x22, 0x26, 0x47,
		0x4c, 0x8e, 0x98, 0x1c, 0x31, 0x39, 0x62, 0x72, 0x00, 0x3a, 0x62, 0x72, 0xa0, 0xb7, 0x7c, 0xa1,
		0x37, 0xda, 0x3f, 0x11, 0x93, 0x23, 0x26, 0x47, 0x4c, 0x8e, 0x98, 0x1c, 0x31, 0x39, 0x20, 0x1c,
		0x31, 0x39, 0x50, 0x5d, 0x36, 0x50, 0x1d, 0xed, 0x9f, 0xe6, 0xda, 0x3f, 0x19, 0xb7, 0x26, 0xda,
		0x51, 0xeb, 0xfe, 0x14, 0x7a, 0xd9, 0x6f, 0xfe, 0xf4, 0xff, 0x9c, 0x6f, 0x63, 0x79, 0x37, 0x6c,
		0xfc, 0x34, 0x21, 0x44, 0xd3, 0x27, 0x9a, 0x3e, 0x19, 0x42, 0x6f, 0x9a, 0x3e, 0x99, 0x70, 0x1f,
		0x4d, 0x9f, 0x70, 0x9e, 0x71, 0x9e, 0xb9, 0xfc, 0x30, 0x02, 0xe2, 0x15, 0x1c, 0x67, 0xbd, 0xe3,
		0xe0, 0xee, 0x83, 0xbb, 0x0f, 0xbc, 0xe4, 0xdc, 0x78, 0xc9, 0xf4, 0x7a, 0x02, 0xbc, 0x01, 0xde,
		0x00, 0x6f, 0x80, 0x37, 0xc0, 0x1b, 0xe0, 0x0d, 0xf0, 0x06, 0x78, 0xdb, 0x16, 0xf0, 0x46, 0x8b,
		0x27, 0xe0, 0x1b, 0xf0, 0x6d, 0x7b, 0xe0, 0x1b, 0x2d, 0x9e, 0xb6, 0x04, 0xc4, 0x91, 0xba, 0x42,
		0xea, 0x0a, 0xa9, 0x2b, 0xb4, 0x78, 0x32, 0x37, 0x19, 0xb4, 0x78, 0x02, 0xcd, 0x81, 0xe6, 0x08,
		0xc6, 0x11, 0x8c, 0x23, 0x18, 0x07, 0x8e, 0x23, 0x18, 0x07, 0x68, 0xb3, 0x06, 0xda, 0xe8, 0xec,
		0x04, 0x7c, 0x03, 0xbe, 0x6d, 0x0d, 0x7c, 0xa3, 0x8a, 0x8c, 0x50, 0x1c, 0x10, 0x8e, 0x50, 0x1c,
		0xa8, 0xae, 0xc0, 0xa8, 0x8e, 0xce, 0x4e, 0x60, 0x39, 0xb0, 0x1c, 0xa1, 0x38, 0x42, 0x71, 0x84,
		0xe2, 0xc0, 0x71, 0x84, 0xe2, 0x00, 0x6d, 0xb9, 0x00, 0x6d, 0x34, 0x74, 0x02, 0xbe, 0x01, 0xdf,
		0x08, 0xc5, 0x11, 0x8a, 0x23, 0x14, 0x07, 0x84, 0x23, 0x14, 0x07, 0xaa, 0xcb, 0x06, 0xaa, 0xa3,
		0xa1, 0xd3, 0xd3, 0x86, 0x4e, 0x66, 0x2d, 0x87, 0x76, 0x94, 0x9a, 0x39, 0xfd, 0x9f, 0x91, 0x14,
		0x65, 0xb8, 0x93, 0x53, 0xd8, 0xf6, 0x9d, 0xdb, 0xe8, 0xc6, 0xbc, 0x93, 0xd3, 0x84, 0x90, 0x59,
		0x27, 0xa7, 0x3d, 0x3a, 0x39, 0x49, 0x63, 0x71, 0x3a, 0x39, 0xd9, 0x56, 0x7b, 0xc6, 0xf0, 0x7a,
		0xa6, 0xdc, 0x24, 0xf4, 0x03, 0x93, 0x46, 0x4c, 0xd3, 0x50, 0xe8, 0xeb, 0x0c, 0xeb, 0x9c, 0xc8,
		0xfb, 0xe6, 0x85, 0x5e, 0xe7, 0xce, 0xf1, 0xc2, 0xb0, 0x1b, 0x7a, 0x6d, 0x67, 0x02, 0xd3, 0x8d,
		0x95, 0xd0, 0x52, 0xca, 0x68, 0x25, 0xb4, 0x12, 0x5a, 0x49, 0x93, 0x73, 0x5a, 0xdd, 0x7e, 0x10,
		0x7b, 0xa1, 0x91, 0xab, 0x2f, 0xe0, 0xe2, 0x0b, 0xb9, 0xe0, 0x02, 0x51, 0x10, 0x49, 0x97, 0x5b,
		0xd8, 0x7f, 0x93, 0x76, 0xb1, 0x6d, 0x38, 0x67, 0x02, 0x2e, 0xb5, 0xa8, 0x2b, 0x6d, 0xeb, 0x08,
		0xec, 0xb9, 0xce, 0x56, 0x4e, 0x65, 0x43, 0x2e, 0x6a, 0x23, 0xc3, 0x48, 0x25, 0x0e, 0xfd, 0x2f,
		0xfd, 0xd8, 0x0d, 0xef, 0x9c, 0xa8, 0xd3, 0x8d, 0x9d, 0x9b, 0xd0, 0x0d, 0xfa, 0x1d, 0x37, 0xf4,
		0xe3, 0x3b, 0x73, 0xac, 0xb2, 0x82, 0x36, 0x68, 0x05, 0xb4, 0x02, 0x5a, 0xd1, 0xe4, 0x1c, 0xbf,
		0xed, 0x05, 0xb1, 0x1f, 0xdf, 0x85, 0xde, 0xb5, 0x84, 0x23, 0x65, 0xa0, 0xb1, 0x4b, 0x27, 0xe3,
		0x47, 0xf9, 0xd5, 0x8d, 0x04, 0xef, 0x46, 0x2f, 0xcf, 0x4f, 0x7e, 0xfd, 0xfd, 0xf2, 0xe8, 0xfc,
		0x8f, 0xe6, 0xc5, 0xe9, 0xd9, 0x65, 0xf3, 0xfd, 0xf9, 0xd1, 0xc7, 0xdf, 0x4f, 0x8f, 0xce, 0x4f,
		0x2e, 0xff, 0x30, 0x65, 0xca, 0xa1, 0xe1, 0x8a, 0x44, 0x2e, 0x39, 0x84, 0x2c, 0xf3, 0xec, 0x3b,
		0x8f, 0x5e, 0xb7, 0xfc, 0xb2, 0x52, 0x7b, 0x5f, 0xca, 0x02, 0x06, 0xb1, 0xf6, 0x8a, 0x45, 0x7f,
		0xbf, 0xca, 0x4b, 0x91, 0x37, 0x34, 0xa2, 0xd0, 0x48, 0x5b, 0x2f, 0xa6, 0x83, 0x57, 0xe2, 0x61,
		0x10, 0xd6, 0x71, 0xfb, 0x71, 0x57, 0x00, 0xa1, 0xcc, 0x52, 0x03, 0x93, 0x80, 0x49, 0xc0, 0x24,
		0x9a, 0x9c, 0xf3, 0xa5, 0xdb, 0xed, 0x78, 0x6e, 0x20, 0x81, 0x47, 0xca, 0x39, 0x50, 0x3f, 0xde,
		0xf7, 0x9e, 0xd7, 0x8a, 0xbd, 0xb6, 0x9c, 0x0a, 0x9a, 0x52, 0x44, 0x0d, 0xa1, 0x86, 0x50, 0x43,
		0x9a, 0x9c, 0xb3, 0x1d, 0xd7, 0x4b, 0x13, 0x9d, 0x11, 0x7a, 0xad, 0x6f, 0x72, 0x1a, 0x68, 0x48,
		0x0d, 0xed, 0x83, 0xf6, 0x41, 0xfb, 0xa0, 0x7d, 0x12, 0x68, 0x9f, 0x38, 0x74, 0x83, 0xe8, 0xd6,
		0x8f, 0xe5, 0x34, 0xd0, 0x94, 0x22, 0x5a, 0x08, 0x2d, 0x84, 0x16, 0x42, 0x0b, 0xad, 0x78, 0xc6,
		0x7e, 0xe0, 0x7e, 0x73, 0xfd, 0x8e, 0xfb, 0xa5, 0xe3, 0xc9, 0x65, 0xd7, 0x2c, 0x22, 0x8a, 0x2e,
		0x42, 0x17, 0xa1, 0x8b, 0x34, 0x39, 0x87, 0xc4, 0x9a, 0x27, 0x0f, 0x42, 0x62, 0x8d, 0xd1, 0x1f,
		0x12, 0x6b, 0x32, 0x79, 0x2a, 0x45, 0x4f, 0xac, 0x79, 0x66, 0x91, 0x47, 0x4d, 0x6b, 0x4a, 0xac,
		0xd6, 0x92, 0xa8, 0x59, 0xac, 0xe4, 0xfb, 0x94, 0xec, 0x93, 0x09, 0x77, 0x52, 0x77, 0x07, 0x2d,
		0xed, 0x9c, 0x82, 0xa9, 0x4b, 0x5c, 0x67, 0x93, 0xec, 0x1c, 0xd6, 0xef, 0x6a, 0x82, 0x1d, 0x2d,
		0x8d, 0x0e, 0x3e, 0xe9, 0x46, 0x3e, 0x1a, 0x24, 0x91, 0xb4, 0xe6, 0x48, 0x71, 0xac, 0xf9, 0x03,
		0x1a, 0x4e, 0xd8, 0x71, 0x43, 0x07, 0xfd, 0x1a, 0xa2, 0x5d, 0x5d, 0x74, 0x6b, 0x8c, 0x66, 0x8d,
		0xd1, 0xab, 0x39, 0x5a, 0x95, 0x95, 0x66, 0xd5, 0xb1, 0xe1, 0x25, 0xb7, 0x7d, 0xeb, 0x07, 0x8e,
		0x1a, 0xdb, 0xce, 0x9d, 0xfa, 0x2c, 0x11, 0xc5, 0xfd, 0xd3, 0xc3, 0x00, 0xda, 0x2e, 0x9e, 0x89,
		0x6b, 0x27, 0xe4, 0xd2, 0x99, 0xba, 0x72, 0x62, 0x2e, 0x9c, 0x98, 0xeb, 0x26, 0xe7, 0xb2, 0xd9,
		0x05, 0x0b, 0xda, 0xae, 0xd9, 0x22, 0x46, 0x1f, 0xf6, 0x7e, 0xd0, 0x39, 0xfe, 0x89, 0xfa, 0xae,
		0x6a, 0xac, 0x3d, 0x0e, 0xfa, 0xb7, 0x83, 0x37, 0xb8, 0xb7, 0x05, 0x2d, 0x14, 0x74, 0x76, 0xdb,
		0x8b, 0x5a, 0xa1, 0xdf, 0xd3, 0xc2, 0x5e, 0x33, 0x8d, 0xbe, 0x1e, 0x88, 0xa0, 0x39, 0xd0, 0x1c,
		0x85, 0xd5, 0x1c, 0xda, 0x81, 0x65, 0xcd, 0x80, 0xb2, 0x1d, 0x99, 0xf7, 0x83, 0xb6, 0xf7, 0x5d,
		0x5f, 0xda, 0x47, 0xcb, 0x91, 0x73, 0xe4, 0xbc, 0xb0, 0x72, 0xde, 0xf7, 0x83, 0x78, 0xbf, 0x62,
		0x20, 0xe7, 0x07, 0x1a, 0x4b, 0xcd, 0x22, 0xb4, 0x06, 0xa1, 0x6a, 0x89, 0x88, 0xac, 0x54, 0x17,
		0x36, 0xa1, 0x08, 0xac, 0x64, 0x8c, 0xcf, 0xa4, 0x6b, 0x9e, 0x44, 0xa4, 0x55, 0x7a, 0x6b, 0xab,
		0x95, 0xc3, 0xea, 0x61, 0xfd, 0xa0, 0x72, 0x58, 0xcb, 0xd0, 0x1e, 0xa7, 0x14, 0xc7, 0x6c, 0x64,
		0xc0, 0xfc, 0x76, 0xfc, 0xe0, 0x4f, 0x53, 0x5f, 0x7d, 0x86, 0x06, 0x86, 0x18, 0x43, 0x5c, 0x58,
		0x43, 0xec, 0x05, 0xfd, 0x5b, 0x2f, 0x74, 0x35, 0x3c, 0xcb, 0x42, 0x79, 0xe9, 0x4f, 0x82, 0xed,
		0xa3, 0xa8, 0x85, 0xbe, 0xf2, 0x58, 0x44, 0x0d, 0x35, 0x82, 0x1a, 0x29, 0xac, 0x1a, 0x31, 0xab,
		0x17, 0x36, 0xa9, 0x13, 0x96, 0xa9, 0x0f, 0x9e, 0xbe, 0xc8, 0xe9, 0xd9, 0xfb, 0x93, 0xb7, 0x47,
		0xa7, 0xcd, 0xe3, 0xd3, 0xe3, 0x0f, 0xc7, 0x1f, 0x2f, 0x9b, 0x9f, 0xce, 0xcf, 0x2e, 0xcf, 0xde,
		0x9e, 0x9d, 0x36, 0x2f, 0xff, 0xf8, 0x74, 0xac, 0xcb, 0x4f, 0x02, 0x25, 0xc1, 0x42, 0x65, 0xcf,
		0x83, 0xd7, 0x69, 0x9e, 0x5d, 0x7e, 0x2c, 0x6d, 0x02, 0xac, 0x4b, 0xbe, 0xc3, 0xf1, 0xe5, 0x3f,
		0x8e, 0xcf, 0x3f, 0x1e, 0x5f, 0xa6, 0x9d, 0xef, 0xd4, 0xb0, 0x2d, 0xba, 0x96, 0xcc, 0x5b, 0xb7,
		0xf7, 0xc5, 0x6d, 0xfd, 0xe9, 0xdc, 0x76, 0xdb, 0x46, 0x76, 0x6d, 0x96, 0x0c, 0x06, 0x0d, 0x83,
		0x56, 0x58, 0x83, 0xf6, 0x88, 0xd5, 0x37, 0x7b, 0x89, 0xa5, 0xb1, 0xf6, 0x9d, 0x77, 0xed, 0xf6,
		0x3b, 0xc3, 0x53, 0xfa, 0x78, 0xf6, 0xf1, 0xb8, 0x94, 0x01, 0x15, 0x14, 0xba, 0xb1, 0xe7, 0xb4,
		0x3a, 0x6e, 0x14, 0xe9, 0xeb, 0x9f, 0x19, 0x1a, 0x28, 0x1f, 0x94, 0x0f, 0x68, 0x3a, 0xeb, 0x68,
		0xfa, 0xa1, 0xcb, 0xce, 0xf9, 0xd1, 0xe5, 0x71, 0xf3, 0xed, 0xe9, 0xd1, 0xc5, 0x45, 0x41, 0x90,
		0xf4, 0xb0, 0x13, 0xcb, 0xf0, 0xad, 0xaa, 0x7b, 0xef, 0xf3, 0x0c, 0xa7, 0x1f, 0x5e, 0xa4, 0x5c,
		0xd9, 0x2b, 0xca, 0xab, 0xbc, 0x2e, 0xcc, 0x9b, 0xd4, 0x6b, 0x85, 0x79, 0x93, 0xc2, 0x9c, 0xc9,
		0x7e, 0x61, 0xce, 0xa4, 0x5a, 0x98, 0x37, 0x29, 0x17, 0x87, 0xbd, 0x0e, 0x0b, 0xf3, 0x26, 0xe5,
		0x5a, 0x71, 0x0e, 0xa5, 0x30, 0x92, 0x52, 0x2b, 0x10, 0x7b, 0x15, 0x47, 0x7d, 0x95, 0x0b, 0xf3,
		0x2a, 0xfb, 0x85, 0xe1, 0xaf, 0xe2, 0xb0, 0x57, 0xa5, 0x38, 0x6f, 0x52, 0x1c, 0xed, 0x55, 0x94,
		0x13, 0x31, 0xea, 0x44, 0x9a, 0xa9, 0x13, 0xd9, 0x2b, 0x0c, 0x73, 0x1d, 0x14, 0x47, 0x4c, 0x0a,
		0xe4, 0xa3, 0x14, 0xe7, 0x4d, 0xaa, 0xc5, 0xe1, 0xaf, 0xe2, 0xe0, 0x95, 0x72, 0x71, 0xe2, 0x77,
		0xc5, 0x91, 0x94, 0xe2, 0x40, 0xaf, 0x72, 0x71, 0xe2, 0x5e, 0xe5, 0xc2, 0xd8, 0xf9, 0x02, 0x79,
		0xc0, 0x85, 0xd1, 0x5e, 0x05, 0x32, 0x8e, 0x7b, 0x66, 0xfc, 0xb5, 0x45, 0x39, 0x56, 0xb1, 0x17,
		0xc5, 0x4e, 0xe4, 0xdf, 0x04, 0x6e, 0x47, 0x3f, 0xc3, 0x61, 0x96, 0x08, 0x29, 0x0e, 0xeb, 0xc8,
		0x90, 0xe2, 0x20, 0x25, 0x11, 0xa9, 0xa7, 0x38, 0xe8, 0x37, 0xf3, 0xd7, 0x6c, 0xe2, 0x6f, 0x49,
		0xe8, 0x43, 0xff, 0x8b, 0xd3, 0x0b, 0xbb, 0x71, 0xb7, 0xd5, 0x35, 0x11, 0xfb, 0x47, 0x64, 0x10,
		0x7c, 0x04, 0x9f, 0xdc, 0xa6, 0xd5, 0xc2, 0x9f, 0xa5, 0xdc, 0xa6, 0x22, 0xd6, 0x08, 0x54, 0xf7,
		0xde, 0x1f, 0xe7, 0xbe, 0x48, 0xe0, 0xec, 0xf2, 0xf7, 0x72, 0xfe, 0xdf, 0x62, 0xe0, 0x4d, 0x14,
		0xe0, 0x2c, 0xde, 0x96, 0x0f, 0x2b, 0x45, 0xe0, 0xa8, 0xfc, 0xbf, 0xc4, 0xc5, 0xe5, 0x87, 0x7a,
		0xb5, 0x08, 0x47, 0xf1, 0x36, 0xff, 0x75, 0x4c, 0x67, 0xef, 0x8a, 0xf0, 0x16, 0x17, 0x97, 0x1f,
		0xca, 0xf5, 0xdc, 0xbf, 0x45, 0xb9, 0x18, 0x8a, 0xf6, 0x5d, 0x01, 0x54, 0x54, 0x79, 0xef, 0xfd,
		0x71, 0xf3, 0xf4, 0xa8, 0x00, 0xf2, 0xfd, 0xf6, 0xa0, 0xfe, 0xba, 0x00, 0x6f, 0x51, 0x7d, 0x5d,
		0x04, 0x83, 0x91, 0x7f, 0xab, 0x57, 0x2e, 0x06, 0x2c, 0xaf, 0x14, 0x43, 0xcf, 0x16, 0xe2, 0x2d,
		0xf6, 0x8b, 0x00, 0x3f, 0x2a, 0xb5, 0x7a, 0x11, 0xe4, 0x62, 0xbf, 0x18, 0x96, 0xfb, 0xbf, 0x8f,
		0x0a, 0x81, 0xcc, 0xab, 0x85, 0x80, 0xb4, 0xcd, 0x0f, 0xa7, 0xdb, 0x7c, 0x85, 0x57, 0xd4, 0x31,
		0x00, 0x0a, 0xc3, 0x13, 0x12, 0x34, 0xed, 0x7f, 0x66, 0xb0, 0x3b, 0xa5, 0x7f, 0x7a, 0x77, 0x49,
		0xfb, 0x96, 0x96, 0x4e, 0xfd, 0x28, 0x3e, 0x8a, 0xe3, 0x64, 0xfd, 0xd7, 0x4b, 0x1f, 0xfc, 0xe0,
		0xb8, 0xe3, 0xdd, 0x7a, 0xc1, 0xa8, 0xfd, 0x5d, 0x82, 0xd1, 0x02, 0x1f, 0xdc, 0xef, 0x33, 0x2b,
		0xf4, 0x86, 0x9c, 0x94, 0xce, 0xc2, 0xb6, 0x17, 0x7a, 0xed, 0x5f, 0x07, 0xaf, 0x15, 0xf4, 0x3b,
		0x1d, 0xa3, 0xdd, 0x51, 0xe4, 0x19, 0x0b, 0xbc, 0x52, 0x4a, 0x34, 0x92, 0x61, 0xfd, 0x98, 0x88,
		0xd5, 0xdc, 0xb6, 0x9c, 0x87, 0x16, 0xff, 0xcb, 0x92, 0x7d, 0x4b, 0xba, 0x5f, 0x82, 0xfb, 0xb4,
		0xf8, 0xbd, 0xe6, 0x9f, 0x7a, 0xc1, 0x13, 0x97, 0xba, 0xbd, 0x71, 0xfb, 0x34, 0xb7, 0x33, 0xec,
		0x15, 0xb1, 0xbc, 0xbd, 0xc1, 0xc3, 0xe5, 0xd7, 0xdc, 0x92, 0x25, 0x3b, 0xb1, 0x7a, 0x84, 0xc5,
		0xda, 0x1b, 0xbc, 0x24, 0x37, 0x75, 0x8a, 0x37, 0x72, 0x49, 0x6f, 0xde, 0x94, 0x6f, 0xd8, 0x94,
		0x6f, 0xd2, 0xd4, 0x6f, 0xcc, 0xd4, 0xb8, 0x70, 0xdd, 0x88, 0x88, 0x52, 0xa2, 0x56, 0x3a, 0xd3,
		0xed, 0x4d, 0xd0, 0x31, 0x27, 0xe1, 0xc4, 0x92, 0xc4, 0x93, 0x4a, 0x54, 0x2e, 0x6a, 0x35, 0x2f,
		0x66, 0x55, 0x2f, 0x62, 0xb5, 0x2f, 0x5e, 0xb5, 0x2f, 0x5a, 0xf5, 0x2f, 0x56, 0xcd, 0x4c, 0x62,
		0xd2, 0x09, 0x23, 0xa5, 0xd6, 0xe4, 0x34, 0x15, 0x67, 0xe1, 0x8c, 0xd7, 0x59, 0x1e, 0x86, 0xb3,
		0xc7, 0x30, 0x1c, 0x31, 0x56, 0x34, 0x67, 0xc9, 0xa2, 0x60, 0xda, 0x39, 0x03, 0xf8, 0x6a, 0xf0,
		0xff, 0xaf, 0xc6, 0x2c, 0x9d, 0xe2, 0x1c, 0xaa, 0x61, 0x73, 0x27, 0xbf, 0xad, 0x2e, 0x7d, 0x93,
		0x85, 0x6a, 0xe2, 0xb7, 0x87, 0xf8, 0x21, 0x7e, 0x4f, 0x1f, 0x47, 0x39, 0xa5, 0xe6, 0xa1, 0x47,
		0x99, 0xe7, 0x5e, 0xab, 0xa5, 0xd1, 0x4c, 0xed, 0x80, 0x42, 0xfb, 0xfc, 0xd2, 0xa7, 0xb1, 0x84,
		0xbf, 0x7c, 0x39, 0xf2, 0x39, 0x5f, 0x4d, 0x98, 0x9f, 0x81, 0x71, 0x0c, 0x8c, 0xdb, 0x12, 0x21,
		0x55, 0x1e, 0x18, 0xc7, 0xd8, 0xa7, 0x9d, 0x94, 0x98, 0xdc, 0x94, 0xd9, 0xc5, 0x98, 0x5e, 0x8c,
		0xf9, 0xe5, 0x84, 0x40, 0x33, 0xb8, 0xca, 0xd8, 0x27, 0x9d, 0xbd, 0x50, 0x46, 0x93, 0x86, 0xa8,
		0x12, 0x59, 0x47, 0xd6, 0x73, 0x28, 0xeb, 0x7d, 0x3f, 0x88, 0xcb, 0x75, 0x03, 0x59, 0xaf, 0x33,
		0xfa, 0x49, 0x8f, 0x0c, 0xa3, 0x9f, 0xac, 0x6f, 0x6d, 0xbd, 0x56, 0xdb, 0x67, 0xea, 0xd3, 0x46,
		0xac, 0xef, 0x37, 0x2f, 0x68, 0x77, 0x43, 0x23, 0xfb, 0xfb, 0x40, 0x02, 0x0b, 0x8c, 0x05, 0x06,
		0x6d, 0xa7, 0x8f, 0xb6, 0x8b, 0x19, 0xd8, 0xce, 0x5e, 0xaa, 0x46, 0x32, 0x4f, 0x83, 0x64, 0x8d,
		0xd4, 0x79, 0xc5, 0x38, 0x55, 0xe3, 0xc3, 0x80, 0x48, 0x41, 0xf2, 0x34, 0xe6, 0x13, 0x25, 0x0c,
		0x12, 0x35, 0x56, 0x87, 0x90, 0x13, 0x85, 0x8c, 0x13, 0x27, 0x64, 0x54, 0x48, 0xc8, 0x10, 0x4f,
		0xc8, 0xb0, 0xcf, 0x6e, 0x2b, 0xd4, 0xf4, 0x02, 0x16, 0x7b, 0xb6, 0xe2, 0xa1, 0xd7, 0x3d, 0xac,
		0xfe, 0x43, 0x96, 0x16, 0x72, 0xf6, 0x72, 0x7d, 0xf0, 0xf8, 0x75, 0x1e, 0x1e, 0x7a, 0xf4, 0xd3,
		0xf8, 0xb1, 0x97, 0x3d, 0x6e, 0xc9, 0x8f, 0xde, 0x76, 0x6f, 0x7b, 0xa1, 0x17, 0x45, 0x5e, 0xfb,
		0x62, 0xf8, 0xc8, 0x73, 0xac, 0x50, 0xf2, 0xa3, 0xdf, 0xdc, 0x3f, 0xbd, 0xf3, 0x6e, 0x77, 0x9e,
		0x4d, 0x9e, 0xbe, 0x66, 0x69, 0xf6, 0x9f, 0x1e, 0x3d, 0xf4, 0xec, 0xc3, 0xde, 0x3f, 0xbb, 0xff,
		0xff, 0x01, 0x00, 0x00, 0xff, 0xff, 0x01, 0x00, 0x00, 0xff, 0xff, 0x75, 0x76, 0x4e, 0x36, 0x03,
		0xfa, 0x6d, 0x01,
	}
)

// ΛEnumTypes is a map, keyed by a YANG schema path, of the enumerated types that
// correspond with the leaf. The type is represented as a reflect.Type. The naming
// of the map ensures that there are no clashes with valid YANG identifiers.
var ΛEnumTypes = map[string][]reflect.Type{
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/state/forwarding-action": {
		reflect.TypeOf((E_OpenconfigAcl_FORWARDING_ACTION)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/state/log-action": {
		reflect.TypeOf((E_OpenconfigAcl_LOG_ACTION)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state/protocol": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state/protocol": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state/ethertype": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_ETHERTYPE)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_PortNumRange_Enum)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_PortNumRange_Enum)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/tcp-flags": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_TCP_FLAGS)(0)),
	},
	"/acl/acl-sets/acl-set/state/type": {
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/egress-acl-sets/egress-acl-set/state/type": {
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/state/type": {
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/state/counter-capability": {
		reflect.TypeOf((E_OpenconfigAcl_ACL_COUNTER_CAPABILITY)(0)),
	},
	"/aps/aps-modules/aps-module/state/active-path": {
		reflect.TypeOf((E_OpenconfigTransportLineProtection_APS_PATHS)(0)),
	},
	"/aps/aps-modules/aps-module/state/force-to-port": {
		reflect.TypeOf((E_ApsModule_ForceToPort)(0)),
	},
	"/bgp/global/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/neighbors/neighbor/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/graceful-restart/state/mode": {
		reflect.TypeOf((E_GracefulRestart_Mode)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/received/last-notification-error-code": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/received/last-notification-error-subcode": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-code": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-subcode": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/peer-type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_PeerType)(0)),
	},
	"/bgp/neighbors/neighbor/state/remove-private-as": {
		reflect.TypeOf((E_OpenconfigBgpTypes_RemovePrivateAsOption)(0)),
	},
	"/bgp/neighbors/neighbor/state/send-community": {
		reflect.TypeOf((E_OpenconfigBgpTypes_CommunityType)(0)),
	},
	"/bgp/neighbors/neighbor/state/session-state": {
		reflect.TypeOf((E_Neighbor_SessionState)(0)),
	},
	"/bgp/neighbors/neighbor/state/supported-capabilities": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_CAPABILITY)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/peer-groups/peer-group/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/state/peer-type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_PeerType)(0)),
	},
	"/bgp/peer-groups/peer-group/state/remove-private-as": {
		reflect.TypeOf((E_OpenconfigBgpTypes_RemovePrivateAsOption)(0)),
	},
	"/bgp/peer-groups/peer-group/state/send-community": {
		reflect.TypeOf((E_OpenconfigBgpTypes_CommunityType)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/origin": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/origin": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/as-path/as-segment/state/type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AsPathSegmentType)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/as4-path/as4-segment/state/type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AsPathSegmentType)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/state/origin": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BgpOriginAttrType)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/state/type": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/type": {
		reflect.TypeOf((E_Segment_Type)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE)(0)),
	},
	"/bgp/rib/communities/community/state/community": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY)(0)),
	},
	"/components/component/port/breakout-mode/state/channel-speed": {
		reflect.TypeOf((E_OpenconfigIfEthernet_ETHERNET_SPEED)(0)),
	},
	"/components/component/port/optical-port/state/admin-state": {
		reflect.TypeOf((E_OpenconfigTransportTypes_AdminStateType)(0)),
	},
	"/components/component/port/optical-port/state/optical-port-type": {
		reflect.TypeOf((E_OpenconfigTransportTypes_OPTICAL_PORT_TYPE)(0)),
	},
	"/components/component/state/oper-status": {
		reflect.TypeOf((E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS)(0)),
	},
	"/components/component/state/temperature/alarm-severity": {
		reflect.TypeOf((E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY)(0)),
	},
	"/components/component/state/type": {
		reflect.TypeOf((E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT)(0)),
		reflect.TypeOf((E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT)(0)),
	},
	"/components/component/transceiver/state/connector-type": {
		reflect.TypeOf((E_OpenconfigTransportTypes_FIBER_CONNECTOR_TYPE)(0)),
	},
	"/components/component/transceiver/state/ethernet-pmd": {
		reflect.TypeOf((E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE)(0)),
	},
	"/components/component/transceiver/state/ethernet-pmd-preconf": {
		reflect.TypeOf((E_OpenconfigTransportTypes_ETHERNET_PMD_TYPE)(0)),
	},
	"/components/component/transceiver/state/fec-mode": {
		reflect.TypeOf((E_OpenconfigPlatformTypes_FEC_MODE_TYPE)(0)),
	},
	"/components/component/transceiver/state/fec-status": {
		reflect.TypeOf((E_OpenconfigPlatformTypes_FEC_STATUS_TYPE)(0)),
	},
	"/components/component/transceiver/state/form-factor": {
		reflect.TypeOf((E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE)(0)),
	},
	"/components/component/transceiver/state/form-factor-preconf": {
		reflect.TypeOf((E_OpenconfigTransportTypes_TRANSCEIVER_FORM_FACTOR_TYPE)(0)),
	},
	"/components/component/transceiver/state/otn-compliance-code": {
		reflect.TypeOf((E_OpenconfigTransportTypes_OTN_APPLICATION_CODE)(0)),
	},
	"/components/component/transceiver/state/present": {
		reflect.TypeOf((E_Transceiver_Present)(0)),
	},
	"/components/component/transceiver/state/sonet-sdh-compliance-code": {
		reflect.TypeOf((E_OpenconfigTransportTypes_SONET_APPLICATION_CODE)(0)),
	},
	"/interfaces/interface/aggregation/state/lag-type": {
		reflect.TypeOf((E_OpenconfigIfAggregate_AggregationType)(0)),
	},
	"/interfaces/interface/aggregation/switched-vlan/state/interface-mode": {
		reflect.TypeOf((E_OpenconfigVlanTypes_VlanModeType)(0)),
	},
	"/interfaces/interface/ethernet/state/duplex-mode": {
		reflect.TypeOf((E_Ethernet_DuplexMode)(0)),
	},
	"/interfaces/interface/ethernet/state/negotiated-duplex-mode": {
		reflect.TypeOf((E_Ethernet_NegotiatedDuplexMode)(0)),
	},
	"/interfaces/interface/ethernet/state/negotiated-port-speed": {
		reflect.TypeOf((E_OpenconfigIfEthernet_ETHERNET_SPEED)(0)),
	},
	"/interfaces/interface/ethernet/state/port-speed": {
		reflect.TypeOf((E_OpenconfigIfEthernet_ETHERNET_SPEED)(0)),
	},
	"/interfaces/interface/ethernet/switched-vlan/state/interface-mode": {
		reflect.TypeOf((E_OpenconfigVlanTypes_VlanModeType)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv4/addresses/address/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_IpAddressOrigin)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv4/neighbors/neighbor/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_NeighborOrigin)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv4/proxy-arp/state/mode": {
		reflect.TypeOf((E_ProxyArp_Mode)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv6/addresses/address/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_IpAddressOrigin)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv6/addresses/address/state/status": {
		reflect.TypeOf((E_Address_Status)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv6/neighbors/neighbor/state/neighbor-state": {
		reflect.TypeOf((E_Neighbor_NeighborState)(0)),
	},
	"/interfaces/interface/routed-vlan/ipv6/neighbors/neighbor/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_NeighborOrigin)(0)),
	},
	"/interfaces/interface/state/admin-status": {
		reflect.TypeOf((E_Interface_AdminStatus)(0)),
	},
	"/interfaces/interface/state/oper-status": {
		reflect.TypeOf((E_Interface_OperStatus)(0)),
	},
	"/interfaces/interface/state/tpid": {
		reflect.TypeOf((E_OpenconfigVlanTypes_TPID_TYPES)(0)),
	},
	"/interfaces/interface/state/type": {
		reflect.TypeOf((E_IETFInterfaces_InterfaceType)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv4/addresses/address/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_IpAddressOrigin)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv4/neighbors/neighbor/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_NeighborOrigin)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv4/proxy-arp/state/mode": {
		reflect.TypeOf((E_ProxyArp_Mode)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv6/addresses/address/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_IpAddressOrigin)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv6/addresses/address/state/status": {
		reflect.TypeOf((E_Address_Status)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv6/neighbors/neighbor/state/neighbor-state": {
		reflect.TypeOf((E_Neighbor_NeighborState)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/ipv6/neighbors/neighbor/state/origin": {
		reflect.TypeOf((E_OpenconfigIfIp_NeighborOrigin)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/state/admin-status": {
		reflect.TypeOf((E_Interface_AdminStatus)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/state/oper-status": {
		reflect.TypeOf((E_Interface_OperStatus)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/vlan/egress-mapping/state/tpid": {
		reflect.TypeOf((E_OpenconfigVlanTypes_TPID_TYPES)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/vlan/egress-mapping/state/vlan-stack-action": {
		reflect.TypeOf((E_OpenconfigVlanTypes_VlanStackAction)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/vlan/ingress-mapping/state/tpid": {
		reflect.TypeOf((E_OpenconfigVlanTypes_TPID_TYPES)(0)),
	},
	"/interfaces/interface/subinterfaces/subinterface/vlan/ingress-mapping/state/vlan-stack-action": {
		reflect.TypeOf((E_OpenconfigVlanTypes_VlanStackAction)(0)),
	},
	"/lacp/interfaces/interface/members/member/state/activity": {
		reflect.TypeOf((E_OpenconfigLacp_LacpActivityType)(0)),
	},
	"/lacp/interfaces/interface/members/member/state/synchronization": {
		reflect.TypeOf((E_OpenconfigLacp_LacpSynchronizationType)(0)),
	},
	"/lacp/interfaces/interface/members/member/state/timeout": {
		reflect.TypeOf((E_OpenconfigLacp_LacpTimeoutType)(0)),
	},
	"/lacp/interfaces/interface/state/interval": {
		reflect.TypeOf((E_OpenconfigLacp_LacpPeriodType)(0)),
	},
	"/lacp/interfaces/interface/state/lacp-mode": {
		reflect.TypeOf((E_OpenconfigLacp_LacpActivityType)(0)),
	},
	"/lldp/interfaces/interface/neighbors/neighbor/capabilities/capability/state/name": {
		reflect.TypeOf((E_OpenconfigLldpTypes_LLDP_SYSTEM_CAPABILITY)(0)),
	},
	"/lldp/interfaces/interface/neighbors/neighbor/state/chassis-id-type": {
		reflect.TypeOf((E_OpenconfigLldpTypes_ChassisIdType)(0)),
	},
	"/lldp/interfaces/interface/neighbors/neighbor/state/port-id-type": {
		reflect.TypeOf((E_OpenconfigLldpTypes_PortIdType)(0)),
	},
	"/lldp/state/chassis-id-type": {
		reflect.TypeOf((E_OpenconfigLldpTypes_ChassisIdType)(0)),
	},
	"/lldp/state/suppress-tlv-advertisement": {
		reflect.TypeOf((E_OpenconfigLldpTypes_LLDP_TLV)(0)),
	},
	"/local-routes/static-routes/static/next-hops/next-hop/state/next-hop": {
		reflect.TypeOf((E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP)(0)),
	},
	"/messages/debug-entries/debug-service/state/service": {
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/messages/state/severity": {
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry/state/decapsulate-header": {
		reflect.TypeOf((E_OpenconfigAftTypes_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry/state/origin-protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry/state/decapsulate-header": {
		reflect.TypeOf((E_OpenconfigAftTypes_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry/state/origin-protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/afts/mpls/label-entry/state/label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/afts/mpls/label-entry/state/popped-mpls-label-stack": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/afts/next-hops/next-hop/state/encapsulate-header": {
		reflect.TypeOf((E_OpenconfigAftTypes_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/afts/next-hops/next-hop/state/origin-protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/afts/next-hops/next-hop/state/pushed-mpls-label-stack": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/ip-protocol": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/mpls-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/state/type": {
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE)(0)),
	},
	"/network-instances/network-instance/encapsulation/state/encapsulation-type": {
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_ENCAPSULATION)(0)),
	},
	"/network-instances/network-instance/encapsulation/state/label-allocation-mode": {
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE)(0)),
	},
	"/network-instances/network-instance/fdb/mac-table/entries/entry/state/entry-type": {
		reflect.TypeOf((E_Entry_EntryType)(0)),
	},
	"/network-instances/network-instance/inter-instance-policies/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/inter-instance-policies/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/interfaces/interface/state/associated-address-families": {
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/lower-bound": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/upper-bound": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/global/state/null-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_NULL_LABEL_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/global/state/pw-encapsulation": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object/state/hop-type": {
		reflect.TypeOf((E_OpenconfigMpls_MplsHopType)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/state/sid-selection-mode": {
		reflect.TypeOf((E_NamedExplicitPath_SidSelectionMode)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/state/specification-type": {
		reflect.TypeOf((E_OpenconfigMpls_TeBandwidthType)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/state/cspf-tiebreaker": {
		reflect.TypeOf((E_OpenconfigMpls_CspfTieBreaking)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/state/path-computation-method": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/state/cspf-tiebreaker": {
		reflect.TypeOf((E_OpenconfigMpls_CspfTieBreaking)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/state/path-computation-method": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/admin-status": {
		reflect.TypeOf((E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/metric-type": {
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_METRIC_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/oper-status": {
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_OPER_STATUS)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/protection-style-requested": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/role": {
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_ROLE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/signaling-protocol": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/type": {
		reflect.TypeOf((E_OpenconfigMplsTypes_TUNNEL_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/incoming-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/push-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/incoming-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/push-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/incoming-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/push-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family/state/afi-name": {
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/state/adjacency-type": {
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAdjacencyType)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/state/afi-name": {
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/state/priority": {
		reflect.TypeOf((E_BandwidthReservation_Priority_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection/state/link-protection-style-requested": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/neighbors/neighbor/state/neighbor-status": {
		reflect.TypeOf((E_Neighbor_NeighborStatus)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/type": {
		reflect.TypeOf((E_ExplicitRouteObject_Type)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state/reported-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-in": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-out": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/protection-requested": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/status": {
		reflect.TypeOf((E_Session_Status)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/type": {
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_ROLE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/state/mpls-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/state/mpls-label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/state/flooding-type": {
		reflect.TypeOf((E_OpenconfigMpls_MplsSrlgFloodingType)(0)),
	},
	"/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/state/threshold-specification": {
		reflect.TypeOf((E_IgpFloodingBandwidth_ThresholdSpecification)(0)),
	},
	"/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/state/threshold-type": {
		reflect.TypeOf((E_IgpFloodingBandwidth_ThresholdType)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state/protocol": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state/protocol": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state/ethertype": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_ETHERTYPE)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_PortNumRange_Enum)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_PortNumRange_Enum)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/tcp-flags": {
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_TCP_FLAGS)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/graceful-restart/state/mode": {
		reflect.TypeOf((E_GracefulRestart_Mode)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/received/last-notification-error-code": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/received/last-notification-error-subcode": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-code": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-subcode": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/peer-type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_PeerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/remove-private-as": {
		reflect.TypeOf((E_OpenconfigBgpTypes_RemovePrivateAsOption)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/send-community": {
		reflect.TypeOf((E_OpenconfigBgpTypes_CommunityType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/session-state": {
		reflect.TypeOf((E_Neighbor_SessionState)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/supported-capabilities": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_CAPABILITY)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/state/default-export-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state/peer-type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_PeerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state/remove-private-as": {
		reflect.TypeOf((E_OpenconfigBgpTypes_RemovePrivateAsOption)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state/send-community": {
		reflect.TypeOf((E_OpenconfigBgpTypes_CommunityType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/origin": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/origin": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/state/afi-safi-name": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as-path/as-segment/state/type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AsPathSegmentType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as4-path/as4-segment/state/type": {
		reflect.TypeOf((E_OpenconfigBgpTypes_AsPathSegmentType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/state/origin": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BgpOriginAttrType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/state/type": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/type": {
		reflect.TypeOf((E_Segment_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community": {
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/state/afi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/state/safi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/state/afi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/state/safi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/state/afi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/state/nh-type": {
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger/state/reset-trigger": {
		reflect.TypeOf((E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/state/level-capability": {
		reflect.TypeOf((E_OpenconfigIsisTypes_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/timers/lsp-generation/state/adaptive-timer": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AdaptiveTimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/timers/spf/state/adaptive-timer": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AdaptiveTimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/state/afi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/state/safi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/adjacency-state": {
		reflect.TypeOf((E_OpenconfigIsisTypes_IsisInterfaceAdjState)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/adjacency-type": {
		reflect.TypeOf((E_OpenconfigIsisTypes_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/neighbor-circuit-type": {
		reflect.TypeOf((E_OpenconfigIsisTypes_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/nlpid": {
		reflect.TypeOf((E_Adjacency_Nlpid)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/topology": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
		reflect.TypeOf((E_AdjacencySid_SidId_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/label-options": {
		reflect.TypeOf((E_PrefixSid_LabelOptions)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/state/afi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/state/safi-name": {
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/state/circuit-type": {
		reflect.TypeOf((E_OpenconfigIsisTypes_CircuitType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/state/hello-padding": {
		reflect.TypeOf((E_OpenconfigIsisTypes_HelloPaddingType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/state/flags": {
		reflect.TypeOf((E_Lsp_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/state/pdu-type": {
		reflect.TypeOf((E_Lsp_PduType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/authentication/state/crypto-type": {
		reflect.TypeOf((E_Authentication_CryptoType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": {
		reflect.TypeOf((E_Flags_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": {
		reflect.TypeOf((E_PrefixSid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": {
		reflect.TypeOf((E_AdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": {
		reflect.TypeOf((E_LanAdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": {
		reflect.TypeOf((E_LinkAttributes_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": {
		reflect.TypeOf((E_LinkProtectionType_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/default-metric/state/flags": {
		reflect.TypeOf((E_DefaultMetric_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/delay-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/error-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/expense-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/default-metric/state/flags": {
		reflect.TypeOf((E_DefaultMetric_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/delay-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/error-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/expense-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-srlgs/ipv4-srlg/state/flags": {
		reflect.TypeOf((E_Ipv4Srlg_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": {
		reflect.TypeOf((E_Flags_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": {
		reflect.TypeOf((E_PrefixSid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-srlgs/ipv6-srlg/state/flags": {
		reflect.TypeOf((E_Ipv6Srlg_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/default-metric/state/flags": {
		reflect.TypeOf((E_DefaultMetric_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/delay-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/error-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/expense-metric/state/flags": {
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": {
		reflect.TypeOf((E_AdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": {
		reflect.TypeOf((E_LanAdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": {
		reflect.TypeOf((E_LinkAttributes_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": {
		reflect.TypeOf((E_LinkProtectionType_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": {
		reflect.TypeOf((E_Flags_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": {
		reflect.TypeOf((E_PrefixSid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": {
		reflect.TypeOf((E_Flags_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": {
		reflect.TypeOf((E_PrefixSid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": {
		reflect.TypeOf((E_AdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": {
		reflect.TypeOf((E_LanAdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": {
		reflect.TypeOf((E_LinkAttributes_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": {
		reflect.TypeOf((E_LinkProtectionType_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": {
		reflect.TypeOf((E_AdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": {
		reflect.TypeOf((E_LanAdjacencySid_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": {
		reflect.TypeOf((E_LinkAttributes_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": {
		reflect.TypeOf((E_LinkProtectionType_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology/topologies/topology/state/attributes": {
		reflect.TypeOf((E_Topology_Attributes)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/nlpid/state/nlpid": {
		reflect.TypeOf((E_Nlpid_Nlpid)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/state/flags": {
		reflect.TypeOf((E_Capability_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-algorithms/state/algorithm": {
		reflect.TypeOf((E_SegmentRoutingAlgorithms_Algorithm)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state/label": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/state/flags": {
		reflect.TypeOf((E_SegmentRoutingCapability_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/state/metric-style": {
		reflect.TypeOf((E_OpenconfigIsisTypes_MetricStyle)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors/neighbor/state/adjacency-state": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/state/network-type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/state/metric-type": {
		reflect.TypeOf((E_AsExternalLsa_MetricType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/state/metric-type": {
		reflect.TypeOf((E_AsExternalLsa_MetricType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state/link-type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/adjacency-sid/state/sid-type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_SrSidType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/state/address-family": {
		reflect.TypeOf((E_ExtendedPrefix_AddressFamily)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/state/route-type": {
		reflect.TypeOf((E_ExtendedPrefix_RouteType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/extended-prefix-range/state/address-family": {
		reflect.TypeOf((E_ExtendedPrefix_AddressFamily)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid/state/sid-scope": {
		reflect.TypeOf((E_PrefixSid_SidScope)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid/state/sid-value-type": {
		reflect.TypeOf((E_PrefixSid_SidValueType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/sid-label-binding/state/sid-type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_SrSidType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/state/reason": {
		reflect.TypeOf((E_Tlv_Reason)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-algorithm/state/supported-algorithms": {
		reflect.TypeOf((E_OpenconfigOspfTypes_SR_ALGORITHM)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/sid-label/state/entry-type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_SrSidType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES)(0)),
		reflect.TypeOf((E_SegmentRoutingSidLabelRange_Tlv_Type_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES)(0)),
		reflect.TypeOf((E_RouterInformation_Tlv_Type_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/state/scope": {
		reflect.TypeOf((E_OpaqueLsa_Scope)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/link-type": {
		reflect.TypeOf((E_SubTlv_LinkType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/type": {
		reflect.TypeOf((E_Link_SubTlv_Type_Enum)(0)),
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE)(0)),
		reflect.TypeOf((E_NodeAttribute_SubTlv_Type_Enum)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_ROUTER_LSA_TYPES)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/state/type": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_LSA_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links/virtual-link/state/adjacency-state": {
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/state/summary-route-cost-mode": {
		reflect.TypeOf((E_Global_SummaryRouteCostMode)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/lsa-generation/state/timer-type": {
		reflect.TypeOf((E_LsaGeneration_TimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/state/include": {
		reflect.TypeOf((E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/state/trigger": {
		reflect.TypeOf((E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/spf/state/timer-type": {
		reflect.TypeOf((E_LsaGeneration_TimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/neighbors/neighbor/state/mode": {
		reflect.TypeOf((E_OpenconfigPimTypes_PIM_MODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/state/mode": {
		reflect.TypeOf((E_OpenconfigPimTypes_PIM_MODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/state/identifier": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state/next-hop": {
		reflect.TypeOf((E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP)(0)),
	},
	"/network-instances/network-instance/route-limits/route-limit/state/afi": {
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/segment-routing/srgbs/srgb/state/dataplane-type": {
		reflect.TypeOf((E_OpenconfigSegmentRoutingTypes_SrDataplaneType)(0)),
	},
	"/network-instances/network-instance/segment-routing/srlbs/srlb/state/dataplane-type": {
		reflect.TypeOf((E_OpenconfigSegmentRoutingTypes_SrDataplaneType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/encapsulate-header": {
		reflect.TypeOf((E_OpenconfigAftTypes_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/origin-protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/pushed-mpls-label-stack": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/state/invalid-reason": {
		reflect.TypeOf((E_OpenconfigSegmentRoutingTypes_SrteInvalidSlReason)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/state/enlp": {
		reflect.TypeOf((E_OpenconfigSegmentRoutingTypes_EnlpType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/state/protocol-origin": {
		reflect.TypeOf((E_OpenconfigSegmentRoutingTypes_SrteProtocolType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid": {
		reflect.TypeOf((E_OpenconfigMplsTypes_MplsLabel_Enum)(0)),
	},
	"/network-instances/network-instance/state/enabled-address-families": {
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/state/type": {
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/address-family": {
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/default-import-policy": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/dst-protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/src-protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/tables/table/state/address-family": {
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/tables/table/state/protocol": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/vlans/vlan/state/status": {
		reflect.TypeOf((E_Vlan_Status)(0)),
	},
	"/optical-amplifier/amplifiers/amplifier/state/amp-mode": {
		reflect.TypeOf((E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_MODE)(0)),
	},
	"/optical-amplifier/amplifiers/amplifier/state/fiber-type-profile": {
		reflect.TypeOf((E_OpenconfigOpticalAmplifier_FIBER_TYPE_PROFILE)(0)),
	},
	"/optical-amplifier/amplifiers/amplifier/state/gain-range": {
		reflect.TypeOf((E_OpenconfigOpticalAmplifier_GAIN_RANGE)(0)),
	},
	"/optical-amplifier/amplifiers/amplifier/state/type": {
		reflect.TypeOf((E_OpenconfigOpticalAmplifier_OPTICAL_AMPLIFIER_TYPE)(0)),
	},
	"/routing-policy/defined-sets/prefix-sets/prefix-set/state/mode": {
		reflect.TypeOf((E_PrefixSet_Mode)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/state/mode": {
		reflect.TypeOf((E_SetTag_Mode)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/actions/state/policy-result": {
		reflect.TypeOf((E_OpenconfigRoutingPolicy_PolicyResultType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set/state/match-set-options": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set/state/match-set-options": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set/state/match-set-options": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/state/install-protocol-eq": {
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/stp/global/state/enabled-protocol": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PROTOCOL)(0)),
	},
	"/stp/interfaces/interface/state/edge-port": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_EDGE_PORT)(0)),
	},
	"/stp/interfaces/interface/state/guard": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_StpGuardType)(0)),
	},
	"/stp/interfaces/interface/state/link-type": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_StpLinkType)(0)),
	},
	"/stp/mstp/mst-instances/mst-instance/interfaces/interface/state/port-state": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PORT_STATE)(0)),
	},
	"/stp/mstp/mst-instances/mst-instance/interfaces/interface/state/role": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE)(0)),
	},
	"/stp/rapid-pvst/vlan/interfaces/interface/state/port-state": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PORT_STATE)(0)),
	},
	"/stp/rapid-pvst/vlan/interfaces/interface/state/role": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE)(0)),
	},
	"/stp/rstp/interfaces/interface/state/port-state": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PORT_STATE)(0)),
	},
	"/stp/rstp/interfaces/interface/state/role": {
		reflect.TypeOf((E_OpenconfigSpanningTreeTypes_STP_PORT_ROLE)(0)),
	},
	"/system/aaa/accounting/events/event/state/event-type": {
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE)(0)),
	},
	"/system/aaa/accounting/events/event/state/record": {
		reflect.TypeOf((E_Event_Record)(0)),
	},
	"/system/aaa/accounting/state/accounting-method": {
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/authentication/state/authentication-method": {
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/authentication/users/user/state/role": {
		reflect.TypeOf((E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES)(0)),
	},
	"/system/aaa/authorization/events/event/state/event-type": {
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE)(0)),
	},
	"/system/aaa/authorization/state/authorization-method": {
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/server-groups/server-group/state/type": {
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_SERVER_TYPE)(0)),
	},
	"/system/alarms/alarm/state/severity": {
		reflect.TypeOf((E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY)(0)),
	},
	"/system/alarms/alarm/state/type-id": {
		reflect.TypeOf((E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID)(0)),
	},
	"/system/cpus/cpu/state/index": {
		reflect.TypeOf((E_Cpu_Index_Enum)(0)),
	},
	"/system/grpc-server/state/listen-addresses": {
		reflect.TypeOf((E_GrpcServer_ListenAddresses_Enum)(0)),
	},
	"/system/logging/console/selectors/selector/state/facility": {
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/console/selectors/selector/state/severity": {
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/state/facility": {
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/state/severity": {
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/messages/debug-entries/debug-service/state/service": {
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/system/messages/state/severity": {
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/ntp/ntp-keys/ntp-key/state/key-type": {
		reflect.TypeOf((E_OpenconfigSystem_NTP_AUTH_TYPE)(0)),
	},
	"/system/ntp/servers/server/state/association-type": {
		reflect.TypeOf((E_Server_AssociationType)(0)),
	},
	"/system/ssh-server/state/protocol-version": {
		reflect.TypeOf((E_SshServer_ProtocolVersion)(0)),
	},
	"/terminal-device/logical-channels/channel/ethernet/lldp/neighbors/neighbor/state/chassis-id-type": {
		reflect.TypeOf((E_OpenconfigLldpTypes_ChassisIdType)(0)),
	},
	"/terminal-device/logical-channels/channel/ethernet/lldp/neighbors/neighbor/state/port-id-type": {
		reflect.TypeOf((E_OpenconfigLldpTypes_PortIdType)(0)),
	},
	"/terminal-device/logical-channels/channel/ethernet/state/client-als": {
		reflect.TypeOf((E_Ethernet_ClientAls)(0)),
	},
	"/terminal-device/logical-channels/channel/logical-channel-assignments/assignment/state/assignment-type": {
		reflect.TypeOf((E_Assignment_AssignmentType)(0)),
	},
	"/terminal-device/logical-channels/channel/logical-channel-assignments/assignment/state/mapping": {
		reflect.TypeOf((E_OpenconfigTransportTypes_FRAME_MAPPING_PROTOCOL)(0)),
	},
	"/terminal-device/logical-channels/channel/otn/state/tributary-slot-granularity": {
		reflect.TypeOf((E_OpenconfigTransportTypes_TRIBUTARY_SLOT_GRANULARITY)(0)),
	},
	"/terminal-device/logical-channels/channel/state/admin-state": {
		reflect.TypeOf((E_OpenconfigTransportTypes_AdminStateType)(0)),
	},
	"/terminal-device/logical-channels/channel/state/link-state": {
		reflect.TypeOf((E_Channel_LinkState)(0)),
	},
	"/terminal-device/logical-channels/channel/state/logical-channel-type": {
		reflect.TypeOf((E_OpenconfigTransportTypes_LOGICAL_ELEMENT_PROTOCOL_TYPE)(0)),
	},
	"/terminal-device/logical-channels/channel/state/loopback-mode": {
		reflect.TypeOf((E_OpenconfigTransportTypes_LoopbackModeType)(0)),
	},
	"/terminal-device/logical-channels/channel/state/rate-class": {
		reflect.TypeOf((E_OpenconfigTransportTypes_TRIBUTARY_RATE_CLASS_TYPE)(0)),
	},
	"/terminal-device/logical-channels/channel/state/trib-protocol": {
		reflect.TypeOf((E_OpenconfigTransportTypes_TRIBUTARY_PROTOCOL_TYPE)(0)),
	},
}
